(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  13337603,     383717]*)
(*NotebookOutlinePosition[  13415727,     386163]*)
(*  CellTagsIndexPosition[  13406168,     385864]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["8. Introduction to Random Processes", "Title",
  CellTags->"c:1"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["8.1 Random Walks", "Subtitle",
  CellTags->{"i:30", "c:2"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["8.1.1 Introduction", "Subsubtitle",
  CellTags->"c:3"],

Cell[TextData[{
  "How is heat conducted through a material? We know from experiment that the \
heat flux obeys Fick's law, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], " ", "=", 
          " ", \(\(-\[Kappa]\)\ \[Del]\ T\)}], TraditionalForm]]],
  ", and as a result the temperature is described by the heat equation, "
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]T/\[PartialD]t\), "=", 
          RowBox[{"\[Chi]", " ", 
            RowBox[{\(\[Del]\^2\), 
              RowBox[{"T", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.1)"],

Cell["\<\
 Why, however, does the heat flux obey Fick's law? What are the \
underlying microscopic processes that lead to this result? \
\>", "Text"],

Cell["\<\
\tIn a conductor, it is known that heat energy is carried from \
place to place mostly by the conduction electrons, which are free to move \
throughout the material. In a hot region of the conductor, the electrons on \
average move more rapidly than in the surrounding colder regions. As a \
result, they disperse through the colder electrons and carry their energy \
with them.  The resulting diffusion of heat is intimately connected to the \
diffusion of the electrons themselves. For this reason, good electrical \
conductors are also good thermal conductors.\
\>", "Text"],

Cell["\<\
\tThe electrons don't simply move in straight-line trajectories; \
otherwise they would be described by the collisionless Boltzmann equation, \
not the heat equation. Rather, the electrons collide with one another and \
with nearly stationary ions in the material.  As a result of these \
collisions, the electron dynamics is chaotic, and the electrons move \
randomly.  We will see that this random component to the dynamics is \
essential to the diffusive spreading of the temperature observed in solutions \
of the heat equation.\
\>", "Text"],

Cell["\<\
\tThese complex collisional processes require many-body quantum \
theory for their description. However, Fick's law is a very simple result. \
Furthermore, this law applies to a broad range of systems for which the \
details of the dynamics differ greatly. For example,  thermal conduction in \
nonconductors is due to the propagation of phonons (sound wave packets) \
rather than electrons, yet  Fick's law still applies.  Can we find a \
simplified model of the electron dynamics that still leads to diffusion of \
heat, but which avoids the niceties of quantum collision theory?  \
\>", \
"Text"],

Cell[TextData[{
  "\tMany  of the ideas discussed in the following sections were developed by \
Ludwig ",
  ButtonBox["Boltzmann",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Boltzmann.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ", the father of statistical physics. Important theory contributions were \
also made by Poisson, ",
  ButtonBox["Maxwell",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Maxwell.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ",  Gibbs,  Einstein, von Smoluchowski, and others.  However, we will begin \
with some  elementary ideas in probability theory, first put forward by Jacob \
",
  ButtonBox["Bernoulli",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bernoulli_\
Jacob.html"], None},
    ButtonStyle->"Hyperlink"],
  " in the seventeenth century.  "
}], "Text",
  CellTags->"i:1"]
}, Closed]],

Cell[CellGroupData[{

Cell["8.1.2 The Statistics of Random Walks", "Subsubtitle",
  CellTags->"c:4"],

Cell[CellGroupData[{

Cell["The Random Walk Model", "Section",
  CellTags->"c:5"],

Cell[TextData[{
  "\tWe will describe thermal diffusion in a conductor with a random walk \
model.  First, we will neglect quantum effects and treat the electrons as a \
gas of classical point particles. Next, we will assume that the conduction \
electrons move only in one dimension. Third, we will assume that electron \
positions are restricted to a grid of values, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"x", " ", "=", " ", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(j = \  ... \), 
          ",", \(-2\), ",", \(-1\), ",", "0", ",", "1", ",", "2", ",", 
          "..."}], TraditionalForm]]],
  ". Fourth, we will assume that there are only two groups of electrons, ",
  StyleBox["hot",
    FontSlant->"Italic"],
  " electrons with energy 1 in scaled units, and ",
  StyleBox["cold",
    FontSlant->"Italic"],
  " electrons with energy  zero, which remain stationary and so are \
unimportant.  The hot electrons diffuse, and carry their energy with them, \
causing thermal diffusion. "
}], "Text",
  CellTags->"i:2"],

Cell[TextData[{
  "\tWe will employ the following simple dynamical model  for the hot \
electrons: an electron suffers a random collision at regular time intervals \
",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". Thus",
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{
              StyleBox["\[CapitalDelta]",
                FontSlant->"Plain"], "t"}]], 
          RowBox[{"-", 
            StyleBox["1",
              FontSlant->"Plain"]}]], TraditionalForm]],
    FontSlant->"Italic"],
  StyleBox[" is roughly the electron collision frequency.",
    FontSlant->"Italic"],
  " After a collision, the electron ends up at one of the two neighboring \
grid points to its initial location. Thus, \[CapitalDelta]",
  StyleBox["x is roughly the mean free path",
    FontSlant->"Italic"],
  ", or mean distance traveled between collisions. If the electron is at grid \
point ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at time ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ",",
  " at the next timestep ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(n + 1\)\)]],
  " the electron is at either grid point  ",
  Cell[BoxData[
      \(TraditionalForm\`j - 1\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1\)]],
  ",  with equal probability. "
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  "\tWe will show that in the limit that the number of electrons ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  " and as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", "0"}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "\[Rule]", "0"}], 
        TraditionalForm]]],
  ", the number density ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  " of the hot particles obeys the diffusion equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]n\/\[PartialD]t = D\ \[Del]\^2 n\)]],
  ","
}], "NumberedEquation",
  CellTags->"(8.1.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is the ",
  StyleBox["particle diffusion coefficient",
    FontSlant->"Italic"],
  " (units ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "2"], "/", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "), related to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", " ", "=", " ", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "/", "2"}], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". Hence, in this model the thermal diffusivity is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = D\)]],
  ". "
}], "Text",
  CellTags->"i:4"],

Cell["\<\
\tThis version of the electron dynamics is called a random walk in \
one dimension.  It is not realistic as it stands, but it contains much of the \
basic physics behind the chaotic collision processes that are actually \
responsible for thermal conduction. [Some of the pitfalls associated with the \
neglect of quantum effects are considered in Exercise (12).] The same model \
can be applied to any number of other diffusive processes, such as thermal \
diffusion in nonconductors where phonons take the place of electrons, or the  \
diffusion of atoms through a gas. The model is simple enough to solve \
analytically using concepts from probability theory. Before we do so, \
however, it is entertaining and instructive to view the dynamics via a \
simulation of the random walk.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulations", "Section",
  CellTags->"c:6"],

Cell[TextData[{
  StyleBox["\tMathematica",
    FontSlant->"Italic"],
  "'s intrinsic function ",
  StyleBox["Random",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to perform random walk simulations. ",
  StyleBox["Random[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a random number in the range  from 0 to 1. ",
  StyleBox["Random[t,range]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a random number of type ",
  StyleBox["t",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["t",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " being either ",
  StyleBox["Integer",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Real",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Complex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") in the range ",
  StyleBox["range",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For instance, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Random",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["Integer",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["{",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["i",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["j",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox["}",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[" ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "yields any integer in the list  ",
  Cell[BoxData[
      \(TraditionalForm\`{i, i + 1,  ... , j}\)]],
  " with equal probability.  This means that, if we evaluate this random \
number ",
  Cell[BoxData[
      \(TraditionalForm\`N >> 1\)]],
  " times, the number of times ",
  Cell[BoxData[
      \(TraditionalForm\`H(i)\)]],
  " that integer ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " occurs is ",
  StyleBox["approximately",
    FontSlant->"Italic"],
  " the same as for any other integer in the list. More precisely, in the \
limit as ",
  Cell[BoxData[
      \(TraditionalForm\`N \[Rule] \ \[Infinity]\)]],
  ", the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(i)\)]],
  " that  ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " occurs is defined as"
}], "Text",
  CellTags->"i:6"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(i)\  = \ 
        lim\_\(N \[Rule] \ \[Infinity]\)\(H(i)\)/N\)]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.3)"],

Cell[TextData[{
  "This is simply the fraction of times that ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " occurs.  In any random process, this probability is well defined and is \
independent of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " in the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`N \[Rule] \ \[Infinity]\)]],
  ".  Integers ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are equally probable when ",
  Cell[BoxData[
      \(TraditionalForm\`P(i) = P(j)\)]],
  ".  However, for finite ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`H(i)\)]],
  " may differ substantially from the prediction based on its ",
  StyleBox["expected ",
    FontSlant->"Italic"],
  StyleBox["value",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]H\[RightAngleBracket] \((i)\)\  = \
\ N\ \(P(i)\)\)]],
  ". One of the objects of this chapter will be to examine how quantities \
such as ",
  Cell[BoxData[
      \(TraditionalForm\`H(i)\)]],
  " vary from their expected (",
  StyleBox["average",
    FontSlant->"Italic"],
  ")  values."
}], "Text",
  CellTags->"i:91"],

Cell[TextData[{
  "\tIn order to make an electron take random steps of size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " to either the left or right, define the random number function ",
  StyleBox["s[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(s[] := \ \(\(\[CapitalDelta]x\)\(\ \)\((2  Random[Integer, {0, 1}] - 
            1)\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.1"],

Cell[TextData[{
  "This function, which has no arguments, is designed to return either ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " with equal probability. (Try evaluating it several times to test this. \
Make a table of 20 values. How many times does ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " occur? )"
}], "Text"],

Cell[TextData[{
  "\tWe will follow the dynamics of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " electrons simultaneously. For the ",
  Cell[BoxData[
      \(TraditionalForm\`k\ th\ electron\)]],
  ", with position ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k\%n\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ",  the dynamics is given by the equation "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_k\%n = \ x\_k\%\(n - 1\) + \ s\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.4)"],

Cell["\<\
This equation can be programmed as a recursion relation in the \
usual way: \
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(x[k_, n_]\  := \ \(x[k, n]\  = \ 
        x[k, n - 1]\  + \ s[]\)\)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.2"],

Cell[TextData[{
  "We will follow the dynamics of ",
  Cell[BoxData[
      \(TraditionalForm\`M = 200\)]],
  " electrons for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_\(\(step\)\(\ \)\) = 50\)]],
  " steps. As an initial condition, we will start all electrons at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(x[k_, 0]\  = \ 0;\)\), "\n", 
    \(\[CapitalDelta]x\  = \ 1; M = 200; 
    Nstep\  = \ 50;\[IndentingNewLine]\), "\n", 
    \(\(positions\  = \ 
        Table[x[k, n], {k, 1, M}, {n, 0, Nstep}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.3"],

Cell[TextData[{
  "Each row in the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`positions\)]],
  " is the trajectory of a particular electron, as shown in Cell ",
  ButtonBox["8.4",
    ButtonData:>"Cell 8.4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[positions[\([10]\)], 
        AxesLabel \[Rule] {"\<n\>", "\<x/\[CapitalDelta]x\>"}];\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 8.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.210916 0.0654004 [
[.21055 .19842 -6 -9 ]
[.21055 .19842 6 0 ]
[.39729 .19842 -6 -9 ]
[.39729 .19842 6 0 ]
[.58403 .19842 -6 -9 ]
[.58403 .19842 6 0 ]
[.77077 .19842 -6 -9 ]
[.77077 .19842 6 0 ]
[.95752 .19842 -6 -9 ]
[.95752 .19842 6 0 ]
[1.025 .21092 0 -6 ]
[1.025 .21092 10 6 ]
[.01131 .08012 -12 -4.5 ]
[.01131 .08012 0 4.5 ]
[.01131 .34172 -6 -4.5 ]
[.01131 .34172 0 4.5 ]
[.01131 .47252 -6 -4.5 ]
[.01131 .47252 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21055 .21092 m
.21055 .21717 L
s
[(10)] .21055 .19842 0 1 Mshowa
.39729 .21092 m
.39729 .21717 L
s
[(20)] .39729 .19842 0 1 Mshowa
.58403 .21092 m
.58403 .21717 L
s
[(30)] .58403 .19842 0 1 Mshowa
.77077 .21092 m
.77077 .21717 L
s
[(40)] .77077 .19842 0 1 Mshowa
.95752 .21092 m
.95752 .21717 L
s
[(50)] .95752 .19842 0 1 Mshowa
.125 Mabswid
.06116 .21092 m
.06116 .21467 L
s
.09851 .21092 m
.09851 .21467 L
s
.13585 .21092 m
.13585 .21467 L
s
.1732 .21092 m
.1732 .21467 L
s
.2479 .21092 m
.2479 .21467 L
s
.28525 .21092 m
.28525 .21467 L
s
.3226 .21092 m
.3226 .21467 L
s
.35994 .21092 m
.35994 .21467 L
s
.43464 .21092 m
.43464 .21467 L
s
.47199 .21092 m
.47199 .21467 L
s
.50934 .21092 m
.50934 .21467 L
s
.54669 .21092 m
.54669 .21467 L
s
.62138 .21092 m
.62138 .21467 L
s
.65873 .21092 m
.65873 .21467 L
s
.69608 .21092 m
.69608 .21467 L
s
.73343 .21092 m
.73343 .21467 L
s
.80812 .21092 m
.80812 .21467 L
s
.84547 .21092 m
.84547 .21467 L
s
.88282 .21092 m
.88282 .21467 L
s
.92017 .21092 m
.92017 .21467 L
s
.99486 .21092 m
.99486 .21467 L
s
.25 Mabswid
0 .21092 m
1 .21092 L
s
gsave
1.025 .21092 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .08012 m
.03006 .08012 L
s
[(-2)] .01131 .08012 1 0 Mshowa
.02381 .34172 m
.03006 .34172 L
s
[(2)] .01131 .34172 1 0 Mshowa
.02381 .47252 m
.03006 .47252 L
s
[(4)] .01131 .47252 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(6)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .11282 m
.02756 .11282 L
s
.02381 .14552 m
.02756 .14552 L
s
.02381 .17822 m
.02756 .17822 L
s
.02381 .24362 m
.02756 .24362 L
s
.02381 .27632 m
.02756 .27632 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .37442 m
.02756 .37442 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .43982 m
.02756 .43982 L
s
.02381 .50522 m
.02756 .50522 L
s
.02381 .53792 m
.02756 .53792 L
s
.02381 .57062 m
.02756 .57062 L
s
.02381 .04742 m
.02756 .04742 L
s
.02381 .01472 m
.02756 .01472 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.04248 .21092 Mdot
.06116 .14552 Mdot
.07983 .08012 Mdot
.09851 .14552 Mdot
.11718 .21092 Mdot
.13585 .14552 Mdot
.15453 .08012 Mdot
.1732 .01472 Mdot
.19188 .08012 Mdot
.21055 .14552 Mdot
.22923 .08012 Mdot
.2479 .01472 Mdot
.26657 .08012 Mdot
.28525 .14552 Mdot
.30392 .08012 Mdot
.3226 .14552 Mdot
.34127 .21092 Mdot
.35994 .14552 Mdot
.37862 .21092 Mdot
.39729 .27632 Mdot
.41597 .21092 Mdot
.43464 .27632 Mdot
.45331 .34172 Mdot
.47199 .27632 Mdot
.49066 .34172 Mdot
.50934 .40712 Mdot
.52801 .47252 Mdot
.54669 .40712 Mdot
.56536 .47252 Mdot
.58403 .53792 Mdot
.60271 .60332 Mdot
.62138 .53792 Mdot
.64006 .47252 Mdot
.65873 .53792 Mdot
.6774 .47252 Mdot
.69608 .40712 Mdot
.71475 .34172 Mdot
.73343 .40712 Mdot
.7521 .47252 Mdot
.77077 .40712 Mdot
.78945 .34172 Mdot
.80812 .27632 Mdot
.8268 .34172 Mdot
.84547 .40712 Mdot
.86415 .47252 Mdot
.88282 .53792 Mdot
.90149 .60332 Mdot
.92017 .53792 Mdot
.93884 .60332 Mdot
.95752 .53792 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o5_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo0_l0000]ooooo`;o00005_ooool2
o`000?oooooo2_ooool001Kooooo00?o0000ooooooooool0;?ooool2o`0001Kooooo0_l0003ooooo
o`[ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o
0000ooooooooool0oooooom@ooooo`005_ooool2o`000?ooooooDOooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`002oooool5o`0000Kooooo00?o0000ooooooooool0
oooooom@ooooo`002oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
oooooom@ooooo`000oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`3ooooooe3ooooo000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000>ooooo`;o00005_ooool2
o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0003gooooo`003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo00kooooo0_l0000Fooooo`;o00002_ooool2o`00
00[ooooo0_l0000:ooooo`;o00002_ooool2o`000?Oooooo000?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom@ooooo`002oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0oooooom@ooooo`002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo0_l0003ooooooe7ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo0_l0
0009ooooo`;o00002_ooool2o`0000[ooooo0_l0000Fooooo`;o00005_ooool2o`0000[ooooo0_l0
000:ooooo`;o0000iOooool001Kooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000:
ooooo`;o00005_ooool2o`0001Kooooo0_l0000:ooooo`;o00002_ooool2o`000>Gooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo03?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^;_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0_ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^037ooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0`ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo000Fooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0cooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg027ooooo000Fooooo`;o0000=_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@4100;oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
4100<oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0;Oooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@400dooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool07oooool001Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000<?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool00000<_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
0000;oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000<oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool07oooool001Kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000<Ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<Oooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool00000;oooool01?oMgMgoEEEEooooool00004oooo
o`05o`000?ooooooooooooooool00000<?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`00000Qooooo`005_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400booooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0`ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400`ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400`
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400Qooooo`005_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0^ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg02oo
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<?ooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool001Kooooo00?o0000ooooooooool0<ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0_ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^037ooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^033ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h08Oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo@_ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00Gooooo000Fooooo`03o`000?oooooooooo0?oooooo@oooool0
1Ol0003ooooooooooooooooo000000Sooooo000Fooooo`03o`000?oooooooooo0?oooooo@oooool0
1Ol0003ooooooooooooooooo000000Sooooo000>oooooooo0000@ol0000;ooooo`05o`000?oooooo
ooooooooool000002?ooool001Kooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000000Sooooo000Fooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Fooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool01_ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool2o`000?ooooooDOooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool2o`0007Gooooo0_l0000:ooooo`;o00002_ooool2o`0006[ooooo0_l0001Eooooo`005_ooool0
0ol0003oooooooooo`1dooooo`;o00002_ooool2o`0000[ooooo0_l0001Zooooo`;o0000EOooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`;o0000oooooomAooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooooe3o
oooo000;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooooe3o
oooo000<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooom@ooooo`003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000Q_ooool2o`0000[ooooo0_l00016ooooo`;o00005_oo
ool2o`0000[ooooo0_l0001?ooooo`003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo08Kooooo0_l0000:ooooo`;o0000A_ooool2o`0001Kooooo0_l0000:ooooo`;o0000Coooool0
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooe3ooooo000;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooooe3ooooo000;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool2o`000?ooooooDOooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool2o`0009Wooooo0_l0000:ooooo`;o0000;_ooool2o`0000[ooooo
0_l0000:ooooo`;o00005_ooool2o`0004Wooooo000Fooooo`03o`000?oooooooooo09Sooooo0_l0
000:ooooo`;o0000;_ooool2o`0000[ooooo0_l0000:ooooo`;o00005_ooool2o`0004Wooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool2o`000?ooooooDOooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`003Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom@ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooD?ooool000_ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooD?ooool000_ooooo00Co
A4A4omgMgOoooooo00001oooool3o`0009kooooo0_l0000:ooooo`;o00005_ooool2o`0000[ooooo
0_l0000Fooooo`;o00008_ooool2o`0004?ooooo000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0W_ooool2o`0000[ooooo0_l0000Fooooo`;o00002_ooool2o`0001Kooooo
0_l0000Rooooo`;o0000@oooool000cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`3ooooooe3ooooo000<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom@
ooooo`003Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`;o0000oooooomAooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`;o0000/Oooool2o`0000[ooooo0_l0000:ooooo`;o0000
A_ooool2o`0000[ooooo0_l0000:ooooo`;o00009Oooool001Kooooo00?o0000ooooooooool0/?oo
ool2o`0000[ooooo0_l0000:ooooo`;o0000A_ooool2o`0000[ooooo0_l0000:ooooo`;o00009Ooo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`;o0000oooooomAooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000;ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000;ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000;ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`000;Kooooo0_l0001Nooooo`;o00002_ooool2o`0000[ooooo0_l0000Oooooo`002oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0]_ooool2o`0005kooooo0_l0000:
ooooo`;o00002_ooool2o`0001oooooo000;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooo
ooooool0oooooom@ooooo`002oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oo
ooooD?ooool000cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooooe3o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo000@ooooo`03ob4Q8OoMgMgooooo0?ooooooE_ooool000Sooooo0_l00002
ooooo`;o00000_ooool00onHV9SoEEEEooooo`03ooooo`03oc8b<_l0003o000000?o000000?o<S8b
ooooooooool00_l00002ooooo`;o0000oooooom4ooooo`002?ooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?o0000omgMgOooool00_ooool00onHV9SoA4A4ooooo`02ooooo`0:odA4A?nH
V9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMgOooooooA?ooool000Wooooo00CogMgMo`00
0?l@413oc<c<1?ooool2ogMgM`Cooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0
003o410@olc<c?ooooooAOooool000Wooooo00Cok^k^ob4Q8Ol@413ok^k^1?ooool00oo^k^ko410@
onk^kP03ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^kooooo
odGooooo0009ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo00?oEEEEoiRHV?ooool00_ooool01Oo^
k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8boooooom5ooooo`002?ooool2
o`0000;ooooo0_l00004ooooo`03omgMgOl@413ooooo00?ooooo00?oMgMgob4Q8OmEEED01?ooool2
o`0000;ooooo0_l0003oooooodCooooo000Cooooo`03oeEEEOnHV9Sooooo00;ooooo00?ogMgMo`00
0?oMgMd0oooooom>ooooo`004oooool00onj^[[oA4A4ooooo`03ooooo`03ojVYZOoooooooooo0?oo
ooooCOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68676, -3.22504, \
0.208569, 0.0595536}}]
}, Open  ]],

Cell["\<\
The electron wanders randomly, sometimes returning to the origin, \
but over time tending to take large excursions from its initial location. \
This can also be observed by viewing the positions of all the electrons vs. \
time using an animation.\
\>", "Text"],

Cell[TextData[{
  "\tAt timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " the positions of the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " electrons are given by the following list:"
}], "Text"],

Cell[BoxData[
    \(pos[n_]\  := \ Table[positions[\([j, n + 1]\)], {j, 1, M}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.5"],

Cell[TextData[{
  "These positions are followed in Cell ",
  ButtonBox["8.6",
    ButtonData:>"Cell 8.6",
    ButtonStyle->"Hyperlink"],
  " for 50 steps."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[pos[n], PlotRange \[Rule] {\(-30\), 30}, 
          AxesLabel \[Rule] {"\<k\>", "\<x/\[CapitalDelta]x, n= \>" <> 
                ToString[n]}], {n, 0, 50}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.6"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30902 Mdot
.03333 .30902 Mdot
.0381 .30902 Mdot
.04286 .30902 Mdot
.04762 .30902 Mdot
.05238 .30902 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .30902 Mdot
.07143 .30902 Mdot
.07619 .30902 Mdot
.08095 .30902 Mdot
.08571 .30902 Mdot
.09048 .30902 Mdot
.09524 .30902 Mdot
.1 .30902 Mdot
.10476 .30902 Mdot
.10952 .30902 Mdot
.11429 .30902 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .30902 Mdot
.14286 .30902 Mdot
.14762 .30902 Mdot
.15238 .30902 Mdot
.15714 .30902 Mdot
.1619 .30902 Mdot
.16667 .30902 Mdot
.17143 .30902 Mdot
.17619 .30902 Mdot
.18095 .30902 Mdot
.18571 .30902 Mdot
.19048 .30902 Mdot
.19524 .30902 Mdot
.2 .30902 Mdot
.20476 .30902 Mdot
.20952 .30902 Mdot
.21429 .30902 Mdot
.21905 .30902 Mdot
.22381 .30902 Mdot
.22857 .30902 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .30902 Mdot
.24762 .30902 Mdot
.25238 .30902 Mdot
.25714 .30902 Mdot
.2619 .30902 Mdot
.26667 .30902 Mdot
.27143 .30902 Mdot
.27619 .30902 Mdot
.28095 .30902 Mdot
.28571 .30902 Mdot
.29048 .30902 Mdot
.29524 .30902 Mdot
.3 .30902 Mdot
.30476 .30902 Mdot
.30952 .30902 Mdot
.31429 .30902 Mdot
.31905 .30902 Mdot
.32381 .30902 Mdot
.32857 .30902 Mdot
.33333 .30902 Mdot
.3381 .30902 Mdot
.34286 .30902 Mdot
.34762 .30902 Mdot
.35238 .30902 Mdot
.35714 .30902 Mdot
.3619 .30902 Mdot
.36667 .30902 Mdot
.37143 .30902 Mdot
.37619 .30902 Mdot
.38095 .30902 Mdot
.38571 .30902 Mdot
.39048 .30902 Mdot
.39524 .30902 Mdot
.4 .30902 Mdot
.40476 .30902 Mdot
.40952 .30902 Mdot
.41429 .30902 Mdot
.41905 .30902 Mdot
.42381 .30902 Mdot
.42857 .30902 Mdot
.43333 .30902 Mdot
.4381 .30902 Mdot
.44286 .30902 Mdot
.44762 .30902 Mdot
.45238 .30902 Mdot
.45714 .30902 Mdot
.4619 .30902 Mdot
.46667 .30902 Mdot
.47143 .30902 Mdot
.47619 .30902 Mdot
.48095 .30902 Mdot
.48571 .30902 Mdot
.49048 .30902 Mdot
.49524 .30902 Mdot
.5 .30902 Mdot
.50476 .30902 Mdot
.50952 .30902 Mdot
.51429 .30902 Mdot
.51905 .30902 Mdot
.52381 .30902 Mdot
.52857 .30902 Mdot
.53333 .30902 Mdot
.5381 .30902 Mdot
.54286 .30902 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .30902 Mdot
.5619 .30902 Mdot
.56667 .30902 Mdot
.57143 .30902 Mdot
.57619 .30902 Mdot
.58095 .30902 Mdot
.58571 .30902 Mdot
.59048 .30902 Mdot
.59524 .30902 Mdot
.6 .30902 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .30902 Mdot
.61905 .30902 Mdot
.62381 .30902 Mdot
.62857 .30902 Mdot
.63333 .30902 Mdot
.6381 .30902 Mdot
.64286 .30902 Mdot
.64762 .30902 Mdot
.65238 .30902 Mdot
.65714 .30902 Mdot
.6619 .30902 Mdot
.66667 .30902 Mdot
.67143 .30902 Mdot
.67619 .30902 Mdot
.68095 .30902 Mdot
.68571 .30902 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .30902 Mdot
.70476 .30902 Mdot
.70952 .30902 Mdot
.71429 .30902 Mdot
.71905 .30902 Mdot
.72381 .30902 Mdot
.72857 .30902 Mdot
.73333 .30902 Mdot
.7381 .30902 Mdot
.74286 .30902 Mdot
.74762 .30902 Mdot
.75238 .30902 Mdot
.75714 .30902 Mdot
.7619 .30902 Mdot
.76667 .30902 Mdot
.77143 .30902 Mdot
.77619 .30902 Mdot
.78095 .30902 Mdot
.78571 .30902 Mdot
.79048 .30902 Mdot
.79524 .30902 Mdot
.8 .30902 Mdot
.80476 .30902 Mdot
.80952 .30902 Mdot
.81429 .30902 Mdot
.81905 .30902 Mdot
.82381 .30902 Mdot
.82857 .30902 Mdot
.83333 .30902 Mdot
.8381 .30902 Mdot
.84286 .30902 Mdot
.84762 .30902 Mdot
.85238 .30902 Mdot
.85714 .30902 Mdot
.8619 .30902 Mdot
.86667 .30902 Mdot
.87143 .30902 Mdot
.87619 .30902 Mdot
.88095 .30902 Mdot
.88571 .30902 Mdot
.89048 .30902 Mdot
.89524 .30902 Mdot
.9 .30902 Mdot
.90476 .30902 Mdot
.90952 .30902 Mdot
.91429 .30902 Mdot
.91905 .30902 Mdot
.92381 .30902 Mdot
.92857 .30902 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .30902 Mdot
.94762 .30902 Mdot
.95238 .30902 Mdot
.95714 .30902 Mdot
.9619 .30902 Mdot
.96667 .30902 Mdot
.97143 .30902 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo03oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0>Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0dooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool2
o`0004?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg03Oooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool00ol0003oooooooooo`13
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Oo
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400Cooooo`00:?ooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0003o
ooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0doooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000004oooool002Sooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000003Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400kooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400hooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04Oooool002Sooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04oooool002Sooooo0_l00010ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0eooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
ooldooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:?ooool00ol0003oooooooooo`3o
ooooocGooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`008?ooooooo`0003Co00003?ooool0
1?l0003oV9RHoc8b<_o<c<`5ooooo`00:?ooooooo`0002Go00004oooool00ol0003o410@oiRHV006
ooooo`00:?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017ooooo00Co0000onk^
k_mEEEGoQhN71Oooool002Sooooo00?o0000ooooooooool0ooooooleooooo`05o`000?ooooooA4A4
o`000?l@41001?ooool002Sooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo
00Kooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`06ooooo`00
:?ooool00ol0003oooooooooo`3oooooocCooooo0_l00008ooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`3oooooockooooo
000Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo?oooool001Sooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0003ooooo
ocoooooo000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolnooooo`006Oooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooo
ockooooo000Eooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`006Oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooockooooo000Hoooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooolo
ooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooooom7
ooooo`006?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooooom7
ooooo`005Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`3oooooodOooooo000Eooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^0?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?ooool0
0olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003oooo
o`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02o`00
00;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolMooooo`000oooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3oooo
o`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@
41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0oooooolMooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool0
1Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooo
oooooooooooo0000017ooooo00Go410@oooooooooooooooooa0@403ooooooagooooo0004ooooo`04
onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKo
QhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo
1_l00009ooooo`05o`000?ooooooooooooooool00000oooooolMooooo`001?ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co
8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo0000017ooooo00Go0000oooooooo
ooooooooo`00003ooooooagooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?oo
ool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0?ooooo`05oa0@4?ooooooooooooooool@4100oooooolMoooo
o`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg0?oooooo7Oooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0`
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolMooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31932 Mdot
.03333 .29872 Mdot
.0381 .31932 Mdot
.04286 .29872 Mdot
.04762 .31932 Mdot
.05238 .31932 Mdot
.05714 .31932 Mdot
.0619 .31932 Mdot
.06667 .29872 Mdot
.07143 .29872 Mdot
.07619 .31932 Mdot
.08095 .31932 Mdot
.08571 .31932 Mdot
.09048 .31932 Mdot
.09524 .29872 Mdot
.1 .31932 Mdot
.10476 .31932 Mdot
.10952 .29872 Mdot
.11429 .31932 Mdot
.11905 .29872 Mdot
.12381 .31932 Mdot
.12857 .29872 Mdot
.13333 .29872 Mdot
.1381 .31932 Mdot
.14286 .31932 Mdot
.14762 .29872 Mdot
.15238 .31932 Mdot
.15714 .31932 Mdot
.1619 .29872 Mdot
.16667 .31932 Mdot
.17143 .31932 Mdot
.17619 .31932 Mdot
.18095 .29872 Mdot
.18571 .29872 Mdot
.19048 .31932 Mdot
.19524 .29872 Mdot
.2 .31932 Mdot
.20476 .31932 Mdot
.20952 .31932 Mdot
.21429 .31932 Mdot
.21905 .29872 Mdot
.22381 .31932 Mdot
.22857 .31932 Mdot
.23333 .31932 Mdot
.2381 .29872 Mdot
.24286 .29872 Mdot
.24762 .31932 Mdot
.25238 .29872 Mdot
.25714 .31932 Mdot
.2619 .29872 Mdot
.26667 .29872 Mdot
.27143 .29872 Mdot
.27619 .29872 Mdot
.28095 .29872 Mdot
.28571 .31932 Mdot
.29048 .29872 Mdot
.29524 .31932 Mdot
.3 .31932 Mdot
.30476 .29872 Mdot
.30952 .29872 Mdot
.31429 .29872 Mdot
.31905 .29872 Mdot
.32381 .29872 Mdot
.32857 .29872 Mdot
.33333 .29872 Mdot
.3381 .29872 Mdot
.34286 .31932 Mdot
.34762 .29872 Mdot
.35238 .31932 Mdot
.35714 .29872 Mdot
.3619 .29872 Mdot
.36667 .31932 Mdot
.37143 .29872 Mdot
.37619 .29872 Mdot
.38095 .29872 Mdot
.38571 .29872 Mdot
.39048 .31932 Mdot
.39524 .31932 Mdot
.4 .31932 Mdot
.40476 .29872 Mdot
.40952 .31932 Mdot
.41429 .29872 Mdot
.41905 .31932 Mdot
.42381 .29872 Mdot
.42857 .29872 Mdot
.43333 .31932 Mdot
.4381 .31932 Mdot
.44286 .31932 Mdot
.44762 .31932 Mdot
.45238 .29872 Mdot
.45714 .29872 Mdot
.4619 .31932 Mdot
.46667 .29872 Mdot
.47143 .31932 Mdot
.47619 .29872 Mdot
.48095 .31932 Mdot
.48571 .29872 Mdot
.49048 .29872 Mdot
.49524 .31932 Mdot
.5 .29872 Mdot
.50476 .31932 Mdot
.50952 .29872 Mdot
.51429 .31932 Mdot
.51905 .29872 Mdot
.52381 .29872 Mdot
.52857 .31932 Mdot
.53333 .29872 Mdot
.5381 .29872 Mdot
.54286 .29872 Mdot
.54762 .29872 Mdot
.55238 .31932 Mdot
.55714 .29872 Mdot
.5619 .31932 Mdot
.56667 .29872 Mdot
.57143 .29872 Mdot
.57619 .29872 Mdot
.58095 .29872 Mdot
.58571 .29872 Mdot
.59048 .29872 Mdot
.59524 .31932 Mdot
.6 .29872 Mdot
.60476 .29872 Mdot
.60952 .29872 Mdot
.61429 .31932 Mdot
.61905 .31932 Mdot
.62381 .31932 Mdot
.62857 .29872 Mdot
.63333 .29872 Mdot
.6381 .31932 Mdot
.64286 .31932 Mdot
.64762 .29872 Mdot
.65238 .31932 Mdot
.65714 .29872 Mdot
.6619 .29872 Mdot
.66667 .29872 Mdot
.67143 .29872 Mdot
.67619 .31932 Mdot
.68095 .31932 Mdot
.68571 .29872 Mdot
.69048 .29872 Mdot
.69524 .29872 Mdot
.7 .29872 Mdot
.70476 .29872 Mdot
.70952 .31932 Mdot
.71429 .31932 Mdot
.71905 .29872 Mdot
.72381 .29872 Mdot
.72857 .31932 Mdot
.73333 .29872 Mdot
.7381 .29872 Mdot
.74286 .31932 Mdot
.74762 .29872 Mdot
.75238 .31932 Mdot
.75714 .31932 Mdot
.7619 .29872 Mdot
.76667 .29872 Mdot
.77143 .31932 Mdot
.77619 .29872 Mdot
.78095 .29872 Mdot
.78571 .31932 Mdot
.79048 .29872 Mdot
.79524 .31932 Mdot
.8 .29872 Mdot
.80476 .29872 Mdot
.80952 .29872 Mdot
.81429 .29872 Mdot
.81905 .31932 Mdot
.82381 .31932 Mdot
.82857 .31932 Mdot
.83333 .29872 Mdot
.8381 .31932 Mdot
.84286 .29872 Mdot
.84762 .29872 Mdot
.85238 .29872 Mdot
.85714 .31932 Mdot
.8619 .29872 Mdot
.86667 .31932 Mdot
.87143 .29872 Mdot
.87619 .31932 Mdot
.88095 .31932 Mdot
.88571 .29872 Mdot
.89048 .31932 Mdot
.89524 .31932 Mdot
.9 .29872 Mdot
.90476 .29872 Mdot
.90952 .29872 Mdot
.91429 .31932 Mdot
.91905 .29872 Mdot
.92381 .29872 Mdot
.92857 .31932 Mdot
.93333 .29872 Mdot
.9381 .29872 Mdot
.94286 .29872 Mdot
.94762 .31932 Mdot
.95238 .29872 Mdot
.95714 .29872 Mdot
.9619 .29872 Mdot
.96667 .31932 Mdot
.97143 .29872 Mdot
.97619 .29872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo03oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0>Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0dooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool2
o`0004?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg03Oooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool00ol0003oooooooooo`13
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Oo
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400Cooooo`00:?ooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0003o
ooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0doooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000004oooool002Sooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000003Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400kooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400hooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04Oooool002Sooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04oooool002Sooooo0_l00010ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0eooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`05o`000?oooooo0000o`000?ooool00_l00005ooooo`?o00001_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`00
0003ooooool0003o000000Kooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo2_l00003
ooooo`co000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000005o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool4o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000004o`00
0004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000000ol00004ooooo`?o00000oooool2
o`000003ooooool0003o000000Co00000_ooool8o`0000?ooooo0ol000001Ooooooo0000o`000?l0
003ooooo00;o00000oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol0
0004ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000?o
000000Coooooo`000?l0003o00007?ooool002Sooooo00Go0000ooooool0003o0000ooooo`02o`00
00Gooooo0ol00006ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00000oooool2
o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?ooool:o`0000?ooooo3?l000001?oooooo0000o`000?ooool3o`000003oooo
ool0003o000000Go00000oooool2o`000004ooooool0003o0000ooooo`Co00001Oooool3o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool6
o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`00
0003o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`So00000ooo
ool3o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`?o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo
00Go000000?oooooo`000?l000000ol000001?oooooo0000o`000?l0000Booooo`;o00000_ooool0
0ol@413o0000o`000003ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00Go0000oooo
ooo^k^ko<S8bolc<c004ooooo`008?ooooooo`0003Co00003?ooool01?l0003oV9RHoc8b<_o<c<`5
ooooo`00:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04Oooool00ol0003o410@oiRHV006ooooo`00:?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002Sooooo0_l000001?oooooo
0000o`000?ooool6o`0000?ooooo1_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00;o00000oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00003oooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooo
oooo0000o`000007ooooo`;o000000Coooooo`000?l0003o00002oooool2o`000003ooooool0003o
000000?ooooo0_l00005ooooo`Go000000Coooooo`000?l0003ooooo0_l00002ooooo`Oo00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool4o`0000?o
oooo0ol000000ooooooo0000o`000006ooooo`?o00001oooool3o`0000?ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`Go000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000ooooo`?o000000?ooooo
o`000?l000000_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00005_ooool0
1Ol0003oooooodA4A?l0003o410@00Cooooo000Xooooo`;o000000Coooooo`000?l0003ooooo1_l0
0003ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo0ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0
003o000000Co000000?oooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000001ooo
ool2o`000004ooooool0003o0000o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1Oooool5o`000004ooooool0003o0000ooooo`;o00000_ooool7o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo1?l00003ooooo`?o000000?ooooo
o`000?l000001_ooool3o`0000Oooooo0ol00003ooooo`;o00000_ooool2o`000004ooooool0003o
0000o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool5o`000003ooooool0
003o000000Cooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000;o0000
0oooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0001Kooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo0?oooooo=?ooool2o`0000Sooooo000Xooooo`;o0000oooooolooooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoo
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo
?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`005_ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo?_ooool0
01Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`006?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
ooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`005_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoo
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo
?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool001Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`3oooooockooooo000Eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`005_oo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`000?oooooo
?oooool001Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolnooooo`006?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Iooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
?_ooool001Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So410@o`000?lb
<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo
?_ooool001Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`3oooooockooooo000Iooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo
00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooocoo
oooo000Gooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodOo
oooo000Hooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodOo
oooo000Eooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?ooooooAoooool001Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03
ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo
00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo00oooooo1?l000000ol@413oooooooooo`3ooooooa[ooooo0003ooooo`06onk^
k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?ooooo00[o
A4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@400<
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?o0000ooooooooool0oooo
oolLooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooo
oooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo0000
01Cooooo00?o0000ooooooooool0oooooolLooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5oooo
o`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o
410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003ooooo
ooooo`3ooooooacooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?oooooo
ooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7
QhOoooooojVYZOl000005?ooool00ol0003oooooooooo`3ooooooacooooo0003ooooo`;o00000_oo
ool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_oo
ool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oo
oooooooo0?oooooo7?ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03Cooooo
00?o0000ooooooooool0oooooolLooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoo
oooooooo037ooooo00?oEEEEofIVI_l00000oooooolNooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30902 Mdot
.03333 .28842 Mdot
.0381 .30902 Mdot
.04286 .30902 Mdot
.04762 .30902 Mdot
.05238 .30902 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .28842 Mdot
.07143 .28842 Mdot
.07619 .32962 Mdot
.08095 .32962 Mdot
.08571 .30902 Mdot
.09048 .32962 Mdot
.09524 .30902 Mdot
.1 .30902 Mdot
.10476 .32962 Mdot
.10952 .28842 Mdot
.11429 .30902 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .30902 Mdot
.14286 .30902 Mdot
.14762 .28842 Mdot
.15238 .32962 Mdot
.15714 .32962 Mdot
.1619 .30902 Mdot
.16667 .32962 Mdot
.17143 .32962 Mdot
.17619 .32962 Mdot
.18095 .28842 Mdot
.18571 .30902 Mdot
.19048 .32962 Mdot
.19524 .28842 Mdot
.2 .32962 Mdot
.20476 .32962 Mdot
.20952 .30902 Mdot
.21429 .32962 Mdot
.21905 .30902 Mdot
.22381 .30902 Mdot
.22857 .30902 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .30902 Mdot
.24762 .30902 Mdot
.25238 .28842 Mdot
.25714 .30902 Mdot
.2619 .28842 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .30902 Mdot
.28095 .30902 Mdot
.28571 .32962 Mdot
.29048 .30902 Mdot
.29524 .32962 Mdot
.3 .30902 Mdot
.30476 .28842 Mdot
.30952 .30902 Mdot
.31429 .30902 Mdot
.31905 .30902 Mdot
.32381 .28842 Mdot
.32857 .30902 Mdot
.33333 .30902 Mdot
.3381 .30902 Mdot
.34286 .30902 Mdot
.34762 .30902 Mdot
.35238 .30902 Mdot
.35714 .30902 Mdot
.3619 .30902 Mdot
.36667 .32962 Mdot
.37143 .28842 Mdot
.37619 .30902 Mdot
.38095 .30902 Mdot
.38571 .28842 Mdot
.39048 .32962 Mdot
.39524 .30902 Mdot
.4 .30902 Mdot
.40476 .28842 Mdot
.40952 .32962 Mdot
.41429 .28842 Mdot
.41905 .32962 Mdot
.42381 .28842 Mdot
.42857 .28842 Mdot
.43333 .30902 Mdot
.4381 .30902 Mdot
.44286 .30902 Mdot
.44762 .32962 Mdot
.45238 .28842 Mdot
.45714 .30902 Mdot
.4619 .30902 Mdot
.46667 .28842 Mdot
.47143 .32962 Mdot
.47619 .28842 Mdot
.48095 .32962 Mdot
.48571 .30902 Mdot
.49048 .30902 Mdot
.49524 .32962 Mdot
.5 .28842 Mdot
.50476 .30902 Mdot
.50952 .30902 Mdot
.51429 .30902 Mdot
.51905 .28842 Mdot
.52381 .30902 Mdot
.52857 .32962 Mdot
.53333 .30902 Mdot
.5381 .30902 Mdot
.54286 .30902 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .28842 Mdot
.5619 .30902 Mdot
.56667 .30902 Mdot
.57143 .30902 Mdot
.57619 .30902 Mdot
.58095 .30902 Mdot
.58571 .30902 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .28842 Mdot
.60476 .28842 Mdot
.60952 .30902 Mdot
.61429 .32962 Mdot
.61905 .30902 Mdot
.62381 .32962 Mdot
.62857 .30902 Mdot
.63333 .28842 Mdot
.6381 .30902 Mdot
.64286 .32962 Mdot
.64762 .30902 Mdot
.65238 .30902 Mdot
.65714 .30902 Mdot
.6619 .28842 Mdot
.66667 .28842 Mdot
.67143 .28842 Mdot
.67619 .32962 Mdot
.68095 .30902 Mdot
.68571 .28842 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .30902 Mdot
.70476 .30902 Mdot
.70952 .32962 Mdot
.71429 .32962 Mdot
.71905 .30902 Mdot
.72381 .28842 Mdot
.72857 .30902 Mdot
.73333 .30902 Mdot
.7381 .28842 Mdot
.74286 .30902 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .32962 Mdot
.7619 .30902 Mdot
.76667 .28842 Mdot
.77143 .30902 Mdot
.77619 .28842 Mdot
.78095 .30902 Mdot
.78571 .30902 Mdot
.79048 .30902 Mdot
.79524 .32962 Mdot
.8 .30902 Mdot
.80476 .30902 Mdot
.80952 .28842 Mdot
.81429 .30902 Mdot
.81905 .30902 Mdot
.82381 .30902 Mdot
.82857 .32962 Mdot
.83333 .28842 Mdot
.8381 .30902 Mdot
.84286 .30902 Mdot
.84762 .28842 Mdot
.85238 .30902 Mdot
.85714 .30902 Mdot
.8619 .28842 Mdot
.86667 .30902 Mdot
.87143 .28842 Mdot
.87619 .30902 Mdot
.88095 .30902 Mdot
.88571 .28842 Mdot
.89048 .32962 Mdot
.89524 .32962 Mdot
.9 .28842 Mdot
.90476 .28842 Mdot
.90952 .30902 Mdot
.91429 .32962 Mdot
.91905 .30902 Mdot
.92381 .28842 Mdot
.92857 .32962 Mdot
.93333 .30902 Mdot
.9381 .28842 Mdot
.94286 .30902 Mdot
.94762 .32962 Mdot
.95238 .30902 Mdot
.95714 .28842 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .30902 Mdot
.97619 .28842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo03oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0>Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0dooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool2
o`0004?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg03Oooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool00ol0003oooooooooo`13
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Oo
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400Cooooo`00:?ooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0003o
ooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0doooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000004oooool002Sooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000003Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400kooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400hooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04Oooool002Sooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04oooool002Sooooo1?l00008ooooo`?o00002_ooool2o`0000[o
oooo0_l00008ooooo`;o00000_ooool2o`0000gooooo1Ol000001?oooooo0000o`000?lb<S82o`00
0003onk^k_oooooooooo00Gooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00000_ooool2o`000003ofIVI_l0003o
000000?ooooo00?ok^k^oc8b<_l000000_l00003ooooo`?o000000?o<S8bonk^k_ooool01_ooool2
o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00007ooooo`Go00000_ooool2
o`0000Gooooo00?oEEEEofIVI_l000000_ooool2o`000003ooooool0003o000000;o00000oooool0
0oo^k^ko<S8bo`000002o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool4o`0000?ooooo0_l00003
ooooo`;o000000Co410@o`000?lQ8B7oc<c<0ol000001Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool01?l0003oooooo`000?l00008ooooo`?o
00002_ooool2o`0000[ooooo0_l00008ooooo`;o00000_ooool2o`00013ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002
o`0000Kooooo0_l00007ooooo`Go00000_ooool2o`0000[ooooo0_l00002ooooo`;o00001oooool2
o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000_ooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool3
o`0000;ooooo0_l0000Looooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooldooooo`;o0000
0_ooool00ol@413o0000o`000003ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00Go
0000ooooooo^k^ko<S8bolc<c004ooooo`008?ooooooo`0003Co00003?ooool01?l0003oV9RHoc8b
<_o<c<`5ooooo`00:?ooool2o`000003ooooool0003o000000Oo00000_ooool01?l0003ooooooooo
ooooool2o`000004ooooool0003o0000o`0000?ooooo2_l00004ooooo`?o00001?ooool2o`0000Ko
oooo3Ol000000ooooooo0000o`000003o`000003ooooool0003o000000Co000000Coooooo`000?l0
003ooooo1Ol000000ooooooo0000o`00000:o`0000?ooooo0ol00003ooooo`Co00001oooool5o`00
00;ooooo1?l00005ooooo`Co000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool8
o`000003ooooool0003o000000Oo000000?oooooo`000?ooool00_ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000001_l00005ooooo`;o000000?oooooo`000?l000001?l0
0003ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o000000Coooooo`000?l0003ooooo
2Ol000000ooooooo0000o`000003o`000003ooooool0003o000000Oo000000Coooooo`000?l0003o
oooo0ol00007ooooo`;o000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?ooool2
o`0000;ooooo1Ol0000Cooooo`03o`000?l@413oV9RH00Kooooo000Xooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:?ooool00ol0
003oooooooooo`3oooooocGooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:?ooool00ol0
003oooooooooo`3oooooocGooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000oooooooo
ool0ooooooleooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo00cooooo
0ol000000ooooooo0000o`000003ooooo`;o00003?ooool4o`000003ooooool0003o000000;o0000
0oooool2o`000005ooooool0003o0000o`000?ooool00_l0000Dooooo`;o000000?oooooo`000?l0
00005?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0001?ooooo0_l00004ooooo`Co
00001?ooool2o`0000Wooooo0_l00008ooooo`?o00002_ooool3o`0000[ooooo0_l00008ooooo`;o
00004Oooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0001[ooooo0_l00008ooooo`00
:?ooool2o`0000gooooo0ol000000ooooooo0000o`000003ooooo`;o00003?ooool4o`000003oooo
ool0003o000000;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0000Dooooo`;o
000000?oooooo`000?l000005?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0001?o
oooo0_l00004ooooo`Co00001?ooool2o`0000Wooooo0_l00008ooooo`?o00002_ooool3o`0000[o
oooo0_l00008ooooo`;o00004Oooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0002Co
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo
?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooo
ooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnoooo
o`006?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooocoooooo000Hooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo
?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooo
ooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`005Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000F
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000oooo
ooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolooooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooo
oolnooooo`005Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolnooooo`006?oo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo
?oooool001Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo00000?oooooo
Aoooool001Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@0?oooooo
Aoooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0oooooom7ooooo`005Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP3oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?ooooooA?ooool000cooooo
00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l00002ooooo`;o00000ooo
ool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o<S8booooooooool00_l0
0002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool03_ooool5o`000?oooooo7Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zj
o`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHoooooooo
ooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000oooo
ooooooooooooo`000002ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A40?oooooo7Ooo
ool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgM
oa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03oiRHV?lQ8B7ok^k^0?oooooo7_ooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^
k^ko410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^
k^hBooooo`05o`000?ooooooooooooooool000000_ooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h0
oooooolMooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^
k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooo
oonYZJWo000001Cooooo00?oMgMgofIVI_ooool0oooooolLooooo`000oooool2o`0000;ooooo0_l0
0005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0
000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04oooool00ol0003ooooooooo
o`3ooooooa_ooooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0aooooo`05o`00
0?nj^[[ooooooiRHV?l@4100oooooolMooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVY
ZOoooooooooo033ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooooagooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31932 Mdot
.03333 .29872 Mdot
.0381 .31932 Mdot
.04286 .29872 Mdot
.04762 .31932 Mdot
.05238 .31932 Mdot
.05714 .31932 Mdot
.0619 .31932 Mdot
.06667 .29872 Mdot
.07143 .29872 Mdot
.07619 .31932 Mdot
.08095 .33992 Mdot
.08571 .29872 Mdot
.09048 .31932 Mdot
.09524 .31932 Mdot
.1 .29872 Mdot
.10476 .31932 Mdot
.10952 .29872 Mdot
.11429 .29872 Mdot
.11905 .29872 Mdot
.12381 .31932 Mdot
.12857 .29872 Mdot
.13333 .29872 Mdot
.1381 .31932 Mdot
.14286 .31932 Mdot
.14762 .29872 Mdot
.15238 .31932 Mdot
.15714 .33992 Mdot
.1619 .31932 Mdot
.16667 .31932 Mdot
.17143 .33992 Mdot
.17619 .33992 Mdot
.18095 .29872 Mdot
.18571 .29872 Mdot
.19048 .33992 Mdot
.19524 .29872 Mdot
.2 .31932 Mdot
.20476 .33992 Mdot
.20952 .31932 Mdot
.21429 .33992 Mdot
.21905 .29872 Mdot
.22381 .29872 Mdot
.22857 .29872 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .29872 Mdot
.24762 .29872 Mdot
.25238 .29872 Mdot
.25714 .29872 Mdot
.2619 .29872 Mdot
.26667 .31932 Mdot
.27143 .27812 Mdot
.27619 .29872 Mdot
.28095 .29872 Mdot
.28571 .31932 Mdot
.29048 .31932 Mdot
.29524 .33992 Mdot
.3 .29872 Mdot
.30476 .27812 Mdot
.30952 .31932 Mdot
.31429 .31932 Mdot
.31905 .31932 Mdot
.32381 .27812 Mdot
.32857 .31932 Mdot
.33333 .29872 Mdot
.3381 .29872 Mdot
.34286 .31932 Mdot
.34762 .29872 Mdot
.35238 .31932 Mdot
.35714 .31932 Mdot
.3619 .29872 Mdot
.36667 .33992 Mdot
.37143 .29872 Mdot
.37619 .31932 Mdot
.38095 .29872 Mdot
.38571 .29872 Mdot
.39048 .33992 Mdot
.39524 .29872 Mdot
.4 .29872 Mdot
.40476 .29872 Mdot
.40952 .31932 Mdot
.41429 .29872 Mdot
.41905 .31932 Mdot
.42381 .27812 Mdot
.42857 .27812 Mdot
.43333 .29872 Mdot
.4381 .31932 Mdot
.44286 .29872 Mdot
.44762 .33992 Mdot
.45238 .29872 Mdot
.45714 .31932 Mdot
.4619 .31932 Mdot
.46667 .27812 Mdot
.47143 .31932 Mdot
.47619 .29872 Mdot
.48095 .31932 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .33992 Mdot
.5 .29872 Mdot
.50476 .31932 Mdot
.50952 .31932 Mdot
.51429 .31932 Mdot
.51905 .29872 Mdot
.52381 .31932 Mdot
.52857 .33992 Mdot
.53333 .29872 Mdot
.5381 .29872 Mdot
.54286 .29872 Mdot
.54762 .31932 Mdot
.55238 .29872 Mdot
.55714 .29872 Mdot
.5619 .29872 Mdot
.56667 .29872 Mdot
.57143 .29872 Mdot
.57619 .31932 Mdot
.58095 .29872 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .31932 Mdot
.6 .27812 Mdot
.60476 .29872 Mdot
.60952 .31932 Mdot
.61429 .33992 Mdot
.61905 .29872 Mdot
.62381 .33992 Mdot
.62857 .31932 Mdot
.63333 .27812 Mdot
.6381 .31932 Mdot
.64286 .33992 Mdot
.64762 .31932 Mdot
.65238 .31932 Mdot
.65714 .31932 Mdot
.6619 .27812 Mdot
.66667 .27812 Mdot
.67143 .29872 Mdot
.67619 .33992 Mdot
.68095 .31932 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .31932 Mdot
.7 .31932 Mdot
.70476 .31932 Mdot
.70952 .31932 Mdot
.71429 .31932 Mdot
.71905 .29872 Mdot
.72381 .29872 Mdot
.72857 .31932 Mdot
.73333 .29872 Mdot
.7381 .29872 Mdot
.74286 .29872 Mdot
.74762 .29872 Mdot
.75238 .33992 Mdot
.75714 .33992 Mdot
.7619 .29872 Mdot
.76667 .29872 Mdot
.77143 .29872 Mdot
.77619 .27812 Mdot
.78095 .31932 Mdot
.78571 .29872 Mdot
.79048 .29872 Mdot
.79524 .31932 Mdot
.8 .29872 Mdot
.80476 .31932 Mdot
.80952 .27812 Mdot
.81429 .29872 Mdot
.81905 .31932 Mdot
.82381 .29872 Mdot
.82857 .31932 Mdot
.83333 .29872 Mdot
.8381 .29872 Mdot
.84286 .31932 Mdot
.84762 .27812 Mdot
.85238 .29872 Mdot
.85714 .29872 Mdot
.8619 .29872 Mdot
.86667 .31932 Mdot
.87143 .29872 Mdot
.87619 .29872 Mdot
.88095 .29872 Mdot
.88571 .29872 Mdot
.89048 .33992 Mdot
.89524 .31932 Mdot
.9 .27812 Mdot
.90476 .27812 Mdot
.90952 .31932 Mdot
.91429 .31932 Mdot
.91905 .29872 Mdot
.92381 .27812 Mdot
.92857 .31932 Mdot
.93333 .29872 Mdot
.9381 .27812 Mdot
.94286 .31932 Mdot
.94762 .33992 Mdot
.95238 .29872 Mdot
.95714 .27812 Mdot
.9619 .29872 Mdot
.96667 .29872 Mdot
.97143 .29872 Mdot
.97619 .27812 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo03oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0>Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0dooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool2
o`0004?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg03Oooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool00ol0003oooooooooo`13
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Oo
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400Cooooo`00:?ooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0003o
ooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0doooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000004oooool002Sooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00?o0000ooooool000000_l00007ooooo`;o00001?ooool2o`0001cooooo1?l0
0009ooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Dooooo`;o00002?ooool2o`0000Oooooo1?l00003ooooo`;o
00001oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01_l0
003ooooooooooooooooo0000ooooo`;o00002?ooool2o`0000[ooooo0_l0000>ooooo`Co00000ooo
ool2o`0000?ooooo0_l00002ooooo`07ogMgMomVIVKo0000o`000?oooooo0000ooooo`03o`0000?o
oooo00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Cooooo00Go410@ooooool0003o0000oa0@4007ooooo`;o00001?ooool2o`00
01cooooo1?l00009ooooo`;o000000?oooooo`000?ooool00oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400Dooooo`;o00002?ooool2o`0000Oooooo1?l0
0003ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Ko
410@oooooooooooooooooa0@4?ooool2o`0000Sooooo0_l0000:ooooo`;o00003_ooool4o`0000?o
oooo0_l00003ooooo`;o00000oooool3o`000003ooooool@413ooooo00;o000000Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000Xooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000Xooooo`;o0000@?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool00omEEEGoIVIV
o`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01?ooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool01Ol0003oooooo`000?l0003ooooo00;o00001Oooool3o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00003
ooooo`;o00002?ooool3o`000003ooooool0003o000000Kooooo3ol00002ooooo`Co00000oooool2
o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo1Ol000000ooooooo0000
o`000005o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o
00001?ooool2o`0000Oooooo0ol000000ooooooo0000o`000004o`0000?ooooo1Ol00002ooooo`Ko
00000oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool5o`000003ooooool0003o0000
00Go00002?ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Moooo
o`00:?ooool01Ol0003oooooo`000?l0003ooooo00;o00001Oooool3o`0000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00003ooooo`;o00002?ooool3
o`000003ooooool0003o000000Kooooo3ol00002ooooo`Co00000oooool2o`0000Wooooo0ol00000
0ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo
0_l00006ooooo`;o00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`000005o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o00001?ooool2o`0000Oo
oooo0ol000000ooooooo0000o`000004o`0000?ooooo1Ol00002ooooo`Ko00000oooool2o`000004
ooooool0003o0000ooooo`?o00000_ooool5o`000003ooooool0003o000000Go00002?ooool2o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Cooooo`;o00000_ooool00ol@
413o0000o`000003ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00Go0000ooooooo^
k^ko<S8bolc<c004ooooo`008?ooooooo`0003Co00003?ooool01?l0003oV9RHoc8b<_o<c<`5oooo
o`00:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003o410@oiRHV006ooooo`00:?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002Sooooo0_l000001?oooooo0000
o`000?ooool6o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0000?o
oooo0ol000001?oooooo0000o`000?ooool4o`0000Sooooo0_l000000ooooooo0000o`00000?oooo
o`;o00001?ooool3o`0000Cooooo1Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
o`Co000000Coooooo`000?l0003ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001Oooool2
o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo1Ol00005ooooo`;o00000_ooool8o`0000?ooooo0_l0000>ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1Oooool2o`0000Oooooo0_l00002ooooo`?o00000oooool2o`0000;ooooo0_l0000Mooooo`05o`00
0?ooooooA4A4o`000?l@41001?ooool002Sooooo0_l000001?oooooo0000o`000?ooool6o`0000?o
oooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0000?ooooo0ol000001?oooooo
0000o`000?ooool4o`0000Sooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool3o`00
00Cooooo1Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co000000Coooooo`00
0?l0003ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
1Ol00005ooooo`;o00000_ooool8o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000Oooooo
0_l00002ooooo`?o00000oooool2o`0000;ooooo0_l0000Mooooo`03o`000?oooooooooo00Kooooo
000Xooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`06ooooo`00:?ooool0
0ol0003oooooooooo`3oooooocCooooo0_l00008ooooo`00:?ooool2o`000?oooooo?oooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`0=ooooo`;o0000
5_ooool2o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000001Oooooo
0_l0000Dooooo`;o00001Oooool2o`00013ooooo0_l0000<ooooo`;o00002?ooool2o`0001Wooooo
1?l00004ooooo`;o00002Oooool2o`0001Gooooo0ol0000Wooooo`;o00004?ooool2o`0002Cooooo
000Xooooo`03o`000?oooooooooo00gooooo0_l0000Fooooo`;o00000_ooool3o`0000?ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000005oooool2o`0001Cooooo0_l00005ooooo`;o00004?oo
ool2o`0000cooooo0_l00008ooooo`;o00006Oooool4o`0000Cooooo0_l00009ooooo`;o00005Ooo
ool3o`0002Oooooo0_l0000@ooooo`;o00009?ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`3oooooockooooo000Hoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo?oooool001Sooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0ooooooln
ooooo`006?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0003oooooocoooooo
000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo?_ooool001Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolnooooo`006Oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooockooooo
000Eooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo?_ooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool0
0ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xoooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooockooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolnooooo`006Oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
5oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooooom7ooooo`00
6?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooooom7ooooo`00
5Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
odOooooo000Eooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^0?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7o
gMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003ooooo`03oiRH
V?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02o`0000;ooooo
0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0>ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0oooooolMooooo`000oooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4
A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb
<S80oooooolMooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413o
gMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooo
oooo000001Gooooo00?o0000ooooooooool0oooooolKooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^
k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^
k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00onY
ZJWo410@ooooo`3ooooooacooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRH
V?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05
o`000?n7QhOoooooojVYZOl000004oooool00ol@413o0000okZj^P3ooooooagooooo0003ooooo`;o
00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o
00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03
okZj^_lQ8B7ooooo0?oooooo7?ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM
037ooooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooagooooo000?ooooo`03okZj^_m4A4Cooooo
00;ooooo00?oZJVYooooooooool0<?ooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo7Oooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32962 Mdot
.03333 .28842 Mdot
.0381 .30902 Mdot
.04286 .28842 Mdot
.04762 .32962 Mdot
.05238 .32962 Mdot
.05714 .32962 Mdot
.0619 .32962 Mdot
.06667 .28842 Mdot
.07143 .30902 Mdot
.07619 .32962 Mdot
.08095 .35022 Mdot
.08571 .28842 Mdot
.09048 .30902 Mdot
.09524 .30902 Mdot
.1 .30902 Mdot
.10476 .30902 Mdot
.10952 .30902 Mdot
.11429 .28842 Mdot
.11905 .28842 Mdot
.12381 .32962 Mdot
.12857 .28842 Mdot
.13333 .28842 Mdot
.1381 .30902 Mdot
.14286 .30902 Mdot
.14762 .30902 Mdot
.15238 .32962 Mdot
.15714 .35022 Mdot
.1619 .30902 Mdot
.16667 .32962 Mdot
.17143 .35022 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .30902 Mdot
.19048 .35022 Mdot
.19524 .28842 Mdot
.2 .30902 Mdot
.20476 .35022 Mdot
.20952 .30902 Mdot
.21429 .35022 Mdot
.21905 .28842 Mdot
.22381 .28842 Mdot
.22857 .28842 Mdot
.23333 .30902 Mdot
.2381 .28842 Mdot
.24286 .30902 Mdot
.24762 .28842 Mdot
.25238 .30902 Mdot
.25714 .30902 Mdot
.2619 .28842 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .28842 Mdot
.28095 .28842 Mdot
.28571 .32962 Mdot
.29048 .30902 Mdot
.29524 .32962 Mdot
.3 .30902 Mdot
.30476 .26781 Mdot
.30952 .32962 Mdot
.31429 .32962 Mdot
.31905 .32962 Mdot
.32381 .28842 Mdot
.32857 .32962 Mdot
.33333 .30902 Mdot
.3381 .28842 Mdot
.34286 .32962 Mdot
.34762 .30902 Mdot
.35238 .32962 Mdot
.35714 .30902 Mdot
.3619 .28842 Mdot
.36667 .35022 Mdot
.37143 .28842 Mdot
.37619 .30902 Mdot
.38095 .28842 Mdot
.38571 .28842 Mdot
.39048 .32962 Mdot
.39524 .28842 Mdot
.4 .28842 Mdot
.40476 .28842 Mdot
.40952 .32962 Mdot
.41429 .28842 Mdot
.41905 .30902 Mdot
.42381 .26781 Mdot
.42857 .26781 Mdot
.43333 .30902 Mdot
.4381 .32962 Mdot
.44286 .30902 Mdot
.44762 .35022 Mdot
.45238 .30902 Mdot
.45714 .32962 Mdot
.4619 .32962 Mdot
.46667 .28842 Mdot
.47143 .30902 Mdot
.47619 .30902 Mdot
.48095 .30902 Mdot
.48571 .30902 Mdot
.49048 .32962 Mdot
.49524 .35022 Mdot
.5 .30902 Mdot
.50476 .32962 Mdot
.50952 .30902 Mdot
.51429 .32962 Mdot
.51905 .28842 Mdot
.52381 .32962 Mdot
.52857 .32962 Mdot
.53333 .28842 Mdot
.5381 .30902 Mdot
.54286 .30902 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .30902 Mdot
.5619 .28842 Mdot
.56667 .30902 Mdot
.57143 .30902 Mdot
.57619 .32962 Mdot
.58095 .28842 Mdot
.58571 .30902 Mdot
.59048 .28842 Mdot
.59524 .30902 Mdot
.6 .26781 Mdot
.60476 .28842 Mdot
.60952 .32962 Mdot
.61429 .35022 Mdot
.61905 .28842 Mdot
.62381 .35022 Mdot
.62857 .32962 Mdot
.63333 .26781 Mdot
.6381 .32962 Mdot
.64286 .35022 Mdot
.64762 .30902 Mdot
.65238 .32962 Mdot
.65714 .32962 Mdot
.6619 .26781 Mdot
.66667 .28842 Mdot
.67143 .28842 Mdot
.67619 .32962 Mdot
.68095 .30902 Mdot
.68571 .28842 Mdot
.69048 .28842 Mdot
.69524 .30902 Mdot
.7 .30902 Mdot
.70476 .32962 Mdot
.70952 .32962 Mdot
.71429 .30902 Mdot
.71905 .30902 Mdot
.72381 .28842 Mdot
.72857 .30902 Mdot
.73333 .28842 Mdot
.7381 .30902 Mdot
.74286 .30902 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .35022 Mdot
.7619 .30902 Mdot
.76667 .30902 Mdot
.77143 .28842 Mdot
.77619 .28842 Mdot
.78095 .30902 Mdot
.78571 .30902 Mdot
.79048 .30902 Mdot
.79524 .30902 Mdot
.8 .30902 Mdot
.80476 .30902 Mdot
.80952 .26781 Mdot
.81429 .28842 Mdot
.81905 .30902 Mdot
.82381 .30902 Mdot
.82857 .32962 Mdot
.83333 .28842 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .28842 Mdot
.85714 .30902 Mdot
.8619 .30902 Mdot
.86667 .30902 Mdot
.87143 .28842 Mdot
.87619 .28842 Mdot
.88095 .30902 Mdot
.88571 .30902 Mdot
.89048 .32962 Mdot
.89524 .30902 Mdot
.9 .26781 Mdot
.90476 .26781 Mdot
.90952 .32962 Mdot
.91429 .32962 Mdot
.91905 .30902 Mdot
.92381 .26781 Mdot
.92857 .30902 Mdot
.93333 .30902 Mdot
.9381 .28842 Mdot
.94286 .32962 Mdot
.94762 .35022 Mdot
.95238 .28842 Mdot
.95714 .28842 Mdot
.9619 .30902 Mdot
.96667 .30902 Mdot
.97143 .30902 Mdot
.97619 .28842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo03oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01oooool2o`0002;ooooo1?l0000:ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o00002?ooool2
o`0000Oooooo0_l0000<ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0_l0000:ooooo`;o00003_ooool4o`00
00?ooooo0_l00004ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool2o`0004?ooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL01oooool2o`0002;ooooo1?l0000<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2
o`0000Sooooo0_l00007ooooo`;o00003_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l0000:ooooo`;o00003_ooool4o`0000?o
oooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool00ol0003oooooooooo`13
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Oo
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400Cooooo`00:?ooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0003o
ooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0doooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000004oooool002Sooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000003Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400kooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400hooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04Oooool002Sooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04oooool002Sooooo1?l000000ooooooo0000o`000005ooooo`;o
00001?ooool2o`0000Oooooo0ol000001?oooooo0000o`000?l0000Aooooo`;o00001_ooool4o`00
0003ooooool0003o000000Co00000_ooool2o`000003oc8b<_l0003o000000?o00002oooool2o`00
00;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002
o`000003ooooool0003o000000kooooo0_l000000omVIVKo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool3o`000004oc8b<_o^k^ko0000o`0000Oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l0000=ooooo`?o00000_ooool4o`0000?ooooo
00?oEEEEofIVI_l000000_ooool2o`000003ooooool0003o000000;o00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?o00002_ooool2o`0000Cooooo0ol00002ooooo`;o00001?ooool4o`00017o
oooo0_l000000ol@413o0000o`000003o`000003ooooooo^k^ko<S8b00;o000000Wok^k^oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h04oooool002Sooooo00Go0000ooooool0003o0000oooo
o`02o`0000Gooooo0_l00004ooooo`;o00001oooool3o`000004ooooool0003o0000o`00017ooooo
0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000ol0000;ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003_ooool2o`0000kooooo0_l00003oooo
o`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00
00gooooo0ol00002ooooo`Co00002?ooool2o`000003ooooool0003o000000[ooooo0ol0000:oooo
o`;o00001?ooool3o`0000;ooooo0_l00004ooooo`Co00004Oooool2o`0000;ooooo1?l00003oooo
o`;o00007?ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo=?ooool2o`0000;ooooo00?o
410@o`000?l000000oooool002Sooooo00?o0000ooooooooool0ooooooleooooo`05o`000?oooooo
k^k^oc8b<_o<c<`01?ooool0023oooooool0000do`0000cooooo00Co0000oiRHV?lb<S;oc<c<1Ooo
ool002Sooooo00?o0000ooooooooool00_l00008ooooo`;o00001?ooool8o`0000;ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo0ol00003ooooo`?o00000oooool2o`000004ooooool0003o
0000o`0000Cooooo0_l000001?oooooo0000o`000?ooool6o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Oooooo00Co0000oooooooooooooooo0_l00002ooooo`;o000000Coooooo`000?l0
003ooooo0_l00004ooooo`Ko00000oooool2o`000003ooooool0003o000000Kooooo2?l000001?oo
oooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000003Oooool3o`0000Sooooo0_l00002
ooooo`Co00000_ooool4o`000003ooooool0003o000000Go00000oooool3o`0000?ooooo2Ol00002
ooooo`Co000000?oooooo`000?ooool01Oooool5o`0000;ooooo1?l000000ooooooo0000o`000005
ooooo`;o000000Coooooo`000?l0003o00001oooool6o`0001?ooooo00?o0000oa0@4?nHV9P01_oo
ool002Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Aooooo`04o`000?o^k^ko
EEEEohN7Q`Gooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool01Ol0003oooooodA4A?l0
003o410@00Cooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`06
ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool01_ooool002So
oooo0_l00004ooooo`Ko00000oooool2o`0000cooooo0_l00007ooooo`;o00000oooool2o`0002;o
oooo0_l000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000[ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo1?l00007ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`?o00003Oooool2o`0000Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00006ooooo`Co00002oooool2o`00
01Gooooo0_l00003ooooo`;o00003?ooool2o`0000Cooooo0ol00007ooooo`;o00007?ooool2o`00
00Sooooo000Xooooo`;o00001?ooool6o`0000?ooooo0_l0000<ooooo`;o00001oooool2o`0000?o
oooo0_l0000Rooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`Co
00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000gooooo0_l00008oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo1?l00004ooooo`;o00001_ooool4o`00
00_ooooo0_l0000Eooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`?o00001oooool2o`00
02Kooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`0000ko
oooo0_l0000Fooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
0000;Oooool2o`0001Oooooo0_l0000<ooooo`;o00008oooool4o`0000Cooooo0_l0000Qooooo`;o
0000>Oooool2o`0002Cooooo000Xooooo`03o`000?oooooooooo00gooooo0_l0000Fooooo`;o0000
0_ooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000;Oooool2o`0001Oooooo
0_l0000<ooooo`;o00008oooool4o`0000Cooooo0_l0000Qooooo`;o0000>Oooool2o`0002Cooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool0
0ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0ooooooln
ooooo`006?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2
o`000?oooooo?oooool001Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo0?oooooo?_ooool001Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolnooooo`005Oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo?_ooool001Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0_l0003oooooocoooooo000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolnooooo`006Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
1?ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool0
0ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool001Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
6Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool00000oooooom7ooooo`006?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100oooooom7ooooo`005Oooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodOooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj
^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`00
0oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l00000
0ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@ooooo`;o000000?o410@oooooooo
ool0oooooolKooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgM
gOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000
omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0
000<ooooo`03o`000?oooooooooo0?oooooo7?ooool000Cooooo00CogMgMo`000?l@413oc<c<1Ooo
ool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;o
oooo00Go0000ooooooooooooooooo`00000Aooooo`Go0000oooooolMooooo`001?ooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04
ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
2Oooool01?m4A4CogMgMooooool0003ooooooakooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKo
oooo00WoEEEEoiRHV?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMg
Molb<S8Booooo`05o`000?n7QhOoooooojVYZOl000004Oooool01?oMgMgoEEEEooooool0003ooooo
oakooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo
8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0@ooooo`03ogMgMoo<c<co00000?oooooo7_ooool000oooooo00OoEEEEoiRHV?oooooo
ooooomgMgOl0003ogMgM03;ooooo00?ok^k^odA4A?l00000oooooolNooooo`003oooool00onj^[[o
A4A4ooooo`02ooooo`03ojVYZOoooooooooo03;ooooo00?oMgMgo`000?ooool0oooooolMooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33992 Mdot
.03333 .27812 Mdot
.0381 .29872 Mdot
.04286 .27812 Mdot
.04762 .31932 Mdot
.05238 .33992 Mdot
.05714 .33992 Mdot
.0619 .31932 Mdot
.06667 .27812 Mdot
.07143 .29872 Mdot
.07619 .31932 Mdot
.08095 .33992 Mdot
.08571 .29872 Mdot
.09048 .29872 Mdot
.09524 .31932 Mdot
.1 .31932 Mdot
.10476 .31932 Mdot
.10952 .31932 Mdot
.11429 .29872 Mdot
.11905 .29872 Mdot
.12381 .33992 Mdot
.12857 .29872 Mdot
.13333 .27812 Mdot
.1381 .31932 Mdot
.14286 .31932 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .33992 Mdot
.1619 .29872 Mdot
.16667 .31932 Mdot
.17143 .33992 Mdot
.17619 .33992 Mdot
.18095 .29872 Mdot
.18571 .31932 Mdot
.19048 .36052 Mdot
.19524 .27812 Mdot
.2 .29872 Mdot
.20476 .33992 Mdot
.20952 .29872 Mdot
.21429 .33992 Mdot
.21905 .29872 Mdot
.22381 .29872 Mdot
.22857 .27812 Mdot
.23333 .31932 Mdot
.2381 .29872 Mdot
.24286 .29872 Mdot
.24762 .27812 Mdot
.25238 .29872 Mdot
.25714 .29872 Mdot
.2619 .29872 Mdot
.26667 .31932 Mdot
.27143 .29872 Mdot
.27619 .27812 Mdot
.28095 .27812 Mdot
.28571 .33992 Mdot
.29048 .31932 Mdot
.29524 .33992 Mdot
.3 .31932 Mdot
.30476 .27812 Mdot
.30952 .33992 Mdot
.31429 .33992 Mdot
.31905 .31932 Mdot
.32381 .27812 Mdot
.32857 .33992 Mdot
.33333 .29872 Mdot
.3381 .29872 Mdot
.34286 .33992 Mdot
.34762 .29872 Mdot
.35238 .33992 Mdot
.35714 .31932 Mdot
.3619 .29872 Mdot
.36667 .36052 Mdot
.37143 .29872 Mdot
.37619 .29872 Mdot
.38095 .29872 Mdot
.38571 .27812 Mdot
.39048 .33992 Mdot
.39524 .29872 Mdot
.4 .29872 Mdot
.40476 .29872 Mdot
.40952 .31932 Mdot
.41429 .29872 Mdot
.41905 .29872 Mdot
.42381 .27812 Mdot
.42857 .25751 Mdot
.43333 .29872 Mdot
.4381 .31932 Mdot
.44286 .29872 Mdot
.44762 .33992 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .33992 Mdot
.46667 .27812 Mdot
.47143 .29872 Mdot
.47619 .29872 Mdot
.48095 .29872 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .33992 Mdot
.5 .29872 Mdot
.50476 .31932 Mdot
.50952 .31932 Mdot
.51429 .33992 Mdot
.51905 .27812 Mdot
.52381 .31932 Mdot
.52857 .33992 Mdot
.53333 .29872 Mdot
.5381 .29872 Mdot
.54286 .31932 Mdot
.54762 .31932 Mdot
.55238 .29872 Mdot
.55714 .31932 Mdot
.5619 .27812 Mdot
.56667 .29872 Mdot
.57143 .31932 Mdot
.57619 .31932 Mdot
.58095 .29872 Mdot
.58571 .29872 Mdot
.59048 .29872 Mdot
.59524 .29872 Mdot
.6 .25751 Mdot
.60476 .29872 Mdot
.60952 .31932 Mdot
.61429 .33992 Mdot
.61905 .27812 Mdot
.62381 .33992 Mdot
.62857 .33992 Mdot
.63333 .27812 Mdot
.6381 .31932 Mdot
.64286 .36052 Mdot
.64762 .29872 Mdot
.65238 .33992 Mdot
.65714 .33992 Mdot
.6619 .25751 Mdot
.66667 .29872 Mdot
.67143 .27812 Mdot
.67619 .33992 Mdot
.68095 .31932 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .29872 Mdot
.7 .29872 Mdot
.70476 .33992 Mdot
.70952 .31932 Mdot
.71429 .31932 Mdot
.71905 .31932 Mdot
.72381 .27812 Mdot
.72857 .29872 Mdot
.73333 .29872 Mdot
.7381 .29872 Mdot
.74286 .31932 Mdot
.74762 .29872 Mdot
.75238 .31932 Mdot
.75714 .36052 Mdot
.7619 .29872 Mdot
.76667 .31932 Mdot
.77143 .27812 Mdot
.77619 .27812 Mdot
.78095 .29872 Mdot
.78571 .31932 Mdot
.79048 .29872 Mdot
.79524 .31932 Mdot
.8 .29872 Mdot
.80476 .31932 Mdot
.80952 .25751 Mdot
.81429 .27812 Mdot
.81905 .31932 Mdot
.82381 .31932 Mdot
.82857 .31932 Mdot
.83333 .29872 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .25751 Mdot
.85238 .27812 Mdot
.85714 .29872 Mdot
.8619 .31932 Mdot
.86667 .31932 Mdot
.87143 .29872 Mdot
.87619 .29872 Mdot
.88095 .29872 Mdot
.88571 .29872 Mdot
.89048 .33992 Mdot
.89524 .29872 Mdot
.9 .25751 Mdot
.90476 .25751 Mdot
.90952 .31932 Mdot
.91429 .33992 Mdot
.91905 .31932 Mdot
.92381 .25751 Mdot
.92857 .31932 Mdot
.93333 .29872 Mdot
.9381 .29872 Mdot
.94286 .31932 Mdot
.94762 .36052 Mdot
.95238 .29872 Mdot
.95714 .29872 Mdot
.9619 .29872 Mdot
.96667 .29872 Mdot
.97143 .31932 Mdot
.97619 .29872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo07Sooooo0_l0000booooo`;o0000
4Oooool2o`0002_ooooo0_l0000:ooooo`;o00003_ooool4o`0000?ooooo0_l0000/ooooo`00:?oo
ool00ol0003oooooooooo`1hooooo`;o0000<_ooool2o`00017ooooo0_l0000[ooooo`;o00002_oo
ool2o`0000kooooo1?l00003ooooo`;o0000;?ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`0oooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^03Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0=?ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04ooo
ool002Sooooo0_l00013ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03_o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0gooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL0=?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002Sooooo00?o0000
ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Wooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400gooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41004oooool002Sooooo00?o0000ooooooooool0@_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003Oo
oooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool0=?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000001?ooooo000Xooooo`05o`000?oooooo0000o`000?ooool00_l0
0005ooooo`;o00004_ooool2o`00017ooooo0_l00008ooooo`;o00000oooool3o`000005oc8b<_o<
c<coooooooooool000000_ooool4o`0000Gooooo0_l00004ooooo`;o00004Oooool2o`0000Wooooo
0_l0000;ooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00002ooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`;o00000_ooool2o`0000[o
oooo0_l00002ooooo`;o00001oooool00ol0003oooooooooo`02o`000006ooooool0003o8B4Qo`00
0?lb<S;oc<c<0_ooool01?l0003oooooooooooooool4o`0000[ooooo0_l00005ooooo`;o00000_oo
ool2o`0001gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool01Ol0003oooooo`000?l0003ooooo00;o
00001Oooool2o`0001;ooooo0_l0000Aooooo`;o00002?ooool2o`0000?ooooo0ol00004ooooo`03
oa0@4?oooooooooo00Co00001Oooool2o`0000Cooooo0_l0000Aooooo`;o00002Oooool2o`0000_o
oooo0_l000000ooooooo0000ooooo`03ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`00
00;ooooo00?o410@ooooooooool01oooool2o`0000oooooo0_l00002ooooo`;o00002_ooool2o`00
00;ooooo0_l00007ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool01Oooool01Ol@
413ooooooooooooooooo410@00?o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00007_ooool0
1Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo017ooooo000Xooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg03_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Cooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01?ooooo000Xooooo`;o0000@?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool00omEEEGoIVIVo`000005ooooo`Co00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`02o`0000Sooooo0_l00003ooooo`?o00001_ooool3o`000003ooooool0
003o000000Sooooo0_l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o0000
0_ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000004Oooool3o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000003o`0000?ooooo1?l000000ooooooo0000
o`000002o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`Go00001?ooool2o`0000Sooooo
0ol00003ooooo`;o00000_ooool2o`0000;ooooo1ol000000ooooooo0000o`00000;ooooo`;o0000
1?ooool2o`0000Gooooo1Ol00007ooooo`Co000000?oooooo`000?l000000oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Wooooo0_l00005ooooo`;o00000_ooool7o`000003oooo
ool0003o000000Wooooo1?l00002ooooo`Ko000000?oooooo`000?l000007?ooool002Sooooo00?o
0000ooooooooool00_l00008ooooo`;o00000oooool3o`0000Kooooo0ol000000ooooooo0000o`00
0008ooooo`;o00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo
1?l000000ooooooo0000o`000003o`000003ooooool0003o0000017ooooo0ol000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Co000000?oooooo`000?l00000
0_l00002ooooo`;o000000?oooooo`000?l000001oooool5o`0000Cooooo0_l00008ooooo`?o0000
0oooool2o`0000;ooooo0_l00002ooooo`Oo000000?oooooo`000?l000002oooool2o`0000Cooooo
0_l00005ooooo`Go00001oooool4o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`;o00001Oooool2o`0000;ooooo1ol000000ooooooo0000
o`000009ooooo`Co00000_ooool6o`000003ooooool0003o000001;ooooo0_l00002ooooo`03oa0@
4?l0003o000000?ooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool01Ol0003oooooonk^
k_lb<S;oc<c<00Cooooo000Poooooooo0000=?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo
000Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?l@413oV9RH00Kooooo000Xooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:?ooool00ol0003oooooooooo`03
ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Ko00001oooool6o`0000?ooooo0_l00003
ooooo`;o00003Oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000[ooooo0_l0000>ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`Co00000_ooool4
o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool4o`0000Sooooo0_l00007
ooooo`;o00002oooool2o`0000Oooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1Ol00003ooooo`;o00000ooo
ool4o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o0000
5?ooool01Ol0003oooooodA4A?l0003o410@00Cooooo000Xooooo`03o`000?oooooooooo00?ooooo
0_l00002ooooo`;o00000oooool2o`0000Cooooo1_l00007ooooo`Ko00000oooool2o`0000?ooooo
0_l0000=ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
2_ooool2o`0000kooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo1?l00002ooooo`Co0000
0_ooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`Co00002?ooool2o`0000Oooooo
0_l0000;ooooo`;o00001oooool5o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool5o`0000?ooooo0_l00003ooooo`Co
00002oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Oooooo0_l0000Doooo
o`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003o
ooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`3oooooocCooooo0_l00008ooooo`00:?oo
ool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`00
00Kooooo0ol00005ooooo`;o00002oooool2o`0000Wooooo0_l00002ooooo`?o00001oooool2o`00
0003ooooool0003o000001Cooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00004?ooool6o`0000Sooooo0_l00004oooo
o`;o00000_ooool2o`0001Wooooo1_l00005ooooo`Co00001?ooool2o`0000Kooooo0_l0000goooo
o`;o00001Oooool2o`0002oooooo000Xooooo`;o00001_ooool3o`0000Gooooo0_l0000;ooooo`;o
00002Oooool2o`0000;ooooo0ol00007ooooo`;o000000?oooooo`000?l000005?ooool2o`000003
ooooool0003o000000;ooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000[o
oooo0_l0000@ooooo`Ko00002?ooool2o`0000Cooooo0_l00002ooooo`;o00006Oooool6o`0000Go
oooo1?l00004ooooo`;o00001_ooool2o`0003Oooooo0_l00005ooooo`;o0000;oooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0;oooool2o`0003Cooooo
0_l0001Booooo`;o00008Oooool2o`0003Wooooo0_l0000Tooooo`00:?ooool00ol0003ooooooooo
o`0_ooooo`;o0000=?ooool2o`0005;ooooo0_l0000Qooooo`;o0000>Oooool2o`0002Cooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool2o`000?oooooo?oooool001Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolnooooo`006?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0003oooooocoooooo000Gooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0?oooooo?_ooool001Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0oooooolnooooo`006Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolnooooo`005Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolnooooo`006Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01?ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooooom7ooooo`006?ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooooom7ooooo`005Oooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodOooooo000E
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo
Aoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0C
ooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo
00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002oooo
o`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?
ooooo`05odA4A?l0003o0000oc8b<_oMgMd0oooooolLooooo`000oooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Sooooo
ooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003o
oooooooooooooooo000000;ooooo1_l0000=ooooo`03ogMgMolb<S;ooooo0?oooooo6oooool000Co
oooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004
ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`00
0?oooooooooo0?oooooo6_ooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@
onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBoooo
o`05o`000?ooooooooooooooool000000_ooool6o`0000gooooo00?oMgMgoc8b<_ooool0oooooolK
ooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@
onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo
000001;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03ooooooacooooo0003ooooo`;o00000_ooool2
o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2
o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0@ooooo`03o`000?oooooo
oooo0?oooooo7_ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03;ooooo00?o
0000ooooooooool0oooooolNooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooo
oooo037ooooo1?l0003ooooooagooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32962 Mdot
.03333 .26781 Mdot
.0381 .30902 Mdot
.04286 .26781 Mdot
.04762 .30902 Mdot
.05238 .32962 Mdot
.05714 .32962 Mdot
.0619 .30902 Mdot
.06667 .28842 Mdot
.07143 .28842 Mdot
.07619 .30902 Mdot
.08095 .32962 Mdot
.08571 .30902 Mdot
.09048 .28842 Mdot
.09524 .30902 Mdot
.1 .32962 Mdot
.10476 .30902 Mdot
.10952 .30902 Mdot
.11429 .28842 Mdot
.11905 .30902 Mdot
.12381 .35022 Mdot
.12857 .30902 Mdot
.13333 .26781 Mdot
.1381 .30902 Mdot
.14286 .30902 Mdot
.14762 .32962 Mdot
.15238 .32962 Mdot
.15714 .32962 Mdot
.1619 .28842 Mdot
.16667 .30902 Mdot
.17143 .32962 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .30902 Mdot
.19048 .37082 Mdot
.19524 .26781 Mdot
.2 .28842 Mdot
.20476 .32962 Mdot
.20952 .28842 Mdot
.21429 .35022 Mdot
.21905 .30902 Mdot
.22381 .30902 Mdot
.22857 .28842 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .30902 Mdot
.24762 .26781 Mdot
.25238 .30902 Mdot
.25714 .30902 Mdot
.2619 .30902 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .26781 Mdot
.28095 .26781 Mdot
.28571 .35022 Mdot
.29048 .32962 Mdot
.29524 .35022 Mdot
.3 .32962 Mdot
.30476 .26781 Mdot
.30952 .35022 Mdot
.31429 .35022 Mdot
.31905 .30902 Mdot
.32381 .28842 Mdot
.32857 .32962 Mdot
.33333 .28842 Mdot
.3381 .30902 Mdot
.34286 .35022 Mdot
.34762 .30902 Mdot
.35238 .35022 Mdot
.35714 .32962 Mdot
.3619 .28842 Mdot
.36667 .35022 Mdot
.37143 .28842 Mdot
.37619 .28842 Mdot
.38095 .30902 Mdot
.38571 .26781 Mdot
.39048 .35022 Mdot
.39524 .28842 Mdot
.4 .28842 Mdot
.40476 .28842 Mdot
.40952 .30902 Mdot
.41429 .28842 Mdot
.41905 .30902 Mdot
.42381 .28842 Mdot
.42857 .26781 Mdot
.43333 .28842 Mdot
.4381 .32962 Mdot
.44286 .30902 Mdot
.44762 .32962 Mdot
.45238 .30902 Mdot
.45714 .35022 Mdot
.4619 .32962 Mdot
.46667 .26781 Mdot
.47143 .28842 Mdot
.47619 .30902 Mdot
.48095 .28842 Mdot
.48571 .32962 Mdot
.49048 .32962 Mdot
.49524 .35022 Mdot
.5 .28842 Mdot
.50476 .32962 Mdot
.50952 .32962 Mdot
.51429 .32962 Mdot
.51905 .26781 Mdot
.52381 .30902 Mdot
.52857 .35022 Mdot
.53333 .30902 Mdot
.5381 .30902 Mdot
.54286 .32962 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .30902 Mdot
.5619 .26781 Mdot
.56667 .28842 Mdot
.57143 .32962 Mdot
.57619 .30902 Mdot
.58095 .28842 Mdot
.58571 .28842 Mdot
.59048 .28842 Mdot
.59524 .30902 Mdot
.6 .26781 Mdot
.60476 .30902 Mdot
.60952 .32962 Mdot
.61429 .32962 Mdot
.61905 .26781 Mdot
.62381 .32962 Mdot
.62857 .32962 Mdot
.63333 .26781 Mdot
.6381 .32962 Mdot
.64286 .37082 Mdot
.64762 .30902 Mdot
.65238 .35022 Mdot
.65714 .32962 Mdot
.6619 .26781 Mdot
.66667 .28842 Mdot
.67143 .26781 Mdot
.67619 .32962 Mdot
.68095 .32962 Mdot
.68571 .28842 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .28842 Mdot
.70476 .35022 Mdot
.70952 .30902 Mdot
.71429 .32962 Mdot
.71905 .30902 Mdot
.72381 .28842 Mdot
.72857 .30902 Mdot
.73333 .28842 Mdot
.7381 .30902 Mdot
.74286 .32962 Mdot
.74762 .30902 Mdot
.75238 .30902 Mdot
.75714 .35022 Mdot
.7619 .28842 Mdot
.76667 .32962 Mdot
.77143 .28842 Mdot
.77619 .26781 Mdot
.78095 .30902 Mdot
.78571 .30902 Mdot
.79048 .28842 Mdot
.79524 .30902 Mdot
.8 .28842 Mdot
.80476 .30902 Mdot
.80952 .24721 Mdot
.81429 .28842 Mdot
.81905 .30902 Mdot
.82381 .32962 Mdot
.82857 .32962 Mdot
.83333 .30902 Mdot
.8381 .26781 Mdot
.84286 .32962 Mdot
.84762 .24721 Mdot
.85238 .26781 Mdot
.85714 .28842 Mdot
.8619 .30902 Mdot
.86667 .30902 Mdot
.87143 .28842 Mdot
.87619 .30902 Mdot
.88095 .30902 Mdot
.88571 .30902 Mdot
.89048 .35022 Mdot
.89524 .28842 Mdot
.9 .26781 Mdot
.90476 .26781 Mdot
.90952 .32962 Mdot
.91429 .35022 Mdot
.91905 .32962 Mdot
.92381 .24721 Mdot
.92857 .32962 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .32962 Mdot
.94762 .35022 Mdot
.95238 .30902 Mdot
.95714 .28842 Mdot
.9619 .28842 Mdot
.96667 .28842 Mdot
.97143 .30902 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000>gooooo0_l0000:ooooo`;o00005Oooool2o`0002cooooo000Xooooo`03o`000?oooooooooo
0>cooooo0_l0000:ooooo`;o00005Oooool2o`0002cooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00Go0000oooo
ool0003o0000ooooo`02o`0001Wooooo0_l0000Aooooo`;o00003Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00?ok^k^oc8b<_l000001?l00005ooooo`;o00005oooool2o`0000_ooooo0_l0
0009ooooo`Go000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo0ol000000olb
<S;ok^k^ooooo`08ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
0003ooooool0003o000000Wooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000[o<S8b
omgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^kooooo0_l0000Aooooo`;o00000_ooool2o`00
00gooooo1?l00009ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool4o`000003ooooool0003o000001Wooooo0_l0000A
ooooo`;o00003_ooool2o`000007ogMgMolb<S;ooooooooooomgMgOoV9RHooooo`04o`0000Gooooo
0_l0000Gooooo`;o00002oooool2o`0000Wooooo0_l000000ooooooo0000ooooo`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg00Wooooo0_l00009ooooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000002oooool00ol0003o
ooooooooo`06ooooo`0:ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMgooooo`;o0000
4Oooool2o`0000;ooooo0_l0000=ooooo`Co00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02Sooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400gooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002Sooooo00?o0000oooo
ooooool0@_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000003Oooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool0=?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000Xooooo`03o`000?oooooooooo
03oooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000>ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`00000gooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002Sooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
>oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@4100>?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000Xooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03_ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg03Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000Xooooo`;o0000
2_ooool3o`0000Cooooo0_l00006ooooo`;o00003?ooool2o`0000[ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0=ooooo`;o
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;o00001?ooool4o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000002Oooool01?mEEEGo0000o`000?ooool2
o`000003ooooooo^k^ko<S8b00?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0
0002ooooo`Go00005_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oEEEEofIVI_l000000_oo
ool2o`000003ooooool0003o000000;o00000oooool01Oo^k^ko<S8bo`000?l0003ok^k^00;o0000
1?ooool4o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h04oooool002Sooooo00?o0000ooooooooool02Oooool3o`0000Cooooo0_l00006oooo
o`;o00003?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`00
00kooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001;ooooo0_l00002ooooo`Go00005_ooool2o`0000?ooooo0_l00003
ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000004
ooooo`Co00000oooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`00017ooooo1?l0000O
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0ooooooldooooo`;o00000_ooool00ol@413o0000
o`000003ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00Go0000ooooooo^k^ko<S8b
olc<c004ooooo`008?ooooooo`0003Co00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:?oo
ool00ol0003oooooooooo`02o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o000000Co
ooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0
003ooooo0ol00006ooooo`;o00000_ooool3o`0000Sooooo1?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Co00003?ooool01?l0003oooooo`000?l00004ooooo`;o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`03ooooo`;o00001_ooool3o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool00ol0003oooooooooo`04
ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000002_ooool3o`0000_ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo
1?l000000ooooooo0000o`000002o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l00003ooooo`;o00001_ooool4o`000003ooooool0003o000000?o00002oooool5o`0000;o
oooo0_l00004ooooo`?o00004oooool00ol0003o410@oiRHV006ooooo`00:?ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002Sooooo
00?o0000ooooooooool0ooooooleooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002Sooooo
00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo00Kooooo000Xooooo`03o`000?oo
oooooooo0?oooooo=Oooool00ol0003oooooooooo`06ooooo`00:?ooool2o`0000Kooooo0ol00005
ooooo`;o00001?ooool2o`0000gooooo1Ol00002ooooo`;o00002?ooool2o`0001Sooooo0_l00000
0ooooooo0000o`000007ooooo`;o00001oooool2o`0001Oooooo0_l000000ooooooo0000o`000002
ooooo`;o00001Oooool4o`0000;ooooo1Ol00007ooooo`;o00001_ooool2o`0000[ooooo2?l00000
0ooooooo0000o`000004ooooo`;o00001?ooool3o`0000Sooooo0_l00007ooooo`;o00001Oooool2
o`00013ooooo0ol00003ooooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`;o00000_oo
ool2o`0001cooooo0_l00008ooooo`00:?ooool2o`0000Kooooo0ol00005ooooo`;o00001?ooool2
o`0000gooooo1Ol00002ooooo`;o00002?ooool2o`0001Sooooo0_l000000ooooooo0000o`000007
ooooo`;o00001oooool2o`0001Oooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool4
o`0000;ooooo1Ol00007ooooo`;o00001_ooool2o`0000[ooooo2?l000000ooooooo0000o`000004
ooooo`;o00001?ooool3o`0000Sooooo0_l00007ooooo`;o00001Oooool2o`00013ooooo0ol00003
ooooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0002Kooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`0001_ooooo0_l0000>
ooooo`;o00002_ooool2o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`Co00001_ooool2
o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00004_ooool2o`0000[ooooo0_l00008
ooooo`;o00009?ooool2o`0000kooooo0_l0000>ooooo`;o00009oooool2o`0000Gooooo0_l00009
ooooo`;o00009?ooool002Sooooo00?o0000ooooooooool06_ooool2o`0000kooooo0_l0000:oooo
o`;o00005?ooool2o`000003ooooool0003o000000;ooooo1?l00006ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Gooooo0_l0000Booooo`;o00002_ooool2o`0000Sooooo0_l0000Toooo
o`;o00003_ooool2o`0000kooooo0_l0000Wooooo`;o00001Oooool2o`0000Wooooo0_l0000Toooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`;o0000<?ooool2o`0008Sooooo0_l00022ooooo`00:?ooool00ol0003o
ooooooooo`0_ooooo`;o0000R?ooool2o`0008;ooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`006?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooocoooooo000Hooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo
?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolooooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`005Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000oooooolooooo
o`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolnoooo
o`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolnoooo
o`005Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo?oooool0
01Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo00000?ooooooAoooool0
01Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@0?ooooooAoooool0
01Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooo
oom7ooooo`005Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP3oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?ooooooA?ooool000cooooo00?o8B4Q
omgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l00002ooooo`;o00000oooool00onH
V9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o<S8booooooooool00_l00002oooo
o`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool03_ooool01Oo^k^ko<S8bo`000?l@413oc<c<0?oooooo7Oooool000?ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4
A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00co
oooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So
8B4Q0?oooooo7Oooool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@
omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000oooooooooooo
ooooo`00000Aooooo`05o`000?ooooooooooooooool00000oooooolMooooo`001?ooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04
ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q0?oooooo7Oooool000Cooooo00Co8B4QogMgMomgMgOo
<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Aooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0oooooolMooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;o
oooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool03oooool00omEEEGoQhN7ooooo`3ooooooaoooooo000?ooooo`07oeEE
EOnHV9SooooooooooooMgMgo0000omgMg@0aooooo`03omgMgOl@413oV9RH0?oooooo7oooool000oo
oooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0aooooo`04olc<c?m4A4Co0000oa0@
4?oooooo7Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31932 Mdot
.03333 .27812 Mdot
.0381 .29872 Mdot
.04286 .27812 Mdot
.04762 .29872 Mdot
.05238 .31932 Mdot
.05714 .31932 Mdot
.0619 .31932 Mdot
.06667 .27812 Mdot
.07143 .27812 Mdot
.07619 .31932 Mdot
.08095 .33992 Mdot
.08571 .31932 Mdot
.09048 .27812 Mdot
.09524 .29872 Mdot
.1 .33992 Mdot
.10476 .29872 Mdot
.10952 .31932 Mdot
.11429 .27812 Mdot
.11905 .29872 Mdot
.12381 .33992 Mdot
.12857 .29872 Mdot
.13333 .27812 Mdot
.1381 .29872 Mdot
.14286 .29872 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .33992 Mdot
.1619 .29872 Mdot
.16667 .31932 Mdot
.17143 .33992 Mdot
.17619 .33992 Mdot
.18095 .29872 Mdot
.18571 .31932 Mdot
.19048 .36052 Mdot
.19524 .27812 Mdot
.2 .29872 Mdot
.20476 .31932 Mdot
.20952 .29872 Mdot
.21429 .36052 Mdot
.21905 .31932 Mdot
.22381 .31932 Mdot
.22857 .29872 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .31932 Mdot
.24762 .25751 Mdot
.25238 .29872 Mdot
.25714 .29872 Mdot
.2619 .31932 Mdot
.26667 .31932 Mdot
.27143 .27812 Mdot
.27619 .25751 Mdot
.28095 .27812 Mdot
.28571 .36052 Mdot
.29048 .31932 Mdot
.29524 .33992 Mdot
.3 .33992 Mdot
.30476 .25751 Mdot
.30952 .33992 Mdot
.31429 .33992 Mdot
.31905 .31932 Mdot
.32381 .29872 Mdot
.32857 .33992 Mdot
.33333 .29872 Mdot
.3381 .29872 Mdot
.34286 .36052 Mdot
.34762 .29872 Mdot
.35238 .33992 Mdot
.35714 .33992 Mdot
.3619 .29872 Mdot
.36667 .36052 Mdot
.37143 .27812 Mdot
.37619 .27812 Mdot
.38095 .31932 Mdot
.38571 .25751 Mdot
.39048 .33992 Mdot
.39524 .29872 Mdot
.4 .27812 Mdot
.40476 .29872 Mdot
.40952 .31932 Mdot
.41429 .27812 Mdot
.41905 .29872 Mdot
.42381 .29872 Mdot
.42857 .25751 Mdot
.43333 .27812 Mdot
.4381 .33992 Mdot
.44286 .31932 Mdot
.44762 .33992 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .31932 Mdot
.46667 .25751 Mdot
.47143 .27812 Mdot
.47619 .29872 Mdot
.48095 .29872 Mdot
.48571 .31932 Mdot
.49048 .33992 Mdot
.49524 .33992 Mdot
.5 .27812 Mdot
.50476 .31932 Mdot
.50952 .33992 Mdot
.51429 .31932 Mdot
.51905 .25751 Mdot
.52381 .31932 Mdot
.52857 .36052 Mdot
.53333 .29872 Mdot
.5381 .29872 Mdot
.54286 .31932 Mdot
.54762 .29872 Mdot
.55238 .29872 Mdot
.55714 .29872 Mdot
.5619 .27812 Mdot
.56667 .27812 Mdot
.57143 .33992 Mdot
.57619 .29872 Mdot
.58095 .27812 Mdot
.58571 .29872 Mdot
.59048 .29872 Mdot
.59524 .31932 Mdot
.6 .25751 Mdot
.60476 .29872 Mdot
.60952 .31932 Mdot
.61429 .33992 Mdot
.61905 .25751 Mdot
.62381 .31932 Mdot
.62857 .33992 Mdot
.63333 .27812 Mdot
.6381 .31932 Mdot
.64286 .36052 Mdot
.64762 .29872 Mdot
.65238 .36052 Mdot
.65714 .33992 Mdot
.6619 .25751 Mdot
.66667 .29872 Mdot
.67143 .27812 Mdot
.67619 .33992 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .29872 Mdot
.7 .27812 Mdot
.70476 .33992 Mdot
.70952 .29872 Mdot
.71429 .31932 Mdot
.71905 .29872 Mdot
.72381 .27812 Mdot
.72857 .31932 Mdot
.73333 .27812 Mdot
.7381 .29872 Mdot
.74286 .33992 Mdot
.74762 .31932 Mdot
.75238 .31932 Mdot
.75714 .36052 Mdot
.7619 .27812 Mdot
.76667 .33992 Mdot
.77143 .29872 Mdot
.77619 .25751 Mdot
.78095 .31932 Mdot
.78571 .31932 Mdot
.79048 .29872 Mdot
.79524 .29872 Mdot
.8 .29872 Mdot
.80476 .31932 Mdot
.80952 .23691 Mdot
.81429 .27812 Mdot
.81905 .29872 Mdot
.82381 .31932 Mdot
.82857 .31932 Mdot
.83333 .31932 Mdot
.8381 .27812 Mdot
.84286 .33992 Mdot
.84762 .25751 Mdot
.85238 .27812 Mdot
.85714 .29872 Mdot
.8619 .29872 Mdot
.86667 .29872 Mdot
.87143 .29872 Mdot
.87619 .29872 Mdot
.88095 .31932 Mdot
.88571 .31932 Mdot
.89048 .33992 Mdot
.89524 .27812 Mdot
.9 .25751 Mdot
.90476 .27812 Mdot
.90952 .31932 Mdot
.91429 .36052 Mdot
.91905 .33992 Mdot
.92381 .23691 Mdot
.92857 .31932 Mdot
.93333 .29872 Mdot
.9381 .31932 Mdot
.94286 .31932 Mdot
.94762 .36052 Mdot
.95238 .29872 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .31932 Mdot
.97619 .31932 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3/ooooo`;o00008Oooool2o`0002co
oooo000Xooooo`03o`000?oooooooooo0>cooooo0_l0000Qooooo`;o0000;?ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo043ooooo0_l00007ooooo`;o00001oooool2o`0001Oooooo0_l0000;ooooo`;o0000
2Oooool2o`0000kooooo0_l0000Gooooo`;o00001?ooool2o`0000_ooooo0_l0000Qooooo`;o0000
5?ooool2o`0000kooooo0_l0000cooooo`00:?ooool00ol0003oooooooooo`10ooooo`;o00001ooo
ool2o`0000Oooooo0_l0000Gooooo`;o00002oooool2o`0000Wooooo0_l0000>ooooo`;o00005ooo
ool2o`0000Cooooo0_l0000;ooooo`;o00008Oooool2o`0001Cooooo0_l0000>ooooo`;o0000<ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`0ooooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Wooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^03Gooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOoooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002Sooooo0_l00013ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg03_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0gooooo`03o`000?oooooo
oooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0=?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool002Sooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo03Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400gooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004ooo
ool002Sooooo00?o0000ooooooooool0@_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool0=?ooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000X
ooooo`05o`000?oooooo0000o`000?ooool00_l00005ooooo`?o00001?ooool2o`0000Kooooo0_l0
0003ooooo`;o00004Oooool2o`0000gooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`03o`00
0?oooooo000000Co00006Oooool4o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000[ooooo
0_l00004ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Wo
oooo0ol00002ooooo`;o00003_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo00?o0000ooooooooool00_l000001_oooooo0000o`000?l0003o<S8bolc<c0;ooooo00?o0000
ooooool000000_l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000003?ooool00omgMgOoIVIVo`000003o`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo017ooooo000Xooooo`05o`000?oooooo0000o`000?ooool00_l0
0005ooooo`?o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00004Oooool2o`0000gooooo00?o
0000ooooooooool01?ooool01Ol@413oooooo`000?l0003o410@00;o00006Oooool4o`0000Gooooo
0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`03oa0@4?oooooooooo00;o0000
0oooool01Ol@413ooooooooooooooooo410@00Wooooo0ol00002ooooo`;o00003_ooool2o`0000[o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_l000000ooooooo
0000o`000005ooooo`05oa0@4?oooooo0000o`000?l@41003Oooool2o`0000Gooooo0_l00002oooo
o`;o00003?ooool2o`000003ooooool0003o000000gooooo1?l000001Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:?ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0kooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0=oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0dooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool2o`00043ooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>Oooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo00?oEEEEofIV
I_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Cooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000=
ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool5o`0000?ooooo0ol0
000Cooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00009ooooo`Co0000
0oooool3o`0000kooooo1?l0000>ooooo`?o000000?oooooo`000?l000000ol00004ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool3o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Cooooo1?l00004ooooo`;o
00002_ooool8o`0000oooooo0_l00004ooooo`;o00000_ooool2o`0001oooooo000Xooooo`03o`00
0?oooooooooo00;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000;ooooo
0_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`000003
ooooool0003o000000?ooooo1Ol00003ooooo`?o00004oooool2o`000005ooooool0003o0000o`00
0?ooool00_l00002ooooo`;o00002Oooool4o`0000?ooooo0ol0000>ooooo`Co00003_ooool3o`00
0003ooooool0003o000000?o00001?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000;
ooooo`;o00001?ooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Wooooo0_l00004ooooo`Co00001?ooool2o`0000[ooooo2?l0000?ooooo`;o00001?ooool2
o`0000;ooooo0_l0000Eooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:?ooool00ol0
003oooooooooo`3oooooocGooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`008?ooooooo`00
03Co00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003o410@oiRHV006oooo
o`00:?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017ooooo00Co0000onk^k_mE
EEGoQhN71Oooool002Sooooo0_l00006ooooo`Co00000oooool2o`000003ooooool0003o000000Go
oooo0_l0000:ooooo`?o00000oooool2o`0000?ooooo0_l00004ooooo`;o00000oooool3o`0000Co
oooo0_l00004ooooo`?o00001Oooool2o`0000Oooooo0_l0000Aooooo`;o00001oooool2o`0000So
oooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2
o`0001Gooooo0_l00003ooooo`;o00000oooool4o`0000Oooooo0ol00004ooooo`;o00001?ooool5
o`0000cooooo1?l00005ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Oooooo0ol0
000Cooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002Sooooo0_l00006ooooo`Co00000ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`?o00000oooool2o`0000?ooooo0_l0
0004ooooo`;o00000oooool3o`0000Cooooo0_l00004ooooo`?o00001Oooool2o`0000Oooooo0_l0
000Aooooo`;o00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003_ooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l00003ooooo`;o00000oooool4o`0000Oo
oooo0ol00004ooooo`;o00001?ooool5o`0000cooooo1?l00005ooooo`;o00001?ooool2o`000004
ooooool0003o0000o`0000Oooooo0ol0000Cooooo`03o`000?oooooooooo00Kooooo000Xooooo`03
o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003ooooo
ooooo`3oooooocCooooo0_l00008ooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`00
00Gooooo0_l00009ooooo`;o00000_ooool3o`0002?ooooo0ol000000ooooooo0000o`000002o`00
00;ooooo0_l00005ooooo`Co00002?ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0ol00003ooooo`;o00004?ooool2o`0000cooooo0_l00002ooooo`;o00001oooool2o`00
00Cooooo0ol00005ooooo`;o00002_ooool2o`0000Gooooo0_l0000Fooooo`;o00003?ooool2o`00
00Oooooo0_l0000]ooooo`00:?ooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`0000Go
oooo0_l00009ooooo`;o00000_ooool3o`0002?ooooo0ol000000ooooooo0000o`000002o`0000;o
oooo0_l00005ooooo`Co00002?ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000Wo
oooo0ol00003ooooo`;o00004?ooool2o`0000cooooo0_l00002ooooo`;o00001oooool2o`0000Co
oooo0ol00005ooooo`;o00002_ooool2o`0000Gooooo0_l0000Fooooo`;o00003?ooool2o`0000Oo
oooo0_l0000]ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo
0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`0_ooooo`;o00001Oooool2o`0001Cooooo0_l0000?ooooo`;o00001_ooool2o`0002oooooo
0_l0000Qooooo`;o000000?oooooo`000?l000007_ooool2o`0002kooooo0_l00009ooooo`;o0000
9?ooool002Sooooo00?o0000ooooooooool0;oooool2o`0000Gooooo0_l0000Dooooo`;o00003ooo
ool2o`0000Kooooo0_l0000_ooooo`;o00008Oooool2o`000003ooooool0003o000001kooooo0_l0
000^ooooo`;o00002Oooool2o`0002Cooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
01Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooo
ooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolnooooo`006?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo
?oooool001Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
?_ooool001Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0?oooooo?_ooool001Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l0003oooooocoooooo000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolnoooo
o`006Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0
003oooooooooo`3oooooockooooo000Eooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`005Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`00
0?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooo
ooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o
0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oo
oooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo
00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`3oooooockooooo000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`006Oooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3o
ooooockooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool00000oooooom7ooooo`006?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100oooooom7ooooo`005Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`3oooooodOooooo000Eooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooAoooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooo
oom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`00
00;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb
<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0@ooooo`03o`000?o^k^kooooo0?oooooo7Oooool0
00?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9So
A4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<
c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002oooool00omEEEGo
ZJVYooooo`3ooooooagooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05
oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?oooooo
ooooooooool000004oooool00onYZJWoEEEEooooo`3ooooooagooooo0004ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo
00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<oooo
o`03ob4Q8Ooooooooooo0?oooooo7?ooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmE
EEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;o
oooo00Go0000ohN7QoooooooZJVYo`00000Dooooo`03oeEEEOo<c<cooooo0?oooooo7?ooool000?o
oooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Co
oooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;o
oooo00?oZJVYogMgMoooool0oooooolLooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`00
0?oMgMd0<Oooool01Ol@413ooooooooooooooooo<S8b0?oooooo7Oooool000oooooo00?o^[ZjodA4
A?ooool00_ooool00onYZJWoooooooooo`0`ooooo`Go0000oooooolMooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30902 Mdot
.03333 .28842 Mdot
.0381 .28842 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .32962 Mdot
.05714 .32962 Mdot
.0619 .30902 Mdot
.06667 .26781 Mdot
.07143 .28842 Mdot
.07619 .32962 Mdot
.08095 .32962 Mdot
.08571 .32962 Mdot
.09048 .26781 Mdot
.09524 .28842 Mdot
.1 .32962 Mdot
.10476 .28842 Mdot
.10952 .32962 Mdot
.11429 .26781 Mdot
.11905 .28842 Mdot
.12381 .35022 Mdot
.12857 .28842 Mdot
.13333 .28842 Mdot
.1381 .28842 Mdot
.14286 .30902 Mdot
.14762 .30902 Mdot
.15238 .30902 Mdot
.15714 .35022 Mdot
.1619 .28842 Mdot
.16667 .30902 Mdot
.17143 .35022 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .30902 Mdot
.19048 .35022 Mdot
.19524 .26781 Mdot
.2 .28842 Mdot
.20476 .32962 Mdot
.20952 .28842 Mdot
.21429 .37082 Mdot
.21905 .30902 Mdot
.22381 .32962 Mdot
.22857 .30902 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .32962 Mdot
.24762 .24721 Mdot
.25238 .30902 Mdot
.25714 .28842 Mdot
.2619 .30902 Mdot
.26667 .32962 Mdot
.27143 .28842 Mdot
.27619 .24721 Mdot
.28095 .28842 Mdot
.28571 .37082 Mdot
.29048 .30902 Mdot
.29524 .35022 Mdot
.3 .32962 Mdot
.30476 .26781 Mdot
.30952 .35022 Mdot
.31429 .35022 Mdot
.31905 .32962 Mdot
.32381 .30902 Mdot
.32857 .32962 Mdot
.33333 .30902 Mdot
.3381 .30902 Mdot
.34286 .37082 Mdot
.34762 .28842 Mdot
.35238 .32962 Mdot
.35714 .35022 Mdot
.3619 .30902 Mdot
.36667 .35022 Mdot
.37143 .26781 Mdot
.37619 .26781 Mdot
.38095 .32962 Mdot
.38571 .26781 Mdot
.39048 .32962 Mdot
.39524 .30902 Mdot
.4 .26781 Mdot
.40476 .28842 Mdot
.40952 .32962 Mdot
.41429 .28842 Mdot
.41905 .30902 Mdot
.42381 .28842 Mdot
.42857 .24721 Mdot
.43333 .26781 Mdot
.4381 .32962 Mdot
.44286 .30902 Mdot
.44762 .35022 Mdot
.45238 .30902 Mdot
.45714 .32962 Mdot
.4619 .32962 Mdot
.46667 .26781 Mdot
.47143 .28842 Mdot
.47619 .30902 Mdot
.48095 .28842 Mdot
.48571 .30902 Mdot
.49048 .32962 Mdot
.49524 .32962 Mdot
.5 .26781 Mdot
.50476 .30902 Mdot
.50952 .35022 Mdot
.51429 .32962 Mdot
.51905 .26781 Mdot
.52381 .30902 Mdot
.52857 .37082 Mdot
.53333 .30902 Mdot
.5381 .28842 Mdot
.54286 .30902 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .30902 Mdot
.5619 .28842 Mdot
.56667 .28842 Mdot
.57143 .35022 Mdot
.57619 .30902 Mdot
.58095 .26781 Mdot
.58571 .30902 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .24721 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .35022 Mdot
.61905 .26781 Mdot
.62381 .32962 Mdot
.62857 .35022 Mdot
.63333 .28842 Mdot
.6381 .32962 Mdot
.64286 .35022 Mdot
.64762 .30902 Mdot
.65238 .37082 Mdot
.65714 .32962 Mdot
.6619 .26781 Mdot
.66667 .28842 Mdot
.67143 .28842 Mdot
.67619 .32962 Mdot
.68095 .35022 Mdot
.68571 .28842 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .28842 Mdot
.70476 .32962 Mdot
.70952 .30902 Mdot
.71429 .30902 Mdot
.71905 .30902 Mdot
.72381 .26781 Mdot
.72857 .32962 Mdot
.73333 .26781 Mdot
.7381 .28842 Mdot
.74286 .32962 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .35022 Mdot
.7619 .28842 Mdot
.76667 .35022 Mdot
.77143 .30902 Mdot
.77619 .24721 Mdot
.78095 .32962 Mdot
.78571 .32962 Mdot
.79048 .30902 Mdot
.79524 .30902 Mdot
.8 .30902 Mdot
.80476 .30902 Mdot
.80952 .22661 Mdot
.81429 .28842 Mdot
.81905 .30902 Mdot
.82381 .32962 Mdot
.82857 .32962 Mdot
.83333 .32962 Mdot
.8381 .26781 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .28842 Mdot
.85714 .30902 Mdot
.8619 .30902 Mdot
.86667 .30902 Mdot
.87143 .28842 Mdot
.87619 .28842 Mdot
.88095 .32962 Mdot
.88571 .30902 Mdot
.89048 .35022 Mdot
.89524 .26781 Mdot
.9 .26781 Mdot
.90476 .28842 Mdot
.90952 .30902 Mdot
.91429 .37082 Mdot
.91905 .32962 Mdot
.92381 .22661 Mdot
.92857 .30902 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .30902 Mdot
.94762 .35022 Mdot
.95238 .28842 Mdot
.95714 .28842 Mdot
.9619 .28842 Mdot
.96667 .28842 Mdot
.97143 .32962 Mdot
.97619 .32962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolnooooo`00
5_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003]ooooo`;o00008Oooool2o`0002cooooo000Xooooo`03o`000?oooooooooo0>cooooo0_l0000Q
ooooo`;o0000;?ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool2o`00047ooooo0_l00007ooooo`;o0000;Oooool2
o`0003;ooooo0_l0000dooooo`;o0000FOooool002Sooooo00?o0000ooooooooool0@?ooool2o`00
00Oooooo0_l0000]ooooo`;o0000<_ooool2o`0003Cooooo0_l0001Iooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o00001_ooool2o`0001Kooooo0_l0000=oooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0
000Booooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00008ooooo`Go000000Go
410@ooooooooooook^k^oc8b<P03o`0000?ooooo0ol000000olb<S;ok^k^ooooo`0=ooooo`;o0000
2_ooool2o`0000_ooooo0_l0000<ooooo`Co000000Co410@o`000?l0003ooooo0ol000002Olb<S;o
gMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o000000?oooooo`000?l000003Ooo
ool3o`0000_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Xooooo`;o00002_ooool2o`0000Gooooo0_l00006ooooo`;o0000
5_ooool2o`00013ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01oooool2
o`0001;ooooo1?l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Sooooo0_l00000
0ooooooo0000ooooo`03ooooo`03ogMgMonHV9Sooooo00;o00000oooool2o`000003oooooonHV9So
MgMg00kooooo0_l0000:ooooo`;o00002oooool2o`0000kooooo00?o0000ooooooooool00_l00000
1_oooooo0000o`000?ooooooMgMgoc8b<P;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o
000000?oooooo`000?l000003Oooool3o`0000_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000X
ooooo`03o`000?oooooooooo04?ooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0iooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@4100=oooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@
40?ooooo00?o410@ooooooooool0<oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@01?ooooo000Xooooo`03o`000?oooooo
oooo04;ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00000gooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003oooo
o`03o`000?oooooooooo03Cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0o
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003_ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000gooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000=oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000Xooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03_o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@03Sooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`00:?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0kooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0=oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0dooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:?ooool7o`0000Ko
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?o
00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`Wo000000?oooooonk^k_lb
<S800_l000000oo^k^ko0000o`00000Booooo`;o00003oooool2o`000004ooooool0003o0000oooo
o`;o00003?ooool01?mEEEGo0000o`000?ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00001_ooool3o`0000Gooooo0_l0000;oooo
o`;o00002Oooool3o`0000;ooooo0_l00003ooooo`;o000000?oEEEEofIVI_l000001Oooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0=ooooo`;o00002Oooool2o`0000Cooooo1?l00007
ooooo`;o00002Oooool00onHV9So410@o`000006o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool00ol0003oooooo`000004o`0000Kooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?o00001Ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Booooo`;o00003oooool2o`000004ooooool0003o0000ooooo`;o0000
3Oooool2o`000003ooooool0003o000000oooooo0_l00006ooooo`?o00001Oooool2o`0000_ooooo
0_l00009ooooo`?o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000kooooo
0_l00009ooooo`;o00001?ooool4o`0000Oooooo0_l0000<ooooo`Ko00007oooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo0?oooooo=?ooool2o`0000;ooooo00?o410@o`000?l000000oooool002So
oooo00?o0000ooooooooool0ooooooleooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool0023o
ooooool0000do`0000cooooo00Co0000oiRHV?lb<S;oc<c<1Oooool002Sooooo0_l00004ooooo`;o
00000_ooool2o`0000;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`Go
00000oooool2o`0000;ooooo0ol00008ooooo`Go00001_ooool2o`000003ooooool0003o000000Ko
oooo0_l00005ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`0000Wooooo0_l000000ooooooo0000ooooo`02ooooo`;o00001Oooool2o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`000004ooooool0003o
0000ooooo`Ko00001?ooool2o`000005ooooool0003o0000ooooool000000_ooool3o`0000Wooooo
0ol0000;ooooo`?o00000oooool5o`0000Cooooo00Co0000ooooool0003o00001_ooool2o`0000?o
oooo1ol00002ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`Go00000oooool3o`0000Go
oooo0_l00004ooooo`Ko00002Oooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Ko
oooo000Xooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04Oooool01?l0003ok^k^
oeEEEOn7QhL5ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00Go0000oooooom4A4Co
0000oa0@4004ooooo`00:?ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool0
1_ooool002Sooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo00Kooooo000X
ooooo`03o`000?oooooooooo00Gooooo0ol00004ooooo`Go00000_ooool2o`000003ooooool0003o
000001_ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2
o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Oooooo0_l00003ooooo`Co00001oooool3o`0000Cooooo0_l0000Gooooo`;o00001_ooool2
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000Oooooo0ol0000:ooooo`Go000000?oooooo`000?l000002Oooool2
o`0000[ooooo0_l0000>ooooo`?o00004_ooool2o`0000Sooooo000Xooooo`;o00001_ooool3o`00
00Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000006oooool2o`0000Cooooo0_l00004oooo
o`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000?ooooo1?l00007oooo
o`?o00001?ooool2o`0001Oooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l00004oooo
o`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool3o`00
00[ooooo1Ol000000ooooooo0000o`000009ooooo`;o00002_ooool2o`0000kooooo0ol0000Loooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0000Kooooo`;o
00002Oooool2o`0000;ooooo0ol00003ooooo`;o00007_ooool2o`0000;ooooo1?l0000;ooooo`;o
000000?oooooo`000?l000005oooool2o`00017ooooo0_l0000@ooooo`;o00003?ooool2o`0000;o
oooo0_l00002ooooo`;o00002_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000Tooooo`;o
00004?ooool2o`0002Cooooo000Xooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`;o0000
0_ooool3o`0000?ooooo0_l0000Nooooo`;o00000_ooool4o`0000_ooooo0_l000000ooooooo0000
o`00000Gooooo`;o00004Oooool2o`00013ooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo
0_l0000:ooooo`;o00005Oooool2o`000003ooooool0003o000002Cooooo0_l0000@ooooo`;o0000
9?ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3o
ooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooooooo
ool0oooooolnooooo`00:?ooool2o`0003Oooooo0_l0000Dooooo`;o00003oooool2o`0003Oooooo
0_l0000Tooooo`;o0000C_ooool2o`0002oooooo000Xooooo`03o`000?oooooooooo03Kooooo0_l0
000Dooooo`;o00003oooool2o`0003Oooooo0_l0000Tooooo`;o0000C_ooool2o`0002oooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000
ooooooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool0
01Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003o
ooooocoooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
ooooockooooo000Fooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnoooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooocko
oooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooo
oolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolooooo
o`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo
?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`005Oooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3oooooockooooo000Fooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@4006ooooo`;o0000ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo
?_ooool001Wooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000
ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0
003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000X
ooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03
o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?oo
ool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool0
02Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo
00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000E
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0oooooolnooooo`005Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooolnooooo`006?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool2o`000?oooooo?oooool001Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo00000?ooooooAoooool001Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooo
oooooooooooo410@0?ooooooAoooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooom7ooooo`005Oooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo
0?ooooooA?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo
0_l00002ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o0000
00?o<S8booooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool03_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
0?oooooo7Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgo
oooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
2Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q0?oooooo7Oooool000Cooooo00CogMgMo`000?l@413o
c<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@
olc<c1;ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool00000
oooooolMooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo
00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`Ko00002Oooool01Olb<S;oV9RHoooooonHV9So<S8b0?oooooo7Ooo
ool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^
k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00
000Aooooo`05olc<c?l0003o0000o`000?o<c<`0oooooolMooooo`000oooool2o`0000;ooooo0_l0
0005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0
000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03oooool01Ol@413o^[Zjoooo
oonj^[[o410@0?oooooo7Oooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM037o
oooo00Go0000okZj^_oooooo^[Zjo`00003ooooooagooooo000?ooooo`03okZj^_m4A4Cooooo00;o
oooo00?oZJVYooooooooool0<?ooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo7Oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -32 0 ]
[.02381 .64303 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31932 Mdot
.03333 .29872 Mdot
.0381 .29872 Mdot
.04286 .29872 Mdot
.04762 .31932 Mdot
.05238 .31932 Mdot
.05714 .33992 Mdot
.0619 .31932 Mdot
.06667 .27812 Mdot
.07143 .29872 Mdot
.07619 .33992 Mdot
.08095 .33992 Mdot
.08571 .33992 Mdot
.09048 .25751 Mdot
.09524 .29872 Mdot
.1 .31932 Mdot
.10476 .29872 Mdot
.10952 .33992 Mdot
.11429 .25751 Mdot
.11905 .29872 Mdot
.12381 .33992 Mdot
.12857 .29872 Mdot
.13333 .27812 Mdot
.1381 .29872 Mdot
.14286 .31932 Mdot
.14762 .29872 Mdot
.15238 .31932 Mdot
.15714 .36052 Mdot
.1619 .29872 Mdot
.16667 .29872 Mdot
.17143 .33992 Mdot
.17619 .33992 Mdot
.18095 .29872 Mdot
.18571 .29872 Mdot
.19048 .36052 Mdot
.19524 .25751 Mdot
.2 .29872 Mdot
.20476 .33992 Mdot
.20952 .29872 Mdot
.21429 .36052 Mdot
.21905 .29872 Mdot
.22381 .33992 Mdot
.22857 .29872 Mdot
.23333 .27812 Mdot
.2381 .27812 Mdot
.24286 .31932 Mdot
.24762 .23691 Mdot
.25238 .29872 Mdot
.25714 .29872 Mdot
.2619 .29872 Mdot
.26667 .31932 Mdot
.27143 .29872 Mdot
.27619 .23691 Mdot
.28095 .27812 Mdot
.28571 .38112 Mdot
.29048 .31932 Mdot
.29524 .33992 Mdot
.3 .31932 Mdot
.30476 .25751 Mdot
.30952 .36052 Mdot
.31429 .36052 Mdot
.31905 .33992 Mdot
.32381 .31932 Mdot
.32857 .33992 Mdot
.33333 .29872 Mdot
.3381 .29872 Mdot
.34286 .36052 Mdot
.34762 .29872 Mdot
.35238 .31932 Mdot
.35714 .36052 Mdot
.3619 .29872 Mdot
.36667 .36052 Mdot
.37143 .25751 Mdot
.37619 .25751 Mdot
.38095 .33992 Mdot
.38571 .25751 Mdot
.39048 .31932 Mdot
.39524 .31932 Mdot
.4 .27812 Mdot
.40476 .29872 Mdot
.40952 .31932 Mdot
.41429 .27812 Mdot
.41905 .31932 Mdot
.42381 .29872 Mdot
.42857 .25751 Mdot
.43333 .25751 Mdot
.4381 .31932 Mdot
.44286 .31932 Mdot
.44762 .33992 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .33992 Mdot
.46667 .27812 Mdot
.47143 .29872 Mdot
.47619 .31932 Mdot
.48095 .27812 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .33992 Mdot
.5 .27812 Mdot
.50476 .29872 Mdot
.50952 .36052 Mdot
.51429 .31932 Mdot
.51905 .25751 Mdot
.52381 .29872 Mdot
.52857 .36052 Mdot
.53333 .29872 Mdot
.5381 .27812 Mdot
.54286 .31932 Mdot
.54762 .31932 Mdot
.55238 .29872 Mdot
.55714 .29872 Mdot
.5619 .29872 Mdot
.56667 .29872 Mdot
.57143 .36052 Mdot
.57619 .29872 Mdot
.58095 .25751 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .23691 Mdot
.60476 .29872 Mdot
.60952 .29872 Mdot
.61429 .33992 Mdot
.61905 .25751 Mdot
.62381 .33992 Mdot
.62857 .36052 Mdot
.63333 .29872 Mdot
.6381 .31932 Mdot
.64286 .36052 Mdot
.64762 .31932 Mdot
.65238 .36052 Mdot
.65714 .31932 Mdot
.6619 .25751 Mdot
.66667 .29872 Mdot
.67143 .29872 Mdot
.67619 .31932 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .31932 Mdot
.7 .27812 Mdot
.70476 .31932 Mdot
.70952 .29872 Mdot
.71429 .29872 Mdot
.71905 .29872 Mdot
.72381 .25751 Mdot
.72857 .33992 Mdot
.73333 .25751 Mdot
.7381 .29872 Mdot
.74286 .31932 Mdot
.74762 .31932 Mdot
.75238 .31932 Mdot
.75714 .33992 Mdot
.7619 .29872 Mdot
.76667 .36052 Mdot
.77143 .31932 Mdot
.77619 .23691 Mdot
.78095 .31932 Mdot
.78571 .31932 Mdot
.79048 .31932 Mdot
.79524 .29872 Mdot
.8 .31932 Mdot
.80476 .29872 Mdot
.80952 .21631 Mdot
.81429 .29872 Mdot
.81905 .29872 Mdot
.82381 .31932 Mdot
.82857 .33992 Mdot
.83333 .33992 Mdot
.8381 .27812 Mdot
.84286 .33992 Mdot
.84762 .27812 Mdot
.85238 .29872 Mdot
.85714 .29872 Mdot
.8619 .31932 Mdot
.86667 .29872 Mdot
.87143 .29872 Mdot
.87619 .27812 Mdot
.88095 .31932 Mdot
.88571 .29872 Mdot
.89048 .36052 Mdot
.89524 .25751 Mdot
.9 .27812 Mdot
.90476 .27812 Mdot
.90952 .29872 Mdot
.91429 .36052 Mdot
.91905 .31932 Mdot
.92381 .21631 Mdot
.92857 .31932 Mdot
.93333 .31932 Mdot
.9381 .31932 Mdot
.94286 .31932 Mdot
.94762 .33992 Mdot
.95238 .27812 Mdot
.95714 .29872 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .33992 Mdot
.97619 .33992 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo
000Eooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooAoooool000gooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`3oooooodGooooo000Hooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o0000ooooooloooooo`005oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo?_ooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Eooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool000gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?ooo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3ooooo
ockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000oooooolo
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oo
oooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003ooooo
ocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0
oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolnooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3oooooockooooo000=ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000ooooooloooooo`00
6?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0k?ooool2o`00027o
oooo0_l0000/ooooo`005_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3/ooooo`;o00008Oooool2o`0002cooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xooooo`03o`000?oooooo
oooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`10ooooo`;o00001oooool2o`00067ooooo0_l0000dooooo`;o0000FOooool002Sooooo
00?o0000ooooooooool0@?ooool2o`0000Oooooo0_l0001Qooooo`;o0000=?ooool2o`0005Wooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0003oooooocoooooo000Xoooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool00ol0003oooooooooo`0@ooooo`;o00001_ooool2o`0001Kooooo0_l0000Pooooo`;o0000
4_ooool4o`000003ooooool0003o000000_ooooo0ol0000Hooooo`;o00004Oooool2o`0000[ooooo
0_l0000;ooooo`;o00004Oooool2o`000003ooooool0003o0000033ooooo0_l0000dooooo`00:?oo
ool00ol0003oooooooooo`0@ooooo`;o00001_ooool2o`0001Kooooo0_l0000Pooooo`;o00004_oo
ool4o`000003ooooool0003o000000_ooooo0ol0000Hooooo`;o00004Oooool2o`0000[ooooo0_l0
000;ooooo`;o00004Oooool2o`000003ooooool0003o0000033ooooo0_l0000dooooo`00:?ooool0
0ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo03oooooo00GoA4A4o`00
0?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>Oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0
003o<S8bonk^kP0dooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`00:?ooool2o`0004?ooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL0>oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000ooooooooool01_ooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`0dooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Cooooo`00:?ooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@03Oooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo03?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:?ooool0
0ol0003oooooooooo`12ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000=oooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0dooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002Sooooo00?o0000
ooooooooool02Oooool2o`0001;ooooo0_l0000Mooooo`Co000000Co8B4Qo`000?lb<S;oc<c<0_oo
ool01?l0003oooooooooooooool3o`0002;ooooo0_l00002ooooo`;o00003_ooool2o`000003oooo
ool0003ooooo00;o000000Coooooo`000?oooooooooo0_l00003ooooo`06o`000?oooooooooooooo
ool0003ooooo0_l0000[ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Gooooo1?l0000<ooooo`;o000000Coooooo`000?l0003o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool002So
oooo00?o0000ooooooooool02Oooool2o`0001;ooooo0_l0000Mooooo`Co00001_ooool01Ol@413o
oooooooooooooooo410@00;o00008_ooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`00
0?ooool00_l000001?oooooo410@ooooooooool2o`0000?ooooo00Ko410@oooooooooooooooooa0@
4?ooool2o`0002_ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400Dooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Gooooo1?l0000<ooooo`;o000000Coooooo`000?l0003o410@0oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002Sooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0=?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002Sooooo0_l00010
ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Wooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0eooooo`03
oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool0
0ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooo000000Co00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000002ooooo`Co00000_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000Kooooo1Ol000000ooooooo0000o`00000Aooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000_ooooo0_l00004ooooo`;o00003Oooool2o`0000Sooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool6o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000Wooooo0ol00004ooooo`;o00001?ooool5o`0000?ooooo0_l00006ooooo`;o00002?oo
ool2o`000004ooooool0003o0000ooooo`?o00002?ooool4o`000004ooooool0003o0000o`0000?o
oooo0_l00005ooooo`;o00003Oooool4o`0001oooooo000Xooooo`03o`000?oooooo000000Co0000
1_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool3o`0000?ooooo0_l000001?oooooo
0000o`000?ooool4o`0000Kooooo1Ol000000ooooooo0000o`00000Aooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000_ooooo0_l00004ooooo`;o00003Oooool2o`0000Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000000;ooooo0_l00003oooo
o`?o00001Oooool2o`0000Wooooo0ol00004ooooo`;o00001?ooool5o`0000?ooooo0_l00006oooo
o`;o00002?ooool2o`000004ooooool0003o0000ooooo`?o00002?ooool4o`000004ooooool0003o
0000o`0000?ooooo0_l00005ooooo`;o00003Oooool4o`0001Gooooo0_l00002ooooo`03oa0@4?l0
003o000000?ooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool01Ol0003oooooonk^k_lb
<S;oc<c<00Cooooo000Poooooooo0000=?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000X
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0A
ooooo`03o`000?l@413oV9RH00Kooooo000Xooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:?ooool2o`0000Cooooo1_l0000:oooo
o`;o00002oooool2o`000003ooooool0003o000001[ooooo0_l00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Kooooo0_l00006ooooo`;o00002_ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`?o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000
00;o00001Oooool2o`0000Oooooo0ol0000:ooooo`;o00003_ooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`Go00001?ooool2
o`000003ooooool0003o000000Go00001_ooool2o`0000Wooooo0_l00004ooooo`;o00002_ooool2
o`000003ooooool0003o000000Co00007Oooool01Ol0003oooooodA4A?l0003o410@00Cooooo000X
ooooo`;o00001?ooool6o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000006_ooool2
o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0000:
ooooo`Co00000_ooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00001oooool3o`0000[ooooo0_l0000>
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0
003o000000[ooooo1Ol00004ooooo`;o000000?oooooo`000?l000001Ol00006ooooo`;o00002Ooo
ool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?l0000Mooooo`03o`000?oo
oooooooo00Kooooo000Xooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`06
ooooo`00:?ooool00ol0003oooooooooo`3oooooocCooooo0_l00008ooooo`00:?ooool2o`000?oo
oooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003ooooooooo
o`06ooooo`;o00001?ooool5o`0000Gooooo0_l00002ooooo`;o00003Oooool3o`0000Oooooo0_l0
0004ooooo`;o00005?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00004ooo
ool6o`0000Sooooo0_l0000Mooooo`;o00001?ooool4o`00013ooooo0_l0000=ooooo`;o00001_oo
ool2o`0001Cooooo1?l000000ooooooo0000o`00000Nooooo`;o00001Oooool3o`0001cooooo000X
ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`Go00001Oooool2o`0000;ooooo0_l0000=
ooooo`?o00001oooool2o`0000Cooooo0_l0000Dooooo`;o00001Oooool2o`000003ooooool0003o
000000kooooo0_l0000Cooooo`Ko00002?ooool2o`0001gooooo0_l00004ooooo`Co00004?ooool2
o`0000gooooo0_l00006ooooo`;o00005?ooool4o`000003ooooool0003o000001kooooo0_l00005
ooooo`?o00007?ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003ooooooooo
o`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool09Oooool2o`0000Sooooo0_l00005ooooo`;o00006oooool4o`0000Kooooo0_l00003oooo
o`;o000000?oooooo`000?l00000:_ooool2o`0000?ooooo0_l0000;ooooo`;o00004?ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Qooooo`;o00009?ooool2o`0000Gooooo0_l0000_oooo
o`00:?ooool00ol0003oooooooooo`0Uooooo`;o00002?ooool2o`0000Gooooo0_l0000Kooooo`Co
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Zooooo`;o00000oooool2o`0000_o
oooo0_l0000@ooooo`;o00000_ooool2o`000003ooooool0003o0000027ooooo0_l0000Tooooo`;o
00001Oooool2o`0002oooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`1<ooooo`;o0000koooool002Sooooo
00?o0000ooooooooool0C?ooool2o`000>oooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooo
ooooool0oooooolnooooo`006?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?_ooool001So
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003ooooo
ocoooooo000Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0?oooooo?_ooool001Sooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolnooooo`006?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
ockooooo000Fooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool2o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool0
0ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo
000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0ooooooln
ooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`;o0000ooooooloooooo`00
:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_oo
ool002Sooooo00?o0000ooooooooool0oooooolnooooo`005Oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`3oooooockooooo000Fooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`;o0000ooooooloooooo`005oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3oooooockooooo000Hooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?_oo
ool001Wooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Gooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo0_l0
003oooooocoooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o0000oooo
ooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2
o`000?oooooo?oooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool00ol0003o
ooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xoooo
o`;o0000ooooooloooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Xooooo`03o`00
0?oooooooooo0?oooooo?_ooool002Sooooo00?o0000ooooooooool0oooooolnooooo`00:?ooool0
0ol0003oooooooooo`3oooooockooooo000Xooooo`03o`000?oooooooooo0?oooooo?_ooool002So
oooo00?o0000ooooooooool0oooooolnooooo`00:?ooool2o`000?oooooo?oooool002Sooooo00?o
0000ooooooooool0oooooolnooooo`00:?ooool00ol0003oooooooooo`3oooooockooooo000Eoooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolnooooo`005Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolnooooo`006?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool2o`000?oooooo?oooool001Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo00000?ooooooAoooool001Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@0?ooooooAoooool001Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0oooooom7ooooo`005Oooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodOooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?oo
ooooA?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l0
0002ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o
<S8booooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool03_ooool01?l@413o0000odA4A?o<c<cooooooako
oooo0003ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool01_l0003ogMgMoooooooooooo
V9RHodA4A0?ooooo00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool0
0oo<c<co0000oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000_ooooo00?o
V9RHoa0@4?oMgMd0oooooolMooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0ooo
ool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003o
oooooooooooooooo000001Cooooo00?oQhN7oeEEEOooool0oooooolLooooo`001?ooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04
ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
2Oooool01Oo<c<co8B4Qo`000?mEEEGo00000?oooooo7Oooool000Cooooo00Co8B4QogMgMomgMgOo
<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Aooooo`05ob4Q8On7QhOooooooiRH
V?l00000oooooolMooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;o
oooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool03oooool01Ol0003ooooooooooooooooo00000?oooooo7Oooool000oo
oooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM037ooooo00Go8B4QoiRHV?ooooooMgMgoeEE
E@3ooooooagooooo000?ooooo`03okZj^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool0
1Oo<c<co410@o`000?lb<S;ok^k^0?oooooo7Oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-27.4401, -32.4017, \
0.857472, 0.396404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30902 Mdot
.03333 .30902 Mdot
.0381 .28842 Mdot
.04286 .30902 Mdot
.04762 .30902 Mdot
.05238 .30902 Mdot
.05714 .35022 Mdot
.0619 .30902 Mdot
.06667 .28842 Mdot
.07143 .28842 Mdot
.07619 .32962 Mdot
.08095 .35022 Mdot
.08571 .35022 Mdot
.09048 .24721 Mdot
.09524 .28842 Mdot
.1 .30902 Mdot
.10476 .30902 Mdot
.10952 .32962 Mdot
.11429 .24721 Mdot
.11905 .30902 Mdot
.12381 .32962 Mdot
.12857 .30902 Mdot
.13333 .28842 Mdot
.1381 .28842 Mdot
.14286 .30902 Mdot
.14762 .28842 Mdot
.15238 .30902 Mdot
.15714 .35022 Mdot
.1619 .30902 Mdot
.16667 .30902 Mdot
.17143 .32962 Mdot
.17619 .32962 Mdot
.18095 .28842 Mdot
.18571 .30902 Mdot
.19048 .37082 Mdot
.19524 .26781 Mdot
.2 .28842 Mdot
.20476 .32962 Mdot
.20952 .28842 Mdot
.21429 .37082 Mdot
.21905 .30902 Mdot
.22381 .35022 Mdot
.22857 .28842 Mdot
.23333 .28842 Mdot
.2381 .26781 Mdot
.24286 .30902 Mdot
.24762 .22661 Mdot
.25238 .30902 Mdot
.25714 .28842 Mdot
.2619 .28842 Mdot
.26667 .32962 Mdot
.27143 .28842 Mdot
.27619 .24721 Mdot
.28095 .26781 Mdot
.28571 .39142 Mdot
.29048 .30902 Mdot
.29524 .32962 Mdot
.3 .32962 Mdot
.30476 .24721 Mdot
.30952 .37082 Mdot
.31429 .37082 Mdot
.31905 .35022 Mdot
.32381 .32962 Mdot
.32857 .35022 Mdot
.33333 .28842 Mdot
.3381 .28842 Mdot
.34286 .35022 Mdot
.34762 .30902 Mdot
.35238 .32962 Mdot
.35714 .37082 Mdot
.3619 .30902 Mdot
.36667 .37082 Mdot
.37143 .24721 Mdot
.37619 .24721 Mdot
.38095 .32962 Mdot
.38571 .26781 Mdot
.39048 .30902 Mdot
.39524 .32962 Mdot
.4 .26781 Mdot
.40476 .28842 Mdot
.40952 .32962 Mdot
.41429 .26781 Mdot
.41905 .30902 Mdot
.42381 .28842 Mdot
.42857 .24721 Mdot
.43333 .24721 Mdot
.4381 .30902 Mdot
.44286 .30902 Mdot
.44762 .35022 Mdot
.45238 .30902 Mdot
.45714 .35022 Mdot
.4619 .32962 Mdot
.46667 .28842 Mdot
.47143 .28842 Mdot
.47619 .30902 Mdot
.48095 .28842 Mdot
.48571 .30902 Mdot
.49048 .32962 Mdot
.49524 .32962 Mdot
.5 .28842 Mdot
.50476 .28842 Mdot
.50952 .35022 Mdot
.51429 .30902 Mdot
.51905 .24721 Mdot
.52381 .30902 Mdot
.52857 .35022 Mdot
.53333 .28842 Mdot
.5381 .28842 Mdot
.54286 .32962 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .28842 Mdot
.5619 .28842 Mdot
.56667 .30902 Mdot
.57143 .35022 Mdot
.57619 .30902 Mdot
.58095 .24721 Mdot
.58571 .32962 Mdot
.59048 .30902 Mdot
.59524 .35022 Mdot
.6 .24721 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .32962 Mdot
.61905 .24721 Mdot
.62381 .32962 Mdot
.62857 .35022 Mdot
.63333 .28842 Mdot
.6381 .30902 Mdot
.64286 .37082 Mdot
.64762 .30902 Mdot
.65238 .35022 Mdot
.65714 .32962 Mdot
.6619 .24721 Mdot
.66667 .30902 Mdot
.67143 .28842 Mdot
.67619 .30902 Mdot
.68095 .32962 Mdot
.68571 .26781 Mdot
.69048 .30902 Mdot
.69524 .32962 Mdot
.7 .28842 Mdot
.70476 .30902 Mdot
.70952 .28842 Mdot
.71429 .30902 Mdot
.71905 .28842 Mdot
.72381 .26781 Mdot
.72857 .35022 Mdot
.73333 .26781 Mdot
.7381 .30902 Mdot
.74286 .30902 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .35022 Mdot
.7619 .30902 Mdot
.76667 .35022 Mdot
.77143 .32962 Mdot
.77619 .22661 Mdot
.78095 .30902 Mdot
.78571 .32962 Mdot
.79048 .32962 Mdot
.79524 .28842 Mdot
.8 .32962 Mdot
.80476 .28842 Mdot
.80952 .20601 Mdot
.81429 .28842 Mdot
.81905 .28842 Mdot
.82381 .30902 Mdot
.82857 .35022 Mdot
.83333 .32962 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .30902 Mdot
.85714 .30902 Mdot
.8619 .32962 Mdot
.86667 .28842 Mdot
.87143 .28842 Mdot
.87619 .26781 Mdot
.88095 .30902 Mdot
.88571 .30902 Mdot
.89048 .35022 Mdot
.89524 .24721 Mdot
.9 .26781 Mdot
.90476 .28842 Mdot
.90952 .30902 Mdot
.91429 .37082 Mdot
.91905 .32962 Mdot
.92381 .20601 Mdot
.92857 .32962 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .32962 Mdot
.94762 .32962 Mdot
.95238 .26781 Mdot
.95714 .30902 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .35022 Mdot
.97619 .32962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000>[ooooo0_l0000Qooooo`;o0000
:oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0j_ooool2o`00027ooooo0_l0000[ooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000@Oooool2o`0009kooooo0_l0001Hooooo`00:oooool00ol0003oooooooooo`10
ooooo`;o0000W_ooool2o`0005Sooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool04Oooool2
o`0000Gooooo0_l0000_ooooo`;o00001oooool2o`0001;ooooo0ol0000>ooooo`?o00006?ooool2
o`00017ooooo0_l00004ooooo`;o00001?ooool2o`0000_ooooo0_l00014ooooo`;o0000=?ooool0
02_ooooo0_l0000Booooo`;o00001Oooool2o`0002oooooo0_l00007ooooo`;o00004_ooool3o`00
00kooooo0ol0000Hooooo`;o00004Oooool2o`0000Cooooo0_l00004ooooo`;o00002oooool2o`00
04Cooooo0_l0000dooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0000aooooo`;o00002oooool2o`000005odA4A?l0003o0000oc8b<_oMgMd00_ooool01?o^
k^ko<S8bo`000?lb<S82o`0001kooooo0_l00002ooooo`;o00000oooool2o`0000kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
02kooooo0_l00004ooooo`Co000000Co410@o`000?l0003ooooo0ol000002Olb<S;ogMgMoooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o00001_ooool2o`0000Kooooo0_l0000:ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`0`ooooo`;o00002oooool2o`0000?ooooo00SoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV0;o00007_ooool2o`0000;ooooo0_l00003ooooo`;o0000
4?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02kooooo0_l00006ooooo`03o`000?oooooooooo00;o000000Koooooo`00
0?l0003oooooogMgMolb<S82ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool2o`0000Kooooo
0_l00006ooooo`;o00002_ooool00onHV9So8B4Qonk^kP02o`0000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000oooooooo
ool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000ooooooooool0@_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003Kooooo00?o
0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
<oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000>_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003Kooooo
00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`00000fooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100>_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@4100=oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo017ooooo000[ooooo`;o00000_ooool2o`0000Oooooo0ol00005
ooooo`;o00002_ooool3o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool4o`000003ooooool0003ooooo00;ooooo1_l000000onHV9SoMgMgooooo`0>
ooooo`Co00004_ooool2o`0000Cooooo0_l0000:ooooo`Co000000Ooooooo`000?l0003oooooogMg
MonHV9Sooooo00?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o00001?ooool3o`0001Co
oooo0_l00009ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`000004ooooool0003o
0000ooooo`?o00001?ooool2o`0000Kooooo1?l00008ooooo`;o00002Oooool01_l0003o^[Zjoooo
oonHV9So410@ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04oooool002_ooooo00Co0000oooooooooooooooo0_l00007ooooo`?o00001Oooool2
o`0000[ooooo0ol000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003ooooool0003o
000000?ooooo1?l000000ooooooo0000o`000008o`000003oc8b<_o^k^kooooo00kooooo1?l0000B
ooooo`;o00001?ooool2o`0000[ooooo1?l000001_oooooo0000o`000?ooooook^k^oc8b<PCo0000
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o00001?ooool3o`0001Cooooo0_l00009ooooo`;o
00001oooool2o`000004oeEEEOl0003o0000ooooo`;o00000_ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00001_oo
ool4o`0000Sooooo0_l00009ooooo`06oiRHV?l@413o0000ob4Q8Oo<c<cooooo0_l000001Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?oo
ooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool4o`000003ooooool0
003o000000?o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`05ooooo`?o00000_oo
ool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0
0007ooooo`?o00001Oooool2o`000005ooooool0003o0000ooooool000001oooool2o`0000Gooooo
00?o0000ooooooooool01oooool2o`0000;ooooo0ol00006ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000Cooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
00000oooool01?l0003oooooooooooooool2o`000003ooooool0003o000000Gooooo0ol00003oooo
o`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;o00001_ooool5o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Kooooo1?l00003ooooo`;o00001?ooool3o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo
00;ooooo1?l00005ooooo`?o00001Oooool2o`0000Gooooo1?l00004ooooo`;o000000Goooooo`00
0?l0003oooooo`00000Cooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0
003oooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0
003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooooooo
ool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo00cooooo
0_l00008ooooo`;o00000oooool2o`0000cooooo1?l00006ooooo`;o00004Oooool2o`0000Oooooo
0ol00005ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo
0_l00007ooooo`?o00003Oooool2o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Gooooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`?o0000
00?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Cooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0000Oooooo0_l0000Aooooo`;o00002?ooool002_ooooo0_l0
000=ooooo`;o00002?ooool2o`0000?ooooo0_l0000<ooooo`Co00001_ooool2o`00017ooooo0_l0
0007ooooo`?o00001Oooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0
000>ooooo`;o00001oooool3o`0000gooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0
003o000000Sooooo0_l00005ooooo`;o00000oooool2o`0000oooooo0_l00004ooooo`;o00000_oo
ool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00003ooo
ool2o`000003ooooool0003o000000;ooooo1?l00007ooooo`;o00006oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`07ooooo`;o00001Oooool3o`0001Cooooo0_l0000Booooo`;o00006ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000Cooooo0_l0000;ooooo`;o00001Oooool2o`0000Sooooo0_l00006ooooo`;o00005Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`;o00004Oooool2o`0001Kooooo0_l0
000Mooooo`00:oooool2o`0000Sooooo0_l00005ooooo`?o00005?ooool2o`0001;ooooo0_l0000K
ooooo`;o000000?oooooo`000?l000000_ooool2o`0001kooooo0_l000000ooooooo0000o`00000=
ooooo`;o00001?ooool2o`0000_ooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo0_l0000E
ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l0000Aooooo`;o00005_ooool2
o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00
033ooooo0_l00005ooooo`;o00006oooool3o`0000_ooooo0_l000000ooooooo0000o`00001Boooo
o`;o0000D?ooool2o`0002kooooo000[ooooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o
00006oooool3o`0000_ooooo0_l000000ooooooo0000o`00001Booooo`;o0000D?ooool2o`0002ko
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0001=ooooo`;o0000k?ooool002_ooooo00?o0000ooooooooool0
C?ooool2o`000>cooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo
>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo
>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0
01Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`000?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3o
oooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooocco
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3o
oooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000K
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooo
oolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooo
oom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooo
oom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?oo
ool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003
ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0?ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
k_oooooo5Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgo
oooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolEooooo`00
1?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@
00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0?oooooo5Oooool000Cooooo00Co
k^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7
QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?ooooooooooooooool000000_ooool6
o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000?oooooo5Ooo
ool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^
k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00
000Dooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00003ooooooaGooooo
0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEE
E@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@403ooooooaGooooo
000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0dooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooooaGooooo000?ooooo`03okZj^_m4A4Cooooo00;o
oooo00?oZJVYooooooooool0<Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31932 Mdot
.03333 .31932 Mdot
.0381 .29872 Mdot
.04286 .29872 Mdot
.04762 .31932 Mdot
.05238 .31932 Mdot
.05714 .33992 Mdot
.0619 .29872 Mdot
.06667 .27812 Mdot
.07143 .27812 Mdot
.07619 .33992 Mdot
.08095 .33992 Mdot
.08571 .36052 Mdot
.09048 .23691 Mdot
.09524 .27812 Mdot
.1 .31932 Mdot
.10476 .29872 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .29872 Mdot
.12381 .31932 Mdot
.12857 .29872 Mdot
.13333 .29872 Mdot
.1381 .29872 Mdot
.14286 .29872 Mdot
.14762 .29872 Mdot
.15238 .31932 Mdot
.15714 .36052 Mdot
.1619 .31932 Mdot
.16667 .31932 Mdot
.17143 .31932 Mdot
.17619 .31932 Mdot
.18095 .29872 Mdot
.18571 .29872 Mdot
.19048 .38112 Mdot
.19524 .25751 Mdot
.2 .29872 Mdot
.20476 .31932 Mdot
.20952 .27812 Mdot
.21429 .36052 Mdot
.21905 .31932 Mdot
.22381 .33992 Mdot
.22857 .27812 Mdot
.23333 .29872 Mdot
.2381 .27812 Mdot
.24286 .29872 Mdot
.24762 .23691 Mdot
.25238 .29872 Mdot
.25714 .27812 Mdot
.2619 .29872 Mdot
.26667 .33992 Mdot
.27143 .27812 Mdot
.27619 .23691 Mdot
.28095 .27812 Mdot
.28571 .40172 Mdot
.29048 .31932 Mdot
.29524 .31932 Mdot
.3 .33992 Mdot
.30476 .25751 Mdot
.30952 .38112 Mdot
.31429 .38112 Mdot
.31905 .36052 Mdot
.32381 .33992 Mdot
.32857 .33992 Mdot
.33333 .29872 Mdot
.3381 .27812 Mdot
.34286 .33992 Mdot
.34762 .29872 Mdot
.35238 .31932 Mdot
.35714 .38112 Mdot
.3619 .31932 Mdot
.36667 .36052 Mdot
.37143 .23691 Mdot
.37619 .25751 Mdot
.38095 .33992 Mdot
.38571 .27812 Mdot
.39048 .31932 Mdot
.39524 .33992 Mdot
.4 .27812 Mdot
.40476 .27812 Mdot
.40952 .33992 Mdot
.41429 .27812 Mdot
.41905 .29872 Mdot
.42381 .27812 Mdot
.42857 .25751 Mdot
.43333 .25751 Mdot
.4381 .31932 Mdot
.44286 .29872 Mdot
.44762 .33992 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .31932 Mdot
.46667 .29872 Mdot
.47143 .27812 Mdot
.47619 .31932 Mdot
.48095 .27812 Mdot
.48571 .31932 Mdot
.49048 .33992 Mdot
.49524 .33992 Mdot
.5 .29872 Mdot
.50476 .29872 Mdot
.50952 .33992 Mdot
.51429 .29872 Mdot
.51905 .25751 Mdot
.52381 .29872 Mdot
.52857 .33992 Mdot
.53333 .27812 Mdot
.5381 .27812 Mdot
.54286 .31932 Mdot
.54762 .29872 Mdot
.55238 .31932 Mdot
.55714 .27812 Mdot
.5619 .29872 Mdot
.56667 .29872 Mdot
.57143 .36052 Mdot
.57619 .29872 Mdot
.58095 .23691 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .25751 Mdot
.60476 .31932 Mdot
.60952 .29872 Mdot
.61429 .33992 Mdot
.61905 .25751 Mdot
.62381 .31932 Mdot
.62857 .33992 Mdot
.63333 .27812 Mdot
.6381 .31932 Mdot
.64286 .36052 Mdot
.64762 .31932 Mdot
.65238 .36052 Mdot
.65714 .31932 Mdot
.6619 .23691 Mdot
.66667 .31932 Mdot
.67143 .27812 Mdot
.67619 .29872 Mdot
.68095 .31932 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .31932 Mdot
.7 .29872 Mdot
.70476 .31932 Mdot
.70952 .27812 Mdot
.71429 .29872 Mdot
.71905 .29872 Mdot
.72381 .27812 Mdot
.72857 .36052 Mdot
.73333 .25751 Mdot
.7381 .31932 Mdot
.74286 .29872 Mdot
.74762 .29872 Mdot
.75238 .33992 Mdot
.75714 .36052 Mdot
.7619 .29872 Mdot
.76667 .33992 Mdot
.77143 .31932 Mdot
.77619 .23691 Mdot
.78095 .31932 Mdot
.78571 .33992 Mdot
.79048 .33992 Mdot
.79524 .29872 Mdot
.8 .33992 Mdot
.80476 .29872 Mdot
.80952 .21631 Mdot
.81429 .27812 Mdot
.81905 .29872 Mdot
.82381 .29872 Mdot
.82857 .33992 Mdot
.83333 .33992 Mdot
.8381 .29872 Mdot
.84286 .33992 Mdot
.84762 .25751 Mdot
.85238 .31932 Mdot
.85714 .29872 Mdot
.8619 .33992 Mdot
.86667 .29872 Mdot
.87143 .27812 Mdot
.87619 .27812 Mdot
.88095 .31932 Mdot
.88571 .29872 Mdot
.89048 .33992 Mdot
.89524 .23691 Mdot
.9 .27812 Mdot
.90476 .29872 Mdot
.90952 .31932 Mdot
.91429 .36052 Mdot
.91905 .33992 Mdot
.92381 .21631 Mdot
.92857 .33992 Mdot
.93333 .31932 Mdot
.9381 .31932 Mdot
.94286 .33992 Mdot
.94762 .33992 Mdot
.95238 .27812 Mdot
.95714 .29872 Mdot
.9619 .29872 Mdot
.96667 .31932 Mdot
.97143 .36052 Mdot
.97619 .31932 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0>[ooooo0_l0000Qooooo`;o0000
:oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0j_ooool2o`00027ooooo0_l0000[ooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool04Oooool2o`0000Go
oooo0_l0000Vooooo`;o00001oooool2o`0001_ooooo0_l0000mooooo`;o00005oooool2o`00023o
oooo0_l0000Rooooo`;o0000=?ooool002_ooooo00?o0000ooooooooool04Oooool2o`0000Gooooo
0_l0000Vooooo`;o00001oooool2o`0001_ooooo0_l0000mooooo`;o00005oooool2o`00023ooooo
0_l0000Rooooo`;o0000=?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo033ooooo0_l0000Pooooo`;o0000
4oooool2o`0000kooooo0ol0000Hooooo`;o00005oooool2o`0000Cooooo0_l0000Pooooo`;o0000
8Oooool2o`0004;ooooo000[ooooo`03o`000?oooooooooo033ooooo0_l0000Pooooo`;o00004ooo
ool2o`0000kooooo0ol0000Hooooo`;o00005oooool2o`0000Cooooo0_l0000Pooooo`;o00008Ooo
ool2o`0004;ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooo
ooooool02_ooool3o`0000Gooooo0_l0000Qooooo`;o00000oooool2o`000003ooooool0003o0000
00?ooooo00CoMgMgo`000?l0003ooooo0ol000000ooooooo0000o`00000@ooooo`;o00003?ooool2
o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000cooooo0_l000001Ooooooo0000o`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`Co00001?ooool2o`0001Go
oooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool02oooool2o`0000oooooo0ol00006oooo
o`;o00003?ooool00onHV9So0000o`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo00[ooooo0ol00005
ooooo`;o00008Oooool2o`0000?ooooo0_l000001ooooooo0000o`000?l0003o8B4Qo`000?lb<S80
0_l000001Ooooooo0000o`000?l0003ooooo00;o00004?ooool2o`0000cooooo0_l00002ooooo`Co
000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o000000Goooooo`000?l0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool4o`0000Cooooo0_l0000Eooooo`;o00002Ooo
ool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`000006ooooool0003o8B4Qo`000?lb<S;o
c<c<0_ooool01Ol0003ooooooooooooooooo000000gooooo0_l0000?ooooo`?o00001_ooool2o`00
00gooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Aooooo`00:oooool2o`00043ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo
000[ooooo`03o`000?oooooooooo03oooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
>?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`04o`000?ooooooooooooooo`?o00001?ooool2o`0000_ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001_l00008ooooo`Co00000_ooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`;o
00005?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool3o`000004ooooool0003o0000oooo
o`;o00001Oooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00
01;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0ol00003oooo
o`;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00001?ooool4o`00
00Cooooo0_l00004ooooo`;o00003_ooool3o`00023ooooo000[ooooo`04o`000?oooooooooooooo
o`?o00001?ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l00008oooo
o`Co00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000001?ooooo0_l00002ooooo`;o00005?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool3
o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo1?l000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000Gooooo0ol00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol0
0003ooooo`;o00001?ooool4o`0000Cooooo0_l00004ooooo`;o00003_ooool3o`0001Kooooo0_l0
0002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool0
1Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So
<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool4o`00
00?ooooo0ol0000=ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000005o`00
00Kooooo0_l00003ooooo`;o00004oooool4o`0000oooooo0_l000000ooooooo0000o`000006oooo
o`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000004?ooool4o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co00002Oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Cooooo`;o00001oooool2o`0000Kooooo0_l00006
ooooo`?o00001oooool2o`000003ooooool0003o000001;ooooo00Go0000oooooom4A4Co0000oa0@
4004ooooo`00:oooool4o`0000?ooooo0ol0000=ooooo`;o00001Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000005o`0000Kooooo0_l00003ooooo`;o00004oooool4o`0000oooooo0_l00000
0ooooooo0000o`000006ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000004?ooool4o`0000Sooooo0_l00004ooooo`;o00001?ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`Co00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Cooooo`;o00001ooo
ool2o`0000Kooooo0_l00006ooooo`?o00001oooool2o`000003ooooool0003o000001;ooooo00?o
0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooo
oooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<Oooool2o`0000Sooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo00Oooooo0_l00003ooooo`Co00001_ooool2o`00027ooooo0_l0000;ooooo`;o00002?oo
ool2o`0000Gooooo1?l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00002_oo
ool2o`000003ooooool0003o000000Sooooo0ol00002ooooo`;o00001?ooool2o`0001;ooooo0_l0
0004ooooo`;o00000_ooool2o`0002Cooooo0_l00002ooooo`;o00001?ooool3o`000003ooooool0
003o000000Oooooo0ol000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002ooooo`Co00009?ooool002_ooooo00?o0000ooooooooool01oooool2
o`0000?ooooo1?l00006ooooo`;o00008Oooool2o`0000_ooooo0_l00008ooooo`;o00001Oooool4
o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000002?ooool3o`0000;ooooo0_l00004ooooo`;o00004_ooool2o`0000Cooooo0_l00002
ooooo`;o00009?ooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001oooool3
o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o
000000;ooooo1?l0000Tooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`0?ooooo`;o00005?ooool2o`0000oooooo0_l0000Nooooo`;o00003?ooool2o`00
03cooooo0_l0000Dooooo`;o000000?oooooo`000?l000005Oooool2o`0000Kooooo0_l0000^oooo
o`;o00003oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo00oooooo0_l0000Dooooo`;o
00003oooool2o`0001kooooo0_l0000<ooooo`;o0000??ooool2o`0001Cooooo0_l000000ooooooo
0000o`00000Eooooo`;o00001_ooool2o`0002kooooo0_l0000?ooooo`;o00007Oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo02oooooo0_l0000Rooooo`?o00002oooool2o`000=Oooooo000[ooooo`03o`00
0?oooooooooo02oooooo0_l0000Rooooo`?o00002oooool2o`000=Oooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`1<ooooo`;o0000k?ooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^1_ooool00ol0003oooooooooo`1<ooooo`;o0000k?ooool001_ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`00
0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`000?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo
??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_o
oooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
0000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4oooo
o`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo
0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;ooooo
ooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0?ooooo`Co000000Co410@oooooooooooooooo1?l000000ol@
413oooooooooo`3ooooooa;ooooo0003ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool0
1_l0003ogMgMooooooooooooV9RHodA4A0?ooooo00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@400<ooooo`05o`000?ooooooooooooooool00000
0_ooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaCooooo
0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@
41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?ooooooooooooooool000005?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo5?ooool000Cooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?oo
ool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?ooooooooooooooool000000_ooool6o`0000co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaCooooo0004ooooo`04ob4Q
8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?oo
ool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVYZOl000005?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo5?ooool000?ooooo0_l00002ooooo`;o0000
1Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o0000
4?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooooaCooooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo
0000omgMg@0dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolDooooo`00
3oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo037ooooo00?oEEEEofIVI_l00000
1Oooool00omEEEGoIVIVo`00003ooooooaKooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32962 Mdot
.03333 .32962 Mdot
.0381 .28842 Mdot
.04286 .30902 Mdot
.04762 .32962 Mdot
.05238 .32962 Mdot
.05714 .32962 Mdot
.0619 .30902 Mdot
.06667 .26781 Mdot
.07143 .28842 Mdot
.07619 .35022 Mdot
.08095 .35022 Mdot
.08571 .37082 Mdot
.09048 .24721 Mdot
.09524 .26781 Mdot
.1 .32962 Mdot
.10476 .30902 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .30902 Mdot
.14286 .30902 Mdot
.14762 .30902 Mdot
.15238 .30902 Mdot
.15714 .35022 Mdot
.1619 .32962 Mdot
.16667 .30902 Mdot
.17143 .32962 Mdot
.17619 .30902 Mdot
.18095 .28842 Mdot
.18571 .30902 Mdot
.19048 .37082 Mdot
.19524 .26781 Mdot
.2 .28842 Mdot
.20476 .30902 Mdot
.20952 .28842 Mdot
.21429 .35022 Mdot
.21905 .30902 Mdot
.22381 .32962 Mdot
.22857 .26781 Mdot
.23333 .28842 Mdot
.2381 .26781 Mdot
.24286 .28842 Mdot
.24762 .24721 Mdot
.25238 .28842 Mdot
.25714 .26781 Mdot
.2619 .28842 Mdot
.26667 .32962 Mdot
.27143 .26781 Mdot
.27619 .22661 Mdot
.28095 .28842 Mdot
.28571 .41202 Mdot
.29048 .32962 Mdot
.29524 .32962 Mdot
.3 .35022 Mdot
.30476 .24721 Mdot
.30952 .37082 Mdot
.31429 .39142 Mdot
.31905 .37082 Mdot
.32381 .32962 Mdot
.32857 .32962 Mdot
.33333 .30902 Mdot
.3381 .26781 Mdot
.34286 .35022 Mdot
.34762 .30902 Mdot
.35238 .30902 Mdot
.35714 .37082 Mdot
.3619 .32962 Mdot
.36667 .35022 Mdot
.37143 .22661 Mdot
.37619 .24721 Mdot
.38095 .35022 Mdot
.38571 .26781 Mdot
.39048 .30902 Mdot
.39524 .32962 Mdot
.4 .28842 Mdot
.40476 .26781 Mdot
.40952 .32962 Mdot
.41429 .26781 Mdot
.41905 .30902 Mdot
.42381 .28842 Mdot
.42857 .24721 Mdot
.43333 .24721 Mdot
.4381 .30902 Mdot
.44286 .30902 Mdot
.44762 .32962 Mdot
.45238 .32962 Mdot
.45714 .35022 Mdot
.4619 .30902 Mdot
.46667 .28842 Mdot
.47143 .26781 Mdot
.47619 .30902 Mdot
.48095 .28842 Mdot
.48571 .30902 Mdot
.49048 .32962 Mdot
.49524 .32962 Mdot
.5 .30902 Mdot
.50476 .30902 Mdot
.50952 .35022 Mdot
.51429 .30902 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .35022 Mdot
.53333 .26781 Mdot
.5381 .26781 Mdot
.54286 .32962 Mdot
.54762 .28842 Mdot
.55238 .30902 Mdot
.55714 .26781 Mdot
.5619 .30902 Mdot
.56667 .28842 Mdot
.57143 .37082 Mdot
.57619 .28842 Mdot
.58095 .22661 Mdot
.58571 .32962 Mdot
.59048 .30902 Mdot
.59524 .35022 Mdot
.6 .26781 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .35022 Mdot
.61905 .26781 Mdot
.62381 .32962 Mdot
.62857 .35022 Mdot
.63333 .26781 Mdot
.6381 .30902 Mdot
.64286 .35022 Mdot
.64762 .32962 Mdot
.65238 .35022 Mdot
.65714 .32962 Mdot
.6619 .24721 Mdot
.66667 .30902 Mdot
.67143 .26781 Mdot
.67619 .28842 Mdot
.68095 .30902 Mdot
.68571 .28842 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .28842 Mdot
.70476 .30902 Mdot
.70952 .26781 Mdot
.71429 .28842 Mdot
.71905 .28842 Mdot
.72381 .26781 Mdot
.72857 .37082 Mdot
.73333 .26781 Mdot
.7381 .32962 Mdot
.74286 .28842 Mdot
.74762 .28842 Mdot
.75238 .32962 Mdot
.75714 .35022 Mdot
.7619 .28842 Mdot
.76667 .32962 Mdot
.77143 .30902 Mdot
.77619 .22661 Mdot
.78095 .32962 Mdot
.78571 .32962 Mdot
.79048 .32962 Mdot
.79524 .28842 Mdot
.8 .32962 Mdot
.80476 .28842 Mdot
.80952 .22661 Mdot
.81429 .28842 Mdot
.81905 .28842 Mdot
.82381 .28842 Mdot
.82857 .35022 Mdot
.83333 .35022 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .32962 Mdot
.85714 .28842 Mdot
.8619 .35022 Mdot
.86667 .28842 Mdot
.87143 .26781 Mdot
.87619 .28842 Mdot
.88095 .32962 Mdot
.88571 .28842 Mdot
.89048 .32962 Mdot
.89524 .24721 Mdot
.9 .26781 Mdot
.90476 .28842 Mdot
.90952 .30902 Mdot
.91429 .37082 Mdot
.91905 .32962 Mdot
.92381 .20601 Mdot
.92857 .35022 Mdot
.93333 .32962 Mdot
.9381 .30902 Mdot
.94286 .35022 Mdot
.94762 .35022 Mdot
.95238 .28842 Mdot
.95714 .28842 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .35022 Mdot
.97619 .32962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo3_ooool2o`0002_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo3_ooool2o`0002_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
000Iooooo`;o0000;oooool2o`0001_ooooo0_l0000mooooo`;o0000>Oooool2o`0000Sooooo0_l0
001>ooooo`00:oooool00ol0003oooooooooo`0Hooooo`;o0000;oooool2o`0001_ooooo0_l0000m
ooooo`;o0000>Oooool2o`0000Sooooo0_l0001>ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo017ooooo0_l0000]ooooo`;o00004?ooool2o`0001?ooooo0_l0000>ooooo`?o0000A?ooool2
o`0004Cooooo0_l0000dooooo`00:oooool2o`0001;ooooo0_l0000]ooooo`;o00004?ooool2o`00
01?ooooo0_l0000>ooooo`?o0000A?ooool2o`0004Cooooo0_l0000dooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000;ooooo`;o00001_ooool2o`0001co
oooo0_l00008ooooo`;o000000Coooooo`000?l0003oA4A40_l000001Olb<S;o0000o`000?oooooo
k^k^00;o000000?o<S8bonk^k_ooool04?ooool2o`0000cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000003_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`?o
000000?o<S8bonk^k_l000000_l00004ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o
00002Oooool2o`0000Wooooo1?l000001?l@413o0000o`000?ooool3o`000009oc8b<_oMgMgooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo0_l00005ooooo`;o00001oooool2o`0000[ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo000[ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00007?ooool2o`0000So
oooo0_l000000ooooooo0000o`000003ooooo`05ogMgMol0003o0000oooooomgMgL00_l000000onH
V9SoMgMgooooo`0@ooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000?oooo
o`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`03
o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00002_ooool2
o`0000;ooooo0_l000001_oooooo0000o`000?ooooooMgMgoc8b<P;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Gooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool0
0ol0003oooooooooo`12ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000=_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000
ooooooooool0?oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00000jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00
:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo
0_l00002ooooo`;o00002?ooool2o`0001oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1Oooool2o`000004ooooool0003o0000ooooo`;o000000Koooooo`000?l0003oV9RHoooooonHV9P2
o`0002;ooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003ooooo00;o000000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9So0000o`000?mgMgL01?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo1?l00002ooooo`03o`000?oooooooooo00?o000000?oooooogMgMonHV9P00_l000000omgMgOo
ooooooooo`05ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00001?ooool4o`00
0004ooooool0003o0000ooooo`;o00001?ooool2o`0000Wooooo00?o0000okZj^_ooool01Ol00000
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:ooo
ool01?l0003oooooooooooooool2o`0000Sooooo0_l0000Oooooo`;o00001?ooool2o`000003oooo
ool0003o000000Gooooo0_l000000ooooooo0000o`000003o`000006ooooool0003o0000oc8b<_l0
003o<S8b0_l0000Rooooo`;o00001_ooool2o`0000[ooooo0_l000000omVIVKo0000ooooo`02o`00
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?l0003ok^k^00Cooooo
0_l00004ooooo`;o000000?oooooo`000?l000007?ooool2o`000003ooooool0003o000000;ooooo
0_l000000omEEEGoIVIVo`000003o`0000;ooooo1_l000000oooooook^k^oc8b<P02o`000003onk^
k_oooooooooo00Gooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00004ooooo`Co
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002Oooool00onHV9So410@o`000005o`00
0005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@4?l0003o000000?o
oooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Co
oooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`00
0?oooooooooo00;ooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o0000
0_ooool<o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`?o
00002oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go
00002?ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00004ooooo`?o00000_ooool01?l0
003oooooo`000?l00002ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o
000000Wooooo0_l000000ooooooo0000o`000007ooooo`?o000000?oooooo`000?l000000_l00006
ooooo`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Wooooo00?o0000
ooooooooool01oooool2o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`04o`000?oooooo0000o`0000Oooooo0_l0
00000ooooooo0000ooooo`0Booooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool0
0ol0003oooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool0
0ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooo
ooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`Co00000oooool5o`0000_o
oooo0_l0000@ooooo`;o000000?oooooo`000?l000003_ooool2o`0000_ooooo0_l00005ooooo`Co
00001_ooool4o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo0ol0000:ooooo`?o
00003Oooool2o`0000[ooooo0_l0000:ooooo`;o00001Oooool2o`000003ooooool0003o000001Oo
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000;ooooo`;o
000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o
00002oooool2o`00017ooooo0_l00008ooooo`00:oooool4o`0000?ooooo1Ol0000;ooooo`;o0000
4?ooool2o`000003ooooool0003o000000kooooo0_l0000;ooooo`;o00001Oooool4o`0000Kooooo
1?l00008ooooo`;o00002?ooool2o`0000;ooooo0_l0000:ooooo`?o00002_ooool3o`0000gooooo
0_l0000:ooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Gooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000002oooool2o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000_ooooo
0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00cooooo1?l00006ooooo`;o0000
3Oooool2o`0000oooooo0_l0000Hooooo`;o00002oooool2o`0000Gooooo0_l00003ooooo`;o0000
5Oooool2o`0000gooooo0_l00004ooooo`;o00004_ooool2o`0000Cooooo0_l00002ooooo`;o0000
0oooool2o`000003ooooool0003o000001gooooo0_l0000Dooooo`?o00001oooool2o`0001;ooooo
0_l00002ooooo`Co00001Oooool2o`0001gooooo000[ooooo`;o00003Oooool4o`0000Kooooo0_l0
000=ooooo`;o00003oooool2o`0001Sooooo0_l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l0
000Eooooo`;o00003Oooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000007Oooool2o`0001Cooooo0ol00007ooooo`;o00004_oo
ool2o`0000;ooooo1?l00005ooooo`;o00007Oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o00004?ooool2o`0001kooooo0_l0000Rooooo`;o000000?ooooo
o`000?l000002Oooool2o`0003oooooo0_l0000^ooooo`;o0000=_ooool2o`0002kooooo000[oooo
o`03o`000?oooooooooo00oooooo0_l0000Nooooo`;o00008_ooool2o`000003ooooool0003o0000
00Wooooo0_l0000oooooo`;o0000;_ooool2o`0003Kooooo0_l0000^ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000EOooool2o`000>Cooooo000[ooooo`03o`000?oooooooooo05Cooooo0_l0003Tooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0001<ooooo`;o0000k?ooool001_ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0C?ooool2o`000>cooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`00
6oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo
000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCooooo
000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oo
ooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q
8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?o
V9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o00000_oo
ool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00oooooo1?l000000ol@413oooooooooo`05o`000?oooooo5Oooool000?ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool0
2_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@
00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`02
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolEooooo`001?ooool01?oMgMgo0000oa0@4?o<
c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413o
c<c<4_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool00oooool00onH
V9So8B4Qonk^kP3ooooooaKooooo0004ooooo`04onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@
4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_oo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
00?oV9RHob4Q8Oo^k^h0oooooolEooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEE
EOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_oo
ool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?o0000ooooooooool01Oooool00omgMgOoIVIV
ooooo`3ooooooaCooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_oo
ool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolCooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0=?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooolEooooo`003oooool00onj^[[oA4A4
ooooo`02ooooo`03ojVYZOoooooooooo037ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@
o`000?lQ8B7oc<c<0?oooooo5Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33992 Mdot
.03333 .33992 Mdot
.0381 .27812 Mdot
.04286 .31932 Mdot
.04762 .31932 Mdot
.05238 .31932 Mdot
.05714 .31932 Mdot
.0619 .29872 Mdot
.06667 .25751 Mdot
.07143 .29872 Mdot
.07619 .36052 Mdot
.08095 .36052 Mdot
.08571 .38112 Mdot
.09048 .25751 Mdot
.09524 .27812 Mdot
.1 .33992 Mdot
.10476 .31932 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .29872 Mdot
.12381 .29872 Mdot
.12857 .29872 Mdot
.13333 .29872 Mdot
.1381 .29872 Mdot
.14286 .29872 Mdot
.14762 .31932 Mdot
.15238 .29872 Mdot
.15714 .36052 Mdot
.1619 .33992 Mdot
.16667 .29872 Mdot
.17143 .31932 Mdot
.17619 .31932 Mdot
.18095 .27812 Mdot
.18571 .29872 Mdot
.19048 .38112 Mdot
.19524 .27812 Mdot
.2 .27812 Mdot
.20476 .31932 Mdot
.20952 .27812 Mdot
.21429 .36052 Mdot
.21905 .31932 Mdot
.22381 .31932 Mdot
.22857 .25751 Mdot
.23333 .27812 Mdot
.2381 .27812 Mdot
.24286 .27812 Mdot
.24762 .23691 Mdot
.25238 .27812 Mdot
.25714 .27812 Mdot
.2619 .29872 Mdot
.26667 .31932 Mdot
.27143 .27812 Mdot
.27619 .21631 Mdot
.28095 .27812 Mdot
.28571 .40172 Mdot
.29048 .33992 Mdot
.29524 .33992 Mdot
.3 .36052 Mdot
.30476 .23691 Mdot
.30952 .36052 Mdot
.31429 .38112 Mdot
.31905 .38112 Mdot
.32381 .33992 Mdot
.32857 .31932 Mdot
.33333 .29872 Mdot
.3381 .27812 Mdot
.34286 .33992 Mdot
.34762 .31932 Mdot
.35238 .29872 Mdot
.35714 .38112 Mdot
.3619 .33992 Mdot
.36667 .33992 Mdot
.37143 .23691 Mdot
.37619 .25751 Mdot
.38095 .33992 Mdot
.38571 .27812 Mdot
.39048 .29872 Mdot
.39524 .31932 Mdot
.4 .29872 Mdot
.40476 .25751 Mdot
.40952 .33992 Mdot
.41429 .25751 Mdot
.41905 .29872 Mdot
.42381 .27812 Mdot
.42857 .23691 Mdot
.43333 .25751 Mdot
.4381 .29872 Mdot
.44286 .31932 Mdot
.44762 .31932 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .29872 Mdot
.46667 .27812 Mdot
.47143 .27812 Mdot
.47619 .29872 Mdot
.48095 .29872 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .33992 Mdot
.5 .29872 Mdot
.50476 .31932 Mdot
.50952 .33992 Mdot
.51429 .29872 Mdot
.51905 .27812 Mdot
.52381 .27812 Mdot
.52857 .33992 Mdot
.53333 .25751 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .29872 Mdot
.55238 .31932 Mdot
.55714 .27812 Mdot
.5619 .29872 Mdot
.56667 .27812 Mdot
.57143 .36052 Mdot
.57619 .29872 Mdot
.58095 .23691 Mdot
.58571 .33992 Mdot
.59048 .31932 Mdot
.59524 .36052 Mdot
.6 .25751 Mdot
.60476 .29872 Mdot
.60952 .29872 Mdot
.61429 .36052 Mdot
.61905 .27812 Mdot
.62381 .31932 Mdot
.62857 .36052 Mdot
.63333 .25751 Mdot
.6381 .29872 Mdot
.64286 .36052 Mdot
.64762 .33992 Mdot
.65238 .36052 Mdot
.65714 .31932 Mdot
.6619 .23691 Mdot
.66667 .29872 Mdot
.67143 .25751 Mdot
.67619 .27812 Mdot
.68095 .29872 Mdot
.68571 .29872 Mdot
.69048 .29872 Mdot
.69524 .29872 Mdot
.7 .29872 Mdot
.70476 .31932 Mdot
.70952 .27812 Mdot
.71429 .27812 Mdot
.71905 .27812 Mdot
.72381 .25751 Mdot
.72857 .36052 Mdot
.73333 .25751 Mdot
.7381 .33992 Mdot
.74286 .27812 Mdot
.74762 .29872 Mdot
.75238 .31932 Mdot
.75714 .36052 Mdot
.7619 .29872 Mdot
.76667 .31932 Mdot
.77143 .29872 Mdot
.77619 .21631 Mdot
.78095 .33992 Mdot
.78571 .31932 Mdot
.79048 .33992 Mdot
.79524 .29872 Mdot
.8 .33992 Mdot
.80476 .27812 Mdot
.80952 .21631 Mdot
.81429 .29872 Mdot
.81905 .27812 Mdot
.82381 .27812 Mdot
.82857 .36052 Mdot
.83333 .33992 Mdot
.8381 .29872 Mdot
.84286 .33992 Mdot
.84762 .27812 Mdot
.85238 .33992 Mdot
.85714 .27812 Mdot
.8619 .36052 Mdot
.86667 .29872 Mdot
.87143 .25751 Mdot
.87619 .29872 Mdot
.88095 .31932 Mdot
.88571 .29872 Mdot
.89048 .33992 Mdot
.89524 .23691 Mdot
.9 .25751 Mdot
.90476 .29872 Mdot
.90952 .29872 Mdot
.91429 .38112 Mdot
.91905 .31932 Mdot
.92381 .19571 Mdot
.92857 .33992 Mdot
.93333 .31932 Mdot
.9381 .31932 Mdot
.94286 .36052 Mdot
.94762 .36052 Mdot
.95238 .29872 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .31932 Mdot
.97143 .33992 Mdot
.97619 .33992 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3oooooo`kooooo0_l0000[
ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo0?oooooo3_ooool2o`0002_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
BOooool2o`0009Gooooo0_l00008ooooo`;o0000C_ooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0BOooool2o`0009Gooooo
0_l00008ooooo`;o0000C_ooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo01Sooooo0_l0000Vooooo`;o00004?ooool2o`0001;o
oooo0_l0000?ooooo`;o0000;?ooool2o`0001Oooooo0_l00014ooooo`;o0000=?ooool002_ooooo
00?o0000ooooooooool06?ooool2o`0002Kooooo0_l0000@ooooo`;o00004_ooool2o`0000oooooo
0_l0000/ooooo`;o00005oooool2o`0004Cooooo0_l0000dooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
2_ooool2o`0000Gooooo0_l0000Wooooo`;o0000:oooool2o`0000Oooooo0_l000000ooooooo0000
o`000003ooooo`;o00007Oooool2o`0001;ooooo0_l00008ooooo`;o00002Oooool2o`0000kooooo
0_l000000ooooooo0000o`00000Xooooo`;o00001oooool2o`0003;ooooo000[ooooo`03o`000?oo
oooooooo00[ooooo0_l00005ooooo`;o00009oooool2o`0002_ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000oooool2o`0001gooooo0_l0000Booooo`;o00002?ooool2o`0000Wooooo0_l0
000>ooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Oooooo0_l0000booooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l00010ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^03Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03Cooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8b
omgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0<oooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000oooo
ooooool0@_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0=_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo
04?ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
=_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool0<_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@01?ooooo000[ooooo`04o`000?ooooooooooooooo`;o00003oooool2
o`0001Sooooo0_l00002ooooo`Co000000?oooooo`000?l000001Oooool5o`000005ooooool0003o
0000o`000?ooool00ol000000ooooooo0000o`00000@ooooo`;o00003?ooool2o`0000[ooooo0_l0
000:ooooo`Co00001?ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000oooooo0_l00008ooooo`Go0000
1Oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00000_ooool3o`0000Ko
oooo0_l000000ooooooo0000o`00000Iooooo`03oiRHV?lQ8B7ok^k^00Co00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool002_ooooo00Co0000oooooooo
oooooooo0_l0000?ooooo`;o00006?ooool2o`0000;ooooo1?l000000ooooooo0000o`000005oooo
o`Wo000000Goooooo`000?l0003o0000ooooo`02o`00013ooooo0_l0000<ooooo`;o00002_ooool2
o`0000[ooooo1?l00004ooooo`05o`000?ooooooooooooooool000000oooool5o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o00003oooool2o`0000Sooooo1Ol0
0002ooooo`03o`000?lQ8B7o000000;o00000_ooool01Ol0003ooooooooooooooooo000000[ooooo
0_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000001[ooooo00?oMgMgofIVI_l00000
0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00
:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo
0_l00010ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003o
ooooooooo`0oooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0dooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
<oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000003?ooool<o`0000?o
oooo0_l00004ooooo`;o00005Oooool2o`0001?ooooo0_l00004ooooo`;o00002Oooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo1?l00004ooooo`;o
00000_ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo1?l00006ooooo`;o
00001oooool2o`0000;ooooo2?l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
00Cooooo0ol0000;ooooo`;o00008oooool002_ooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003o000000cooooo3?l00003ooooo`;o00001?ooool2o`0001Gooooo0_l0000Cooooo`;o
00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Go
oooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000?o
oooo0_l00006ooooo`Co00001_ooool2o`0000Oooooo0_l00002ooooo`So00003?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`?o00002oooool2o`0001Wooooo0_l00002oooo
o`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003o
ooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<
c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003ooooo
ooooo`02ooooo`Oo00003?ooool2o`0000_ooooo0_l00005ooooo`Co00001_ooool2o`0000?ooooo
0ol0000;ooooo`;o00004Oooool2o`0000?ooooo0_l0000=ooooo`;o00003?ooool5o`0000Sooooo
1?l00002ooooo`;o00003?ooool2o`0000[ooooo0_l00008ooooo`;o00002?ooool2o`0000cooooo
0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l0000Kooooo`;o00002Oooool2o`0000?ooooo
0ol00007ooooo`;o00005Oooool01Ol0003oooooodA4A?l0003o410@00Cooooo000[ooooo`03o`00
0?oooooooooo00;ooooo1ol0000<ooooo`;o00002oooool2o`0000Gooooo1?l00006ooooo`;o0000
0oooool3o`0000_ooooo0_l0000Aooooo`;o00000oooool2o`0000gooooo0_l0000<ooooo`Go0000
2?ooool4o`0000;ooooo0_l0000<ooooo`;o00002_ooool2o`0000Sooooo0_l00008ooooo`;o0000
3?ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0001_ooooo0_l00009ooooo`;o0000
0oooool3o`0000Oooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oo
oooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3o
oooooc7ooooo0_l00008ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool4o`0001?ooooo1?l0000>ooooo`;o00009Oooool4o`0000Kooooo
0_l00004ooooo`;o00001?ooool3o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000Wooooo
0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00004Oooool2o`0001[ooooo
0_l0000;ooooo`Co000000?oooooo`000?l000002?ooool2o`000004ooooool0003o0000ooooo`;o
00002_ooool2o`0000Wooooo0_l0000;ooooo`Co00006oooool002_ooooo1?l0000Cooooo`Co0000
3_ooool2o`0002Gooooo1?l00006ooooo`;o00001?ooool2o`0000Cooooo0ol00003ooooo`;o0000
1_ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o0000
2_ooool2o`00017ooooo0_l0000Jooooo`;o00002oooool4o`000003ooooool0003o000000Sooooo
0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00009ooooo`;o00002oooool4o`0001_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00cooooo
1?l0000Eooooo`;o00003oooool2o`0001Sooooo0_l000000ooooooo0000o`00001=ooooo`;o0000
1Oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo
0_l00006ooooo`;o00005?ooool2o`0000Sooooo0_l0000Fooooo`Co00009?ooool002_ooooo00?o
0000ooooooooool03?ooool4o`0001Gooooo0_l0000?ooooo`;o00006?ooool2o`000003ooooool0
003o000004gooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000005Oooool2o`0000Kooooo0_l0000Dooooo`;o00002?ooool2o`0001Kooooo1?l0
000Tooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool03oooool2o`0001kooooo0_l0000Sooooo`Co00002Ooo
ool2o`000:Oooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`0?ooooo`;o00007_ooool2
o`0002?ooooo1?l00009ooooo`;o0000Yoooool2o`0002kooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1<
ooooo`;o0000k?ooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
1_ooool00ol0003oooooooooo`1<ooooo`;o0000k?ooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo
>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo
>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0
01Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`000?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3o
oooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooocco
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3o
oooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000K
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooo
oolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooo
oom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooo
oom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?oo
ool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003
ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0?ooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<
c?oooooo5Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgo
oooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S80oooooolEooooo`00
1?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@
00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooa?ooooo0004ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo
00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<oooo
o`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool0oooooolDooooo`001?ooool01?lQ8B7o
MgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo
00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?o0000oooo
ooooool01?ooool00ol@413o0000okZj^P3ooooooaGooooo0003ooooo`;o00000_ooool2o`0000Go
oooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013o
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o^[Zjob4Q8Oooool0oooooolDooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`00
0?oMgMd0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9SooooookZj^_l00000oooooolE
ooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo037ooooo00?oEEEEofIV
I_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo5Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32962 Mdot
.03333 .32962 Mdot
.0381 .28842 Mdot
.04286 .32962 Mdot
.04762 .30902 Mdot
.05238 .32962 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .26781 Mdot
.07143 .28842 Mdot
.07619 .37082 Mdot
.08095 .35022 Mdot
.08571 .37082 Mdot
.09048 .26781 Mdot
.09524 .26781 Mdot
.1 .35022 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .28842 Mdot
.13333 .30902 Mdot
.1381 .28842 Mdot
.14286 .28842 Mdot
.14762 .30902 Mdot
.15238 .30902 Mdot
.15714 .35022 Mdot
.1619 .35022 Mdot
.16667 .30902 Mdot
.17143 .30902 Mdot
.17619 .30902 Mdot
.18095 .28842 Mdot
.18571 .28842 Mdot
.19048 .37082 Mdot
.19524 .28842 Mdot
.2 .28842 Mdot
.20476 .30902 Mdot
.20952 .26781 Mdot
.21429 .37082 Mdot
.21905 .32962 Mdot
.22381 .30902 Mdot
.22857 .26781 Mdot
.23333 .26781 Mdot
.2381 .26781 Mdot
.24286 .26781 Mdot
.24762 .22661 Mdot
.25238 .26781 Mdot
.25714 .26781 Mdot
.2619 .30902 Mdot
.26667 .30902 Mdot
.27143 .26781 Mdot
.27619 .20601 Mdot
.28095 .26781 Mdot
.28571 .39142 Mdot
.29048 .35022 Mdot
.29524 .32962 Mdot
.3 .35022 Mdot
.30476 .24721 Mdot
.30952 .35022 Mdot
.31429 .39142 Mdot
.31905 .39142 Mdot
.32381 .35022 Mdot
.32857 .30902 Mdot
.33333 .30902 Mdot
.3381 .28842 Mdot
.34286 .32962 Mdot
.34762 .32962 Mdot
.35238 .30902 Mdot
.35714 .39142 Mdot
.3619 .32962 Mdot
.36667 .35022 Mdot
.37143 .22661 Mdot
.37619 .24721 Mdot
.38095 .35022 Mdot
.38571 .26781 Mdot
.39048 .28842 Mdot
.39524 .30902 Mdot
.4 .28842 Mdot
.40476 .26781 Mdot
.40952 .35022 Mdot
.41429 .26781 Mdot
.41905 .30902 Mdot
.42381 .28842 Mdot
.42857 .24721 Mdot
.43333 .24721 Mdot
.4381 .28842 Mdot
.44286 .32962 Mdot
.44762 .30902 Mdot
.45238 .32962 Mdot
.45714 .35022 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .28842 Mdot
.47619 .28842 Mdot
.48095 .30902 Mdot
.48571 .32962 Mdot
.49048 .30902 Mdot
.49524 .35022 Mdot
.5 .30902 Mdot
.50476 .30902 Mdot
.50952 .35022 Mdot
.51429 .30902 Mdot
.51905 .28842 Mdot
.52381 .28842 Mdot
.52857 .35022 Mdot
.53333 .26781 Mdot
.5381 .26781 Mdot
.54286 .32962 Mdot
.54762 .28842 Mdot
.55238 .30902 Mdot
.55714 .26781 Mdot
.5619 .28842 Mdot
.56667 .26781 Mdot
.57143 .35022 Mdot
.57619 .28842 Mdot
.58095 .22661 Mdot
.58571 .32962 Mdot
.59048 .30902 Mdot
.59524 .37082 Mdot
.6 .24721 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .37082 Mdot
.61905 .26781 Mdot
.62381 .30902 Mdot
.62857 .37082 Mdot
.63333 .26781 Mdot
.6381 .30902 Mdot
.64286 .35022 Mdot
.64762 .35022 Mdot
.65238 .37082 Mdot
.65714 .30902 Mdot
.6619 .24721 Mdot
.66667 .28842 Mdot
.67143 .26781 Mdot
.67619 .26781 Mdot
.68095 .28842 Mdot
.68571 .28842 Mdot
.69048 .28842 Mdot
.69524 .28842 Mdot
.7 .28842 Mdot
.70476 .32962 Mdot
.70952 .28842 Mdot
.71429 .26781 Mdot
.71905 .28842 Mdot
.72381 .26781 Mdot
.72857 .35022 Mdot
.73333 .24721 Mdot
.7381 .32962 Mdot
.74286 .26781 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .35022 Mdot
.7619 .30902 Mdot
.76667 .32962 Mdot
.77143 .28842 Mdot
.77619 .20601 Mdot
.78095 .35022 Mdot
.78571 .32962 Mdot
.79048 .32962 Mdot
.79524 .28842 Mdot
.8 .35022 Mdot
.80476 .28842 Mdot
.80952 .20601 Mdot
.81429 .28842 Mdot
.81905 .26781 Mdot
.82381 .28842 Mdot
.82857 .37082 Mdot
.83333 .32962 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .28842 Mdot
.85238 .35022 Mdot
.85714 .28842 Mdot
.8619 .35022 Mdot
.86667 .28842 Mdot
.87143 .26781 Mdot
.87619 .28842 Mdot
.88095 .32962 Mdot
.88571 .30902 Mdot
.89048 .32962 Mdot
.89524 .24721 Mdot
.9 .24721 Mdot
.90476 .28842 Mdot
.90952 .28842 Mdot
.91429 .39142 Mdot
.91905 .30902 Mdot
.92381 .18541 Mdot
.92857 .35022 Mdot
.93333 .32962 Mdot
.9381 .30902 Mdot
.94286 .35022 Mdot
.94762 .35022 Mdot
.95238 .30902 Mdot
.95714 .26781 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .35022 Mdot
.97619 .32962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003oooooo`oooooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`3oooooo`kooooo
0_l0000[ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
BOooool2o`0009Gooooo0_l00008ooooo`;o0000C_ooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0BOooool2o`0009Gooooo
0_l00008ooooo`;o0000C_ooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0001Wooooo0_l0
000Vooooo`;o00009?ooool2o`0003gooooo0_l0002Cooooo`00:oooool00ol0003oooooooooo`0H
ooooo`;o00009_ooool2o`0002Cooooo0_l0000mooooo`;o0000Toooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`1Booooo`;o00004oooool2o`0000kooooo0ol0000aooooo`;o00004Oooool2
o`0001?ooooo0_l0000_ooooo`Co0000<_ooool002_ooooo0_l0001Cooooo`;o00004oooool2o`00
00kooooo0ol0000aooooo`;o00004Oooool2o`0001?ooooo0_l0000_ooooo`Co0000<_ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o00002oooool2o`0000Go
oooo0ol0000Qooooo`;o00000oooool;o`000005ooooooo^k^ko0000o`000?lb<S800_l0000Noooo
o`;o00001?ooool2o`000003ooooool0003o000000kooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o00001?ooool2o`000003
ooooool0003o000000kooooo0_l00002ooooo`;o00002Oooool4o`0000Oooooo1?l000001Ol@413o
0000o`000?ooooooA4A400Co00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0000>
ooooo`;o00004oooool7o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`?o0000
8Oooool2o`0000?ooooo1ol000001_oooooo0000o`000?l0003oooooogMgM`;o000000?oV9RHo`00
0?l000007_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ol0
0004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l00009ooooo`Co00002Ooo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool2o`0000kooooo0_l0000Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_l000001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool0
0ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103oooo
o`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool00ol0003oooooooooo`12
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000=_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0
003oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000ooooooooool0?oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool00000=_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000003Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00:oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@
oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00002ooooo`;o0000
2?ooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000Wooooo2?l0000;ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`;o00003Oooool2o`000003
ooooool0003o000000Kooooo0_l00002ooooo`;o00001Oooool6o`0000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`Co000000?oMgMgooooooooool00_ooool2o`0000;ooooo0_l00003oooo
o`;o00006Oooool2o`0000;ooooo2?l000001?oooooo0000o`000?ooool2o`0000;ooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00001Oooool2o`000004ooooool0
003o0000ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l0
00001oooool3o`0000Sooooo00Ko0000okZj^_ooooooV9RHoa0@4?ooool2o`000005ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`04o`000?oo
ooooooooooooo`;o00002?ooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000Wooooo
2?l0000;ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00005ooooo`Ko00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo1?l000000oo^k^koooooooooo`02ooooo`;o00000_ooool2o`00
00?ooooo0_l0000Iooooo`;o00000_ooool8o`000004oeEEEOl0003o0000ooooo`;o00000_ooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool4o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000Oo
oooo0ol00008ooooo`06oiRHV?l@413o0000ob4Q8Oo<c<cooooo0_l000001Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolaooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?ooooooo`00033o
00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003oooooooooo`04ooooo`;o
000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`0:ooooo`Co000000?oooooo`00
0?l000000_ooool3o`0000?ooooo1Ol00006ooooo`;o00000_ooool01?l0003oooooo`000?l0000:
ooooo`?o00003?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool3o`0000[ooooo0_l00000
0ooooooo0000ooooo`02ooooo`;o00001oooool3o`0000Oooooo0_l000001?oooooo0000o`000?oo
ool3o`000003ooooool0003o000000Wooooo0_l0000:ooooo`?o000000?oooooo`000?l000000_l0
0002ooooo`;o00000_ooool3o`0000?ooooo0_l00009ooooo`03o`000?oooooooooo00_ooooo00Co
0000ooooool0003o00000oooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`?o00002?ooool2o`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000?o
oooo0_l000000ooooooo0000ooooo`0Booooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00
:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00
:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o
0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`Co000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`;o00008Oooool2o`0001Gooooo0_l0000<ooooo`?o00000ooo
ool2o`0001Kooooo0_l000000ooooooo0000o`000008ooooo`;o00004?ooool2o`0000[ooooo0_l0
000Rooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000_ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l0
000Aooooo`;o00002?ooool002_ooooo1?l000001?oooooo0000o`000?ooool2o`0000kooooo0_l0
000Qooooo`;o00005Oooool2o`0000cooooo0ol00003ooooo`;o00005_ooool2o`000003ooooool0
003o000000Sooooo0_l0000@ooooo`;o00002_ooool2o`0002;ooooo0_l00009ooooo`;o00000_oo
ool2o`0000;ooooo0_l00004ooooo`?o00002oooool2o`000003ooooool0003o000000[ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00002oooool2o`0001_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool03_ooool2o`0000Cooooo1?l0000=ooooo`?o00009Oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0000gooooo
0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00005?ooool3o`0001Oooooo
0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
4_ooool2o`0000;ooooo1?l00005ooooo`;o00007Oooool002_ooooo0_l0000?ooooo`;o00001?oo
ool4o`0000gooooo0ol0000Uooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
2oooool2o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o0000
1?ooool2o`0000_ooooo0_l0000Dooooo`?o00005oooool2o`0000Kooooo0_l00006ooooo`;o0000
0oooool2o`0000kooooo0_l000000ooooooo0000o`00000Booooo`;o00000_ooool4o`0000Gooooo
0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
000=ooooo`;o000000?oooooo`000?l000007_ooool2o`0000Gooooo0_l0001aooooo`;o00001?oo
ool2o`0000;ooooo0_l00006ooooo`;o0000<oooool2o`0004Sooooo000[ooooo`03o`000?oooooo
oooo00cooooo0_l000000ooooooo0000o`00000Nooooo`;o00001Oooool2o`00077ooooo0_l00004
ooooo`;o00000_ooool2o`0000Kooooo0_l0000cooooo`;o0000B?ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`0004gooooo0_l00006ooooo`Co00002Oooool2o`000:Oooooo0_l0000^ooooo`00:oooool00ol0
003oooooooooo`1<ooooo`;o00001_ooool4o`0000Wooooo0_l0002Wooooo`;o0000;_ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooo
ooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001So
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?o
oooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool0
0_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo
00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oo
oooo1?l000000ol@413oooooooooo`02ooooo`;o000000?o410@ooooooooool0oooooolCooooo`00
0oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4
A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<
o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolDooooo`001?ooool01?oMgMgo0000oa0@4?o<
c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413o
c<c<4_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool00_ooool5o`00
0?oooooo5Oooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02oooo
o`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?oo
ooooooooooooool000000_ooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgM
ooooool0003ooooooaKooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?oo
ooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`00
0?n7QhOoooooojVYZOl000005?ooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`00
0?oooooo5_ooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03
ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01;ooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`00003ooooooaKo
oooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0dooooo`03o`000?oooooooooo
00?ooooo00?ok^k^odA4A?l00000oooooolFooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03
ojVYZOoooooooooo037ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`3ooooooaGo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31932 Mdot
.03333 .31932 Mdot
.0381 .29872 Mdot
.04286 .33992 Mdot
.04762 .29872 Mdot
.05238 .31932 Mdot
.05714 .31932 Mdot
.0619 .29872 Mdot
.06667 .27812 Mdot
.07143 .29872 Mdot
.07619 .36052 Mdot
.08095 .36052 Mdot
.08571 .38112 Mdot
.09048 .25751 Mdot
.09524 .25751 Mdot
.1 .33992 Mdot
.10476 .31932 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .31932 Mdot
.12381 .29872 Mdot
.12857 .29872 Mdot
.13333 .31932 Mdot
.1381 .29872 Mdot
.14286 .27812 Mdot
.14762 .29872 Mdot
.15238 .31932 Mdot
.15714 .33992 Mdot
.1619 .33992 Mdot
.16667 .31932 Mdot
.17143 .31932 Mdot
.17619 .29872 Mdot
.18095 .29872 Mdot
.18571 .29872 Mdot
.19048 .36052 Mdot
.19524 .29872 Mdot
.2 .29872 Mdot
.20476 .29872 Mdot
.20952 .27812 Mdot
.21429 .38112 Mdot
.21905 .33992 Mdot
.22381 .31932 Mdot
.22857 .27812 Mdot
.23333 .27812 Mdot
.2381 .25751 Mdot
.24286 .25751 Mdot
.24762 .23691 Mdot
.25238 .27812 Mdot
.25714 .27812 Mdot
.2619 .31932 Mdot
.26667 .29872 Mdot
.27143 .27812 Mdot
.27619 .21631 Mdot
.28095 .25751 Mdot
.28571 .40172 Mdot
.29048 .33992 Mdot
.29524 .31932 Mdot
.3 .36052 Mdot
.30476 .23691 Mdot
.30952 .33992 Mdot
.31429 .40172 Mdot
.31905 .38112 Mdot
.32381 .33992 Mdot
.32857 .31932 Mdot
.33333 .29872 Mdot
.3381 .27812 Mdot
.34286 .31932 Mdot
.34762 .33992 Mdot
.35238 .29872 Mdot
.35714 .40172 Mdot
.3619 .31932 Mdot
.36667 .36052 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .33992 Mdot
.38571 .25751 Mdot
.39048 .27812 Mdot
.39524 .29872 Mdot
.4 .27812 Mdot
.40476 .27812 Mdot
.40952 .36052 Mdot
.41429 .27812 Mdot
.41905 .31932 Mdot
.42381 .27812 Mdot
.42857 .23691 Mdot
.43333 .23691 Mdot
.4381 .27812 Mdot
.44286 .31932 Mdot
.44762 .31932 Mdot
.45238 .33992 Mdot
.45714 .33992 Mdot
.4619 .27812 Mdot
.46667 .27812 Mdot
.47143 .29872 Mdot
.47619 .27812 Mdot
.48095 .31932 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .33992 Mdot
.5 .31932 Mdot
.50476 .31932 Mdot
.50952 .36052 Mdot
.51429 .31932 Mdot
.51905 .29872 Mdot
.52381 .29872 Mdot
.52857 .36052 Mdot
.53333 .25751 Mdot
.5381 .25751 Mdot
.54286 .33992 Mdot
.54762 .27812 Mdot
.55238 .31932 Mdot
.55714 .25751 Mdot
.5619 .29872 Mdot
.56667 .25751 Mdot
.57143 .36052 Mdot
.57619 .29872 Mdot
.58095 .21631 Mdot
.58571 .31932 Mdot
.59048 .31932 Mdot
.59524 .36052 Mdot
.6 .23691 Mdot
.60476 .29872 Mdot
.60952 .29872 Mdot
.61429 .36052 Mdot
.61905 .27812 Mdot
.62381 .31932 Mdot
.62857 .38112 Mdot
.63333 .27812 Mdot
.6381 .29872 Mdot
.64286 .33992 Mdot
.64762 .36052 Mdot
.65238 .36052 Mdot
.65714 .29872 Mdot
.6619 .23691 Mdot
.66667 .27812 Mdot
.67143 .27812 Mdot
.67619 .27812 Mdot
.68095 .27812 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .27812 Mdot
.7 .29872 Mdot
.70476 .31932 Mdot
.70952 .29872 Mdot
.71429 .25751 Mdot
.71905 .29872 Mdot
.72381 .25751 Mdot
.72857 .33992 Mdot
.73333 .23691 Mdot
.7381 .31932 Mdot
.74286 .25751 Mdot
.74762 .31932 Mdot
.75238 .31932 Mdot
.75714 .33992 Mdot
.7619 .31932 Mdot
.76667 .33992 Mdot
.77143 .27812 Mdot
.77619 .19571 Mdot
.78095 .36052 Mdot
.78571 .31932 Mdot
.79048 .33992 Mdot
.79524 .27812 Mdot
.8 .33992 Mdot
.80476 .27812 Mdot
.80952 .19571 Mdot
.81429 .27812 Mdot
.81905 .25751 Mdot
.82381 .27812 Mdot
.82857 .38112 Mdot
.83333 .31932 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .29872 Mdot
.85238 .33992 Mdot
.85714 .27812 Mdot
.8619 .36052 Mdot
.86667 .29872 Mdot
.87143 .27812 Mdot
.87619 .29872 Mdot
.88095 .33992 Mdot
.88571 .31932 Mdot
.89048 .33992 Mdot
.89524 .25751 Mdot
.9 .23691 Mdot
.90476 .29872 Mdot
.90952 .29872 Mdot
.91429 .40172 Mdot
.91905 .29872 Mdot
.92381 .19571 Mdot
.92857 .33992 Mdot
.93333 .31932 Mdot
.9381 .29872 Mdot
.94286 .36052 Mdot
.94762 .33992 Mdot
.95238 .31932 Mdot
.95714 .25751 Mdot
.9619 .27812 Mdot
.96667 .31932 Mdot
.97143 .36052 Mdot
.97619 .31932 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3Pooooo`;o00002?ooool2
o`00027ooooo0_l0000[ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo0>3ooooo0_l00008ooooo`;o00008Oooool2o`0002_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool0013ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o0000oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0BOooool2o`0005[ooooo0_l0002Cooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`19ooooo`;o0000F_ooool2o`0009?ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Hooooo`;o00009_ooool2o`00013o
oooo0_l0000Booooo`?o00003_ooool3o`00037ooooo0_l0000Aooooo`;o00004oooool2o`00037o
oooo0_l0000booooo`00:oooool00ol0003oooooooooo`0Hooooo`;o00009_ooool2o`00013ooooo
0_l0000Booooo`?o00003_ooool3o`00037ooooo0_l0000Aooooo`;o00004oooool2o`00037ooooo
0_l0000booooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool04Oooool3o`0002Wooooo1?l00009ooooo`;o0000
7_ooool2o`0002_ooooo0ol00004ooooo`;o000000?oooooo`000?l00000:_ooool2o`000003oooo
ool0003o000000Cooooo0_l0000Eooooo`;o00005Oooool2o`00017ooooo0_l0000Qooooo`00:ooo
ool00ol0003oooooooooo`0Aooooo`?o0000:Oooool4o`0000Wooooo0_l0000Nooooo`;o0000:ooo
ool3o`0000Cooooo0_l000000ooooooo0000o`00000Zooooo`;o000000?oooooo`000?l000001?oo
ool2o`0001Gooooo0_l0000Eooooo`;o00004Oooool2o`00027ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00043o
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0=?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`12oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0foooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000ooooooooool0@oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0booooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41004oooool002_ooooo00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0000Boooo
o`;o00000oooool4o`0000Cooooo0ol000001_oooooo0000o`000?l0003oooooo`00017ooooo0_l0
000=ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l00005ooooo`?o000000?oooooo`000?l000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`;o00005?ooool2o`0000;ooooo0_l00008oooo
o`So000000?oooooo`000?l000000oooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooo
ooooool000000oooool3o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l0
0004ooooo`;o00000_ooool2o`0001Gooooo00CoV9RHob4Q8Oo^k^kooooo0ol00003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003ooooo
ooooo`0:ooooo`;o00005Oooool2o`0001;ooooo0_l00003ooooo`Co000000?oooooo`000?lQ8B40
1?l000001_oooooo0000o`000?l0003oooooo`00017ooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00005ooooo`?o000000?ooooo
o`000?l000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000004ooooo`;o00005?ooool2o`0000;ooooo0_l00008ooooo`So000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01?l0003o
ooooooooooooool3o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00004
ooooo`;o00000_ooool2o`0001Kooooo00?oMgMgofIVI_ooool00ol00003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00010ooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0coooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`0oooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`03oeEEEOmVIVKo0000
00Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool01?l0003ooooooooo
ooooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000>ooooo`?o0000
00Coooooo`000?l0003ooooo0_l00007ooooo`[o00004Oooool2o`0001;ooooo0_l00004ooooo`;o
00002oooool2o`0001Gooooo0_l0000<ooooo`Co00002Oooool2o`0000?ooooo0_l00006ooooo`Co
00001_ooool2o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00000Uooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0ol000000ooo
oooo0000o`000004ooooo`;o00009oooool002_ooooo00Co0000oooooooooooooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000003_ooool3o`000004ooooool0003o0000
ooooo`;o00001oooool:o`00017ooooo0_l0000Booooo`;o00001?ooool2o`0000_ooooo0_l0000E
ooooo`;o00003?ooool4o`0000Wooooo0_l00003ooooo`;o00001_ooool4o`0000Kooooo0_l00004
ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000009Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`?o000000?oooooo`000?l000001?oo
ool2o`0001gooooo0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<
ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5
ooooo`00:oooool4o`0000Cooooo1?l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00003oooo
o`;o00000oooool3o`0000kooooo0_l0000:ooooo`;o00002?ooool2o`0000Sooooo0_l00002oooo
o`;o00001?ooool2o`0000oooooo0_l00005ooooo`Co00002?ooool5o`000005ooooool0003o0000
o`000?ooool00_l00009ooooo`;o00002?ooool4o`0000Sooooo0_l0000Fooooo`;o00002Oooool6
o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000002oooool2
o`0000gooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000001;ooooo00Go0000
oooooom4A4Co0000oa0@4004ooooo`00:oooool4o`0000Cooooo1?l0000<ooooo`;o00000_ooool2
o`0000?ooooo0_l00003ooooo`;o00000oooool3o`0000kooooo0_l0000:ooooo`;o00002?ooool2
o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000oooooo0_l00005ooooo`Co00002?ooool5
o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00002?ooool4o`0000Sooooo0_l0
000Fooooo`;o00002Oooool6o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000002oooool2o`0000gooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000001;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooooolb
ooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<Oooool2o`00
00Sooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo00;ooooo0_l0000@ooooo`Co00003Oooool3o`00013ooooo0_l0
000Cooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0001?ooooo1?l0
0009ooooo`;o00003Oooool2o`0001cooooo0_l0000Hooooo`;o00001_ooool2o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00001oooool2o`000003ooooool0
003o000000Wooooo0_l00004ooooo`;o00009?ooool002_ooooo00?o0000ooooooooool00_ooool2
o`00013ooooo1?l0000=ooooo`?o00004?ooool2o`0001?ooooo0_l00004ooooo`;o00000_ooool2
o`0000Gooooo0_l00009ooooo`;o00004oooool4o`0000Wooooo0_l0000=ooooo`;o00007?ooool2
o`0001Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o
000000kooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0000T
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0<oooo
o`Co00007oooool2o`0001oooooo0_l0000Booooo`;o00002oooool2o`0001cooooo0_l00004oooo
o`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool4o`0002Gooooo0_l0000Foooo
o`;o00005_ooool2o`0000Oooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`0<ooooo`Co
00007oooool2o`0001oooooo0_l0000Booooo`;o00002oooool2o`0001cooooo0_l00004ooooo`;o
00002oooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool4o`0002Gooooo0_l0000Fooooo`;o
00005_ooool2o`0000Oooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool03oooool2o`0002Go
oooo0_l0000Nooooo`;o0000Foooool2o`0003_ooooo0_l00018ooooo`00:oooool00ol0003ooooo
ooooo`0?ooooo`;o00009Oooool2o`0001kooooo0_l0001Kooooo`;o0000>oooool2o`0004Sooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`1<ooooo`;o00001_ooool2o`0000_ooooo0_l0002Wooooo`;o0000
;_ooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0
003oooooooooo`1<ooooo`;o00001_ooool2o`0000_ooooo0_l0002Wooooo`;o0000;_ooool001_o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000ooooooll
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo>oooool001_ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`00
6?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`00
7?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool00000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj
^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`00
0oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l00000
0ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?ooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000003oc8b<_oMgMgooooo0?oooooo4oooool000?ooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RH
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go
0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMg
Molb<S;ooooo0?oooooo4oooool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo
00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000oooo
ooooooooooooo`00000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolB
ooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7
ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo0?oo
oooo4oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^
oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7Qooooooo
ZJVYo`00000Dooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03ooooo
oaCooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo
8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`00
3oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0=?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo5_ooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWo
ooooooooo`0aooooo`03oeEEEOmVIVKo000000Gooooo1?l0003ooooooaGooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32962 Mdot
.03333 .30902 Mdot
.0381 .30902 Mdot
.04286 .35022 Mdot
.04762 .28842 Mdot
.05238 .30902 Mdot
.05714 .32962 Mdot
.0619 .28842 Mdot
.06667 .26781 Mdot
.07143 .30902 Mdot
.07619 .37082 Mdot
.08095 .37082 Mdot
.08571 .39142 Mdot
.09048 .26781 Mdot
.09524 .26781 Mdot
.1 .32962 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .24721 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .28842 Mdot
.14286 .26781 Mdot
.14762 .30902 Mdot
.15238 .32962 Mdot
.15714 .32962 Mdot
.1619 .35022 Mdot
.16667 .32962 Mdot
.17143 .30902 Mdot
.17619 .30902 Mdot
.18095 .28842 Mdot
.18571 .30902 Mdot
.19048 .37082 Mdot
.19524 .28842 Mdot
.2 .30902 Mdot
.20476 .28842 Mdot
.20952 .28842 Mdot
.21429 .39142 Mdot
.21905 .32962 Mdot
.22381 .30902 Mdot
.22857 .28842 Mdot
.23333 .28842 Mdot
.2381 .26781 Mdot
.24286 .24721 Mdot
.24762 .22661 Mdot
.25238 .28842 Mdot
.25714 .28842 Mdot
.2619 .30902 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .22661 Mdot
.28095 .24721 Mdot
.28571 .41202 Mdot
.29048 .35022 Mdot
.29524 .30902 Mdot
.3 .37082 Mdot
.30476 .22661 Mdot
.30952 .35022 Mdot
.31429 .41202 Mdot
.31905 .37082 Mdot
.32381 .32962 Mdot
.32857 .30902 Mdot
.33333 .28842 Mdot
.3381 .28842 Mdot
.34286 .30902 Mdot
.34762 .32962 Mdot
.35238 .30902 Mdot
.35714 .39142 Mdot
.3619 .32962 Mdot
.36667 .37082 Mdot
.37143 .22661 Mdot
.37619 .24721 Mdot
.38095 .32962 Mdot
.38571 .24721 Mdot
.39048 .26781 Mdot
.39524 .28842 Mdot
.4 .28842 Mdot
.40476 .26781 Mdot
.40952 .37082 Mdot
.41429 .26781 Mdot
.41905 .30902 Mdot
.42381 .26781 Mdot
.42857 .22661 Mdot
.43333 .24721 Mdot
.4381 .26781 Mdot
.44286 .32962 Mdot
.44762 .30902 Mdot
.45238 .32962 Mdot
.45714 .35022 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .28842 Mdot
.47619 .28842 Mdot
.48095 .30902 Mdot
.48571 .32962 Mdot
.49048 .32962 Mdot
.49524 .35022 Mdot
.5 .30902 Mdot
.50476 .30902 Mdot
.50952 .35022 Mdot
.51429 .32962 Mdot
.51905 .30902 Mdot
.52381 .28842 Mdot
.52857 .37082 Mdot
.53333 .24721 Mdot
.5381 .26781 Mdot
.54286 .35022 Mdot
.54762 .26781 Mdot
.55238 .32962 Mdot
.55714 .26781 Mdot
.5619 .30902 Mdot
.56667 .24721 Mdot
.57143 .35022 Mdot
.57619 .28842 Mdot
.58095 .20601 Mdot
.58571 .30902 Mdot
.59048 .32962 Mdot
.59524 .37082 Mdot
.6 .24721 Mdot
.60476 .28842 Mdot
.60952 .30902 Mdot
.61429 .37082 Mdot
.61905 .26781 Mdot
.62381 .30902 Mdot
.62857 .39142 Mdot
.63333 .26781 Mdot
.6381 .28842 Mdot
.64286 .32962 Mdot
.64762 .37082 Mdot
.65238 .35022 Mdot
.65714 .28842 Mdot
.6619 .24721 Mdot
.66667 .26781 Mdot
.67143 .28842 Mdot
.67619 .28842 Mdot
.68095 .28842 Mdot
.68571 .26781 Mdot
.69048 .28842 Mdot
.69524 .26781 Mdot
.7 .28842 Mdot
.70476 .32962 Mdot
.70952 .28842 Mdot
.71429 .24721 Mdot
.71905 .28842 Mdot
.72381 .24721 Mdot
.72857 .35022 Mdot
.73333 .24721 Mdot
.7381 .32962 Mdot
.74286 .24721 Mdot
.74762 .32962 Mdot
.75238 .32962 Mdot
.75714 .35022 Mdot
.7619 .30902 Mdot
.76667 .32962 Mdot
.77143 .28842 Mdot
.77619 .18541 Mdot
.78095 .35022 Mdot
.78571 .32962 Mdot
.79048 .35022 Mdot
.79524 .26781 Mdot
.8 .32962 Mdot
.80476 .26781 Mdot
.80952 .18541 Mdot
.81429 .26781 Mdot
.81905 .24721 Mdot
.82381 .26781 Mdot
.82857 .37082 Mdot
.83333 .30902 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .28842 Mdot
.85238 .35022 Mdot
.85714 .26781 Mdot
.8619 .37082 Mdot
.86667 .28842 Mdot
.87143 .26781 Mdot
.87619 .30902 Mdot
.88095 .32962 Mdot
.88571 .32962 Mdot
.89048 .32962 Mdot
.89524 .26781 Mdot
.9 .22661 Mdot
.90476 .30902 Mdot
.90952 .30902 Mdot
.91429 .41202 Mdot
.91905 .30902 Mdot
.92381 .20601 Mdot
.92857 .32962 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .37082 Mdot
.94762 .35022 Mdot
.95238 .30902 Mdot
.95714 .26781 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .37082 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003Qooooo`;o00002?ooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0>3ooooo
0_l00008ooooo`;o0000C_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000:Gooooo0_l0001Vooooo`;o0000:oooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0YOooool2o`0006Kooooo
0_l0000[ooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000@Oooool2o`0000Oooooo0_l0
0007ooooo`;o00004_ooool2o`0000oooooo0_l0002=ooooo`;o0000<_ooool002_ooooo00?o0000
ooooooooool0@?ooool2o`0000Oooooo0_l00007ooooo`;o00004_ooool2o`0000oooooo0_l0002=
ooooo`;o0000<_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Hooooo`;o00009Oooool2
o`0000Wooooo0_l0000Kooooo`;o000000?oooooo`000?l000003?ooool2o`0001gooooo0_l00008
ooooo`;o00002?ooool2o`00017ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`00000Eooooo`;o0000Boooool002_ooooo0_l0000Iooooo`;o00009Oooool2
o`0000Wooooo0_l0000Kooooo`;o000000?oooooo`000?l000003?ooool2o`0001gooooo0_l00008
ooooo`;o00002?ooool2o`00017ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`00000Eooooo`;o0000Boooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o00002oooool2o`0000Gooooo0ol0000=ooooo`;o00006_ooool2
o`000005odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko
oooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00002ooooo`;o00002?ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o000000Coooooo`00
0?l0003ooooo1?l00009ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`Oo000000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo
00?o0000ooooooooool02_ooool2o`0000Gooooo0ol0000=ooooo`;o00006_ooool2o`0000?ooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL08?ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000001?oo
oooo0000o`000?ooool2o`00017ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000003ooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL01oooool2o`000004ooooool0003o0000ooooo`Co00002Oooool2o`00
00;ooooo0_l00005ooooo`;o00003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400;o000000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo
00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03So
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000ooooooooool0
@_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000003Kooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o
0000ooooooooool0<oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000>_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000003Kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100>_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@4100=oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000[ooooo`;o00001Oooool2o`00
00;ooooo0_l0000Eooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo1?l000001?oooooo0000ooooooooool3o`000006oooooomgMgOo0000o`000?nHV9SoMgMg
3oooool4o`0000oooooo0ol0000Aooooo`Ko00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?l0003o0000ogMgM`0=ooooo`;o00001_ooool2o`0000Sooooo0_l00004oooo
o`;o00000_ooool5o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0001;ooooo
0_l000000ooooooo0000o`000003ooooo`;o00005Oooool01_l0003o^[ZjoooooonHV9So410@oooo
o`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04ooo
ool002_ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l0000Eooooo`;o00002oooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l000000ooooooo0000o`000004
o`000006ooooooo^k^ko0000o`000?lb<S;ok^k^3oooool4o`0000oooooo0ol0000Aooooo`Ko0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0=oooo
o`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool5o`000004ooooool0003o0000
ooooo`;o000000CoEEEEo`000?l0003ooooo0_l00002ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;o00004_ooool2o`000003ooooool0003o000000?ooooo0_l0000Eooooo`06oiRH
V?l@413o0000ob4Q8Oo<c<cooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o
00000_ooool00ol@413o0000o`000003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo
00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?ooooooo`00033o00003?ooool01?l0003oV9RH
oc8b<_o<c<`5ooooo`00:oooool00ol0003oooooo`000003o`0000;ooooo0_l00004ooooo`;o0000
3?ooool7o`0000;ooooo0_l00004ooooo`Go000000?oooooo`000?l000000_ooool2o`0000?ooooo
00Co0000ooooool0003o00002_ooool3o`0000Oooooo0_l00003ooooo`03o`000?oooooooooo00;o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003Oooool01?l0003oooooooooooooool2
o`0000Oooooo0ol00007ooooo`;o00001?ooool3o`0000;ooooo0_l00008ooooo`03o`000?oooooo
oooo00;o00001Oooool2o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00001?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?oo
ool2o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0ol00006ooooo`?o000000?o
ooooo`000?l000000_ooool4o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004_oo
ool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000ooooooooool0oooooolb
ooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo00?o0000ooooooooool0oooooolb
ooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0
003oooooooooo`06ooooo`00:oooool3o`0000Oooooo0_l0000;ooooo`?o00003?ooool4o`000003
ooooool0003o000000kooooo0_l0000Mooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o
00004?ooool2o`000003ooooool0003o000000Sooooo1?l00005ooooo`;o00002Oooool2o`0000[o
oooo0_l0000>ooooo`;o00004?ooool2o`0000Wooooo1_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l0000;ooooo`;o00002_ooool5o`0000Wooooo0_l0000Pooooo`;o00002?ooool002_ooooo
0ol00007ooooo`;o00002oooool3o`0000cooooo1?l000000ooooooo0000o`00000>ooooo`;o0000
7Oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo0_l000000ooooooo0000
o`000008ooooo`Co00001Oooool2o`0000Wooooo0_l0000:ooooo`;o00003_ooool2o`00013ooooo
0_l00009ooooo`Ko00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002oooool2o`0000[ooooo
1Ol00009ooooo`;o0000:_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`02ooooo`;o0000
4_ooool2o`0000kooooo0_l0000Uooooo`;o00001?ooool2o`0002_ooooo0_l00009ooooo`;o0000
0_ooool2o`0000Wooooo0_l00006ooooo`;o00005oooool2o`0001Gooooo0_l00006ooooo`;o0000
1_ooool4o`00017ooooo0_l0000Kooooo`;o00009?ooool002_ooooo0_l00003ooooo`;o00004_oo
ool2o`0000kooooo0_l0000Uooooo`;o00001?ooool2o`0002_ooooo0_l00009ooooo`;o00000_oo
ool2o`0000Wooooo0_l00006ooooo`;o00005oooool2o`0001Gooooo0_l00006ooooo`;o00001_oo
ool4o`00017ooooo0_l0000Kooooo`;o00009?ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o00003Oooool4o`0001oooooo0_l0000Oooooo`;o00001?ooool2
o`0000cooooo0_l0000;ooooo`;o00008_ooool2o`0001;ooooo0_l00004ooooo`;o00002?ooool2
o`0003Gooooo0_l00008ooooo`;o00005_ooool2o`0000Oooooo0_l0000Mooooo`00:oooool00ol0
003oooooooooo`0<ooooo`Co00007oooool2o`0001oooooo0_l00004ooooo`;o00003?ooool2o`00
00_ooooo0_l0000Rooooo`;o00004_ooool2o`0000Cooooo0_l00008ooooo`;o0000=Oooool2o`00
00Sooooo0_l0000Fooooo`;o00001oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000@oooo
o`;o00009Oooool2o`0002Wooooo0_l0001@ooooo`;o0000QOooool002_ooooo00?o0000oooooooo
ool03oooool2o`0002Gooooo0_l0000Yooooo`;o0000D?ooool2o`0008Gooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oo
oooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool3o`0004cooooo0_l00006ooooo`;o0000]?ooool2o`0002ko
oooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo04cooooo0_l00006ooooo`;o0000]?ooool2o`0002kooooo000Kooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oo
oooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000ooooooll
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o
^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo
0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`00
0003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?l@413oc<c<oooooolEooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Sooooooooo
ooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooo
oooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@3ooooooaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3oooo
o`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?oo
ooooooooooooool000005?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000oooooolEooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;o
oooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000
ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40oooooolEooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEE
EOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_oo
ool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?o0000ooooooooool00_ooool01Ol0003oEEEE
o`000?l@413oc<c<0?oooooo5Oooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@
ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7
ooooo`3ooooooaOooooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0dooooo`03
o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0oooooolGooooo`003oooool00onj^[[oA4A4
ooooo`02ooooo`03ojVYZOoooooooooo037ooooo00?oEEEEofIVI_l000001Oooool01?o<c<coA4A4
o`000?l@413ooooooaGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33992 Mdot
.03333 .31932 Mdot
.0381 .31932 Mdot
.04286 .33992 Mdot
.04762 .27812 Mdot
.05238 .29872 Mdot
.05714 .33992 Mdot
.0619 .29872 Mdot
.06667 .27812 Mdot
.07143 .29872 Mdot
.07619 .38112 Mdot
.08095 .36052 Mdot
.08571 .40172 Mdot
.09048 .25751 Mdot
.09524 .27812 Mdot
.1 .33992 Mdot
.10476 .33992 Mdot
.10952 .33992 Mdot
.11429 .25751 Mdot
.11905 .29872 Mdot
.12381 .31932 Mdot
.12857 .29872 Mdot
.13333 .31932 Mdot
.1381 .27812 Mdot
.14286 .27812 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .31932 Mdot
.1619 .33992 Mdot
.16667 .31932 Mdot
.17143 .29872 Mdot
.17619 .31932 Mdot
.18095 .29872 Mdot
.18571 .31932 Mdot
.19048 .36052 Mdot
.19524 .29872 Mdot
.2 .31932 Mdot
.20476 .29872 Mdot
.20952 .29872 Mdot
.21429 .38112 Mdot
.21905 .33992 Mdot
.22381 .31932 Mdot
.22857 .27812 Mdot
.23333 .29872 Mdot
.2381 .27812 Mdot
.24286 .25751 Mdot
.24762 .23691 Mdot
.25238 .27812 Mdot
.25714 .29872 Mdot
.2619 .31932 Mdot
.26667 .31932 Mdot
.27143 .29872 Mdot
.27619 .21631 Mdot
.28095 .25751 Mdot
.28571 .42232 Mdot
.29048 .33992 Mdot
.29524 .29872 Mdot
.3 .36052 Mdot
.30476 .21631 Mdot
.30952 .36052 Mdot
.31429 .42232 Mdot
.31905 .36052 Mdot
.32381 .33992 Mdot
.32857 .31932 Mdot
.33333 .27812 Mdot
.3381 .29872 Mdot
.34286 .31932 Mdot
.34762 .33992 Mdot
.35238 .31932 Mdot
.35714 .40172 Mdot
.3619 .33992 Mdot
.36667 .38112 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .33992 Mdot
.38571 .25751 Mdot
.39048 .25751 Mdot
.39524 .27812 Mdot
.4 .27812 Mdot
.40476 .25751 Mdot
.40952 .38112 Mdot
.41429 .27812 Mdot
.41905 .29872 Mdot
.42381 .27812 Mdot
.42857 .21631 Mdot
.43333 .25751 Mdot
.4381 .27812 Mdot
.44286 .33992 Mdot
.44762 .31932 Mdot
.45238 .33992 Mdot
.45714 .33992 Mdot
.4619 .29872 Mdot
.46667 .27812 Mdot
.47143 .27812 Mdot
.47619 .27812 Mdot
.48095 .31932 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .36052 Mdot
.5 .29872 Mdot
.50476 .31932 Mdot
.50952 .36052 Mdot
.51429 .33992 Mdot
.51905 .29872 Mdot
.52381 .29872 Mdot
.52857 .38112 Mdot
.53333 .25751 Mdot
.5381 .25751 Mdot
.54286 .36052 Mdot
.54762 .27812 Mdot
.55238 .31932 Mdot
.55714 .27812 Mdot
.5619 .31932 Mdot
.56667 .25751 Mdot
.57143 .33992 Mdot
.57619 .29872 Mdot
.58095 .19571 Mdot
.58571 .29872 Mdot
.59048 .31932 Mdot
.59524 .36052 Mdot
.6 .23691 Mdot
.60476 .29872 Mdot
.60952 .31932 Mdot
.61429 .36052 Mdot
.61905 .27812 Mdot
.62381 .31932 Mdot
.62857 .40172 Mdot
.63333 .25751 Mdot
.6381 .27812 Mdot
.64286 .31932 Mdot
.64762 .38112 Mdot
.65238 .36052 Mdot
.65714 .27812 Mdot
.6619 .25751 Mdot
.66667 .25751 Mdot
.67143 .29872 Mdot
.67619 .29872 Mdot
.68095 .29872 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .27812 Mdot
.7 .27812 Mdot
.70476 .31932 Mdot
.70952 .29872 Mdot
.71429 .23691 Mdot
.71905 .27812 Mdot
.72381 .23691 Mdot
.72857 .33992 Mdot
.73333 .25751 Mdot
.7381 .33992 Mdot
.74286 .23691 Mdot
.74762 .31932 Mdot
.75238 .33992 Mdot
.75714 .33992 Mdot
.7619 .31932 Mdot
.76667 .31932 Mdot
.77143 .27812 Mdot
.77619 .19571 Mdot
.78095 .36052 Mdot
.78571 .31932 Mdot
.79048 .33992 Mdot
.79524 .25751 Mdot
.8 .31932 Mdot
.80476 .27812 Mdot
.80952 .19571 Mdot
.81429 .25751 Mdot
.81905 .25751 Mdot
.82381 .25751 Mdot
.82857 .36052 Mdot
.83333 .31932 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .27812 Mdot
.85238 .36052 Mdot
.85714 .25751 Mdot
.8619 .38112 Mdot
.86667 .27812 Mdot
.87143 .25751 Mdot
.87619 .31932 Mdot
.88095 .33992 Mdot
.88571 .33992 Mdot
.89048 .33992 Mdot
.89524 .25751 Mdot
.9 .21631 Mdot
.90476 .31932 Mdot
.90952 .31932 Mdot
.91429 .42232 Mdot
.91905 .29872 Mdot
.92381 .19571 Mdot
.92857 .31932 Mdot
.93333 .31932 Mdot
.9381 .29872 Mdot
.94286 .36052 Mdot
.94762 .33992 Mdot
.95238 .29872 Mdot
.95714 .25751 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .36052 Mdot
.97619 .29872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`2Uooooo`;o0000>Oooool2
o`0000Sooooo0_l0000Qooooo`;o0000:oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`2Uooooo`;o0000>Oooool2o`0000Sooooo
0_l0000Qooooo`;o0000:oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`19ooooo`;o0000
1oooool2o`0002?ooooo0_l0002=ooooo`;o0000<_ooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0BOooool2o`0000Oooooo
0_l0000Sooooo`;o0000SOooool2o`0003;ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`10ooooo`;o00009?ooool3o`0004;o
oooo0_l0000Pooooo`;o000000?oooooo`000?l000001?ooool2o`0006;ooooo000[ooooo`03o`00
0?oooooooooo043ooooo0_l0000Tooooo`?o0000@_ooool2o`00023ooooo0_l000000ooooooo0000
o`000004ooooo`;o0000H_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`;o0000
9Oooool2o`0000Wooooo0_l0000Nooooo`?o00000oooool2o`0000Kooooo0_l0000Mooooo`?o0000
1oooool2o`0001;ooooo0_l00007ooooo`?o00004_ooool2o`00017ooooo0_l00004ooooo`Co0000
2Oooool2o`0000;ooooo0_l00005ooooo`;o00004Oooool2o`00027ooooo000[ooooo`03o`000?oo
oooooooo017ooooo0_l00005ooooo`;o00009Oooool2o`0000Wooooo0_l0000Nooooo`?o00000ooo
ool2o`0000Kooooo0_l0000Mooooo`?o00001oooool2o`0001;ooooo0_l00007ooooo`?o00004_oo
ool2o`00017ooooo0_l00004ooooo`Co00002Oooool2o`0000;ooooo0_l00005ooooo`;o00004Ooo
ool2o`00027ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooo
ooooool01?ooool2o`0000Cooooo0_l00006ooooo`;o00002oooool4o`0001Oooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000oooooo0_l0000A
ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`Go00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`000004oooo
ool0003o0000o`0000;ooooo00Co0000ooooool0003o00001Oooool01OmgMgOo<S8boooooooooooo
000000?ooooo0ol00008ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l0000G
ooooo`04oiRHV?lQ8B7ok^k^ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool04Oooool002_ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0
0006ooooo`;o00002oooool4o`0001Oooooo0_l000001Ooooooo0000o`000?l0003o8B4Q00?o0000
0_ooool01Ol0003ooooooooooooooooo000000oooooo0_l0000Aooooo`?o00000oooool2o`000003
ooooool0003o000000;ooooo0_l00006ooooo`Go00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o000000?oooooo`000?l000004Oooool2
o`0000?ooooo0_l00004ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo00Co
0000ooooool0003o00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Co0000oooooooo
oooooooo0ol00008ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l0000Hoooo
o`03ogMgMomVIVKooooo00?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool04Oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo017ooooo000[ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04ooo
ool002_ooooo00?o0000ooooooooool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0=?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool01Oooool2o`000004ooooool0003o
0000ooooo`;o00003?ooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0
0006ooooo`;o00002oooool2o`0001Kooooo0_l0000;ooooo`;o00002_ooool2o`0000?ooooo1?l0
000>ooooo`Co00001?ooool2o`0001;ooooo1Ol000000ooooooo0000o`000004ooooo`;o0000?Ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000001_ooooo000[
ooooo`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0
00000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000;o00001Oooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000_ooooo0_l0
000Fooooo`;o00002oooool2o`0000[ooooo0_l00003ooooo`Co00003_ooool4o`0000Cooooo0_l0
000Booooo`Go000000?oooooo`000?l000001?ooool2o`0003gooooo0_l00004ooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`;o00000_ooool00ol@413o0000o`00
0003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<
c004ooooo`009?ooooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool0
0ol0003o410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000ooooool000000ol0000Hoooo
o`;o000000?oooooo`000?l000000_ooool5o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l0000:ooooo`?o00004Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Kooooo`;o00002?ooool5o`0000;ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`00013ooooo0_l0000;
ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o
000000Sooooo0_l00007ooooo`?o00001?ooool4o`0001oooooo00Go0000oooooom4A4Co0000oa0@
4004ooooo`00:oooool00ol0003oooooo`000003o`0001Sooooo0_l000000ooooooo0000o`000002
ooooo`Go000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Ooo
ool2o`0000[ooooo0ol0000Aooooo`;o00000_ooool2o`000003ooooool0003o000001_ooooo0_l0
0008ooooo`Go00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000007ooooo`;o00001?oo
ool2o`0000;ooooo0_l00004ooooo`;o00004?ooool2o`0000_ooooo0_l00003ooooo`?o00001?oo
ool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo0ol0
0004ooooo`Co00007oooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3o
oooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooooolaoooo
o`;o00002?ooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo0ol00002ooooo`;o00000oooool2o`0000_ooooo1?l0000>ooooo`;o00004?oo
ool2o`0001?ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00004?oo
ool2o`000003ooooool0003o000000;o00003oooool2o`0000oooooo0_l0000^ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000Sooooo0_l0000Jooooo`Go00003oooool2o`0002Cooooo000[
ooooo`?o00000_ooool2o`0000?ooooo0_l0000;ooooo`Co00003_ooool2o`00013ooooo0_l0000C
ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo0_l00000
0ooooooo0000o`000002o`0000oooooo0_l0000?ooooo`;o0000;_ooool2o`000003ooooool0003o
000000;ooooo0ol00008ooooo`;o00006_ooool5o`0000oooooo0_l0000Tooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00007oooool2o`00
01oooooo0_l000001?oooooo0000o`000?ooool2o`0003?ooooo0_l00002ooooo`;o00002Oooool2
o`0000gooooo0_l00004ooooo`;o00002_ooool2o`0002Gooooo0_l0000<ooooo`;o00001Oooool2
o`0001Wooooo0_l00007ooooo`;o00007Oooool002_ooooo00?o0000ooooooooool03_ooool2o`00
01oooooo0_l0000Oooooo`;o000000Coooooo`000?l0003ooooo0_l0000cooooo`;o00000_ooool2
o`0000Wooooo0_l0000=ooooo`;o00001?ooool2o`0000[ooooo0_l0000Uooooo`;o00003?ooool2
o`0000Gooooo0_l0000Iooooo`;o00001oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0<
ooooo`;o0000:?ooool2o`0002cooooo0_l0000;ooooo`;o00008_ooool2o`0002;ooooo0_l0000o
ooooo`;o0000?_ooool002_ooooo00?o0000ooooooooool03?ooool2o`0002Sooooo0_l0000/oooo
o`;o00002oooool2o`0002;ooooo0_l0000Rooooo`;o0000?oooool2o`0003kooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`0?ooooo`;o0000D?ooool2o`00053ooooo0_l00025ooooo`006Oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00oooooo0_l0
001@ooooo`;o0000D?ooool2o`0008Gooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003ooooooc_ooooo000K
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`1<ooooo`;o00001_oo
ool2o`000;Cooooo0_l0000^ooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`1<ooooo`;o00001_ooool2o`000;Cooooo0_l0
000^ooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
0?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooooom4ooooo`006oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooooom4ooooo`006?ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000H
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo
A?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0C
ooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo
00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002oooo
o`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`3ooooooaGooooo0003oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?o
oooo00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000
oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?o0000oooooooo
ool01?ooool00omEEEGoZJVYooooo`3ooooooaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Go
oooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`B
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`04ooooo`03ojVYZOmE
EEGooooo0?oooooo5Oooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^
kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05
o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?o0000ooooooooool01Oooool00olQ
8B7oooooooooo`3ooooooaCooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRH
V?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05
o`000?n7QhOoooooojVYZOl000005?ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo
0?oooooo5?ooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03
ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`3ooooooaCo
oooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0dooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooc8b<P3ooooooaGooooo000?ooooo`03okZj^_m4A4Cooooo
00;ooooo00?oZJVYooooooooool0<Oooool00omEEEGoIVIVo`000004ooooo`Go0000oooooolEoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .35022 Mdot
.03333 .30902 Mdot
.0381 .32962 Mdot
.04286 .35022 Mdot
.04762 .28842 Mdot
.05238 .28842 Mdot
.05714 .32962 Mdot
.0619 .28842 Mdot
.06667 .26781 Mdot
.07143 .30902 Mdot
.07619 .37082 Mdot
.08095 .35022 Mdot
.08571 .41202 Mdot
.09048 .24721 Mdot
.09524 .26781 Mdot
.1 .32962 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .24721 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .28842 Mdot
.14286 .26781 Mdot
.14762 .30902 Mdot
.15238 .32962 Mdot
.15714 .32962 Mdot
.1619 .32962 Mdot
.16667 .32962 Mdot
.17143 .28842 Mdot
.17619 .30902 Mdot
.18095 .28842 Mdot
.18571 .32962 Mdot
.19048 .35022 Mdot
.19524 .30902 Mdot
.2 .32962 Mdot
.20476 .28842 Mdot
.20952 .28842 Mdot
.21429 .37082 Mdot
.21905 .35022 Mdot
.22381 .30902 Mdot
.22857 .26781 Mdot
.23333 .30902 Mdot
.2381 .28842 Mdot
.24286 .26781 Mdot
.24762 .24721 Mdot
.25238 .28842 Mdot
.25714 .30902 Mdot
.2619 .32962 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .20601 Mdot
.28095 .26781 Mdot
.28571 .41202 Mdot
.29048 .35022 Mdot
.29524 .28842 Mdot
.3 .37082 Mdot
.30476 .20601 Mdot
.30952 .37082 Mdot
.31429 .43262 Mdot
.31905 .37082 Mdot
.32381 .35022 Mdot
.32857 .32962 Mdot
.33333 .28842 Mdot
.3381 .30902 Mdot
.34286 .30902 Mdot
.34762 .32962 Mdot
.35238 .30902 Mdot
.35714 .39142 Mdot
.3619 .35022 Mdot
.36667 .37082 Mdot
.37143 .24721 Mdot
.37619 .22661 Mdot
.38095 .32962 Mdot
.38571 .24721 Mdot
.39048 .24721 Mdot
.39524 .28842 Mdot
.4 .26781 Mdot
.40476 .24721 Mdot
.40952 .37082 Mdot
.41429 .28842 Mdot
.41905 .30902 Mdot
.42381 .26781 Mdot
.42857 .20601 Mdot
.43333 .26781 Mdot
.4381 .28842 Mdot
.44286 .32962 Mdot
.44762 .30902 Mdot
.45238 .35022 Mdot
.45714 .32962 Mdot
.4619 .28842 Mdot
.46667 .26781 Mdot
.47143 .28842 Mdot
.47619 .28842 Mdot
.48095 .32962 Mdot
.48571 .32962 Mdot
.49048 .30902 Mdot
.49524 .37082 Mdot
.5 .28842 Mdot
.50476 .32962 Mdot
.50952 .37082 Mdot
.51429 .32962 Mdot
.51905 .30902 Mdot
.52381 .28842 Mdot
.52857 .37082 Mdot
.53333 .24721 Mdot
.5381 .26781 Mdot
.54286 .35022 Mdot
.54762 .28842 Mdot
.55238 .30902 Mdot
.55714 .28842 Mdot
.5619 .32962 Mdot
.56667 .26781 Mdot
.57143 .35022 Mdot
.57619 .30902 Mdot
.58095 .18541 Mdot
.58571 .30902 Mdot
.59048 .30902 Mdot
.59524 .37082 Mdot
.6 .22661 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .37082 Mdot
.61905 .28842 Mdot
.62381 .32962 Mdot
.62857 .39142 Mdot
.63333 .24721 Mdot
.6381 .28842 Mdot
.64286 .32962 Mdot
.64762 .39142 Mdot
.65238 .35022 Mdot
.65714 .26781 Mdot
.6619 .24721 Mdot
.66667 .24721 Mdot
.67143 .30902 Mdot
.67619 .28842 Mdot
.68095 .30902 Mdot
.68571 .28842 Mdot
.69048 .30902 Mdot
.69524 .26781 Mdot
.7 .26781 Mdot
.70476 .30902 Mdot
.70952 .28842 Mdot
.71429 .22661 Mdot
.71905 .28842 Mdot
.72381 .22661 Mdot
.72857 .35022 Mdot
.73333 .24721 Mdot
.7381 .35022 Mdot
.74286 .24721 Mdot
.74762 .32962 Mdot
.75238 .35022 Mdot
.75714 .35022 Mdot
.7619 .32962 Mdot
.76667 .32962 Mdot
.77143 .28842 Mdot
.77619 .20601 Mdot
.78095 .37082 Mdot
.78571 .30902 Mdot
.79048 .35022 Mdot
.79524 .26781 Mdot
.8 .30902 Mdot
.80476 .28842 Mdot
.80952 .18541 Mdot
.81429 .24721 Mdot
.81905 .24721 Mdot
.82381 .24721 Mdot
.82857 .37082 Mdot
.83333 .32962 Mdot
.8381 .26781 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .35022 Mdot
.85714 .24721 Mdot
.8619 .39142 Mdot
.86667 .26781 Mdot
.87143 .24721 Mdot
.87619 .30902 Mdot
.88095 .32962 Mdot
.88571 .35022 Mdot
.89048 .32962 Mdot
.89524 .26781 Mdot
.9 .22661 Mdot
.90476 .30902 Mdot
.90952 .32962 Mdot
.91429 .43262 Mdot
.91905 .28842 Mdot
.92381 .20601 Mdot
.92857 .30902 Mdot
.93333 .30902 Mdot
.9381 .28842 Mdot
.94286 .37082 Mdot
.94762 .35022 Mdot
.95238 .30902 Mdot
.95714 .26781 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .37082 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0002Vooooo`;o0000@oooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0:Gooooo
0_l00013ooooo`;o0000C_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`0004Wooooo0_l00007ooooo`;o00008oooool2o`0006Oooooo0_l0000[ooooo`;o0000
:oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0BOooool2o`0000Oooooo0_l0000Sooooo`;o0000Ioooool2o`0002_ooooo
0_l0000[ooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000J?ooool2o`0004;ooooo0_l0
000Pooooo`;o000000?oooooo`000?l00000=?ooool2o`0003;ooooo000[ooooo`03o`000?oooooo
oooo06Oooooo0_l00012ooooo`;o00008?ooool2o`000003ooooool0003o000003Cooooo0_l0000b
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`;o00009_ooool2
o`0002Cooooo0_l00002ooooo`?o00000oooool2o`0002Gooooo0_l0000Looooo`;o00001oooool3
o`0001;ooooo0_l000000ooooooo0000o`00000Dooooo`Co00002Oooool2o`0000;ooooo0_l0000k
ooooo`00:oooool2o`0001;ooooo0_l00005ooooo`;o00009_ooool2o`0002Cooooo0_l00002oooo
o`?o00000oooool2o`0002Gooooo0_l0000Looooo`;o00001oooool3o`0001;ooooo0_l000000ooo
oooo0000o`00000Dooooo`Co00002Oooool2o`0000;ooooo0_l0000kooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000;ooooo`;o00001_ooool2o`0000go
oooo0_l0000Gooooo`;o00000oooool3o`000008oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb
<S82o`0002;ooooo0_l00006ooooo`Co00002?ooool5o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00007ooooo`;o00006Ooo
ool2o`0000[ooooo1ol000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOoooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000_ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000cooooo1ol000001_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`0:ooooo`;o0000
1_ooool2o`0000gooooo0_l0000Gooooo`;o00000oooool2o`000003oooooomgMgOo<S8b00;ooooo
00CoMgMgoiRHV?ooooooV9RH0_l0000Rooooo`;o00001_ooool4o`0000Sooooo0_l000000ooooooo
0000ooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooooonHV9So
MgMgooooo`;o00001oooool2o`0001Wooooo0_l0000:ooooo`?o00000_ooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000;oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0000<ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00
:oooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo
00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`00000jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000C
ooooo`00:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400gooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool0
02_ooooo0_l00005ooooo`?o000000?oooooo`000?l000005Oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000005ooooo`Co00001_ooool3o`0000;ooooo0_l00002ooooo`05ogMgMol0003o0000
oiRHV?mgMgL01?ooool2o`0000Wooooo0_l0000Aooooo`;o00001?ooool2o`0000Gooooo0_l00005
ooooo`;o000000Coooooo`000?l0003o00000oooool00omgMgOoV9RHooooo`02o`0000?ooooo00Go
MgMgoiRHV?l0003o0000ogMgM`04ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002?ooool2o`00023o
oooo0_l00004ooooo`;o000000Go^[ZjoooooonHV9So410@ooooo`02o`000005ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooo
oooo00Cooooo0ol000000ooooooo0000o`00000Eooooo`;o00002?ooool2o`000003ooooool0003o
000000Gooooo1?l00006ooooo`Oo00000_ooool01Oo^k^ko0000o`000?lb<S;ok^k^00Cooooo0_l0
0009ooooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`000004oeEEEOl0
003o0000o`0000?ooooo00?ok^k^oc8b<_l000000_l00003ooooo`05onk^k_lb<S;o0000o`000?o^
k^h01?ooool2o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o00002_ooool2o`000003
ooooool0003o000000Cooooo00CoEEEEo`000?l0003ooooo0_l00002ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;o00002?ooool2o`00023ooooo0_l00004ooooo`;o000000Go410@
o`000?lQ8B7oc<c<ooooo`02o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00002
ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0
003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8b
olc<c0Gooooo000[ooooo`04o`000?oooooo0000o`0000[ooooo0_l0000<ooooo`Oo00000_ooool2
o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00001Oooool01Ol0003oooooo`000?l0
003ooooo00;o00001Oooool5o`0000cooooo00?o0000ooooooooool01Oooool3o`000004ooooool0
003o0000o`0000gooooo00Co0000oooooooooooooooo0_l00007ooooo`?o00002_ooool2o`000003
ooooool0003ooooo00?ooooo0_l00008ooooo`;o00001_ooool7o`000003ooooool0003o000000;o
00002?ooool00ol0003oooooooooo`05ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00002Oooool00ol0003oooooooooo`0;ooooo`;o00000_ooool2o`0000Wooooo00?o0000oooo
ooooool02Oooool3o`0000Kooooo0_l00005ooooo`Co00000oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Booooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0
oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`04o`000?ooooooooooooooo`;o0000
1?ooool2o`0000_ooooo0ol0000<ooooo`Oo00001?ooool2o`0000;ooooo0_l0000Aooooo`;o0000
4_ooool2o`0000?ooooo0_l00009ooooo`;o00004?ooool2o`0000?ooooo0_l00005ooooo`?o0000
1?ooool2o`000003ooooool0003o000000cooooo0_l0000Aooooo`;o00001?ooool2o`0001gooooo
0_l00003ooooo`?o00004_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000
o`000003ooooo`;o00009_ooool2o`0000Sooooo000[ooooo`;o00000_ooool2o`0000Cooooo0_l0
000;ooooo`?o00003?ooool7o`0000Cooooo0_l00002ooooo`;o00004Oooool2o`0001;ooooo0_l0
0003ooooo`;o00002Oooool2o`00013ooooo0_l00003ooooo`;o00001Oooool3o`0000Cooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00004Oooool2o`0000Cooooo0_l0000Mooooo`;o00000ooo
ool3o`0001;ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000ooo
ool2o`00033ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0ol00002ooooo`;o00002_ooool2o`0000Kooooo0_l0
000Gooooo`;o00001oooool2o`0001?ooooo0_l00008ooooo`;o00002_ooool2o`0001Wooooo0_l0
000Jooooo`;o00001_ooool2o`0001Oooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000Sooooo0_l0000Aooooo`;o00002?ooool2o`00017ooooo0_l0000Tooooo`00:oooool3
o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`0001Oooooo0_l00007ooooo`;o00004oooool2
o`0000Sooooo0_l0000:ooooo`;o00006Oooool2o`0001[ooooo0_l00006ooooo`;o00005oooool2
o`0001Gooooo0_l000000ooooooo0000o`000002ooooo`?o00002?ooool2o`00017ooooo0_l00008
ooooo`;o00004Oooool2o`0002Cooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`0000gooooo0_l0000Xooooo`;o00006?ooool2o`000004ooooool0003o0000
ooooo`;o00003?ooool2o`0000_ooooo0_l0000Hooooo`;o00000_ooool2o`0000Cooooo0_l0000B
ooooo`;o00001?ooool2o`00037ooooo0_l0000<ooooo`;o00008?ooool2o`0000Oooooo0_l0000M
ooooo`00:oooool00ol0003oooooooooo`0<ooooo`;o0000:?ooool2o`0001Sooooo0_l000001?oo
oooo0000o`000?ooool2o`0000cooooo0_l0000;ooooo`;o00006?ooool2o`0000;ooooo0_l00004
ooooo`;o00004_ooool2o`0000Cooooo0_l0000aooooo`;o00003?ooool2o`00023ooooo0_l00007
ooooo`;o00007Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`0006;ooooo0_l0001@ooooo`;o00001?ooool2
o`0003oooooo0_l0000nooooo`00:oooool00ol0003oooooooooo`1Qooooo`;o0000D?ooool2o`00
00Cooooo0_l0000oooooo`;o0000?_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`?o00003oooool2o`0003_ooooo0_l0003/ooooo`006oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0?ooooo`;o0000>oooool2o`00
0>cooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0E?ooool2o`000;Co
oooo0_l0000^ooooo`00:oooool2o`0005Gooooo0_l0002dooooo`;o0000;_ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3ooooo
odCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o0000
0_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b
<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00oooooo1?l000002?l@413oooooooooooo<c<co8B4Q
o`000?lQ8B7oc<c<oooooolEooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo
00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo0000
00;ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@3o
oooooaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgo
ooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000oooooolEoooo
o`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMg
MoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000oooooooooooooooo
o`000002ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S80oooooolEooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Sooooooooo
ooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7
oooooonYZJWo000001Cooooo00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0003oc<c<
0?oooooo5Oooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03
ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@
0?oooooo5Oooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03Cooooo00?o0000
ooooooooool00_ooool01Ol0003o^[Zjoooooonj^[[o00000?oooooo5Oooool000oooooo00?o^[Zj
odA4A?ooool00_ooool00onYZJWoooooooooo`0aooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@3ooooooaGooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36052 Mdot
.03333 .31932 Mdot
.0381 .33992 Mdot
.04286 .33992 Mdot
.04762 .29872 Mdot
.05238 .27812 Mdot
.05714 .31932 Mdot
.0619 .29872 Mdot
.06667 .25751 Mdot
.07143 .31932 Mdot
.07619 .36052 Mdot
.08095 .36052 Mdot
.08571 .42232 Mdot
.09048 .25751 Mdot
.09524 .27812 Mdot
.1 .33992 Mdot
.10476 .31932 Mdot
.10952 .33992 Mdot
.11429 .25751 Mdot
.11905 .29872 Mdot
.12381 .29872 Mdot
.12857 .31932 Mdot
.13333 .29872 Mdot
.1381 .29872 Mdot
.14286 .27812 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .31932 Mdot
.1619 .31932 Mdot
.16667 .33992 Mdot
.17143 .29872 Mdot
.17619 .31932 Mdot
.18095 .29872 Mdot
.18571 .31932 Mdot
.19048 .36052 Mdot
.19524 .29872 Mdot
.2 .33992 Mdot
.20476 .29872 Mdot
.20952 .27812 Mdot
.21429 .36052 Mdot
.21905 .36052 Mdot
.22381 .31932 Mdot
.22857 .25751 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .27812 Mdot
.24762 .25751 Mdot
.25238 .29872 Mdot
.25714 .31932 Mdot
.2619 .31932 Mdot
.26667 .29872 Mdot
.27143 .27812 Mdot
.27619 .19571 Mdot
.28095 .25751 Mdot
.28571 .42232 Mdot
.29048 .36052 Mdot
.29524 .27812 Mdot
.3 .38112 Mdot
.30476 .19571 Mdot
.30952 .38112 Mdot
.31429 .44292 Mdot
.31905 .36052 Mdot
.32381 .33992 Mdot
.32857 .31932 Mdot
.33333 .27812 Mdot
.3381 .29872 Mdot
.34286 .29872 Mdot
.34762 .33992 Mdot
.35238 .29872 Mdot
.35714 .40172 Mdot
.3619 .36052 Mdot
.36667 .38112 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .33992 Mdot
.38571 .23691 Mdot
.39048 .23691 Mdot
.39524 .27812 Mdot
.4 .25751 Mdot
.40476 .23691 Mdot
.40952 .36052 Mdot
.41429 .29872 Mdot
.41905 .29872 Mdot
.42381 .25751 Mdot
.42857 .21631 Mdot
.43333 .25751 Mdot
.4381 .29872 Mdot
.44286 .31932 Mdot
.44762 .31932 Mdot
.45238 .33992 Mdot
.45714 .33992 Mdot
.4619 .27812 Mdot
.46667 .25751 Mdot
.47143 .29872 Mdot
.47619 .27812 Mdot
.48095 .33992 Mdot
.48571 .33992 Mdot
.49048 .31932 Mdot
.49524 .36052 Mdot
.5 .29872 Mdot
.50476 .31932 Mdot
.50952 .38112 Mdot
.51429 .31932 Mdot
.51905 .29872 Mdot
.52381 .29872 Mdot
.52857 .38112 Mdot
.53333 .23691 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .27812 Mdot
.55238 .31932 Mdot
.55714 .27812 Mdot
.5619 .31932 Mdot
.56667 .27812 Mdot
.57143 .36052 Mdot
.57619 .29872 Mdot
.58095 .19571 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .36052 Mdot
.6 .23691 Mdot
.60476 .29872 Mdot
.60952 .29872 Mdot
.61429 .36052 Mdot
.61905 .29872 Mdot
.62381 .33992 Mdot
.62857 .38112 Mdot
.63333 .23691 Mdot
.6381 .29872 Mdot
.64286 .31932 Mdot
.64762 .38112 Mdot
.65238 .36052 Mdot
.65714 .27812 Mdot
.6619 .25751 Mdot
.66667 .23691 Mdot
.67143 .31932 Mdot
.67619 .27812 Mdot
.68095 .31932 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .25751 Mdot
.7 .25751 Mdot
.70476 .29872 Mdot
.70952 .27812 Mdot
.71429 .21631 Mdot
.71905 .29872 Mdot
.72381 .21631 Mdot
.72857 .36052 Mdot
.73333 .23691 Mdot
.7381 .36052 Mdot
.74286 .25751 Mdot
.74762 .33992 Mdot
.75238 .36052 Mdot
.75714 .36052 Mdot
.7619 .31932 Mdot
.76667 .31932 Mdot
.77143 .29872 Mdot
.77619 .19571 Mdot
.78095 .38112 Mdot
.78571 .29872 Mdot
.79048 .33992 Mdot
.79524 .25751 Mdot
.8 .29872 Mdot
.80476 .29872 Mdot
.80952 .19571 Mdot
.81429 .25751 Mdot
.81905 .23691 Mdot
.82381 .23691 Mdot
.82857 .38112 Mdot
.83333 .33992 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .27812 Mdot
.85238 .36052 Mdot
.85714 .23691 Mdot
.8619 .40172 Mdot
.86667 .25751 Mdot
.87143 .25751 Mdot
.87619 .29872 Mdot
.88095 .31932 Mdot
.88571 .36052 Mdot
.89048 .33992 Mdot
.89524 .25751 Mdot
.9 .23691 Mdot
.90476 .29872 Mdot
.90952 .33992 Mdot
.91429 .44292 Mdot
.91905 .27812 Mdot
.92381 .19571 Mdot
.92857 .29872 Mdot
.93333 .31932 Mdot
.9381 .27812 Mdot
.94286 .36052 Mdot
.94762 .36052 Mdot
.95238 .31932 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .36052 Mdot
.97619 .29872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`19ooooo`;o00001oooool2
o`00057ooooo0_l0000iooooo`;o00002?ooool2o`00027ooooo0_l0000[ooooo`006Oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo04Wooooo
0_l00007ooooo`;o0000DOooool2o`0003Wooooo0_l00008ooooo`;o00008Oooool2o`0002_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool0013ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o0000oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0Moooool2o`0005Cooooo0_l000000ooooooo0000
o`00001Xooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`1gooooo`;o0000E?ooool2o`000003ooooool0003o000006Sooooo
000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`1Vooooo`?o000000Coooooo`000?l0003o00000oooool2o`0002Gooooo0_l0000Boooo
o`;o00002?ooool2o`0000Sooooo0_l0000Booooo`;o00006?ooool3o`0000Wooooo0_l0000;oooo
o`;o0000<_ooool002_ooooo00?o0000ooooooooool0I_ooool3o`000004ooooool0003o0000o`00
00?ooooo0_l0000Uooooo`;o00004_ooool2o`0000Sooooo0_l00008ooooo`;o00004_ooool2o`00
01Sooooo0ol00009ooooo`;o00002oooool2o`0003;ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0:oooo
o`;o00001Oooool2o`0000Gooooo0_l0000Pooooo`;o00001?ooool2o`0000Sooooo0_l0000Roooo
o`;o00001_ooool4o`0000Sooooo0_l0000jooooo`;o00002?ooool3o`0000_ooooo0_l0000>oooo
o`;o00001?ooool2o`0000gooooo1?l00005ooooo`;o0000=?ooool002_ooooo00?o0000oooooooo
ool02_ooool2o`0000Gooooo0_l00005ooooo`;o00008?ooool2o`0000Cooooo0_l00008ooooo`;o
00008_ooool2o`0000Kooooo1?l00008ooooo`;o0000>_ooool2o`0000Sooooo0ol0000;ooooo`;o
00003_ooool2o`0000Cooooo0_l0000=ooooo`Co00001Oooool2o`0003Cooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgM
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003ooooooooo
o`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000ooooooooool0@ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400foooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0b
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41004oooool002_ooooo00?o0000ooooooooool01Oooool2o`0000_ooooo0_l0
000=ooooo`;o00004_ooool2o`0000Sooooo0_l000000oooooooMgMgoc8b<P02ooooo`?o000000?o
ooooo`000?ooool00oooool2o`0000Wooooo0_l0000Aooooo`;o00004_ooool2o`0000;ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooooooooooooooo0000oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Iooooo`;o00001?ooool2
o`000003ooooool0003o000000Gooooo0_l00008ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?l000004oooool2o`0000Cooooo0_l0
00001?ooooooV9RHob4Q8Oo^k^h4o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo017ooooo000[ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`;o0000
3Oooool2o`0001;ooooo0_l00008ooooo`?o000000Co<S8bolc<c?oooooooooo0ol000000ooooooo
0000ooooo`03ooooo`;o00002Oooool2o`00017ooooo0_l0000Booooo`;o00000_ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooooooool0003ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000001Wooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000005?ooool2o`000003ooooool0003o000001?ooooo0_l00004oooo
o`;o00000_ooool00omgMgOoIVIVo`000003o`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo017ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03Oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0Aooooo`00:oooool2o`00043ooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo03oooooo1?l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0>?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001Oooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00Cooooo0_l00002
ooooo`;o00003oooool4o`000004ooooool0003o0000o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001oooool3o`0000?ooooo0_l00002ooooo`;o00005?oo
ool3o`000003ooooool0003o0000017ooooo0ol00004ooooo`;o00002?ooool2o`0000Oooooo0_l0
0003ooooo`Co00003_ooool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000000ooo
ool2o`0000kooooo0_l00002ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o00000_oo
ool4o`0001?ooooo0_l00007ooooo`;o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`00
000Kooooo`00:oooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0000oooooo1?l00000
1?oooooo0000o`000?l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000Oooooo0ol00003ooooo`;o00000_ooool2o`0001Cooooo0ol000000ooooooo0000o`00
000Aooooo`?o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00000oooool4o`0000kooooo0_l0
0002ooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo1?l0000Cooooo`;o00001ooo
ool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo00?o
410@o`000?l000000oooool002_ooooo00?o0000ooooooooool0oooooolbooooo`05o`000?oooooo
k^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`0000cooooo00Co0000oiRHV?lb<S;oc<c<1Ooo
ool002_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000oa0@4?nHV9P01_ooool002_ooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Aooooo`04o`000?o^k^koEEEEohN7Q`Gooooo000[ooooo`04o`000?oooooo0000
o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`Ko00000oooool2
o`000003ooooool0003o000000Wooooo0_l00008ooooo`Co00004_ooool2o`00023ooooo1?l0000;
ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000005
ooooo`;o00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Gooooo`?o00005Oooool2
o`0000[ooooo0_l0000>ooooo`;o00000oooool2o`0001[ooooo00Go0000oooooom4A4Co0000oa0@
4004ooooo`00:oooool01?l0003oooooo`000?l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0
0005ooooo`;o00001?ooool6o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?oo
ool4o`0001;ooooo0_l0000Pooooo`Co00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0009ooooo`;o000000?oooooo`000?l000001Oooool2o`00013ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000005oooool3o`0001Gooooo0_l0000:ooooo`;o00003_ooool2o`0000?ooooo0_l0
000Jooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool0
0ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00008oooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool01?l0003oooooooooooooool3o`00013ooooo1?l0000@ooooo`;o00002?ooool2o`0002?ooooo
0_l00005ooooo`;o00002Oooool2o`0001?ooooo1?l00005ooooo`?o00004?ooool2o`0001Kooooo
0_l0000Sooooo`;o00002oooool2o`0000_ooooo0_l0000@ooooo`;o00000oooool2o`00033ooooo
000[ooooo`04o`000?ooooooooooooooo`?o00004?ooool4o`00013ooooo0_l00008ooooo`;o0000
8oooool2o`0000Gooooo0_l00009ooooo`;o00004oooool4o`0000Gooooo0ol0000@ooooo`;o0000
5_ooool2o`0002?ooooo0_l0000;ooooo`;o00002oooool2o`00013ooooo0_l00003ooooo`;o0000
<?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0ol0000<ooooo`Co00007ooo
ool2o`0000Gooooo1?l0000Cooooo`;o00001oooool2o`0000_ooooo0_l0000<ooooo`;o00006?oo
ool2o`0001Gooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000000_ooool3o`0001_ooooo0_l00008ooooo`;o00003oooool4o`0000Gooooo0_l0
000Mooooo`00:oooool3o`0000cooooo1?l0000Oooooo`;o00001Oooool4o`0001?ooooo0_l00007
ooooo`;o00002oooool2o`0000cooooo0_l0000Hooooo`;o00005Oooool2o`0000Gooooo0_l00004
ooooo`;o00002_ooool2o`0001Gooooo0_l000000ooooooo0000o`000002ooooo`?o00006oooool2
o`0000Sooooo0_l0000?ooooo`Co00001Oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1@
ooooo`;o000000?oooooo`000?l000003oooool2o`0002Wooooo0_l00004ooooo`;o00007?ooool2
o`0000Cooooo0_l0000Wooooo`;o00003?ooool2o`0004Sooooo000[ooooo`03o`000?oooooooooo
053ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000:Oooool2o`0000Cooooo0_l0000Loooo
o`;o00001?ooool2o`0002Oooooo0_l0000<ooooo`;o0000B?ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
067ooooo0_l0002Gooooo`;o0000?_ooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`1Qooooo`;o0000Uoooool2o`0003kooooo000K
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooo
oolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`0?ooooo`;o0000>oooool2o`000>cooooo000Kooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo0_l0
000kooooo`;o0000k?ooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0E?oo
ool2o`000;Cooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`1Dooooo`;o0000]?ooool2
o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooocco
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo
??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`3ooooooc_ooooo000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Kooooo`03
ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0?oooooo>oooool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0
01Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0
01cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolkooooo`006oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`000?oooooo>oooool001[ooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo00000?ooooooA?ooool001_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@
413ooooooooooooooooo410@0?ooooooA?ooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooom4ooooo`006?ooool01OnYZJWo410@o`000?l@
413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj
^[[ooooo0?ooooooA?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool0
00?ooooo0_l00002ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o0000
00?o000000?o<S8booooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03oooool4o`000007oa0@4?oooooo
oooooa0@4?l0003oA4A4olc<c03ooooooaKooooo0003ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?ooooo00[oA4A4oiRHV?ooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@400<ooooo`05o`000?oooooooooo
ooooool000000_ooool6o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So410@omgMg@3o
oooooaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgo
ooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`05ooooo`03ohN7QomEEEGooooo0?oooooo5?ooool000Cooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02ooooo`05ohN7QomgMgOoooooofIV
I_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?ooooooooooooooool000000_oo
ool6o`0000cooooo00?o0000ooooooooool00_ooool01Oo<c<co8B4Qo`000?mEEEGo00000?oooooo
5Oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@
4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVY
o`00000Dooooo`03o`000?oooooooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`00003ooooooaGo
oooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4Q
oeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00003ooooooaGo
oooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0dooooo`03o`000?oooooooooo
00;ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@3ooooooaGooooo000?ooooo`03okZj^_m4A4Cooooo
00;ooooo00?oZJVYooooooooool0<Oooool00omEEEGoIVIVo`000004ooooo`05olc<c?l@413o0000
oc8b<_o^k^h0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .37082 Mdot
.03333 .32962 Mdot
.0381 .35022 Mdot
.04286 .32962 Mdot
.04762 .28842 Mdot
.05238 .28842 Mdot
.05714 .32962 Mdot
.0619 .28842 Mdot
.06667 .26781 Mdot
.07143 .30902 Mdot
.07619 .35022 Mdot
.08095 .37082 Mdot
.08571 .41202 Mdot
.09048 .26781 Mdot
.09524 .26781 Mdot
.1 .32962 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .24721 Mdot
.11905 .28842 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .28842 Mdot
.14286 .26781 Mdot
.14762 .30902 Mdot
.15238 .32962 Mdot
.15714 .30902 Mdot
.1619 .30902 Mdot
.16667 .35022 Mdot
.17143 .28842 Mdot
.17619 .30902 Mdot
.18095 .30902 Mdot
.18571 .32962 Mdot
.19048 .37082 Mdot
.19524 .30902 Mdot
.2 .32962 Mdot
.20476 .30902 Mdot
.20952 .26781 Mdot
.21429 .37082 Mdot
.21905 .35022 Mdot
.22381 .30902 Mdot
.22857 .24721 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .28842 Mdot
.24762 .24721 Mdot
.25238 .30902 Mdot
.25714 .32962 Mdot
.2619 .30902 Mdot
.26667 .28842 Mdot
.27143 .28842 Mdot
.27619 .20601 Mdot
.28095 .24721 Mdot
.28571 .41202 Mdot
.29048 .37082 Mdot
.29524 .26781 Mdot
.3 .39142 Mdot
.30476 .20601 Mdot
.30952 .37082 Mdot
.31429 .43262 Mdot
.31905 .37082 Mdot
.32381 .35022 Mdot
.32857 .32962 Mdot
.33333 .28842 Mdot
.3381 .30902 Mdot
.34286 .28842 Mdot
.34762 .32962 Mdot
.35238 .30902 Mdot
.35714 .39142 Mdot
.3619 .35022 Mdot
.36667 .37082 Mdot
.37143 .22661 Mdot
.37619 .22661 Mdot
.38095 .35022 Mdot
.38571 .22661 Mdot
.39048 .24721 Mdot
.39524 .28842 Mdot
.4 .26781 Mdot
.40476 .22661 Mdot
.40952 .37082 Mdot
.41429 .30902 Mdot
.41905 .28842 Mdot
.42381 .26781 Mdot
.42857 .20601 Mdot
.43333 .26781 Mdot
.4381 .28842 Mdot
.44286 .30902 Mdot
.44762 .30902 Mdot
.45238 .32962 Mdot
.45714 .32962 Mdot
.4619 .26781 Mdot
.46667 .26781 Mdot
.47143 .30902 Mdot
.47619 .28842 Mdot
.48095 .35022 Mdot
.48571 .32962 Mdot
.49048 .30902 Mdot
.49524 .37082 Mdot
.5 .30902 Mdot
.50476 .32962 Mdot
.50952 .39142 Mdot
.51429 .30902 Mdot
.51905 .28842 Mdot
.52381 .30902 Mdot
.52857 .37082 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .35022 Mdot
.54762 .28842 Mdot
.55238 .32962 Mdot
.55714 .26781 Mdot
.5619 .32962 Mdot
.56667 .26781 Mdot
.57143 .37082 Mdot
.57619 .28842 Mdot
.58095 .20601 Mdot
.58571 .30902 Mdot
.59048 .28842 Mdot
.59524 .35022 Mdot
.6 .24721 Mdot
.60476 .28842 Mdot
.60952 .30902 Mdot
.61429 .35022 Mdot
.61905 .30902 Mdot
.62381 .32962 Mdot
.62857 .37082 Mdot
.63333 .22661 Mdot
.6381 .28842 Mdot
.64286 .30902 Mdot
.64762 .39142 Mdot
.65238 .35022 Mdot
.65714 .28842 Mdot
.6619 .26781 Mdot
.66667 .22661 Mdot
.67143 .32962 Mdot
.67619 .26781 Mdot
.68095 .32962 Mdot
.68571 .26781 Mdot
.69048 .28842 Mdot
.69524 .24721 Mdot
.7 .26781 Mdot
.70476 .28842 Mdot
.70952 .26781 Mdot
.71429 .22661 Mdot
.71905 .28842 Mdot
.72381 .20601 Mdot
.72857 .37082 Mdot
.73333 .24721 Mdot
.7381 .35022 Mdot
.74286 .24721 Mdot
.74762 .32962 Mdot
.75238 .37082 Mdot
.75714 .35022 Mdot
.7619 .32962 Mdot
.76667 .30902 Mdot
.77143 .30902 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .35022 Mdot
.79524 .24721 Mdot
.8 .28842 Mdot
.80476 .30902 Mdot
.80952 .18541 Mdot
.81429 .26781 Mdot
.81905 .24721 Mdot
.82381 .24721 Mdot
.82857 .39142 Mdot
.83333 .32962 Mdot
.8381 .26781 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .37082 Mdot
.85714 .22661 Mdot
.8619 .39142 Mdot
.86667 .26781 Mdot
.87143 .24721 Mdot
.87619 .30902 Mdot
.88095 .30902 Mdot
.88571 .37082 Mdot
.89048 .32962 Mdot
.89524 .26781 Mdot
.9 .22661 Mdot
.90476 .30902 Mdot
.90952 .32962 Mdot
.91429 .45322 Mdot
.91905 .28842 Mdot
.92381 .20601 Mdot
.92857 .30902 Mdot
.93333 .32962 Mdot
.9381 .26781 Mdot
.94286 .37082 Mdot
.94762 .35022 Mdot
.95238 .30902 Mdot
.95714 .28842 Mdot
.9619 .26781 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .28842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003Qooooo`;o00002?ooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0>3ooooo
0_l00008ooooo`;o0000C_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`0004Wooooo0_l00007ooooo`;o00008oooool2o`0002cooooo0_l0000Yooooo`;o0000
>oooool2o`0002_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o00008oooool2o`0002cooooo
0_l0000Yooooo`;o0000>oooool2o`0002_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
001Wooooo`?o000000?oooooo`000?l000001?ooool2o`0002Gooooo0_l0000Looooo`;o00002?oo
ool2o`0000cooooo0_l0000Zooooo`;o00002oooool2o`0003;ooooo000[ooooo`03o`000?oooooo
oooo06Kooooo0ol000000ooooooo0000o`000004ooooo`;o00009Oooool2o`0001cooooo0_l00008
ooooo`;o00003?ooool2o`0002[ooooo0_l0000;ooooo`;o0000<_ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`0Hooooo`;o00008?ooool2o`0000Cooooo0_l00008ooooo`;o00007oooool2
o`0003kooooo0_l0000Kooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo0_l00005
ooooo`?o00003Oooool2o`0003_ooooo000[ooooo`;o00006Oooool2o`00023ooooo0_l00004oooo
o`;o00002?ooool2o`0001oooooo0_l0000nooooo`;o00006oooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000>ooooo`;o00001Oooool3o`0000gooooo0_l0000kooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000;ooooo`;o00001Oooool3o`0000go
oooo0_l0000Booooo`;o00002?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`;o00007Oooool2o`0000Kooooo1?l00007ooooo`Ko000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Kooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo1_l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOoooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool2o`0000Gooooo0_l000000ooooooo0000o`000003oooo
o`;o00001oooool2o`0000_ooooo1_l000002?oooooo0000o`000?o^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo00[ooooo
0_l00005ooooo`?o00003Oooool2o`0001;ooooo0_l0000;ooooo`09ogMgMolb<S;ooooooooooomg
MgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0000Mooooo`;o00001_ooool4o`0000Oooooo0ol00000
0ooooooo0000ooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooo
oonHV9SoMgMgooooo`;o00001?ooool2o`000003ooooool0003o000001_ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL03Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001oooool2o`0000_ooooo0_l000001OlQ8B7ok^k^oooooom4A4Cooooo00;o0000
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_o
oooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooooooo
ool0@_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000003Kooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo
00?o0000ooooooooool0<oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oo
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000>_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000003Kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100>_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05
oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000[ooooo`;o00001Oooool3
o`000003ooooool0003o000000oooooo0_l00004ooooo`;o00002?ooool2o`00017ooooo1Ol00005
ooooo`?o000000?oV9RHogMgMoooool03_ooool2o`000003ooooool0003o000000kooooo0_l00005
ooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool2o`000003oooooonHV9SoMgMg00Cooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0
0008ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_l0
0002ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000
8_ooool2o`0000Gooooo00Go0000okZj^_ooooooV9RHoa0@4002o`000004ooooool0003o0000oooo
o`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo
00Cooooo0ol000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0000Sooooo0_l0000Aoooo
o`Oo00000oooool3o`000003oc8b<_o^k^kooooo00kooooo0_l000000ooooooo0000o`00000>oooo
o`;o00001Oooool2o`0000Cooooo0_l00007ooooo`04oeEEEOmVIVKo0000o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^k_ooool00oooool2o`0000Oooooo0_l0
0002ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l0
00000omVIVKo0000ooooo`02o`0000;ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool2o`0002;ooooo0_l00005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_l000000ooooooo
0000o`000003o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:oooool0
0ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?oooooo
o`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003oooooooooo`0;
ooooo`;o00003Oooool6o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00007ooooo`;o000000?o
ooooo`000?l000003Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool3o`0000gooooo00?o
0000ooooooooool00_l00006ooooo`Go00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001_ooool00ol0003oooooooooo`07ooooo`;o00000_oo
ool01?l0003oooooooooooooool2o`000003ooooool0003o000000Gooooo0_l0000=ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool4o`0000;ooooo0_l00004ooooo`;o0000
1oooool00ol0003oooooooooo`09ooooo`Co00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000
1_ooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000
ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`05o`000?oooooo0000
o`000?ooool00_l00003ooooo`;o00002oooool3o`0000cooooo0_l00009ooooo`;o00000_ooool2
o`0000oooooo0_l0000Dooooo`;o00000oooool2o`0001kooooo1?l00006ooooo`;o00001?ooool2
o`0000cooooo0_l000000ooooooo0000o`00000Aooooo`;o00003?ooool2o`000003ooooool0003o
000001;ooooo0_l00003ooooo`;o00004oooool2o`000003ooooool0003o000000gooooo0_l00003
ooooo`;o00001_ooool2o`0001kooooo0_l00008ooooo`00:oooool4o`000003ooooool0003o0000
00?ooooo0_l0000;ooooo`?o00003?ooool2o`0000Wooooo0_l00002ooooo`;o00003oooool2o`00
01Cooooo0_l00003ooooo`;o00007_ooool4o`0000Kooooo0_l00004ooooo`;o00003?ooool2o`00
0003ooooool0003o0000017ooooo0_l0000<ooooo`;o000000?oooooo`000?l000004_ooool2o`00
00?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00006oooo
o`;o0000:?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool01?l0003oooooooooooooool2o`0000Wooooo0_l00008
ooooo`;o00004?ooool2o`0000kooooo0_l0000Mooooo`;o00002_ooool2o`0000Cooooo0_l0000L
ooooo`;o00004Oooool2o`0000gooooo0_l00004ooooo`;o00002_ooool2o`0001Sooooo0_l00003
ooooo`;o00002?ooool2o`0002kooooo0_l0000Tooooo`00:oooool2o`0000;ooooo0_l00009oooo
o`;o00002?ooool2o`00013ooooo0_l0000>ooooo`;o00007Oooool2o`0000[ooooo0_l00004oooo
o`;o00007?ooool2o`00017ooooo0_l0000=ooooo`;o00001?ooool2o`0000[ooooo0_l0000Hoooo
o`;o00000oooool2o`0000Sooooo0_l0000^ooooo`;o00009?ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`?o00003_ooool2o`0001oooooo0_l00005ooooo`;o
00005Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00002oooool2o`0001So
oooo0_l00008ooooo`;o00002oooool2o`0000oooooo0_l0000Mooooo`;o00001Oooool2o`0001co
oooo0_l00008ooooo`;o00003oooool2o`0000Oooooo0_l0000Mooooo`00:oooool3o`0000kooooo
0_l0000Oooooo`;o00001Oooool2o`0001Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000_ooooo0_l0000Hooooo`;o00002?ooool2o`0000_ooooo0_l0000?ooooo`;o0000
7Oooool2o`0000Gooooo0_l0000Looooo`;o00002?ooool2o`0000oooooo0_l00007ooooo`;o0000
7Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool2o`00057ooooo0_l0000?ooooo`;o0000;?ooool2o`0002Sooooo
0_l0000Wooooo`;o00003?ooool2o`0000Sooooo0_l0000nooooo`00:oooool00ol0003ooooooooo
o`1@ooooo`;o00003oooool2o`0002cooooo0_l0000Xooooo`;o00009oooool2o`0000cooooo0_l0
0008ooooo`;o0000?_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000K
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00003ooo
ool2o`0003_ooooo0_l0003/ooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0?ooooo`;o0000>oooool2o`000>cooooo000K
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000I
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0E?ooool2o`000>Cooooo000[oooo
o`;o0000EOooool2o`000>Cooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo3?ooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo
2oooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooocco
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo
??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool0
01_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003o
oooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003o
ooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403o
ooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<
ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`00
00?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo
00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolEooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooo
oooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;o
oooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo5Ooo
ool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgM
oa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@403ooooooaGooooo0004oooo
o`04onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomV
IVKoQhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;o
oooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00003ooooo
oaGooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@
413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVY
ZOl000005?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000oooooolE
ooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q
8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool04oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0oooooolC
ooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<Oooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooooaGooooo000?ooooo`03okZj
^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP3ooooooaGooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36052 Mdot
.03333 .33992 Mdot
.0381 .33992 Mdot
.04286 .31932 Mdot
.04762 .27812 Mdot
.05238 .27812 Mdot
.05714 .31932 Mdot
.0619 .27812 Mdot
.06667 .25751 Mdot
.07143 .31932 Mdot
.07619 .33992 Mdot
.08095 .36052 Mdot
.08571 .42232 Mdot
.09048 .25751 Mdot
.09524 .27812 Mdot
.1 .31932 Mdot
.10476 .31932 Mdot
.10952 .33992 Mdot
.11429 .25751 Mdot
.11905 .29872 Mdot
.12381 .29872 Mdot
.12857 .31932 Mdot
.13333 .31932 Mdot
.1381 .27812 Mdot
.14286 .25751 Mdot
.14762 .29872 Mdot
.15238 .31932 Mdot
.15714 .29872 Mdot
.1619 .29872 Mdot
.16667 .33992 Mdot
.17143 .29872 Mdot
.17619 .31932 Mdot
.18095 .29872 Mdot
.18571 .33992 Mdot
.19048 .38112 Mdot
.19524 .29872 Mdot
.2 .31932 Mdot
.20476 .29872 Mdot
.20952 .25751 Mdot
.21429 .38112 Mdot
.21905 .36052 Mdot
.22381 .31932 Mdot
.22857 .23691 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .27812 Mdot
.24762 .25751 Mdot
.25238 .31932 Mdot
.25714 .31932 Mdot
.2619 .29872 Mdot
.26667 .29872 Mdot
.27143 .27812 Mdot
.27619 .21631 Mdot
.28095 .25751 Mdot
.28571 .40172 Mdot
.29048 .36052 Mdot
.29524 .25751 Mdot
.3 .40172 Mdot
.30476 .21631 Mdot
.30952 .38112 Mdot
.31429 .42232 Mdot
.31905 .38112 Mdot
.32381 .36052 Mdot
.32857 .33992 Mdot
.33333 .29872 Mdot
.3381 .29872 Mdot
.34286 .27812 Mdot
.34762 .33992 Mdot
.35238 .29872 Mdot
.35714 .40172 Mdot
.3619 .33992 Mdot
.36667 .36052 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .36052 Mdot
.38571 .21631 Mdot
.39048 .23691 Mdot
.39524 .29872 Mdot
.4 .27812 Mdot
.40476 .23691 Mdot
.40952 .36052 Mdot
.41429 .29872 Mdot
.41905 .29872 Mdot
.42381 .27812 Mdot
.42857 .19571 Mdot
.43333 .25751 Mdot
.4381 .29872 Mdot
.44286 .31932 Mdot
.44762 .31932 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .27812 Mdot
.46667 .27812 Mdot
.47143 .31932 Mdot
.47619 .27812 Mdot
.48095 .36052 Mdot
.48571 .31932 Mdot
.49048 .31932 Mdot
.49524 .36052 Mdot
.5 .29872 Mdot
.50476 .33992 Mdot
.50952 .40172 Mdot
.51429 .29872 Mdot
.51905 .27812 Mdot
.52381 .31932 Mdot
.52857 .36052 Mdot
.53333 .21631 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .29872 Mdot
.55238 .31932 Mdot
.55714 .25751 Mdot
.5619 .31932 Mdot
.56667 .25751 Mdot
.57143 .36052 Mdot
.57619 .29872 Mdot
.58095 .21631 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .25751 Mdot
.60476 .29872 Mdot
.60952 .31932 Mdot
.61429 .33992 Mdot
.61905 .31932 Mdot
.62381 .31932 Mdot
.62857 .38112 Mdot
.63333 .23691 Mdot
.6381 .29872 Mdot
.64286 .29872 Mdot
.64762 .38112 Mdot
.65238 .33992 Mdot
.65714 .27812 Mdot
.6619 .27812 Mdot
.66667 .21631 Mdot
.67143 .33992 Mdot
.67619 .27812 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .27812 Mdot
.69524 .25751 Mdot
.7 .25751 Mdot
.70476 .29872 Mdot
.70952 .25751 Mdot
.71429 .23691 Mdot
.71905 .27812 Mdot
.72381 .21631 Mdot
.72857 .38112 Mdot
.73333 .25751 Mdot
.7381 .33992 Mdot
.74286 .25751 Mdot
.74762 .33992 Mdot
.75238 .36052 Mdot
.75714 .33992 Mdot
.7619 .33992 Mdot
.76667 .31932 Mdot
.77143 .29872 Mdot
.77619 .19571 Mdot
.78095 .40172 Mdot
.78571 .29872 Mdot
.79048 .36052 Mdot
.79524 .23691 Mdot
.8 .29872 Mdot
.80476 .31932 Mdot
.80952 .19571 Mdot
.81429 .27812 Mdot
.81905 .25751 Mdot
.82381 .25751 Mdot
.82857 .40172 Mdot
.83333 .33992 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .25751 Mdot
.85238 .38112 Mdot
.85714 .23691 Mdot
.8619 .38112 Mdot
.86667 .25751 Mdot
.87143 .23691 Mdot
.87619 .29872 Mdot
.88095 .29872 Mdot
.88571 .38112 Mdot
.89048 .31932 Mdot
.89524 .27812 Mdot
.9 .21631 Mdot
.90476 .29872 Mdot
.90952 .33992 Mdot
.91429 .44292 Mdot
.91905 .29872 Mdot
.92381 .19571 Mdot
.92857 .29872 Mdot
.93333 .33992 Mdot
.9381 .27812 Mdot
.94286 .36052 Mdot
.94762 .36052 Mdot
.95238 .31932 Mdot
.95714 .29872 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .38112 Mdot
.97619 .27812 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1gooooo`;o0000Ioooool2
o`0000Sooooo0_l0000Qooooo`;o0000:oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`1gooooo`;o0000Ioooool2o`0000Sooooo
0_l0000Qooooo`;o0000:oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`19ooooo`;o0000
1oooool2o`0001Kooooo0_l0000[ooooo`;o00003?ooool2o`0001Sooooo0_l0000?ooooo`;o0000
=?ooool2o`0003;ooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o00005_ooool2o`0002_ooooo
0_l0000<ooooo`;o00006?ooool2o`0000oooooo0_l0000dooooo`;o0000<_ooool001Wooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo03[o
oooo0_l0000Zooooo`?o00000_ooool2o`0000?ooooo0_l00013ooooo`;o00005_ooool2o`0001Oo
oooo0_l0000Aooooo`;o00000_ooool2o`0003_ooooo000[ooooo`03o`000?oooooooooo03[ooooo
0_l0000Zooooo`?o00000_ooool2o`0000?ooooo0_l00013ooooo`;o00005_ooool2o`0001Oooooo
0_l0000Aooooo`;o00000_ooool2o`0003_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0:ooooo`;o0000
1Oooool2o`0000Gooooo0_l00007ooooo`;o00004_ooool2o`0000Wooooo0_l00008ooooo`;o0000
0oooool2o`0002Oooooo0_l0000Tooooo`;o000000?oooooo`000?l000002?ooool2o`0001_ooooo
0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000005Oooool3o`0000Kooooo
0_l00003ooooo`;o0000?Oooool002_ooooo00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001oooool2o`0001;ooooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l0
000Wooooo`;o00009?ooool2o`000003ooooool0003o000000Sooooo0_l0000Kooooo`?o000000?o
ooooo`000?l000001Oooool2o`000003ooooool0003o000001Gooooo0ol00006ooooo`;o00000ooo
ool2o`0003gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooo
ooooool01?ooool3o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o00007_ooool2o`00
0003oooooomgMgOo<S8b00;ooooo0ol000000ooooooo0000ooooo`0Aooooo`;o00003oooool2o`00
00Kooooo0_l00009ooooo`?o000000?oooooo`000?l000000oooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00002ooooo`04o`000?oooooo0000o`0002;ooooo1?l00002ooooo`;o000000Co
ooooo`000?l0003o00001Oooool01?l0003oooooo`000?l00005ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`0000oooooo0_l0000;oooo
o`;o000000GooooooiRHV?lQ8B7ok^k^ooooo`03o`0000;ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000004oooool002_ooooo00?o0000ooooooooool01?ooool3o`000003ooooool0003o
000000Sooooo0_l0000;ooooo`;o00007_ooool3o`000004oc8b<_o<c<coooooooooo`?o000000?o
ooooo`000?ooool04Oooool2o`0000oooooo0_l00006ooooo`;o00002Oooool3o`000003ooooool0
003o000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool01?l0003ooooo
o`000?l0000Rooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000Gooooo00Co0000oooo
ool0003o00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`;o00001Oooool2o`0000oooooo0_l0000;ooooo`;o00000_ooool00omgMgOoIVIV
ooooo`03o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000[ooooo`;o0000
@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000oooooooo
ool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool06Oooool4o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Oooooo0ol00006oooo
o`?o00004_ooool4o`0000;ooooo0_l0000;ooooo`;o00001?ooool3o`0000Cooooo0_l0000Aoooo
o`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00008oooo
o`Co00004?ooool2o`0001?ooooo0_l00002ooooo`;o00000_ooool2o`0001Gooooo1?l00005oooo
o`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000Noooo
o`00:oooool00ol0003oooooooooo`0Iooooo`Co00001Oooool2o`000005ooooool0003o0000o`00
0?ooool00_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001oooool3o`00
00Kooooo0ol0000Booooo`Co00000_ooool2o`0000_ooooo0_l00004ooooo`?o00001?ooool2o`00
017ooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`00
00Sooooo1?l0000@ooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o00005Oooool4o`00
00Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
01Cooooo0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04
o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00
:oooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`?o0000
1Oooool4o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00007ooooo`?o0000
=_ooool5o`0000Cooooo0_l00002ooooo`Co00002?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000005ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0002Wooooo0_l0000:ooooo`;o
00002Oooool2o`0000gooooo0_l0000@ooooo`;o00006_ooool01Ol0003oooooodA4A?l0003o410@
00Cooooo000[ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oo
oooo0ol00005ooooo`Co00000oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Oo
oooo0ol0000fooooo`Go00001?ooool2o`0000;ooooo1?l00008ooooo`;o00001_ooool2o`000003
ooooool0003o000000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000:Oooool2o`00
00[ooooo0_l00009ooooo`;o00003Oooool2o`00013ooooo0_l0000Jooooo`03o`000?oooooooooo
00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00
:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00008ooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooo`000003o`00
00Wooooo0_l00008ooooo`;o00004?ooool2o`0000Cooooo0_l0000Yooooo`;o00000oooool2o`00
00?ooooo0_l0000Kooooo`;o00003?ooool2o`0000[ooooo0_l0000=ooooo`;o00001?ooool2o`00
00[ooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool4o`000003ooooool0003o0000
00;o00004oooool2o`0001Gooooo0_l00006ooooo`;o0000:?ooool002_ooooo00?o0000ooooool0
00000ol00009ooooo`;o00002?ooool2o`00013ooooo0_l00004ooooo`;o0000:Oooool2o`0000?o
oooo0_l00003ooooo`;o00006oooool2o`0000cooooo0_l0000:ooooo`;o00003Oooool2o`0000Co
oooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo1?l000000ooooooo
0000o`000002o`0001?ooooo0_l0000Eooooo`;o00001_ooool2o`0002Sooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`?o00003_ooool2o`0002Sooooo0_l0000Cooooo`;o0000
2?ooool2o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0001Cooooo0_l00002ooooo`;o0000
2?ooool2o`0000_ooooo0_l0000eooooo`;o00002Oooool2o`0002cooooo1?l0000Tooooo`00:ooo
ool3o`0000kooooo0_l0000Xooooo`;o00004oooool2o`0000Sooooo0_l0000;ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000Dooooo`;o00000_ooool2o`0000Sooooo0_l0000;ooooo`;o0000=Ooo
ool2o`0000Wooooo0_l0000/ooooo`Co00009?ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo02oooooo0_l0
0005ooooo`;o00006oooool2o`000003ooooool0003o000005_ooooo0_l00004ooooo`;o00005ooo
ool2o`0002?ooooo0_l000000ooooooo0000o`000005ooooo`;o00006?ooool2o`0001gooooo000[
ooooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o00006oooool2o`000003ooooool0003o
000005_ooooo0_l00004ooooo`;o00005oooool2o`0002?ooooo0_l000000ooooooo0000o`000005
ooooo`;o00006?ooool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2
o`0000oooooo0_l0000/ooooo`;o0000DOooool2o`0000cooooo0_l00018ooooo`006Oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo04cooooo
0_l00002ooooo`;o00003oooool2o`0002cooooo0_l0001Aooooo`;o00003?ooool2o`0004Sooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`0?ooooo`;o0000@oooool2o`000>Cooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo
0_l00013ooooo`;o0000i?ooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
ooooool;ooooo`;o0000;_ooool002_ooooo00?o0000ooooooooool0ooooool;ooooo`;o0000;_oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo>oooool001_ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolk
ooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001So
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool00000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0
oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2
o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol00000
0olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`0>ooooo`Go00001?ooool4o`000003oa0@4?oo
oooooooo0?oooooo4_ooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`00
0?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zj
o`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolD
ooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooM
gMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooooaCooooo0004ooooo`04onk^
k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKoQhN7
00Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0
000;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooolDooooo`001?ooool0
1?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^
00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooooaCooooo0003ooooo`;o00000_ooool2
o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2
o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolDooooo`003oooool01omEEEGoV9RHoooooooooooo
gMgMo`000?oMgMd0<Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooolDooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo033ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`03oeEEEOmVIVKo00000?oooooo5_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .37082 Mdot
.03333 .35022 Mdot
.0381 .35022 Mdot
.04286 .32962 Mdot
.04762 .26781 Mdot
.05238 .26781 Mdot
.05714 .32962 Mdot
.0619 .28842 Mdot
.06667 .26781 Mdot
.07143 .32962 Mdot
.07619 .32962 Mdot
.08095 .37082 Mdot
.08571 .43262 Mdot
.09048 .26781 Mdot
.09524 .26781 Mdot
.1 .32962 Mdot
.10476 .30902 Mdot
.10952 .32962 Mdot
.11429 .24721 Mdot
.11905 .28842 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .32962 Mdot
.1381 .28842 Mdot
.14286 .24721 Mdot
.14762 .28842 Mdot
.15238 .32962 Mdot
.15714 .30902 Mdot
.1619 .30902 Mdot
.16667 .35022 Mdot
.17143 .30902 Mdot
.17619 .30902 Mdot
.18095 .30902 Mdot
.18571 .32962 Mdot
.19048 .37082 Mdot
.19524 .30902 Mdot
.2 .30902 Mdot
.20476 .28842 Mdot
.20952 .24721 Mdot
.21429 .39142 Mdot
.21905 .35022 Mdot
.22381 .32962 Mdot
.22857 .24721 Mdot
.23333 .28842 Mdot
.2381 .30902 Mdot
.24286 .26781 Mdot
.24762 .24721 Mdot
.25238 .32962 Mdot
.25714 .30902 Mdot
.2619 .28842 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .20601 Mdot
.28095 .24721 Mdot
.28571 .41202 Mdot
.29048 .35022 Mdot
.29524 .24721 Mdot
.3 .41202 Mdot
.30476 .22661 Mdot
.30952 .37082 Mdot
.31429 .43262 Mdot
.31905 .39142 Mdot
.32381 .37082 Mdot
.32857 .35022 Mdot
.33333 .30902 Mdot
.3381 .30902 Mdot
.34286 .26781 Mdot
.34762 .35022 Mdot
.35238 .28842 Mdot
.35714 .41202 Mdot
.3619 .35022 Mdot
.36667 .37082 Mdot
.37143 .22661 Mdot
.37619 .24721 Mdot
.38095 .35022 Mdot
.38571 .22661 Mdot
.39048 .22661 Mdot
.39524 .28842 Mdot
.4 .26781 Mdot
.40476 .22661 Mdot
.40952 .37082 Mdot
.41429 .28842 Mdot
.41905 .28842 Mdot
.42381 .28842 Mdot
.42857 .18541 Mdot
.43333 .24721 Mdot
.4381 .28842 Mdot
.44286 .32962 Mdot
.44762 .32962 Mdot
.45238 .30902 Mdot
.45714 .32962 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .32962 Mdot
.47619 .26781 Mdot
.48095 .37082 Mdot
.48571 .30902 Mdot
.49048 .30902 Mdot
.49524 .37082 Mdot
.5 .28842 Mdot
.50476 .32962 Mdot
.50952 .41202 Mdot
.51429 .28842 Mdot
.51905 .28842 Mdot
.52381 .30902 Mdot
.52857 .35022 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .35022 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .24721 Mdot
.5619 .32962 Mdot
.56667 .24721 Mdot
.57143 .37082 Mdot
.57619 .30902 Mdot
.58095 .20601 Mdot
.58571 .32962 Mdot
.59048 .30902 Mdot
.59524 .35022 Mdot
.6 .26781 Mdot
.60476 .28842 Mdot
.60952 .32962 Mdot
.61429 .35022 Mdot
.61905 .32962 Mdot
.62381 .32962 Mdot
.62857 .37082 Mdot
.63333 .22661 Mdot
.6381 .30902 Mdot
.64286 .28842 Mdot
.64762 .39142 Mdot
.65238 .35022 Mdot
.65714 .26781 Mdot
.6619 .26781 Mdot
.66667 .20601 Mdot
.67143 .32962 Mdot
.67619 .28842 Mdot
.68095 .35022 Mdot
.68571 .28842 Mdot
.69048 .28842 Mdot
.69524 .26781 Mdot
.7 .24721 Mdot
.70476 .28842 Mdot
.70952 .24721 Mdot
.71429 .24721 Mdot
.71905 .26781 Mdot
.72381 .20601 Mdot
.72857 .39142 Mdot
.73333 .24721 Mdot
.7381 .32962 Mdot
.74286 .24721 Mdot
.74762 .35022 Mdot
.75238 .35022 Mdot
.75714 .32962 Mdot
.7619 .32962 Mdot
.76667 .30902 Mdot
.77143 .30902 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .28842 Mdot
.79048 .37082 Mdot
.79524 .24721 Mdot
.8 .30902 Mdot
.80476 .32962 Mdot
.80952 .18541 Mdot
.81429 .26781 Mdot
.81905 .24721 Mdot
.82381 .26781 Mdot
.82857 .39142 Mdot
.83333 .32962 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .24721 Mdot
.85238 .39142 Mdot
.85714 .24721 Mdot
.8619 .39142 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .30902 Mdot
.88095 .28842 Mdot
.88571 .39142 Mdot
.89048 .30902 Mdot
.89524 .26781 Mdot
.9 .20601 Mdot
.90476 .28842 Mdot
.90952 .32962 Mdot
.91429 .45322 Mdot
.91905 .28842 Mdot
.92381 .18541 Mdot
.92857 .30902 Mdot
.93333 .32962 Mdot
.9381 .28842 Mdot
.94286 .37082 Mdot
.94762 .35022 Mdot
.95238 .32962 Mdot
.95714 .30902 Mdot
.9619 .28842 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .28842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0001hooooo`;o0000Ioooool2o`0000Sooooo0_l0000Qooooo`;o0000:oooool002_ooooo
00?o0000ooooooooool0Moooool2o`0006Oooooo0_l00008ooooo`;o00008Oooool2o`0002_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00019ooooo`;o0000
F_ooool2o`0001Sooooo0_l0000?ooooo`;o0000=?ooool2o`0003;ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04Wooooo
0_l0001Jooooo`;o00006?ooool2o`0000oooooo0_l0000dooooo`;o0000<_ooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`0005?ooooo0_l0000Booooo`;o00000_ooool3o`0000?ooooo0_l0
000Uooooo`;o00007?ooool2o`0004Kooooo0_l0000kooooo`00:oooool00ol0003oooooooooo`1B
ooooo`;o00004_ooool2o`0000;ooooo0ol00003ooooo`;o00009Oooool2o`0001cooooo0_l00016
ooooo`;o0000>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Hooooo`;o00001oooool2
o`0001;ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00005_ooool2
o`0000oooooo0_l0000Tooooo`;o000000?oooooo`000?l000009_ooool2o`000004ooooool0003o
0000o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o00001Oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`0003gooooo000[ooooo`;o00006Oooool2o`0000Oooooo0_l0000B
ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0001Kooooo0_l0000?
ooooo`;o00009?ooool2o`000003ooooool0003o000002Kooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_l0000mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l00005ooooo`?o00000oooool2o`0000Gooooo0ol0000[ooooo`?o000000Wo<S8b
omgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h04_ooool2o`0000oooooo0_l0000Cooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_ooool2o`00017ooooo0_l0000?ooooo`Co00002?ooool2o`000003ooooool0003o000000Co
00000_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`Co00005?ooool2o`0000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo00Cooooo0ol0
0003ooooo`;o00001Oooool3o`0002_ooooo0_l000000oooooooMgMgoc8b<P02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04_ooool2o`0000oooooo0_l0000Eooooo`;o00000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`00017ooooo0_l0000?
ooooo`Co00002?ooool2o`0000?ooooo00Co0000ooooool0003o00001Oooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`Co00005?ooool2o`0000cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo04?ooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`07oooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0<_ooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01?ooooo
000[ooooo`03o`000?oooooooooo04;ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo03?ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00:ooo
ool00ol0003oooooooooo`0oooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000003[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000=_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
01?ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aoooo
o`00:oooool2o`0000Wooooo0_l0000?ooooo`;o00001?ooool2o`000003ooooool0003o000000oo
oooo0_l00007ooooo`;o000000?oooooo`000?ooool01?ooool4o`000003oiRHV?mgMgOooooo01Co
oooo0_l0000;ooooo`;o00001?ooool5o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?oo
ool00oooool00omgMgOoV9RHooooo`02o`0000;ooooo0ol000000oooooooV9RHogMgM`0Eooooo`;o
00002_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`00
0?ooool01?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2
o`0000kooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000Go^[Zj
oooooonHV9So410@ooooo`04o`000003ooooool0003o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Cooooo`00:oooool00ol0003oooooooooo`08ooooo`;o00003oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000_oo
ool4o`000003oc8b<_o^k^kooooo01Cooooo0_l0000;ooooo`;o00001?ooool5o`0000;ooooo0_l0
0005ooooo`?o000000?oIVIVo`000?ooool00oooool00oo^k^ko<S8bo`000002o`0000;ooooo1?l0
00000olb<S;ok^k^ooooo`0Dooooo`;o00002_ooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o000000?oIVIVo`000?ooool01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`;o00003_ooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0000Co
oooo0_l000001Ol@413o0000ob4Q8Oo<c<cooooo00Oo00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@
4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^
k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo
000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool2o`0000?ooooo1?l0
0007ooooo`Wo00000_ooool4o`0000?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo1Ol0
000<ooooo`03o`000?oooooooooo00?ooooo1?l00004ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool2o`0000Sooooo1?l000000ooooooo0000ooooo`05ooooo`;o00001Ooo
ool3o`0000Kooooo0_l00002ooooo`?o00002oooool3o`0000kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`05ooooo`Co00000oooool00ol0003oooooooooo`02o`0000Wooooo00?o
0000ooooooooool02Oooool3o`0000;ooooo0_l00009ooooo`;o00001oooool2o`0000Cooooo00?o
0000ooooooooool04Oooool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000
ooooooooool0oooooolbooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo00?o0000
ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo
0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`02ooooo`;o
00000oooool2o`0000;ooooo0ol00006ooooo`Co00001_ooool2o`0000?ooooo0_l00009ooooo`;o
00002Oooool2o`0000Oooooo0_l0000gooooo`Co000000?oooooo`000?l000000_ooool2o`0000So
oooo0_l0000?ooooo`;o00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000<oooo
o`;o00004oooool2o`0000?ooooo1?l0000;ooooo`;o00001_ooool2o`000003ooooool0003o0000
01;ooooo0_l00006ooooo`;o00000oooool2o`0001Wooooo0_l00008ooooo`00:oooool2o`0000?o
oooo0_l00003ooooo`;o00000_ooool3o`0000Kooooo1?l00006ooooo`;o00000oooool2o`0000Wo
oooo0_l00009ooooo`;o00001oooool2o`0003Oooooo1?l000000ooooooo0000o`000002ooooo`;o
00002?ooool2o`0000oooooo0_l00005ooooo`;o00001_ooool2o`000004ooooool0003o0000o`00
00cooooo0_l0000Cooooo`;o00000oooool4o`0000_ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000004_ooool2o`0000Kooooo0_l00003ooooo`;o00008oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooo`000003o`0002Gooooo0_l0000>ooooo`;o00004oooool2o`0000[ooooo0_l00003oooo
o`;o00000oooool2o`0000Cooooo0_l0000Zooooo`;o00000oooool2o`0000gooooo0_l00004oooo
o`;o00002_ooool2o`0000Kooooo0_l0000Booooo`Co0000>Oooool2o`0002Cooooo000[ooooo`Ko
00009Oooool2o`0000kooooo0_l0000Cooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`0002[ooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l0000:ooooo`;o
00001_ooool2o`0001;ooooo1?l0000iooooo`;o00009?ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`?o00003_ooool2o`0001oooooo0_l0000Rooooo`;o0000
0_ooool2o`0000_ooooo0_l0000;ooooo`;o00005?ooool2o`0000;ooooo0_l0000Eooooo`;o0000
3oooool2o`0002oooooo0_l0000/ooooo`;o00001oooool2o`0001gooooo000[ooooo`?o00003_oo
ool2o`0001oooooo0_l0000Rooooo`;o00000_ooool2o`0000_ooooo0_l0000;ooooo`;o00005?oo
ool2o`0000;ooooo0_l0000Eooooo`;o00003oooool2o`0002oooooo0_l0000/ooooo`;o00001ooo
ool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0000gooooo`;o00007_ooool2o`00067ooooo0_l0
000Gooooo`;o00003_ooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0003Oooooo000[ooooo`03o`000?oooooooooo03Kooooo0_l0000Nooooo`;o0000HOooool2
o`0001Oooooo0_l0000>ooooo`;o00003?ooool2o`0000Gooooo0_l000000ooooooo0000o`000005
ooooo`;o0000=oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Koooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000C?ooool2
o`0000;ooooo0_l0000?ooooo`;o0000;?ooool2o`000:Wooooo000Kooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04cooooo0_l00002
ooooo`;o00003oooool2o`0002cooooo0_l0002Yooooo`006oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Koooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo00oooooo0_l00013ooooo`;o0000i?ooool002_ooooo0_l0000@ooooo`;o
0000@oooool2o`000>Cooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool2o`000?oooooo3?ooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo2ooo
ool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`00
6Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_o
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooo
oc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003ooooo
odCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403ooooo
odCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<oooo
o`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?o
oooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o
00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00kooooo1Ol00003ooooo`Go0000oooooolEooooo`000oooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4
A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OnHV9So8B4Qonk^k_ooooooA4A40?oooooo5Oooool000Cooooo00CogMgMo`000?l@
413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o
410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Booooo`03oiRHV?lQ8B7ok^k^00Gooooo
00?oV9RHob4Q8Oo^k^h0oooooolFooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^
k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^
kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002oooool00onHV9So8B4Qonk^kP05
ooooo`03oiRHV?lQ8B7ok^k^0?oooooo5Oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool0
2OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b
<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Dooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMg
ofIVI_ooool0oooooolDooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo
00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg
00;o000000?oV9RHooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo4oooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM037ooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooolEooooo`003ooo
ool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo033ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooolEooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .38112 Mdot
.03333 .33992 Mdot
.0381 .33992 Mdot
.04286 .33992 Mdot
.04762 .27812 Mdot
.05238 .25751 Mdot
.05714 .31932 Mdot
.0619 .27812 Mdot
.06667 .27812 Mdot
.07143 .31932 Mdot
.07619 .31932 Mdot
.08095 .36052 Mdot
.08571 .42232 Mdot
.09048 .27812 Mdot
.09524 .25751 Mdot
.1 .33992 Mdot
.10476 .31932 Mdot
.10952 .31932 Mdot
.11429 .25751 Mdot
.11905 .29872 Mdot
.12381 .29872 Mdot
.12857 .29872 Mdot
.13333 .33992 Mdot
.1381 .27812 Mdot
.14286 .25751 Mdot
.14762 .29872 Mdot
.15238 .33992 Mdot
.15714 .31932 Mdot
.1619 .31932 Mdot
.16667 .36052 Mdot
.17143 .29872 Mdot
.17619 .29872 Mdot
.18095 .29872 Mdot
.18571 .31932 Mdot
.19048 .36052 Mdot
.19524 .29872 Mdot
.2 .29872 Mdot
.20476 .29872 Mdot
.20952 .25751 Mdot
.21429 .40172 Mdot
.21905 .36052 Mdot
.22381 .33992 Mdot
.22857 .25751 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .25751 Mdot
.24762 .25751 Mdot
.25238 .33992 Mdot
.25714 .31932 Mdot
.2619 .27812 Mdot
.26667 .31932 Mdot
.27143 .27812 Mdot
.27619 .21631 Mdot
.28095 .23691 Mdot
.28571 .40172 Mdot
.29048 .33992 Mdot
.29524 .23691 Mdot
.3 .42232 Mdot
.30476 .21631 Mdot
.30952 .38112 Mdot
.31429 .44292 Mdot
.31905 .40172 Mdot
.32381 .36052 Mdot
.32857 .33992 Mdot
.33333 .31932 Mdot
.3381 .31932 Mdot
.34286 .25751 Mdot
.34762 .36052 Mdot
.35238 .29872 Mdot
.35714 .42232 Mdot
.3619 .36052 Mdot
.36667 .38112 Mdot
.37143 .21631 Mdot
.37619 .23691 Mdot
.38095 .33992 Mdot
.38571 .21631 Mdot
.39048 .23691 Mdot
.39524 .27812 Mdot
.4 .25751 Mdot
.40476 .23691 Mdot
.40952 .38112 Mdot
.41429 .29872 Mdot
.41905 .29872 Mdot
.42381 .29872 Mdot
.42857 .19571 Mdot
.43333 .25751 Mdot
.4381 .27812 Mdot
.44286 .33992 Mdot
.44762 .31932 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .29872 Mdot
.46667 .29872 Mdot
.47143 .33992 Mdot
.47619 .25751 Mdot
.48095 .38112 Mdot
.48571 .29872 Mdot
.49048 .29872 Mdot
.49524 .38112 Mdot
.5 .27812 Mdot
.50476 .31932 Mdot
.50952 .42232 Mdot
.51429 .27812 Mdot
.51905 .29872 Mdot
.52381 .29872 Mdot
.52857 .33992 Mdot
.53333 .21631 Mdot
.5381 .25751 Mdot
.54286 .33992 Mdot
.54762 .29872 Mdot
.55238 .29872 Mdot
.55714 .23691 Mdot
.5619 .33992 Mdot
.56667 .23691 Mdot
.57143 .38112 Mdot
.57619 .29872 Mdot
.58095 .19571 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .27812 Mdot
.60476 .29872 Mdot
.60952 .33992 Mdot
.61429 .33992 Mdot
.61905 .33992 Mdot
.62381 .33992 Mdot
.62857 .38112 Mdot
.63333 .21631 Mdot
.6381 .29872 Mdot
.64286 .29872 Mdot
.64762 .40172 Mdot
.65238 .33992 Mdot
.65714 .27812 Mdot
.6619 .25751 Mdot
.66667 .21631 Mdot
.67143 .31932 Mdot
.67619 .27812 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .27812 Mdot
.69524 .25751 Mdot
.7 .25751 Mdot
.70476 .27812 Mdot
.70952 .23691 Mdot
.71429 .23691 Mdot
.71905 .27812 Mdot
.72381 .19571 Mdot
.72857 .40172 Mdot
.73333 .23691 Mdot
.7381 .31932 Mdot
.74286 .25751 Mdot
.74762 .36052 Mdot
.75238 .33992 Mdot
.75714 .31932 Mdot
.7619 .31932 Mdot
.76667 .31932 Mdot
.77143 .29872 Mdot
.77619 .17511 Mdot
.78095 .38112 Mdot
.78571 .29872 Mdot
.79048 .36052 Mdot
.79524 .25751 Mdot
.8 .31932 Mdot
.80476 .33992 Mdot
.80952 .17511 Mdot
.81429 .27812 Mdot
.81905 .23691 Mdot
.82381 .25751 Mdot
.82857 .40172 Mdot
.83333 .31932 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .25751 Mdot
.85238 .38112 Mdot
.85714 .25751 Mdot
.8619 .40172 Mdot
.86667 .23691 Mdot
.87143 .21631 Mdot
.87619 .31932 Mdot
.88095 .27812 Mdot
.88571 .40172 Mdot
.89048 .31932 Mdot
.89524 .27812 Mdot
.9 .19571 Mdot
.90476 .29872 Mdot
.90952 .33992 Mdot
.91429 .46353 Mdot
.91905 .29872 Mdot
.92381 .19571 Mdot
.92857 .29872 Mdot
.93333 .31932 Mdot
.9381 .29872 Mdot
.94286 .36052 Mdot
.94762 .33992 Mdot
.95238 .33992 Mdot
.95714 .29872 Mdot
.9619 .27812 Mdot
.96667 .27812 Mdot
.97143 .36052 Mdot
.97619 .29872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0h?ooool2o`0000Sooooo0_l0
001>ooooo`00:oooool00ol0003oooooooooo`3Pooooo`;o00002?ooool2o`0004kooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`1gooooo`;o0000;?ooool2o`0002Wooooo0_l0000dooooo`;o00001Oooool2
o`0002_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo
00?o0000ooooooooool0Moooool2o`0002cooooo0_l0000Yooooo`;o0000=?ooool2o`0000Gooooo
0_l0000[ooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o0000
4_ooool2o`0000;ooooo0_l0000[ooooo`;o00007?ooool2o`0000Sooooo0_l0000looooo`;o0000
>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0BOooool2o`0000Oooooo0_l0000Booooo`;o00000_ooool2o`0002_ooooo
0_l0000Looooo`;o00002?ooool2o`0003cooooo0_l0000kooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0B_ooool2o`0000?o
oooo0_l0000Fooooo`;o00000_ooool2o`0000?ooooo0_l0000/ooooo`;o000000?oooooo`000?l0
0000:Oooool3o`0000Cooooo0_l0000Hooooo`;o00003?ooool2o`0003gooooo000[ooooo`03o`00
0?oooooooooo04[ooooo0_l00003ooooo`;o00005_ooool2o`0000;ooooo0_l00003ooooo`;o0000
;?ooool2o`000003ooooool0003o000002Wooooo0ol00004ooooo`;o00006?ooool2o`0000cooooo
0_l0000mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool01Oooool2o`0000_ooooo0_l00004ooooo`;o0000
1oooool2o`0001;ooooo0_l00003ooooo`;o00000oooool3o`0001_ooooo0_l0000?ooooo`;o0000
2?ooool2o`0000_ooooo0_l0000Aooooo`;o00009?ooool2o`0000Sooooo0ol0000;ooooo`;o0000
3_ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l00000?oooool002_ooooo00?o
0000ooooooooool01Oooool2o`0000_ooooo0_l00004ooooo`;o00001oooool2o`0001;ooooo0_l0
0003ooooo`;o00000oooool3o`0001_ooooo0_l0000?ooooo`;o00002?ooool2o`0000_ooooo0_l0
000Aooooo`;o00009?ooool2o`0000Sooooo0ol0000;ooooo`;o00003_ooool2o`0000Kooooo0_l0
0006ooooo`;o000000?oooooo`000?l00000?oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000@?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0doooo
o`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^03?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000oooo
ooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`0cooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400C
ooooo`00:oooool00ol0003oooooooooo`04ooooo`;o00000_ooool4o`0000Gooooo0_l0000<oooo
o`;o00008Oooool00omgMgOo<S8booooo`04o`000003ooooool0003ooooo027ooooo0_l0000;oooo
o`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool2o`00
00?ooooo00?o0000ooooooooool04_ooool2o`0000oooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`000003ooooool0003ooooo00;o00001Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool02oooool2o`0000Gooooo0_l0000;ooooo`;o00000_oo
ool2o`0000kooooo00CoV9RHob4Q8Oo^k^kooooo1?l00002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003oooooooooo`04ooooo`;o0000
0_ooool4o`0000Gooooo0_l0000<ooooo`;o00007_ooool01_l0003o8B4Qo`000?lb<S;oc<c<oooo
o`Co000000?oooooo`000?ooool08Oooool2o`0000_ooooo0_l00009ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000oooool00ol0003oooooooooo`0Boooo
o`;o00003oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?ooooo
o`000?ooool00_l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000gooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo0_l0000?ooooo`03ogMg
MomVIVKooooo00Co00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool04Oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017o
oooo000[ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_o
oooo00?o0000ooooooooool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hoooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0=?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^03?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool06Oooool5o`0000Cooooo0_l00005ooooo`Go
00000_ooool5o`0000Oooooo0ol0000Qooooo`;o00004Oooool5o`0000Wooooo0ol00004ooooo`Co
00001_ooool4o`0000Gooooo0ol00006ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`Co
00009Oooool2o`0000;ooooo0_l0000Rooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`0000Cooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`0Iooooo`Go
00001?ooool2o`0000Gooooo1Ol00002ooooo`Go00001oooool3o`00027ooooo0_l0000Aooooo`Go
00002Oooool3o`0000Cooooo1?l00006ooooo`Co00001Oooool3o`0000Kooooo0_l00002ooooo`;o
00000_ooool2o`0000Sooooo1?l0000Uooooo`;o00000_ooool2o`0002;ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo0_l00002oooo
o`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003o
ooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<
c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003ooooo
ooooo`07ooooo`;o00000_ooool3o`0000Oooooo0ol0000=ooooo`?o00001_ooool2o`0001?ooooo
0_l000000ooooooo0000o`00000Booooo`Co00007oooool3o`0000kooooo0_l0000Fooooo`;o0000
6?ooool2o`0001?ooooo0_l00003ooooo`Go00002?ooool2o`0000Sooooo0_l000000ooooooo0000
o`000008ooooo`;o00000oooool2o`0000_ooooo0_l0000Oooooo`05o`000?ooooooA4A4o`000?l@
41001?ooool002_ooooo00?o0000ooooooooool01oooool2o`0000;ooooo0ol00007ooooo`?o0000
3Oooool3o`0000Kooooo0_l0000Cooooo`;o000000?oooooo`000?l000004_ooool4o`0001oooooo
0ol0000>ooooo`;o00005_ooool2o`0001Sooooo0_l0000Cooooo`;o00000oooool5o`0000Sooooo
0_l00008ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
7oooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o
0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o00002?ooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooool000001?l0000@ooooo`;o00002?ooool2o`0000?ooooo0_l0000Dooooo`;o0000
1oooool2o`0000Wooooo0_l0000:ooooo`;o00003_ooool2o`00013ooooo0_l00003ooooo`;o0000
0_ooool2o`0000oooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`Ko0000
1oooool2o`0000Kooooo0_l0000Dooooo`;o00003_ooool2o`0001gooooo0_l0000:ooooo`?o0000
8oooool002_ooooo00?o0000ooooool000001?l0000@ooooo`;o00002?ooool2o`0000?ooooo0_l0
000Dooooo`;o00001oooool2o`0000Wooooo0_l0000:ooooo`;o00003_ooool2o`00013ooooo0_l0
0003ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l0
0003ooooo`Ko00001oooool2o`0000Kooooo0_l0000Dooooo`;o00003_ooool2o`0001gooooo0_l0
000:ooooo`?o00008oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool03_ooool2o`0001Sooooo0_l00005ooooo`;o00001oooool2o`0001gooooo0_l00005
ooooo`;o00000oooool2o`0007;ooooo0_l0000;ooooo`;o0000;?ooool2o`0000Oooooo0_l0000M
ooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00006?ooool2o`0000Gooooo0_l00007oooo
o`;o00007Oooool2o`0000Gooooo0_l00003ooooo`;o0000L_ooool2o`0000_ooooo0_l0000/oooo
o`;o00001oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool3o`0005?ooooo0_l0000?ooooo`;o00002oooool2o`00
01Cooooo0_l00002ooooo`;o00005Oooool2o`0000oooooo0_l0000]ooooo`;o00004oooool2o`00
047ooooo000[ooooo`?o0000Doooool2o`0000oooooo0_l0000;ooooo`;o00005?ooool2o`0000;o
oooo0_l0000Eooooo`;o00003oooool2o`0002gooooo0_l0000Cooooo`;o0000@Oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo03Kooooo0_l0000Dooooo`;o00002?ooool2o`00067ooooo0_l0000Gooooo`;o
00007?ooool2o`0000Sooooo0_l00005ooooo`;o0000=oooool001Wooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0fooooo`;o00005?ooool2
o`0000Sooooo0_l0001Qooooo`;o00005oooool2o`0001cooooo0_l00008ooooo`;o00001Oooool2
o`0003Oooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool0
01_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`0?ooooo`;o0000?oooool2o`0000oooooo0_l0000/
ooooo`;o0000ZOooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool03oooool2o`0003oooooo0_l0000?ooooo`;o0000;?ooool2
o`000:Wooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo05Cooooo0_l0003T
ooooo`00:oooool00ol0003oooooooooo`1Dooooo`;o0000i?ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo2oooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo2oooool2o`0002ko
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_o
oooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?oo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3o
ooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o
00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003
oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo1Ol00003ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`0oooooolEooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko
0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj
^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;o
oooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Ol@413o^[ZjoooooomgMgOo
<S8b0?oooooo5Oooool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@
omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool0oooooolCooooo`00
1?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMooo
ooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06ooooo`03ojVYZOl@413ooooo0?oooooo5?oo
ool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^
k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00
000Dooooo`03ogMgMomVIVKooooo00Cooooo00?o410@o`000?nj^[X0oooooolEooooo`000oooool2
o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2
o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04oooool0
0ol0003oooooooooo`04ooooo`03okZj^_lQ8B7ooooo0?oooooo5?ooool000oooooo00OoEEEEoiRH
V?ooooooooooomgMgOl0003ogMgM037ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@
4?nHV9SooooookZj^_l00000oooooolEooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVY
ZOoooooooooo033ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .37082 Mdot
.03333 .35022 Mdot
.0381 .32962 Mdot
.04286 .32962 Mdot
.04762 .28842 Mdot
.05238 .26781 Mdot
.05714 .30902 Mdot
.0619 .28842 Mdot
.06667 .26781 Mdot
.07143 .32962 Mdot
.07619 .32962 Mdot
.08095 .35022 Mdot
.08571 .43262 Mdot
.09048 .28842 Mdot
.09524 .24721 Mdot
.1 .35022 Mdot
.10476 .32962 Mdot
.10952 .32962 Mdot
.11429 .24721 Mdot
.11905 .28842 Mdot
.12381 .28842 Mdot
.12857 .28842 Mdot
.13333 .35022 Mdot
.1381 .26781 Mdot
.14286 .26781 Mdot
.14762 .30902 Mdot
.15238 .32962 Mdot
.15714 .32962 Mdot
.1619 .30902 Mdot
.16667 .35022 Mdot
.17143 .30902 Mdot
.17619 .30902 Mdot
.18095 .30902 Mdot
.18571 .30902 Mdot
.19048 .37082 Mdot
.19524 .30902 Mdot
.2 .28842 Mdot
.20476 .30902 Mdot
.20952 .26781 Mdot
.21429 .39142 Mdot
.21905 .35022 Mdot
.22381 .32962 Mdot
.22857 .24721 Mdot
.23333 .28842 Mdot
.2381 .30902 Mdot
.24286 .24721 Mdot
.24762 .24721 Mdot
.25238 .32962 Mdot
.25714 .32962 Mdot
.2619 .26781 Mdot
.26667 .30902 Mdot
.27143 .26781 Mdot
.27619 .22661 Mdot
.28095 .22661 Mdot
.28571 .39142 Mdot
.29048 .32962 Mdot
.29524 .24721 Mdot
.3 .43262 Mdot
.30476 .20601 Mdot
.30952 .37082 Mdot
.31429 .43262 Mdot
.31905 .39142 Mdot
.32381 .35022 Mdot
.32857 .32962 Mdot
.33333 .32962 Mdot
.3381 .30902 Mdot
.34286 .24721 Mdot
.34762 .35022 Mdot
.35238 .30902 Mdot
.35714 .43262 Mdot
.3619 .35022 Mdot
.36667 .37082 Mdot
.37143 .22661 Mdot
.37619 .24721 Mdot
.38095 .32962 Mdot
.38571 .22661 Mdot
.39048 .24721 Mdot
.39524 .26781 Mdot
.4 .24721 Mdot
.40476 .24721 Mdot
.40952 .39142 Mdot
.41429 .28842 Mdot
.41905 .28842 Mdot
.42381 .30902 Mdot
.42857 .20601 Mdot
.43333 .24721 Mdot
.4381 .26781 Mdot
.44286 .35022 Mdot
.44762 .32962 Mdot
.45238 .32962 Mdot
.45714 .35022 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .32962 Mdot
.47619 .24721 Mdot
.48095 .37082 Mdot
.48571 .28842 Mdot
.49048 .30902 Mdot
.49524 .39142 Mdot
.5 .28842 Mdot
.50476 .30902 Mdot
.50952 .41202 Mdot
.51429 .26781 Mdot
.51905 .28842 Mdot
.52381 .28842 Mdot
.52857 .32962 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .32962 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .24721 Mdot
.5619 .35022 Mdot
.56667 .22661 Mdot
.57143 .39142 Mdot
.57619 .28842 Mdot
.58095 .18541 Mdot
.58571 .30902 Mdot
.59048 .30902 Mdot
.59524 .32962 Mdot
.6 .28842 Mdot
.60476 .28842 Mdot
.60952 .35022 Mdot
.61429 .35022 Mdot
.61905 .32962 Mdot
.62381 .32962 Mdot
.62857 .39142 Mdot
.63333 .22661 Mdot
.6381 .28842 Mdot
.64286 .30902 Mdot
.64762 .41202 Mdot
.65238 .32962 Mdot
.65714 .28842 Mdot
.6619 .26781 Mdot
.66667 .22661 Mdot
.67143 .32962 Mdot
.67619 .26781 Mdot
.68095 .35022 Mdot
.68571 .28842 Mdot
.69048 .28842 Mdot
.69524 .26781 Mdot
.7 .24721 Mdot
.70476 .26781 Mdot
.70952 .22661 Mdot
.71429 .24721 Mdot
.71905 .26781 Mdot
.72381 .18541 Mdot
.72857 .41202 Mdot
.73333 .22661 Mdot
.7381 .30902 Mdot
.74286 .24721 Mdot
.74762 .35022 Mdot
.75238 .35022 Mdot
.75714 .30902 Mdot
.7619 .32962 Mdot
.76667 .30902 Mdot
.77143 .28842 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .28842 Mdot
.79048 .35022 Mdot
.79524 .26781 Mdot
.8 .32962 Mdot
.80476 .32962 Mdot
.80952 .16481 Mdot
.81429 .26781 Mdot
.81905 .22661 Mdot
.82381 .26781 Mdot
.82857 .41202 Mdot
.83333 .30902 Mdot
.8381 .26781 Mdot
.84286 .30902 Mdot
.84762 .26781 Mdot
.85238 .37082 Mdot
.85714 .24721 Mdot
.8619 .41202 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .30902 Mdot
.88095 .28842 Mdot
.88571 .41202 Mdot
.89048 .30902 Mdot
.89524 .28842 Mdot
.9 .18541 Mdot
.90476 .30902 Mdot
.90952 .35022 Mdot
.91429 .47383 Mdot
.91905 .30902 Mdot
.92381 .18541 Mdot
.92857 .30902 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .37082 Mdot
.94762 .32962 Mdot
.95238 .35022 Mdot
.95714 .28842 Mdot
.9619 .26781 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .28842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3Zooooo`;o0000C_ooool0
02_ooooo0_l0003[ooooo`;o0000C_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000Y_ooool2o`0002Wooooo0_l0000>ooooo`;o00009?ooool2o`0000Go
oooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`2Uooooo`;o0000:Oooool2o`0000kooooo
0_l0000Tooooo`;o00001Oooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0ol0001Booooo`;o00008oooool2o`000<7ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05;ooooo
0_l0000Sooooo`;o0000`Oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0004[ooooo0ol0
000Jooooo`;o00000_ooool2o`0002_ooooo0_l00008ooooo`;o00004_ooool2o`0000Sooooo0_l0
000;ooooo`;o00001Oooool2o`0001Sooooo0_l0000>ooooo`;o0000>oooool002_ooooo00?o0000
ooooooooool0BOooool3o`0001[ooooo0_l00002ooooo`;o0000:oooool2o`0000Sooooo0_l0000B
ooooo`;o00002?ooool2o`0000_ooooo0_l00005ooooo`;o00006?ooool2o`0000kooooo0_l0000k
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`;o00008?ooool2
o`0000?ooooo0ol0000=ooooo`;o00003?ooool2o`0000Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o00002oooool2o`0001Oooooo0_l0000Yooooo`;o00000_ooool2
o`0000Oooooo0_l0000Qooooo`Co0000?Oooool002_ooooo0_l0000Cooooo`;o00001?ooool2o`00
023ooooo0_l00003ooooo`?o00003Oooool2o`0000cooooo0_l00008ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001_ooool2o`0000_ooooo0_l0000Gooooo`;o0000:Oooool2o`00
00;ooooo0_l00007ooooo`;o00008Oooool4o`0003gooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`0000Kooooo0_l00003ooooo`;o00004oooool4o`0001;o
oooo0_l00008ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo1?l000000olb<S;ok^k^ooooo`0Q
ooooo`;o00002oooool2o`0000Oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0_ooool2o`000005oc8b<_l0003o<S8bonk^k_ooool00_l0000Tooooo`;o00000_ooool2o`00
00Cooooo2Ol00002ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o000001[ooooo1Ol0
00002?oooooo0000o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01?ooooo000[ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o00004oooool4o`00
01;ooooo0_l0000;ooooo`03ogMgMolb<S;ooooo00Co000000?oV9RHogMgMoooool08Oooool2o`00
00_ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`;o000000GoV9RHoooooonHV9SoMgMgooooo`02o`0002Cooooo0_l00002ooooo`;o00001?oo
ool4o`000003ooooool0003ooooo00;o00001Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oo
ooooV9RHogMgM`07ooooo`;o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000Joooo
o`06oiRHV?lQ8B7ok^k^oooooom4A4Cooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400Cooooo`00:oooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;oooooooooool0
00000oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0cooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00004oooool002_ooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`00000jooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003Ko
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400gooooo`05
o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool04Oooool002_ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l00006oooo
o`Go00005?ooool2o`0000Sooooo0_l000000ooooooo0000ooooo`05ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0:?ooool3o`0000_ooooo0ol000001?oooooo0000ooooooooool2o`000003ogMgMonH
V9Sooooo00;o00000oooool4o`000003ogMgMooooooooooo00_ooooo0_l00005ooooo`?o00002?oo
ool2o`0000Cooooo0_l00007ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000;ooooo0_l0000Kooooo`;o0000
0_ooool2o`0000cooooo00Go0000okZj^_ooooooV9RHoa0@4002o`000004ooooool0003o0000oooo
o`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo
00Cooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo1Ol0000Dooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo0ol0000;
ooooo`?o000000CoIVIVo`000?oooooooooo0_l000000oo^k^ko<S8bo`000002o`0000?ooooo1?l0
00000oo^k^koooooooooo`0;ooooo`;o00001Oooool3o`0000Sooooo0_l00004ooooo`;o00001ooo
ool3o`0000?ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`0000;ooooo0_l0000Kooooo`;o00000_ooool2o`0000cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c002o`000003ooooool0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@4?l0
003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb
<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[
ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo3?l000000ooooooo0000o`000002ooooo`03o`000?oooooo
oooo00?ooooo0_l00006ooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool3
o`0000gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool02?ooool2
o`000004ooooool0003o0000o`0000_ooooo0ol00008ooooo`Go00003Oooool2o`0000gooooo00?o
0000ooooooooool02oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oo
oooooooo00[ooooo0_l000000ooooooo0000o`000008ooooo`?o00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`03o`000?oooooooooo017ooooo00?o
0000oa0@4?nHV9P01_ooool002_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0A
ooooo`04o`000?o^k^koEEEEohN7Q`Gooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool0
1Ol0003oooooodA4A?l0003o410@00Cooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool0
0ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000oooo
ooooool01_ooool002_ooooo00Co0000oooooooooooooooo0ol00007ooooo`?o00001oooool3o`00
00_ooooo1?l0000Booooo`;o00001oooool3o`0000Sooooo0_l0000:ooooo`?o00003Oooool2o`00
01;ooooo0ol00004ooooo`;o00003oooool2o`0000?ooooo0_l0000=ooooo`;o00001_ooool3o`00
00Oooooo0_l00003ooooo`;o00006_ooool2o`0000Wooooo1?l0000Yooooo`;o00006_ooool2o`00
00Sooooo000[ooooo`;o00000_ooool3o`0000Oooooo0ol00007ooooo`?o00002oooool4o`0001;o
oooo0_l00007ooooo`?o00002?ooool2o`0000[ooooo0ol0000=ooooo`;o00004_ooool3o`0000Co
oooo0_l0000?ooooo`;o00000oooool2o`0000gooooo0_l00006ooooo`?o00001oooool2o`0000?o
oooo0_l0000Jooooo`;o00002Oooool4o`0002Wooooo0_l0000Tooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`04
o`000?oooooo0000o`0000gooooo0_l00004ooooo`;o00002?ooool2o`0000Sooooo0_l0000>oooo
o`;o00007Oooool2o`0000Gooooo0_l00003ooooo`;o00005_ooool2o`0000?ooooo0_l0000Moooo
o`;o00003Oooool3o`0001;ooooo0_l0000Booooo`Co00002Oooool2o`0002;ooooo0_l0000;oooo
o`;o00008oooool002_ooooo1?l0000=ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`;o
00003_ooool2o`0001gooooo0_l00005ooooo`;o00000oooool2o`0001Kooooo0_l00003ooooo`;o
00007Oooool2o`0000gooooo0ol0000Booooo`;o00004_ooool4o`0000Wooooo0_l0000Rooooo`;o
00002oooool2o`0002?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool3o`0002oooooo0_l0000Rooooo`;o00003oooool2o`00027ooooo0_l0001^ooooo`;o0000
6Oooool2o`0000Oooooo0_l0000Mooooo`00:oooool3o`0002oooooo0_l0000Rooooo`;o00003ooo
ool2o`00027ooooo0_l0001^ooooo`;o00006Oooool2o`0000Oooooo0_l0000Mooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000=oooool2o`0001Cooooo0_l00008ooooo`;o00006Oooool2o`0001Sooooo0_l0
000Eooooo`;o00003oooool2o`0002gooooo0_l0001Fooooo`00:oooool00ol0003oooooooooo`0f
ooooo`;o00005?ooool2o`0000Sooooo0_l0000Iooooo`;o00006?ooool2o`0001Gooooo0_l0000?
ooooo`;o0000;Oooool2o`0005Kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolk
ooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3
o`0008oooooo0_l0000Xooooo`;o00005oooool2o`0001cooooo0_l00008ooooo`;o00001Oooool2
o`0003Oooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo08oooooo0_l0000Xooooo`;o00005oooool2o`0001cooooo0_l00008
ooooo`;o00001Oooool2o`0003Oooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolk
ooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool03oooool2o`0003oooooo0_l00002ooooo`;o00002oooool2o`000=Oooooo000[ooooo`;o
00004?ooool2o`0003oooooo0_l00002ooooo`;o00002oooool2o`000=Oooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000ooooool<ooooo`;o0000;_oo
ool002_ooooo00?o0000ooooooooool0ooooool;ooooo`;o0000;_ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`00
6oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool0
0ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;ooooo
odGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o
0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj
^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo1Ol00005oooo
o`;o000000?o410@ooooooooool0oooooolCooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^
k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooo
oooooooo000000;ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3ooooooaCooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05
oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?oooooo
ooooooooool000004_ooool00onHV9So8B4Qonk^kP04ooooo`Go0000oooooolEooooo`001?ooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIV
ohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`04odA4A?oMgMgoooooo`000?oooooo5_ooool0
00Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko
410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000D
ooooo`03ogMgMomVIVKooooo00;ooooo00CogMgMoeEEEOoooooo0000oooooolFooooo`000oooool2
o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2
o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04oooool0
0ol0003oooooooooo`02ooooo`03ogMgMoo<c<co00000?oooooo5_ooool000oooooo00OoEEEEoiRH
V?ooooooooooomgMgOl0003ogMgM037ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^
k_m4A4Co00000?oooooo5_ooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWooooooooo
o`0`ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00omgMgOo0000ooooo`3ooooooaGooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .38112 Mdot
.03333 .33992 Mdot
.0381 .33992 Mdot
.04286 .33992 Mdot
.04762 .29872 Mdot
.05238 .25751 Mdot
.05714 .29872 Mdot
.0619 .27812 Mdot
.06667 .27812 Mdot
.07143 .33992 Mdot
.07619 .31932 Mdot
.08095 .36052 Mdot
.08571 .42232 Mdot
.09048 .29872 Mdot
.09524 .23691 Mdot
.1 .36052 Mdot
.10476 .33992 Mdot
.10952 .31932 Mdot
.11429 .25751 Mdot
.11905 .29872 Mdot
.12381 .29872 Mdot
.12857 .29872 Mdot
.13333 .33992 Mdot
.1381 .27812 Mdot
.14286 .27812 Mdot
.14762 .31932 Mdot
.15238 .33992 Mdot
.15714 .31932 Mdot
.1619 .29872 Mdot
.16667 .36052 Mdot
.17143 .31932 Mdot
.17619 .31932 Mdot
.18095 .29872 Mdot
.18571 .29872 Mdot
.19048 .38112 Mdot
.19524 .31932 Mdot
.2 .27812 Mdot
.20476 .31932 Mdot
.20952 .27812 Mdot
.21429 .38112 Mdot
.21905 .36052 Mdot
.22381 .31932 Mdot
.22857 .23691 Mdot
.23333 .29872 Mdot
.2381 .31932 Mdot
.24286 .25751 Mdot
.24762 .23691 Mdot
.25238 .33992 Mdot
.25714 .31932 Mdot
.2619 .27812 Mdot
.26667 .29872 Mdot
.27143 .27812 Mdot
.27619 .21631 Mdot
.28095 .21631 Mdot
.28571 .40172 Mdot
.29048 .33992 Mdot
.29524 .25751 Mdot
.3 .44292 Mdot
.30476 .21631 Mdot
.30952 .38112 Mdot
.31429 .44292 Mdot
.31905 .38112 Mdot
.32381 .36052 Mdot
.32857 .33992 Mdot
.33333 .33992 Mdot
.3381 .31932 Mdot
.34286 .25751 Mdot
.34762 .36052 Mdot
.35238 .31932 Mdot
.35714 .44292 Mdot
.3619 .33992 Mdot
.36667 .36052 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .31932 Mdot
.38571 .23691 Mdot
.39048 .23691 Mdot
.39524 .27812 Mdot
.4 .25751 Mdot
.40476 .23691 Mdot
.40952 .40172 Mdot
.41429 .27812 Mdot
.41905 .27812 Mdot
.42381 .29872 Mdot
.42857 .21631 Mdot
.43333 .25751 Mdot
.4381 .25751 Mdot
.44286 .36052 Mdot
.44762 .31932 Mdot
.45238 .31932 Mdot
.45714 .36052 Mdot
.4619 .27812 Mdot
.46667 .29872 Mdot
.47143 .31932 Mdot
.47619 .25751 Mdot
.48095 .36052 Mdot
.48571 .27812 Mdot
.49048 .29872 Mdot
.49524 .40172 Mdot
.5 .27812 Mdot
.50476 .29872 Mdot
.50952 .40172 Mdot
.51429 .25751 Mdot
.51905 .27812 Mdot
.52381 .29872 Mdot
.52857 .33992 Mdot
.53333 .23691 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .31932 Mdot
.55238 .31932 Mdot
.55714 .25751 Mdot
.5619 .33992 Mdot
.56667 .21631 Mdot
.57143 .40172 Mdot
.57619 .29872 Mdot
.58095 .19571 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .27812 Mdot
.60476 .27812 Mdot
.60952 .36052 Mdot
.61429 .36052 Mdot
.61905 .31932 Mdot
.62381 .33992 Mdot
.62857 .40172 Mdot
.63333 .21631 Mdot
.6381 .27812 Mdot
.64286 .31932 Mdot
.64762 .40172 Mdot
.65238 .33992 Mdot
.65714 .27812 Mdot
.6619 .25751 Mdot
.66667 .23691 Mdot
.67143 .31932 Mdot
.67619 .27812 Mdot
.68095 .36052 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .27812 Mdot
.7 .25751 Mdot
.70476 .27812 Mdot
.70952 .23691 Mdot
.71429 .25751 Mdot
.71905 .25751 Mdot
.72381 .19571 Mdot
.72857 .40172 Mdot
.73333 .21631 Mdot
.7381 .31932 Mdot
.74286 .25751 Mdot
.74762 .33992 Mdot
.75238 .33992 Mdot
.75714 .31932 Mdot
.7619 .31932 Mdot
.76667 .31932 Mdot
.77143 .27812 Mdot
.77619 .17511 Mdot
.78095 .38112 Mdot
.78571 .29872 Mdot
.79048 .33992 Mdot
.79524 .27812 Mdot
.8 .31932 Mdot
.80476 .33992 Mdot
.80952 .17511 Mdot
.81429 .27812 Mdot
.81905 .21631 Mdot
.82381 .27812 Mdot
.82857 .42232 Mdot
.83333 .29872 Mdot
.8381 .27812 Mdot
.84286 .31932 Mdot
.84762 .27812 Mdot
.85238 .36052 Mdot
.85714 .25751 Mdot
.8619 .42232 Mdot
.86667 .23691 Mdot
.87143 .23691 Mdot
.87619 .29872 Mdot
.88095 .27812 Mdot
.88571 .42232 Mdot
.89048 .31932 Mdot
.89524 .29872 Mdot
.9 .19571 Mdot
.90476 .31932 Mdot
.90952 .33992 Mdot
.91429 .46353 Mdot
.91905 .31932 Mdot
.92381 .19571 Mdot
.92857 .31932 Mdot
.93333 .31932 Mdot
.9381 .29872 Mdot
.94286 .38112 Mdot
.94762 .31932 Mdot
.95238 .33992 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .38112 Mdot
.97619 .29872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0h?ooool2o`0000Sooooo0_l0
001>ooooo`00:oooool00ol0003oooooooooo`3Pooooo`;o00002?ooool2o`0004kooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`2Uooooo`;o0000:Oooool2o`0003Cooooo0_l00005ooooo`;o0000:oooool0
01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooo
ooooo`2Uooooo`;o0000:Oooool2o`0003Cooooo0_l00005ooooo`;o0000:oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`19ooooo`?o00001_ooool2o`0002?ooooo0_l0000Xooooo`;o0000
4_ooool2o`0001cooooo0_l0000Hooooo`;o0000Boooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0BOooool3o`0000Kooooo
0_l0000Sooooo`;o0000:?ooool2o`0001;ooooo0_l0000Looooo`;o00006?ooool2o`0004_ooooo
000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`0Booooo`;o00009_ooool2o`0000Cooooo0_l0000Tooooo`?o000000Coooooo`000?l0
003o00000oooool2o`0002Gooooo0_l0000Vooooo`;o00002oooool2o`0002gooooo1?l0000koooo
o`00:oooool00ol0003oooooooooo`0Booooo`;o00009_ooool2o`0000Cooooo0_l0000Tooooo`?o
000000Coooooo`000?l0003o00000oooool2o`0002Gooooo0_l0000Vooooo`;o00002oooool2o`00
02gooooo1?l0000kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool01Oooool2o`00017ooooo0_l0000Uoooo
o`;o00003_ooool2o`0000cooooo0_l0000?ooooo`;o00002?ooool4o`0000Wooooo0_l0000:oooo
o`;o00002oooool2o`0001kooooo0_l00009ooooo`;o00000_ooool4o`0000Gooooo0_l0000Qoooo
o`;o0000?oooool002_ooooo00?o0000ooooooooool01Oooool2o`00017ooooo0_l0000Uooooo`;o
00003_ooool2o`0000cooooo0_l0000?ooooo`;o00002?ooool4o`0000Wooooo0_l0000:ooooo`;o
00002oooool2o`0001kooooo0_l00009ooooo`;o00000_ooool4o`0000Gooooo0_l0000Qooooo`;o
0000?oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000@?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03?ooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo
000[ooooo`03o`000?oooooooooo04;ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`0cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:ooo
ool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0
>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103
ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool00ol0003ooooooooo
o`08ooooo`Co00004oooool4o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`03ogMgMolb
<S;ooooo00Co000000?oooooo`000?ooool08Oooool2o`0000Cooooo0ol0000;ooooo`;o00000_oo
ool00ol0003oooooooooo`03o`0000;ooooo0_l00003ooooo`;o00000_ooool01?l0003oooooo`00
0?l0000Aooooo`?o00002?ooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo1?l000000ooooooo0000ooooo`07ooooo`05ogMgMolb<S;oooooooooool000000oooool3o`00
00Gooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o000000Sooooo0_l0000Boooo
o`03oiRHV?lQ8B7ok^k^00Co00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool04Oooool002_ooooo00?o0000ooooooooool02?ooool4o`0001?ooooo1?l0000?oooo
o`;o000000?oooooo`000?l000002?ooool01_l0003o8B4Qo`000?lb<S;oc<c<ooooo`Co000000?o
ooooo`000?ooool08Oooool2o`0000Cooooo0ol0000;ooooo`;o00000_ooool00ol0003ooooooooo
o`03o`0000;ooooo0_l00003ooooo`;o00000_ooool01?l0003oooooo`000?l0000Aooooo`?o0000
2?ooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo
0000ooooo`04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01?l0003oooooooooooooool3
o`0000Gooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o000000Sooooo0_l0000C
ooooo`03ogMgMomVIVKo000000?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool04Oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo017ooooo000[ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4oooool002_ooooo00?o0000ooooooooool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003o000000Sooooo0_l00006ooooo`Go00002?ooool2o`0000Cooooo1?l0000<ooooo`;o00002?oo
ool2o`0002kooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000Looooo`;o00006oooool2o`0000cooooo0_l0000;ooooo`;o00001?oo
ool2o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000006oooool002_ooooo00?o0000
ooooooooool01?ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`Go00002?ooool2
o`0000Cooooo1?l0000<ooooo`;o00002?ooool2o`0002kooooo0_l0000:ooooo`;o00001_ooool2
o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l0000Looooo`;o00006oooool2
o`0000cooooo0_l0000;ooooo`;o00001?ooool2o`0000_ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000004Oooool2o`0000;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000oooo
ooooool0oooooolbooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`00
00cooooo00Co0000oiRHV?lb<S;oc<c<1Oooool002_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oa0@4?nHV9P01_ooool002_o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`04o`000?o^k^koEEEEohN7
Q`Gooooo000[ooooo`03o`000?oooooooooo00cooooo0_l00008ooooo`;o00002_ooool2o`000003
ooooool0003o000000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo0_l00004ooooo`;o00005oooool2o`0000;ooooo0_l00007ooooo`;o00004_ooool3o`0000Co
oooo0_l0000Eooooo`?o00002?ooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2o`0001?o
oooo0_l00003ooooo`Go00002?ooool2o`0000_ooooo0_l0000=ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Kooooo`05o`000?ooooooA4A4o`00
0?l@41001?ooool002_ooooo00?o0000ooooooooool03?ooool2o`0000Sooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`0000Cooooo0_l0000Gooooo`;o00000_ooool2o`0000Oooooo0_l0000Booooo`?o
00001?ooool2o`0001Gooooo0ol00008ooooo`;o00002Oooool2o`0000Gooooo0_l00006ooooo`;o
00004oooool2o`0000?ooooo1Ol00008ooooo`;o00002oooool2o`0000gooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001_ooooo00?o0000oooooooo
ool01_ooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo
000[ooooo`03o`000?oooooooooo0?oooooo<Oooool2o`0000Sooooo000[ooooo`;o0000ooooooll
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo000000Co
00001oooool2o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0001gooooo0_l00009ooooo`;o
00002_ooool3o`0000Oooooo0_l0000`ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o
00001oooool2o`0000Oooooo0_l0000Jooooo`Co00002Oooool2o`0000?ooooo0_l0000Mooooo`;o
00002oooool2o`0002?ooooo000[ooooo`03o`000?oooooo000000Co00001oooool2o`0000Sooooo
0_l00007ooooo`;o00000oooool2o`0001gooooo0_l00009ooooo`;o00002_ooool3o`0000Oooooo
0_l0000`ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0000Oooooo
0_l0000Jooooo`Co00002Oooool2o`0000?ooooo0_l0000Mooooo`;o00002oooool2o`0002?ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00kooooo0_l0
0004ooooo`;o00004_ooool2o`0000kooooo0_l0000Mooooo`;o00001Oooool2o`0000Cooooo0_l0
000Eooooo`;o00000oooool2o`0000Gooooo0_l0000Uooooo`?o00004_ooool2o`0003;ooooo0_l0
0011ooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00001?ooool2o`0001;ooooo0_l0000>
ooooo`;o00007Oooool2o`0000Gooooo0_l00004ooooo`;o00005Oooool2o`0000?ooooo0_l00005
ooooo`;o00009Oooool3o`0001;ooooo0_l0000booooo`;o0000@Oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000;oooool2
o`0000Gooooo0_l0000Kooooo`;o000000?oooooo`000?l00000R_ooool2o`0002kooooo0_l00007
ooooo`;o00007Oooool002_ooooo0ol0000_ooooo`;o00001Oooool2o`0001_ooooo0_l000000ooo
oooo0000o`00002:ooooo`;o0000;_ooool2o`0000Oooooo0_l0000Mooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0C?ooool2o`0002?ooooo0_l0000Hooooo`;o00000_ooool2o`00017ooooo0_l0000?oooo
o`;o00001?ooool2o`0001Oooooo0_l0001Vooooo`006Oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo04cooooo0_l0000Sooooo`;o00006?oo
ool2o`0000;ooooo0_l0000Aooooo`;o00003oooool2o`0000Cooooo0_l0000Gooooo`;o0000I_oo
ool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00oooooo0_l0003Oooooo`;o00002?ooool2o`0000Gooooo0_l0
000gooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`0?ooooo`;o0000goooool2o`0000Sooooo0_l00005ooooo`;o0000=ooo
ool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l0
000;ooooo`;o0000eoooool002_ooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l0000;
ooooo`;o0000eoooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo2oooool2o`0002kooooo000[oooo
o`03o`000?oooooooooo0?oooooo2oooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001So
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001So
oooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Joooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Koooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hoooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?oo
ool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgo
oooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEE
EOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`00
00;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00kooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0oooooolDooooo`000oooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3oooo
o`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@
41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`3ooooooa?ooooo0004ooooo`04omgMgOl0003o410@
olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@
4?o<c<`Booooo`05o`000?ooooooooooooooool000004_ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo0?oooooo4_ooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko
410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hB
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`3ooooooa?ooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00Wo
EEEEoiRHV?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8B
ooooo`05o`000?n7QhOoooooojVYZOl000005?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0oooooolDooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@
413ooooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo5_ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM037ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo0?oooooo5_ooool000oooooo
00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0`ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`000?oooooo5Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39142 Mdot
.03333 .35022 Mdot
.0381 .35022 Mdot
.04286 .32962 Mdot
.04762 .28842 Mdot
.05238 .26781 Mdot
.05714 .30902 Mdot
.0619 .28842 Mdot
.06667 .28842 Mdot
.07143 .35022 Mdot
.07619 .32962 Mdot
.08095 .35022 Mdot
.08571 .43262 Mdot
.09048 .28842 Mdot
.09524 .24721 Mdot
.1 .37082 Mdot
.10476 .32962 Mdot
.10952 .32962 Mdot
.11429 .24721 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .35022 Mdot
.1381 .28842 Mdot
.14286 .26781 Mdot
.14762 .30902 Mdot
.15238 .32962 Mdot
.15714 .30902 Mdot
.1619 .30902 Mdot
.16667 .35022 Mdot
.17143 .32962 Mdot
.17619 .32962 Mdot
.18095 .28842 Mdot
.18571 .28842 Mdot
.19048 .39142 Mdot
.19524 .30902 Mdot
.2 .28842 Mdot
.20476 .32962 Mdot
.20952 .28842 Mdot
.21429 .37082 Mdot
.21905 .37082 Mdot
.22381 .32962 Mdot
.22857 .24721 Mdot
.23333 .28842 Mdot
.2381 .32962 Mdot
.24286 .26781 Mdot
.24762 .24721 Mdot
.25238 .32962 Mdot
.25714 .30902 Mdot
.2619 .26781 Mdot
.26667 .30902 Mdot
.27143 .28842 Mdot
.27619 .20601 Mdot
.28095 .20601 Mdot
.28571 .39142 Mdot
.29048 .32962 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .20601 Mdot
.30952 .37082 Mdot
.31429 .43262 Mdot
.31905 .39142 Mdot
.32381 .37082 Mdot
.32857 .35022 Mdot
.33333 .32962 Mdot
.3381 .30902 Mdot
.34286 .24721 Mdot
.34762 .35022 Mdot
.35238 .30902 Mdot
.35714 .45322 Mdot
.3619 .35022 Mdot
.36667 .37082 Mdot
.37143 .24721 Mdot
.37619 .24721 Mdot
.38095 .30902 Mdot
.38571 .22661 Mdot
.39048 .24721 Mdot
.39524 .26781 Mdot
.4 .24721 Mdot
.40476 .24721 Mdot
.40952 .39142 Mdot
.41429 .26781 Mdot
.41905 .28842 Mdot
.42381 .28842 Mdot
.42857 .22661 Mdot
.43333 .24721 Mdot
.4381 .24721 Mdot
.44286 .35022 Mdot
.44762 .30902 Mdot
.45238 .32962 Mdot
.45714 .37082 Mdot
.4619 .26781 Mdot
.46667 .30902 Mdot
.47143 .32962 Mdot
.47619 .24721 Mdot
.48095 .35022 Mdot
.48571 .26781 Mdot
.49048 .28842 Mdot
.49524 .39142 Mdot
.5 .26781 Mdot
.50476 .30902 Mdot
.50952 .41202 Mdot
.51429 .26781 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .35022 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .35022 Mdot
.54762 .30902 Mdot
.55238 .32962 Mdot
.55714 .26781 Mdot
.5619 .32962 Mdot
.56667 .20601 Mdot
.57143 .39142 Mdot
.57619 .30902 Mdot
.58095 .18541 Mdot
.58571 .30902 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .28842 Mdot
.60476 .28842 Mdot
.60952 .35022 Mdot
.61429 .35022 Mdot
.61905 .30902 Mdot
.62381 .35022 Mdot
.62857 .39142 Mdot
.63333 .20601 Mdot
.6381 .26781 Mdot
.64286 .30902 Mdot
.64762 .41202 Mdot
.65238 .35022 Mdot
.65714 .28842 Mdot
.6619 .24721 Mdot
.66667 .24721 Mdot
.67143 .32962 Mdot
.67619 .28842 Mdot
.68095 .37082 Mdot
.68571 .28842 Mdot
.69048 .28842 Mdot
.69524 .26781 Mdot
.7 .24721 Mdot
.70476 .28842 Mdot
.70952 .22661 Mdot
.71429 .26781 Mdot
.71905 .26781 Mdot
.72381 .18541 Mdot
.72857 .41202 Mdot
.73333 .22661 Mdot
.7381 .32962 Mdot
.74286 .24721 Mdot
.74762 .32962 Mdot
.75238 .35022 Mdot
.75714 .32962 Mdot
.7619 .32962 Mdot
.76667 .30902 Mdot
.77143 .26781 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .28842 Mdot
.79048 .32962 Mdot
.79524 .26781 Mdot
.8 .32962 Mdot
.80476 .32962 Mdot
.80952 .18541 Mdot
.81429 .28842 Mdot
.81905 .20601 Mdot
.82381 .28842 Mdot
.82857 .41202 Mdot
.83333 .30902 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .37082 Mdot
.85714 .24721 Mdot
.8619 .41202 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .28842 Mdot
.88095 .26781 Mdot
.88571 .43262 Mdot
.89048 .32962 Mdot
.89524 .28842 Mdot
.9 .20601 Mdot
.90476 .32962 Mdot
.90952 .35022 Mdot
.91429 .45322 Mdot
.91905 .32962 Mdot
.92381 .18541 Mdot
.92857 .32962 Mdot
.93333 .32962 Mdot
.9381 .30902 Mdot
.94286 .39142 Mdot
.94762 .30902 Mdot
.95238 .32962 Mdot
.95714 .26781 Mdot
.9619 .26781 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .28842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0002Vooooo`;o0000:Oooool2o`0000kooooo0_l00008ooooo`;o00008Oooool2o`0002_o
oooo000[ooooo`03o`000?oooooooooo0:Gooooo0_l0000Yooooo`;o00003_ooool2o`0000Sooooo
0_l0000Qooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`0004Wooooo0ol00006ooooo`;o0000COooool2o`0001;ooooo0_l0000fooooo`;o0000
5oooool2o`0003;ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo04Wooooo0ol00006ooooo`;o0000COooool2o`0001;ooooo
0_l0000fooooo`;o00005oooool2o`0003;ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
001[ooooo`;o00002oooool2o`0001kooooo0_l0000cooooo`;o00001Oooool2o`0002Sooooo0_l0
000kooooo`00:oooool00ol0003oooooooooo`1Zooooo`;o00002oooool2o`0001kooooo0_l0000c
ooooo`;o00001Oooool2o`0002Sooooo0_l0000kooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo01;ooooo0_l00004ooooo`;o00008?ooool2o`0000Cooooo0_l0000Kooooo`;o00001oooool3
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l00009ooooo`;o0000=oooool3
o`0000Sooooo0_l0000;ooooo`;o00008Oooool4o`0003gooooo000[ooooo`;o00004oooool2o`00
00Cooooo0_l0000Pooooo`;o00001?ooool2o`0001_ooooo0_l00007ooooo`?o00000_ooool2o`00
0003ooooool0003o000000;o00001_ooool4o`0000Wooooo0_l0000gooooo`?o00002?ooool2o`00
00_ooooo0_l0000Qooooo`Co0000?Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o00001_ooool2o`0001[ooooo0_l0000Looooo`?o000000?o<S8bomgMgOoo
ool00_l000001?lb<S;o0000oc8b<_o^k^h4ooooo`;o00007?ooool2o`0000Cooooo0_l0000<oooo
o`Ko000000Go410@o`000?l0003ok^k^oc8b<P03o`0000;ooooo1?l000000olb<S;ok^k^ooooo`02
o`0000Cooooo0_l0000Fooooo`;o00004?ooool2o`000003ooooool0003o000000Co00000_ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Gooooo
0_l0000>ooooo`;o00002?ooool2o`00013ooooo2?l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`05ooooo`;o
00006_ooool2o`0001cooooo0_l000001?ooooooMgMgoc8b<_ooool2o`000004oiRHV?ooooooV9RH
ogMgM`Cooooo0_l0000Looooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`03o`000?oooooo
oooo00;o000000?oMgMgoiRHV?ooool00_l00002ooooo`?o000000CooooooiRHV?mgMgOooooo0_l0
0004ooooo`;o00005_ooool2o`00013ooooo0_l00003ooooo`Co00001Oooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`02o`0000Gooooo0_l0000>ooooo`;o00002?ooool2o`00
013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003o`000005ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo04?ooooo00Co
0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0
003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0<_ooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo
00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo03?ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
=_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03Oooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Aooooo`00:oooool2o`0000Gooooo0_l00002ooooo`Co00001Oooool2o`0000co
oooo0_l0000;ooooo`Co00000_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000ooooo`05ooooo`05ogMgMol0003o0000oiRHV?mgMgL0:Oooool4o`0000gooooo00?o0000oooo
ooooool00_ooool2o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?l0003o0000ogMgM`0A
ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool2o`0000Oooooo1?l00003ooooo`;o00002Oooool2o`0000Co
oooo0_l0000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool2o`000003ooooool0003o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`04oooo
o`;o00000_ooool4o`0000Gooooo0_l0000<ooooo`;o00002oooool4o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`05onk^k_l0003o0000
oc8b<_o^k^h0:Oooool4o`0000_ooooo00?oEEEEofIVI_l000001?ooool3o`000003oc8b<_o^k^ko
oooo00;ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Aooooo`;o000000Coooooo`000?l0003o0000
3_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oIVIVo`000?oo
ool01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001oooool4o`00
00?ooooo0_l00009ooooo`;o00001?ooool2o`0000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000
<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00Oooooo
0_l00003ooooo`03o`000?oooooooooo00[ooooo1Ol00004ooooo`;o000000?oooooo`000?l00000
0_l00007ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`Go00003?ooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool3o`0000Kooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo
0ol00002ooooo`;o00002Oooool3o`0000_ooooo0_l00007ooooo`Co00000_ooool00ol0003ooooo
ooooo`04ooooo`;o00001Oooool2o`0000gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`;o00003Oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?oooooo0000o`000?ooool00_l00007ooooo`03o`000?oooooooooo017o
oooo00?o0000oa0@4?nHV9P01_ooool002_ooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Aooooo`04o`000?o^k^koEEEEohN7Q`Gooooo000[ooooo`03o`000?oooooooooo0?oooooo
<_ooool01Ol0003oooooodA4A?l0003o410@00Cooooo000[ooooo`03o`000?oooooooooo0?oooooo
<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o
0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l00007
ooooo`?o00002oooool2o`0000Cooooo1?l00006ooooo`;o00001?ooool2o`0000;ooooo0_l00003
ooooo`;o00002Oooool2o`0000_ooooo0_l0000Rooooo`;o00001?ooool2o`0001Kooooo0_l00000
0ooooooo0000o`000008ooooo`;o00005Oooool2o`0001?ooooo1?l000000ooooooo0000o`000002
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000=ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000Iooooo`;o00002?ooool0
02_ooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo0ol0000;ooooo`;o00001?ooool4o`00
00Kooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00002oooool2o`00
02;ooooo0_l00004ooooo`;o00005_ooool2o`000003ooooool0003o000000Sooooo0_l0000Eoooo
o`;o00004oooool4o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o0000
00;o00002Oooool2o`0000gooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00000oooool2o`0002?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooool000000ol00008oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l0000_ooooo`;o00000oooool2o`00
00?ooooo0_l0000Fooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`;o00004_ooool3o`00
0003ooooool0003o000000Oooooo0_l0000Looooo`;o0000;Oooool2o`00033ooooo000[ooooo`Ko
00002?ooool2o`000003ooooool0003o000000kooooo0_l00008ooooo`;o0000;oooool2o`0000?o
oooo0_l00003ooooo`;o00005_ooool2o`0000[ooooo0_l0000<ooooo`;o00000oooool2o`0001;o
oooo0ol000000ooooooo0000o`000007ooooo`;o00007?ooool2o`0002gooooo0_l0000`ooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000Eooooo`;o0000
8?ooool4o`0001Wooooo0_l00002ooooo`;o00002oooool2o`0001[ooooo0_l00011ooooo`;o0000
<_ooool2o`0002;ooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`0Dooooo`;o00008?oo
ool4o`0001Wooooo0_l00002ooooo`;o00002oooool2o`0001[ooooo0_l00011ooooo`;o0000<_oo
ool2o`0002;ooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000;oooool2o`0001_ooooo0_l0
0008ooooo`;o00006Oooool2o`0001Sooooo0_l0000Eooooo`;o00003oooool2o`0002gooooo0_l0
000^ooooo`;o00009_ooool002_ooooo0ol0000_ooooo`;o00006oooool2o`0000Sooooo0_l0000I
ooooo`;o00006?ooool2o`0001Gooooo0_l0000?ooooo`;o0000;Oooool2o`0002kooooo0_l0000V
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002?ooooo`;o0000:?ooool2
o`0001Oooooo0_l0000Looooo`;o00002?ooool2o`0003kooooo000Kooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo08oooooo0_l0000X
ooooo`;o00005oooool2o`0001cooooo0_l00008ooooo`;o0000?_ooool001_ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolk
ooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`0?ooooo`;o0000@oooool2o`000:_ooooo0_l0000goooo
o`00:oooool2o`00013ooooo0_l00013ooooo`;o0000Zoooool2o`0003Oooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00057ooooo0_l0000?ooooo`;o0000
Yoooool2o`0002kooooo000[ooooo`03o`000?oooooooooo053ooooo0_l0000?ooooo`;o0000Yooo
ool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`00
6Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_o
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooo
oc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003ooooo
odCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403ooooo
odCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<oooo
o`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?o
oooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o
00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0oooooolE
ooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooo
oiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo
00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmEEEGoMgMgoooooonHV9So8B4Q0?oooooo5Oooool0
00Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@
4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`00003ooooooaGooooo0004ooooo`04
onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKo
QhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@3ooooooaGo
oooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@413o
k^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVYZOl0
00005?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0oooooolEoooo
o`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmE
EED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool04oooool01_l0003oooooooooooooooooEEEEohN7Qooooooo6?ooool000oooooo00OoEEEEoiRH
V?ooooooooooomgMgOl0003ogMgM037ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgM
gOl@413oV9RH0?oooooo5oooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWooooooooo
o`0`ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool01?o<c<coA4A4o`000?l@413ooooooaGo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .38112 Mdot
.03333 .36052 Mdot
.0381 .36052 Mdot
.04286 .31932 Mdot
.04762 .29872 Mdot
.05238 .25751 Mdot
.05714 .29872 Mdot
.0619 .29872 Mdot
.06667 .29872 Mdot
.07143 .33992 Mdot
.07619 .31932 Mdot
.08095 .36052 Mdot
.08571 .44292 Mdot
.09048 .27812 Mdot
.09524 .25751 Mdot
.1 .36052 Mdot
.10476 .33992 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .29872 Mdot
.12381 .29872 Mdot
.12857 .31932 Mdot
.13333 .33992 Mdot
.1381 .29872 Mdot
.14286 .27812 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .29872 Mdot
.1619 .31932 Mdot
.16667 .33992 Mdot
.17143 .33992 Mdot
.17619 .33992 Mdot
.18095 .29872 Mdot
.18571 .27812 Mdot
.19048 .38112 Mdot
.19524 .31932 Mdot
.2 .29872 Mdot
.20476 .33992 Mdot
.20952 .27812 Mdot
.21429 .36052 Mdot
.21905 .36052 Mdot
.22381 .31932 Mdot
.22857 .25751 Mdot
.23333 .29872 Mdot
.2381 .33992 Mdot
.24286 .25751 Mdot
.24762 .25751 Mdot
.25238 .31932 Mdot
.25714 .29872 Mdot
.2619 .27812 Mdot
.26667 .31932 Mdot
.27143 .29872 Mdot
.27619 .21631 Mdot
.28095 .21631 Mdot
.28571 .38112 Mdot
.29048 .31932 Mdot
.29524 .25751 Mdot
.3 .46353 Mdot
.30476 .21631 Mdot
.30952 .38112 Mdot
.31429 .44292 Mdot
.31905 .40172 Mdot
.32381 .38112 Mdot
.32857 .33992 Mdot
.33333 .33992 Mdot
.3381 .29872 Mdot
.34286 .25751 Mdot
.34762 .36052 Mdot
.35238 .29872 Mdot
.35714 .44292 Mdot
.3619 .36052 Mdot
.36667 .38112 Mdot
.37143 .23691 Mdot
.37619 .25751 Mdot
.38095 .29872 Mdot
.38571 .21631 Mdot
.39048 .23691 Mdot
.39524 .25751 Mdot
.4 .23691 Mdot
.40476 .23691 Mdot
.40952 .40172 Mdot
.41429 .27812 Mdot
.41905 .29872 Mdot
.42381 .27812 Mdot
.42857 .21631 Mdot
.43333 .23691 Mdot
.4381 .25751 Mdot
.44286 .36052 Mdot
.44762 .29872 Mdot
.45238 .31932 Mdot
.45714 .36052 Mdot
.4619 .27812 Mdot
.46667 .29872 Mdot
.47143 .33992 Mdot
.47619 .23691 Mdot
.48095 .36052 Mdot
.48571 .27812 Mdot
.49048 .27812 Mdot
.49524 .38112 Mdot
.5 .27812 Mdot
.50476 .31932 Mdot
.50952 .40172 Mdot
.51429 .25751 Mdot
.51905 .25751 Mdot
.52381 .27812 Mdot
.52857 .36052 Mdot
.53333 .21631 Mdot
.5381 .25751 Mdot
.54286 .33992 Mdot
.54762 .31932 Mdot
.55238 .33992 Mdot
.55714 .25751 Mdot
.5619 .33992 Mdot
.56667 .21631 Mdot
.57143 .38112 Mdot
.57619 .29872 Mdot
.58095 .17511 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .31932 Mdot
.6 .27812 Mdot
.60476 .29872 Mdot
.60952 .33992 Mdot
.61429 .33992 Mdot
.61905 .29872 Mdot
.62381 .36052 Mdot
.62857 .38112 Mdot
.63333 .21631 Mdot
.6381 .25751 Mdot
.64286 .31932 Mdot
.64762 .42232 Mdot
.65238 .33992 Mdot
.65714 .29872 Mdot
.6619 .25751 Mdot
.66667 .25751 Mdot
.67143 .31932 Mdot
.67619 .27812 Mdot
.68095 .36052 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .27812 Mdot
.7 .23691 Mdot
.70476 .29872 Mdot
.70952 .21631 Mdot
.71429 .25751 Mdot
.71905 .27812 Mdot
.72381 .17511 Mdot
.72857 .40172 Mdot
.73333 .23691 Mdot
.7381 .33992 Mdot
.74286 .25751 Mdot
.74762 .33992 Mdot
.75238 .33992 Mdot
.75714 .31932 Mdot
.7619 .33992 Mdot
.76667 .29872 Mdot
.77143 .25751 Mdot
.77619 .17511 Mdot
.78095 .38112 Mdot
.78571 .29872 Mdot
.79048 .31932 Mdot
.79524 .25751 Mdot
.8 .33992 Mdot
.80476 .33992 Mdot
.80952 .19571 Mdot
.81429 .27812 Mdot
.81905 .21631 Mdot
.82381 .27812 Mdot
.82857 .40172 Mdot
.83333 .29872 Mdot
.8381 .27812 Mdot
.84286 .33992 Mdot
.84762 .25751 Mdot
.85238 .38112 Mdot
.85714 .25751 Mdot
.8619 .40172 Mdot
.86667 .25751 Mdot
.87143 .21631 Mdot
.87619 .27812 Mdot
.88095 .27812 Mdot
.88571 .44292 Mdot
.89048 .31932 Mdot
.89524 .27812 Mdot
.9 .21631 Mdot
.90476 .33992 Mdot
.90952 .33992 Mdot
.91429 .46353 Mdot
.91905 .31932 Mdot
.92381 .17511 Mdot
.92857 .33992 Mdot
.93333 .33992 Mdot
.9381 .31932 Mdot
.94286 .40172 Mdot
.94762 .31932 Mdot
.95238 .31932 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .27812 Mdot
.97143 .36052 Mdot
.97619 .27812 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0YOooool2o`0002Wooooo0_l0
000>ooooo`;o0000:oooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0:Gooooo0_l0000Y
ooooo`;o00003_ooool2o`0002_ooooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0j_ooool2
o`0004kooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo
00?o0000ooooooooool0j_ooool2o`0004kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
BOooool3o`0000Kooooo0_l0000Fooooo`;o00002oooool2o`0001kooooo0_l00008ooooo`;o0000
4_ooool2o`0001Gooooo0_l0000Oooooo`;o00003_ooool2o`0000Oooooo0_l0000booooo`006ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`19ooooo`?o00001_ooool2o`0001Kooooo0_l0000;ooooo`;o00007_ooool2o`0000Sooooo
0_l0000Booooo`;o00005Oooool2o`0001oooooo0_l0000>ooooo`;o00001oooool2o`0003;ooooo
000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`0Hooooo`;o0000C?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Ko
oooo0_l0000;ooooo`;o0000@_ooool2o`0000Sooooo0_l0001Uooooo`00:oooool00ol0003ooooo
ooooo`0Hooooo`;o0000C?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo
0_l0000;ooooo`;o0000@_ooool2o`0000Sooooo0_l0001Uooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
1Oooool2o`0000_ooooo0_l0000Vooooo`;o00000oooool3o`0000gooooo0_l0000<ooooo`;o0000
2?ooool2o`0000Cooooo0_l0000;ooooo`;o00005Oooool3o`0000Cooooo0_l00004ooooo`;o0000
5_ooool2o`0000Kooooo0ol0000<ooooo`;o00001oooool2o`0000Oooooo0_l00005ooooo`;o0000
3_ooool2o`000003ooooool0003o000000;o0000?Oooool002_ooooo00?o0000ooooooooool01Ooo
ool2o`0000_ooooo0_l0000Vooooo`;o00000oooool3o`0000gooooo0_l0000<ooooo`;o00002?oo
ool2o`0000Cooooo0_l0000;ooooo`;o00005Oooool3o`0000Cooooo0_l00004ooooo`;o00005_oo
ool2o`0000Kooooo0ol0000<ooooo`;o00001oooool2o`0000Oooooo0_l00005ooooo`;o00003_oo
ool2o`000003ooooool0003o000000;o0000?Oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000@?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0doooo
o`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^03?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000oooo
ooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`0cooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400C
ooooo`00:oooool00ol0003oooooooooo`0Aooooo`;o00003_ooool2o`0000_ooooo0_l00005oooo
o`;o00002oooool00omgMgOo<S8booooo`02o`0000?ooooo00?o0000ooooooooool09_ooool2o`00
0003ooooool0003o000000Wooooo0_l00002ooooo`03o`000?oooooooooo00Co000000?oooooo`00
0?l000000oooool00ol0003oooooo`000002o`0001Cooooo0_l0000Eooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`04o`000?oooooo0000o`0000Gooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo00_ooooo1?l00003ooooo`;o00002Oooool4o`0000;ooooo
0_l0000>ooooo`03oiRHV?lQ8B7ok^k^00Go000000?oooooo`000?l000000oooool01Ol0003ooooo
oooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo017ooooo0_l0000>ooooo`;o0000
2oooool2o`0000Gooooo0_l00008ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003oooo
o`03o`000?oooooooooo02Kooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool00ol0
003oooooooooo`04o`000003ooooool0003o000000?ooooo00?o0000ooooool000000_l0000Doooo
o`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool01?l0003oooooo`000?l0
0002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000go
oooo1?l00003ooooo`;o00002Oooool4o`0000;ooooo0_l0000?ooooo`03ogMgMomVIVKo000000Co
000000?oooooo`000?l000000oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`00:oooool2o`00043o
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo
03oooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo
00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000003o`0000gooooo1?l00002oooo
o`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0_l00002oooo
o`;o00004oooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo0_l00003oooo
o`;o00008?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00008oooo
o`;o00000_ooool2o`00017ooooo0_l00004ooooo`;o00003?ooool2o`0004Oooooo000[ooooo`03
o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000003o`0000gooooo1?l00002ooooo`;o
00001?ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o
00004oooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`;o
00008?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`;o
00000_ooool2o`00017ooooo0_l00004ooooo`;o00003?ooool2o`0003gooooo0_l00002ooooo`03
oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003ooooo
onk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Go
oooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003ooooooooo
o`02ooooo`;o00002?ooool2o`0000kooooo0_l00004ooooo`?o000000?oooooo`000?l000002?oo
ool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0000_ooooo`;o00003_oo
ool2o`0000_ooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l0
000Hooooo`;o00002?ooool2o`0001gooooo0_l00006ooooo`;o00001?ooool2o`000004ooooool0
003o0000o`0001[ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003ooooo
ooooo`02ooooo`;o00002?ooool2o`0000kooooo0_l00004ooooo`?o000000?oooooo`000?l00000
2?ooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0000_ooooo`;o0000
3_ooool2o`0000_ooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo
0_l0000Hooooo`;o00002?ooool2o`0001gooooo0_l00006ooooo`;o00001?ooool2o`000004oooo
ool0003o0000o`0001[ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0
oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<Ooo
ool2o`0000Sooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo00_ooooo0_l00008ooooo`?o00001_ooool2o`0000So
oooo1Ol00006ooooo`;o00002?ooool2o`0001[ooooo0ol0000Xooooo`;o00005?ooool4o`000003
ooooool0003o000000gooooo0ol0000:ooooo`;o00006?ooool6o`000003ooooool0003o000000Wo
oooo1?l00009ooooo`;o00004Oooool3o`0000Cooooo1?l0000Xooooo`00:oooool00ol0003ooooo
ooooo`0;ooooo`;o00002?ooool3o`0000Kooooo0_l00008ooooo`Go00001_ooool2o`0000Sooooo
0_l0000Jooooo`?o0000:?ooool2o`0001Cooooo1?l000000ooooooo0000o`00000=ooooo`?o0000
2_ooool2o`0001Sooooo1_l000000ooooooo0000o`000009ooooo`Co00002Oooool2o`00017ooooo
0ol00004ooooo`Co0000:?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooool000000ol0000;ooooo`;o00001?ooool2o`00023ooooo1?l0000Tooooo`;o00000ooo
ool2o`0001Kooooo0_l00003ooooo`;o00001Oooool2o`0000cooooo0_l0000Kooooo`;o00003ooo
ool2o`0005Kooooo0_l0000Mooooo`00:oooool00ol0003oooooo`000003o`0000_ooooo0_l00004
ooooo`;o00008?ooool4o`0002Cooooo0_l00003ooooo`;o00005_ooool2o`0000?ooooo0_l00005
ooooo`;o00003?ooool2o`0001_ooooo0_l0000?ooooo`;o0000E_ooool2o`0001gooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool3
o`0002oooooo0_l0000Kooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00009Oooool2
o`0001Gooooo0_l0000?ooooo`;o0000;Oooool2o`0001?ooooo0_l00011ooooo`00:oooool3o`00
02oooooo0_l0000Kooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00009Oooool2o`00
01Gooooo0_l0000?ooooo`;o0000;Oooool2o`0001?ooooo0_l00011ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0E_ooool2o`0001Wooooo0_l0000Looooo`;o0000@Oooool2o`0001cooooo0_l00008oooo
o`;o00005_ooool2o`0002Kooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPKooooo00?o0000ooooooooool0E_ooool2o`0001Wooooo0_l0000Looooo`;o0000@Ooo
ool2o`0001cooooo0_l00008ooooo`;o00005_ooool2o`0002Kooooo000Kooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0
003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`2iooooo`;o0000Ooooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0^Oooool2o`0007oooooo000Iooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo00oooooo0_l00013ooooo`;o00002oooool2o`0009kooooo0_l0
000gooooo`00:oooool00ol0003oooooooooo`0?ooooo`;o0000@oooool2o`0000_ooooo0_l0002N
ooooo`;o0000=oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo053ooooo0_l0002hooooo`;o0000;_ooool0
02_ooooo00?o0000ooooooooool0D?ooool2o`000;Sooooo0_l0000^ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wo
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Koooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolk
ooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooooom4
ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooooom4
ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?ooool0
0olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003oooo
o`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02o`00
00;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0>ooooo`Go00001Oooool00ol0003ok^k^ooooo`3ooooooaGooooo0003oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?o
oooo00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000
oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`03oeEEEOnYZJWooooo0?oooooo5Oooool000Cooooo00CogMgMo`000?l@
413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o
410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Booooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?oZJVYoeEEEOooool0oooooolEooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^
k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^
kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06
ooooo`03ob4Q8Ooooooooooo0?oooooo5?ooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool0
2OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b
<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Dooooo`03ogMgMomVIVKooooo00Gooooo00?oEEEE
olc<c?ooool0oooooolDooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo
00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg
00;o000000?oV9RHooooooooool04oooool00ol0003oooooooooo`04ooooo`03ojVYZOmgMgOooooo
0?oooooo5?ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM037ooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?oooooooooooooooolb<S80oooooolEooooo`003ooo
ool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo033ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`Go0000oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39142 Mdot
.03333 .35022 Mdot
.0381 .35022 Mdot
.04286 .30902 Mdot
.04762 .28842 Mdot
.05238 .26781 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .30902 Mdot
.07143 .35022 Mdot
.07619 .30902 Mdot
.08095 .37082 Mdot
.08571 .43262 Mdot
.09048 .28842 Mdot
.09524 .26781 Mdot
.1 .37082 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .30902 Mdot
.12381 .28842 Mdot
.12857 .30902 Mdot
.13333 .35022 Mdot
.1381 .28842 Mdot
.14286 .26781 Mdot
.14762 .32962 Mdot
.15238 .32962 Mdot
.15714 .28842 Mdot
.1619 .30902 Mdot
.16667 .35022 Mdot
.17143 .32962 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .28842 Mdot
.19048 .37082 Mdot
.19524 .32962 Mdot
.2 .28842 Mdot
.20476 .32962 Mdot
.20952 .28842 Mdot
.21429 .35022 Mdot
.21905 .37082 Mdot
.22381 .32962 Mdot
.22857 .24721 Mdot
.23333 .28842 Mdot
.2381 .32962 Mdot
.24286 .24721 Mdot
.24762 .26781 Mdot
.25238 .32962 Mdot
.25714 .30902 Mdot
.2619 .26781 Mdot
.26667 .30902 Mdot
.27143 .30902 Mdot
.27619 .22661 Mdot
.28095 .22661 Mdot
.28571 .39142 Mdot
.29048 .30902 Mdot
.29524 .24721 Mdot
.3 .45322 Mdot
.30476 .22661 Mdot
.30952 .37082 Mdot
.31429 .45322 Mdot
.31905 .39142 Mdot
.32381 .39142 Mdot
.32857 .35022 Mdot
.33333 .32962 Mdot
.3381 .30902 Mdot
.34286 .26781 Mdot
.34762 .37082 Mdot
.35238 .28842 Mdot
.35714 .43262 Mdot
.3619 .35022 Mdot
.36667 .39142 Mdot
.37143 .22661 Mdot
.37619 .26781 Mdot
.38095 .30902 Mdot
.38571 .20601 Mdot
.39048 .22661 Mdot
.39524 .26781 Mdot
.4 .22661 Mdot
.40476 .22661 Mdot
.40952 .41202 Mdot
.41429 .28842 Mdot
.41905 .28842 Mdot
.42381 .28842 Mdot
.42857 .22661 Mdot
.43333 .22661 Mdot
.4381 .26781 Mdot
.44286 .37082 Mdot
.44762 .30902 Mdot
.45238 .30902 Mdot
.45714 .35022 Mdot
.4619 .26781 Mdot
.46667 .30902 Mdot
.47143 .32962 Mdot
.47619 .22661 Mdot
.48095 .37082 Mdot
.48571 .26781 Mdot
.49048 .26781 Mdot
.49524 .39142 Mdot
.5 .28842 Mdot
.50476 .32962 Mdot
.50952 .39142 Mdot
.51429 .26781 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .35022 Mdot
.53333 .22661 Mdot
.5381 .24721 Mdot
.54286 .35022 Mdot
.54762 .30902 Mdot
.55238 .35022 Mdot
.55714 .24721 Mdot
.5619 .35022 Mdot
.56667 .22661 Mdot
.57143 .39142 Mdot
.57619 .28842 Mdot
.58095 .16481 Mdot
.58571 .32962 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .28842 Mdot
.60476 .28842 Mdot
.60952 .35022 Mdot
.61429 .35022 Mdot
.61905 .30902 Mdot
.62381 .35022 Mdot
.62857 .39142 Mdot
.63333 .20601 Mdot
.6381 .26781 Mdot
.64286 .30902 Mdot
.64762 .43262 Mdot
.65238 .35022 Mdot
.65714 .28842 Mdot
.6619 .24721 Mdot
.66667 .26781 Mdot
.67143 .30902 Mdot
.67619 .26781 Mdot
.68095 .37082 Mdot
.68571 .28842 Mdot
.69048 .30902 Mdot
.69524 .26781 Mdot
.7 .22661 Mdot
.70476 .30902 Mdot
.70952 .20601 Mdot
.71429 .26781 Mdot
.71905 .26781 Mdot
.72381 .16481 Mdot
.72857 .41202 Mdot
.73333 .22661 Mdot
.7381 .32962 Mdot
.74286 .24721 Mdot
.74762 .35022 Mdot
.75238 .32962 Mdot
.75714 .32962 Mdot
.7619 .35022 Mdot
.76667 .30902 Mdot
.77143 .24721 Mdot
.77619 .16481 Mdot
.78095 .39142 Mdot
.78571 .28842 Mdot
.79048 .32962 Mdot
.79524 .24721 Mdot
.8 .35022 Mdot
.80476 .32962 Mdot
.80952 .20601 Mdot
.81429 .28842 Mdot
.81905 .20601 Mdot
.82381 .26781 Mdot
.82857 .39142 Mdot
.83333 .30902 Mdot
.8381 .28842 Mdot
.84286 .32962 Mdot
.84762 .24721 Mdot
.85238 .37082 Mdot
.85714 .24721 Mdot
.8619 .39142 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .28842 Mdot
.88095 .28842 Mdot
.88571 .45322 Mdot
.89048 .30902 Mdot
.89524 .28842 Mdot
.9 .20601 Mdot
.90476 .32962 Mdot
.90952 .32962 Mdot
.91429 .45322 Mdot
.91905 .32962 Mdot
.92381 .16481 Mdot
.92857 .35022 Mdot
.93333 .35022 Mdot
.9381 .32962 Mdot
.94286 .41202 Mdot
.94762 .30902 Mdot
.95238 .32962 Mdot
.95714 .26781 Mdot
.9619 .26781 Mdot
.96667 .26781 Mdot
.97143 .37082 Mdot
.97619 .26781 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`2Uooooo`;o0000:Oooool2
o`0000kooooo0_l0000[ooooo`;o0000:oooool002_ooooo0_l0002Vooooo`;o0000:Oooool2o`00
00kooooo0_l0000[ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0001Zooooo`;o0000
BOooool2o`0001Gooooo0_l0000Looooo`;o000000?oooooo`000?l000005oooool2o`0003;ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo06[ooooo0_l00019ooooo`;o00005Oooool2o`0001cooooo0_l000000ooooooo0000
o`00000Gooooo`;o0000<_ooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0001Wooooo0_l0
000_ooooo`?o00001_ooool2o`0001;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`?o00002oooool2o`00013ooooo0_l00008ooooo`;o00009_ooool2o`0000Sooooo0_l0
000Xooooo`;o0000>oooool002_ooooo00?o0000ooooooooool06?ooool2o`0002oooooo0ol00006
ooooo`;o00004_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol0000;
ooooo`;o00004?ooool2o`0000Sooooo0_l0000Vooooo`;o00002?ooool2o`0002Sooooo0_l0000k
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o00003_ooool2
o`0004Oooooo0_l00004ooooo`;o00007_ooool2o`0001Kooooo0_l00007ooooo`;o00001Oooool2
o`0000kooooo0_l000000ooooooo0000o`000002o`0003gooooo000[ooooo`;o0000>oooool2o`00
00?ooooo0_l0000>ooooo`;o0000Aoooool2o`0000Cooooo0_l0000Nooooo`;o00005_ooool2o`00
00Oooooo0_l00005ooooo`;o00003_ooool2o`000003ooooool0003o000000;o0000?Oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o00001_ooool2o`0000_o
oooo0_l0000=ooooo`;o00007?ooool01_m4A4Co0000o`000?lb<S;ogMgMooooo`;o000000Co<S8b
o`000?lb<S;ok^k^4_ooool2o`0000Sooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo1_l0
00000ol@413o0000o`000003o`000004oc8b<_o^k^koooooooooo`Co000000?o<S8bonk^k_ooool0
7_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00oooooo0_l0000Rooooo`go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[oooo
o`03o`000?oooooooooo00Gooooo0_l0000;ooooo`;o00003Oooool2o`0001gooooo0_l000000omg
MgOo<S8booooo`02o`000004oiRHV?ooooooV9RHogMgMa;ooooo0_l00008ooooo`;o00001?ooool2
o`0000_ooooo0_l00005ooooo`;o00000_ooool00ol0003oooooooooo`04o`000003oooooonHV9So
MgMg00;ooooo0ol000000oooooooV9RHogMgM`0Oooooo`;o00001oooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`Co00001Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0?ooooo`;o00008_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go000000?oooooo`00
0?l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo
04?ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
=_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool0<_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo03?o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000fooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool00000=_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400foooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`00:oooool2o`0000Gooooo0_l0000;ooooo`;o00002?oo
ool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`;o000000?oooooo`000?ooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo
0_l0000Aooooo`Go00003Oooool00ol0003oooooooooo`02ooooo`03ogMgMonHV9Sooooo00;o0000
0oooool01OmgMgOoV9RHo`000?l0003oMgMg00gooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00003_ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00007ooooo`;o00001Oooool2
o`0000Wooooo1?l00002ooooo`;o00003?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo
00?o0000ooooooooool01?ooool2o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo
0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000
o`000002o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`;o00004Oooool5o`0000_o
oooo00?oEEEEofIVI_l000001?ooool00oo^k^ko<S8bo`000002o`0000?ooooo00Gok^k^oc8b<_l0
003o0000onk^kP0=ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000kooooo0_l00007
ooooo`;o00001?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Cooooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo1?l00002ooooo`;o00003?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo<Ooo
ool2o`0000;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000ooooooooool0oooooolb
ooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`0000cooooo00Co0000
oiRHV?lb<S;oc<c<1Oooool002_ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1ol0000;
ooooo`;o000000?oooooo`000?l000002?ooool3o`0000?ooooo0_l00009ooooo`03o`000?oooooo
oooo00Wooooo1_l00004ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00001?ooool0
0ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`?o00000_ooool2
o`0000Wooooo00?o0000ooooooooool02oooool2o`0000gooooo00?o0000ooooooooool01?ooool2
o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`03o`000?oooooo
oooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`03o`000?oooooo
oooo00;o00002_ooool00ol0003oooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`0A
ooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03
o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo01Gooooo0_l0000;ooooo`?o0000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Fooooo`;o0000:?ooool2o`0000Sooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
:_ooool2o`0000;ooooo0ol00008ooooo`;o00000oooool2o`0000Wooooo0_l0000Aooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000Iooooo`;o00002?ooool002_ooooo0_l0
000Fooooo`;o00002oooool3o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l00003ooooo`;o00005_ooool2o`0002Sooooo0_l00008ooooo`;o00005_oo
ool2o`000003ooooool0003o000002[ooooo0_l00002ooooo`?o00002?ooool2o`0000?ooooo0_l0
0009ooooo`;o00004Oooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00008ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooo`000003o`0000Sooooo0_l00009ooooo`;o00001_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o00008Oooool2o`0000Sooooo0_l0
000Kooooo`;o00004oooool2o`0000?ooooo1?l000000ooooooo0000o`00000=ooooo`?o000000?o
ooooo`000?l000001oooool2o`0001[ooooo0_l00003ooooo`;o00002Oooool2o`0002Gooooo1?l0
000Xooooo`00:oooool6o`0000Sooooo0_l00009ooooo`;o00001_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000009ooooo`;o00008Oooool2o`0000Sooooo0_l0000Kooooo`;o00004oooool2
o`0000?ooooo1?l000000ooooooo0000o`00000=ooooo`?o000000?oooooo`000?l000001oooool2
o`0001[ooooo0_l00003ooooo`;o00002Oooool2o`0002Gooooo1?l0000Xooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000?ooooo`;o00001?ooool2o`00
01Wooooo0_l00007ooooo`;o00006Oooool2o`0000Wooooo0_l0000Kooooo`;o00002_ooool2o`00
03[ooooo0_l0000booooo`;o00008_ooool2o`0001gooooo000[ooooo`03o`000?oooooooooo00ko
oooo0_l00004ooooo`;o00006Oooool2o`0000Oooooo0_l0000Iooooo`;o00002Oooool2o`0001_o
oooo0_l0000:ooooo`;o0000>_ooool2o`0003;ooooo0_l0000Rooooo`;o00007Oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool3o`0004cooooo0_l00008ooooo`?o00002oooool2o`0002Gooooo0_l00002ooooo`;o
00004Oooool2o`0000oooooo0_l0000]ooooo`;o00003?ooool2o`0000Sooooo0_l0000nooooo`00
:oooool3o`0004cooooo0_l00008ooooo`?o00002oooool2o`0002Gooooo0_l00002ooooo`;o0000
4Oooool2o`0000oooooo0_l0000]ooooo`;o00003?ooool2o`0000Sooooo0_l0000nooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0ol0001aooooo`;o0000Goooool2o`0003kooooo
0_l0000Vooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1aooooo`;o0000Goooool2o`0003kooooo0_l0000Vooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00oooooo0_l0001@ooooo`;o0000E_oo
ool2o`0007oooooo000[ooooo`;o00004?ooool2o`00053ooooo0_l0001Fooooo`;o0000Ooooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000DOooool2o`00
00;ooooo0_l0002[ooooo`;o00001oooool2o`0002kooooo000[ooooo`03o`000?oooooooooo053o
oooo0_l00002ooooo`;o0000Zoooool2o`0000Oooooo0_l0000^ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo>oooool0
01_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooo
oolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooo
oolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool00000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo
00?o0000okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooo
oom5ooooo`000oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8b
o`000?l000000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o
^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0>ooooo`Go00000ooo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<0?oooooo5Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zj
o`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHoooooooo
ooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000oooo
ooooooooooooo`000002ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@3ooooooaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo
0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Boooo
o`05o`000?ooooooooooooooool000004_ooool00onHV9So8B4Qonk^kP04ooooo`05o`000?oooooo
ooooooooool00000oooooolEooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@
413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;o
oooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80oooooolEooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86
ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomg
MgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?oMgMgofIVI_ooool00_ooool0
1Oo<c<co0000o`000?l0003oc<c<0?oooooo5Oooool000?ooooo0_l00002ooooo`;o00001Oooool0
0ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01?ooooo00Wo0000oooooooooooooooooa0@
4?nj^[[ooooookZj^_l@4100oooooolEooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`00
0?oMgMd0<Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zjo`00
003ooooooaGooooo000?ooooo`03okZj^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooaGooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .38112 Mdot
.03333 .33992 Mdot
.0381 .36052 Mdot
.04286 .29872 Mdot
.04762 .29872 Mdot
.05238 .27812 Mdot
.05714 .31932 Mdot
.0619 .31932 Mdot
.06667 .31932 Mdot
.07143 .36052 Mdot
.07619 .29872 Mdot
.08095 .38112 Mdot
.08571 .42232 Mdot
.09048 .27812 Mdot
.09524 .25751 Mdot
.1 .36052 Mdot
.10476 .31932 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .29872 Mdot
.12381 .27812 Mdot
.12857 .29872 Mdot
.13333 .36052 Mdot
.1381 .29872 Mdot
.14286 .27812 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .27812 Mdot
.1619 .29872 Mdot
.16667 .36052 Mdot
.17143 .31932 Mdot
.17619 .36052 Mdot
.18095 .31932 Mdot
.18571 .27812 Mdot
.19048 .36052 Mdot
.19524 .31932 Mdot
.2 .27812 Mdot
.20476 .31932 Mdot
.20952 .29872 Mdot
.21429 .36052 Mdot
.21905 .38112 Mdot
.22381 .31932 Mdot
.22857 .23691 Mdot
.23333 .27812 Mdot
.2381 .31932 Mdot
.24286 .23691 Mdot
.24762 .25751 Mdot
.25238 .31932 Mdot
.25714 .31932 Mdot
.2619 .27812 Mdot
.26667 .29872 Mdot
.27143 .29872 Mdot
.27619 .21631 Mdot
.28095 .23691 Mdot
.28571 .40172 Mdot
.29048 .29872 Mdot
.29524 .25751 Mdot
.3 .44292 Mdot
.30476 .21631 Mdot
.30952 .38112 Mdot
.31429 .46353 Mdot
.31905 .40172 Mdot
.32381 .38112 Mdot
.32857 .36052 Mdot
.33333 .33992 Mdot
.3381 .31932 Mdot
.34286 .25751 Mdot
.34762 .36052 Mdot
.35238 .27812 Mdot
.35714 .44292 Mdot
.3619 .36052 Mdot
.36667 .38112 Mdot
.37143 .23691 Mdot
.37619 .27812 Mdot
.38095 .29872 Mdot
.38571 .21631 Mdot
.39048 .21631 Mdot
.39524 .27812 Mdot
.4 .21631 Mdot
.40476 .23691 Mdot
.40952 .40172 Mdot
.41429 .27812 Mdot
.41905 .27812 Mdot
.42381 .29872 Mdot
.42857 .23691 Mdot
.43333 .21631 Mdot
.4381 .27812 Mdot
.44286 .38112 Mdot
.44762 .29872 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .25751 Mdot
.46667 .29872 Mdot
.47143 .33992 Mdot
.47619 .23691 Mdot
.48095 .38112 Mdot
.48571 .27812 Mdot
.49048 .27812 Mdot
.49524 .38112 Mdot
.5 .27812 Mdot
.50476 .33992 Mdot
.50952 .40172 Mdot
.51429 .25751 Mdot
.51905 .25751 Mdot
.52381 .29872 Mdot
.52857 .36052 Mdot
.53333 .23691 Mdot
.5381 .25751 Mdot
.54286 .36052 Mdot
.54762 .31932 Mdot
.55238 .33992 Mdot
.55714 .23691 Mdot
.5619 .36052 Mdot
.56667 .23691 Mdot
.57143 .40172 Mdot
.57619 .27812 Mdot
.58095 .17511 Mdot
.58571 .33992 Mdot
.59048 .27812 Mdot
.59524 .33992 Mdot
.6 .27812 Mdot
.60476 .27812 Mdot
.60952 .33992 Mdot
.61429 .33992 Mdot
.61905 .29872 Mdot
.62381 .33992 Mdot
.62857 .40172 Mdot
.63333 .21631 Mdot
.6381 .25751 Mdot
.64286 .31932 Mdot
.64762 .44292 Mdot
.65238 .33992 Mdot
.65714 .27812 Mdot
.6619 .23691 Mdot
.66667 .27812 Mdot
.67143 .31932 Mdot
.67619 .27812 Mdot
.68095 .38112 Mdot
.68571 .27812 Mdot
.69048 .31932 Mdot
.69524 .27812 Mdot
.7 .23691 Mdot
.70476 .31932 Mdot
.70952 .21631 Mdot
.71429 .25751 Mdot
.71905 .27812 Mdot
.72381 .17511 Mdot
.72857 .42232 Mdot
.73333 .23691 Mdot
.7381 .31932 Mdot
.74286 .25751 Mdot
.74762 .33992 Mdot
.75238 .33992 Mdot
.75714 .31932 Mdot
.7619 .36052 Mdot
.76667 .31932 Mdot
.77143 .25751 Mdot
.77619 .17511 Mdot
.78095 .40172 Mdot
.78571 .29872 Mdot
.79048 .31932 Mdot
.79524 .25751 Mdot
.8 .33992 Mdot
.80476 .31932 Mdot
.80952 .21631 Mdot
.81429 .29872 Mdot
.81905 .19571 Mdot
.82381 .25751 Mdot
.82857 .40172 Mdot
.83333 .31932 Mdot
.8381 .29872 Mdot
.84286 .31932 Mdot
.84762 .23691 Mdot
.85238 .36052 Mdot
.85714 .23691 Mdot
.8619 .38112 Mdot
.86667 .25751 Mdot
.87143 .21631 Mdot
.87619 .29872 Mdot
.88095 .29872 Mdot
.88571 .46353 Mdot
.89048 .29872 Mdot
.89524 .27812 Mdot
.9 .21631 Mdot
.90476 .33992 Mdot
.90952 .31932 Mdot
.91429 .44292 Mdot
.91905 .31932 Mdot
.92381 .15451 Mdot
.92857 .33992 Mdot
.93333 .33992 Mdot
.9381 .33992 Mdot
.94286 .40172 Mdot
.94762 .31932 Mdot
.95238 .31932 Mdot
.95714 .27812 Mdot
.9619 .25751 Mdot
.96667 .25751 Mdot
.97143 .38112 Mdot
.97619 .27812 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3oooooo`kooooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`3oooooo`kooooo
0_l0000[ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`2Uooooo`;o0000:Oooool2o`0000kooooo0_l0001Hooooo`00:oooool00ol0003oooooooooo`2U
ooooo`;o0000:Oooool2o`0000kooooo0_l0001Hooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0kOooool2
o`0004_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo
00?o0000ooooooooool0kOooool2o`0004_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
BOooool2o`0000Oooooo0_l0000Fooooo`?o000000?oooooo`000?l000002?ooool2o`0003_ooooo
0_l0000Eooooo`;o00007?ooool2o`00017ooooo0_l00007ooooo`;o0000<_ooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
BOooool2o`0000Oooooo0_l0000Fooooo`?o000000?oooooo`000?l000002?ooool2o`0003_ooooo
0_l0000Eooooo`;o00007?ooool2o`00017ooooo0_l00007ooooo`;o0000<_ooool001Wooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01So
oooo0_l0000Pooooo`;o00000oooool2o`0000Wooooo0_l0000Jooooo`;o00002?ooool2o`0000Go
oooo0_l0000<ooooo`;o00004?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Kooooo`;o
00002Oooool2o`0000Sooooo0_l0000Qooooo`;o000000?oooooo`000?l00000?oooool002_ooooo
00?o0000ooooooooool06?ooool2o`00023ooooo0_l00003ooooo`;o00002Oooool2o`0001[ooooo
0_l00008ooooo`;o00001Oooool2o`0000cooooo0_l0000@ooooo`;o00001Oooool2o`000003oooo
ool0003o000001_ooooo0_l00009ooooo`;o00002?ooool2o`00027ooooo0_l000000ooooooo0000
o`00000oooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool04_ooool2o`0002cooooo0_l0000=ooooo`;o0000
3?ooool2o`0002;ooooo0_l0000>ooooo`?o00001?ooool2o`0001cooooo0_l0000Eooooo`;o0000
1oooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0000Kooooo`Co0000
7_ooool002_ooooo00?o0000ooooooooool04_ooool2o`0002cooooo0_l0000=ooooo`;o00003?oo
ool2o`0002;ooooo0_l0000>ooooo`?o00001?ooool2o`0001cooooo0_l0000Eooooo`;o00001ooo
ool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0000Kooooo`Co00007_oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000@?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03?ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[oooo
o`03o`000?oooooooooo04;ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0
003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool00ol0003oooooooooo`05oooo
o`;o00002_ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00002oooo
o`;o00002?ooool2o`0000Cooooo00?oMgMgoc8b<_ooool00_l00003ooooo`03o`000?oooooooooo
01?ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0ol00004ooooo`;o00002Oooool00ol0
003oooooooooo`04o`000003ooooool0003o000000?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000kooooo0_l000001?oooooo0000o`00
0?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool01?l0003oooooo`000?l00005oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0Sooooo`;o00003_ooool0
0onHV9So8B4Qonk^kP02o`000004ooooool0003oooooooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000001?ooooo000[ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`;o00002?oo
ool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o000000Oo
ooooo`000?lQ8B7o0000oc8b<_o<c<cooooo00;o00000oooool00ol0003oooooooooo`0Cooooo`;o
00001Oooool2o`0000Cooooo0_l00004ooooo`?o00001?ooool2o`0000Wooooo00?o0000oooooooo
ool01?l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000003Oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Uooooo`;o00003oooool0
1_mgMgOoIVIVo`000?l0003oooooo`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00004oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017o
oooo000[ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_o
oooo00?o0000ooooooooool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hoooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0=?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^03?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool00_ooool4o`0000Kooooo0_l0000;ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00003Oooool2o`0000oooooo0ol00004oooo
o`;o00006_ooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`00013ooooo0_l0000Koooo
o`;o0000<?ooool2o`0000Oooooo0_l00005ooooo`;o00002Oooool4o`000003ooooool0003o0000
03Gooooo000[ooooo`03o`000?oooooooooo00;ooooo1?l00006ooooo`;o00002oooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000gooooo0_l0000?ooooo`?o00001?ooool2o`00
01[ooooo0_l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l0000@ooooo`;o00006oooool2o`00
033ooooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo1?l000000ooooooo0000o`00000[oooo
o`;o00000_ooool00ol@413o0000o`000003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;o
oooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?ooooooo`00033o00003?ooool01?l0003o
V9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04Oooool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo
00?o0000ooooooooool01oooool5o`0000Wooooo0_l0000;ooooo`?o00001?ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000?ooooo
0ol0000Gooooo`;o00008?ooool2o`0001_ooooo0_l0000Kooooo`;o00001_ooool2o`0000Cooooo
0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l00000
1oooool3o`0001[ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003ooooo
ooooo`07ooooo`Go00002Oooool2o`0000_ooooo0ol00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000oooool3o`0001Oooooo
0_l0000Pooooo`;o00006oooool2o`0001_ooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo
0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o0000
1_ooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`000007ooooo`?o0000
6_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o
0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o00002?ooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00Co0000ooooool0003o00005Oooool2o`0004;ooooo0_l0000Tooooo`;o00000_ooool2o`0000So
oooo0_l0000<ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo
0000o`000007ooooo`;o00006_ooool4o`0000cooooo0_l0000Nooooo`;o00001Oooool5o`0002Oo
oooo000[ooooo`04o`000?oooooo0000o`0001Gooooo0_l00012ooooo`;o00009?ooool2o`0000;o
oooo0_l00008ooooo`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`?o
000000?oooooo`000?l000001oooool2o`0001[ooooo1?l0000<ooooo`;o00007_ooool2o`0000Go
oooo1Ol0000Wooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool01?l0003ooooo
ooooooooool2o`0000Sooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00001Oooool2o`00027ooooo0_l00003ooooo`;o00000oooool2o`00033o
oooo0_l00003ooooo`;o00000oooool2o`0003_ooooo0_l0000Iooooo`;o0000@Oooool002_ooooo
00Co0000oooooooooooooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo0_l00008ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000Qooooo`;o00000oooool2o`0000?o
oooo0_l0000`ooooo`;o00000oooool2o`0000?ooooo0_l0000kooooo`;o00006Oooool2o`00047o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool3o`0000kooooo0_l0000Xooooo`;o00006Oooool2o`0000;ooooo0_l0000;ooooo`;o
00005Oooool2o`0000[ooooo0_l00002ooooo`;o0000=_ooool2o`0003Gooooo0_l0000Oooooo`;o
00007Oooool002_ooooo0ol0000>ooooo`;o0000:?ooool2o`0001Wooooo0_l00002ooooo`;o0000
2oooool2o`0001Gooooo0_l0000:ooooo`;o00000_ooool2o`0003Kooooo0_l0000eooooo`;o0000
7oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`1<ooooo`;o00002?ooool2o`0001Wooooo
0_l0000Looooo`;o00004Oooool2o`0000oooooo0_l0000]ooooo`;o00003?ooool2o`00023ooooo
0_l0000Vooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6oooo
o`03o`000?oooooooooo04cooooo0_l00008ooooo`;o00006Oooool2o`0001cooooo0_l0000Aoooo
o`;o00003oooool2o`0002gooooo0_l0000<ooooo`;o00008?ooool2o`0002Kooooo000Kooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkoooo
o`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`0?ooooo`;o0000`Oooool2o`0006Kooooo000Kooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo0_l00031oooo
o`;o0000I_ooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0D?ooool2o`00
00oooooo0_l0001Fooooo`;o0000Coooool2o`0002kooooo000[ooooo`03o`000?oooooooooo053o
oooo0_l0000?ooooo`;o0000E_ooool2o`0004oooooo0_l0000^ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0E?ooool2o`000:_ooooo0_l0000gooooo`00:oooool00ol0003oooooooooo`1Dooooo`;o0000
Zoooool2o`0003Oooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00
0?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000H
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_o
oooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooocco
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_o
oooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo
00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0
003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGo
oooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000
o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X0
2oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo1Ol00003ooooo`04
oa0@4?l0003oA4A4olc<c?oooooo5_ooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4
ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000oooooooooooooooo
o`000002ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?oV9RHoa0@4?oM
gMd0oooooolEooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413o
gMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?oV9RHob4Q8Oo^k^h01oooool00on7QhOoEEEEooooo`3ooooooaCooooo0004
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooo
oomVIVKoQhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo0000
00;ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00003o
oooooaGooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^
k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOooooo
ojVYZOl000005?ooool00omgMgOoIVIVooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l00000oooo
oolEooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMg
ob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool04oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0oooo
oolCooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<Oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@3ooooooaGooooo000?ooooo`03
okZj^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP3ooooooaGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39142 Mdot
.03333 .32962 Mdot
.0381 .35022 Mdot
.04286 .30902 Mdot
.04762 .30902 Mdot
.05238 .26781 Mdot
.05714 .32962 Mdot
.0619 .32962 Mdot
.06667 .32962 Mdot
.07143 .37082 Mdot
.07619 .28842 Mdot
.08095 .37082 Mdot
.08571 .43262 Mdot
.09048 .28842 Mdot
.09524 .24721 Mdot
.1 .35022 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .28842 Mdot
.12381 .26781 Mdot
.12857 .28842 Mdot
.13333 .37082 Mdot
.1381 .30902 Mdot
.14286 .26781 Mdot
.14762 .32962 Mdot
.15238 .32962 Mdot
.15714 .28842 Mdot
.1619 .30902 Mdot
.16667 .35022 Mdot
.17143 .30902 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .26781 Mdot
.19048 .37082 Mdot
.19524 .32962 Mdot
.2 .28842 Mdot
.20476 .32962 Mdot
.20952 .30902 Mdot
.21429 .37082 Mdot
.21905 .39142 Mdot
.22381 .30902 Mdot
.22857 .22661 Mdot
.23333 .26781 Mdot
.2381 .30902 Mdot
.24286 .22661 Mdot
.24762 .26781 Mdot
.25238 .32962 Mdot
.25714 .30902 Mdot
.2619 .28842 Mdot
.26667 .30902 Mdot
.27143 .30902 Mdot
.27619 .20601 Mdot
.28095 .22661 Mdot
.28571 .41202 Mdot
.29048 .28842 Mdot
.29524 .26781 Mdot
.3 .43262 Mdot
.30476 .20601 Mdot
.30952 .37082 Mdot
.31429 .47383 Mdot
.31905 .41202 Mdot
.32381 .39142 Mdot
.32857 .37082 Mdot
.33333 .35022 Mdot
.3381 .30902 Mdot
.34286 .24721 Mdot
.34762 .35022 Mdot
.35238 .28842 Mdot
.35714 .43262 Mdot
.3619 .37082 Mdot
.36667 .39142 Mdot
.37143 .24721 Mdot
.37619 .28842 Mdot
.38095 .28842 Mdot
.38571 .22661 Mdot
.39048 .22661 Mdot
.39524 .26781 Mdot
.4 .20601 Mdot
.40476 .24721 Mdot
.40952 .39142 Mdot
.41429 .28842 Mdot
.41905 .28842 Mdot
.42381 .30902 Mdot
.42857 .24721 Mdot
.43333 .22661 Mdot
.4381 .28842 Mdot
.44286 .39142 Mdot
.44762 .28842 Mdot
.45238 .32962 Mdot
.45714 .32962 Mdot
.4619 .26781 Mdot
.46667 .28842 Mdot
.47143 .35022 Mdot
.47619 .22661 Mdot
.48095 .39142 Mdot
.48571 .28842 Mdot
.49048 .26781 Mdot
.49524 .39142 Mdot
.5 .28842 Mdot
.50476 .32962 Mdot
.50952 .39142 Mdot
.51429 .24721 Mdot
.51905 .26781 Mdot
.52381 .30902 Mdot
.52857 .37082 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .37082 Mdot
.54762 .32962 Mdot
.55238 .35022 Mdot
.55714 .24721 Mdot
.5619 .37082 Mdot
.56667 .22661 Mdot
.57143 .41202 Mdot
.57619 .26781 Mdot
.58095 .16481 Mdot
.58571 .35022 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .26781 Mdot
.60476 .26781 Mdot
.60952 .32962 Mdot
.61429 .32962 Mdot
.61905 .30902 Mdot
.62381 .35022 Mdot
.62857 .39142 Mdot
.63333 .22661 Mdot
.6381 .26781 Mdot
.64286 .30902 Mdot
.64762 .45322 Mdot
.65238 .35022 Mdot
.65714 .28842 Mdot
.6619 .22661 Mdot
.66667 .26781 Mdot
.67143 .32962 Mdot
.67619 .28842 Mdot
.68095 .39142 Mdot
.68571 .26781 Mdot
.69048 .30902 Mdot
.69524 .28842 Mdot
.7 .24721 Mdot
.70476 .30902 Mdot
.70952 .20601 Mdot
.71429 .26781 Mdot
.71905 .26781 Mdot
.72381 .16481 Mdot
.72857 .43262 Mdot
.73333 .24721 Mdot
.7381 .30902 Mdot
.74286 .26781 Mdot
.74762 .32962 Mdot
.75238 .32962 Mdot
.75714 .32962 Mdot
.7619 .37082 Mdot
.76667 .32962 Mdot
.77143 .24721 Mdot
.77619 .16481 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .30902 Mdot
.79524 .24721 Mdot
.8 .32962 Mdot
.80476 .30902 Mdot
.80952 .20601 Mdot
.81429 .28842 Mdot
.81905 .18541 Mdot
.82381 .26781 Mdot
.82857 .39142 Mdot
.83333 .32962 Mdot
.8381 .28842 Mdot
.84286 .30902 Mdot
.84762 .24721 Mdot
.85238 .35022 Mdot
.85714 .22661 Mdot
.8619 .37082 Mdot
.86667 .26781 Mdot
.87143 .22661 Mdot
.87619 .30902 Mdot
.88095 .28842 Mdot
.88571 .47383 Mdot
.89048 .28842 Mdot
.89524 .26781 Mdot
.9 .22661 Mdot
.90476 .35022 Mdot
.90952 .32962 Mdot
.91429 .43262 Mdot
.91905 .30902 Mdot
.92381 .16481 Mdot
.92857 .35022 Mdot
.93333 .32962 Mdot
.9381 .35022 Mdot
.94286 .41202 Mdot
.94762 .32962 Mdot
.95238 .32962 Mdot
.95714 .28842 Mdot
.9619 .26781 Mdot
.96667 .26781 Mdot
.97143 .37082 Mdot
.97619 .26781 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`2Uooooo`;o0000:Oooool2
o`0000kooooo0_l0000[ooooo`;o0000:oooool002_ooooo0_l0002Vooooo`;o0000:Oooool2o`00
00kooooo0_l0000[ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000k_ooool2o`0004_ooooo000[ooooo`03o`000?oooooooooo0>gooooo
0_l0001;ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
BOooool2o`0000Oooooo0_l0000Jooooo`;o0000G?ooool2o`0001cooooo0_l0001>ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`19ooooo`;o00001oooool2o`0001[ooooo0_l0001Looooo`;o00007?ooool2o`0004kooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0000Iooooo`;o00008?ooool2o`0000?ooooo0_l0
0009ooooo`;o00007_ooool3o`0000_ooooo0_l0000;ooooo`;o00004?ooool2o`0000Sooooo0_l0
000Booooo`;o00001oooool2o`0003Wooooo0_l00002ooooo`;o00001oooool2o`0003;ooooo000[
ooooo`03o`000?oooooooooo01Sooooo0_l0000Pooooo`;o00000oooool2o`0000Wooooo0_l0000N
ooooo`?o00002oooool2o`0000_ooooo0_l0000@ooooo`;o00002?ooool2o`0001;ooooo0_l00007
ooooo`;o0000>Oooool2o`0000;ooooo0_l00007ooooo`;o0000<_ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`0Booooo`;o0000BOooool2o`0000Oooooo0_l00008ooooo`;o00001Oooool2
o`0001Sooooo0_l0000;ooooo`;o0000:Oooool2o`0000Sooooo0_l0000:ooooo`;o00001Oooool2
o`0000kooooo0_l00012ooooo`00:oooool2o`0001?ooooo0_l00019ooooo`;o00001oooool2o`00
00Sooooo0_l00005ooooo`;o00006?ooool2o`0000_ooooo0_l0000Yooooo`;o00002?ooool2o`00
00[ooooo0_l00005ooooo`;o00003_ooool2o`0004;ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`0000_o
oooo0_l0000<ooooo`;o000000KoooooodA4A?l0003o0000oc8b<_oMgMd2ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01?ooool2o`0001cooooo0_l0000Booooo`Ko000000?o410@ooooooooool00ol0
00000olb<S;ok^k^ooooo`02ooooo`?o000000?o<S8bonk^k_ooool00_l0000:ooooo`;o00001Ooo
ool3o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo1_l00002ooooo`03odA4A?l0
003o000000;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0000;ooooo`;o0000
1oooool2o`0000cooooo1Ol000000ooooooo0000o`000005o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`05ooooo`;o00005?ooool2o`0000Cooooo
0_l0000;ooooo`;o00003?ooool2o`0000;ooooo0_l000002OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`;o00007?ooool2o`0001;ooooo0_l00002ooooo`03o`000?oooooo
oooo00;ooooo0_l000000oooooooV9RHogMgM`03ooooo`;o000000CooooooiRHV?mgMgOooooo0_l0
000:ooooo`;o00001Oooool3o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo1?l0
0005ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo0_l0000;ooooo`;o0000
1oooool2o`0000cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool4o`000003ooooool0003o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13oooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03;o
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400Cooooo`00:oooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;ooooo
ooooool000000oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003ooooo
ooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0cooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000004oooool002_ooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003o
ooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo
000003Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400g
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool04Oooool002_ooooo0_l0000=ooooo`;o00000oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000007ooooo`;o00002oooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool2o`000004oiRHV?ooooooV9RHogMgM`;ooooo0_l0000Aooooo`;o00001Oooool4o`0000Sooooo
0ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003oooooooooo`;o
000000?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool2o`00
01;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool2o`0000Gooooo0_l0000;
ooooo`;o000000?oooooo`000?l000003Oooool01Ol0003o^[ZjoooooonHV9So410@00;o000000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_o
oooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000_ooooo0_l0000;ooooo`Co00000_ooool2o`000004oc8b<_l0003o<S8bonk^
kP;ooooo0_l0000Aooooo`;o00001Oooool4o`0000Sooooo0ol00004ooooo`;o000000?oooooo`00
0?l000000oooool2o`000004ofIVI_l0003oooooooooo`;o000000?ok^k^oc8b<_l000000_l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool2o`0001;ooooo0_l00004ooooo`;o00001?oo
ool2o`000004oooooomEEEGoIVIVo`0000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool2o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000003Oooool01OnHV9So
410@o`000?lQ8B7oc<c<00;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo<Oooool2o`00
00;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000ooooooooool0oooooolbooooo`05
o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`0000cooooo00Co0000oiRHV?lb
<S;oc<c<1Oooool002_ooooo00?o0000ooooooooool00_ooool4o`0000Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`02ooooo`;o00001Oooool5o`000003ooooool0003o000000Oo
oooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool6o`0000_ooooo00?o0000oooooooo
ool01Oooool2o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`;o
00001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo0_l0000<ooooo`;o
00000_ooool2o`0000Wooooo0_l0000<ooooo`?o00000oooool2o`0000Oooooo00Co0000ooooool0
003o00002?ooool3o`0000[ooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04Oooool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000oooooooo
ool0oooooolbooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo00?o0000oooooooo
ool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo
<_ooool00ol0003oooooooooo`06ooooo`00:oooool01?l0003oooooo`000?l00006ooooo`Go0000
2Oooool2o`0000_ooooo0ol0000;ooooo`;o000000?oooooo`000?l000003Oooool2o`0003[ooooo
1?l0000<ooooo`;o00002oooool2o`0000cooooo0_l00003ooooo`?o00003oooool2o`0001Gooooo
1Ol000000ooooooo0000o`000008ooooo`;o00002?ooool2o`0001Gooooo0_l00006ooooo`;o0000
0_ooool3o`0001Wooooo0_l00008ooooo`00:oooool4o`0000Kooooo1Ol00009ooooo`;o00002ooo
ool3o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000>_ooool4o`0000cooooo0_l0
000;ooooo`;o00003?ooool2o`0000?ooooo0ol0000?ooooo`;o00005Oooool5o`000003ooooool0
003o000000Sooooo0_l00008ooooo`;o00005Oooool2o`0000Kooooo0_l00002ooooo`?o00008ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool01?l0003oooooooooooooool2o`00017ooooo1?l0000@ooooo`;o0000
00?oooooo`000?l00000;Oooool2o`0000;ooooo0_l0000Tooooo`;o00005_ooool2o`0000Sooooo
0_l0000:ooooo`;o00001oooool2o`0003[ooooo0_l0000>ooooo`;o00001Oooool2o`000003oooo
ool0003o000002Oooooo000[ooooo`;o00000_ooool2o`00017ooooo1?l0000@ooooo`;o000000?o
ooooo`000?l00000;Oooool2o`0000;ooooo0_l0000Tooooo`;o00005_ooool2o`0000Sooooo0_l0
000:ooooo`;o00001oooool2o`0003[ooooo0_l0000>ooooo`;o00001Oooool2o`000003ooooool0
003o000002Oooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`0000cooooo0_l000000ooooooo0000o`00000>ooooo`;o00003oooool2o`0000Gooooo0_l0000K
ooooo`;o00001?ooool2o`0000Sooooo0_l0000`ooooo`;o00000oooool2o`0000?ooooo0_l0000k
ooooo`;o00007?ooool2o`0001oooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`0;oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000oooooo0_l00005ooooo`;o00006oooool2o`00
00Cooooo0_l00008ooooo`;o0000<?ooool2o`0000?ooooo0_l00003ooooo`;o0000>oooool2o`00
01cooooo0_l0000Oooooo`;o00007Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool3o`0003Sooooo0_l0000Moooo
o`;o00002oooool2o`0000_ooooo0_l00008ooooo`;o00002_ooool2o`0000;ooooo0_l00002oooo
o`;o00008_ooool2o`0000kooooo0_l0000Mooooo`;o00003?ooool2o`0004Sooooo000[ooooo`?o
0000>?ooool2o`0001gooooo0_l0000;ooooo`;o00002oooool2o`0000Sooooo0_l0000:ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Rooooo`;o00003_ooool2o`0001gooooo0_l0000<ooooo`;o
0000B?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000C?ooool2o`0000So
oooo0_l0001:ooooo`;o0000K_ooool2o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04cooooo0_l00008ooooo`;o
0000B_ooool2o`0006kooooo0_l0000Vooooo`006oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo00oooooo0_l0000oooooo`;o00003oooool2o`0006oooooo0_l0000fooooo`;o0000
;_ooool002_ooooo0_l0000@ooooo`;o0000?oooool2o`0000oooooo0_l0001_ooooo`;o0000=_oo
ool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000;[ooooo0_l0001oooooo`00:oooool00ol0003oooooooooo`2iooooo`;o0000Ooooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`0005Gooooo0_l0002[ooooo`;o0000=oooool002_ooooo00?o0000oooooooo
ool0E?ooool2o`000:_ooooo0_l0000gooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hoooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`000?oooooo>oooool001[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo00000?ooooooA?ooool001_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@0?ooooooA?ooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0oooooom4ooooo`006?ooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?oo
ooooA?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l0
0002ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o
<S8booooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool03_ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP3ooooooaGooooo0003ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?ooooo00[oA4A4oiRHV?oooooo
ooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@400<ooooo`05o`000?oo
ooooooooooooool000000_ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolEooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_oo
ool01Ol0003ooooooooooooooooo000001Gooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo0?oooooo4oooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko
410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hB
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo00000?oooooo5Oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b
1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOo
MgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03oa0@4?l0003o^[Zj00?ooooo
00Go0000ooooooooooooooooo`00003ooooooaGooooo0003ooooo`;o00000_ooool2o`0000Gooooo
00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo
00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@403ooooooaGooooo000?ooooo`07oeEEEOnHV9SooooooooooooM
gMgo0000omgMg@0aooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg0?oooooo5Oooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0`
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo
5Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .40172 Mdot
.03333 .33992 Mdot
.0381 .33992 Mdot
.04286 .29872 Mdot
.04762 .29872 Mdot
.05238 .27812 Mdot
.05714 .31932 Mdot
.0619 .33992 Mdot
.06667 .31932 Mdot
.07143 .36052 Mdot
.07619 .29872 Mdot
.08095 .38112 Mdot
.08571 .42232 Mdot
.09048 .27812 Mdot
.09524 .25751 Mdot
.1 .36052 Mdot
.10476 .31932 Mdot
.10952 .36052 Mdot
.11429 .23691 Mdot
.11905 .27812 Mdot
.12381 .25751 Mdot
.12857 .27812 Mdot
.13333 .38112 Mdot
.1381 .31932 Mdot
.14286 .25751 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .27812 Mdot
.1619 .29872 Mdot
.16667 .33992 Mdot
.17143 .29872 Mdot
.17619 .36052 Mdot
.18095 .31932 Mdot
.18571 .25751 Mdot
.19048 .38112 Mdot
.19524 .33992 Mdot
.2 .27812 Mdot
.20476 .33992 Mdot
.20952 .31932 Mdot
.21429 .38112 Mdot
.21905 .38112 Mdot
.22381 .31932 Mdot
.22857 .21631 Mdot
.23333 .27812 Mdot
.2381 .29872 Mdot
.24286 .23691 Mdot
.24762 .25751 Mdot
.25238 .33992 Mdot
.25714 .29872 Mdot
.2619 .27812 Mdot
.26667 .31932 Mdot
.27143 .31932 Mdot
.27619 .21631 Mdot
.28095 .23691 Mdot
.28571 .40172 Mdot
.29048 .29872 Mdot
.29524 .27812 Mdot
.3 .42232 Mdot
.30476 .19571 Mdot
.30952 .36052 Mdot
.31429 .46353 Mdot
.31905 .40172 Mdot
.32381 .38112 Mdot
.32857 .38112 Mdot
.33333 .33992 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .33992 Mdot
.35238 .27812 Mdot
.35714 .42232 Mdot
.3619 .36052 Mdot
.36667 .40172 Mdot
.37143 .25751 Mdot
.37619 .27812 Mdot
.38095 .29872 Mdot
.38571 .21631 Mdot
.39048 .21631 Mdot
.39524 .25751 Mdot
.4 .19571 Mdot
.40476 .23691 Mdot
.40952 .38112 Mdot
.41429 .29872 Mdot
.41905 .29872 Mdot
.42381 .31932 Mdot
.42857 .23691 Mdot
.43333 .21631 Mdot
.4381 .29872 Mdot
.44286 .38112 Mdot
.44762 .27812 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .27812 Mdot
.46667 .27812 Mdot
.47143 .33992 Mdot
.47619 .23691 Mdot
.48095 .38112 Mdot
.48571 .29872 Mdot
.49048 .25751 Mdot
.49524 .38112 Mdot
.5 .29872 Mdot
.50476 .33992 Mdot
.50952 .40172 Mdot
.51429 .23691 Mdot
.51905 .27812 Mdot
.52381 .31932 Mdot
.52857 .38112 Mdot
.53333 .21631 Mdot
.5381 .25751 Mdot
.54286 .36052 Mdot
.54762 .31932 Mdot
.55238 .33992 Mdot
.55714 .25751 Mdot
.5619 .38112 Mdot
.56667 .23691 Mdot
.57143 .40172 Mdot
.57619 .25751 Mdot
.58095 .17511 Mdot
.58571 .33992 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .27812 Mdot
.60476 .27812 Mdot
.60952 .33992 Mdot
.61429 .31932 Mdot
.61905 .31932 Mdot
.62381 .36052 Mdot
.62857 .38112 Mdot
.63333 .21631 Mdot
.6381 .27812 Mdot
.64286 .31932 Mdot
.64762 .46353 Mdot
.65238 .36052 Mdot
.65714 .27812 Mdot
.6619 .21631 Mdot
.66667 .27812 Mdot
.67143 .33992 Mdot
.67619 .27812 Mdot
.68095 .38112 Mdot
.68571 .25751 Mdot
.69048 .29872 Mdot
.69524 .27812 Mdot
.7 .23691 Mdot
.70476 .29872 Mdot
.70952 .19571 Mdot
.71429 .27812 Mdot
.71905 .25751 Mdot
.72381 .15451 Mdot
.72857 .42232 Mdot
.73333 .23691 Mdot
.7381 .29872 Mdot
.74286 .27812 Mdot
.74762 .33992 Mdot
.75238 .31932 Mdot
.75714 .31932 Mdot
.7619 .36052 Mdot
.76667 .31932 Mdot
.77143 .25751 Mdot
.77619 .17511 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .31932 Mdot
.79524 .25751 Mdot
.8 .31932 Mdot
.80476 .29872 Mdot
.80952 .21631 Mdot
.81429 .27812 Mdot
.81905 .19571 Mdot
.82381 .27812 Mdot
.82857 .38112 Mdot
.83333 .31932 Mdot
.8381 .29872 Mdot
.84286 .31932 Mdot
.84762 .23691 Mdot
.85238 .36052 Mdot
.85714 .23691 Mdot
.8619 .36052 Mdot
.86667 .27812 Mdot
.87143 .23691 Mdot
.87619 .29872 Mdot
.88095 .27812 Mdot
.88571 .48413 Mdot
.89048 .29872 Mdot
.89524 .25751 Mdot
.9 .23691 Mdot
.90476 .36052 Mdot
.90952 .33992 Mdot
.91429 .44292 Mdot
.91905 .31932 Mdot
.92381 .15451 Mdot
.92857 .33992 Mdot
.93333 .31932 Mdot
.9381 .33992 Mdot
.94286 .42232 Mdot
.94762 .33992 Mdot
.95238 .31932 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .27812 Mdot
.97143 .38112 Mdot
.97619 .25751 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3@ooooo`;o0000>oooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0=3ooooo
0_l0000kooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0YOooool2o`0003Wooooo0_l0001Hooooo`00:oooool00ol0003oooooooooo`2U
ooooo`;o0000>Oooool2o`0005Sooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1Booooo`;o00006_ooool2
o`0005cooooo0_l0000Oooooo`;o0000Boooool001Wooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`1Booooo`;o00006_ooool2o`0005cooooo
0_l0000Oooooo`;o0000Boooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0jooooo`;o0000
3Oooool2o`0001oooooo0ol0000;ooooo`;o00007Oooool2o`0001cooooo0_l00007ooooo`;o0000
:_ooool2o`0004kooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o00007oooool3o`0000_ooooo
0_l0000Mooooo`;o00007?ooool2o`0000Oooooo0_l0000Zooooo`;o0000C_ooool001Wooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01So
oooo0_l0000Uooooo`;o00002Oooool2o`00017ooooo0_l0000Aooooo`;o00001Oooool2o`0000co
oooo0_l0000:ooooo`;o00003_ooool2o`0002Kooooo0_l00008ooooo`;o00008Oooool2o`000003
ooooool0003o000000;ooooo0_l00007ooooo`;o0000<_ooool002_ooooo00?o0000ooooooooool0
6?ooool2o`0002Gooooo0_l00009ooooo`;o00004Oooool2o`00017ooooo0_l00005ooooo`;o0000
3?ooool2o`0000[ooooo0_l0000>ooooo`;o00009_ooool2o`0000Sooooo0_l0000Qooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Oooooo0_l0000booooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
4_ooool2o`0000Oooooo0_l00004ooooo`;o00002oooool2o`00013ooooo0_l0000Tooooo`;o0000
1Oooool2o`0001_ooooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l0000Oooooo`;o0000
2?ooool2o`0000kooooo0_l00005ooooo`;o00007?ooool2o`0001Oooooo0_l0000Kooooo`00:ooo
ool00ol0003oooooooooo`0Booooo`;o00001oooool2o`0000Cooooo0_l0000;ooooo`;o00004?oo
ool2o`0002Cooooo0_l00005ooooo`;o00006oooool2o`0000cooooo0_l00004ooooo`;o00001?oo
ool2o`0001oooooo0_l00008ooooo`;o00003_ooool2o`0000Gooooo0_l0000Looooo`;o00005ooo
ool2o`0001_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooo
ooooool01Oooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`00
00_ooooo0_l00008ooooo`;o00001?ooool00omgMgOo<S8booooo`02o`0000?ooooo00?o0000oooo
ooooool00_ooool2o`0000oooooo0_l00005ooooo`;o00005?ooool2o`0000;ooooo0ol000000ooo
oooo0000ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00?o0000
ooooooooool04_ooool3o`0000Sooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
3Oooool4o`0000_ooooo0_l00003ooooo`;o00004_ooool00onHV9So8B4Qonk^kP05o`0000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo000[ooooo`03o`00
0?oooooooooo00Gooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000Oooooo
0_l0000;ooooo`;o00002?ooool2o`000007ooooool0003o8B4Qo`000?lb<S;oc<c<ooooo`02o`00
00?ooooo00?o0000ooooooooool00_ooool2o`0000oooooo0_l00005ooooo`;o00005?ooool2o`00
00;ooooo0ol000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000;ooooo00?o0000ooooooooool04_ooool3o`0000Sooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo00?o0000ob4Q8Ol000000_l0
0002ooooo`05o`000?ooooooooooooooool000003Oooool4o`0000_ooooo0_l00003ooooo`;o0000
4oooool00omgMgOoIVIVo`000004o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo017ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03Oooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0Aooooo`00:oooool2o`00043ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01?ooooo000[ooooo`03o`000?oooooooooo03oooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0>?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00;ooooo1?l00006ooooo`;o
00006?ooool2o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o00002?ooool2o`0001[o
oooo0_l00008ooooo`?o00001?ooool2o`0000cooooo0_l00003ooooo`;o00006Oooool2o`0001co
oooo0_l00002ooooo`;o00002Oooool2o`0001;ooooo0_l00008ooooo`;o00002Oooool2o`0000?o
oooo0_l0000eooooo`00:oooool00ol0003oooooooooo`02ooooo`Co00001_ooool2o`0001Sooooo
0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000Sooooo0_l0000Jooooo`;o0000
2?ooool3o`0000Cooooo0_l0000<ooooo`;o00000oooool2o`0001Wooooo0_l0000Looooo`;o0000
0_ooool2o`0000Wooooo0_l0000Booooo`;o00002?ooool2o`0000Wooooo0_l00003ooooo`;o0000
:oooool2o`0000;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000ooooooooool0oooo
oolbooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`0000cooooo00Co
0000oiRHV?lb<S;oc<c<1Oooool002_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oa0@4?nHV9P01_ooool002_ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`04o`000?o^k^koEEEEohN7Q`Gooooo000[
ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2
o`000004ooooool0003o0000o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0ol0
000Cooooo`;o00006?ooool2o`0000Kooooo0_l0000Dooooo`;o00001Oooool2o`0001;ooooo1?l0
0005ooooo`;o00007oooool3o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`00
0008ooooo`;o000000?oooooo`000?l000005Oooool2o`0000?ooooo0_l00003ooooo`;o00006_oo
ool01Ol0003oooooodA4A?l0003o410@00Cooooo000[ooooo`03o`000?oooooooooo00Oooooo0_l0
00000ooooooo0000o`000009ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000Oooooo
0_l00007ooooo`;o00000_ooool2o`0000_ooooo0ol0000Cooooo`;o00006?ooool2o`0000Kooooo
0_l0000Dooooo`;o00001Oooool2o`0001;ooooo1?l00005ooooo`;o00007oooool3o`000003oooo
ool0003o000000Cooooo0ol000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l00000
5Oooool2o`0000?ooooo0_l00003ooooo`;o00006_ooool00ol0003oooooooooo`06ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000
ooooooooool0oooooolaooooo`;o00002?ooool002_ooooo0_l0003ooooooccooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooool000000ol00005ooooo`;o0000
7_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00005_ooool2o`0000;ooooo
0_l0000Pooooo`;o00000_ooool2o`0000Sooooo0_l0000<ooooo`;o00002?ooool2o`000003oooo
ool0003o000000?ooooo0_l0000@ooooo`;o00005Oooool2o`0002oooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Tooooo`00:oooool00ol0003oooooo`000003o`0000Gooooo
0_l0000Nooooo`;o00001_ooool2o`000003ooooool0003o000000gooooo0_l0000Fooooo`;o0000
0_ooool2o`00023ooooo0_l00002ooooo`;o00002?ooool2o`0000cooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`00013ooooo0_l0000Eooooo`;o0000;oooool2o`0000Cooooo
0_l000001?oooooo0000o`000?ooool2o`0002Cooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`Co00004oooool2o`0002Kooooo
0_l0000>ooooo`;o0000=Oooool2o`0001Kooooo0_l00007ooooo`;o00007oooool2o`0001Wooooo
0_l000000ooooooo0000o`00000;ooooo`;o0000<Oooool002_ooooo00?o0000ooooooooool02ooo
ool2o`0000Oooooo1?l0000Cooooo`;o00009_ooool2o`0000kooooo0_l0000eooooo`;o00005_oo
ool2o`0000Oooooo0_l0000Oooooo`;o00006Oooool2o`000003ooooool0003o000000_ooooo0_l0
000aooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool03_ooool2o`0000kooooo0_l0000?ooooo`;o00001Ooo
ool4o`0001gooooo1?l0000Fooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`;o00002?oo
ool2o`0000Sooooo0_l0000Booooo`;o00003_ooool2o`0001gooooo0_l0000<ooooo`;o0000:Ooo
ool2o`0001gooooo000[ooooo`03o`000?oooooooooo00kooooo0_l0000>ooooo`;o00003oooool2
o`0000Gooooo1?l0000Mooooo`Co00005_ooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool2
o`0000Sooooo0_l00008ooooo`;o00004_ooool2o`0000kooooo0_l0000Mooooo`;o00003?ooool2
o`0002Wooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0ol0001<ooooo`;o00002?ooool2o`0000cooooo0_l0000Y
ooooo`;o00004Oooool2o`0009Kooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo0ol0001<ooooo`;o00002?ooool2o`0000cooooo0_l0000Yooooo`;o0000
4Oooool2o`0009Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo
>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`0?ooooo`;o0000?oooool2o`0000oooooo
0_l0001_ooooo`;o0000?_ooool2o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo0_l0000oooooo`;o0000
3oooool2o`0006oooooo0_l0000nooooo`;o00009_ooool001Wooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0ooooool;ooooo`;o0000;_ooool002_ooooo00?o0000ooooooooool0oooo
ool;ooooo`;o0000;_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00
0?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo05Cooooo0_l0001Sooooo`;o0000Oooo
ool002_ooooo00?o0000ooooooooool0E?ooool2o`0006?ooooo0_l0001oooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0ooooool2ooooo`;o0000=oooool002_ooooo00?o0000ooooooooool0ooooool2oooo
o`;o0000=oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo
??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000H
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000L
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zj
ooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003
ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003
o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo00GoV9RHoa0@4?l0003o<S8b
olc<c004ooooo`Co000000?o410@ooooooooool0oooooolBooooo`000oooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9So
ooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0
003ooooooooooooooooo000000;ooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_oo
ool00ol0003oooooooooo`3ooooooaCooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mg
MgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05
o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo5?ooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02oooo
o`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?oo
ooooooooooooool000000_ooool6o`0000cooooo00?oZJVYoa0@4?ooool01Oooool00ol0003ooooo
ooooo`3ooooooaCooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?oooooo
ooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7
QhOoooooojVYZOl000004oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo
5?ooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ
8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oo
oooooooo01;ooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooooaCooooo000?
ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0aooooo`05oa0@4?nHV9SooooookZj^_l0
00001_ooool00ol0003oooooooooo`3ooooooaCooooo000?ooooo`03okZj^_m4A4Cooooo00;ooooo
00?oZJVYooooooooool0<?ooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00?oEEEEofIVI_l0
0000oooooolFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .41202 Mdot
.03333 .32962 Mdot
.0381 .32962 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .26781 Mdot
.05714 .30902 Mdot
.0619 .35022 Mdot
.06667 .30902 Mdot
.07143 .35022 Mdot
.07619 .30902 Mdot
.08095 .39142 Mdot
.08571 .41202 Mdot
.09048 .28842 Mdot
.09524 .24721 Mdot
.1 .35022 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .24721 Mdot
.11905 .28842 Mdot
.12381 .26781 Mdot
.12857 .26781 Mdot
.13333 .37082 Mdot
.1381 .32962 Mdot
.14286 .24721 Mdot
.14762 .30902 Mdot
.15238 .30902 Mdot
.15714 .28842 Mdot
.1619 .28842 Mdot
.16667 .35022 Mdot
.17143 .28842 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .24721 Mdot
.19048 .37082 Mdot
.19524 .35022 Mdot
.2 .26781 Mdot
.20476 .35022 Mdot
.20952 .32962 Mdot
.21429 .39142 Mdot
.21905 .37082 Mdot
.22381 .30902 Mdot
.22857 .20601 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .24721 Mdot
.24762 .24721 Mdot
.25238 .32962 Mdot
.25714 .28842 Mdot
.2619 .28842 Mdot
.26667 .32962 Mdot
.27143 .32962 Mdot
.27619 .20601 Mdot
.28095 .24721 Mdot
.28571 .39142 Mdot
.29048 .28842 Mdot
.29524 .26781 Mdot
.3 .43262 Mdot
.30476 .18541 Mdot
.30952 .37082 Mdot
.31429 .45322 Mdot
.31905 .39142 Mdot
.32381 .37082 Mdot
.32857 .39142 Mdot
.33333 .32962 Mdot
.3381 .32962 Mdot
.34286 .24721 Mdot
.34762 .35022 Mdot
.35238 .28842 Mdot
.35714 .43262 Mdot
.3619 .37082 Mdot
.36667 .39142 Mdot
.37143 .26781 Mdot
.37619 .26781 Mdot
.38095 .28842 Mdot
.38571 .22661 Mdot
.39048 .20601 Mdot
.39524 .26781 Mdot
.4 .20601 Mdot
.40476 .22661 Mdot
.40952 .37082 Mdot
.41429 .30902 Mdot
.41905 .30902 Mdot
.42381 .32962 Mdot
.42857 .22661 Mdot
.43333 .22661 Mdot
.4381 .30902 Mdot
.44286 .39142 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .35022 Mdot
.4619 .28842 Mdot
.46667 .26781 Mdot
.47143 .32962 Mdot
.47619 .22661 Mdot
.48095 .39142 Mdot
.48571 .28842 Mdot
.49048 .26781 Mdot
.49524 .39142 Mdot
.5 .30902 Mdot
.50476 .32962 Mdot
.50952 .41202 Mdot
.51429 .22661 Mdot
.51905 .26781 Mdot
.52381 .30902 Mdot
.52857 .37082 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .35022 Mdot
.54762 .30902 Mdot
.55238 .32962 Mdot
.55714 .24721 Mdot
.5619 .39142 Mdot
.56667 .24721 Mdot
.57143 .39142 Mdot
.57619 .26781 Mdot
.58095 .16481 Mdot
.58571 .32962 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .26781 Mdot
.60476 .28842 Mdot
.60952 .35022 Mdot
.61429 .32962 Mdot
.61905 .32962 Mdot
.62381 .37082 Mdot
.62857 .37082 Mdot
.63333 .22661 Mdot
.6381 .28842 Mdot
.64286 .32962 Mdot
.64762 .45322 Mdot
.65238 .37082 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .26781 Mdot
.67143 .32962 Mdot
.67619 .26781 Mdot
.68095 .37082 Mdot
.68571 .26781 Mdot
.69048 .28842 Mdot
.69524 .28842 Mdot
.7 .22661 Mdot
.70476 .30902 Mdot
.70952 .20601 Mdot
.71429 .26781 Mdot
.71905 .24721 Mdot
.72381 .16481 Mdot
.72857 .43262 Mdot
.73333 .22661 Mdot
.7381 .30902 Mdot
.74286 .26781 Mdot
.74762 .32962 Mdot
.75238 .32962 Mdot
.75714 .30902 Mdot
.7619 .37082 Mdot
.76667 .32962 Mdot
.77143 .24721 Mdot
.77619 .16481 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .32962 Mdot
.79524 .26781 Mdot
.8 .32962 Mdot
.80476 .30902 Mdot
.80952 .20601 Mdot
.81429 .28842 Mdot
.81905 .20601 Mdot
.82381 .28842 Mdot
.82857 .39142 Mdot
.83333 .30902 Mdot
.8381 .28842 Mdot
.84286 .30902 Mdot
.84762 .24721 Mdot
.85238 .35022 Mdot
.85714 .22661 Mdot
.8619 .35022 Mdot
.86667 .26781 Mdot
.87143 .22661 Mdot
.87619 .30902 Mdot
.88095 .28842 Mdot
.88571 .49443 Mdot
.89048 .30902 Mdot
.89524 .26781 Mdot
.9 .24721 Mdot
.90476 .37082 Mdot
.90952 .35022 Mdot
.91429 .45322 Mdot
.91905 .32962 Mdot
.92381 .14421 Mdot
.92857 .35022 Mdot
.93333 .30902 Mdot
.9381 .32962 Mdot
.94286 .43262 Mdot
.94762 .35022 Mdot
.95238 .32962 Mdot
.95714 .26781 Mdot
.9619 .28842 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .26781 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0ooooool>ooooo`;o0000:ooo
ool002_ooooo0_l0003oooooo`oooooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0:Gooooo0_l0000Yooooo`;o00003_ooool2o`0005Sooooo000[ooooo`;o0000Y_ooool2o`00
02Wooooo0_l0000>ooooo`;o0000F?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000Doooool2o`000>Kooooo000[ooooo`03o`000?oooooooooo05;ooooo
0_l0003Vooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
>_ooool2o`0000gooooo0_l0000Pooooo`;o000000?oooooo`000?l00000C_ooool2o`0000cooooo
0_l0000Looooo`;o000000?oooooo`000?l00000Boooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0>_ooool2o`0000gooooo
0_l0000Pooooo`;o000000?oooooo`000?l00000C_ooool2o`0000cooooo0_l0000Looooo`;o0000
00?oooooo`000?l00000Boooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0006_ooooo0_l0
0004ooooo`;o00001Oooool3o`0000_ooooo0_l0000:ooooo`;o00001?ooool2o`0001cooooo0_l0
000Booooo`;o00002?ooool2o`0002Cooooo0_l00002ooooo`;o0000>oooool002_ooooo00?o0000
ooooooooool0J_ooool2o`0000Cooooo0_l00005ooooo`?o00002oooool2o`0000[ooooo0_l00004
ooooo`;o00007?ooool2o`0001;ooooo0_l00008ooooo`;o00009?ooool2o`0000;ooooo0_l0000k
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`;o00001oooool2
o`0000_ooooo0_l0000?ooooo`?o00002?ooool2o`00017ooooo0_l0000oooooo`;o000000?ooooo
o`000?l00000;?ooool2o`0000kooooo0_l0000Eooooo`;o00003_ooool2o`0003;ooooo000[oooo
o`;o00004oooool2o`0000Cooooo0_l00007ooooo`;o00002oooool2o`0000oooooo0ol00008oooo
o`;o00004Oooool2o`0003oooooo0_l000000ooooooo0000o`00000/ooooo`;o00003_ooool2o`00
01Gooooo0_l0000>ooooo`;o0000<_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o00001_ooool2o`0001Cooooo0ol0000Dooooo`;o00002oooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00005Oooool3
o`0000Cooooo0_l0000>ooooo`;o00000oooool5o`000003oa0@4?oooooooooo00?o000000?o<S8b
onk^k_ooool00_ooool3o`000003oc8b<_o^k^kooooo00;o00002_ooool2o`0000Gooooo0_l0000B
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co000000Go410@oooooooooooooooo
odA4A004o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00004oooool2o`0000Oo
oooo0_l0000<ooooo`Oo000000?oooooonk^k_lb<S800ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04oooool002_ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo0ol0000Dooooo`;o
00003_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00005Ooo
ool3o`0000Cooooo0_l0000>ooooo`;o00000oooool2o`000003ooooool0003ooooo00?ooooo0_l0
00000oooooooV9RHogMgM`03ooooo`;o000000CooooooiRHV?mgMgOooooo0_l0000:ooooo`;o0000
1Oooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00007ooooo`;o
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000Cooooo`;o00001oooool2o`00
00cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002o`000004oooooomgMgOoV9RHooooo`;o00000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo04?ooooo00Co
0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0
003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0<_ooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo
00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo03?ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
=_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03Oooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Aooooo`00:oooool2o`0000?ooooo0_l0000=ooooo`;o00001_ooool2o`0000[o
oooo0ol000000ooooooo0000o`00000Aooooo`Co00000oooool4o`000004oiRHV?ooooooV9RHogMg
M`;ooooo0_l0000Aooooo`;o00001oooool2o`0001Kooooo0_l00002ooooo`03o`000?oooooooooo
00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Ooo
ool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000Sooooo1?l00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo
1?l00003ooooo`;o00002oooool2o`00013ooooo00Ko0000okZj^_ooooooV9RHoa0@4?ooool4o`00
0003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0
003oooooooooo`02ooooo`;o00003Oooool2o`0000Kooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000004Oooool;o`000004oc8b<_l0003o<S8bonk^kP;ooooo0_l0000Aooooo`;o00001oooool2
o`0001Kooooo0_l000000omEEEGoIVIVo`000002ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool2o`0000;ooooo0_l00008ooooo`;o0000
1?ooool2o`0000Sooooo1?l000001?ooooooEEEEofIVI_l00005ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo1?l00003ooooo`;o00002oooool2o`00013ooooo00KoV9RHoa0@
4?l0003o8B4Qolc<c?ooool5o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Cooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@
413o0000o`000003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^
k^ko<S8bolc<c004ooooo`009?ooooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5oooo
o`00:oooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003ooooo1?l0000<oooo
o`03o`000?oooooooooo00Gooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00002Oooool0
1?l0003oooooo`000?l0000:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o00001?ooool2o`0000;ooooo0_l0
000=ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`02o`0000Wooooo0_l00003ooooo`;o00001ooo
ool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool3o`0000;ooooo0_l0
000:ooooo`?o00002oooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7
QhL5ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@
4004ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool0
02_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03
o`000?oooooo000000?o00004_ooool2o`0000Sooooo0_l0000Dooooo`;o00002oooool2o`0000;o
oooo0ol0000Aooooo`Co00006?ooool2o`0000cooooo0_l00008ooooo`;o00003?ooool2o`0000So
oooo0_l000000ooooooo0000o`000004ooooo`Co00001Oooool2o`0000Kooooo0_l0000Eooooo`Co
00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Rooooo`;o00001?ooool2o`0000;o
oooo0_l0000Iooooo`;o00002?ooool002_ooooo1_l0000Booooo`;o00002?ooool2o`0001Cooooo
0_l0000;ooooo`;o00000_ooool3o`00017ooooo1?l0000Hooooo`;o00003?ooool2o`0000Sooooo
0_l0000<ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o0000
1_ooool2o`0001Gooooo1?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000002;ooooo
0_l00004ooooo`;o00000_ooool2o`0002?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
2?ooool2o`000003ooooool0003o000000Oooooo1?l0000@ooooo`;o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000002Wooooo0_l0000Pooooo`;o00006?ooool2o`0001;ooooo
0_l00017ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l00004ooooo`;o0000
9?ooool002_ooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool4o`00013ooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000:Oooool2o`00023ooooo0_l0
000Hooooo`;o00004_ooool2o`0004Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?oo
ool2o`0000Cooooo0_l0000Tooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0000Oooooo`;o00003oooool2o`0000Oooooo0_l0000Iooooo`;o00000_ooool2
o`0000[ooooo0_l0000<ooooo`;o00008_ooool2o`0001_ooooo0ol00006ooooo`;o00001_ooool2
o`0001Oooooo0_l0000Yooooo`;o00004_ooool2o`0001gooooo000[ooooo`03o`000?oooooooooo
01kooooo0_l0000?ooooo`;o00001oooool2o`0001Wooooo0_l00002ooooo`;o00002_ooool2o`00
00cooooo0_l0000Rooooo`;o00006oooool3o`0000Kooooo0_l00006ooooo`;o00005oooool2o`00
02Wooooo0_l0000Booooo`;o00007Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0000oooooo0_l0000Voooo
o`;o00005?ooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o00005Oooool2o`00
00[ooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000003kooooo0_l0000<oooo
o`;o0000B?ooool002_ooooo00?o0000ooooooooool03_ooool2o`0002Kooooo0_l0000Dooooo`;o
00002?ooool2o`000003ooooool0003o000000Wooooo0_l0000Eooooo`;o00002_ooool2o`0000;o
oooo0_l0000Booooo`;o000000?oooooo`000?l00000?_ooool2o`0000cooooo0_l00018ooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0000?ooooo`;o0000O_ooool2o`000:Wo
oooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00003oooool2o`0007kooooo0_l0002Yooooo`006oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
oooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo053ooooo0_l0000?ooooo`;o0000Koooool2o`0003kooooo0_l0000Vooooo`00:ooo
ool2o`00057ooooo0_l0000?ooooo`;o0000Koooool2o`0003kooooo0_l0000Vooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0001Eooooo`;o0000Hoooool2
o`0004oooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`1Dooooo`;o0000Hoooool2o`00
04oooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooo`?ooooo0_l0000gooooo`00
:oooool00ol0003oooooooooo`3oooooo`;ooooo0_l0000gooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o
^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo
0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`00
0003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`Go0000oooooolEooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OnHV9So8B4Q
onk^k_ooooooA4A40?oooooo5Oooool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?o
oooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000
ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0oooo
oolFooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00Go
QhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`Ko00003?ooool00onYZJWo410@ooooo`04ooooo`03oiRHV?lQ8B7ok^k^
0?oooooo5Oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHoooooooooooo
k^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7Qooo
ooooZJVYo`00000Cooooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMgofIVI_ooool0oooooolDoooo
o`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmE
EED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool04_ooool00onj^[[o8B4Qooooo`06ooooo`03o`000?oooooooooo0?oooooo4oooool000oooooo
00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM037ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooolEooooo`003oooool00onj^[[oA4A4ooooo`02
ooooo`03ojVYZOoooooooooo033ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .40172 Mdot
.03333 .31932 Mdot
.0381 .33992 Mdot
.04286 .27812 Mdot
.04762 .29872 Mdot
.05238 .27812 Mdot
.05714 .29872 Mdot
.0619 .33992 Mdot
.06667 .29872 Mdot
.07143 .36052 Mdot
.07619 .31932 Mdot
.08095 .40172 Mdot
.08571 .40172 Mdot
.09048 .27812 Mdot
.09524 .23691 Mdot
.1 .33992 Mdot
.10476 .33992 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .29872 Mdot
.12381 .27812 Mdot
.12857 .27812 Mdot
.13333 .38112 Mdot
.1381 .33992 Mdot
.14286 .23691 Mdot
.14762 .31932 Mdot
.15238 .31932 Mdot
.15714 .27812 Mdot
.1619 .27812 Mdot
.16667 .36052 Mdot
.17143 .27812 Mdot
.17619 .36052 Mdot
.18095 .29872 Mdot
.18571 .23691 Mdot
.19048 .36052 Mdot
.19524 .33992 Mdot
.2 .25751 Mdot
.20476 .36052 Mdot
.20952 .33992 Mdot
.21429 .40172 Mdot
.21905 .38112 Mdot
.22381 .31932 Mdot
.22857 .21631 Mdot
.23333 .27812 Mdot
.2381 .29872 Mdot
.24286 .23691 Mdot
.24762 .25751 Mdot
.25238 .33992 Mdot
.25714 .29872 Mdot
.2619 .27812 Mdot
.26667 .31932 Mdot
.27143 .31932 Mdot
.27619 .19571 Mdot
.28095 .23691 Mdot
.28571 .38112 Mdot
.29048 .27812 Mdot
.29524 .27812 Mdot
.3 .44292 Mdot
.30476 .17511 Mdot
.30952 .36052 Mdot
.31429 .44292 Mdot
.31905 .40172 Mdot
.32381 .38112 Mdot
.32857 .40172 Mdot
.33333 .31932 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .36052 Mdot
.35238 .29872 Mdot
.35714 .44292 Mdot
.3619 .36052 Mdot
.36667 .40172 Mdot
.37143 .27812 Mdot
.37619 .27812 Mdot
.38095 .27812 Mdot
.38571 .23691 Mdot
.39048 .19571 Mdot
.39524 .25751 Mdot
.4 .19571 Mdot
.40476 .21631 Mdot
.40952 .36052 Mdot
.41429 .31932 Mdot
.41905 .29872 Mdot
.42381 .33992 Mdot
.42857 .21631 Mdot
.43333 .23691 Mdot
.4381 .31932 Mdot
.44286 .40172 Mdot
.44762 .25751 Mdot
.45238 .29872 Mdot
.45714 .33992 Mdot
.4619 .27812 Mdot
.46667 .27812 Mdot
.47143 .33992 Mdot
.47619 .23691 Mdot
.48095 .38112 Mdot
.48571 .27812 Mdot
.49048 .27812 Mdot
.49524 .38112 Mdot
.5 .31932 Mdot
.50476 .33992 Mdot
.50952 .40172 Mdot
.51429 .23691 Mdot
.51905 .25751 Mdot
.52381 .29872 Mdot
.52857 .36052 Mdot
.53333 .23691 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .29872 Mdot
.55238 .33992 Mdot
.55714 .23691 Mdot
.5619 .38112 Mdot
.56667 .23691 Mdot
.57143 .40172 Mdot
.57619 .25751 Mdot
.58095 .15451 Mdot
.58571 .33992 Mdot
.59048 .27812 Mdot
.59524 .31932 Mdot
.6 .27812 Mdot
.60476 .27812 Mdot
.60952 .33992 Mdot
.61429 .33992 Mdot
.61905 .33992 Mdot
.62381 .38112 Mdot
.62857 .38112 Mdot
.63333 .23691 Mdot
.6381 .29872 Mdot
.64286 .31932 Mdot
.64762 .44292 Mdot
.65238 .38112 Mdot
.65714 .29872 Mdot
.6619 .21631 Mdot
.66667 .27812 Mdot
.67143 .33992 Mdot
.67619 .25751 Mdot
.68095 .38112 Mdot
.68571 .25751 Mdot
.69048 .29872 Mdot
.69524 .27812 Mdot
.7 .21631 Mdot
.70476 .31932 Mdot
.70952 .21631 Mdot
.71429 .27812 Mdot
.71905 .23691 Mdot
.72381 .15451 Mdot
.72857 .44292 Mdot
.73333 .23691 Mdot
.7381 .29872 Mdot
.74286 .27812 Mdot
.74762 .31932 Mdot
.75238 .33992 Mdot
.75714 .29872 Mdot
.7619 .38112 Mdot
.76667 .33992 Mdot
.77143 .23691 Mdot
.77619 .17511 Mdot
.78095 .38112 Mdot
.78571 .29872 Mdot
.79048 .33992 Mdot
.79524 .27812 Mdot
.8 .33992 Mdot
.80476 .31932 Mdot
.80952 .19571 Mdot
.81429 .29872 Mdot
.81905 .21631 Mdot
.82381 .27812 Mdot
.82857 .40172 Mdot
.83333 .29872 Mdot
.8381 .29872 Mdot
.84286 .29872 Mdot
.84762 .25751 Mdot
.85238 .36052 Mdot
.85714 .23691 Mdot
.8619 .36052 Mdot
.86667 .25751 Mdot
.87143 .21631 Mdot
.87619 .31932 Mdot
.88095 .29872 Mdot
.88571 .50473 Mdot
.89048 .31932 Mdot
.89524 .27812 Mdot
.9 .23691 Mdot
.90476 .38112 Mdot
.90952 .36052 Mdot
.91429 .46353 Mdot
.91905 .33992 Mdot
.92381 .13391 Mdot
.92857 .36052 Mdot
.93333 .31932 Mdot
.9381 .31932 Mdot
.94286 .42232 Mdot
.94762 .33992 Mdot
.95238 .33992 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .36052 Mdot
.97619 .25751 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0ooooool>ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0ooooool>ooooo`;o
0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0:Gooooo0_l0000Yooooo`;o0000J?ooool002_ooooo
00?o0000ooooooooool0YOooool2o`0002Wooooo0_l0001Xooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`1Booooo`;o0000S?ooool2o`0005Sooooo000[
ooooo`03o`000?oooooooooo05;ooooo0_l0002<ooooo`;o0000F?ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo04Wooooo0_l0000Pooooo`;o000000?oooooo`000?l00000N_ooool2o`0004kooooo000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
BOooool2o`00023ooooo0_l000000ooooooo0000o`00001jooooo`;o0000C_ooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`0jooooo`;o0000=?ooool2o`0000Gooooo0_l00015ooooo`;o0000
2Oooool2o`000003ooooool0003o000001oooooo0_l0000>ooooo`;o0000>oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
>_ooool2o`0003Cooooo0_l00005ooooo`;o0000AOooool2o`0000Wooooo0_l000000ooooooo0000
o`00000Oooooo`;o00003_ooool2o`0003_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Booooo`;o00001?ooool2o`0000Oo
oooo0_l0000;ooooo`;o00003oooool2o`0000Wooooo0_l0000Aooooo`;o00002oooool2o`0000co
oooo0_l0000;ooooo`;o00002_ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00004_ooool2o`0001Sooooo0_l00002ooooo`;o00002_ooool2o`0001Sooooo0_l0000;ooooo`;o
0000<_ooool002_ooooo00?o0000ooooooooool04_ooool2o`0000Cooooo0_l00007ooooo`;o0000
2oooool2o`0000oooooo0_l00009ooooo`;o00004Oooool2o`0000_ooooo0_l0000<ooooo`;o0000
2oooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000001;ooooo
0_l0000Hooooo`;o00000_ooool2o`0000[ooooo0_l0000Hooooo`;o00002oooool2o`0003;ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`0booooo`;o00003?ooool2o`0002_ooooo0_l0000>ooooo`;o0000
4oooool2o`00013ooooo0_l0000Looooo`;o000000?oooooo`000?l00000;oooool2o`0000?ooooo
0_l0000Pooooo`;o00006oooool002_ooooo00?o0000ooooooooool0<_ooool2o`0000cooooo0_l0
000[ooooo`;o00003_ooool2o`0001?ooooo0_l0000@ooooo`;o00007?ooool2o`000003ooooool0
003o000002oooooo0_l00003ooooo`;o00008?ooool2o`0001_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00043o
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0=?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`12oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0foooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000ooooooooool0@oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0booooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41004oooool002_ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o0000
00[ooooo0_l00008ooooo`?o00001oooool3o`000003ooooool0003o0000017ooooo0_l00004oooo
o`03ogMgMolb<S;ooooo00;o00000oooool00ol0003oooooooooo`04o`0001Gooooo1Ol0000Foooo
o`?o000000Coooooo`000?oooooooooo1?l00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooo`000?l0000>ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`0000Oo
oooo0_l00003ooooo`;o00001oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000007oooo
o`;o00001_ooool2o`0001Cooooo0_l0000>ooooo`03oiRHV?lQ8B7ok^k^00Co00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool002_ooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`?o00001oooool3o`00
0003ooooool0003o0000017ooooo0_l000001ooooooo0000ob4Q8Ol0003o<S8bolc<c?ooool00_l0
0003ooooo`03o`000?oooooooooo00Co00005Oooool5o`0001Kooooo0ol000001?oooooo0000oooo
ooooool4o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`00
00kooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00001oooool2o`0000?ooooo0_l00004
ooooo`03o`000?lQ8B7o000000;o00000_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
0006ooooo`;o00005?ooool2o`0000oooooo00?oMgMgofIVI_l000000ol00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00010ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0c
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`0oooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`03oeEEEOmVIVKo
000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00004Oooool2o`0000oo
oooo0_l00004ooooo`;o00006oooool2o`0001;ooooo0_l00008ooooo`;o00005?ooool2o`0000Go
oooo0_l0000Iooooo`;o00001?ooool2o`0000Sooooo0_l0000=ooooo`;o00000oooool2o`0000Oo
oooo0_l00007ooooo`;o00000oooool5o`0000[ooooo0_l0000Hooooo`;o00007_ooool002_ooooo
00?o0000ooooooooool01?ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`00017o
oooo0_l0000?ooooo`;o00001?ooool2o`0001_ooooo0_l0000Booooo`;o00002?ooool2o`0001Co
oooo0_l00005ooooo`;o00006Oooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool2o`0000?o
oooo0_l00007ooooo`;o00001oooool2o`0000?ooooo1Ol0000:ooooo`;o00006?ooool2o`0001Co
oooo0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo
<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`00
0?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:ooo
ool01?l0003oooooo`000?l0000;ooooo`;o00005?ooool3o`0001Cooooo0_l0000;ooooo`?o0000
4Oooool4o`0001Gooooo0_l00005ooooo`;o00004Oooool2o`0001[ooooo0_l0000=ooooo`;o0000
4?ooool2o`0000_ooooo0_l0000@ooooo`;o00004oooool2o`0000?ooooo0_l0000;ooooo`?o0000
7_ooool01Ol0003oooooodA4A?l0003o410@00Cooooo000[ooooo`04o`000?oooooo0000o`0000_o
oooo0_l0000Dooooo`?o00005?ooool2o`0000_ooooo0ol0000Aooooo`Co00005Oooool2o`0000Go
oooo0_l0000Aooooo`;o00006_ooool2o`0000gooooo0_l0000@ooooo`;o00002oooool2o`00013o
oooo0_l0000Cooooo`;o00000oooool2o`0000_ooooo0ol0000Nooooo`03o`000?oooooooooo00Ko
oooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc7ooooo0_l00008ooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool01?l0003oooooooooooooool2o`00
00Gooooo0_l0000:ooooo`Co00001oooool2o`0000oooooo0_l00003ooooo`;o00002oooool2o`00
03;ooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`Co00002?ooool2o`00
00Kooooo1Ol0000=ooooo`;o00005oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000008_ooool2o`0000Oooooo0ol0000Sooooo`00:oooool01?l0003oooooooooooooool2o`00
00Gooooo0_l0000:ooooo`Co00001oooool2o`0000oooooo0_l00003ooooo`;o00002oooool2o`00
03;ooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`Co00002?ooool2o`00
00Kooooo1Ol0000=ooooo`;o00005oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000008_ooool2o`0000Oooooo0ol0000Sooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`0;ooooo`;o00006oooool2o`000003ooooool0003o000000;o
oooo0_l00002ooooo`;o00007_ooool2o`0000Wooooo0_l00003ooooo`;o00003?ooool2o`0002;o
oooo0_l0001Pooooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l0000;ooooo`;o
00007Oooool002_ooooo00?o0000ooooooooool02oooool2o`0001_ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`0001kooooo0_l00009ooooo`;o00000oooool2o`0000cooooo
0_l0000Rooooo`;o0000H?ooool2o`000003ooooool0003o000000cooooo0_l00004ooooo`;o0000
2oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Nooooo`;o00006?ooool2o`0001;ooooo
0_l00009ooooo`;o0000;_ooool2o`0000;ooooo0_l0000Booooo`;o00004Oooool3o`0000Kooooo
0_l00006ooooo`;o00005oooool2o`0000Cooooo0_l0000Sooooo`;o0000<Oooool002_ooooo00?o
0000ooooooooool07_ooool2o`0001Sooooo0_l0000Booooo`;o00002Oooool2o`0002kooooo0_l0
0002ooooo`;o00004_ooool2o`00017ooooo0ol00006ooooo`;o00001_ooool2o`0001Oooooo0_l0
0004ooooo`;o00008oooool2o`00037ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool3o`0000kooooo0ol0000Uooooo`;o00007_oo
ool2o`000003ooooool0003o000000Wooooo0_l0000Eooooo`;o00004_ooool2o`00017ooooo0_l0
001<ooooo`;o0000B?ooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^1_ooool3o`0000kooooo0ol0000Uooooo`;o00007_ooool2o`000003ooooool0003o000000Wo
oooo0_l0000Eooooo`;o00004_ooool2o`00017ooooo0_l0001<ooooo`;o0000B?ooool001_ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_o
oooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo0?oooooo4oooool2o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo4oooool2o`0002Ko
oooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o
00002oooool2o`0005Kooooo0_l0000Gooooo`;o0000I_ooool002_ooooo00?o0000ooooooooool0
D?ooool2o`0000;ooooo0_l0000;ooooo`;o0000E_ooool2o`0001Oooooo0_l0001Vooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0ooooool;ooooo`;o0000;_ooool002_ooooo00?o0000ooooooooool0oooo
ool;ooooo`;o0000;_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00
0?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0ooooool2ooooo`;o0000=oooool0
01Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3o
ooooo`;ooooo0_l0000gooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooo
oolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000H
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_oo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000oooooom4ooooo`006ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100oooooom4ooooo`006?oo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCo
oooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
0?ooooooA?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgM
ooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mE
EEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l0
0002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0>ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01OnHV9So410@o`000?lb<S;oc<c<
0?oooooo5Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgo
oooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
2Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P3ooooo
oaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgooooo
omgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?ooooooooooooooool00000
5Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool000Cooooo00Co
k^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7
QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?ooooooooooooooool000000_ooool6
o`0000cooooo00?oZJVYoa0@4?ooool01Oooool00onYZJWo410@ooooo`3ooooooaCooooo0004oooo
o`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@413ok^k^oa0@4?o^
k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVYZOl000004oooool0
0ol@413o0000okZj^P05ooooo`03oa0@4?l0003o^[Zj0?oooooo5Oooool000?ooooo0_l00002oooo
o`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002oooo
o`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o^[Zjob4Q
8Oooool01Oooool00onj^[[o8B4Qooooo`3ooooooaCooooo000?ooooo`07oeEEEOnHV9Sooooooooo
oooMgMgo0000omgMg@0aooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol@413oV9RHoooo
oonj^[[o00000?oooooo5Oooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWooooooooo
o`0`ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY0?oo
oooo5Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .41202 Mdot
.03333 .30902 Mdot
.0381 .35022 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .26781 Mdot
.05714 .28842 Mdot
.0619 .35022 Mdot
.06667 .28842 Mdot
.07143 .35022 Mdot
.07619 .30902 Mdot
.08095 .39142 Mdot
.08571 .39142 Mdot
.09048 .28842 Mdot
.09524 .24721 Mdot
.1 .35022 Mdot
.10476 .32962 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .28842 Mdot
.12381 .26781 Mdot
.12857 .26781 Mdot
.13333 .39142 Mdot
.1381 .35022 Mdot
.14286 .22661 Mdot
.14762 .32962 Mdot
.15238 .32962 Mdot
.15714 .28842 Mdot
.1619 .26781 Mdot
.16667 .35022 Mdot
.17143 .26781 Mdot
.17619 .37082 Mdot
.18095 .30902 Mdot
.18571 .24721 Mdot
.19048 .35022 Mdot
.19524 .32962 Mdot
.2 .24721 Mdot
.20476 .35022 Mdot
.20952 .32962 Mdot
.21429 .39142 Mdot
.21905 .39142 Mdot
.22381 .32962 Mdot
.22857 .22661 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .24721 Mdot
.24762 .26781 Mdot
.25238 .32962 Mdot
.25714 .30902 Mdot
.2619 .26781 Mdot
.26667 .32962 Mdot
.27143 .32962 Mdot
.27619 .18541 Mdot
.28095 .24721 Mdot
.28571 .39142 Mdot
.29048 .28842 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .18541 Mdot
.30952 .37082 Mdot
.31429 .43262 Mdot
.31905 .39142 Mdot
.32381 .39142 Mdot
.32857 .41202 Mdot
.33333 .30902 Mdot
.3381 .30902 Mdot
.34286 .22661 Mdot
.34762 .37082 Mdot
.35238 .28842 Mdot
.35714 .45322 Mdot
.3619 .37082 Mdot
.36667 .41202 Mdot
.37143 .28842 Mdot
.37619 .26781 Mdot
.38095 .26781 Mdot
.38571 .22661 Mdot
.39048 .18541 Mdot
.39524 .24721 Mdot
.4 .18541 Mdot
.40476 .22661 Mdot
.40952 .35022 Mdot
.41429 .32962 Mdot
.41905 .28842 Mdot
.42381 .32962 Mdot
.42857 .22661 Mdot
.43333 .22661 Mdot
.4381 .30902 Mdot
.44286 .39142 Mdot
.44762 .26781 Mdot
.45238 .28842 Mdot
.45714 .32962 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .32962 Mdot
.47619 .22661 Mdot
.48095 .37082 Mdot
.48571 .26781 Mdot
.49048 .28842 Mdot
.49524 .37082 Mdot
.5 .32962 Mdot
.50476 .32962 Mdot
.50952 .39142 Mdot
.51429 .22661 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .35022 Mdot
.53333 .22661 Mdot
.5381 .26781 Mdot
.54286 .32962 Mdot
.54762 .28842 Mdot
.55238 .35022 Mdot
.55714 .22661 Mdot
.5619 .37082 Mdot
.56667 .24721 Mdot
.57143 .41202 Mdot
.57619 .24721 Mdot
.58095 .16481 Mdot
.58571 .35022 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .26781 Mdot
.60476 .26781 Mdot
.60952 .32962 Mdot
.61429 .32962 Mdot
.61905 .35022 Mdot
.62381 .37082 Mdot
.62857 .39142 Mdot
.63333 .24721 Mdot
.6381 .28842 Mdot
.64286 .32962 Mdot
.64762 .45322 Mdot
.65238 .37082 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .26781 Mdot
.67143 .32962 Mdot
.67619 .24721 Mdot
.68095 .37082 Mdot
.68571 .24721 Mdot
.69048 .28842 Mdot
.69524 .28842 Mdot
.7 .22661 Mdot
.70476 .30902 Mdot
.70952 .22661 Mdot
.71429 .26781 Mdot
.71905 .24721 Mdot
.72381 .16481 Mdot
.72857 .43262 Mdot
.73333 .24721 Mdot
.7381 .28842 Mdot
.74286 .26781 Mdot
.74762 .32962 Mdot
.75238 .35022 Mdot
.75714 .30902 Mdot
.7619 .39142 Mdot
.76667 .35022 Mdot
.77143 .24721 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .35022 Mdot
.79524 .26781 Mdot
.8 .35022 Mdot
.80476 .30902 Mdot
.80952 .18541 Mdot
.81429 .28842 Mdot
.81905 .22661 Mdot
.82381 .28842 Mdot
.82857 .41202 Mdot
.83333 .28842 Mdot
.8381 .30902 Mdot
.84286 .28842 Mdot
.84762 .26781 Mdot
.85238 .37082 Mdot
.85714 .24721 Mdot
.8619 .37082 Mdot
.86667 .24721 Mdot
.87143 .20601 Mdot
.87619 .32962 Mdot
.88095 .30902 Mdot
.88571 .49443 Mdot
.89048 .30902 Mdot
.89524 .28842 Mdot
.9 .24721 Mdot
.90476 .37082 Mdot
.90952 .35022 Mdot
.91429 .47383 Mdot
.91905 .35022 Mdot
.92381 .12361 Mdot
.92857 .37082 Mdot
.93333 .32962 Mdot
.9381 .32962 Mdot
.94286 .41202 Mdot
.94762 .32962 Mdot
.95238 .32962 Mdot
.95714 .28842 Mdot
.9619 .28842 Mdot
.96667 .28842 Mdot
.97143 .35022 Mdot
.97619 .24721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000ooooool?ooooo`;o0000:oooool002_ooooo00?o
0000ooooooooool0ooooool>ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0:Gooooo0_l0000Yooooo`;o0000J?ooool002_ooooo0_l0002Vooooo`;o0000:Oooool2o`00
06Sooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0004[o
oooo0_l00007ooooo`;o00005oooool2o`000003ooooool0003o0000073ooooo0_l00008ooooo`;o
0000C_ooool002_ooooo00?o0000ooooooooool0BOooool2o`0000Oooooo0_l0000Gooooo`;o0000
00?oooooo`000?l00000L?ooool2o`0000Sooooo0_l0001>ooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool0013ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o0000__ooool2o`0003gooooo0_l0000kooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2nooooo`;o0000?Oooool2o`0003_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
000Iooooo`;o00001oooool2o`0001Oooooo0_l0000Qooooo`;o00002oooool2o`0000Cooooo0_l0
0005ooooo`?o00002oooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`0002Wooooo0_l0
00000ooooooo0000o`00000Oooooo`;o0000Boooool002_ooooo00?o0000ooooooooool06?ooool2
o`0000Oooooo0_l0000Gooooo`;o00008Oooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool3
o`0000_ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo0_l0000Yooooo`;o000000?ooooo
o`000?l000007oooool2o`0004_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool04_ooool2
o`0001[ooooo0_l00002ooooo`;o00002oooool2o`0000Wooooo0_l0000Qooooo`;o0000<_ooool2
o`000003ooooool0003o000000oooooo0_l0000;ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000;ooooo0_l0000:ooooo`;o00006?ooool4o`0000Wooooo0_l0000Eooooo`;o00006oooool0
02_ooooo0_l0000Cooooo`;o00006_ooool2o`0000;ooooo0_l0000;ooooo`;o00002Oooool2o`00
027ooooo0_l0000booooo`;o000000?oooooo`000?l000003oooool2o`0000_ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000_ooool2o`0000[ooooo0_l0000Hooooo`Co00002Oooool2o`00
01Gooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l00006ooooo`;o00005?ooool3o`0000Sooooo0_l000000ooooooo0000o`00000Dooooo`06
odA4A?l0003o0000oc8b<_oMgMgooooo0_l000001?lb<S;o0000oc8b<_o^k^h4ooooo`;o00005_oo
ool4o`0001;ooooo0_l00004ooooo`Co000000So410@o`000?l0003ok^k^oc8b<_l0003o<S8bonk^
kP?ooooo0ol000000olb<S;ok^k^ooooo`02o`00017ooooo0ol0000Aooooo`;o00002_ooool4o`00
0005oa0@4?oooooooooooooooom4A4@01?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool2o`0000kooooo0_l0000Jooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`05ooooo`;o0000
5?ooool3o`0000Sooooo0_l000000ooooooo0000o`00000Eooooo`;o000000?oMgMgoc8b<_ooool0
0_l000001?nHV9SooooooiRHV?mgMgL4ooooo`;o00005_ooool4o`0001;ooooo0_l00006ooooo`03
o`000?oooooooooo00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o000000CooooooiRH
V?mgMgOooooo0_l0000Aooooo`?o00004Oooool2o`0000cooooo0_l00007ooooo`;o00000_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000>ooooo`;o00006_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04oooool002_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103oooo
o`03oa0@4?oooooooooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooo410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_o
oooo00?o0000ooooooooool0@_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool0<oooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03
o`000?oooooooooo03oooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool00000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004ooo
ool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000[
ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2
o`0000[ooooo0_l0000Eooooo`Co00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0
000Aooooo`;o00001?ooool2o`0000cooooo0_l00008ooooo`;o000000Koooooo`000?l0003o0000
ooooool00004ooooo`;o000000?ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg
00Cooooo0_l0000;ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`Co00000oooool00ol0
003oooooooooo`03ooooo`04o`000?oooooo0000o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0=ooooo`Co000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00003?ooool01Ol0003o^[Zj
oooooonHV9So410@00Go000000?ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01?ooooo000[ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Kooooo0_l0000:ooooo`;o00005Oooool7o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP02ooooo`;o00004Oooool2o`0000Cooooo0_l0000<ooooo`;o00002?ooool2o`00
0006ooooool0003o0000o`000?mVIVKo00001?ooool3o`000003oc8b<_o^k^kooooo00;ooooo00Go
k^k^oc8b<_l0003o0000onk^kP04ooooo`;o00002oooool2o`0000cooooo0_l00004ooooo`;o0000
2?ooool4o`000004oooooomEEEGoIVIVo`0000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool4o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Cooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@
413o0000o`000003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^
k^ko<S8bolc<c004ooooo`009?ooooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5oooo
o`00:oooool01?l0003oooooo`000?l00003ooooo`;o00001_ooool2o`0000cooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool02Oooool3
o`0000kooooo00?o0000ooooooooool00oooool4o`0000Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`07ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_l00009ooooo`03o`000?oooooooooo00;ooooo0_l00007
ooooo`;o00001?ooool2o`0000Oooooo0ol0000;ooooo`;o000000?oooooo`000?l000002_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oa0@4?nHV9P01_ooool0
02_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`04o`000?o^k^koEEEE
ohN7Q`Gooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooodA4A?l0003o
410@00Cooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06oooo
o`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo
00?o0000ooooooooool05Oooool2o`0000_ooooo0ol0000;ooooo`;o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00000_ooool3o`0002[ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
0_ooool2o`0000Oooooo0ol0000:ooooo`;o00003Oooool2o`0000?ooooo0ol00007ooooo`;o0000
1_ooool2o`0001Gooooo0_l0000Uooooo`;o00004?ooool3o`000004ooooool0003o0000o`0001Wo
oooo0_l00008ooooo`00:oooool2o`0001Kooooo0_l0000;ooooo`?o00002oooool2o`0000?ooooo
0_l00002ooooo`;o00001oooool2o`0000;ooooo0ol0000Zooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000;ooooo0_l00007ooooo`?o00002_ooool2o`0000gooooo0_l00003ooooo`?o0000
1oooool2o`0000Kooooo0_l0000Eooooo`;o00009Oooool2o`00013ooooo0ol000001?oooooo0000
o`000?l0000Sooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oooooo1?l00007ooooo`;o00001oooool2o`0000Gooooo0_l00002oooo
o`;o0000??ooool2o`0002;ooooo0_l00005ooooo`;o00002?ooool2o`0000Wooooo0_l0000Voooo
o`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Oooooo`;o000000?oooooo`00
0?l000003_ooool2o`0001gooooo000[ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000007ooooo`Co00001oooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0003co
oooo0_l0000Rooooo`;o00001Oooool2o`0000Sooooo0_l00009ooooo`;o00009_ooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000007oooool2o`000003ooooool0003o000000ko
oooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0000/ooooo`;o00009_ooool2o`0000Wooooo0_l00003ooooo`;o00008_ooool2o`0000;ooooo
0_l0000Booooo`;o00004Oooool2o`0000Oooooo0_l00006ooooo`;o0000<_ooool2o`000003oooo
ool0003o000000_ooooo0_l00005ooooo`;o0000:_ooool002_ooooo00?o0000ooooooooool0:ooo
ool2o`0002Kooooo0_l00009ooooo`;o00000oooool2o`0002;ooooo0_l00002ooooo`;o00004_oo
ool2o`00017ooooo0_l00007ooooo`;o00001_ooool2o`0003;ooooo0_l000000ooooooo0000o`00
000;ooooo`;o00001Oooool2o`0002[ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000?ooooo`?o00003Ooo
ool2o`0001Kooooo1?l0000Booooo`;o00002?ooool3o`0002;ooooo0_l0000Booooo`;o00008_oo
ool2o`0002Oooooo0_l00004ooooo`;o0000E_ooool002_ooooo00?o0000ooooooooool03_ooool3
o`0000gooooo0_l0000Fooooo`Co00004_ooool2o`0000Sooooo0ol0000Rooooo`;o00004_ooool2
o`0002;ooooo0_l0000Wooooo`;o00001?ooool2o`0005Kooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool0
01_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool3o`0005Wooooo0_l00009ooooo`;o0000??ooool2o`0004cooooo0_l0000P
ooooo`;o00009_ooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0001Iooooo`;o00002Oooool2o`0003cooooo0_l0001<ooooo`;o00008?ooool2
o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0E?ooool2o`00
07cooooo0_l0001Vooooo`00:oooool2o`0005Gooooo0_l0001looooo`;o0000I_ooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000DOooool2o`0000oooooo
0_l0001Fooooo`;o0000Ooooool002_ooooo00?o0000ooooooooool0D?ooool2o`0000oooooo0_l0
001Fooooo`;o0000Ooooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo3?ooool2o`0002kooooo000[
ooooo`03o`000?oooooooooo0?oooooo2oooool2o`0002kooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
ooooo`?ooooo0_l0000gooooo`00:oooool00ol0003oooooooooo`3oooooo`;ooooo0_l0000goooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_o
oooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool0
01Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo
01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOoo
ool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;o
oooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00kooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o000000?o410@ooooooooool0oooooolC
ooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooo
oiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo
00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooooaCooooo0004ooooo`04
omgMgOl0003o410@olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool0
1?oMgMgo0000oa0@4?o<c<`Booooo`05o`000?ooooooooooooooool000005Oooool01?l0003ooooo
ooooooooool5o`000?oooooo5Oooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko
410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hB
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?oZJVYoa0@4?ooool00_oo
ool01?m4A4CogMgMooooool0003ooooooaKooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo
00WoEEEEoiRHV?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb
<S8Booooo`05o`000?n7QhOoooooojVYZOl000004oooool00ol@413o0000okZj^P03ooooo`04omgM
gOmEEEGoooooo`000?oooooo5_ooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@
ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o^[Zjob4Q8Oooool00oooool00omgMgOoc<c<
o`00003ooooooaKooooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0aooooo`05
oa0@4?nHV9SooooookZj^_l000001?ooool00oo^k^koA4A4o`00003ooooooaKooooo000?ooooo`03
okZj^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool01OnYZJWo410@o`000?l@413oZJVY
00Gooooo00?oMgMgo`000?ooool0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .42232 Mdot
.03333 .29872 Mdot
.0381 .33992 Mdot
.04286 .27812 Mdot
.04762 .31932 Mdot
.05238 .27812 Mdot
.05714 .29872 Mdot
.0619 .33992 Mdot
.06667 .29872 Mdot
.07143 .33992 Mdot
.07619 .29872 Mdot
.08095 .38112 Mdot
.08571 .40172 Mdot
.09048 .29872 Mdot
.09524 .23691 Mdot
.1 .36052 Mdot
.10476 .33992 Mdot
.10952 .36052 Mdot
.11429 .21631 Mdot
.11905 .27812 Mdot
.12381 .27812 Mdot
.12857 .27812 Mdot
.13333 .38112 Mdot
.1381 .33992 Mdot
.14286 .23691 Mdot
.14762 .33992 Mdot
.15238 .33992 Mdot
.15714 .29872 Mdot
.1619 .27812 Mdot
.16667 .36052 Mdot
.17143 .25751 Mdot
.17619 .36052 Mdot
.18095 .31932 Mdot
.18571 .23691 Mdot
.19048 .36052 Mdot
.19524 .31932 Mdot
.2 .25751 Mdot
.20476 .33992 Mdot
.20952 .31932 Mdot
.21429 .38112 Mdot
.21905 .38112 Mdot
.22381 .31932 Mdot
.22857 .21631 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .23691 Mdot
.24762 .27812 Mdot
.25238 .33992 Mdot
.25714 .29872 Mdot
.2619 .27812 Mdot
.26667 .31932 Mdot
.27143 .33992 Mdot
.27619 .17511 Mdot
.28095 .23691 Mdot
.28571 .40172 Mdot
.29048 .29872 Mdot
.29524 .25751 Mdot
.3 .46353 Mdot
.30476 .19571 Mdot
.30952 .36052 Mdot
.31429 .42232 Mdot
.31905 .38112 Mdot
.32381 .38112 Mdot
.32857 .42232 Mdot
.33333 .31932 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .36052 Mdot
.35238 .29872 Mdot
.35714 .46353 Mdot
.3619 .36052 Mdot
.36667 .42232 Mdot
.37143 .27812 Mdot
.37619 .25751 Mdot
.38095 .25751 Mdot
.38571 .21631 Mdot
.39048 .17511 Mdot
.39524 .23691 Mdot
.4 .19571 Mdot
.40476 .23691 Mdot
.40952 .33992 Mdot
.41429 .31932 Mdot
.41905 .27812 Mdot
.42381 .31932 Mdot
.42857 .23691 Mdot
.43333 .23691 Mdot
.4381 .29872 Mdot
.44286 .38112 Mdot
.44762 .25751 Mdot
.45238 .29872 Mdot
.45714 .31932 Mdot
.4619 .29872 Mdot
.46667 .29872 Mdot
.47143 .31932 Mdot
.47619 .21631 Mdot
.48095 .38112 Mdot
.48571 .27812 Mdot
.49048 .29872 Mdot
.49524 .36052 Mdot
.5 .31932 Mdot
.50476 .33992 Mdot
.50952 .38112 Mdot
.51429 .23691 Mdot
.51905 .25751 Mdot
.52381 .29872 Mdot
.52857 .36052 Mdot
.53333 .23691 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .27812 Mdot
.55238 .36052 Mdot
.55714 .23691 Mdot
.5619 .36052 Mdot
.56667 .23691 Mdot
.57143 .40172 Mdot
.57619 .23691 Mdot
.58095 .17511 Mdot
.58571 .33992 Mdot
.59048 .29872 Mdot
.59524 .33992 Mdot
.6 .27812 Mdot
.60476 .25751 Mdot
.60952 .33992 Mdot
.61429 .33992 Mdot
.61905 .36052 Mdot
.62381 .36052 Mdot
.62857 .40172 Mdot
.63333 .23691 Mdot
.6381 .29872 Mdot
.64286 .33992 Mdot
.64762 .46353 Mdot
.65238 .38112 Mdot
.65714 .27812 Mdot
.6619 .21631 Mdot
.66667 .25751 Mdot
.67143 .33992 Mdot
.67619 .25751 Mdot
.68095 .36052 Mdot
.68571 .25751 Mdot
.69048 .27812 Mdot
.69524 .29872 Mdot
.7 .23691 Mdot
.70476 .29872 Mdot
.70952 .21631 Mdot
.71429 .25751 Mdot
.71905 .25751 Mdot
.72381 .15451 Mdot
.72857 .44292 Mdot
.73333 .23691 Mdot
.7381 .27812 Mdot
.74286 .25751 Mdot
.74762 .31932 Mdot
.75238 .33992 Mdot
.75714 .31932 Mdot
.7619 .38112 Mdot
.76667 .33992 Mdot
.77143 .23691 Mdot
.77619 .19571 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .33992 Mdot
.79524 .27812 Mdot
.8 .33992 Mdot
.80476 .31932 Mdot
.80952 .19571 Mdot
.81429 .27812 Mdot
.81905 .21631 Mdot
.82381 .27812 Mdot
.82857 .40172 Mdot
.83333 .27812 Mdot
.8381 .31932 Mdot
.84286 .29872 Mdot
.84762 .25751 Mdot
.85238 .38112 Mdot
.85714 .25751 Mdot
.8619 .38112 Mdot
.86667 .23691 Mdot
.87143 .21631 Mdot
.87619 .33992 Mdot
.88095 .31932 Mdot
.88571 .48413 Mdot
.89048 .29872 Mdot
.89524 .29872 Mdot
.9 .25751 Mdot
.90476 .36052 Mdot
.90952 .36052 Mdot
.91429 .48413 Mdot
.91905 .36052 Mdot
.92381 .11331 Mdot
.92857 .36052 Mdot
.93333 .31932 Mdot
.9381 .33992 Mdot
.94286 .40172 Mdot
.94762 .31932 Mdot
.95238 .31932 Mdot
.95714 .27812 Mdot
.9619 .29872 Mdot
.96667 .27812 Mdot
.97143 .36052 Mdot
.97619 .25751 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool>ooooo`;o0000:oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooo`kooooo
0_l0000[ooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0=3ooooo0_l0001Xooooo`00:oooool00ol0003ooooo
ooooo`3@ooooo`;o0000J?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0BOooool2o`00023ooooo0_l0000hooooo`;o0000Toooool002_ooooo00?o0000
ooooooooool0BOooool2o`00023ooooo0_l0000hooooo`;o0000Toooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo05;ooooo0_l0000Jooooo`;o0000L?ooool2o`0000Sooooo0_l0001>ooooo`006Oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo05;ooooo
0_l0000Jooooo`;o0000L?ooool2o`0000Sooooo0_l0001>ooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo01Sooooo0_l0000Pooooo`;o0000;_ooool2o`0001Wooooo0_l0000gooooo`;o0000
3?ooool2o`0001oooooo0_l0000>ooooo`;o0000>oooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06?ooool2o`00023ooooo
0_l0000^ooooo`;o00006Oooool2o`0003Oooooo0_l0000<ooooo`;o00007oooool2o`0000kooooo
0_l0000kooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool04_ooool2o`0000gooooo0_l0000;ooooo`;o00003oooool2o`0000Wo
oooo0_l0000Aooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0ol0000Gooooo`;o
00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l0000Boooo
o`;o00002?ooool2o`0000[ooooo0_l0000Jooooo`;o0000?Oooool002_ooooo00?o0000oooooooo
ool04_ooool2o`0000gooooo0_l0000;ooooo`;o00003oooool2o`0000Wooooo0_l0000Aooooo`;o
00003_ooool2o`000003ooooool0003o000000Gooooo0ol0000Gooooo`;o00001?ooool2o`0000Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l0000Booooo`;o00002?ooool2o`00
00[ooooo0_l0000Jooooo`;o0000?Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo02Wooooo0_l00007oooo
o`;o00006oooool2o`0001Kooooo1?l0000Booooo`;o00004oooool2o`0001Sooooo0_l0000Aoooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00001Oooool2o`0001kooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00005Oooool2o`0001_ooooo000[ooooo`03o`000?oooooooooo
02Wooooo0_l00007ooooo`;o00006oooool2o`0001Kooooo1?l0000Booooo`;o00004oooool2o`00
01Sooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00001Oooool2
o`0001kooooo0_l000000ooooooo0000o`00000;ooooo`;o00005Oooool2o`0001_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb
<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003o
ooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000oooooooo
ool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000ooooooooool00_ooool2o`000003
ooooool0003o000001;ooooo1Ol00008ooooo`;o00006?ooool2o`000003ogMgMolb<S;ooooo00;o
00000oooool00ol0003oooooooooo`0Iooooo`;o00003?ooool2o`0000oooooo00?o0000oooooooo
ool00ol00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?l0003o
oooo00;o00003_ooool2o`0000oooooo0_l00008ooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`;o000000Co<S8boooooooooooo00000oooool00ol0003oooooooooo`05ooooo`;o00001?oo
ool4o`000003ooooool0003o0000027ooooo00?oV9RHob4Q8Oo^k^h00_l000000ooooooo0000o`00
0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:ooo
ool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000004_ooool5o`0000Sooooo0_l0
000Gooooo`?o000000?o<S8bolc<c?ooool00_l00003ooooo`03o`000?oooooooooo01Wooooo0_l0
000<ooooo`;o00003oooool00ol0003oooooooooo`03o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?oooooo0000o`000?ooool00_l0000>ooooo`;o00003oooool2o`0000So
oooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o0000olc<c002oooo
o`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo1?l000000ooooooo0000o`00000R
ooooo`05ogMgMomVIVKo0000o`000?ooool00_l00002ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400g
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool04Oooool002_ooooo0_l00010ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`0oooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^03Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`03oeEEEOmVIVKo000000Gooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool01?l0003oooooo`000?l00006ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o00004_ooool2o`0001Gooooo0ol00004ooooo`;o
00002?ooool2o`00017ooooo0_l0000Hooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Kooooo0_l00008ooooo`;o00004_ooool2o`0000cooooo0_l0000@ooooo`Co0000:?ooool2o`00
00gooooo0ol0000Booooo`;o00008?ooool002_ooooo00Co0000ooooool0003o00001_ooool2o`00
0003ooooool0003o000000;o00000oooool2o`0001;ooooo0_l0000Eooooo`?o00001?ooool2o`00
00Sooooo0_l0000Aooooo`;o00006?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o00002?ooool2o`0001;ooooo0_l0000<ooooo`;o00004?ooool4o`0002Sooooo0_l0000=
ooooo`?o00004_ooool2o`0001Kooooo0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[oooo
o`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooo
oooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH
00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04Oooool01?l0003o
k^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003oooooooooo`04ooooo`;o00009_ooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0000Booooo`Co00005Oooool2o`000003
ooooool0003o000000Sooooo0_l00002ooooo`;o00001oooool2o`0004Sooooo0_l000000ooooooo
0000o`000007ooooo`;o00001?ooool2o`0000Sooooo0_l0000;ooooo`;o00003_ooool2o`0000;o
oooo0ol0000Jooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo00?o0000oooooooo
ool01?ooool2o`0002Kooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o
00004_ooool4o`0001Gooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000Oo
oooo0_l00018ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00008ooooo`;o
00002oooool2o`0000kooooo0_l00002ooooo`?o00006_ooool00ol0003oooooooooo`06ooooo`00
:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o
0000ooooooooool0oooooolaooooo`;o00002?ooool002_ooooo0_l0003ooooooccooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00Co0000oooooooooooooooo0_l00005oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000>
ooooo`;o00003Oooool2o`0000?ooooo0_l0000Xooooo`;o00006oooool2o`0000[ooooo0_l0000:
ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo0_l00006ooooo`;o00005oooool2
o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000005Oooool2o`00017ooooo0_l0000W
ooooo`00:oooool01?l0003oooooooooooooool2o`0000Gooooo0_l000000ooooooo0000o`000008
ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000kooooo0_l0000=ooooo`;o00000ooo
ool2o`0002Sooooo0_l0000Kooooo`;o00002_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`?o00001oooool2o`0000Kooooo0_l0000Gooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00004Oooool2o`0002Oooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01Cooooo1?l0000@ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0002;ooooo0_l00009ooooo`;o00000oooool2o`0002Kooooo0_l00008
ooooo`;o00001Oooool2o`000003ooooool0003o0000013ooooo0ol0000?ooooo`;o0000@_ooool3
o`000004ooooool0003o0000ooooo`;o00002oooool2o`0001gooooo000[ooooo`03o`000?oooooo
oooo01Cooooo1?l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0002;ooooo0_l00009
ooooo`;o00000oooool2o`0002Kooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o
0000013ooooo0ol0000?ooooo`;o0000@_ooool3o`000004ooooool0003o0000ooooo`;o00002ooo
ool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00003_ooool2o`0001Kooooo1?l0
000Looooo`?o00008_ooool2o`0000[ooooo0_l00006ooooo`;o0000:_ooool2o`0001oooooo0_l0
0004ooooo`;o00004oooool2o`000003ooooool0003o000003kooooo000[ooooo`03o`000?oooooo
oooo00kooooo0_l0000>ooooo`;o00005_ooool4o`0001cooooo0ol0000Rooooo`;o00002_ooool2
o`0000Kooooo0_l0000Zooooo`;o00007oooool2o`0000Cooooo0_l0000Cooooo`;o000000?ooooo
o`000?l00000?_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00oooooo0_l0000kooooo`;o0000E?ooool2
o`0000oooooo0_l0000kooooo`;o00008?ooool2o`0002Kooooo000Iooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool03oooool2o`0003_ooooo
0_l0001Dooooo`;o00003oooool2o`0003_ooooo0_l0000Pooooo`;o00009_ooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
E?ooool2o`0000?ooooo0_l00009ooooo`;o0000e?ooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0ol0001Dooooo`;o00000oooool2o`0000Wooooo
0_l0003Dooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3Booooo`;o0000
I_ooool002_ooooo00?o0000ooooooooool0d_ooool2o`0006Kooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`1@ooooo`;o00003oooool2o`0005Kooooo0_l0001oooooo`00:oooool00ol0003oooooooooo`1@
ooooo`;o00003oooool2o`0005Kooooo0_l0001oooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0ooooool2
ooooo`;o00001oooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo0_ooool2o`00
00Oooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001So
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Koooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?oooooo>oooool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`000?oooooo>oooool001[ooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo00000?ooooooA?ooool001_ooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@0?ooooooA?ooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooom4ooooo`006?ooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodCooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Rooooo`03o`00
0?nj^[[ooooo0?ooooooA?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOoo
ool000?ooooo0_l00002ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o
000000?o000000?o<S8booooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@3ooooooaCooooo0003ooooo`06onk^
k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?ooooo00[o
A4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@400<
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMg
oc8b<P07ooooo`03ogMgMolb<S;ooooo0?oooooo4oooool000Cooooo00CogMgMo`000?l@413oc<c<
1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<
c1;ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0oooooolBooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413o
k^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo
00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00onYZJWo410@ooooo`06ooooo`03
ogMgMolb<S;ooooo0?oooooo4oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGo
V9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo
00Go0000ohN7QoooooooZJVYo`00000Cooooo`03oa0@4?l0003o^[Zj00Cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c03ooooooaCooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?oo
ool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0Booooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000oooooooo
ool0oooooolFooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<Oooool01Ol@
413oV9RHoooooonj^[[o000000Cooooo00?o0000ooooooooool0oooooolFooooo`003oooool00onj
^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo033ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04
ooooo`Co0000oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .43262 Mdot
.03333 .28842 Mdot
.0381 .35022 Mdot
.04286 .26781 Mdot
.04762 .30902 Mdot
.05238 .28842 Mdot
.05714 .30902 Mdot
.0619 .35022 Mdot
.06667 .28842 Mdot
.07143 .32962 Mdot
.07619 .30902 Mdot
.08095 .37082 Mdot
.08571 .41202 Mdot
.09048 .28842 Mdot
.09524 .24721 Mdot
.1 .37082 Mdot
.10476 .35022 Mdot
.10952 .37082 Mdot
.11429 .22661 Mdot
.11905 .26781 Mdot
.12381 .28842 Mdot
.12857 .26781 Mdot
.13333 .37082 Mdot
.1381 .35022 Mdot
.14286 .24721 Mdot
.14762 .35022 Mdot
.15238 .35022 Mdot
.15714 .28842 Mdot
.1619 .26781 Mdot
.16667 .37082 Mdot
.17143 .24721 Mdot
.17619 .35022 Mdot
.18095 .32962 Mdot
.18571 .22661 Mdot
.19048 .37082 Mdot
.19524 .32962 Mdot
.2 .26781 Mdot
.20476 .35022 Mdot
.20952 .32962 Mdot
.21429 .39142 Mdot
.21905 .37082 Mdot
.22381 .32962 Mdot
.22857 .22661 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .22661 Mdot
.24762 .28842 Mdot
.25238 .35022 Mdot
.25714 .28842 Mdot
.2619 .28842 Mdot
.26667 .32962 Mdot
.27143 .32962 Mdot
.27619 .16481 Mdot
.28095 .22661 Mdot
.28571 .39142 Mdot
.29048 .28842 Mdot
.29524 .24721 Mdot
.3 .47383 Mdot
.30476 .18541 Mdot
.30952 .35022 Mdot
.31429 .43262 Mdot
.31905 .37082 Mdot
.32381 .39142 Mdot
.32857 .41202 Mdot
.33333 .30902 Mdot
.3381 .32962 Mdot
.34286 .22661 Mdot
.34762 .35022 Mdot
.35238 .30902 Mdot
.35714 .47383 Mdot
.3619 .37082 Mdot
.36667 .41202 Mdot
.37143 .26781 Mdot
.37619 .26781 Mdot
.38095 .24721 Mdot
.38571 .22661 Mdot
.39048 .16481 Mdot
.39524 .22661 Mdot
.4 .20601 Mdot
.40476 .22661 Mdot
.40952 .32962 Mdot
.41429 .32962 Mdot
.41905 .28842 Mdot
.42381 .30902 Mdot
.42857 .24721 Mdot
.43333 .22661 Mdot
.4381 .30902 Mdot
.44286 .37082 Mdot
.44762 .24721 Mdot
.45238 .28842 Mdot
.45714 .32962 Mdot
.4619 .30902 Mdot
.46667 .28842 Mdot
.47143 .32962 Mdot
.47619 .20601 Mdot
.48095 .39142 Mdot
.48571 .28842 Mdot
.49048 .28842 Mdot
.49524 .35022 Mdot
.5 .32962 Mdot
.50476 .35022 Mdot
.50952 .37082 Mdot
.51429 .22661 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .37082 Mdot
.53333 .24721 Mdot
.5381 .26781 Mdot
.54286 .32962 Mdot
.54762 .28842 Mdot
.55238 .35022 Mdot
.55714 .24721 Mdot
.5619 .35022 Mdot
.56667 .24721 Mdot
.57143 .41202 Mdot
.57619 .22661 Mdot
.58095 .18541 Mdot
.58571 .32962 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .28842 Mdot
.60476 .24721 Mdot
.60952 .35022 Mdot
.61429 .35022 Mdot
.61905 .37082 Mdot
.62381 .35022 Mdot
.62857 .41202 Mdot
.63333 .24721 Mdot
.6381 .30902 Mdot
.64286 .35022 Mdot
.64762 .47383 Mdot
.65238 .39142 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .24721 Mdot
.67143 .35022 Mdot
.67619 .24721 Mdot
.68095 .35022 Mdot
.68571 .26781 Mdot
.69048 .28842 Mdot
.69524 .30902 Mdot
.7 .22661 Mdot
.70476 .30902 Mdot
.70952 .20601 Mdot
.71429 .24721 Mdot
.71905 .26781 Mdot
.72381 .14421 Mdot
.72857 .45322 Mdot
.73333 .24721 Mdot
.7381 .26781 Mdot
.74286 .24721 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .30902 Mdot
.7619 .39142 Mdot
.76667 .32962 Mdot
.77143 .22661 Mdot
.77619 .18541 Mdot
.78095 .37082 Mdot
.78571 .30902 Mdot
.79048 .32962 Mdot
.79524 .28842 Mdot
.8 .32962 Mdot
.80476 .32962 Mdot
.80952 .18541 Mdot
.81429 .26781 Mdot
.81905 .22661 Mdot
.82381 .26781 Mdot
.82857 .39142 Mdot
.83333 .26781 Mdot
.8381 .30902 Mdot
.84286 .28842 Mdot
.84762 .26781 Mdot
.85238 .39142 Mdot
.85714 .24721 Mdot
.8619 .37082 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .32962 Mdot
.88095 .32962 Mdot
.88571 .49443 Mdot
.89048 .30902 Mdot
.89524 .28842 Mdot
.9 .24721 Mdot
.90476 .37082 Mdot
.90952 .37082 Mdot
.91429 .47383 Mdot
.91905 .35022 Mdot
.92381 .10301 Mdot
.92857 .37082 Mdot
.93333 .32962 Mdot
.9381 .32962 Mdot
.94286 .41202 Mdot
.94762 .32962 Mdot
.95238 .32962 Mdot
.95714 .28842 Mdot
.9619 .30902 Mdot
.96667 .26781 Mdot
.97143 .37082 Mdot
.97619 .24721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000ooooool>ooooo`;o0000:oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000:ooo
ool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3@ooooo`;o0000J?ooool002_ooooo0_l0003Aooooo`;o0000J?ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`19ooooo`;o00008?ooool2o`000<gooooo000[ooooo`;o0000B_ooool2o`00
023ooooo0_l0003=ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0001Cooooo`;o0000DOooool2o`0003Wooooo0_l00008ooooo`;o0000C_ooool002_ooooo
00?o0000ooooooooool0D_ooool2o`00057ooooo0_l0000iooooo`;o00002?ooool2o`0004kooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0001^ooooo`;o0000
5Oooool2o`0003Oooooo0_l0000<ooooo`;o0000K?ooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0K_ooool2o`0001Gooooo
0_l0000gooooo`;o00003?ooool2o`0006cooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
000Iooooo`;o00005?ooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool2o`00017ooooo0_l0
000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00005oooool2o`00017ooooo
0_l0000Sooooo`;o00005?ooool2o`0000cooooo0_l0000>ooooo`;o0000>oooool002_ooooo00?o
0000ooooooooool06?ooool2o`0001Cooooo0_l0000:ooooo`;o00000oooool2o`0000Wooooo0_l0
000Aooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0001Oooooo
0_l0000Aooooo`;o00008oooool2o`0001Cooooo0_l0000<ooooo`;o00003_ooool2o`0003_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool04_ooool2o`0000gooooo0_l00006ooooo`;o0000
9?ooool2o`0001Sooooo0_l0000<ooooo`;o00001?ooool2o`0001Sooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Qooooo`Co00002Oooool2o`0001Gooooo
0_l0000Kooooo`00:oooool2o`0001?ooooo0_l0000=ooooo`;o00001_ooool2o`0002Cooooo0_l0
000Hooooo`;o00003?ooool2o`0000Cooooo0_l0000Hooooo`;o00001Oooool2o`000003ooooool0
003o000000Wooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000Wooooo0_l0
0004ooooo`;o000000?oooooo`000?l000008Oooool4o`0000Wooooo0_l0000Eooooo`;o00006ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o00000oooool2
o`0001Gooooo0_l000000ooooooo0000o`000008ooooo`;o00002_ooool2o`0000_ooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool3o`0001[ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool3o`000003oc8b<_o^k^ko
oooo00;o0000:oooool2o`0000Cooooo1_l00002ooooo`05odA4A?l0003o0000o`000?oMgMd00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo1?l000000ooooooo0000o`000003ooooo`;o0000
6_ooool5o`0000?ooooo0ol000000olb<S;ok^k^ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h04oooool002_ooooo00?o0000ooooooooool00_ooool2o`0001Gooooo0_l000000ooooooo0000
o`000008ooooo`;o00002_ooool2o`0000kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL06oooool3o`0001cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0_l000001?ooooooV9RHogMgMoooool2o`0002_ooooo0_l00006ooooo`04o`00
0?oooooo0000o`0000Cooooo0_l000002?lb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg3Ooo
ool4o`000003ooooool0003o000000?ooooo0_l0000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool2o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00
:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool00ol0003ooooo
ooooo`12ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000=_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000ooooooooool0
?oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000joooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000=_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000003Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00:oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400j
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo1?l00004oooo
o`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool2o`0001Gooooo1_l000000ooo
oooo0000o`000002o`000004oiRHV?ooooooV9RHogMgM`;ooooo0_l0000Uooooo`;o00002?ooool2
o`0000;ooooo0_l000001?oooooo0000ooooooooool4o`000003oooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?l0003o0000ogMgM`04ooooo`;o00002oooool2o`000003ooooool0003o000000oooooo
0_l00008ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00003?ooool2o`0000kooooo0_l0000<ooooo`05
o`000?nj^[[ooooooiRHV?l@41000_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool01?l0003oooooo`000?l00004ooooo`;o0000
0oooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool2o`0001Gooooo2ol000001?lb<S;o0000
oc8b<_o^k^h2ooooo`;o00009Oooool2o`0000Sooooo0_l00002ooooo`;o000000CoIVIVo`000?oo
oooooooo1Ol000000olb<S;ok^k^ooooo`02ooooo`05onk^k_lb<S;o0000o`000?o^k^h01?ooool2
o`0000_ooooo0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`0000?ooooo00?oEEEE
ofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00003?oo
ool2o`0000kooooo0_l0000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_l000001_ooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?oo
ooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003ooooooooo
o`04ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000gooooo00?o0000ooooooooool00ooo
ool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo0000o`0000[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0ol0000>ooooo`Go0000
2Oooool01Ol0003oooooo`000?l0003ooooo00;o00001oooool2o`0000gooooo0ol0000;ooooo`03
o`000?oooooooooo00;o00002_ooool00ol0003oooooooooo`06ooooo`;o00000oooool00ol0003o
ooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooo
oolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo00_ooooo0_l0000O
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00002oooool3o`0001?ooooo0_l0000C
ooooo`Co00002oooool2o`0000;ooooo0_l00007ooooo`;o00002oooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000^ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0001?ooooo1?l0000>ooooo`?o000000Coooooo`000?l0003o00006Oooool2o`0000Sooooo000[
ooooo`;o00003?ooool2o`0001oooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000;
ooooo`?o00004oooool2o`0001?ooooo1?l0000;ooooo`;o00000_ooool2o`0000Oooooo0_l0000;
ooooo`;o00002_ooool2o`000003ooooool0003o000002kooooo0_l00002ooooo`;o00001Oooool2
o`000003ooooool0003o000000;o00004oooool4o`0000kooooo0ol000001?oooooo0000o`000?l0
000Sooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`0000_ooooo
0_l00008ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo0_l0000=ooooo`;o
00003oooool2o`0000Wooooo0_l0000[ooooo`;o000000?oooooo`000?l000003?ooool2o`000003
ooooool0003o000000gooooo0ol000000ooooooo0000o`000004ooooo`;o00001_ooool2o`000003
ooooool0003o000004Kooooo0_l0000]ooooo`00:oooool2o`0000;ooooo0_l00005ooooo`;o0000
2oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001_ooool2o`0000go
oooo0_l0000?ooooo`;o00002Oooool2o`0002_ooooo0_l000000ooooooo0000o`00000<ooooo`;o
000000?oooooo`000?l000003Oooool3o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o
000000?oooooo`000?l00000A_ooool2o`0002gooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool2o`0000oooooo0_l00004ooooo`Co00001_ooool2o`0000Sooooo
0_l00005ooooo`;o00001oooool2o`0001cooooo0_l0000;ooooo`;o00005_ooool2o`0001;ooooo
0_l00004ooooo`;o00006_ooool2o`0002oooooo0_l0000Fooooo`;o00002oooool3o`0000Cooooo
0_l0000;ooooo`;o00007Oooool002_ooooo00?o0000ooooooooool03_ooool2o`0000Cooooo1?l0
0006ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`;o00007?ooool2o`0000_ooooo0_l0
000Fooooo`;o00004_ooool2o`0000Cooooo0_l0000Jooooo`;o0000;oooool2o`0001Kooooo0_l0
000;ooooo`?o00001?ooool2o`0000_ooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000=ooo
ool2o`0001Cooooo0_l00009ooooo`;o0000;_ooool2o`0003;ooooo0_l0000Oooooo`;o00004_oo
ool2o`0000Gooooo0_l00011ooooo`00:oooool00ol0003oooooooooo`0fooooo`;o00005?ooool2
o`0000Wooooo0_l0000^ooooo`;o0000<_ooool2o`0001oooooo0_l0000Booooo`;o00001Oooool2
o`00047ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000oooooo0_l00018
ooooo`;o00002Oooool2o`0003cooooo0_l0000?ooooo`;o0000GOooool2o`0002Kooooo000Koooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00oooooo0_l00018ooooo`;o00002Oooool2o`0003cooooo0_l0000?ooooo`;o0000GOooool2
o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0ol0001Dooooo`;o0000i?ooool002_o
oooo0ol0001Dooooo`;o0000i?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000doooool2o`0006Kooooo000[ooooo`03o`000?oooooooooo0=;ooooo0_l0
001Vooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`;o0000DOooool2o`0000oooooo0_l0001Fooooo`;o0000Cooo
ool2o`0002kooooo000[ooooo`03o`000?oooooooooo053ooooo0_l0000?ooooo`;o0000E_ooool2
o`0004oooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000ooooool3ooooo`;o0000=oooool0
02_ooooo00?o0000ooooooooool0ooooool2ooooo`;o0000=oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo>oooool001_ooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkoooo
o`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0
003oooooooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool00000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?ooooooooooooooool@4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000
okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5oooo
o`000oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l0
00000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_o
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0>ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<0?oooooo5Oooool000?ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4
A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00co
oooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@3ooooooaGooooo0004ooooo`04omgMgOl0003o
410@olc<c0Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000
oa0@4?o<c<`Booooo`05o`000?ooooooooooooooool000005Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0oooooolCooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5
ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ
8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40oooooolEooooo`001?ooool01?lQ8B7o
MgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo
00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?o410@o`00
0?nj^[X00oooool01Ol0003oEEEEo`000?l@413oc<c<0?oooooo5Oooool000?ooooo0_l00002oooo
o`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002oooo
o`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o^[Zjob4Q
8Oooool00_ooool00omEEEGoQhN7ooooo`3ooooooaOooooo000?ooooo`07oeEEEOnHV9Sooooooooo
oooMgMgo0000omgMg@0aooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRH
V03ooooooaOooooo000?ooooo`03okZj^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool0
1OnYZJWo410@o`000?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@oooooolEooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44292 Mdot
.03333 .29872 Mdot
.0381 .36052 Mdot
.04286 .27812 Mdot
.04762 .31932 Mdot
.05238 .27812 Mdot
.05714 .31932 Mdot
.0619 .33992 Mdot
.06667 .27812 Mdot
.07143 .33992 Mdot
.07619 .29872 Mdot
.08095 .36052 Mdot
.08571 .40172 Mdot
.09048 .29872 Mdot
.09524 .25751 Mdot
.1 .38112 Mdot
.10476 .36052 Mdot
.10952 .36052 Mdot
.11429 .23691 Mdot
.11905 .27812 Mdot
.12381 .27812 Mdot
.12857 .25751 Mdot
.13333 .36052 Mdot
.1381 .36052 Mdot
.14286 .23691 Mdot
.14762 .33992 Mdot
.15238 .36052 Mdot
.15714 .29872 Mdot
.1619 .27812 Mdot
.16667 .36052 Mdot
.17143 .23691 Mdot
.17619 .36052 Mdot
.18095 .31932 Mdot
.18571 .23691 Mdot
.19048 .36052 Mdot
.19524 .33992 Mdot
.2 .27812 Mdot
.20476 .33992 Mdot
.20952 .33992 Mdot
.21429 .40172 Mdot
.21905 .36052 Mdot
.22381 .31932 Mdot
.22857 .23691 Mdot
.23333 .27812 Mdot
.2381 .29872 Mdot
.24286 .23691 Mdot
.24762 .29872 Mdot
.25238 .36052 Mdot
.25714 .29872 Mdot
.2619 .29872 Mdot
.26667 .33992 Mdot
.27143 .31932 Mdot
.27619 .17511 Mdot
.28095 .21631 Mdot
.28571 .38112 Mdot
.29048 .29872 Mdot
.29524 .25751 Mdot
.3 .46353 Mdot
.30476 .17511 Mdot
.30952 .33992 Mdot
.31429 .42232 Mdot
.31905 .38112 Mdot
.32381 .38112 Mdot
.32857 .40172 Mdot
.33333 .29872 Mdot
.3381 .33992 Mdot
.34286 .23691 Mdot
.34762 .33992 Mdot
.35238 .31932 Mdot
.35714 .46353 Mdot
.3619 .36052 Mdot
.36667 .42232 Mdot
.37143 .25751 Mdot
.37619 .25751 Mdot
.38095 .23691 Mdot
.38571 .23691 Mdot
.39048 .15451 Mdot
.39524 .23691 Mdot
.4 .21631 Mdot
.40476 .21631 Mdot
.40952 .31932 Mdot
.41429 .33992 Mdot
.41905 .27812 Mdot
.42381 .31932 Mdot
.42857 .25751 Mdot
.43333 .21631 Mdot
.4381 .29872 Mdot
.44286 .36052 Mdot
.44762 .25751 Mdot
.45238 .29872 Mdot
.45714 .31932 Mdot
.4619 .29872 Mdot
.46667 .29872 Mdot
.47143 .33992 Mdot
.47619 .19571 Mdot
.48095 .38112 Mdot
.48571 .29872 Mdot
.49048 .27812 Mdot
.49524 .33992 Mdot
.5 .31932 Mdot
.50476 .36052 Mdot
.50952 .38112 Mdot
.51429 .23691 Mdot
.51905 .27812 Mdot
.52381 .29872 Mdot
.52857 .38112 Mdot
.53333 .23691 Mdot
.5381 .25751 Mdot
.54286 .31932 Mdot
.54762 .29872 Mdot
.55238 .36052 Mdot
.55714 .23691 Mdot
.5619 .36052 Mdot
.56667 .25751 Mdot
.57143 .42232 Mdot
.57619 .23691 Mdot
.58095 .17511 Mdot
.58571 .31932 Mdot
.59048 .29872 Mdot
.59524 .31932 Mdot
.6 .29872 Mdot
.60476 .23691 Mdot
.60952 .36052 Mdot
.61429 .33992 Mdot
.61905 .38112 Mdot
.62381 .36052 Mdot
.62857 .42232 Mdot
.63333 .25751 Mdot
.6381 .29872 Mdot
.64286 .36052 Mdot
.64762 .48413 Mdot
.65238 .40172 Mdot
.65714 .27812 Mdot
.6619 .19571 Mdot
.66667 .23691 Mdot
.67143 .36052 Mdot
.67619 .25751 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .31932 Mdot
.7 .21631 Mdot
.70476 .29872 Mdot
.70952 .19571 Mdot
.71429 .25751 Mdot
.71905 .27812 Mdot
.72381 .13391 Mdot
.72857 .46353 Mdot
.73333 .25751 Mdot
.7381 .27812 Mdot
.74286 .25751 Mdot
.74762 .29872 Mdot
.75238 .33992 Mdot
.75714 .31932 Mdot
.7619 .40172 Mdot
.76667 .33992 Mdot
.77143 .23691 Mdot
.77619 .19571 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .31932 Mdot
.79524 .27812 Mdot
.8 .31932 Mdot
.80476 .33992 Mdot
.80952 .17511 Mdot
.81429 .27812 Mdot
.81905 .23691 Mdot
.82381 .25751 Mdot
.82857 .40172 Mdot
.83333 .27812 Mdot
.8381 .31932 Mdot
.84286 .29872 Mdot
.84762 .25751 Mdot
.85238 .38112 Mdot
.85714 .23691 Mdot
.8619 .36052 Mdot
.86667 .23691 Mdot
.87143 .21631 Mdot
.87619 .33992 Mdot
.88095 .31932 Mdot
.88571 .48413 Mdot
.89048 .31932 Mdot
.89524 .27812 Mdot
.9 .23691 Mdot
.90476 .38112 Mdot
.90952 .38112 Mdot
.91429 .46353 Mdot
.91905 .36052 Mdot
.92381 .11331 Mdot
.92857 .36052 Mdot
.93333 .33992 Mdot
.9381 .31932 Mdot
.94286 .40172 Mdot
.94762 .31932 Mdot
.95238 .33992 Mdot
.95714 .27812 Mdot
.9619 .29872 Mdot
.96667 .27812 Mdot
.97143 .36052 Mdot
.97619 .23691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool>ooooo`;o0000:oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooo`kooooo
0_l0000[ooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3@ooooo`;o0000J?ooool002_ooooo00?o0000oooooooo
ool0d?ooool2o`0006Sooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1[ooooo`;o0000cOooool002_ooooo
00?o0000ooooooooool0Joooool2o`000<gooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o0000DOooool2o`0004?ooooo0_l0
001>ooooo`00:oooool00ol0003oooooooooo`19ooooo`;o00001oooool2o`00057ooooo0_l00013
ooooo`;o0000C_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo08Gooooo0_l0000gooooo`;o00003?ooool2
o`0001;ooooo0_l0001Hooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo08Gooooo0_l0000gooooo`;o00003?ooool2o`0001;ooooo
0_l0001Hooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo04[ooooo0_l0000Rooooo`Co0000
1_ooool2o`0004oooooo0_l0000booooo`;o0000>oooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0B_ooool2o`0002;ooooo
1?l00006ooooo`;o0000Coooool2o`0003;ooooo0_l0000kooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool06?ooool2o`0000Oo
oooo0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l00003ooooo`;o00007?ooool2o`0000[o
oooo0ol000000ooooooo0000o`00000Rooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o
00001_ooool2o`00017ooooo0_l0000Nooooo`;o00003?ooool2o`0000[ooooo1?l00009ooooo`;o
00005Oooool2o`0001_ooooo000[ooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o0000
1_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0001cooooo0_l0000:ooooo`?o0000
00?oooooo`000?l000008_ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo
0_l0000Aooooo`;o00007_ooool2o`0000cooooo0_l0000:ooooo`Co00002Oooool2o`0001Gooooo
0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool04_ooool2o`0000Sooooo0_l0000aooooo`;o0000
5Oooool3o`0000kooooo0_l00004ooooo`;o00006Oooool2o`0000Oooooo0_l0000Booooo`;o0000
2oooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Kooooo
0_l00012ooooo`00:oooool00ol0003oooooooooo`0Booooo`;o00002?ooool2o`00037ooooo0_l0
000Eooooo`?o00003_ooool2o`0000Cooooo0_l0000Iooooo`;o00001oooool2o`0001;ooooo0_l0
000;ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`;o00001_oo
ool2o`0004;ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`Co00002Oooool2o`00
00[ooooo0_l00008ooooo`;o00001?ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool09oooool2o`0000oooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo02?ooooo0_l00007ooooo`;o00001_oo
ool01?l0003oooooo`000?l00004ooooo`;o000000Co<S8boooooooooooo00000oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool2o`0000?ooooo0_l0000Aooooo`;o00003_ooool00onHV9So
8B4Qonk^kP02o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo017ooooo000[ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo
0000o`000003ooooo`;o00003Oooool4o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`000006
ooooool0003o8B4Qo`000?lb<S;oc<c<0_ooool01Ol0003ooooooooooooooooo000002Wooooo0_l0
000?ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool00ol0003oooooooooo`0Sooooo`;o00001oooool2o`0000Kooooo00Co0000ooooool0003o
00000_ooool01Ol0003o8B4Qo`000?l0003oc<c<00;ooooo00Go0000ooooooooooooooooo`000007
ooooo`;o00001?ooool2o`0000?ooooo0_l0000Aooooo`;o00003oooool01OmgMgOoIVIVo`000?l0
003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
4Oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo
000[ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo
00?o0000ooooooooool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0=?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00Co0000ooooool0003o00002oooool2o`0000?ooooo0_l0000Booooo`;o
00005_ooool2o`000004ooooool0003o0000ooooo`Co00001_ooool2o`0000_ooooo0_l0000Noooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000:ooooo`;o00001Oooool2
o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000;ooooo0_l0000;
ooooo`;o00006oooool2o`0002;ooooo0_l0000Pooooo`00:oooool01?l0003oooooo`000?l0000;
ooooo`;o00000oooool2o`0001;ooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo1?l0
0006ooooo`;o00002oooool2o`0001kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0000[ooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o000000Wooooo
0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l0000Kooooo`;o00008_ooool2o`0001Kooooo
0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_oo
ool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nH
V9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool0
0ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000008oooool2o`0000_ooooo0_l0000<
ooooo`;o00005oooool2o`0000oooooo0_l00003ooooo`;o00002?ooool2o`0000_ooooo0_l0000;
ooooo`;o00002_ooool2o`000003ooooool0003o000001gooooo0_l0000@ooooo`;o00001oooool3
o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000001_ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool0
0ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000008oooool2o`0000_ooooo0_l0000<
ooooo`;o00005oooool2o`0000oooooo0_l00003ooooo`;o00002?ooool2o`0000_ooooo0_l0000;
ooooo`;o00002_ooool2o`000003ooooool0003o000001gooooo0_l0000@ooooo`;o00001oooool3
o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000001_ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooo
ooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oo
oooo<Oooool2o`0000Sooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00000E
ooooo`;o00003?ooool2o`000003ooooool0003o000000;o00003oooool2o`0000_ooooo0_l00007
ooooo`Co00004oooool2o`0000oooooo0_l00005ooooo`;o00008_ooool2o`0001;ooooo0_l0000D
ooooo`;o00000_ooool2o`0000[ooooo0_l0000Cooooo`;o00004?ooool2o`0000?ooooo0_l0000S
ooooo`00:oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000005Oooool2o`00
00cooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0000;ooooo`;o00001oooool4o`00
01?ooooo0_l0000?ooooo`;o00001Oooool2o`0002;ooooo0_l0000Booooo`;o00005?ooool2o`00
00;ooooo0_l0000:ooooo`;o00004oooool2o`00013ooooo0_l00003ooooo`;o00008oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00Co0000oooooooooooooooo0_l0000;oooo
o`;o00001Oooool3o`0000Kooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`;o00002?ooool2o`0001oooooo0_l0000Fooooo`;o00004Oooool2o`00
00cooooo0_l000000ooooooo0000o`00000=ooooo`;o00000_ooool2o`0000Cooooo0_l00006oooo
o`;o0000>?ooool2o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`;o00007Oooool002_o
oooo00Co0000oooooooooooooooo0_l0000;ooooo`;o00001Oooool3o`0000Kooooo0ol00002oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00002?ooool2o`00
01oooooo0_l0000Fooooo`;o00004Oooool2o`0000cooooo0_l000000ooooooo0000o`00000=oooo
o`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o0000>?ooool2o`0000oooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00007Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01Cooooo0_l0000foooo
o`;o00002?ooool3o`0002kooooo0_l00006ooooo`;o00001?ooool2o`0001[ooooo0_l0000_oooo
o`;o00004oooool2o`0000kooooo0ol0000`ooooo`00:oooool00ol0003oooooooooo`0Dooooo`;o
0000=_ooool2o`0000Sooooo0ol0000^ooooo`;o00001_ooool2o`0000Cooooo0_l0000Jooooo`;o
0000;oooool2o`0001?ooooo0_l0000>ooooo`?o0000<?ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00oo
oooo0_l0000Uooooo`;o00008Oooool2o`00063ooooo0_l0000Oooooo`;o00004_ooool2o`00023o
oooo0_l0000Vooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo00oooooo0_l0000Uooooo`;o00008Oooool2o`00063ooooo0_l0000O
ooooo`;o00004_ooool2o`00023ooooo0_l0000Vooooo`006oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Koooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000oooooolk
ooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0E?ooool2
o`0000kooooo0_l0000looooo`;o00003oooool2o`0008Gooooo000Kooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo05Cooooo0_l0000>
ooooo`;o0000??ooool2o`0000oooooo0_l00025ooooo`006Oooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool3
o`000?oooooo>oooool002_ooooo0ol0003ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1@oooo
o`;o00003oooool2o`0006oooooo0_l0000fooooo`;o0000;_ooool002_ooooo00?o0000oooooooo
ool0D?ooool2o`0000oooooo0_l0001_ooooo`;o0000=_ooool2o`0002kooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`2iooooo`;o0000A_ooool2o`0003Oooooo000[ooooo`03o`000?oooooooooo0;Wooooo
0_l00016ooooo`;o0000=oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`00
6oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool0
0ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;ooooo
odGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o
0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj
^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo00GoV9RHoa0@
4?l0003o<S8bolc<c005ooooo`03o`000?o^k^kooooo0?oooooo5Oooool000?ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4Co
V9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo
00Go0000ooooooooooooooooo`000002ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00Gooooo00?oEEEEojVYZOooool0oooooolEooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_oo
ool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool00oooool00onYZJWoEEEE
ooooo`3ooooooaGooooo0004ooooo`04onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h0
0_ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0
003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00Gooooo00?o8B4Q
ooooooooool0oooooolDooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9So
ooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0
003oQhN7oooooonYZJWo000001?ooooo00?o410@o`000?nj^[X01_ooool00omEEEGoc<c<ooooo`3o
oooooaCooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omg
MgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`0Booooo`03okZj^_lQ8B7ooooo00Gooooo00?oZJVYogMgMoooool0oooooolDoooo
o`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<Oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00Go410@oooooooooooooooooc8b<P3ooooooaGooooo000?ooooo`03okZj^_m4
A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
1Ol0003ooooooaGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45322 Mdot
.03333 .28842 Mdot
.0381 .35022 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .28842 Mdot
.05714 .30902 Mdot
.0619 .32962 Mdot
.06667 .26781 Mdot
.07143 .35022 Mdot
.07619 .28842 Mdot
.08095 .37082 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .26781 Mdot
.1 .37082 Mdot
.10476 .35022 Mdot
.10952 .37082 Mdot
.11429 .24721 Mdot
.11905 .26781 Mdot
.12381 .26781 Mdot
.12857 .26781 Mdot
.13333 .37082 Mdot
.1381 .37082 Mdot
.14286 .22661 Mdot
.14762 .32962 Mdot
.15238 .35022 Mdot
.15714 .30902 Mdot
.1619 .26781 Mdot
.16667 .37082 Mdot
.17143 .22661 Mdot
.17619 .35022 Mdot
.18095 .30902 Mdot
.18571 .24721 Mdot
.19048 .37082 Mdot
.19524 .35022 Mdot
.2 .28842 Mdot
.20476 .35022 Mdot
.20952 .32962 Mdot
.21429 .41202 Mdot
.21905 .37082 Mdot
.22381 .32962 Mdot
.22857 .22661 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .24721 Mdot
.24762 .28842 Mdot
.25238 .37082 Mdot
.25714 .30902 Mdot
.2619 .30902 Mdot
.26667 .35022 Mdot
.27143 .32962 Mdot
.27619 .18541 Mdot
.28095 .20601 Mdot
.28571 .39142 Mdot
.29048 .28842 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .16481 Mdot
.30952 .32962 Mdot
.31429 .41202 Mdot
.31905 .39142 Mdot
.32381 .37082 Mdot
.32857 .39142 Mdot
.33333 .28842 Mdot
.3381 .32962 Mdot
.34286 .22661 Mdot
.34762 .32962 Mdot
.35238 .32962 Mdot
.35714 .47383 Mdot
.3619 .35022 Mdot
.36667 .43262 Mdot
.37143 .24721 Mdot
.37619 .26781 Mdot
.38095 .24721 Mdot
.38571 .22661 Mdot
.39048 .16481 Mdot
.39524 .22661 Mdot
.4 .22661 Mdot
.40476 .22661 Mdot
.40952 .30902 Mdot
.41429 .35022 Mdot
.41905 .28842 Mdot
.42381 .30902 Mdot
.42857 .26781 Mdot
.43333 .20601 Mdot
.4381 .28842 Mdot
.44286 .37082 Mdot
.44762 .24721 Mdot
.45238 .28842 Mdot
.45714 .30902 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .35022 Mdot
.47619 .20601 Mdot
.48095 .37082 Mdot
.48571 .28842 Mdot
.49048 .28842 Mdot
.49524 .32962 Mdot
.5 .32962 Mdot
.50476 .35022 Mdot
.50952 .39142 Mdot
.51429 .24721 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .37082 Mdot
.53333 .24721 Mdot
.5381 .26781 Mdot
.54286 .32962 Mdot
.54762 .30902 Mdot
.55238 .37082 Mdot
.55714 .22661 Mdot
.5619 .35022 Mdot
.56667 .26781 Mdot
.57143 .43262 Mdot
.57619 .22661 Mdot
.58095 .16481 Mdot
.58571 .32962 Mdot
.59048 .28842 Mdot
.59524 .30902 Mdot
.6 .30902 Mdot
.60476 .24721 Mdot
.60952 .37082 Mdot
.61429 .35022 Mdot
.61905 .39142 Mdot
.62381 .37082 Mdot
.62857 .43262 Mdot
.63333 .24721 Mdot
.6381 .28842 Mdot
.64286 .37082 Mdot
.64762 .47383 Mdot
.65238 .41202 Mdot
.65714 .26781 Mdot
.6619 .20601 Mdot
.66667 .24721 Mdot
.67143 .37082 Mdot
.67619 .24721 Mdot
.68095 .35022 Mdot
.68571 .26781 Mdot
.69048 .28842 Mdot
.69524 .30902 Mdot
.7 .20601 Mdot
.70476 .28842 Mdot
.70952 .20601 Mdot
.71429 .26781 Mdot
.71905 .26781 Mdot
.72381 .12361 Mdot
.72857 .47383 Mdot
.73333 .26781 Mdot
.7381 .28842 Mdot
.74286 .26781 Mdot
.74762 .30902 Mdot
.75238 .32962 Mdot
.75714 .30902 Mdot
.7619 .41202 Mdot
.76667 .32962 Mdot
.77143 .24721 Mdot
.77619 .20601 Mdot
.78095 .37082 Mdot
.78571 .30902 Mdot
.79048 .32962 Mdot
.79524 .26781 Mdot
.8 .30902 Mdot
.80476 .32962 Mdot
.80952 .16481 Mdot
.81429 .28842 Mdot
.81905 .22661 Mdot
.82381 .24721 Mdot
.82857 .41202 Mdot
.83333 .26781 Mdot
.8381 .32962 Mdot
.84286 .30902 Mdot
.84762 .24721 Mdot
.85238 .37082 Mdot
.85714 .22661 Mdot
.8619 .35022 Mdot
.86667 .22661 Mdot
.87143 .20601 Mdot
.87619 .32962 Mdot
.88095 .30902 Mdot
.88571 .47383 Mdot
.89048 .30902 Mdot
.89524 .28842 Mdot
.9 .24721 Mdot
.90476 .37082 Mdot
.90952 .37082 Mdot
.91429 .45322 Mdot
.91905 .37082 Mdot
.92381 .12361 Mdot
.92857 .35022 Mdot
.93333 .35022 Mdot
.9381 .30902 Mdot
.94286 .41202 Mdot
.94762 .32962 Mdot
.95238 .32962 Mdot
.95714 .26781 Mdot
.9619 .30902 Mdot
.96667 .26781 Mdot
.97143 .37082 Mdot
.97619 .24721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000dOooool2o`0003_ooooo0_l0000[ooooo`00:ooo
ool00ol0003oooooooooo`3@ooooo`;o0000>oooool2o`0002_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`1Booooo`;o00005oooool2o`0003Sooooo0_l00013ooooo`;o0000C_ooool0
02_ooooo0_l0001Cooooo`;o00005oooool2o`0003Sooooo0_l00013ooooo`;o0000C_ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000B_ooool2o`000>oo
oooo000[ooooo`03o`000?oooooooooo04Wooooo0_l0003_ooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool0013ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o0000B_ooool2o`0002cooooo0_l0000;ooooo`;o0000
=oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o00006oooool2o`0003_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo04[ooooo0_l0000/ooooo`;o00002oooool2o`0003Oooooo0_l00009ooooo`;o0000
00?oooooo`000?l000004_ooool2o`0001_ooooo0_l0000kooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o00008_ooool2o`0000Kooooo0_l0000?ooooo`;o00008Oooool2o`0000_ooooo0_l0
00000ooooooo0000o`000003o`0002cooooo0_l00004ooooo`;o0000Aoooool2o`0000[ooooo1?l0
000mooooo`00:oooool00ol0003oooooooooo`0Qooooo`;o00001_ooool2o`0000oooooo0_l0000Q
ooooo`;o00002oooool2o`000003ooooool0003o000000?o0000;?ooool2o`0000Cooooo0_l00017
ooooo`;o00002_ooool4o`0003gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool06?ooool2
o`0001Cooooo0_l0000?ooooo`;o00009Oooool2o`000003ooooool0003o000001;ooooo0_l0000B
ooooo`;o00001?ooool2o`0001?ooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o
000001_ooooo0_l0000=ooooo`;o00001_ooool2o`0000kooooo0_l0000Eooooo`;o00006oooool0
02_ooooo0_l0000Iooooo`;o00005?ooool2o`0000oooooo0_l0000Uooooo`;o000000?oooooo`00
0?l000004_ooool2o`0001;ooooo0_l00004ooooo`;o00004oooool2o`0000Oooooo0_l00008oooo
o`;o000000?oooooo`000?l000006oooool2o`0000gooooo0_l00006ooooo`;o00003_ooool2o`00
01Gooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0000;ooooo`;o00001_ooool2o`0000Gooooo1Ol00008ooooo`;o00005oooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00005_ooool2
o`0000kooooo0_l0000:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo0ol000000olb<S;ok^k^ooooo`02o`0000Oooooo0_l0000Iooooo`;o00001oooool2o`0000Co
oooo1_l00002ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00009oooo
o`;o00007oooool7o`000006ooooool0003o0000o`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Ooo
ool5o`0000Sooooo0_l0000Jooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00Cooooo0_l0000Fooooo`;o00003_ooool2o`0000cooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000001?ooooooV9RHogMgMoooool2o`0000Oooooo0_l0
000Iooooo`;o00001oooool2o`0000Kooooo1?l00002ooooo`;o000000?oooooo`000?l000000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00009ooooo`;o00007oooool01OnHV9So8B4Q
onk^k_ooooooA4A400;o000000Koooooo`000?l0003ooooooiRHV?mgMgL3ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool002_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004ooo
ool002_ooooo00?o0000ooooooooool0@_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool0<oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000[
ooooo`03o`000?oooooooooo03oooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool00000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00004oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017o
oooo000[ooooo`Co000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00009?ooool2o`0000So
oooo1_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0000_ooooo0_l0000Hoooo
o`;o00001?ooool2o`0000;ooooo0_l000001_oooooo0000o`000?l0003oooooo`0000;ooooo1?l0
00000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000o`000?mgMgL04Oooool2o`0000cooooo
0_l0000>ooooo`;o00000_ooool2o`000003ooooool0003ooooo00Cooooo00Co0000ooooool0003o
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo0_l0000Fooooo`;o00003?ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04oooool002_ooooo00Go0000ooooool0003o0000ooooo`02o`000003oooo
ool0003o000000Gooooo0_l0000Tooooo`;o00002?ooool7o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`;o00002oooool2o`0001Sooooo0_l00004ooooo`;o00000_ooool2o`000006
ooooool0003o0000o`000?mVIVKo00000_ooool5o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^
oc8b<_l0003o0000onk^kP0Aooooo`;o00003?ooool2o`0000kooooo0_l00002ooooo`;o000000?o
IVIVo`000?ooool01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`;o0000
5_ooool2o`0000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@4?l0003o000000?ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Cooooo000Toooooooo0000<?l0
000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`03o`000?oooooooooo00Cooooo0_l0
00000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`000?oo
oooooooo00Sooooo0_l000000ooooooo0000ooooo`02ooooo`;o00002Oooool00ol0003ooooooooo
o`09ooooo`Co00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0ol0
0003ooooo`;o00001oooool3o`0000_ooooo00?o0000ooooooooool02oooool2o`0000cooooo1?l0
000;ooooo`03o`000?oooooooooo00cooooo0ol0000;ooooo`05o`000?oooooo0000o`000?ooool0
0_l00007ooooo`;o00000_ooool2o`0000Wooooo00Co0000ooooool0003o00002_ooool2o`000003
ooooool0003o000000[ooooo00Co0000ooooool0003o00001Oooool2o`0000?ooooo00?o0000oooo
ooooool04Oooool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000oooooooo
ool0oooooolbooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo00?o0000oooooooo
ool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo
<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`08ooooo`;o00006?oo
ool2o`00017ooooo0_l00002ooooo`;o00003?ooool2o`0000[ooooo0_l00007ooooo`Ko0000:Ooo
ool4o`0000_ooooo0_l0000:ooooo`;o0000<Oooool2o`0000;ooooo0_l00005ooooo`;o00000ooo
ool2o`0000Sooooo0_l00009ooooo`;o00005?ooool3o`0001Wooooo0_l00008ooooo`00:oooool2
o`0000Wooooo0_l0000Hooooo`;o00004Oooool2o`0000;ooooo0_l0000<ooooo`;o00002_ooool2
o`0000Oooooo1_l0000Yooooo`Co00002oooool2o`0000[ooooo0_l0000aooooo`;o00000_ooool2
o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo0_l0000Dooooo`?o00008oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00008ooooo`;o00003?oo
ool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0001_ooooo0_l0
000>ooooo`;o00003oooool2o`0000Sooooo0_l0000?ooooo`;o00003_ooool2o`0001;ooooo0_l0
000eooooo`;o00004_ooool4o`0002Sooooo000[ooooo`;o00000_ooool2o`0000Sooooo0_l00008
ooooo`;o00003?ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2
o`0001_ooooo0_l0000>ooooo`;o00003oooool2o`0000Sooooo0_l0000?ooooo`;o00003_ooool2
o`0001;ooooo0_l0000eooooo`;o00004_ooool4o`0002Sooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`0000oooooo0_l00004ooooo`Co00001_ooool3o`00
00Oooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo0_l0000Cooooo`;o00008_ooool2o`00
00[ooooo0_l0000<ooooo`;o00001Oooool2o`00013ooooo0_l00002ooooo`;o00001?ooool2o`00
00Kooooo0_l0000Pooooo`;o00004oooool2o`0000kooooo0ol000000ooooooo0000o`00000>oooo
o`;o00007Oooool002_ooooo00?o0000ooooooooool03_ooool2o`0000Cooooo1?l00006ooooo`?o
00001oooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`0001?ooooo0_l0000Rooooo`;o
00002_ooool2o`0000cooooo0_l00005ooooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o
00001_ooool2o`00023ooooo0_l0000Cooooo`;o00003_ooool3o`000003ooooool0003o000000ko
oooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o00004?ooool2o`0003_ooooo0_l00008ooooo`;o
000000?oooooo`000?l00000=?ooool2o`00023ooooo0_l00027ooooo`00:oooool00ol0003ooooo
ooooo`0?ooooo`;o0000>oooool2o`0000Sooooo0_l000000ooooooo0000o`00000dooooo`;o0000
8?ooool2o`0008Oooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0003Kooooo
0_l0000Looooo`;o0000IOooool2o`0001oooooo0_l0000Booooo`;o00008?ooool2o`0002Kooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo03Kooooo0_l0000Looooo`;o0000IOooool2o`0001oooooo0_l0000Booooo`;o0000
8?ooool2o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0I?oo
ool2o`0003cooooo0_l0000?ooooo`;o0000QOooool002_ooooo0_l0001Uooooo`;o0000??ooool2
o`0000oooooo0_l00025ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0ol0001@ooooo`;o0000^?ooool2o`0002kooooo000[ooooo`?o0000D?ooool2o`000;So
oooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000H_ooool2o`0005Kooooo0_l0000Gooooo`;o
0000;Oooool2o`0003Oooooo000[ooooo`03o`000?oooooooooo067ooooo0_l0001Fooooo`;o0000
5oooool2o`0002gooooo0_l0000gooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc_ooooo000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Kooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool0
01cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00
0?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool0oooooolkooooo`006?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolkooooo`006oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000?oooooo>oooool001[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo00000?ooooooA?ooool001_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@0?ooooooA?ooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0oooooom4ooooo`006?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?oooooo
A?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l00002
ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o<S8b
ooooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool03_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c03ooooooaGooooo0003ooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4A0?ooooo00[oA4A4oiRHV?oooooooooo
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@400<ooooo`05o`000?oooooo
ooooooooool000000_ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B40oooooolEooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;o
MgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool0
1Ol0003ooooooooooooooooo000001Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo0?oooooo4oooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@
onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBoooo
o`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool0
1Olb<S;oV9RHoooooonHV9So<S8b0?oooooo5Oooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_oo
ool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMg
oc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
c<c<o`000?l0003o0000olc<c03ooooooaGooooo0003ooooo`;o00000_ooool2o`0000Gooooo00?o
gMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013ooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@okZj^_oooooo^[Zjoa0@403ooooooaGooooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo
0000omgMg@0aooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o
00000?oooooo5Oooool000oooooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0`oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo5Ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .46353 Mdot
.03333 .29872 Mdot
.0381 .33992 Mdot
.04286 .29872 Mdot
.04762 .31932 Mdot
.05238 .27812 Mdot
.05714 .31932 Mdot
.0619 .31932 Mdot
.06667 .27812 Mdot
.07143 .33992 Mdot
.07619 .27812 Mdot
.08095 .36052 Mdot
.08571 .40172 Mdot
.09048 .29872 Mdot
.09524 .25751 Mdot
.1 .36052 Mdot
.10476 .36052 Mdot
.10952 .36052 Mdot
.11429 .23691 Mdot
.11905 .25751 Mdot
.12381 .25751 Mdot
.12857 .27812 Mdot
.13333 .36052 Mdot
.1381 .38112 Mdot
.14286 .23691 Mdot
.14762 .31932 Mdot
.15238 .33992 Mdot
.15714 .31932 Mdot
.1619 .27812 Mdot
.16667 .36052 Mdot
.17143 .23691 Mdot
.17619 .36052 Mdot
.18095 .31932 Mdot
.18571 .25751 Mdot
.19048 .36052 Mdot
.19524 .36052 Mdot
.2 .27812 Mdot
.20476 .36052 Mdot
.20952 .33992 Mdot
.21429 .42232 Mdot
.21905 .38112 Mdot
.22381 .31932 Mdot
.22857 .23691 Mdot
.23333 .27812 Mdot
.2381 .27812 Mdot
.24286 .25751 Mdot
.24762 .27812 Mdot
.25238 .36052 Mdot
.25714 .31932 Mdot
.2619 .29872 Mdot
.26667 .36052 Mdot
.27143 .31932 Mdot
.27619 .19571 Mdot
.28095 .19571 Mdot
.28571 .40172 Mdot
.29048 .27812 Mdot
.29524 .25751 Mdot
.3 .46353 Mdot
.30476 .17511 Mdot
.30952 .33992 Mdot
.31429 .42232 Mdot
.31905 .40172 Mdot
.32381 .36052 Mdot
.32857 .38112 Mdot
.33333 .27812 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .31932 Mdot
.35238 .33992 Mdot
.35714 .46353 Mdot
.3619 .36052 Mdot
.36667 .44292 Mdot
.37143 .25751 Mdot
.37619 .25751 Mdot
.38095 .25751 Mdot
.38571 .21631 Mdot
.39048 .17511 Mdot
.39524 .21631 Mdot
.4 .23691 Mdot
.40476 .21631 Mdot
.40952 .29872 Mdot
.41429 .33992 Mdot
.41905 .27812 Mdot
.42381 .31932 Mdot
.42857 .27812 Mdot
.43333 .21631 Mdot
.4381 .29872 Mdot
.44286 .36052 Mdot
.44762 .25751 Mdot
.45238 .29872 Mdot
.45714 .29872 Mdot
.4619 .29872 Mdot
.46667 .27812 Mdot
.47143 .36052 Mdot
.47619 .21631 Mdot
.48095 .36052 Mdot
.48571 .29872 Mdot
.49048 .27812 Mdot
.49524 .33992 Mdot
.5 .33992 Mdot
.50476 .33992 Mdot
.50952 .38112 Mdot
.51429 .25751 Mdot
.51905 .25751 Mdot
.52381 .29872 Mdot
.52857 .36052 Mdot
.53333 .25751 Mdot
.5381 .27812 Mdot
.54286 .33992 Mdot
.54762 .29872 Mdot
.55238 .36052 Mdot
.55714 .23691 Mdot
.5619 .33992 Mdot
.56667 .25751 Mdot
.57143 .44292 Mdot
.57619 .21631 Mdot
.58095 .17511 Mdot
.58571 .31932 Mdot
.59048 .27812 Mdot
.59524 .29872 Mdot
.6 .31932 Mdot
.60476 .23691 Mdot
.60952 .36052 Mdot
.61429 .33992 Mdot
.61905 .38112 Mdot
.62381 .38112 Mdot
.62857 .44292 Mdot
.63333 .23691 Mdot
.6381 .29872 Mdot
.64286 .36052 Mdot
.64762 .48413 Mdot
.65238 .40172 Mdot
.65714 .27812 Mdot
.6619 .19571 Mdot
.66667 .25751 Mdot
.67143 .38112 Mdot
.67619 .23691 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .31932 Mdot
.7 .19571 Mdot
.70476 .27812 Mdot
.70952 .19571 Mdot
.71429 .27812 Mdot
.71905 .25751 Mdot
.72381 .11331 Mdot
.72857 .46353 Mdot
.73333 .25751 Mdot
.7381 .27812 Mdot
.74286 .25751 Mdot
.74762 .29872 Mdot
.75238 .31932 Mdot
.75714 .31932 Mdot
.7619 .42232 Mdot
.76667 .33992 Mdot
.77143 .23691 Mdot
.77619 .19571 Mdot
.78095 .38112 Mdot
.78571 .29872 Mdot
.79048 .33992 Mdot
.79524 .25751 Mdot
.8 .31932 Mdot
.80476 .33992 Mdot
.80952 .15451 Mdot
.81429 .29872 Mdot
.81905 .23691 Mdot
.82381 .25751 Mdot
.82857 .42232 Mdot
.83333 .25751 Mdot
.8381 .33992 Mdot
.84286 .31932 Mdot
.84762 .25751 Mdot
.85238 .36052 Mdot
.85714 .21631 Mdot
.8619 .33992 Mdot
.86667 .21631 Mdot
.87143 .19571 Mdot
.87619 .31932 Mdot
.88095 .29872 Mdot
.88571 .48413 Mdot
.89048 .31932 Mdot
.89524 .29872 Mdot
.9 .23691 Mdot
.90476 .36052 Mdot
.90952 .36052 Mdot
.91429 .46353 Mdot
.91905 .36052 Mdot
.92381 .13391 Mdot
.92857 .36052 Mdot
.93333 .36052 Mdot
.9381 .29872 Mdot
.94286 .42232 Mdot
.94762 .31932 Mdot
.95238 .33992 Mdot
.95714 .27812 Mdot
.9619 .29872 Mdot
.96667 .27812 Mdot
.97143 .38112 Mdot
.97619 .25751 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0d?ooool2o`0006Sooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0d?ooool2o`0006Sooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo3_ooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo3_ooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3Zooooo`;o0000C_ooool002_ooooo
00?o0000ooooooooool0j_ooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo05;ooooo0_l0000Gooooo`;o0000>?ooool2o`0009?ooooo000[
ooooo`03o`000?oooooooooo05;ooooo0_l0000Gooooo`;o0000>?ooool2o`0009?ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`19ooooo`?o0000L_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000B
ooooo`;o00006oooool2o`0003_ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool0BOooool3o`0007;ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000004_ooool2o`0001_ooooo0_l0000kooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo06[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000;ooooo`;o
00007Oooool2o`0005?ooooo1?l0000mooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`1Zooooo`;o000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00002oooool2o`0001gooooo0_l0001Cooooo`Co0000?Oooool001Wo
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo01Sooooo0_l00007ooooo`;o00001_ooool2o`0000oooooo0_l0000Qooooo`;o00003oooool2
o`0002kooooo0_l0000<ooooo`;o00001oooool2o`0000_ooooo0_l0000Kooooo`;o00003?ooool2
o`0001Oooooo0_l0000booooo`00:oooool00ol0003oooooooooo`0Hooooo`;o00001oooool2o`00
00Kooooo0_l0000?ooooo`;o00008Oooool2o`0000oooooo0_l0000^ooooo`;o00003?ooool2o`00
00Oooooo0_l0000;ooooo`;o00006oooool2o`0000cooooo0_l0000Gooooo`;o0000<_ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo01;ooooo0_l00005ooooo`Co00004Oooool2o`0000oooooo0_l0000>oooo
o`;o00005Oooool5o`0001;ooooo0_l0000Booooo`?o00000oooool2o`0000Sooooo0_l0000Loooo
o`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?ooooo0_l0000Uooooo`;o00006oooool002_ooooo00?o0000oooooooo
ool04_ooool2o`0000Gooooo1?l0000Aooooo`;o00003oooool2o`0000kooooo0_l0000Eooooo`Go
00004_ooool2o`0001;ooooo0ol00003ooooo`;o00002?ooool2o`0001cooooo0_l0000>ooooo`;o
00000_ooool2o`000003ooooool0003o000000kooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000oooool2o`0002Gooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l00010ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h0<oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0@_ooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo04?ooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`07oooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0<_ooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01?ooooo
000[ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`Co00003_ooool2o`0000Sooooo0_l0
000:ooooo`;o00002?ooool3o`000005ooooool0003o0000ogMgMolb<S800_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l0000;ooooo`;o00006?ooool2o`000003ooooool0003o000000Wo
oooo0_l000000ooooooo0000ooooo`03ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000ooooool0003o00003_ooool2o`0001;ooooo0_l00007ooooo`;o00000oooool2
o`000003ooooool0003o000000Kooooo0_l000001?lb<S;oooooooooool00003ooooo`03o`000?oo
oooooooo03?ooooo00?oV9RHob4Q8Oo^k^h00_l000000ooooooo0000o`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003ooooooooo
o`05ooooo`;o00000oooool4o`0000kooooo0_l00008ooooo`;o00002_ooool2o`0000Sooooo1_l0
00001Olb<S;oc<c<oooooooooooo000000?ooooo00?o0000ooooooooool00_l0000;ooooo`;o0000
6?ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000ooooo`03ooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o00003_ooool2o`00
01;ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo00Go0000ob4Q
8Ol0003o0000olc<c002ooooo`05o`000?ooooooooooooooool00000=_ooool01OmgMgOoIVIVo`00
0?l0003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool04Oooool002_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017o
oooo000[ooooo`;o0000@?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_o
oooo00?o0000ooooooooool0?oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hoooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0=?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^03?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00Go0000ooooool0003o0000ooooo`02o`0000gooooo0_l0000boooo
o`;o0000:_ooool2o`0000Oooooo0_l00002ooooo`Go00001Oooool2o`0000[ooooo0_l00005oooo
o`;o00003?ooool2o`0000_ooooo0_l0000>ooooo`;o00003oooool2o`0000[ooooo0_l00007oooo
o`;o00004_ooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`00023ooooo000[ooooo`05
o`000?oooooo0000o`000?ooool00_l0000=ooooo`;o0000<_ooool2o`0002[ooooo0_l00007oooo
o`;o00000_ooool5o`0000Gooooo0_l0000:ooooo`;o00001Oooool2o`0000cooooo0_l0000;oooo
o`;o00003_ooool2o`0000oooooo0_l0000:ooooo`;o00001oooool2o`0001;ooooo0_l00002oooo
o`;o00002oooool2o`0000Gooooo0_l0000Fooooo`;o00000_ooool00ol@413o0000o`000003oooo
o`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004oooo
o`009?ooooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003o
410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo
00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000ooooooooool01?ooool2o`000004oooo
ool0003o0000o`0001Sooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`0000So
oooo0_l00002ooooo`;o00004oooool4o`0001Kooooo0_l0000^ooooo`;o00000oooool2o`0001_o
oooo0_l0000?ooooo`?o00002oooool2o`0000_ooooo0_l00008ooooo`;o00000oooool2o`0000oo
oooo0_l0000Kooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo00?o0000oooooooo
ool01?ooool2o`000004ooooool0003o0000o`0001Sooooo0_l000000ooooooo0000o`000005oooo
o`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o00004oooool4o`0001Kooooo0_l0000^oooo
o`;o00000oooool2o`0001_ooooo0_l0000?ooooo`?o00002oooool2o`0000_ooooo0_l00008oooo
o`;o00000oooool2o`0000oooooo0_l0000Kooooo`03o`000?oooooooooo00Kooooo000[ooooo`03
o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc7ooooo0_l00008ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool01?l0003oooooooooooooool2o`0000Sooooo0_l0000F
ooooo`;o00004?ooool2o`0001cooooo0_l0000;ooooo`;o00004Oooool2o`0001Kooooo1Ol0000:
ooooo`;o00000oooool2o`0000kooooo0_l0000Booooo`;o00006?ooool2o`0000Gooooo0_l00003
ooooo`;o00002?ooool2o`0000Gooooo0_l0000Iooooo`;o00008oooool002_ooooo00Co0000oooo
oooooooooooo0_l00008ooooo`;o00005_ooool2o`00013ooooo0_l0000Looooo`;o00002oooool2
o`00017ooooo0_l0000Fooooo`Go00002_ooool2o`0000?ooooo0_l0000>ooooo`;o00004_ooool2
o`0001Sooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o00006Oooool2
o`0002?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
00kooooo0_l00004ooooo`Co00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`?o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l0000?ooooo`;o00002_ooool2o`00
01Kooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Gooooo0_l0000@oooo
o`;o00002?ooool2o`0003gooooo0_l0000>ooooo`?o000000Coooooo`000?l0003ooooo1?l0000X
ooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00001?ooool4o`0000Kooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000gooooo0_l00002oooo
o`;o00003oooool2o`0000[ooooo0_l0000Fooooo`;o00001oooool2o`000003ooooool0003o0000
00cooooo0_l00005ooooo`;o00004?ooool2o`0000Sooooo0_l0000mooooo`;o00003_ooool3o`00
0004ooooool0003o0000ooooo`Co0000:?ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01oooooo0_l0000G
ooooo`;o00007oooool2o`0003Cooooo0_l0000Pooooo`?o00003?ooool2o`00023ooooo0_l0000g
ooooo`;o00007Oooool002_ooooo00?o0000ooooooooool07oooool2o`0001Oooooo0_l0000Ooooo
o`;o0000=?ooool2o`00023ooooo0ol0000<ooooo`;o00008?ooool2o`0003Oooooo0_l0000Moooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool03oooool2o`0003_ooooo0_l00008ooooo`;o0000Hoooool2o`00
07gooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o
0000ooooooooool03oooool2o`0003_ooooo0_l00008ooooo`;o0000Hoooool2o`0007gooooo000K
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooo
oolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`0fooooo`;o00007?ooool2o`0008Kooooo0_l0000Booooo`;o00008?oo
ool2o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo03Kooooo0_l0000Looooo`;o0000Q_ooool2o`0001;ooooo0_l0
000Pooooo`;o00009_ooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0I?oo
ool2o`0003cooooo0_l0000?ooooo`;o0000QOooool002_ooooo00?o0000ooooooooool0I?ooool2
o`0003cooooo0_l0000?ooooo`;o0000QOooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000D?ooool2o`0000oooooo0_l0001_
ooooo`;o0000=_ooool2o`0002kooooo000[ooooo`?o0000D?ooool2o`0000oooooo0_l0001_oooo
o`;o0000=_ooool2o`0002kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`2iooooo`;o0000A_ooool2o`00
03Oooooo000[ooooo`03o`000?oooooooooo0;Wooooo0_l00016ooooo`;o0000=oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`3ooooooc_ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000oooooolkooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003oooooocco
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo
??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool0
01_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003o
oooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003o
ooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403o
ooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<
ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`00
00?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo
00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00kooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`04oa0@4?l0
003oA4A4olc<c?oooooo5_ooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06
o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002
ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?oV9RHoa0@4?oMgMd0oooo
oolEooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooo
oooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool01?ooool00on7QhOoEEEEooooo`3ooooooaCooooo0004ooooo`04
onk^k_lQ8B7o410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKo
QhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo
1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00003ooooooaGo
oooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@413o
k^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVYZOl0
00004oooool00ol@413o0000okZj^P03ooooo`05ob4Q8On7QhOooooooiRHV?l00000oooooolEoooo
o`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmE
EED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool04_ooool00onj^[[o8B4Qooooo`02ooooo`05o`000?ooooooooooooooool00000oooooolEoooo
o`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<Oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@3ooooooaGooooo000?ooooo`03okZj^_m4
A4Cooooo00;ooooo00?oZJVYooooooooool0<?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Goc<c<oa0@4?l0003o<S8bonk^kP3ooooooaGooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45322 Mdot
.03333 .28842 Mdot
.0381 .35022 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .28842 Mdot
.05714 .30902 Mdot
.0619 .32962 Mdot
.06667 .28842 Mdot
.07143 .32962 Mdot
.07619 .28842 Mdot
.08095 .35022 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .24721 Mdot
.1 .37082 Mdot
.10476 .37082 Mdot
.10952 .35022 Mdot
.11429 .24721 Mdot
.11905 .24721 Mdot
.12381 .24721 Mdot
.12857 .28842 Mdot
.13333 .35022 Mdot
.1381 .39142 Mdot
.14286 .24721 Mdot
.14762 .30902 Mdot
.15238 .35022 Mdot
.15714 .30902 Mdot
.1619 .26781 Mdot
.16667 .35022 Mdot
.17143 .22661 Mdot
.17619 .37082 Mdot
.18095 .30902 Mdot
.18571 .26781 Mdot
.19048 .37082 Mdot
.19524 .37082 Mdot
.2 .26781 Mdot
.20476 .37082 Mdot
.20952 .32962 Mdot
.21429 .41202 Mdot
.21905 .39142 Mdot
.22381 .30902 Mdot
.22857 .24721 Mdot
.23333 .28842 Mdot
.2381 .28842 Mdot
.24286 .26781 Mdot
.24762 .28842 Mdot
.25238 .37082 Mdot
.25714 .30902 Mdot
.2619 .30902 Mdot
.26667 .37082 Mdot
.27143 .32962 Mdot
.27619 .18541 Mdot
.28095 .20601 Mdot
.28571 .39142 Mdot
.29048 .28842 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .18541 Mdot
.30952 .32962 Mdot
.31429 .41202 Mdot
.31905 .41202 Mdot
.32381 .35022 Mdot
.32857 .39142 Mdot
.33333 .26781 Mdot
.3381 .30902 Mdot
.34286 .22661 Mdot
.34762 .30902 Mdot
.35238 .35022 Mdot
.35714 .45322 Mdot
.3619 .37082 Mdot
.36667 .43262 Mdot
.37143 .24721 Mdot
.37619 .24721 Mdot
.38095 .26781 Mdot
.38571 .20601 Mdot
.39048 .16481 Mdot
.39524 .20601 Mdot
.4 .22661 Mdot
.40476 .20601 Mdot
.40952 .28842 Mdot
.41429 .32962 Mdot
.41905 .26781 Mdot
.42381 .30902 Mdot
.42857 .26781 Mdot
.43333 .22661 Mdot
.4381 .28842 Mdot
.44286 .35022 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .30902 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .37082 Mdot
.47619 .22661 Mdot
.48095 .35022 Mdot
.48571 .28842 Mdot
.49048 .28842 Mdot
.49524 .35022 Mdot
.5 .32962 Mdot
.50476 .32962 Mdot
.50952 .39142 Mdot
.51429 .24721 Mdot
.51905 .26781 Mdot
.52381 .28842 Mdot
.52857 .35022 Mdot
.53333 .26781 Mdot
.5381 .28842 Mdot
.54286 .35022 Mdot
.54762 .28842 Mdot
.55238 .37082 Mdot
.55714 .24721 Mdot
.5619 .32962 Mdot
.56667 .24721 Mdot
.57143 .43262 Mdot
.57619 .22661 Mdot
.58095 .16481 Mdot
.58571 .30902 Mdot
.59048 .26781 Mdot
.59524 .30902 Mdot
.6 .30902 Mdot
.60476 .24721 Mdot
.60952 .35022 Mdot
.61429 .35022 Mdot
.61905 .39142 Mdot
.62381 .37082 Mdot
.62857 .43262 Mdot
.63333 .22661 Mdot
.6381 .28842 Mdot
.64286 .37082 Mdot
.64762 .49443 Mdot
.65238 .39142 Mdot
.65714 .28842 Mdot
.6619 .18541 Mdot
.66667 .26781 Mdot
.67143 .39142 Mdot
.67619 .22661 Mdot
.68095 .35022 Mdot
.68571 .26781 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .18541 Mdot
.70476 .26781 Mdot
.70952 .18541 Mdot
.71429 .26781 Mdot
.71905 .24721 Mdot
.72381 .10301 Mdot
.72857 .47383 Mdot
.73333 .24721 Mdot
.7381 .26781 Mdot
.74286 .26781 Mdot
.74762 .28842 Mdot
.75238 .32962 Mdot
.75714 .30902 Mdot
.7619 .43262 Mdot
.76667 .32962 Mdot
.77143 .22661 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .35022 Mdot
.79524 .26781 Mdot
.8 .32962 Mdot
.80476 .32962 Mdot
.80952 .16481 Mdot
.81429 .28842 Mdot
.81905 .22661 Mdot
.82381 .24721 Mdot
.82857 .41202 Mdot
.83333 .24721 Mdot
.8381 .32962 Mdot
.84286 .32962 Mdot
.84762 .26781 Mdot
.85238 .35022 Mdot
.85714 .22661 Mdot
.8619 .35022 Mdot
.86667 .22661 Mdot
.87143 .20601 Mdot
.87619 .32962 Mdot
.88095 .28842 Mdot
.88571 .49443 Mdot
.89048 .30902 Mdot
.89524 .30902 Mdot
.9 .22661 Mdot
.90476 .37082 Mdot
.90952 .37082 Mdot
.91429 .45322 Mdot
.91905 .37082 Mdot
.92381 .14421 Mdot
.92857 .37082 Mdot
.93333 .37082 Mdot
.9381 .30902 Mdot
.94286 .41202 Mdot
.94762 .32962 Mdot
.95238 .35022 Mdot
.95714 .28842 Mdot
.9619 .30902 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .24721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000d?ooool2o`0006Sooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0=3ooooo0_l0001Xooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo3_oo
ool2o`0002_ooooo000[ooooo`;o0000ooooool?ooooo`;o0000:oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`1[ooooo`;o0000>?ooool2o`0004?ooooo0_l0001>ooooo`00:oooool2o`00
06cooooo0_l0000hooooo`;o0000@oooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`0004[ooooo0_l00007ooooo`;o0000J_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Booooo`;o0000F?ooool002_ooooo00?o0000ooooooooool0
BOooool2o`0000Oooooo0_l0001Zooooo`;o00002Oooool2o`000003ooooool0003o000001;ooooo
0_l0001Hooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
B_ooool2o`0001kooooo0_l000001?oooooo0000o`000?ooool2o`0008_ooooo0_l0000kooooo`00
6oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`1:ooooo`;o00007_ooool2o`000004ooooool0003o0000ooooo`;o0000Roooool2o`00
03_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000Zooooo`;o0000<_ooool2o`0000oo
oooo0_l00008ooooo`;o00002oooool2o`0001gooooo0_l0000?ooooo`;o00002oooool2o`0001_o
oooo0_l0000<ooooo`;o00002_ooool4o`0000Wooooo0_l0000booooo`00:oooool00ol0003ooooo
ooooo`0Yooooo`;o0000<_ooool2o`0000oooooo0_l00008ooooo`;o00002oooool2o`0001gooooo
0_l0000?ooooo`;o00002oooool2o`0001_ooooo0_l0000<ooooo`;o00002_ooool4o`0000Wooooo
0_l0000booooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`Go0000
1?ooool2o`0001Oooooo0_l0000Zooooo`?o0000:?ooool2o`0000_ooooo0_l000000ooooooo0000
o`000009ooooo`;o00008Oooool2o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
:_ooool2o`0001_ooooo000[ooooo`;o00004oooool2o`0000Cooooo1Ol00004ooooo`;o00005ooo
ool2o`0002[ooooo0ol0000Xooooo`;o00002oooool2o`000003ooooool0003o000000Wooooo0_l0
000Qooooo`;o00000_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Zooooo`;o00006ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o00009oooool2
o`0000Kooooo0_l00002ooooo`;o00002oooool3o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo0_l00009ooooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo
0000o`000004ooooo`;o00001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`?o000000Co<S8bonk^k_l0003o00003oooool2o`0001Gooooo0_l00004ooooo`;o0000
0oooool5o`000005oa0@4?oooooooooooooooom4A4@01?l00002ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool2o`0000kooooo0_l0000Jooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`0V
ooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooogMgMolb<S800_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00009ooooo`;o00003Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg00;o00003oooool2o`0001Gooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0ol00002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01oooool2o`0000kooooo0_l0000Jooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool0
0ol0003oooooooooo`12ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000=_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000
ooooooooool0?oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00000jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00
:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo
1?l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l0000>ooooo`;o00007_ooool6o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00008_ooool2o`0000Oooooo0_l00005oooo
o`?o000000Coooooo`000?oooooooooo1?l000000oooooooV9RHogMgM`03ooooo`06ogMgMonHV9So
0000o`000?mgMgOooooo0_l000000ooooooo0000o`00000Iooooo`;o00001?ooool2o`0000oooooo
00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`000006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3Oooool2o`0001;ooooo0_l0000@ooooo`05o`000?nj^[[ooooooiRHV?l@41000_l0
00001_oooooo0000o`000?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`00:oooool01Ol0003oooooo`000?l0003ooooo00;o000000?oooooo`000?l000000oooool4o`00
00kooooo0_l0000Nooooo`Oo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000R
ooooo`;o00001oooool2o`0000Gooooo0ol000001?mVIVKo0000ooooooooool5o`000003oc8b<_o^
k^kooooo00;ooooo00Kok^k^oc8b<_l0003o0000onk^k_ooool2o`000003ooooool0003o000001Wo
oooo0_l00004ooooo`;o00003Oooool00omEEEGoIVIVo`000005ooooo`Ko000000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h=ooooo`;o00004_ooool2o`00013ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c002o`000006ooooool0003o0000o`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@4?l0
003o000000?ooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb
<S;oc<c<00Cooooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[
ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00;ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l000001Ooooooo0000o`000?oo
oooo000000?ooooo0_l00009ooooo`04o`000?oooooo0000o`0000Sooooo1?l0000=ooooo`03o`00
0?oooooooooo00Gooooo1?l00002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool2o`0000Kooooo1?l0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1oooool2o`000003ooooool0003o000000;o00002oooool00ol0003oooooooooo`0;ooooo`Co0000
2oooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`0000gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03o`0000Wooooo00Co0000ooooool0003o00001Oooool2o`0000?o
oooo00?o0000ooooooooool04Oooool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo
00?o0000ooooooooool0oooooolbooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo
00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oo
oooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`08
ooooo`;o000000?oooooo`000?l00000:?ooool2o`00013ooooo0_l0000:ooooo`;o00007_ooool2
o`0001Sooooo0ol0000?ooooo`;o0000>?ooool2o`0000;ooooo0_l00008ooooo`Co00002?ooool3
o`0000Sooooo0_l0000Dooooo`;o00006_ooool2o`0000Sooooo000[ooooo`;o00002Oooool2o`00
0003ooooool0003o000002Sooooo0_l0000@ooooo`;o00002_ooool2o`0001kooooo0_l0000Hoooo
o`?o00003oooool2o`0003Sooooo0_l00002ooooo`;o00002?ooool4o`0000Sooooo0ol00008oooo
o`;o00005?ooool2o`0002Cooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00Co0000oooooooooooooooo0_l0000;
ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0002gooooo0_l00007
ooooo`;o00006Oooool2o`0000[ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l0000B
ooooo`?o00004_ooool2o`0001oooooo0_l0000Aooooo`;o000000?oooooo`000?l000006Oooool2
o`0002?ooooo000[ooooo`;o00000_ooool2o`0000_ooooo0_l00006ooooo`;o00001_ooool2o`00
00?ooooo0_l00003ooooo`;o0000;Oooool2o`0000Oooooo0_l0000Iooooo`;o00002_ooool2o`00
00;ooooo0_l00008ooooo`;o00000oooool2o`0001;ooooo0ol0000Booooo`;o00007oooool2o`00
017ooooo0_l000000ooooooo0000o`00000Iooooo`;o00008oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o00005Oooool3o`0001Cooooo0_l00002ooooo`?o
000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l0000Kooooo`;o00007oooool2o`0001Ko
oooo0_l0000Dooooo`;o00001?ooool2o`0004gooooo0ol000001?oooooo0000o`000?ooool4o`00
00Wooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`0Dooooo`?o00005?ooool2o`0000;o
oooo0ol000000ooooooo0000o`00000=ooooo`;o00000_ooool2o`0001_ooooo0_l0000Oooooo`;o
00005_ooool2o`0001Cooooo0_l00004ooooo`;o0000COooool3o`000004ooooool0003o0000oooo
o`Co00002Oooool2o`0001gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000@ooooo`;o00003_ooool2o`00
01Oooooo0_l0000Booooo`;o00002oooool2o`0003Cooooo0_l0000Pooooo`;o00002?ooool2o`00
00?ooooo0_l0000Pooooo`;o0000E_ooool002_ooooo00?o0000ooooooooool03oooool2o`0000ko
oooo0_l0000Gooooo`;o00004_ooool2o`0000_ooooo0_l0000dooooo`;o00008?ooool2o`0000So
oooo0_l00003ooooo`;o00008?ooool2o`0005Kooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool3o`0003Kooooo0_l0000Looooo`Co0000V?ooool2o`00023ooooo0_l0000Vooooo`00
6oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0fooooo`;o00007?ooool4o`0009Sooooo0_l0000Pooooo`;o00009_ooool001_ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`1Tooooo`;o0000??ooool2o`0000oooooo
0_l0000Wooooo`;o0000G?ooool002_ooooo0_l0001Uooooo`;o0000??ooool2o`0000oooooo0_l0
000Wooooo`;o0000G?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`?o0000D?ooool2o`0000oooooo0_l0002Wooooo`;o0000;_ooool002_ooooo0ol0001@oooo
o`;o00003oooool2o`000:Oooooo0_l0000^ooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000doooool2o`00
06Kooooo000[ooooo`03o`000?oooooooooo0=;ooooo0_l0001Vooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000^_ooool2o`0004Kooooo0_l0000gooooo`00:oooool00ol0003oooooooooo`2iooooo`;o0000
A_ooool2o`0003Oooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`006?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000I
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0003ooooooc_ooooo000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooo
oolkooooo`006?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolkooooo`006ooo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo
>oooool001[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo00000?oooooo
A?ooool001_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@0?oooooo
A?ooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0oooooom4ooooo`006?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP3oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?ooooooA?ooool000cooooo
00?o8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l00002ooooo`;o00000ooo
ool00onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o<S8booooooooool00_l0
0002ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool04?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0?oooooo5Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oM
gMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko
00003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolEoooo
o`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo
410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo0000017ooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100oooooolEooooo`001?ooool01?o^k^ko8B4Q
oa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04oooo
o`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002Ooo
ool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000oooooolEooooo`00
1?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@
413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo0000017o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo00000?oooooo5Oooool0
00?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE
00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
013ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@0?oooooo5Oooool0
00oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03;ooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo5Oooool000oooooo00?o^[ZjodA4A?ooool00_oo
ool00onYZJWoooooooooo`0booooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP3ooooooaGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .46353 Mdot
.03333 .29872 Mdot
.0381 .36052 Mdot
.04286 .27812 Mdot
.04762 .29872 Mdot
.05238 .27812 Mdot
.05714 .29872 Mdot
.0619 .31932 Mdot
.06667 .29872 Mdot
.07143 .31932 Mdot
.07619 .27812 Mdot
.08095 .33992 Mdot
.08571 .40172 Mdot
.09048 .29872 Mdot
.09524 .25751 Mdot
.1 .38112 Mdot
.10476 .38112 Mdot
.10952 .33992 Mdot
.11429 .23691 Mdot
.11905 .25751 Mdot
.12381 .23691 Mdot
.12857 .29872 Mdot
.13333 .33992 Mdot
.1381 .40172 Mdot
.14286 .23691 Mdot
.14762 .29872 Mdot
.15238 .36052 Mdot
.15714 .31932 Mdot
.1619 .27812 Mdot
.16667 .36052 Mdot
.17143 .21631 Mdot
.17619 .36052 Mdot
.18095 .29872 Mdot
.18571 .27812 Mdot
.19048 .38112 Mdot
.19524 .36052 Mdot
.2 .27812 Mdot
.20476 .36052 Mdot
.20952 .31932 Mdot
.21429 .40172 Mdot
.21905 .40172 Mdot
.22381 .31932 Mdot
.22857 .23691 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .27812 Mdot
.24762 .27812 Mdot
.25238 .38112 Mdot
.25714 .31932 Mdot
.2619 .29872 Mdot
.26667 .36052 Mdot
.27143 .33992 Mdot
.27619 .19571 Mdot
.28095 .21631 Mdot
.28571 .40172 Mdot
.29048 .27812 Mdot
.29524 .27812 Mdot
.3 .46353 Mdot
.30476 .19571 Mdot
.30952 .31932 Mdot
.31429 .40172 Mdot
.31905 .42232 Mdot
.32381 .33992 Mdot
.32857 .40172 Mdot
.33333 .25751 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .31932 Mdot
.35238 .33992 Mdot
.35714 .46353 Mdot
.3619 .36052 Mdot
.36667 .44292 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .25751 Mdot
.38571 .21631 Mdot
.39048 .17511 Mdot
.39524 .19571 Mdot
.4 .23691 Mdot
.40476 .21631 Mdot
.40952 .29872 Mdot
.41429 .33992 Mdot
.41905 .27812 Mdot
.42381 .31932 Mdot
.42857 .27812 Mdot
.43333 .23691 Mdot
.4381 .27812 Mdot
.44286 .33992 Mdot
.44762 .25751 Mdot
.45238 .31932 Mdot
.45714 .31932 Mdot
.4619 .27812 Mdot
.46667 .29872 Mdot
.47143 .38112 Mdot
.47619 .23691 Mdot
.48095 .36052 Mdot
.48571 .27812 Mdot
.49048 .27812 Mdot
.49524 .36052 Mdot
.5 .33992 Mdot
.50476 .31932 Mdot
.50952 .40172 Mdot
.51429 .25751 Mdot
.51905 .27812 Mdot
.52381 .27812 Mdot
.52857 .33992 Mdot
.53333 .27812 Mdot
.5381 .29872 Mdot
.54286 .33992 Mdot
.54762 .27812 Mdot
.55238 .36052 Mdot
.55714 .25751 Mdot
.5619 .33992 Mdot
.56667 .25751 Mdot
.57143 .44292 Mdot
.57619 .23691 Mdot
.58095 .17511 Mdot
.58571 .31932 Mdot
.59048 .27812 Mdot
.59524 .29872 Mdot
.6 .31932 Mdot
.60476 .23691 Mdot
.60952 .36052 Mdot
.61429 .36052 Mdot
.61905 .38112 Mdot
.62381 .38112 Mdot
.62857 .42232 Mdot
.63333 .21631 Mdot
.6381 .29872 Mdot
.64286 .36052 Mdot
.64762 .50473 Mdot
.65238 .38112 Mdot
.65714 .27812 Mdot
.6619 .19571 Mdot
.66667 .25751 Mdot
.67143 .40172 Mdot
.67619 .23691 Mdot
.68095 .33992 Mdot
.68571 .27812 Mdot
.69048 .29872 Mdot
.69524 .31932 Mdot
.7 .17511 Mdot
.70476 .25751 Mdot
.70952 .19571 Mdot
.71429 .25751 Mdot
.71905 .25751 Mdot
.72381 .11331 Mdot
.72857 .46353 Mdot
.73333 .25751 Mdot
.7381 .25751 Mdot
.74286 .25751 Mdot
.74762 .29872 Mdot
.75238 .31932 Mdot
.75714 .31932 Mdot
.7619 .42232 Mdot
.76667 .31932 Mdot
.77143 .23691 Mdot
.77619 .17511 Mdot
.78095 .40172 Mdot
.78571 .29872 Mdot
.79048 .33992 Mdot
.79524 .27812 Mdot
.8 .33992 Mdot
.80476 .33992 Mdot
.80952 .17511 Mdot
.81429 .27812 Mdot
.81905 .23691 Mdot
.82381 .25751 Mdot
.82857 .40172 Mdot
.83333 .23691 Mdot
.8381 .31932 Mdot
.84286 .33992 Mdot
.84762 .27812 Mdot
.85238 .33992 Mdot
.85714 .21631 Mdot
.8619 .36052 Mdot
.86667 .21631 Mdot
.87143 .21631 Mdot
.87619 .31932 Mdot
.88095 .29872 Mdot
.88571 .50473 Mdot
.89048 .29872 Mdot
.89524 .29872 Mdot
.9 .21631 Mdot
.90476 .38112 Mdot
.90952 .36052 Mdot
.91429 .44292 Mdot
.91905 .36052 Mdot
.92381 .15451 Mdot
.92857 .38112 Mdot
.93333 .38112 Mdot
.9381 .31932 Mdot
.94286 .42232 Mdot
.94762 .33992 Mdot
.95238 .33992 Mdot
.95714 .29872 Mdot
.9619 .31932 Mdot
.96667 .29872 Mdot
.97143 .36052 Mdot
.97619 .23691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0d?ooool2o`0006Sooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0d?ooool2o`0006Sooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0ooooool>ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0
ooooool>ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0Joooool2o`0003Sooooo0_l0000Rooooo`;o00005Oooool2o`0000Sooooo0_l0
001>ooooo`00:oooool00ol0003oooooooooo`1[ooooo`;o0000>?ooool2o`0002;ooooo0_l0000E
ooooo`;o00002?ooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`19ooooo`;o00001oooool2
o`0001Wooooo0_l0001?ooooo`;o00003?ooool2o`0006cooooo000Iooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0BOooool2o`0000Oooooo
0_l0000Iooooo`;o0000Coooool2o`0000cooooo0_l0001/ooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo02Wooooo0_l0000Oooooo`;o00007_ooool2o`0000Cooooo0_l00013ooooo`;o0000
@_ooool6o`0000Oooooo0_l0000booooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Yooooo`;o00007oooool2o`0001kooooo
0_l00004ooooo`;o0000@oooool2o`0004;ooooo1_l00007ooooo`;o0000<_ooool001Wooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo01So
oooo0_l000000ooooooo0000o`000004ooooo`;o00005oooool2o`00027ooooo0_l00007ooooo`?o
00001Oooool2o`0000Sooooo0_l0000;ooooo`;o00007Oooool2o`0000Kooooo0_l0000Dooooo`;o
00006oooool2o`0000cooooo0_l00002ooooo`;o0000:_ooool2o`0001_ooooo000[ooooo`03o`00
0?oooooooooo01Sooooo0_l000000ooooooo0000o`000004ooooo`;o00005oooool2o`00027ooooo
0_l00007ooooo`?o00001Oooool2o`0000Sooooo0_l0000;ooooo`;o00007Oooool2o`0000Kooooo
0_l0000Dooooo`;o00006oooool2o`0000cooooo0_l00002ooooo`;o0000:_ooool2o`0001_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0003oooooo0_l0000=ooooo`;o0000
4_ooool2o`0001;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000007?ooool2o`0000Wooooo
0_l000000ooooooo0000o`000002o`0000;ooooo1Ol0000Fooooo`;o0000B_ooool002_ooooo00?o
0000ooooooooool04_ooool2o`0000Gooooo0_l0000oooooo`;o00003Oooool2o`0001;ooooo0_l0
000Booooo`;o00002oooool2o`000003ooooool0003o000001cooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`Go00005_ooool2o`0004[ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00043o
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0=?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`12oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0foooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000ooooooooool0@oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400fooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0booooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41004oooool002_ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Hooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`?o000000GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Co00008oooool2o`000004ooooool0003o
0000ooooo`;o00001Oooool2o`0000;ooooo00?o0000ooooooooool01?l00002ooooo`04o`000?oo
ooooooooooooo`Oo00000_ooool2o`0000_ooooo0_l0000Booooo`;o00001oooool2o`0000Kooooo
00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooooooo
ool01Oooool2o`0000Cooooo0_l00008ooooo`;o00007?ooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000[oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00006?ooool2o`00
00Kooooo0_l00002ooooo`;o00002oooool3o`000005oc8b<_o<c<coooooooooool000000oooool0
0ol0003oooooooooo`04o`0002?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0002ooooo`03o`000?oooooooooo00Co00000_ooool01?l0003oooooooooooooool7o`0000;ooooo
0_l0000;ooooo`;o00004_ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001oooool2o`00
00Cooooo0_l00008ooooo`;o00007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`00:oooool2o`00043ooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
03?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo03oooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIV
I_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Cooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`04o`000?oo
oooo0000o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00009ooooo`;o
00001?ooool2o`0000Sooooo0_l0000>ooooo`?o00001_ooool2o`0002[ooooo0_l0000?ooooo`;o
00005?ooool2o`0000oooooo0_l0000;ooooo`;o00003_ooool2o`0000oooooo0_l0000:ooooo`;o
00006oooool2o`000004ooooool0003o0000o`00017ooooo0_l000000ooooooo0000o`00000Noooo
o`00:oooool01?l0003oooooo`000?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00005
ooooo`;o00002Oooool2o`0000Cooooo0_l00008ooooo`;o00003_ooool3o`0000Kooooo0_l0000Z
ooooo`;o00003oooool2o`0001Cooooo0_l0000?ooooo`;o00002oooool2o`0000kooooo0_l0000?
ooooo`;o00002_ooool2o`0001_ooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o000000?o
ooooo`000?l000005?ooool2o`0000;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000
ooooooooool0oooooolbooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`
o`0000cooooo00Co0000oiRHV?lb<S;oc<c<1Oooool002_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oa0@4?nHV9P01_ooool0
02_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`04o`000?o^k^koEEEE
ohN7Q`Gooooo000[ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00000Hoooo
o`;o00003_ooool2o`0000;ooooo0_l00008ooooo`;o00003_ooool2o`0000Oooooo1?l0000Foooo
o`;o00001_ooool4o`0000cooooo0_l0000Fooooo`;o00000oooool2o`0001_ooooo0_l0000?oooo
o`?o000000?oooooo`000?l000005?ooool2o`0000Wooooo0_l0000Aooooo`;o00001Oooool2o`00
01Oooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003oooooooooo`08oooo
o`;o000000?oooooo`000?l000006?ooool2o`0000kooooo0_l00002ooooo`;o00002?ooool2o`00
00kooooo0_l00007ooooo`Co00005_ooool2o`0000Kooooo1?l0000<ooooo`;o00005_ooool2o`00
00?ooooo0_l0000Kooooo`;o00003oooool3o`000003ooooool0003o000001Cooooo0_l00009oooo
o`;o00004Oooool2o`0000Gooooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo000[ooooo`03
o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc7ooooo0_l00008ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`00
00Kooooo0_l0000Wooooo`;o00003_ooool2o`0000Oooooo0_l0000Aooooo`;o00001_ooool2o`00
013ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000Rooooo`;o00007oooool2o`00
0003ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000001_ooooo0ol0000Soooo
o`00:oooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`0000Kooooo0_l0000Wooooo`;o
00003_ooool2o`0000Oooooo0_l0000Aooooo`;o00001_ooool2o`00013ooooo0_l00006ooooo`;o
00000oooool2o`0000?ooooo0_l0000Rooooo`;o00007oooool2o`000003ooooool0003o000000;o
00002Oooool2o`000003ooooool0003o000001_ooooo0ol0000Sooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool01?l0003oooooooooooooool2o`00023ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000017ooooo0_l0000Kooooo`;o
00008_ooool2o`0000;ooooo0_l0000?ooooo`;o00004?ooool3o`0000Oooooo0_l00010ooooo`;o
00003?ooool2o`000003ooooool0003o000000kooooo0_l0000Mooooo`00:oooool01?l0003ooooo
ooooooooool2o`00023ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`000003
ooooool0003o0000017ooooo0_l0000Kooooo`;o00008_ooool2o`0000;ooooo0_l0000?ooooo`;o
00004?ooool3o`0000Oooooo0_l00010ooooo`;o00003?ooool2o`000003ooooool0003o000000ko
oooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool05?ooool3o`0001Sooooo0_l0000Aooooo`;o
0000@?ooool2o`0002_ooooo0ol00007ooooo`;o0000B_ooool2o`0000Gooooo1?l0000Xooooo`00
:oooool00ol0003oooooooooo`0Dooooo`?o00006?ooool2o`00017ooooo0_l00010ooooo`;o0000
:oooool3o`0000Oooooo0_l0001:ooooo`;o00001Oooool4o`0002Sooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`0?ooooo`;o00003_ooool2o`0001Gooooo1?l0000Booooo`;o00001_ooool2o`0000?ooooo
0_l0000dooooo`;o0000;oooool2o`00023ooooo0_l0000<ooooo`;o0000B?ooool001Wooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0?oooo
o`;o00003_ooool2o`0001Gooooo1?l0000Booooo`;o00001_ooool2o`0000?ooooo0_l0000doooo
o`;o0000;oooool2o`00023ooooo0_l0000<ooooo`;o0000B?ooool001_ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkoooo
o`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`00
0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
05Kooooo0_l0001Kooooo`;o00009oooool2o`0003Cooooo0_l0000Vooooo`006oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`1Foooo
o`;o0000Foooool2o`0002Oooooo0_l0000dooooo`;o00009_ooool001Wooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0I?ooool2o`0003cooooo0_l0001Vooooo`;o0000;_ooool002_o
oooo00?o0000ooooooooool0I?ooool2o`0003cooooo0_l0001Vooooo`;o0000;_ooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o
0000D?ooool2o`0000oooooo0_l0001_ooooo`;o0000I_ooool002_ooooo0ol0001@ooooo`;o0000
3oooool2o`0006oooooo0_l0001Vooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`2iooooo`;o0000A_oo
ool2o`0003Oooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0^Oooool2o`0004Kooooo0_l0000gooooo`006?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool0oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`000?oooooo>oooool001_ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo
??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_o
oooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
0000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_ooool0oooooom4oooo
o`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000oooool2o`0000;ooooo
0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol000000olb<S;ooooo
ooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0@ooooo`;o000000?o410@ooooooooool00_ooool4o`000003
oa0@4?oooooooooo0?oooooo4_ooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4oooo
o`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`00
0002ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo5?oo
ool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgM
oa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Aoooo
o`Go00001_ooool00ol0003oooooooooo`3ooooooaCooooo0004ooooo`04onk^k_lQ8B7o410@onk^
kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo00Cok^k^
ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`04odA4
A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooolDooooo`001?ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co
8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo0000017ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`3ooooooaCooooo0003ooooo`;o00000_ooool2o`0000Go
oooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2o`00013o
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0@ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0oooooolDooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`00
0?oMgMd0<_ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo5?ooool000oo
oooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0booooo`03ogMgMol0003ooooo00Co
oooo00?oEEEEofIVI_l00000oooooolFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45322 Mdot
.03333 .30902 Mdot
.0381 .37082 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .28842 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .30902 Mdot
.07143 .32962 Mdot
.07619 .28842 Mdot
.08095 .32962 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .24721 Mdot
.1 .39142 Mdot
.10476 .39142 Mdot
.10952 .32962 Mdot
.11429 .22661 Mdot
.11905 .24721 Mdot
.12381 .22661 Mdot
.12857 .30902 Mdot
.13333 .32962 Mdot
.1381 .41202 Mdot
.14286 .24721 Mdot
.14762 .30902 Mdot
.15238 .37082 Mdot
.15714 .32962 Mdot
.1619 .26781 Mdot
.16667 .37082 Mdot
.17143 .22661 Mdot
.17619 .37082 Mdot
.18095 .28842 Mdot
.18571 .28842 Mdot
.19048 .37082 Mdot
.19524 .35022 Mdot
.2 .26781 Mdot
.20476 .37082 Mdot
.20952 .32962 Mdot
.21429 .41202 Mdot
.21905 .41202 Mdot
.22381 .30902 Mdot
.22857 .24721 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .28842 Mdot
.24762 .26781 Mdot
.25238 .37082 Mdot
.25714 .30902 Mdot
.2619 .28842 Mdot
.26667 .37082 Mdot
.27143 .32962 Mdot
.27619 .20601 Mdot
.28095 .22661 Mdot
.28571 .39142 Mdot
.29048 .28842 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .20601 Mdot
.30952 .32962 Mdot
.31429 .39142 Mdot
.31905 .43262 Mdot
.32381 .32962 Mdot
.32857 .41202 Mdot
.33333 .26781 Mdot
.3381 .32962 Mdot
.34286 .22661 Mdot
.34762 .30902 Mdot
.35238 .35022 Mdot
.35714 .45322 Mdot
.3619 .37082 Mdot
.36667 .45322 Mdot
.37143 .24721 Mdot
.37619 .24721 Mdot
.38095 .24721 Mdot
.38571 .20601 Mdot
.39048 .16481 Mdot
.39524 .20601 Mdot
.4 .22661 Mdot
.40476 .20601 Mdot
.40952 .28842 Mdot
.41429 .35022 Mdot
.41905 .26781 Mdot
.42381 .32962 Mdot
.42857 .26781 Mdot
.43333 .22661 Mdot
.4381 .26781 Mdot
.44286 .35022 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .32962 Mdot
.4619 .28842 Mdot
.46667 .30902 Mdot
.47143 .37082 Mdot
.47619 .24721 Mdot
.48095 .35022 Mdot
.48571 .26781 Mdot
.49048 .28842 Mdot
.49524 .35022 Mdot
.5 .35022 Mdot
.50476 .32962 Mdot
.50952 .41202 Mdot
.51429 .26781 Mdot
.51905 .26781 Mdot
.52381 .26781 Mdot
.52857 .32962 Mdot
.53333 .26781 Mdot
.5381 .30902 Mdot
.54286 .35022 Mdot
.54762 .26781 Mdot
.55238 .35022 Mdot
.55714 .24721 Mdot
.5619 .35022 Mdot
.56667 .24721 Mdot
.57143 .43262 Mdot
.57619 .22661 Mdot
.58095 .16481 Mdot
.58571 .30902 Mdot
.59048 .26781 Mdot
.59524 .30902 Mdot
.6 .32962 Mdot
.60476 .24721 Mdot
.60952 .37082 Mdot
.61429 .35022 Mdot
.61905 .37082 Mdot
.62381 .39142 Mdot
.62857 .41202 Mdot
.63333 .22661 Mdot
.6381 .30902 Mdot
.64286 .35022 Mdot
.64762 .49443 Mdot
.65238 .37082 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .24721 Mdot
.67143 .41202 Mdot
.67619 .22661 Mdot
.68095 .32962 Mdot
.68571 .26781 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .18541 Mdot
.70476 .26781 Mdot
.70952 .18541 Mdot
.71429 .26781 Mdot
.71905 .24721 Mdot
.72381 .10301 Mdot
.72857 .45322 Mdot
.73333 .24721 Mdot
.7381 .24721 Mdot
.74286 .26781 Mdot
.74762 .28842 Mdot
.75238 .30902 Mdot
.75714 .30902 Mdot
.7619 .41202 Mdot
.76667 .32962 Mdot
.77143 .24721 Mdot
.77619 .18541 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .35022 Mdot
.79524 .28842 Mdot
.8 .35022 Mdot
.80476 .35022 Mdot
.80952 .16481 Mdot
.81429 .26781 Mdot
.81905 .22661 Mdot
.82381 .24721 Mdot
.82857 .41202 Mdot
.83333 .22661 Mdot
.8381 .32962 Mdot
.84286 .35022 Mdot
.84762 .28842 Mdot
.85238 .35022 Mdot
.85714 .22661 Mdot
.8619 .37082 Mdot
.86667 .22661 Mdot
.87143 .22661 Mdot
.87619 .32962 Mdot
.88095 .30902 Mdot
.88571 .51503 Mdot
.89048 .28842 Mdot
.89524 .28842 Mdot
.9 .20601 Mdot
.90476 .37082 Mdot
.90952 .37082 Mdot
.91429 .43262 Mdot
.91905 .35022 Mdot
.92381 .14421 Mdot
.92857 .37082 Mdot
.93333 .39142 Mdot
.9381 .30902 Mdot
.94286 .43262 Mdot
.94762 .32962 Mdot
.95238 .35022 Mdot
.95714 .28842 Mdot
.9619 .30902 Mdot
.96667 .30902 Mdot
.97143 .35022 Mdot
.97619 .24721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000d?ooool2o`0006Sooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0=3ooooo0_l0001Xooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo3_oo
ool2o`0002_ooooo000[ooooo`;o0000ooooool?ooooo`;o0000:oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`1[ooooo`;o0000>?ooool2o`0004?ooooo0_l0001>ooooo`00:oooool2o`00
06cooooo0_l0000hooooo`;o0000@oooool2o`0004kooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000<[ooooo0_l000000ooooooo0000o`00000Booooo`;o
0000F?ooool002_ooooo00?o0000ooooooooool0bOooool2o`000003ooooool0003o000001;ooooo
0_l0001Hooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool0013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
BOooool2o`0000Oooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo0_l0001<ooooo`;o
0000A_ooool2o`0003;ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o00005_ooool2o`000004
ooooool0003o0000ooooo`;o0000C?ooool2o`0004Kooooo0_l0000booooo`006oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o00006Oooool2o`000003ooooool0003o000000cooooo0_l0000Oooooo`;o
00004Oooool2o`0000oooooo0_l00008ooooo`;o0000:_ooool2o`0000oooooo0_l0000;ooooo`;o
0000:Oooool2o`0000;ooooo0_l00006ooooo`Ko0000>oooool002_ooooo00?o0000ooooooooool0
6?ooool2o`000003ooooool0003o000000cooooo0_l0000Oooooo`;o00004Oooool2o`0000oooooo
0_l00008ooooo`;o0000:_ooool2o`0000oooooo0_l0000;ooooo`;o0000:Oooool2o`0000;ooooo
0_l00006ooooo`Ko0000>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Booooo`;o0000
1Oooool2o`0000Kooooo0_l0000Gooooo`;o0000:_ooool5o`0001[ooooo0_l0000Gooooo`;o0000
00?oooooo`000?l000002Oooool2o`00017ooooo0_l0000>ooooo`;o00000_ooool4o`0000Sooooo
0_l0000=ooooo`;o0000;Oooool2o`0001_ooooo000[ooooo`;o00004oooool2o`0000Gooooo0_l0
0006ooooo`;o00005oooool2o`0002[ooooo1Ol0000Jooooo`;o00005oooool2o`000003ooooool0
003o000000Wooooo0_l0000Aooooo`;o00003_ooool2o`0000;ooooo1?l00008ooooo`;o00003Ooo
ool2o`0002gooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo0_l0000Wooooo`;o00002_ooool2o`0000_ooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000Wooooo0_l0000Hooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`Co000000So410@o`000?l0
003ok^k^oc8b<_l0003o<S8bonk^kP;ooooo1Ol000000oo^k^ko0000o`000002ooooo`;o00002ooo
ool2o`0001_ooooo0_l00003ooooo`Go000000Go410@ooooooooooooooooodA4A004o`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`;o00009?ooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000oooo
ooooool09_ooool2o`0000[ooooo0_l0000<ooooo`;o000000WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL01?ooool2o`0000Wooooo0_l0000Hooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00;o000000GoMgMgoiRHV?oo
ooooV9RHogMgM`02ooooo`Go000000?oMgMgo`000?l000000_ooool2o`0000_ooooo0_l0000Koooo
o`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03Oooool2o`0002Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`00
0?oooooooooo04?ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@4100=_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool0<_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000f
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo03?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
000fooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool00000=_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@400fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Aooooo`00:oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00007_ooool4o`0000oooooo0_l00004ooooo`;o000000CoV9RHoooo
oonHV9SoMgMg0_ooool2o`0002;ooooo0_l0000>ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`;o000000?ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Gooooo0_l0
000?ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l000001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Oooooo0_l0000>ooooo`;o00002oooool3o`0000cooooo00Go0000okZj
^_ooooooV9RHoa0@4002o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00007_ooool4o`0000oooooo1?l00002ooooo`;o000000Co<S8bo`000?lb<S;o
k^k^0_ooool2o`0002;ooooo0_l0000>ooooo`;o000000?oEEEEofIVI_l000001?ooool3o`000003
oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Uooooo`;o00003Oooool00omE
EEGoIVIVo`000005ooooo`Ko000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h7ooooo`;o00003_oo
ool2o`0000_ooooo0ol0000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_l000001_ooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?oo
ooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool01?l0003oooooo`00
0?l00003ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o00001oooool01?l0003ooooo
o`000?l00004ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooo0000o`00
0?ooool00ol00004ooooo`?o00003_ooool00ol0003oooooooooo`07ooooo`;o00000_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00002Oooool00ol0
003oooooooooo`08ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`00
0?l000002oooool3o`0000gooooo1?l0000;ooooo`04o`000?ooooooooooooooo`?o00001oooool2
o`0000gooooo00?o0000ooooooooool02oooool2o`0000gooooo00Co0000ooooool0003o00001Ooo
ool4o`000003ooooool0003ooooo01;ooooo00?o0000oa0@4?nHV9P01_ooool002_ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`04o`000?o^k^koEEEEohN7Q`Gooooo000[
ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooodA4A?l0003o410@00Cooooo000[
ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0
003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooooooo
ool02oooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001Oooool2o`0000ko
oooo0_l0000@ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o00006?ooool2o`0000So
oooo0_l0000<ooooo`;o00001Oooool2o`0001Cooooo0_l0000Fooooo`;o00006?ooool2o`0001Co
oooo0_l00009ooooo`;o00005?ooool2o`0001[ooooo0_l00008ooooo`00:oooool2o`0000cooooo
0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o0000
4?ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0001Sooooo0_l00008ooooo`;o0000
3?ooool2o`0000Gooooo0_l0000Dooooo`;o00005_ooool2o`0001Sooooo0_l0000Dooooo`;o0000
2Oooool2o`0001Cooooo0_l0000Tooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo033ooooo
0_l0000^ooooo`;o00004Oooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool4o`0000_ooooo
1?l000000ooooooo0000o`00000>ooooo`;o00001oooool2o`0002[ooooo0_l000000ooooooo0000
o`000002o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o00002?ooool2o`0000Cooooo
0_l0000Mooooo`00:oooool2o`00037ooooo0_l0000^ooooo`;o00004Oooool2o`0000Kooooo0_l0
000:ooooo`;o00000_ooool4o`0000_ooooo1?l000000ooooooo0000o`00000>ooooo`;o00001ooo
ool2o`0002[ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo0000o`00
000Booooo`;o00002?ooool2o`0000Cooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l00002ooooo`;o00008?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o00006oooool2
o`0001oooooo0_l0000Xooooo`;o000000?oooooo`000?l000002?ooool2o`0003gooooo0_l0000;
ooooo`?o00001?ooool2o`0002[ooooo000[ooooo`04o`000?ooooooooooooooo`;o00008?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000gooooo0_l00002
ooooo`;o00006oooool2o`0001oooooo0_l0000Xooooo`;o000000?oooooo`000?l000002?ooool2
o`0003gooooo0_l0000;ooooo`?o00001?ooool2o`0002[ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000@
ooooo`;o00000oooool3o`0003Gooooo0_l00006ooooo`;o0000G?ooool2o`0002kooooo0_l0000/
ooooo`;o0000:?ooool002_ooooo00?o0000ooooooooool03oooool2o`0000?ooooo0ol0000eoooo
o`;o00001_ooool2o`0005cooooo0_l0000^ooooo`;o0000;?ooool2o`0002Sooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo
0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001_ooool3o`0001oooooo0_l0000Eooooo`Co00007oooool2o`00
03Cooooo0_l0000Rooooo`;o00002oooool2o`0001[ooooo0_l0000Booooo`;o0000B?ooool001_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool07oooool2o`0001Gooooo1?l0000Oooooo`;o0000=?ooool2o`0002;ooooo0_l0000;oooo
o`;o00006_ooool2o`0001;ooooo0_l00018ooooo`006oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo05Kooooo0_l0001:ooooo`;o0000I_ooool2o`0000Kooooo0_l0000Vooooo`00
:oooool2o`0005Oooooo0_l0001:ooooo`;o0000I_ooool2o`0000Kooooo0_l0000Vooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0ol0001@ooooo`;o00003ooo
ool2o`000003ooooool0003o000006cooooo0_l0001Vooooo`00:oooool3o`00053ooooo0_l0000?
ooooo`;o000000?oooooo`000?l00000K?ooool2o`0006Kooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`00
0;[ooooo0_l0001oooooo`00:oooool00ol0003oooooooooo`2iooooo`;o0000Ooooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000H
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooo
oolkooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0ooooool2ooooo`;o0000
=oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0003oooooo`;ooooo0_l0000gooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb
<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo
>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo
00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_o
oooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCo
oooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCo
oooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03
ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo
00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo013ooooo0_l000001?l@413oooooooooooooool5o`000?oooooo5Oooool000?o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A4
0oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0
003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolEooooo`001?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`00
0?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo0000017ooooo1Ol00004ooooo`03oiRHV?lQ
8B7ok^k^0?oooooo5_ooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^
kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05
o`000?ooooooooooooooool000000_ooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001_ooool0
0onHV9So8B4Qonk^kP3ooooooaGooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEE
oiRHV?ooooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Boooo
o`05o`000?n7QhOoooooojVYZOl000004Oooool01?oMgMgoEEEEooooool00007ooooo`03ogMgMomV
IVKooooo0?oooooo5?ooool000?ooooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02
ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo013ooooo00?oMgMgolc<c?l000002?ooool00ol0003oooooooooo`3o
oooooa?ooooo000?ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0booooo`03onk^k_m4
A4Co000000Cooooo00Go0000okZj^_ooooooV9RHoa0@403ooooooaGooooo000?ooooo`03okZj^_m4
A4Cooooo00;ooooo00?oZJVYooooooooool0<_ooool00omgMgOo0000ooooo`03ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44292 Mdot
.03333 .31932 Mdot
.0381 .36052 Mdot
.04286 .27812 Mdot
.04762 .29872 Mdot
.05238 .27812 Mdot
.05714 .29872 Mdot
.0619 .29872 Mdot
.06667 .31932 Mdot
.07143 .33992 Mdot
.07619 .29872 Mdot
.08095 .31932 Mdot
.08571 .40172 Mdot
.09048 .31932 Mdot
.09524 .23691 Mdot
.1 .38112 Mdot
.10476 .38112 Mdot
.10952 .33992 Mdot
.11429 .21631 Mdot
.11905 .25751 Mdot
.12381 .21631 Mdot
.12857 .29872 Mdot
.13333 .31932 Mdot
.1381 .42232 Mdot
.14286 .25751 Mdot
.14762 .31932 Mdot
.15238 .38112 Mdot
.15714 .33992 Mdot
.1619 .25751 Mdot
.16667 .36052 Mdot
.17143 .21631 Mdot
.17619 .38112 Mdot
.18095 .29872 Mdot
.18571 .27812 Mdot
.19048 .38112 Mdot
.19524 .36052 Mdot
.2 .25751 Mdot
.20476 .38112 Mdot
.20952 .33992 Mdot
.21429 .42232 Mdot
.21905 .40172 Mdot
.22381 .29872 Mdot
.22857 .23691 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .29872 Mdot
.24762 .27812 Mdot
.25238 .38112 Mdot
.25714 .29872 Mdot
.2619 .27812 Mdot
.26667 .38112 Mdot
.27143 .31932 Mdot
.27619 .19571 Mdot
.28095 .23691 Mdot
.28571 .38112 Mdot
.29048 .29872 Mdot
.29524 .27812 Mdot
.3 .44292 Mdot
.30476 .21631 Mdot
.30952 .31932 Mdot
.31429 .38112 Mdot
.31905 .44292 Mdot
.32381 .33992 Mdot
.32857 .40172 Mdot
.33333 .27812 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .29872 Mdot
.35238 .33992 Mdot
.35714 .46353 Mdot
.3619 .36052 Mdot
.36667 .46353 Mdot
.37143 .23691 Mdot
.37619 .25751 Mdot
.38095 .25751 Mdot
.38571 .19571 Mdot
.39048 .15451 Mdot
.39524 .21631 Mdot
.4 .21631 Mdot
.40476 .19571 Mdot
.40952 .29872 Mdot
.41429 .36052 Mdot
.41905 .27812 Mdot
.42381 .33992 Mdot
.42857 .27812 Mdot
.43333 .21631 Mdot
.4381 .27812 Mdot
.44286 .33992 Mdot
.44762 .27812 Mdot
.45238 .31932 Mdot
.45714 .33992 Mdot
.4619 .29872 Mdot
.46667 .29872 Mdot
.47143 .38112 Mdot
.47619 .23691 Mdot
.48095 .33992 Mdot
.48571 .25751 Mdot
.49048 .27812 Mdot
.49524 .36052 Mdot
.5 .36052 Mdot
.50476 .33992 Mdot
.50952 .42232 Mdot
.51429 .27812 Mdot
.51905 .27812 Mdot
.52381 .25751 Mdot
.52857 .31932 Mdot
.53333 .25751 Mdot
.5381 .29872 Mdot
.54286 .33992 Mdot
.54762 .27812 Mdot
.55238 .33992 Mdot
.55714 .25751 Mdot
.5619 .36052 Mdot
.56667 .23691 Mdot
.57143 .42232 Mdot
.57619 .21631 Mdot
.58095 .17511 Mdot
.58571 .29872 Mdot
.59048 .25751 Mdot
.59524 .31932 Mdot
.6 .31932 Mdot
.60476 .25751 Mdot
.60952 .38112 Mdot
.61429 .36052 Mdot
.61905 .38112 Mdot
.62381 .40172 Mdot
.62857 .42232 Mdot
.63333 .23691 Mdot
.6381 .29872 Mdot
.64286 .33992 Mdot
.64762 .50473 Mdot
.65238 .38112 Mdot
.65714 .29872 Mdot
.6619 .21631 Mdot
.66667 .25751 Mdot
.67143 .40172 Mdot
.67619 .21631 Mdot
.68095 .33992 Mdot
.68571 .25751 Mdot
.69048 .31932 Mdot
.69524 .31932 Mdot
.7 .19571 Mdot
.70476 .25751 Mdot
.70952 .19571 Mdot
.71429 .27812 Mdot
.71905 .23691 Mdot
.72381 .09271 Mdot
.72857 .44292 Mdot
.73333 .25751 Mdot
.7381 .23691 Mdot
.74286 .25751 Mdot
.74762 .27812 Mdot
.75238 .29872 Mdot
.75714 .29872 Mdot
.7619 .42232 Mdot
.76667 .31932 Mdot
.77143 .23691 Mdot
.77619 .17511 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .33992 Mdot
.79524 .29872 Mdot
.8 .33992 Mdot
.80476 .36052 Mdot
.80952 .17511 Mdot
.81429 .27812 Mdot
.81905 .21631 Mdot
.82381 .23691 Mdot
.82857 .42232 Mdot
.83333 .21631 Mdot
.8381 .33992 Mdot
.84286 .36052 Mdot
.84762 .27812 Mdot
.85238 .33992 Mdot
.85714 .23691 Mdot
.8619 .36052 Mdot
.86667 .23691 Mdot
.87143 .21631 Mdot
.87619 .31932 Mdot
.88095 .31932 Mdot
.88571 .50473 Mdot
.89048 .29872 Mdot
.89524 .27812 Mdot
.9 .19571 Mdot
.90476 .36052 Mdot
.90952 .38112 Mdot
.91429 .42232 Mdot
.91905 .36052 Mdot
.92381 .13391 Mdot
.92857 .36052 Mdot
.93333 .38112 Mdot
.9381 .29872 Mdot
.94286 .42232 Mdot
.94762 .31932 Mdot
.95238 .33992 Mdot
.95714 .27812 Mdot
.9619 .29872 Mdot
.96667 .29872 Mdot
.97143 .36052 Mdot
.97619 .23691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3@ooooo`;o0000J?ooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`3@ooooo`;o0000J?ooool001Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000@ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool3o`000?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo3_ooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo3_ooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1[ooooo`;o0000cOooool002_ooooo
00?o0000ooooooooool0Joooool2o`000<gooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0:Gooooo0_l0000iooooo`;o00002?ooool2o`0004kooooo000[
ooooo`03o`000?oooooooooo0:Gooooo0_l0000iooooo`;o00002?ooool2o`0004kooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`19ooooo`;o00007oooool2o`0000Cooooo0_l0001Gooooo`;o000000?ooooo
o`000?l00000>?ooool2o`0003;ooooo000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool0BOooool2o`0001oooooo0_l00004ooooo`;o0000
Eoooool2o`000003ooooool0003o000003Sooooo0_l0000booooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo01Sooooo0_l000000ooooooo0000o`00000<ooooo`;o00009oooool2o`0001Wooooo
0ol00008ooooo`;o0000:_ooool2o`0001Sooooo0_l00002ooooo`;o0000:Oooool2o`0000;ooooo
0_l0000:ooooo`;o0000>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000000cooooo
0_l0000Wooooo`;o00006Oooool3o`0000Sooooo0_l0000Zooooo`;o00006?ooool2o`0000;ooooo
0_l0000Yooooo`;o00000_ooool2o`0000[ooooo0_l0000kooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool04_ooool2o`0002Ko
oooo0_l0000>ooooo`;o00004Oooool2o`0000Oooooo0_l0000Mooooo`;o00006_ooool2o`0001;o
oooo0_l0000Hooooo`;o00001?ooool2o`0000Sooooo0_l0000=ooooo`;o00002Oooool4o`00023o
oooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`0Booooo`;o00009_ooool2o`0000kooooo
0_l0000Aooooo`;o00001oooool2o`0001gooooo0_l0000Jooooo`;o00004_ooool2o`0001Sooooo
0_l00004ooooo`;o00002?ooool2o`0000gooooo0_l00009ooooo`Co00008?ooool2o`0001_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`0Iooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
<oooool4o`0001gooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo
0_l00002ooooo`;o00004Oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`000003oooo
ool0003o000006;ooooo000[ooooo`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o00000ooo
ool2o`0000[ooooo0_l0000cooooo`Co00007Oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00002?ooool2o`0000;ooooo0_l0000Aooooo`;o00001?ooool2o`0000?ooooo0_l0
0007ooooo`;o000000?oooooo`000?l00000H_ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000@?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0doooo
o`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^03?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0>_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Kooooo00?o0000oooo
ooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`0cooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400C
ooooo`00:oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000009oooool2o`00
013ooooo0_l000000omgMgOo<S8booooo`02o`0000?ooooo00?o0000ooooooooool00_ooool2o`00
00Wooooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00?o00000_ooool0
0ol0003oooooooooo`02ooooo`;o0000<?ooool2o`0000Oooooo00GoMgMgo`000?l0003oooooo`00
0003ooooo`03o`000?oooooooooo00_ooooo0_l00008ooooo`;o00003?ooool2o`0000kooooo00?o
V9RHob4Q8Oo^k^h00_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?l000009oooool2o`0000oooooo0ol000000olb<S;oc<c<ooooo`02o`0000?ooooo00?o
0000ooooooooool00_ooool2o`0000Wooooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`00
0?oooooooooo00?o00000_ooool00ol0003oooooooooo`02ooooo`;o0000<?ooool2o`0000Cooooo
00Co0000ob4Q8Ol0003o<S8b0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo0_l00008ooooo`;o00003?ooool2o`0000oooooo00KoMgMgofIVI_l0003o0000ooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00010
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003ooooooooo
o`0oooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0doooo
o`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000kooooo
0_l0000>ooooo`;o00002oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Sooooo
0_l0000?ooooo`;o00004Oooool2o`0000kooooo0ol0000Dooooo`;o00003?ooool2o`0000kooooo
0_l00004ooooo`;o00006oooool3o`0000[ooooo0_l0000Kooooo`;o00003?ooool2o`0000Gooooo
1?l0000Nooooo`00:oooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`0000kooooo0_l0000>ooooo`;o00002oooool2o`000003ooooool0003o000000?o0000
0_ooool2o`0000Sooooo0_l0000?ooooo`;o00004Oooool2o`0000kooooo0ol0000Dooooo`;o0000
3?ooool2o`0000kooooo0_l00004ooooo`;o00006oooool3o`0000[ooooo0_l0000Kooooo`;o0000
3?ooool2o`0000Gooooo1?l0000Dooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?oo
ooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003o410@oiRH
V006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00Co0000
onk^k_mEEEGoQhN71Oooool002_ooooo00Co0000ooooool0003o00002Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0002?ooooo0_l0000:ooooo`;o00001ooo
ool2o`00023ooooo0_l0000Eooooo`;o00004_ooool4o`0001Wooooo1?l0000Cooooo`;o00001?oo
ool2o`0001Wooooo1?l0000Booooo`;o00006oooool01Ol0003oooooodA4A?l0003o410@00Cooooo
000[ooooo`04o`000?oooooo0000o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
2oooool2o`0000;ooooo0_l0000Sooooo`;o00002_ooool2o`0000Oooooo0_l0000Pooooo`;o0000
5Oooool2o`0001;ooooo1?l0000Iooooo`Co00004oooool2o`0000Cooooo0_l0000Iooooo`Co0000
4_ooool2o`0001_ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooo
oolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<Oooool2
o`0000Sooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo00_ooooo0_l00009ooooo`;o00003Oooool2o`0000kooooo
0_l0000Pooooo`;o00001oooool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo
0_l00005ooooo`;o00002_ooool4o`0001[ooooo0_l00009ooooo`;o00007oooool2o`000003oooo
ool0003o000000[ooooo0_l00002ooooo`;o00007?ooool2o`0002?ooooo000[ooooo`03o`000?oo
oooooooo00_ooooo0_l00009ooooo`;o00003Oooool2o`0000kooooo0_l0000Pooooo`;o00001ooo
ool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00002_oo
ool4o`0001[ooooo0_l00009ooooo`;o00007oooool2o`000003ooooool0003o000000[ooooo0_l0
0002ooooo`;o00007?ooool2o`0002?ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`04o`000?ooooooooooooooo`;o00009Oooool2o`0000Kooooo0_l0000aooooo`;o00003_oo
ool2o`0001Kooooo1?l0000@ooooo`;o00003_ooool2o`0003Sooooo0_l00009ooooo`;o00001?oo
ool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0001gooooo000[
ooooo`04o`000?ooooooooooooooo`;o00009Oooool2o`0000Kooooo0_l0000aooooo`;o00003_oo
ool2o`0001Kooooo1?l0000@ooooo`;o00003_ooool2o`0003Sooooo0_l00009ooooo`;o00001?oo
ool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0001gooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`0Dooooo`?o00003?ooool2o`0000Kooooo0_l00002ooooo`;o00000_oo
ool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000^ooooo`;o0000:?oo
ool2o`000003ooooool0003o000000Sooooo0_l0000Uooooo`;o00009?ooool2o`0000Kooooo0_l0
000Xooooo`00:oooool00ol0003oooooooooo`0Dooooo`?o00003?ooool2o`0000Kooooo0_l00002
ooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000^
ooooo`;o0000:?ooool2o`000003ooooool0003o000000Sooooo0_l0000Uooooo`;o00009?ooool2
o`0000Kooooo0_l0000Xooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o
0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool03oooool2o`0002Oooooo0_l0000O
ooooo`;o0000Eoooool2o`0000cooooo0_l0001hooooo`006Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00oooooo0_l0000Wooooo`;o0000
7oooool2o`0005Oooooo0_l0000<ooooo`;o0000N?ooool001_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo
>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo01oooooo
0_l0000Eooooo`;o0000Eoooool2o`00017ooooo0_l0000?ooooo`;o00009oooool2o`0001;ooooo
0_l0000Hooooo`;o00001_ooool2o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01oooooo0_l0000Eooooo`;o0000
Eoooool2o`00017ooooo0_l0000?ooooo`;o00009oooool2o`0001;ooooo0_l0000Hooooo`;o0000
1_ooool2o`0002Kooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000D?ooool2o`0000Cooooo
0_l0001jooooo`;o0000I_ooool002_ooooo0ol0001@ooooo`;o00001?ooool2o`0007[ooooo0_l0
001Vooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0HOooool2o`000003ooooool0003o00000=Cooooo000[
ooooo`03o`000?oooooooooo067ooooo0_l000000ooooooo0000o`00003Dooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`2iooooo`;o0000A_ooool2o`0003Oooooo000Hooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0^Oooool2o`0004Kooooo0_l0000goooo
o`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo>oooool0
01_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooo
oolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_o
oooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooo
oolkooooo`007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool00000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo
00?o0000okZj^_ooool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooo
oom5ooooo`000oooool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8b
o`000?l000000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o
^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@ooooo`;o000000Wo
410@oooooooooooooooooiRHV?l@413o0000oc8b<_o<c<`0oooooolEooooo`000oooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4
A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo
00Go410@okZj^_ooooooMgMgoc8b<P3ooooooaGooooo0004ooooo`04omgMgOl0003o410@olc<c0Go
oooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`B
ooooo`05o`000?ooooooooooooooool000004Oooool5o`0000Oooooo00?o0000ooooooooool0oooo
oolCooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00Go
QhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`Ko00002Oooool01?m4A4CogMgMooooool00007ooooo`03ojVYZOl@413o
oooo0?oooooo5?ooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool02OmEEEGoV9RHoooooooo
ooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7
QoooooooZJVYo`00000Aooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o410@o`000?nj^[X0oooo
oolEooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMg
ob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool04?ooool00omgMgOoc<c<o`000007ooooo`03okZj^_lQ8B7ooooo0?oooooo5?ooool0
00oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03;ooooo00?ok^k^odA4A?l000001?oo
ool01Ol@413oV9RHoooooonj^[[o00000?oooooo5Oooool000oooooo00?o^[ZjodA4A?ooool00_oo
ool00onYZJWoooooooooo`0booooo`03ogMgMol0003ooooo00?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@3ooooooaGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45322 Mdot
.03333 .30902 Mdot
.0381 .37082 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .26781 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .30902 Mdot
.07143 .35022 Mdot
.07619 .28842 Mdot
.08095 .32962 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .22661 Mdot
.1 .39142 Mdot
.10476 .37082 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .26781 Mdot
.12381 .22661 Mdot
.12857 .28842 Mdot
.13333 .30902 Mdot
.1381 .41202 Mdot
.14286 .24721 Mdot
.14762 .32962 Mdot
.15238 .39142 Mdot
.15714 .35022 Mdot
.1619 .24721 Mdot
.16667 .35022 Mdot
.17143 .22661 Mdot
.17619 .39142 Mdot
.18095 .28842 Mdot
.18571 .26781 Mdot
.19048 .37082 Mdot
.19524 .35022 Mdot
.2 .24721 Mdot
.20476 .37082 Mdot
.20952 .32962 Mdot
.21429 .43262 Mdot
.21905 .41202 Mdot
.22381 .30902 Mdot
.22857 .22661 Mdot
.23333 .28842 Mdot
.2381 .30902 Mdot
.24286 .28842 Mdot
.24762 .28842 Mdot
.25238 .39142 Mdot
.25714 .28842 Mdot
.2619 .26781 Mdot
.26667 .37082 Mdot
.27143 .30902 Mdot
.27619 .20601 Mdot
.28095 .24721 Mdot
.28571 .39142 Mdot
.29048 .30902 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .22661 Mdot
.30952 .32962 Mdot
.31429 .37082 Mdot
.31905 .45322 Mdot
.32381 .32962 Mdot
.32857 .41202 Mdot
.33333 .28842 Mdot
.3381 .32962 Mdot
.34286 .22661 Mdot
.34762 .30902 Mdot
.35238 .35022 Mdot
.35714 .45322 Mdot
.3619 .37082 Mdot
.36667 .47383 Mdot
.37143 .22661 Mdot
.37619 .24721 Mdot
.38095 .26781 Mdot
.38571 .18541 Mdot
.39048 .16481 Mdot
.39524 .22661 Mdot
.4 .22661 Mdot
.40476 .20601 Mdot
.40952 .28842 Mdot
.41429 .35022 Mdot
.41905 .28842 Mdot
.42381 .32962 Mdot
.42857 .26781 Mdot
.43333 .22661 Mdot
.4381 .28842 Mdot
.44286 .32962 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .35022 Mdot
.4619 .28842 Mdot
.46667 .28842 Mdot
.47143 .37082 Mdot
.47619 .22661 Mdot
.48095 .35022 Mdot
.48571 .26781 Mdot
.49048 .28842 Mdot
.49524 .35022 Mdot
.5 .35022 Mdot
.50476 .35022 Mdot
.50952 .41202 Mdot
.51429 .26781 Mdot
.51905 .26781 Mdot
.52381 .24721 Mdot
.52857 .32962 Mdot
.53333 .26781 Mdot
.5381 .28842 Mdot
.54286 .32962 Mdot
.54762 .28842 Mdot
.55238 .32962 Mdot
.55714 .24721 Mdot
.5619 .37082 Mdot
.56667 .22661 Mdot
.57143 .41202 Mdot
.57619 .22661 Mdot
.58095 .16481 Mdot
.58571 .28842 Mdot
.59048 .26781 Mdot
.59524 .30902 Mdot
.6 .30902 Mdot
.60476 .24721 Mdot
.60952 .37082 Mdot
.61429 .37082 Mdot
.61905 .39142 Mdot
.62381 .39142 Mdot
.62857 .43262 Mdot
.63333 .24721 Mdot
.6381 .28842 Mdot
.64286 .35022 Mdot
.64762 .51503 Mdot
.65238 .37082 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .26781 Mdot
.67143 .41202 Mdot
.67619 .22661 Mdot
.68095 .32962 Mdot
.68571 .24721 Mdot
.69048 .30902 Mdot
.69524 .32962 Mdot
.7 .18541 Mdot
.70476 .24721 Mdot
.70952 .18541 Mdot
.71429 .26781 Mdot
.71905 .22661 Mdot
.72381 .10301 Mdot
.72857 .45322 Mdot
.73333 .24721 Mdot
.7381 .24721 Mdot
.74286 .26781 Mdot
.74762 .26781 Mdot
.75238 .28842 Mdot
.75714 .28842 Mdot
.7619 .41202 Mdot
.76667 .32962 Mdot
.77143 .22661 Mdot
.77619 .16481 Mdot
.78095 .37082 Mdot
.78571 .30902 Mdot
.79048 .35022 Mdot
.79524 .30902 Mdot
.8 .35022 Mdot
.80476 .37082 Mdot
.80952 .18541 Mdot
.81429 .26781 Mdot
.81905 .20601 Mdot
.82381 .24721 Mdot
.82857 .43262 Mdot
.83333 .22661 Mdot
.8381 .32962 Mdot
.84286 .37082 Mdot
.84762 .28842 Mdot
.85238 .32962 Mdot
.85714 .24721 Mdot
.8619 .37082 Mdot
.86667 .22661 Mdot
.87143 .22661 Mdot
.87619 .32962 Mdot
.88095 .32962 Mdot
.88571 .51503 Mdot
.89048 .30902 Mdot
.89524 .28842 Mdot
.9 .18541 Mdot
.90476 .37082 Mdot
.90952 .37082 Mdot
.91429 .41202 Mdot
.91905 .35022 Mdot
.92381 .14421 Mdot
.92857 .35022 Mdot
.93333 .39142 Mdot
.9381 .30902 Mdot
.94286 .41202 Mdot
.94762 .32962 Mdot
.95238 .35022 Mdot
.95714 .28842 Mdot
.9619 .28842 Mdot
.96667 .30902 Mdot
.97143 .37082 Mdot
.97619 .24721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000d?ooool2o`0006Sooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0=3ooooo0_l0001Xooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo3_oo
ool2o`0002_ooooo000[ooooo`;o0000ooooool?ooooo`;o0000:oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`1[ooooo`;o0000>?ooool2o`0003Wooooo0_l0001Hooooo`00:oooool2o`00
06cooooo0_l0000hooooo`;o0000>Oooool2o`0005Sooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`0006_ooooo0_l0001Mooooo`;o000000?oooooo`000?l0
00007?ooool2o`0001[ooooo0_l0000booooo`00:oooool00ol0003oooooooooo`1Zooooo`;o0000
GOooool2o`000003ooooool0003o000001cooooo0_l0000Jooooo`;o0000<_ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0004Wooooo0_l0000Uooooo`;o0000
C?ooool2o`0002gooooo0_l0001;ooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`19ooooo`;o00009Oooool2o`0004cooooo
0_l0000]ooooo`;o0000Boooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0001?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000oooooo0_l0000Fooooo`;o00002Ooo
ool2o`0000Oooooo0_l00005ooooo`?o00002?ooool2o`0000_ooooo0_l0000Jooooo`;o000000?o
ooooo`000?l000007?ooool2o`0000_ooooo0_l0000>ooooo`;o00004?ooool2o`0000Sooooo1?l0
000kooooo`00:oooool00ol0003oooooooooo`0Booooo`;o00001?ooool2o`000003ooooool0003o
000000cooooo0_l0000?ooooo`;o00005_ooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool3
o`0000Sooooo0_l0000;ooooo`;o00006_ooool2o`000003ooooool0003o000001cooooo0_l0000;
ooooo`;o00003_ooool2o`00013ooooo0_l00008ooooo`Co0000>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`0Qooooo`;o00000oooool2o`0000[ooooo0_l0000Fooooo`;o00006oooool2
o`0002_ooooo0_l00008ooooo`;o00003?ooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool2
o`0000Oooooo1?l0000Gooooo`;o00002Oooool2o`0002;ooooo0_l0000Kooooo`00:oooool2o`00
02;ooooo0_l00003ooooo`;o00002_ooool2o`0001Kooooo0_l0000Kooooo`;o0000:oooool2o`00
00Sooooo0_l0000<ooooo`;o00001oooool2o`0000kooooo0_l00003ooooo`;o00001oooool4o`00
01Oooooo0_l00009ooooo`;o00008_ooool2o`0001_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`0000Kooooo0_l0000Booooo`;o00004oooool2o`0000oo
oooo00KoA4A4o`000?l0003o<S8bomgMgOooool2o`000004oc8b<_l0003o<S8bonk^kPCooooo0_l0
000Hooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`Co000000So410@o`000?l0003ok^k^
oc8b<_l0003o<S8bonk^kP;ooooo1?l000001?lb<S;ok^k^o`000?l0000?ooooo`;o00005Oooool2
o`0000[ooooo1?l000001Ol@413oooooooooooooooooA4A400Go000000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h=ooooo`;o00009?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool01Oooool2o`00
01;ooooo0_l0000Cooooo`;o00004_ooool00omgMgOo<S8booooo`02o`000004oiRHV?ooooooV9RH
ogMgM`Cooooo0_l0000Hooooo`;o00003?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`?o000000?ooooooiRHV?mgMgL00_l0
000?ooooo`;o00005Oooool2o`0000cooooo0_l00007ooooo`?o000000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL=ooooo`;o00009?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o0000
ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo03Sooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000ooooooooool0@_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003Ko
oooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool0<oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000>_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
03Kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100>_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@4100=oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo000[ooooo`;o00000oooool2o`0000Sooooo
0_l0000>ooooo`;o00003_ooool2o`0000kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
000000KoooooogMgMonHV9SooooooiRHV?mgMgL?ooooo`;o00005Oooool2o`000003ooooool0003o
000000Cooooo0_l00005ooooo`?o000000?oooooo`000?ooool00oooool2o`000003oooooonHV9So
MgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`000003ooooool0003o000000Wooooo
0_l0000>ooooo`;o00001?ooool2o`0000oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`?o000000?ooooooiRHV?mgMgL05oooool2o`0000cooooo0_l0000<ooooo`05o`00
0?nj^[[ooooooiRHV?l@41000ol000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`00
00kooooo0_l0000>ooooo`;o00003_ooool2o`000003ooooool0003o000000Co000000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h?ooooo`;o00005Oooool2o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`?o000000?oIVIVo`000?ooool00oooool3o`000003oc8b<_o^k^kooooo00;ooooo00Ko
k^k^oc8b<_l0003o<S8bonk^k_ooool2o`000003ooooool0003o000000Wooooo0_l0000>ooooo`;o
00001?ooool2o`0000gooooo00?oEEEEofIVI_l000001Oooool4o`0000;ooooo1?l000000olb<S;o
k^k^ooooo`0Fooooo`;o00003?ooool2o`0000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003o`00
0005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l00002ooooo`03oa0@4?l0003o000000?o
oooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool01Ol0003oooooonk^k_lb<S;oc<c<00Co
oooo000Toooooooo0000<?l0000<ooooo`04o`000?nHV9So<S8bolc<c0Gooooo000[ooooo`04o`00
0?oooooo0000o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00007ooooo`04
o`000?ooooooooooooooo`;o00002?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo0000
o`0000;ooooo0_l00006ooooo`04o`000?oooooo0000o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo00Oooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`Co00002ooo
ool00ol0003oooooooooo`0;ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`;o000000?o
ooooo`000?l000002_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o00002_oo
ool01?l0003oooooo`000?l00007ooooo`;o000000?oooooo`000?ooool04_ooool00ol0003o410@
oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00Co
0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000ooooooooool0oooooolbooooo`05o`000?oo
ooooA4A4o`000?l@41001?ooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oo
oooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06
ooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2o`00017ooooo0_l0000Loooo
o`;o00000_ooool2o`0000?ooooo0_l0000Hooooo`;o00000oooool2o`0001Sooooo0_l00003oooo
o`Co00009Oooool2o`0000?ooooo0_l0000Cooooo`;o00005?ooool2o`0000;ooooo0_l00005oooo
o`Co00004_ooool2o`0001[ooooo0_l00008ooooo`00:oooool2o`0000oooooo0_l0000Booooo`;o
00004Oooool2o`0001cooooo0_l00002ooooo`;o00000oooool2o`0001Sooooo0_l00003ooooo`;o
00006?ooool2o`0000?ooooo1?l0000Uooooo`;o00000oooool2o`0001?ooooo0_l0000Dooooo`;o
00000_ooool2o`0000Gooooo1?l0000Booooo`;o00009?ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`0;ooooo`;o00002Oooool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o
0000;_ooool2o`00017ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo1Ol0000Xooooo`;o
0000:_ooool2o`000003ooooool0003o000002;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00008oooool002_ooooo0_l0000<ooooo`;o00002Oooool2o`0000gooooo0_l000000ooooooo0000
o`000006ooooo`;o0000;_ooool2o`00017ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo
1Ol0000Xooooo`;o0000:_ooool2o`000003ooooool0003o000002;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00008oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o00000_ooool2o`0001;ooooo0_l0000Hooooo`;o00000_ooool2o`00017ooooo0_l0
000<ooooo`;o00003Oooool2o`0001oooooo0_l0000Iooooo`;o00003Oooool3o`0000[ooooo0_l0
000Uooooo`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00002oooool3o`00017ooooo0_l0
000Mooooo`00:oooool01?l0003oooooooooooooool2o`0001;ooooo0_l0000Hooooo`;o00000_oo
ool2o`00017ooooo0_l0000<ooooo`;o00003Oooool2o`0001oooooo0_l0000Iooooo`;o00003Ooo
ool3o`0000[ooooo0_l0000Uooooo`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00002ooo
ool3o`00017ooooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o00004?ooool2o`0000?ooooo0_l0
000=ooooo`;o00001_ooool2o`0001Gooooo0_l00008ooooo`;o0000Hoooool3o`0005cooooo0_l0
000Xooooo`00:oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000gooooo0_l00006
ooooo`;o00005Oooool2o`0000Sooooo0_l0001Sooooo`?o0000G?ooool2o`0002Sooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
6Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooo
oooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001_ooool3o`0001oooooo0_l0000Gooooo`;o00007oooool2
o`0003Cooooo0_l0000Aooooo`;o00007?ooool2o`0001[ooooo0_l0000/ooooo`;o00001_ooool2
o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o00007oooool2o`0003Cooooo0_l0000A
ooooo`;o00007?ooool2o`0001[ooooo0_l0000/ooooo`;o00001_ooool2o`0002Kooooo000Koooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Ioooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0=_ooool2o`0007_ooooo0_l0000koooo
o`;o0000B?ooool002_ooooo0_l0000gooooo`;o0000Noooool2o`0003_ooooo0_l00018ooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0ol0001@ooooo`;o0000
1?ooool2o`0000Wooooo0_l0001_ooooo`;o0000I_ooool002_ooooo0ol0001@ooooo`;o00001?oo
ool2o`0000Wooooo0_l0001_ooooo`;o0000I_ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0006Gooooo0_l0
003Dooooo`00:oooool00ol0003oooooooooo`1Tooooo`;o0000e?ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0oooooolkooooo`006Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2iooooo`;o0000A_ooool2o`0003Oo
oooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
0000^Oooool2o`0004Kooooo0_l0000gooooo`006oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_o
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooo
oc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003ooooo
odCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403ooooo
odCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<oooo
o`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?o
oooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o
00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo013ooooo0_l000000ol@413oooooooooo`03ooooo`;o000000?o410@oooo
ooooool0oooooolCooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000
omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo
1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolDooooo`001?oo
ool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Co
oooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo0000017ooooo1Ol00003
ooooo`Go0000oooooolEooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413o
k^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo
00Go0000ooooooooooooooooo`000002ooooo`Ko00002Oooool01?m4A4CogMgMooooool00004oooo
o`04odA4A?oMgMgoooooo`000?oooooo5_ooool000Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool0
2OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b
<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Aooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co
gMgMoeEEEOoooooo0000oooooolFooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@
413ooooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool04?ooool00omgMgOoc<c<o`000005ooooo`03ogMgMoo<
c<co00000?oooooo5_ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03;ooooo
00?ok^k^odA4A?l000001Oooool00oo^k^koA4A4o`00003ooooooaKooooo000?ooooo`03okZj^_m4
A4Cooooo00;ooooo00?oZJVYooooooooool0<_ooool00omgMgOo0000ooooo`05ooooo`03ogMgMol0
003ooooo0?oooooo5Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44292 Mdot
.03333 .29872 Mdot
.0381 .36052 Mdot
.04286 .27812 Mdot
.04762 .31932 Mdot
.05238 .25751 Mdot
.05714 .29872 Mdot
.0619 .29872 Mdot
.06667 .31932 Mdot
.07143 .36052 Mdot
.07619 .27812 Mdot
.08095 .31932 Mdot
.08571 .40172 Mdot
.09048 .29872 Mdot
.09524 .23691 Mdot
.1 .40172 Mdot
.10476 .36052 Mdot
.10952 .36052 Mdot
.11429 .21631 Mdot
.11905 .27812 Mdot
.12381 .21631 Mdot
.12857 .27812 Mdot
.13333 .29872 Mdot
.1381 .42232 Mdot
.14286 .23691 Mdot
.14762 .33992 Mdot
.15238 .38112 Mdot
.15714 .36052 Mdot
.1619 .25751 Mdot
.16667 .33992 Mdot
.17143 .21631 Mdot
.17619 .40172 Mdot
.18095 .29872 Mdot
.18571 .25751 Mdot
.19048 .38112 Mdot
.19524 .33992 Mdot
.2 .23691 Mdot
.20476 .38112 Mdot
.20952 .31932 Mdot
.21429 .44292 Mdot
.21905 .42232 Mdot
.22381 .31932 Mdot
.22857 .21631 Mdot
.23333 .29872 Mdot
.2381 .29872 Mdot
.24286 .27812 Mdot
.24762 .29872 Mdot
.25238 .38112 Mdot
.25714 .29872 Mdot
.2619 .27812 Mdot
.26667 .38112 Mdot
.27143 .31932 Mdot
.27619 .21631 Mdot
.28095 .25751 Mdot
.28571 .40172 Mdot
.29048 .29872 Mdot
.29524 .25751 Mdot
.3 .44292 Mdot
.30476 .23691 Mdot
.30952 .33992 Mdot
.31429 .38112 Mdot
.31905 .44292 Mdot
.32381 .31932 Mdot
.32857 .42232 Mdot
.33333 .29872 Mdot
.3381 .33992 Mdot
.34286 .23691 Mdot
.34762 .31932 Mdot
.35238 .33992 Mdot
.35714 .44292 Mdot
.3619 .38112 Mdot
.36667 .48413 Mdot
.37143 .23691 Mdot
.37619 .23691 Mdot
.38095 .25751 Mdot
.38571 .19571 Mdot
.39048 .15451 Mdot
.39524 .23691 Mdot
.4 .23691 Mdot
.40476 .19571 Mdot
.40952 .27812 Mdot
.41429 .36052 Mdot
.41905 .29872 Mdot
.42381 .31932 Mdot
.42857 .27812 Mdot
.43333 .21631 Mdot
.4381 .27812 Mdot
.44286 .33992 Mdot
.44762 .27812 Mdot
.45238 .29872 Mdot
.45714 .36052 Mdot
.4619 .27812 Mdot
.46667 .27812 Mdot
.47143 .38112 Mdot
.47619 .21631 Mdot
.48095 .36052 Mdot
.48571 .27812 Mdot
.49048 .29872 Mdot
.49524 .36052 Mdot
.5 .36052 Mdot
.50476 .36052 Mdot
.50952 .40172 Mdot
.51429 .25751 Mdot
.51905 .25751 Mdot
.52381 .23691 Mdot
.52857 .33992 Mdot
.53333 .27812 Mdot
.5381 .29872 Mdot
.54286 .33992 Mdot
.54762 .27812 Mdot
.55238 .31932 Mdot
.55714 .23691 Mdot
.5619 .36052 Mdot
.56667 .23691 Mdot
.57143 .40172 Mdot
.57619 .21631 Mdot
.58095 .15451 Mdot
.58571 .29872 Mdot
.59048 .25751 Mdot
.59524 .31932 Mdot
.6 .31932 Mdot
.60476 .25751 Mdot
.60952 .38112 Mdot
.61429 .38112 Mdot
.61905 .38112 Mdot
.62381 .40172 Mdot
.62857 .44292 Mdot
.63333 .23691 Mdot
.6381 .27812 Mdot
.64286 .36052 Mdot
.64762 .52533 Mdot
.65238 .38112 Mdot
.65714 .27812 Mdot
.6619 .19571 Mdot
.66667 .27812 Mdot
.67143 .42232 Mdot
.67619 .23691 Mdot
.68095 .31932 Mdot
.68571 .23691 Mdot
.69048 .31932 Mdot
.69524 .33992 Mdot
.7 .19571 Mdot
.70476 .23691 Mdot
.70952 .17511 Mdot
.71429 .27812 Mdot
.71905 .21631 Mdot
.72381 .11331 Mdot
.72857 .46353 Mdot
.73333 .25751 Mdot
.7381 .23691 Mdot
.74286 .27812 Mdot
.74762 .25751 Mdot
.75238 .27812 Mdot
.75714 .29872 Mdot
.7619 .40172 Mdot
.76667 .31932 Mdot
.77143 .21631 Mdot
.77619 .15451 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .36052 Mdot
.79524 .29872 Mdot
.8 .33992 Mdot
.80476 .38112 Mdot
.80952 .19571 Mdot
.81429 .25751 Mdot
.81905 .19571 Mdot
.82381 .23691 Mdot
.82857 .42232 Mdot
.83333 .21631 Mdot
.8381 .33992 Mdot
.84286 .38112 Mdot
.84762 .29872 Mdot
.85238 .31932 Mdot
.85714 .25751 Mdot
.8619 .36052 Mdot
.86667 .23691 Mdot
.87143 .23691 Mdot
.87619 .31932 Mdot
.88095 .33992 Mdot
.88571 .50473 Mdot
.89048 .31932 Mdot
.89524 .27812 Mdot
.9 .17511 Mdot
.90476 .38112 Mdot
.90952 .36052 Mdot
.91429 .42232 Mdot
.91905 .33992 Mdot
.92381 .13391 Mdot
.92857 .36052 Mdot
.93333 .40172 Mdot
.9381 .29872 Mdot
.94286 .42232 Mdot
.94762 .33992 Mdot
.95238 .36052 Mdot
.95714 .27812 Mdot
.9619 .27812 Mdot
.96667 .31932 Mdot
.97143 .36052 Mdot
.97619 .23691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0d?ooool2o`0006Sooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0d?ooool2o`0006Sooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo3_ooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo3_ooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`1[ooooo`;o0000>?ooool2o`0003Wo
oooo0_l0001Hooooo`00:oooool00ol0003oooooooooo`1[ooooo`;o0000>?ooool2o`0003Wooooo
0_l0001Hooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3<ooooo`;o0000>?ooool2o`0003;ooooo000[ooooo`03o`000?oooooooooo0<cooooo0_l0000h
ooooo`;o0000<_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo06[ooooo0_l00004ooooo`;o0000C?ooool2
o`0000Wooooo0_l0000Oooooo`;o000000?oooooo`000?l00000Boooool001Wooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`1Zooooo`;o0000
1?ooool2o`0004cooooo0_l00009ooooo`;o00007oooool2o`000003ooooool0003o000004_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool0013ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o0000oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000000cooooo
0_l0000?ooooo`;o00003Oooool2o`0002gooooo0_l0000;ooooo`;o00007Oooool2o`0002Wooooo
0_l0000>ooooo`;o00004?ooool2o`0004Oooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Sooooo0_l000000ooooooo0000
o`00000<ooooo`;o00003oooool2o`0000gooooo0_l0000]ooooo`;o00002oooool2o`0001gooooo
0_l0000Yooooo`;o00003_ooool2o`00013ooooo0_l00017ooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool04_ooool2o`0000go
oooo0_l0000?ooooo`;o00007_ooool2o`0000Wooooo0_l00007ooooo`?o00001?ooool3o`0002Co
oooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000003ooooo`;o00002Oooool2o`0001Oooooo0_l0000;ooooo`Co00007_ooool2o`0001_o
oooo000[ooooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`;o00003oooool2o`0001kooooo
0_l00009ooooo`;o00001oooool3o`0000Cooooo0ol0000Tooooo`;o00002?ooool2o`000003oooo
ool0003o000001;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo
0_l0000Gooooo`;o00002oooool4o`0001kooooo0_l0000Kooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooo
occooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
1Oooool2o`0001oooooo0_l00006ooooo`;o00006_ooool2o`0000?ooooo0_l0000Hooooo`;o0000
9_ooool3o`0001Cooooo0_l00002ooooo`;o00009Oooool2o`0000;ooooo0_l0000Cooooo`;o0000
2oooool2o`0003oooooo000[ooooo`03o`000?oooooooooo00Gooooo0_l0000Oooooo`;o00001_oo
ool2o`0001[ooooo0_l00003ooooo`;o00006?ooool2o`0002Kooooo0ol0000Dooooo`;o00000_oo
ool2o`0002Gooooo0_l00002ooooo`;o00004oooool2o`0000_ooooo0_l0000oooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l00010ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^03Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03Cooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8b
omgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0<oooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000oooo
ooooool0@_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0=_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo
04?ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
=_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool0<_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo00;ooooo0_l00008oooo
o`;o00002oooool2o`000003ooooool0003o0000027ooooo0_l000001?ooooooMgMgoc8b<_ooool2
o`0000?ooooo00?o0000ooooooooool09?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0ol000001?oooooo0000ooooooooool3o`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`?o00000_ooool2o`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo02?o
oooo0_l0000>ooooo`03oiRHV?lQ8B7ok^k^00Co00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool002_ooooo00?o0000ooooooooool00_ooool2o`0000So
oooo0_l0000;ooooo`;o000000?oooooo`000?l000008Oooool3o`000003oc8b<_o<c<cooooo00;o
00000oooool00ol0003oooooooooo`0Tooooo`;o00001?ooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool3o`000004ooooool0003oooooooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo0ol00002ooooo`;o00006Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000<ooooo`;o00001?ooool00ol0003o8B4Qo`000002o`000003ooooool0003o000000?ooooo00?o
0000ooooooooool08oooool2o`0000oooooo00?oMgMgofIVI_l000000ol00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00010ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0c
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`0oooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`03oeEEEOmVIVKo
000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool01?l0003ooooo
o`000?l00006ooooo`?o00001oooool2o`0000_ooooo0_l0000<ooooo`;o00003_ooool3o`000004
ooooool0003o0000ooooo`;o00002?ooool2o`0000_ooooo0_l0000Hooooo`;o00002?ooool2o`00
00[ooooo0_l0000<ooooo`;o00003?ooool2o`0003;ooooo0_l0000:ooooo`;o00003_ooool2o`00
01Wooooo0_l0000Wooooo`00:oooool01?l0003oooooo`000?l00006ooooo`?o00001oooool2o`00
00_ooooo0_l0000<ooooo`;o00003_ooool3o`000004ooooool0003o0000ooooo`;o00002?ooool2
o`0000_ooooo0_l0000Hooooo`;o00002?ooool2o`0000[ooooo0_l0000<ooooo`;o00003?ooool2
o`0003;ooooo0_l0000:ooooo`;o00003_ooool2o`0001Wooooo0_l0000Mooooo`;o00000_ooool0
0ol@413o0000o`000003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000oooo
ooo^k^ko<S8bolc<c004ooooo`009?ooooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5
ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04Oooool00ol0003o410@oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo0_l00002ooooo`;o00009Oooool2o`0000;ooooo0_l0000<ooooo`;o
00003_ooool2o`0000Gooooo0_l0000Fooooo`;o00009?ooool2o`0000_ooooo1?l0000Fooooo`;o
000000?oooooo`000?l000005Oooool2o`0000Cooooo0_l0000Booooo`;o00001Oooool2o`0000?o
oooo0_l0000Eooooo`;o00005Oooool01Ol0003oooooodA4A?l0003o410@00Cooooo000[ooooo`03
o`000?oooooooooo00Cooooo0_l00004ooooo`;o00000_ooool2o`0002Gooooo0_l00002ooooo`;o
00003?ooool2o`0000kooooo0_l00005ooooo`;o00005_ooool2o`0002Cooooo0_l0000;ooooo`Co
00005_ooool2o`000003ooooool0003o000001Gooooo0_l00004ooooo`;o00004_ooool2o`0000Go
oooo0_l00003ooooo`;o00005Oooool2o`0001Gooooo00?o0000ooooooooool01_ooool002_ooooo
00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oo
oooooooo0?oooooo<Oooool2o`0000Sooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo02;ooooo0_l00004ooooo`;o
00001_ooool2o`00027ooooo0_l00007ooooo`;o00000_ooool2o`0001Wooooo0_l0000Hooooo`;o
00000oooool2o`0002cooooo0_l0000Mooooo`;o00002_ooool2o`0000_ooooo0_l00009ooooo`;o
00001oooool2o`0002Cooooo000[ooooo`03o`000?oooooooooo02;ooooo0_l00004ooooo`;o0000
1_ooool2o`00027ooooo0_l00007ooooo`;o00000_ooool2o`0001Wooooo0_l0000Hooooo`;o0000
0oooool2o`0002cooooo0_l0000Mooooo`;o00002_ooool2o`0000_ooooo0_l00009ooooo`;o0000
1oooool2o`0002Cooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`04o`000?oo
ooooooooooooo`;o00002?ooool2o`0000Sooooo0ol0000=ooooo`;o0000C?ooool2o`0000_ooooo
0_l00005ooooo`;o00000_ooool5o`0000oooooo0_l0000Gooooo`;o0000:_ooool2o`0001Cooooo
0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00007Oooool002_ooooo00Co
0000oooooooooooooooo0_l00008ooooo`;o00002?ooool3o`0000gooooo0_l0001<ooooo`;o0000
2oooool2o`0000Gooooo0_l00002ooooo`Go00003oooool2o`0001Oooooo0_l0000Zooooo`;o0000
5?ooool2o`0000cooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0000Mooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool08oooool2o`0000[ooooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo
0_l0000<ooooo`;o00003Oooool2o`0001oooooo0_l0000Xooooo`Go00002?ooool2o`0002Gooooo
0_l00005ooooo`;o00002Oooool2o`00017ooooo0_l0000aooooo`00:oooool00ol0003ooooooooo
o`0Sooooo`;o00002_ooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0000cooooo0_l0
000=ooooo`;o00007oooool2o`0002Sooooo1Ol00008ooooo`;o00009Oooool2o`0000Gooooo0_l0
0009ooooo`;o00004Oooool2o`00037ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0?ooooo`;o00000ooo
ool2o`0001Gooooo0_l0000Oooooo`;o0000@Oooool2o`00017ooooo0_l0000>ooooo`;o0000:?oo
ool2o`0003;ooooo0_l0000Xooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h6ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`;o00005Oooool2o`0001oo
oooo0_l00011ooooo`;o00004Oooool2o`0000kooooo0_l0000Xooooo`;o0000<_ooool2o`0002So
oooo000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo0ol0003ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`0Oooooo`;o00005oooool2o`0001oooooo0_l0001Uooooo`;o
0000;_ooool2o`0001Sooooo0_l00006ooooo`;o00009_ooool001_ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool07oooool2o`0001Oo
oooo0_l0000Oooooo`;o0000IOooool2o`0002kooooo0_l0000Hooooo`;o00001_ooool2o`0002Ko
oooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000=_ooool2o`0001Sooooo0_l00004ooooo`;o
00002Oooool2o`00053ooooo0_l00025ooooo`00:oooool3o`0003Kooooo0_l0000Hooooo`;o0000
1?ooool2o`0000Wooooo0_l0001@ooooo`;o0000QOooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0=;ooooo
0_l0001Vooooo`00:oooool00ol0003oooooooooo`3Booooo`;o0000I_ooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo06Cooooo0_l0003Dooooo`00:oooool00ol0003oooooooooo`1Tooooo`;o0000e?ooool0
02_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0003Oooooo000Hooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooool2ooooo`;o0000=oooool0
01Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000K
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?oooooo>oooool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0^Oooool2o`0007oooooo000Hooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
^Oooool2o`0007oooooo000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0
003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo
0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_oo
ool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo00?o
QhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo013ooooo
0_l000000ol@413oooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd0oooooolDooooo`00
0oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4
A4@3ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<
o`000?l@41003?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0oooooolCooooo`001?ooool01?oMgMgo0000oa0@4?o<
c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413o
c<c<4_ooool01Ol0003ooooooooooooooooo0000017ooooo1Ol00008ooooo`03o`000?oooooooooo
0?oooooo4_ooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02oooo
o`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?oo
ooooooooooooool000000_ooool6o`0000Wooooo00CoA4A4omgMgOoooooo00002?ooool00omgMgOo
<S8booooo`3ooooooa?ooooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?oo
ooooooooonk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`00
0?n7QhOoooooojVYZOl000004Oooool01?oMgMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`0oooooolDooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo
00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg
00;o000000?oV9RHooooooooool04?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo
0?oooooo5_ooool000oooooo00OoEEEEoiRHV?ooooooooooomgMgOl0003ogMgM03;ooooo00?ok^k^
odA4A?l000001Oooool00ol0003oooooooooo`3ooooooaKooooo000?ooooo`03okZj^_m4A4Cooooo
00;ooooo00?oZJVYooooooooool0<_ooool00omgMgOo0000ooooo`04ooooo`Co0000oooooolEoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .43262 Mdot
.03333 .30902 Mdot
.0381 .35022 Mdot
.04286 .28842 Mdot
.04762 .30902 Mdot
.05238 .24721 Mdot
.05714 .28842 Mdot
.0619 .30902 Mdot
.06667 .30902 Mdot
.07143 .37082 Mdot
.07619 .26781 Mdot
.08095 .32962 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .24721 Mdot
.1 .39142 Mdot
.10476 .35022 Mdot
.10952 .35022 Mdot
.11429 .20601 Mdot
.11905 .26781 Mdot
.12381 .22661 Mdot
.12857 .26781 Mdot
.13333 .30902 Mdot
.1381 .41202 Mdot
.14286 .22661 Mdot
.14762 .35022 Mdot
.15238 .37082 Mdot
.15714 .35022 Mdot
.1619 .26781 Mdot
.16667 .35022 Mdot
.17143 .22661 Mdot
.17619 .41202 Mdot
.18095 .28842 Mdot
.18571 .26781 Mdot
.19048 .39142 Mdot
.19524 .35022 Mdot
.2 .22661 Mdot
.20476 .39142 Mdot
.20952 .32962 Mdot
.21429 .45322 Mdot
.21905 .41202 Mdot
.22381 .32962 Mdot
.22857 .22661 Mdot
.23333 .28842 Mdot
.2381 .30902 Mdot
.24286 .28842 Mdot
.24762 .30902 Mdot
.25238 .39142 Mdot
.25714 .28842 Mdot
.2619 .28842 Mdot
.26667 .37082 Mdot
.27143 .32962 Mdot
.27619 .20601 Mdot
.28095 .26781 Mdot
.28571 .41202 Mdot
.29048 .30902 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .24721 Mdot
.30952 .35022 Mdot
.31429 .39142 Mdot
.31905 .43262 Mdot
.32381 .30902 Mdot
.32857 .41202 Mdot
.33333 .28842 Mdot
.3381 .32962 Mdot
.34286 .22661 Mdot
.34762 .30902 Mdot
.35238 .35022 Mdot
.35714 .43262 Mdot
.3619 .37082 Mdot
.36667 .49443 Mdot
.37143 .24721 Mdot
.37619 .22661 Mdot
.38095 .26781 Mdot
.38571 .20601 Mdot
.39048 .14421 Mdot
.39524 .24721 Mdot
.4 .24721 Mdot
.40476 .18541 Mdot
.40952 .28842 Mdot
.41429 .37082 Mdot
.41905 .28842 Mdot
.42381 .32962 Mdot
.42857 .28842 Mdot
.43333 .22661 Mdot
.4381 .26781 Mdot
.44286 .35022 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .35022 Mdot
.4619 .26781 Mdot
.46667 .26781 Mdot
.47143 .37082 Mdot
.47619 .22661 Mdot
.48095 .37082 Mdot
.48571 .26781 Mdot
.49048 .30902 Mdot
.49524 .35022 Mdot
.5 .37082 Mdot
.50476 .37082 Mdot
.50952 .41202 Mdot
.51429 .24721 Mdot
.51905 .24721 Mdot
.52381 .24721 Mdot
.52857 .32962 Mdot
.53333 .28842 Mdot
.5381 .30902 Mdot
.54286 .35022 Mdot
.54762 .28842 Mdot
.55238 .30902 Mdot
.55714 .22661 Mdot
.5619 .35022 Mdot
.56667 .24721 Mdot
.57143 .39142 Mdot
.57619 .22661 Mdot
.58095 .16481 Mdot
.58571 .28842 Mdot
.59048 .26781 Mdot
.59524 .32962 Mdot
.6 .30902 Mdot
.60476 .26781 Mdot
.60952 .37082 Mdot
.61429 .39142 Mdot
.61905 .37082 Mdot
.62381 .39142 Mdot
.62857 .43262 Mdot
.63333 .22661 Mdot
.6381 .26781 Mdot
.64286 .37082 Mdot
.64762 .53563 Mdot
.65238 .37082 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .26781 Mdot
.67143 .43262 Mdot
.67619 .24721 Mdot
.68095 .30902 Mdot
.68571 .22661 Mdot
.69048 .30902 Mdot
.69524 .35022 Mdot
.7 .18541 Mdot
.70476 .22661 Mdot
.70952 .16481 Mdot
.71429 .26781 Mdot
.71905 .22661 Mdot
.72381 .12361 Mdot
.72857 .45322 Mdot
.73333 .24721 Mdot
.7381 .22661 Mdot
.74286 .26781 Mdot
.74762 .24721 Mdot
.75238 .28842 Mdot
.75714 .30902 Mdot
.7619 .41202 Mdot
.76667 .30902 Mdot
.77143 .22661 Mdot
.77619 .14421 Mdot
.78095 .37082 Mdot
.78571 .30902 Mdot
.79048 .37082 Mdot
.79524 .28842 Mdot
.8 .32962 Mdot
.80476 .37082 Mdot
.80952 .20601 Mdot
.81429 .24721 Mdot
.81905 .18541 Mdot
.82381 .22661 Mdot
.82857 .41202 Mdot
.83333 .22661 Mdot
.8381 .35022 Mdot
.84286 .37082 Mdot
.84762 .28842 Mdot
.85238 .32962 Mdot
.85714 .26781 Mdot
.8619 .37082 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .30902 Mdot
.88095 .35022 Mdot
.88571 .51503 Mdot
.89048 .32962 Mdot
.89524 .26781 Mdot
.9 .18541 Mdot
.90476 .39142 Mdot
.90952 .37082 Mdot
.91429 .43262 Mdot
.91905 .32962 Mdot
.92381 .14421 Mdot
.92857 .37082 Mdot
.93333 .41202 Mdot
.9381 .30902 Mdot
.94286 .41202 Mdot
.94762 .35022 Mdot
.95238 .37082 Mdot
.95714 .26781 Mdot
.9619 .26781 Mdot
.96667 .30902 Mdot
.97143 .37082 Mdot
.97619 .22661 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`;o0000dOooool2o`0006Sooooo000[ooooo`03o`000?oo
oooooooo0=3ooooo0_l0001Xooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo06_ooooo0_l0
001cooooo`;o0000:oooool2o`0002_ooooo000[ooooo`;o0000K?ooool2o`0007?ooooo0_l0000[
ooooo`;o0000:oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`2Uooooo`;o00009Oooool2
o`0006cooooo000[ooooo`;o0000Y_ooool2o`0002Gooooo0_l0001/ooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0001aooooo`;o0000Eoooool2o`0002;o
oooo0_l0000Gooooo`;o0000<_ooool002_ooooo00?o0000ooooooooool0L?ooool2o`0005Oooooo
0_l0000Rooooo`;o00005oooool2o`0003;ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0ol0000Hooooo`;o0000;oooool2o`0001oooooo0_l0001Booooo`;o0000
:_ooool2o`0004kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo01Sooooo0_l0000_ooooo`;o00007oooool2o`0005;ooooo
0_l0000Zooooo`;o0000C_ooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0001cooooo0_l0
0004ooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`;o00008Oooool2o`0000Sooooo0_l0
000?ooooo`;o00002oooool2o`0001Oooooo0_l00004ooooo`;o00003oooool2o`0000kooooo0_l0
0003ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool2o`000003ooooool0
003o000000[ooooo0_l0000Nooooo`;o00006oooool002_ooooo00?o0000ooooooooool06oooool2
o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l0000Qooooo`;o00002?ooool2
o`0000oooooo0_l0000;ooooo`;o00005oooool2o`0000Cooooo0_l0000?ooooo`;o00003_ooool2
o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0001kooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo00Gooooo0_l0000;ooooo`;o0000?_ooool2o`0001;ooooo0_l00005ooooo`?o00008Oooool5
o`0000_ooooo0_l0000Oooooo`;o00003oooool2o`0000;ooooo0_l0000Cooooo`;o00003Oooool2
o`0003gooooo000[ooooo`;o00001_ooool2o`0000_ooooo0_l0000nooooo`;o00004_ooool2o`00
00Gooooo0ol0000Qooooo`Go00002oooool2o`0001oooooo0_l0000?ooooo`;o00000_ooool2o`00
01?ooooo0_l0000=ooooo`;o0000?Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001_ooool2o`0000oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`04onk^k_lb<S;o0000
oc8b<P;o00000oooool2o`0001Sooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool6
o`000008oa0@4?l0003o0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04Oooool2o`0000;ooooo0_l00008ooooo`;o00001oooool2o`0000[ooooo1?l000001Ol@
413oooooooooooooooooA4A400Co00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo0_l0
0009ooooo`;o00003?ooool8o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Kooooo0_l0000Booooo`08ogMgMolb<S;ooooooooooomg
MgOoV9RHoooooonHV9P2o`0000?ooooo0_l0000Hooooo`;o00003oooool2o`000003ooooool0003o
000000;ooooo0ol000001?oooooo0000ooooooooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0_l00002ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000<ooooo`;o00001oooool2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Joooo
o`;o00002Oooool2o`0000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003o`000005ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oo
oooooooo04?ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0hooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100=_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool0<_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo04;ooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000foooo
o`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooo
oooo03?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000f
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool00000=_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000001?ooooo000[ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`00:oooool2o`0000?ooooo0_l00003ooooo`;o
00008oooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`Co000000CoV9RHoooooonH
V9SoMgMg3oooool2o`0001Gooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02o`0000;ooooo0_l00009ooooo`;o00005?ooool2o`0000oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`;o000000CoV9RHoooooonHV9SoMgMg1oooool2o`0000ko
oooo0_l0000Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`02
ooooo`;o00000oooool2o`0002?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001_l00000
1?lb<S;o0000oc8b<_o^k^h?ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o0000
2_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;o00000_ooool2o`0000Wooooo0_l0000Dooooo`;o00003Oooool00omE
EEGoIVIVo`000005ooooo`Co00000_ooool2o`000004oc8b<_l0003o<S8bonk^kPOooooo0_l0000>
ooooo`;o00006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo<Oooool2o`0000;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000oooo
ooooool0oooooolbooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`00
00cooooo00Co0000oiRHV?lb<S;oc<c<1Oooool002_ooooo00Co0000ooooool0003o00000oooool2
o`0000;ooooo1Ol00004ooooo`;o00001oooool01?l0003oooooooooooooool2o`0000Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?l000000ooo
ool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`02o`0000Gooooo0_l0
0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l0
00000ooooooo0000ooooo`09ooooo`;o00000_ooool2o`0000cooooo0ol0000;ooooo`03o`000?oo
oooooooo00Sooooo0_l000000ooooooo0000o`00000=ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003Oooool00ol0003oooooooooo`09ooooo`?o00003_oo
ool01?l0003oooooo`000?l00007ooooo`;o000000?oooooo`000?ooool04_ooool00ol0003o410@
oiRHV006ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00Co
0000onk^k_mEEEGoQhN71Oooool002_ooooo00?o0000ooooooooool0oooooolbooooo`05o`000?oo
ooooA4A4o`000?l@41001?ooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oo
oooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06
ooooo`00:oooool00ol0003oooooooooo`0>ooooo`;o00009Oooool2o`0000;ooooo0_l0000<oooo
o`;o00004oooool2o`0001Sooooo0_l0000Mooooo`;o00004_ooool2o`0003cooooo0_l0000>oooo
o`;o00002_ooool2o`0000Kooooo0_l0000Sooooo`;o00002?ooool002_ooooo0_l0000?ooooo`;o
00009Oooool2o`0000;ooooo0_l0000<ooooo`;o00004oooool2o`0001Sooooo0_l0000Mooooo`;o
00004_ooool2o`0003cooooo0_l0000>ooooo`;o00002_ooool2o`0000Kooooo0_l0000]ooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`04o`000?ooooooooooooooo`;o00004_ooool3o`0000[ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Kooooo0_l0000Qooooo`;o00002oooool2o`0001Wooooo0_l00003
ooooo`;o00002Oooool2o`0000gooooo0_l00003ooooo`;o00009oooool2o`0002Wooooo0_l0000;
ooooo`;o00004_ooool2o`0002Cooooo000[ooooo`;o00000_ooool2o`0001;ooooo0ol0000:oooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00008Oooool2o`0000_ooooo0_l0000I
ooooo`;o00000oooool2o`0000Wooooo0_l0000=ooooo`;o00000oooool2o`0002Oooooo0_l0000Y
ooooo`;o00002oooool2o`0001;ooooo0_l0000Tooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0000<ooooo`;o00005_ooool2o`00027ooooo0_l0000Koooo
o`;o00003_ooool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`?o00007_ooool2o`00
0003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000Uooooo`Co00000oooool2o`00
00Wooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`00
01gooooo000[ooooo`03o`000?oooooooooo00_ooooo0_l0000Fooooo`;o00008Oooool2o`0001_o
oooo0_l0000>ooooo`;o00003oooool2o`000003ooooool0003o000000Cooooo0ol0000Nooooo`;o
000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000002Gooooo1?l00003ooooo`;o
00002Oooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o
00007Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00013ooooo0_l00003ooooo`;o00006Oooool2o`0000;o
oooo0_l0000=ooooo`;o00004?ooool2o`0004cooooo0_l0000;ooooo`;o000000?oooooo`000?l0
0000Doooool2o`00037ooooo000[ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`;o0000
6Oooool2o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`0004cooooo0_l0000;ooooo`;o0000
00?oooooo`000?l00000Doooool2o`00037ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`0001oooooo0_l0000:ooooo`;o00002oooool2o`0001;ooooo0_l0000;ooooo`;o0000
=?ooool2o`0004_ooooo0_l0000Booooo`;o00007_ooool4o`0002Kooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01oooooo
0_l0000:ooooo`;o00002oooool2o`0001;ooooo0_l0000;ooooo`;o0000=?ooool2o`0004_ooooo
0_l0000Booooo`;o00007_ooool4o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0ol0
001Fooooo`;o00002Oooool2o`00053ooooo0_l0000;ooooo`;o0000B?ooool2o`0002kooooo000[
ooooo`?o0000E_ooool2o`0000Wooooo0_l0001@ooooo`;o00002oooool2o`0004Sooooo0_l0000^
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0000goooo
o`;o00006?ooool2o`00083ooooo0_l0001Vooooo`00:oooool00ol0003oooooooooo`0fooooo`;o
00006?ooool2o`00083ooooo0_l0001Vooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0001Uooooo`;o0000
e?ooool002_ooooo00?o0000ooooooooool0I?ooool2o`000=Cooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001So
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0003Oooooo000Joooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000ooooool2
ooooo`;o0000=oooool001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0oooooolkooooo`007?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc_ooooo000Hoooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000;[ooooo0_l0001oooooo`00:oooool00ol0
003oooooooooo`2iooooo`;o0000Ooooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000oc8b
<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolk
ooooo`006?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolkooooo`006oooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo>ooo
ool001[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo00000?ooooooA?oo
ool001_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@0?ooooooA?oo
ool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
oooooom4ooooo`006?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP3oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo000Rooooo`03o`000?nj^[[ooooo0?ooooooA?ooool000cooooo00?o
8B4QomgMgOooool04oooool2oc8b<_ooooooAOooool000?ooooo0_l00002ooooo`;o00000oooool0
0onHV9SoEEEEooooo`02ooooo`03oc8b<_l0003o000000?o000000?o<S8booooooooool00_l00002
ooooo`;o00000_ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool04?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?l@413oc<c<
0?oooooo5Oooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`06o`000?oMgMgo
oooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40oooooolEooooo`00
1?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0oooool01Ol@413ogMgMoooooooMgMgo410@
00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003ooooooooooooooooo0000017ooooo1Ol0
0003ooooo`05o`000?ooooooooooooooool00000oooooolEooooo`001?ooool01?o^k^ko8B4Qoa0@
4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`04
onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002Oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?nHV9SooooooiRHV?lQ8B40oooooolEooooo`001?oo
ool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Soooooooooooo^k^ko410@onk^k_l@413o
k^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003oQhN7oooooonYZJWo0000017ooooo
00CogMgMoeEEEOoooooo00001?ooool01Ol0003oEEEEo`000?l@413oc<c<0?oooooo5Oooool000?o
oooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Co
oooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo013o
oooo00?oMgMgolc<c?l000001?ooool00omEEEGoQhN7ooooo`3ooooooaOooooo000?ooooo`07oeEE
EOnHV9SooooooooooooMgMgo0000omgMg@0booooo`03onk^k_m4A4Co000000Cooooo00?ogMgMoa0@
4?nHV9P0oooooolGooooo`003oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo03;o
oooo00?oMgMgo`000?ooool01?ooool01?o<c<coA4A4o`000?l@413ooooooaGooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44292 Mdot
.03333 .29872 Mdot
.0381 .36052 Mdot
.04286 .27812 Mdot
.04762 .29872 Mdot
.05238 .25751 Mdot
.05714 .29872 Mdot
.0619 .29872 Mdot
.06667 .31932 Mdot
.07143 .36052 Mdot
.07619 .27812 Mdot
.08095 .33992 Mdot
.08571 .40172 Mdot
.09048 .31932 Mdot
.09524 .25751 Mdot
.1 .38112 Mdot
.10476 .36052 Mdot
.10952 .36052 Mdot
.11429 .21631 Mdot
.11905 .25751 Mdot
.12381 .23691 Mdot
.12857 .27812 Mdot
.13333 .29872 Mdot
.1381 .40172 Mdot
.14286 .21631 Mdot
.14762 .33992 Mdot
.15238 .36052 Mdot
.15714 .36052 Mdot
.1619 .27812 Mdot
.16667 .36052 Mdot
.17143 .23691 Mdot
.17619 .40172 Mdot
.18095 .27812 Mdot
.18571 .25751 Mdot
.19048 .38112 Mdot
.19524 .33992 Mdot
.2 .23691 Mdot
.20476 .40172 Mdot
.20952 .33992 Mdot
.21429 .44292 Mdot
.21905 .42232 Mdot
.22381 .31932 Mdot
.22857 .21631 Mdot
.23333 .29872 Mdot
.2381 .31932 Mdot
.24286 .29872 Mdot
.24762 .29872 Mdot
.25238 .38112 Mdot
.25714 .27812 Mdot
.2619 .29872 Mdot
.26667 .36052 Mdot
.27143 .33992 Mdot
.27619 .19571 Mdot
.28095 .27812 Mdot
.28571 .40172 Mdot
.29048 .31932 Mdot
.29524 .25751 Mdot
.3 .44292 Mdot
.30476 .23691 Mdot
.30952 .33992 Mdot
.31429 .38112 Mdot
.31905 .44292 Mdot
.32381 .29872 Mdot
.32857 .42232 Mdot
.33333 .27812 Mdot
.3381 .31932 Mdot
.34286 .23691 Mdot
.34762 .31932 Mdot
.35238 .33992 Mdot
.35714 .42232 Mdot
.3619 .36052 Mdot
.36667 .50473 Mdot
.37143 .23691 Mdot
.37619 .21631 Mdot
.38095 .25751 Mdot
.38571 .21631 Mdot
.39048 .15451 Mdot
.39524 .25751 Mdot
.4 .23691 Mdot
.40476 .19571 Mdot
.40952 .27812 Mdot
.41429 .38112 Mdot
.41905 .29872 Mdot
.42381 .33992 Mdot
.42857 .27812 Mdot
.43333 .21631 Mdot
.4381 .27812 Mdot
.44286 .33992 Mdot
.44762 .25751 Mdot
.45238 .29872 Mdot
.45714 .36052 Mdot
.4619 .25751 Mdot
.46667 .27812 Mdot
.47143 .38112 Mdot
.47619 .23691 Mdot
.48095 .36052 Mdot
.48571 .25751 Mdot
.49048 .31932 Mdot
.49524 .33992 Mdot
.5 .38112 Mdot
.50476 .36052 Mdot
.50952 .42232 Mdot
.51429 .25751 Mdot
.51905 .25751 Mdot
.52381 .25751 Mdot
.52857 .33992 Mdot
.53333 .27812 Mdot
.5381 .29872 Mdot
.54286 .33992 Mdot
.54762 .29872 Mdot
.55238 .29872 Mdot
.55714 .23691 Mdot
.5619 .36052 Mdot
.56667 .25751 Mdot
.57143 .40172 Mdot
.57619 .21631 Mdot
.58095 .17511 Mdot
.58571 .29872 Mdot
.59048 .27812 Mdot
.59524 .31932 Mdot
.6 .31932 Mdot
.60476 .27812 Mdot
.60952 .36052 Mdot
.61429 .40172 Mdot
.61905 .38112 Mdot
.62381 .40172 Mdot
.62857 .42232 Mdot
.63333 .21631 Mdot
.6381 .25751 Mdot
.64286 .36052 Mdot
.64762 .52533 Mdot
.65238 .36052 Mdot
.65714 .29872 Mdot
.6619 .21631 Mdot
.66667 .27812 Mdot
.67143 .44292 Mdot
.67619 .25751 Mdot
.68095 .29872 Mdot
.68571 .23691 Mdot
.69048 .29872 Mdot
.69524 .36052 Mdot
.7 .17511 Mdot
.70476 .21631 Mdot
.70952 .15451 Mdot
.71429 .27812 Mdot
.71905 .23691 Mdot
.72381 .11331 Mdot
.72857 .44292 Mdot
.73333 .25751 Mdot
.7381 .21631 Mdot
.74286 .27812 Mdot
.74762 .25751 Mdot
.75238 .29872 Mdot
.75714 .31932 Mdot
.7619 .40172 Mdot
.76667 .31932 Mdot
.77143 .23691 Mdot
.77619 .13391 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .38112 Mdot
.79524 .29872 Mdot
.8 .31932 Mdot
.80476 .36052 Mdot
.80952 .21631 Mdot
.81429 .23691 Mdot
.81905 .19571 Mdot
.82381 .21631 Mdot
.82857 .42232 Mdot
.83333 .23691 Mdot
.8381 .36052 Mdot
.84286 .36052 Mdot
.84762 .27812 Mdot
.85238 .33992 Mdot
.85714 .27812 Mdot
.8619 .38112 Mdot
.86667 .25751 Mdot
.87143 .21631 Mdot
.87619 .31932 Mdot
.88095 .33992 Mdot
.88571 .52533 Mdot
.89048 .33992 Mdot
.89524 .27812 Mdot
.9 .17511 Mdot
.90476 .38112 Mdot
.90952 .38112 Mdot
.91429 .42232 Mdot
.91905 .31932 Mdot
.92381 .15451 Mdot
.92857 .38112 Mdot
.93333 .42232 Mdot
.9381 .31932 Mdot
.94286 .42232 Mdot
.94762 .36052 Mdot
.95238 .38112 Mdot
.95714 .25751 Mdot
.9619 .27812 Mdot
.96667 .29872 Mdot
.97143 .38112 Mdot
.97619 .23691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0d?ooool2o`0006Sooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0d?ooool2o`0006Sooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0>3ooooo0_l0001Hooooo`00:oooool00ol0003oooooooooo`3Pooooo`;o
0000F?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo06_ooooo0_l0001Oooooo`;o0000?oooool2o`0002_o
oooo000[ooooo`03o`000?oooooooooo06_ooooo0_l0001Oooooo`;o0000?oooool2o`0002_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0:Gooooo0_l0
000Rooooo`;o0000>oooool2o`0003;ooooo000[ooooo`03o`000?oooooooooo0:Gooooo0_l0000R
ooooo`;o0000>oooool2o`0003;ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`19ooooo`;o00009Oooool2
o`0007_ooooo0_l0001;ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo04Wooooo0_l0000Uooooo`;o0000Noooool2o`0004_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?oooooo>oooool0013ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o0000oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0000Gooooo`;o0000
:oooool2o`000003ooooool0003o000000cooooo0_l0000Zooooo`;o00003oooool2o`0000Oooooo
0_l0000:ooooo`;o00002Oooool2o`0001?ooooo0_l00002ooooo`;o00003Oooool2o`0003_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo01Sooooo0_l00007ooooo`;o00005oooool2o`0002_ooooo0_l000000ooooooo0000
o`00000<ooooo`;o0000:_ooool2o`0000oooooo0_l00007ooooo`;o00002_ooool2o`0000Wooooo
0_l0000Cooooo`;o00000_ooool2o`0000gooooo0_l0000kooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool06oooool2o`0000co
oooo0_l00007ooooo`;o00007_ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0001Go
oooo0_l0000Gooooo`;o00009Oooool2o`0000Sooooo0_l0000>ooooo`;o00002oooool2o`0000?o
oooo0_l0000Zooooo`;o00006oooool002_ooooo00?o0000ooooooooool06oooool2o`0000cooooo
0_l00007ooooo`;o00007_ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0001Gooooo
0_l0000Gooooo`;o00009Oooool2o`0000Sooooo0_l0000>ooooo`;o00002oooool2o`0000?ooooo
0_l0000Zooooo`;o00006oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`;o0000
1Oooool2o`0001?ooooo0_l0000Oooooo`;o00006?ooool2o`0000;ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Gooooo0_l00007ooooo`Go00002oooool2o`0001?ooooo0_l0000:ooooo`;o0000
3oooool2o`0000;ooooo0_l0000Rooooo`;o00006_ooool2o`00027ooooo000[ooooo`03o`000?oo
oooooooo00Gooooo0_l0000;ooooo`;o00001Oooool2o`0001?ooooo0_l0000Oooooo`;o00006?oo
ool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`Go00002ooo
ool2o`0001?ooooo0_l0000:ooooo`;o00003oooool2o`0000;ooooo0_l0000Rooooo`;o00006_oo
ool2o`00027ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`00043ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0>?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP0cooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0C
ooooo`00:oooool00ol0003oooooooooo`12ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0<oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
02_ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400fooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004oooool002_ooooo00?o0000oooo
ooooool00_ooool2o`0000Sooooo0_l0000>ooooo`;o00002?ooool2o`0000Cooooo0_l0000Doooo
o`05ogMgMol0003o0000ooooool000000oooool2o`0000kooooo0_l0000Eooooo`;o00001?ooool2
o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000ooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooooooool3o`0000oooooo0_l00002ooooo`;o0000
4Oooool2o`0000cooooo0_l00007ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000001Oo
oooo0_l000000ooooooo0000o`000009ooooo`;o00003_ooool01?nHV9So8B4Qonk^k_ooool3o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo000[oooo
o`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00003_ooool2o`0000Sooooo0_l00004oooo
o`;o00004Oooool01?l0003o8B4Qo`000?lb<S82o`000003ooooool0003ooooo00;ooooo0_l0000>
ooooo`;o00005Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?ooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo
0ol0000?ooooo`;o00000_ooool2o`00017ooooo0_l0000<ooooo`;o00001?ooool00ol0003o8B4Q
o`000002o`0000;ooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000oooooo00?oMgMgofIVI_ooool00ol00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00010ooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`0oooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0dooooo`03oeEEEOmVIVKo000000Gooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool01?l0003oooooo`000?l00003
ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`0001cooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00004?ooool2o`0001_ooooo0_l00008ooooo`;o00006?ooool2o`000004oooo
ool0003o0000o`0000Sooooo0_l0000Dooooo`;o00001Oooool2o`000003ooooool0003o0000017o
oooo0_l0000;ooooo`;o0000<_ooool2o`0001kooooo000[ooooo`04o`000?oooooo0000o`0000?o
oooo0_l000001?oooooo0000o`000?l0000Dooooo`;o00007?ooool2o`000004ooooool0003o0000
o`0000?ooooo0_l0000@ooooo`;o00006oooool2o`0000Sooooo0_l0000Hooooo`;o000000Cooooo
o`000?l0003o00002?ooool2o`0001Cooooo0_l00005ooooo`;o000000?oooooo`000?l000004Ooo
ool2o`0000_ooooo0_l0000booooo`;o00005?ooool2o`0000;ooooo00?o410@o`000?l000000ooo
ool002_ooooo00?o0000ooooooooool0oooooolbooooo`05o`000?ooooook^k^oc8b<_o<c<`01?oo
ool002Coooooool0000`o`0000cooooo00Co0000oiRHV?lb<S;oc<c<1Oooool002_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000
oa0@4?nHV9P01_ooool002_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aoooo
o`04o`000?o^k^koEEEEohN7Q`Gooooo000[ooooo`03o`000?oooooooooo00[ooooo0_l00005oooo
o`;o00009_ooool2o`0000;ooooo0_l0000>ooooo`;o00003Oooool4o`0002[ooooo0_l0000Moooo
o`Co0000;Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00005Oooool2o`00
00_ooooo0_l00004ooooo`;o00007_ooool01Ol0003oooooodA4A?l0003o410@00Cooooo000[oooo
o`03o`000?oooooooooo00[ooooo0_l00005ooooo`;o00009_ooool2o`0000;ooooo0_l0000>oooo
o`;o00003Oooool4o`0002[ooooo0_l0000Mooooo`Co0000;Oooool2o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`;o00005Oooool2o`0000_ooooo0_l00004ooooo`;o00007_ooool00ol0
003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000oooooooo
ool01_ooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o00002?ooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool03_ooool2o`0001;ooooo0_l0000<ooooo`;o00000oooool2o`00013ooooo0_l0000:oooo
o`;o00002oooool2o`0001Cooooo0_l00003ooooo`;o00003_ooool2o`0000Sooooo0_l00003oooo
o`;o0000Foooool2o`0000Oooooo0_l000000ooooooo0000o`00000eooooo`00:oooool00ol0003o
ooooooooo`0>ooooo`;o00004_ooool2o`0000cooooo0_l00003ooooo`;o00004?ooool2o`0000[o
oooo0_l0000;ooooo`;o00005?ooool2o`0000?ooooo0_l0000>ooooo`;o00002?ooool2o`0000?o
oooo0_l0001Kooooo`;o00001oooool2o`000003ooooool0003o000003Gooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000So
oooo0ol0000;ooooo`Co000000?oooooo`000?l000007?ooool2o`0001_ooooo0_l0000Kooooo`;o
00001Oooool2o`0000Gooooo0_l0000?ooooo`;o00003Oooool2o`0000Sooooo0_l000000ooooooo
0000o`00000;ooooo`;o00007oooool2o`0000Sooooo0ol0000Nooooo`;o00009?ooool002_ooooo
00Co0000oooooooooooooooo0_l00008ooooo`;o00002?ooool3o`0000_ooooo1?l000000ooooooo
0000o`00000Looooo`;o00006oooool2o`0001_ooooo0_l00005ooooo`;o00001Oooool2o`0000oo
oooo0_l0000=ooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo0_l0000Oooooo`;o
00002?ooool3o`0001kooooo0_l0000Tooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool05?ooool2o`0001Wo
oooo0_l0000Aooooo`;o00004?ooool2o`0001gooooo0_l0000?ooooo`;o00001oooool2o`0002;o
oooo0_l0000_ooooo`Co00005?ooool2o`0000_ooooo0ol00004ooooo`;o00001Oooool2o`0000Co
oooo0_l0000Mooooo`00:oooool00ol0003oooooooooo`0Dooooo`;o00006Oooool2o`00017ooooo
0_l0000@ooooo`;o00007Oooool2o`0000oooooo0_l00007ooooo`;o00008_ooool2o`0002oooooo
1?l0000Dooooo`;o00002oooool3o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0001gooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`0?ooooo`;o00003_ooool2o`0000[ooooo0_l00006ooooo`;o0000
5oooool2o`0005Cooooo0_l0000;ooooo`;o000000?oooooo`000?l00000:?ooool2o`0005cooooo
000Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooo
ooooool03oooool2o`0000kooooo0_l0000:ooooo`;o00001_ooool2o`0001Oooooo0_l0001Doooo
o`;o00002oooool2o`000003ooooool0003o000002Sooooo0_l0001Looooo`006oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`?o0000oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0>?ooool2o`0001oooooo0_l00006ooooo`;o0000;?ooool2o`0002;ooooo0_l0000koooo
o`;o00006?ooool2o`0000Cooooo1?l0000Vooooo`006oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0hooooo`;o00007oooool2o`00
00Kooooo0_l0000/ooooo`;o00008_ooool2o`0003_ooooo0_l0000Hooooo`;o00001?ooool4o`00
02Kooooo000Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000=_ooool2o`0001Sooooo0_l00004oooo
o`;o0000J?ooool2o`00013ooooo0_l0001Vooooo`00:oooool3o`0003Kooooo0_l0000Hooooo`;o
00001?ooool2o`0006Sooooo0_l0000@ooooo`;o0000I_ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`1Tooooo`;o0000e?ooool001Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`1Tooooo`;o0000e?ooool001Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0003ooooooc_ooooo000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
^Oooool2o`0004Kooooo0_l0000gooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;Wooooo0_l00016ooooo`;o
0000=oooool001Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oo
oooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
oooo>oooool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooolkooooo`006oooool00onYZJWo410@ooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000?oooooo>oooool001[ooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo00000?ooooooA?ooool001_ooooo00?o^[Zjob4Q8Oooool0
0_ooool01Ol@413ooooooooooooooooo410@0?ooooooA?ooool001Sooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooom4ooooo`006?ooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooodCooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Roooo
o`03o`000?nj^[[ooooo0?ooooooA?ooool000cooooo00?o8B4QomgMgOooool04oooool2oc8b<_oo
ooooAOooool000?ooooo0_l00002ooooo`;o00000oooool00onHV9SoEEEEooooo`02ooooo`03oc8b
<_l0003o000000?o000000?o<S8booooooooool00_l00002ooooo`;o00000_ooool00on7QhOo0000
okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool04?ooool2o`000003
oa0@4?oooooooooo00?ooooo00?o0000onk^k_ooool0oooooolEooooo`000oooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nH
V9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool0
1Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?o
EEEEojVYZOooool0oooooolEooooo`001?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`;oMgMg0ooo
ool01Ol@413ogMgMoooooooMgMgo410@00Cooooo00CogMgMo`000?l@413oc<c<4_ooool01Ol0003o
oooooooooooooooo0000017ooooo1Ol00005ooooo`03ojVYZOmEEEGooooo0?oooooo5Oooool000Co
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^k^ko410@onk^kP02ooooo`05ohN7QomgMgOooooo
ofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`05o`000?ooooooooooooooool00000
0_ooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001oooool00olQ8B7oooooooooo`3ooooooaCo
oooo0004ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@413o
k^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVYZOl0
00004Oooool01?oMgMgoEEEEooooool00007ooooo`03oeEEEOo<c<cooooo0?oooooo5?ooool000?o
oooo0_l00002ooooo`;o00001Oooool00ooMgMgo410@ooooo`02ooooo`03ogMgMolQ8B7oEEEE00Co
oooo0_l00002ooooo`;o00004?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo013o
oooo00?oMgMgolc<c?l000001oooool00onYZJWoMgMgooooo`3ooooooaCooooo000?ooooo`07oeEE
EOnHV9SooooooooooooMgMgo0000omgMg@0booooo`03onk^k_m4A4Co000000Cooooo00Go410@oooo
oooooooooooooc8b<P3ooooooaGooooo000?ooooo`03okZj^_m4A4Cooooo00;ooooo00?oZJVYoooo
ooooool0<_ooool00omgMgOo0000ooooo`03ooooo`Go0000oooooolEooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .43262 Mdot
.03333 .30902 Mdot
.0381 .37082 Mdot
.04286 .28842 Mdot
.04762 .28842 Mdot
.05238 .24721 Mdot
.05714 .30902 Mdot
.0619 .28842 Mdot
.06667 .32962 Mdot
.07143 .37082 Mdot
.07619 .26781 Mdot
.08095 .32962 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .26781 Mdot
.1 .37082 Mdot
.10476 .37082 Mdot
.10952 .35022 Mdot
.11429 .22661 Mdot
.11905 .24721 Mdot
.12381 .22661 Mdot
.12857 .26781 Mdot
.13333 .28842 Mdot
.1381 .41202 Mdot
.14286 .22661 Mdot
.14762 .35022 Mdot
.15238 .37082 Mdot
.15714 .37082 Mdot
.1619 .28842 Mdot
.16667 .37082 Mdot
.17143 .24721 Mdot
.17619 .41202 Mdot
.18095 .28842 Mdot
.18571 .26781 Mdot
.19048 .39142 Mdot
.19524 .32962 Mdot
.2 .24721 Mdot
.20476 .41202 Mdot
.20952 .32962 Mdot
.21429 .43262 Mdot
.21905 .41202 Mdot
.22381 .30902 Mdot
.22857 .20601 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .30902 Mdot
.24762 .28842 Mdot
.25238 .37082 Mdot
.25714 .28842 Mdot
.2619 .28842 Mdot
.26667 .35022 Mdot
.27143 .35022 Mdot
.27619 .20601 Mdot
.28095 .28842 Mdot
.28571 .39142 Mdot
.29048 .30902 Mdot
.29524 .26781 Mdot
.3 .45322 Mdot
.30476 .24721 Mdot
.30952 .32962 Mdot
.31429 .39142 Mdot
.31905 .45322 Mdot
.32381 .30902 Mdot
.32857 .41202 Mdot
.33333 .26781 Mdot
.3381 .32962 Mdot
.34286 .24721 Mdot
.34762 .32962 Mdot
.35238 .32962 Mdot
.35714 .41202 Mdot
.3619 .37082 Mdot
.36667 .51503 Mdot
.37143 .24721 Mdot
.37619 .22661 Mdot
.38095 .26781 Mdot
.38571 .20601 Mdot
.39048 .14421 Mdot
.39524 .26781 Mdot
.4 .24721 Mdot
.40476 .20601 Mdot
.40952 .26781 Mdot
.41429 .37082 Mdot
.41905 .30902 Mdot
.42381 .32962 Mdot
.42857 .26781 Mdot
.43333 .22661 Mdot
.4381 .28842 Mdot
.44286 .32962 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .37082 Mdot
.4619 .26781 Mdot
.46667 .28842 Mdot
.47143 .37082 Mdot
.47619 .22661 Mdot
.48095 .35022 Mdot
.48571 .24721 Mdot
.49048 .30902 Mdot
.49524 .32962 Mdot
.5 .37082 Mdot
.50476 .37082 Mdot
.50952 .43262 Mdot
.51429 .26781 Mdot
.51905 .24721 Mdot
.52381 .24721 Mdot
.52857 .32962 Mdot
.53333 .28842 Mdot
.5381 .30902 Mdot
.54286 .32962 Mdot
.54762 .28842 Mdot
.55238 .30902 Mdot
.55714 .24721 Mdot
.5619 .37082 Mdot
.56667 .24721 Mdot
.57143 .41202 Mdot
.57619 .20601 Mdot
.58095 .16481 Mdot
.58571 .28842 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .32962 Mdot
.60476 .28842 Mdot
.60952 .37082 Mdot
.61429 .39142 Mdot
.61905 .37082 Mdot
.62381 .41202 Mdot
.62857 .43262 Mdot
.63333 .22661 Mdot
.6381 .26781 Mdot
.64286 .35022 Mdot
.64762 .53563 Mdot
.65238 .37082 Mdot
.65714 .28842 Mdot
.6619 .20601 Mdot
.66667 .28842 Mdot
.67143 .43262 Mdot
.67619 .26781 Mdot
.68095 .30902 Mdot
.68571 .22661 Mdot
.69048 .28842 Mdot
.69524 .37082 Mdot
.7 .16481 Mdot
.70476 .20601 Mdot
.70952 .14421 Mdot
.71429 .28842 Mdot
.71905 .22661 Mdot
.72381 .10301 Mdot
.72857 .43262 Mdot
.73333 .26781 Mdot
.7381 .20601 Mdot
.74286 .26781 Mdot
.74762 .24721 Mdot
.75238 .28842 Mdot
.75714 .32962 Mdot
.7619 .39142 Mdot
.76667 .30902 Mdot
.77143 .24721 Mdot
.77619 .14421 Mdot
.78095 .37082 Mdot
.78571 .30902 Mdot
.79048 .37082 Mdot
.79524 .28842 Mdot
.8 .30902 Mdot
.80476 .37082 Mdot
.80952 .20601 Mdot
.81429 .24721 Mdot
.81905 .20601 Mdot
.82381 .22661 Mdot
.82857 .41202 Mdot
.83333 .24721 Mdot
.8381 .37082 Mdot
.84286 .35022 Mdot
.84762 .26781 Mdot
.85238 .35022 Mdot
.85714 .28842 Mdot
.8619 .37082 Mdot
.86667 .24721 Mdot
.87143 .22661 Mdot
.87619 .30902 Mdot
.88095 .32962 Mdot
.88571 .51503 Mdot
.89048 .32962 Mdot
.89524 .28842 Mdot
.9 .16481 Mdot
.90476 .39142 Mdot
.90952 .37082 Mdot
.91429 .41202 Mdot
.91905 .30902 Mdot
.92381 .14421 Mdot
.92857 .39142 Mdot
.93333 .41202 Mdot
.9381 .32962 Mdot
.94286 .43262 Mdot
.94762 .35022 Mdot
.95238 .37082 Mdot
.95714 .26781 Mdot
.9619 .26781 Mdot
.96667 .28842 Mdot
.97143 .37082 Mdot
.97619 .22661 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000d?ooool2o`0006Sooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0=3ooooo0_l0001Xooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo06_ooooo0_l0
001Oooooo`;o00004_ooool2o`0002_ooooo0_l0000[ooooo`00:oooool2o`0006cooooo0_l0001O
ooooo`;o00004_ooool2o`0002_ooooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0:Gooooo0_l0000Rooooo`;o0000>oooool2o`0003;ooooo000[ooooo`;o0000Y_ooool2o`00
02;ooooo0_l0000kooooo`;o0000<_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`004?ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0000jooooo`;o0000
3Oooool2o`0001oooooo0_l00004ooooo`;o0000<_ooool2o`0001Sooooo0_l0000:ooooo`;o0000
2Oooool2o`0001?ooooo0_l000000ooooooo0000o`00001;ooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0jooooo`;o0000
3Oooool2o`0001oooooo0_l00004ooooo`;o0000<_ooool2o`0001Sooooo0_l0000:ooooo`;o0000
2Oooool2o`0001?ooooo0_l000000ooooooo0000o`00001;ooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o00006Oooool2o`000003ooooool0003o000000Cooooo0_l00014ooooo`;o00003ooo
ool2o`0000_ooooo0_l0000^ooooo`;o00003_ooool2o`0000Sooooo0_l0000Mooooo`;o00003Ooo
ool2o`0001kooooo0_l0000Kooooo`00:oooool00ol0003oooooooooo`0Hooooo`;o000000?ooooo
o`000?l000001?ooool2o`0004Cooooo0_l0000?ooooo`;o00002oooool2o`0002kooooo0_l0000>
ooooo`;o00002?ooool2o`0001gooooo0_l0000=ooooo`;o00007_ooool2o`0001_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l0000>ooooo`;o00001oooool2
o`0001kooooo0_l00009ooooo`;o00001oooool2o`0000Kooooo0_l0000Hooooo`;o00002?ooool4
o`0000Sooooo0_l000000ooooooo0000o`00000dooooo`;o00001_ooool2o`0000_ooooo0_l00003
ooooo`;o00002?ooool2o`0003gooooo000[ooooo`;o00001_ooool2o`0001;ooooo0_l0000>oooo
o`;o00001oooool2o`0001kooooo0_l00009ooooo`;o00001oooool2o`0000Kooooo0_l0000Hoooo
o`;o00002?ooool4o`0000Sooooo0_l000000ooooooo0000o`00000dooooo`;o00001_ooool2o`00
00_ooooo0_l00003ooooo`;o00002?ooool2o`0003gooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`0000gooooo0_l00004ooooo`;o00002?ooool2o`00013o
oooo0_l0000?ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo0_l00009ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2
o`0000Cooooo0_l00002ooooo`Ko000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP;o
oooo0_l000001?lb<S;o0000oc8b<_o^k^hOooooo`;o00002_ooool2o`0000Oooooo1?l000001?l@
413oooooooooooooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o00006_oo
ool8o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?o
oooo000[ooooo`03o`000?oooooooooo00cooooo0_l00004ooooo`;o00002?ooool2o`00013ooooo
0_l0000Booooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00009
ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool2o`000004oiRHV?ooooooV9RHogMgMaoooooo0_l0000:ooooo`;o00002Oooool00ol0003ooooo
ooooo`03ooooo`;o000000?oooooo`000?l000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oo
oooo0_l0000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ol000001OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`13
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0>?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@03Ko
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400Cooooo`00:oooool00ol0003oooooooooo`12ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003o
ooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0coooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000004oooool002_ooooo00?o0000ooooooooool0?oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000003Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`00:oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100=_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400gooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04Oooool002_ooooo0_l00003ooooo`Co00000_ooool2o`0001Cooooo
0_l00006ooooo`;o00001?ooool2o`00017ooooo0ol000000ooooooo0000o`000002o`000003oiRH
V?ooooooV9RH00;o0000;_ooool2o`0000Kooooo0_l000000ooooooo0000ooooo`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000_ooool2o`00
00Wooooo1?l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0_l00005oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o000000CoV9RHoooooonHV9SoMgMg1oooool2
o`00017ooooo0_l00009ooooo`;o00003?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo0_l0
00000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool002_ooooo00?o
0000ooooooooool00_ooool4o`0000;ooooo0_l0000Dooooo`;o00001_ooool2o`0000Cooooo0_l0
000Aooooo`So000000?o<S8bo`000?lb<S800_l0000^ooooo`;o00001_ooool2o`000003ofIVI_l0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_l00002ooooo`;o00002Oooool4o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000?ooooo00CoEEEEofIVI_l0003o00001?ooool4o`0000;ooooo0_l000001?lb
<S;o0000oc8b<_o^k^h7ooooo`;o00004Oooool2o`0000Wooooo0_l0000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool3o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Cooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolaooooo`;o00000_ooool00ol@
413o0000o`000003ooooo`00:oooool00ol0003oooooooooo`3ooooooc;ooooo00Go0000ooooooo^
k^ko<S8bolc<c004ooooo`009?ooooooo`00033o00003?ooool01?l0003oV9RHoc8b<_o<c<`5oooo
o`00:oooool01?l0003oooooo`000?l00006ooooo`;o00000oooool00ol0003oooooooooo`02oooo
o`;o00001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ool0003o0000ooooo`05o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000
ooooooooool00_l00009ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0
0008ooooo`;o00002_ooool2o`000003ooooool0003ooooo00Wooooo0_l00002ooooo`;o00003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool2o`0000Cooooo0_l00002ooooo`;o00002Ooo
ool00ol0003oooooooooo`09ooooo`?o00002_ooool2o`0000;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool0
0ol0003oooooooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool0
0ol0003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooo
ooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo00[o
oooo0_l00002ooooo`;o00008?ooool2o`0000?ooooo0_l0000Looooo`;o00001oooool6o`0001Co
oooo0_l00003ooooo`;o00003_ooool2o`0000Sooooo0_l00003ooooo`;o00003Oooool4o`0002go
oooo0_l0000Tooooo`;o000000?oooooo`000?l000003?ooool2o`0001gooooo0_l00008ooooo`00
:oooool2o`0000_ooooo0_l00002ooooo`;o00008?ooool2o`0000?ooooo0_l0000Looooo`;o0000
1oooool6o`0001Cooooo0_l00003ooooo`;o00003_ooool2o`0000Sooooo0_l00003ooooo`;o0000
3Oooool4o`0002gooooo0_l0000Tooooo`;o000000?oooooo`000?l000003?ooool2o`0002Oooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool05_ooool2o`0000[ooooo0_l0000Rooooo`?o0000
?_ooool2o`0002oooooo0_l0000jooooo`;o000000?oooooo`000?l000006oooool2o`0002Cooooo
000[ooooo`;o00005oooool2o`0000[ooooo0_l0000Rooooo`?o0000?_ooool2o`0002oooooo0_l0
000jooooo`;o000000?oooooo`000?l000006oooool2o`0002Cooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`0000;ooooo0_l00008ooooo`;o00001oooool3
o`0000cooooo1?l000000ooooooo0000o`00000Hooooo`;o00007oooool2o`0000kooooo0_l0000;
ooooo`;o00000_ooool2o`0000Oooooo0ol0000?ooooo`;o00003Oooool2o`000003ooooool0003o
000000Sooooo0_l0000;ooooo`;o00006?ooool4o`0000?ooooo0_l00008ooooo`;o00001Oooool2
o`0000cooooo0_l0000;ooooo`;o00001?ooool2o`0001gooooo000[ooooo`04o`000?oooooooooo
ooooo`;o00002?ooool2o`0000Oooooo0ol0000<ooooo`Co000000?oooooo`000?l000006?ooool2
o`0001oooooo0_l0000>ooooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`?o00003oooool2
o`0000gooooo0_l000000ooooooo0000o`000008ooooo`;o00002oooool2o`0001Sooooo1?l00003
ooooo`;o00002?ooool2o`0000Gooooo0_l0000<ooooo`;o00002oooool2o`0000Cooooo0_l0000M
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`;o00004?ooool2o`0001kooooo0_l0000Kooooo`;o00001_ooool2
o`0005Wooooo0_l0000[ooooo`;o0000:Oooool2o`0000Gooooo0_l0000Zooooo`00:oooool00ol0
003oooooooooo`0?ooooo`;o00007_ooool2o`0001_ooooo0_l00006ooooo`;o0000FOooool2o`00
02_ooooo0_l0000Yooooo`;o00001Oooool2o`0002[ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006Oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?oooooo>oooool001_o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0001oooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0000Ooooo
o`;o00001_ooool2o`0003oooooo0_l0000>ooooo`;o0000??ooool2o`0001Sooooo0_l00004oooo
o`;o0000:?ooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool07oooool2o`0000[ooooo0_l00006ooooo`;o00000oooool2o`00
01oooooo0_l00006ooooo`;o0000?oooool2o`0000kooooo0_l0000looooo`;o00006?ooool2o`00
00Cooooo0_l0000Xooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo>oooool001_o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`?o0000=_ooool2o`0005Oo
oooo0_l0000Rooooo`;o00002oooool2o`00013ooooo0_l0000nooooo`;o00009_ooool002_ooooo
0ol0000fooooo`;o0000Eoooool2o`0002;ooooo0_l0000;ooooo`;o00004?ooool2o`0003kooooo
0_l0000Vooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
001Aooooo`;o00001?ooool2o`000>;ooooo000[ooooo`03o`000?oooooooooo053ooooo0_l00004
ooooo`;o0000h_ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo06Cooooo0_l0002Kooooo`;o0000=oooool001[ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0001Tooooo`;o0000Voooool2o`0003Oooooo
000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
oooo>oooool001Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l0002jooooo`;o0000Ooooool002_ooooo00?o0000ooooooooool0^Ooo
ool2o`0007oooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003ooooooc_ooooo000Jooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00003oooooodCooooo000Kooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@403oooooodCooooo000Hooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooA?ooool001So
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`008_ooool00ol0003o^[Zjooooo`3oooooodCooooo000<ooooo`03ob4Q8OoMgMgooooo01?o
oooo0_lb<S;oooooodGooooo0003ooooo`;o00000_ooool2o`0000?ooooo00?oV9RHoeEEEOooool0
0_ooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o00000_ooool2o`0000;ooooo
00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo013o
oooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c03ooooooaGooooo0003
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool01_l0003ogMgMooooooooooooV9RHodA4
A0?ooooo00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co
0000oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?o0000oooo
ooooool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q0?oooooo5Oooool000Cooooo00CogMgMo`00
0?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0
003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00000Aooooo`Go00000oooool01Ol0003o
oooooooooooooooo00000?oooooo5Oooool000Cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00oo^
k^ko410@onk^kP02ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^
k^hBooooo`05o`000?ooooooooooooooool000000_ooool6o`0000Wooooo00CoA4A4omgMgOoooooo
00001?ooool01Olb<S;oV9RHoooooonHV9So<S8b0?oooooo5Oooool000Cooooo00Co8B4QogMgMomg
MgOo<S8b1_ooool02OmEEEGoV9RHooooooooooook^k^oa0@4?o^k^ko410@onk^kP04ooooo`04ob4Q
8OmgMgOoMgMgoc8b<Q;ooooo00Go0000ohN7QoooooooZJVYo`00000Aooooo`04omgMgOmEEEGooooo
o`0000Cooooo00Goc<c<o`000?l0003o0000olc<c03ooooooaGooooo0003ooooo`;o00000_ooool2
o`0000Gooooo00?ogMgMoa0@4?ooool00_ooool00omgMgOo8B4QoeEEE@04ooooo`;o00000_ooool2
o`00013ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0@ooooo`03ogMgMoo<c<co
000000Cooooo00Go410@okZj^_oooooo^[Zjoa0@403ooooooaGooooo000?ooooo`07oeEEEOnHV9So
oooooooooooMgMgo0000omgMg@0booooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj^_oooooo
^[Zjo`00003ooooooaGooooo000?ooooo`03okZj^_m4A4Cooooo00;ooooo00?oZJVYooooooooool0
<_ooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooolEooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(49) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .42232 Mdot
.03333 .31932 Mdot
.0381 .38112 Mdot
.04286 .29872 Mdot
.04762 .29872 Mdot
.05238 .25751 Mdot
.05714 .31932 Mdot
.0619 .27812 Mdot
.06667 .31932 Mdot
.07143 .36052 Mdot
.07619 .25751 Mdot
.08095 .31932 Mdot
.08571 .40172 Mdot
.09048 .29872 Mdot
.09524 .25751 Mdot
.1 .38112 Mdot
.10476 .38112 Mdot
.10952 .33992 Mdot
.11429 .21631 Mdot
.11905 .25751 Mdot
.12381 .23691 Mdot
.12857 .25751 Mdot
.13333 .27812 Mdot
.1381 .40172 Mdot
.14286 .21631 Mdot
.14762 .33992 Mdot
.15238 .38112 Mdot
.15714 .38112 Mdot
.1619 .29872 Mdot
.16667 .38112 Mdot
.17143 .23691 Mdot
.17619 .40172 Mdot
.18095 .29872 Mdot
.18571 .25751 Mdot
.19048 .40172 Mdot
.19524 .33992 Mdot
.2 .23691 Mdot
.20476 .40172 Mdot
.20952 .33992 Mdot
.21429 .42232 Mdot
.21905 .40172 Mdot
.22381 .31932 Mdot
.22857 .21631 Mdot
.23333 .29872 Mdot
.2381 .31932 Mdot
.24286 .29872 Mdot
.24762 .29872 Mdot
.25238 .36052 Mdot
.25714 .29872 Mdot
.2619 .29872 Mdot
.26667 .36052 Mdot
.27143 .33992 Mdot
.27619 .19571 Mdot
.28095 .29872 Mdot
.28571 .38112 Mdot
.29048 .31932 Mdot
.29524 .25751 Mdot
.3 .44292 Mdot
.30476 .23691 Mdot
.30952 .31932 Mdot
.31429 .40172 Mdot
.31905 .46353 Mdot
.32381 .29872 Mdot
.32857 .40172 Mdot
.33333 .25751 Mdot
.3381 .31932 Mdot
.34286 .25751 Mdot
.34762 .33992 Mdot
.35238 .33992 Mdot
.35714 .42232 Mdot
.3619 .38112 Mdot
.36667 .52533 Mdot
.37143 .23691 Mdot
.37619 .21631 Mdot
.38095 .25751 Mdot
.38571 .21631 Mdot
.39048 .13391 Mdot
.39524 .25751 Mdot
.4 .25751 Mdot
.40476 .19571 Mdot
.40952 .27812 Mdot
.41429 .36052 Mdot
.41905 .31932 Mdot
.42381 .31932 Mdot
.42857 .25751 Mdot
.43333 .21631 Mdot
.4381 .29872 Mdot
.44286 .33992 Mdot
.44762 .27812 Mdot
.45238 .31932 Mdot
.45714 .38112 Mdot
.4619 .25751 Mdot
.46667 .27812 Mdot
.47143 .36052 Mdot
.47619 .23691 Mdot
.48095 .36052 Mdot
.48571 .23691 Mdot
.49048 .29872 Mdot
.49524 .33992 Mdot
.5 .36052 Mdot
.50476 .38112 Mdot
.50952 .42232 Mdot
.51429 .27812 Mdot
.51905 .25751 Mdot
.52381 .23691 Mdot
.52857 .33992 Mdot
.53333 .29872 Mdot
.5381 .29872 Mdot
.54286 .31932 Mdot
.54762 .27812 Mdot
.55238 .29872 Mdot
.55714 .23691 Mdot
.5619 .36052 Mdot
.56667 .23691 Mdot
.57143 .40172 Mdot
.57619 .19571 Mdot
.58095 .15451 Mdot
.58571 .27812 Mdot
.59048 .27812 Mdot
.59524 .33992 Mdot
.6 .33992 Mdot
.60476 .27812 Mdot
.60952 .36052 Mdot
.61429 .38112 Mdot
.61905 .38112 Mdot
.62381 .40172 Mdot
.62857 .44292 Mdot
.63333 .21631 Mdot
.6381 .27812 Mdot
.64286 .33992 Mdot
.64762 .54593 Mdot
.65238 .38112 Mdot
.65714 .27812 Mdot
.6619 .21631 Mdot
.66667 .29872 Mdot
.67143 .42232 Mdot
.67619 .27812 Mdot
.68095 .29872 Mdot
.68571 .23691 Mdot
.69048 .29872 Mdot
.69524 .36052 Mdot
.7 .15451 Mdot
.70476 .19571 Mdot
.70952 .15451 Mdot
.71429 .27812 Mdot
.71905 .23691 Mdot
.72381 .11331 Mdot
.72857 .42232 Mdot
.73333 .25751 Mdot
.7381 .21631 Mdot
.74286 .25751 Mdot
.74762 .25751 Mdot
.75238 .27812 Mdot
.75714 .31932 Mdot
.7619 .38112 Mdot
.76667 .31932 Mdot
.77143 .25751 Mdot
.77619 .15451 Mdot
.78095 .38112 Mdot
.78571 .31932 Mdot
.79048 .38112 Mdot
.79524 .29872 Mdot
.8 .31932 Mdot
.80476 .36052 Mdot
.80952 .21631 Mdot
.81429 .25751 Mdot
.81905 .21631 Mdot
.82381 .21631 Mdot
.82857 .40172 Mdot
.83333 .23691 Mdot
.8381 .36052 Mdot
.84286 .36052 Mdot
.84762 .25751 Mdot
.85238 .33992 Mdot
.85714 .29872 Mdot
.8619 .38112 Mdot
.86667 .25751 Mdot
.87143 .21631 Mdot
.87619 .31932 Mdot
.88095 .33992 Mdot
.88571 .50473 Mdot
.89048 .33992 Mdot
.89524 .27812 Mdot
.9 .15451 Mdot
.90476 .40172 Mdot
.90952 .36052 Mdot
.91429 .42232 Mdot
.91905 .29872 Mdot
.92381 .13391 Mdot
.92857 .38112 Mdot
.93333 .40172 Mdot
.9381 .33992 Mdot
.94286 .42232 Mdot
.94762 .33992 Mdot
.95238 .38112 Mdot
.95714 .27812 Mdot
.9619 .25751 Mdot
.96667 .27812 Mdot
.97143 .36052 Mdot
.97619 .21631 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000oooooolkooooo`006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>ooo
ool001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0d?ooool2o`0006Sooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0d?ooool2o`0006Sooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo06_ooooo0_l0002Pooooo`;o0000:oooool002_ooooo00?o0000oooooooo
ool0Joooool2o`000:3ooooo0_l0000[ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0YOooool2o`0002;o
oooo0_l000000ooooooo0000o`00000Booooo`;o00009?ooool2o`0003;ooooo000[ooooo`03o`00
0?oooooooooo0:Gooooo0_l0000Rooooo`;o000000?oooooo`000?l000004_ooool2o`0002Cooooo
0_l0000booooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo04Wooooo0_l0000Uooooo`;o0000<_ooool2o`0002Cooooo0_l0001^ooooo`006Oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo04Wooooo
0_l0000Uooooo`;o0000<_ooool2o`0002Cooooo0_l0001^ooooo`006oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo01Sooooo0_l00007ooooo`;o00005oooool2o`0002_ooooo0_l000000ooooooo0000
o`00000<ooooo`;o0000>oooool2o`0000Oooooo0_l0000Eooooo`;o00004oooool2o`000004oooo
ool0003o0000o`0000gooooo0_l0000Nooooo`;o00006oooool001_ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06?ooool2o`0000Oo
oooo0_l0000Gooooo`;o0000:oooool2o`000003ooooool0003o000000cooooo0_l0000kooooo`;o
00001oooool2o`0001Gooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o00003Oooool2o`00
01kooooo0_l0000Kooooo`006Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool06oooool2o`0000cooooo0_l00007ooooo`;o00007_ooool2
o`0001;ooooo0_l0000Mooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000Rooooo`;o00002?ooool2o`00023ooooo0_l00017ooooo`00:oooool00ol0
003oooooooooo`0Kooooo`;o00003?ooool2o`0000Oooooo0_l0000Nooooo`;o00004_ooool2o`00
01gooooo0_l000000ooooooo0000o`00000:ooooo`;o00002?ooool2o`000003ooooool0003o0000
02;ooooo0_l00008ooooo`;o00008?ooool2o`0004Oooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??oo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`05oooo
o`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000004?ooool2o`00
01oooooo0_l00009ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0ol00007oooo
o`;o00002?ooool2o`0000oooooo0_l0000oooooo`;o000000Coooooo`000?l0003o00001_ooool2
o`0000_ooooo0_l00008ooooo`;o00000oooool2o`0001_ooooo0_l0000Pooooo`00:oooool00ol0
003oooooooooo`05ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0001oooooo0_l00009ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00;ooooo0ol00007ooooo`;o00002?ooool2o`0000oooooo0_l0000oooooo`;o000000Coooooo`00
0?l0003o00001_ooool2o`0000_ooooo0_l00008ooooo`;o00000oooool2o`0001_ooooo0_l0000P
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo0_l00010ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^03Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo1?l000001Ol@413oooooooooooooooooA4A4
00;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0<oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_o
oooo00?o0000ooooooooool0@_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`0jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0=_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo000[ooooo`03
o`000?oooooooooo04?ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0hoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@4100=_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool0<_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@01?ooooo000[ooooo`03o`000?oooooooooo00So
oooo0_l0000Dooooo`;o00008_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool09?ooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?ooool00oooool01Ol0
003ooooooooooooooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00009
ooooo`Co00000_ooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo0_l00007
ooooo`03ogMgMolb<S;ooooo00;o00000oooool00ol0003oooooooooo`0Sooooo`;o00003_ooool0
0onHV9So8B4Qonk^kP02o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo017ooooo000[ooooo`03o`000?oooooooooo00Sooooo0_l0000D
ooooo`;o00007oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00000Vooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000ooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo1?l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`0000Co
oooo00Ko0000ob4Q8Ol0003o<S8bolc<c?ooool2o`0000?ooooo00?o0000ooooooooool08oooool2
o`0000oooooo00GoMgMgofIVI_l0003o0000ooooo`02o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo017ooooo000[ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400foooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`00:oooool2o`00043ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01?ooooo000[ooooo`03o`000?oooooooooo03oooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0>?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Coooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo00;ooooo
1?l0000;ooooo`;o00004oooool2o`0000Cooooo0_l0000>ooooo`;o000000Goooooo`000?l0003o
0000ooooo`04o`0000?ooooo0_l0000;ooooo`;o00008Oooool2o`0000kooooo0_l0000;ooooo`?o
00000_ooool2o`00027ooooo0_l00002ooooo`;o000000?oooooo`000?l000007_ooool2o`00017o
oooo0_l0000@ooooo`;o0000;Oooool002_ooooo00?o0000ooooooooool00_ooool4o`0000_ooooo
0_l0000Cooooo`;o00001?ooool2o`0000kooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
00000oooool2o`0000_ooooo0_l0000Qooooo`;o00003_ooool2o`0000_ooooo0ol00002ooooo`;o
00008Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Nooooo`;o00004Oooool2o`00013o
oooo0_l0000Sooooo`;o00000_ooool00ol@413o0000o`000003ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc;ooooo00Go0000ooooooo^k^ko<S8bolc<c004ooooo`009?ooooooo`00033o0000
3?ooool01?l0003oV9RHoc8b<_o<c<`5ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003o410@oiRHV006ooooo`00:ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00Co0000onk^k_mEEEGoQhN7
1Oooool002_ooooo00Co0000ooooool0003o00001_ooool2o`000003ooooool0003o000000;ooooo
0_l0000Yooooo`;o00000_ooool2o`0000kooooo0_l00004ooooo`;o00001oooool2o`0001Kooooo
1?l00006ooooo`;o00006_ooool2o`0003kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool2o`0001Gooooo0_l0000aooooo`05o`000?ooooooA4A4o`000?l@41001?ooool002_ooooo
00Co0000ooooool0003o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000Yooooo`;o
00000_ooool2o`0000kooooo0_l00004ooooo`;o00001oooool2o`0001Kooooo1?l00006ooooo`;o
00006_ooool2o`0003kooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0001Go
oooo0_l0000aooooo`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo0?oooooo
<_ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`3ooooooc7ooooo0_l0
0008ooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`;o
00004?ooool2o`0001Gooooo1?l0000Iooooo`;o00003_ooool2o`0000Sooooo0_l0000Booooo`Co
00002oooool2o`0003gooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool2o`000003
ooooool0003o000002Cooooo000[ooooo`03o`000?oooooooooo01Kooooo0_l0000:ooooo`;o0000
3?ooool2o`0000?ooooo0_l0000@ooooo`;o00005Oooool4o`0001Wooooo0_l0000>ooooo`;o0000
2?ooool2o`0001;ooooo1?l0000;ooooo`;o0000?Oooool2o`0000Oooooo0_l000000ooooooo0000
o`00000<ooooo`;o000000?oooooo`000?l000009?ooool002_ooooo00?o0000ooooooooool0oooo
oolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooolloooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
>oooool002_ooooo00?o0000ooooooooool02oooool2o`0003Gooooo0_l00002ooooo`;o0000:ooo
ool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0000gooooo0_l0
000Hooooo`;o00007oooool2o`0000Sooooo0ol0000Booooo`;o00004Oooool2o`0001gooooo000[
ooooo`03o`000?oooooooooo00_ooooo0_l0000eooooo`;o00000_ooool2o`0002_ooooo0_l0000?
ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l0000=ooooo`;o00006?ooool2
o`0001oooooo0_l00008ooooo`?o00004_ooool2o`00017ooooo0_l0000Mooooo`00:oooool00ol0
003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00Co0000
oooooooooooooooo0_l0000Aooooo`?o00003?ooool4o`000003ooooool0003o000002;ooooo0_l0
000Eooooo`;o00006oooool2o`0000cooooo0_l0000Oooooo`Co00002?ooool2o`0001oooooo0_l0
0004ooooo`Co00005?ooool2o`0001;ooooo0_l00005ooooo`;o00008oooool002_ooooo00Co0000
oooooooooooooooo0_l0000Aooooo`?o00003?ooool4o`000003ooooool0003o000002;ooooo0_l0
000Eooooo`;o00006oooool2o`0000cooooo0_l0000Oooooo`Co00002?ooool2o`0001oooooo0_l0
0004ooooo`Co00005?ooool2o`0001;ooooo0_l00005ooooo`;o00008oooool002_ooooo00?o0000
ooooooooool0oooooolkooooo`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oo
oooooooo00oooooo0_l0000>ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0001[ooooo0_l00003ooooo`;o0000Aoooool2o`0000kooooo0_l0000looooo`;o00005Ooo
ool2o`0000Oooooo0_l0000Xooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h6ooooo`03o`000?oooooooooo00oooooo0_l0000>ooooo`;o00002_ooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0001[ooooo0_l00003ooooo`;o0000Aoooool2o`0000ko
oooo0_l0000looooo`;o00005Oooool2o`0000Oooooo0_l0000Xooooo`006oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_o
oooo000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o
0000oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001_ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0000fooooo`;o
0000:Oooool2o`0002cooooo0_l0000_ooooo`;o00004?ooool2o`0003Kooooo0_l00006ooooo`;o
00009_ooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo0ol0000fooooo`;o0000:Oooool2o`0002cooooo0_l0000_ooooo`;o00004?ooool2o`0003Ko
oooo0_l00006ooooo`;o00009_ooool001Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3o
oooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0D?ooool2o`00067ooooo0_l00025ooooo`00:oooool00ol0003oooooooooo`1@ooooo`;o0000
HOooool2o`0008Gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003o
oooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`1Fooooo`;o0000h_ooool002_ooooo00?o
0000ooooooooool0E_ooool2o`000>;ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool2o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo0_ooool2
o`0003Oooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool0ooooool2ooooo`;o0000=oooool001Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000I
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?oooooo>oooool001[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0003ooooooc_ooooo000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0I?oo
ool2o`000=Cooooo000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0I?ooool2o`000=Cooooo000Hooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooo
oollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0^Oooool2o`0007oooooo000[ooooo`03o`00
0?oooooooooo0;Wooooo0_l0001oooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`;o0000oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03
o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
02_ooooo0_l0003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo
00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[
ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:ooo
ool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool0
01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`007?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooooc_ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool00000oooooom4ooooo`006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@4100oooooom4ooooo`006?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooodCooooo000Hooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooA?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002;ooooo00?o0000okZj^_oo
ool0oooooom4ooooo`003?ooool00olQ8B7ogMgMooooo`0Cooooo`;o<S8boooooom5ooooo`000ooo
ool2o`0000;ooooo0_l00003ooooo`03oiRHV?mEEEGooooo00;ooooo00?o<S8bo`000?l000000ol0
00000olb<S;oooooooooo`02o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@ooooo`;o000000So410@oooooooooooo
oooooa0@4?l0003oA4A4olc<c?oooooo5_ooool000?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`06o`000?oMgMgooooooooooonHV9SoA4A40oooool02_m4A4CoV9RHooooooooooook^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00cooooo00Go0000oooooooooooo
ooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l@413ogMgM0?oo
oooo5Oooool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go410@omgMgOoo
oooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000ooooooooooooooooo`00
000Aooooo`Go00001_ooool00on7QhOoEEEEooooo`3ooooooaCooooo0004ooooo`04onk^k_lQ8B7o
410@onk^kPGooooo00?ok^k^oa0@4?o^k^h00_ooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo
00Cok^k^ob4Q8Ol@413ok^k^4_ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Goc<c<ob4Q8Ol0003oEEEEo`00003ooooooaGooooo0004
ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00WoEEEEoiRHV?ooooooooooonk^k_l@413ok^k^oa0@
4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`05o`000?n7QhOoooooojVYZOl000004Ooo
ool01?oMgMgoEEEEooooool00004ooooo`05ob4Q8On7QhOooooooiRHV?l00000oooooolEooooo`00
0oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413ooooo00;ooooo00?oMgMgob4Q8OmEEED0
1?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
4?ooool00omgMgOoc<c<o`000004ooooo`05o`000?ooooooooooooooool00000oooooolEooooo`00
3oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0<_ooool00oo^k^koA4A4o`000004oooo
o`05ob4Q8OnHV9SoooooogMgMomEEED0oooooolEooooo`003oooool00onj^[[oA4A4ooooo`02oooo
o`03ojVYZOoooooooooo03;ooooo00?oMgMgo`000?ooool00oooool01Oo<c<co410@o`000?lb<S;o
k^k^0?oooooo5Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309017 0.0103006 [
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -18 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -18 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(50)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(100)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(150)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(200)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-30)] .01131 0 1 0 Mshowa
.02381 .10301 m
.03006 .10301 L
s
[(-20)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(-10)] .01131 .20601 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(20)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(30)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(\\220) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .41202 Mdot
.03333 .32962 Mdot
.0381 .37082 Mdot
.04286 .28842 Mdot
.04762 .28842 Mdot
.05238 .26781 Mdot
.05714 .30902 Mdot
.0619 .26781 Mdot
.06667 .32962 Mdot
.07143 .37082 Mdot
.07619 .24721 Mdot
.08095 .30902 Mdot
.08571 .39142 Mdot
.09048 .30902 Mdot
.09524 .26781 Mdot
.1 .37082 Mdot
.10476 .39142 Mdot
.10952 .32962 Mdot
.11429 .22661 Mdot
.11905 .24721 Mdot
.12381 .24721 Mdot
.12857 .24721 Mdot
.13333 .26781 Mdot
.1381 .41202 Mdot
.14286 .22661 Mdot
.14762 .35022 Mdot
.15238 .39142 Mdot
.15714 .39142 Mdot
.1619 .30902 Mdot
.16667 .39142 Mdot
.17143 .24721 Mdot
.17619 .39142 Mdot
.18095 .30902 Mdot
.18571 .24721 Mdot
.19048 .39142 Mdot
.19524 .35022 Mdot
.2 .24721 Mdot
.20476 .41202 Mdot
.20952 .35022 Mdot
.21429 .43262 Mdot
.21905 .39142 Mdot
.22381 .32962 Mdot
.22857 .20601 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .30902 Mdot
.24762 .28842 Mdot
.25238 .37082 Mdot
.25714 .28842 Mdot
.2619 .30902 Mdot
.26667 .37082 Mdot
.27143 .35022 Mdot
.27619 .18541 Mdot
.28095 .28842 Mdot
.28571 .39142 Mdot
.29048 .32962 Mdot
.29524 .24721 Mdot
.3 .45322 Mdot
.30476 .22661 Mdot
.30952 .32962 Mdot
.31429 .41202 Mdot
.31905 .45322 Mdot
.32381 .28842 Mdot
.32857 .41202 Mdot
.33333 .24721 Mdot
.3381 .30902 Mdot
.34286 .26781 Mdot
.34762 .32962 Mdot
.35238 .32962 Mdot
.35714 .43262 Mdot
.3619 .39142 Mdot
.36667 .51503 Mdot
.37143 .22661 Mdot
.37619 .22661 Mdot
.38095 .24721 Mdot
.38571 .20601 Mdot
.39048 .12361 Mdot
.39524 .26781 Mdot
.4 .24721 Mdot
.40476 .18541 Mdot
.40952 .26781 Mdot
.41429 .35022 Mdot
.41905 .32962 Mdot
.42381 .32962 Mdot
.42857 .26781 Mdot
.43333 .20601 Mdot
.4381 .28842 Mdot
.44286 .32962 Mdot
.44762 .26781 Mdot
.45238 .30902 Mdot
.45714 .37082 Mdot
.4619 .24721 Mdot
.46667 .28842 Mdot
.47143 .35022 Mdot
.47619 .24721 Mdot
.48095 .35022 Mdot
.48571 .24721 Mdot
.49048 .30902 Mdot
.49524 .32962 Mdot
.5 .35022 Mdot
.50476 .37082 Mdot
.50952 .43262 Mdot
.51429 .28842 Mdot
.51905 .26781 Mdot
.52381 .22661 Mdot
.52857 .35022 Mdot
.53333 .30902 Mdot
.5381 .28842 Mdot
.54286 .30902 Mdot
.54762 .28842 Mdot
.55238 .28842 Mdot
.55714 .22661 Mdot
.5619 .35022 Mdot
.56667 .24721 Mdot
.57143 .39142 Mdot
.57619 .20601 Mdot
.58095 .16481 Mdot
.58571 .26781 Mdot
.59048 .28842 Mdot
.59524 .32962 Mdot
.6 .35022 Mdot
.60476 .26781 Mdot
.60952 .35022 Mdot
.61429 .37082 Mdot
.61905 .37082 Mdot
.62381 .41202 Mdot
.62857 .43262 Mdot
.63333 .22661 Mdot
.6381 .28842 Mdot
.64286 .32962 Mdot
.64762 .53563 Mdot
.65238 .39142 Mdot
.65714 .26781 Mdot
.6619 .20601 Mdot
.66667 .30902 Mdot
.67143 .41202 Mdot
.67619 .26781 Mdot
.68095 .30902 Mdot
.68571 .24721 Mdot
.69048 .28842 Mdot
.69524 .35022 Mdot
.7 .16481 Mdot
.70476 .18541 Mdot
.70952 .16481 Mdot
.71429 .28842 Mdot
.71905 .24721 Mdot
.72381 .10301 Mdot
.72857 .43262 Mdot
.73333 .24721 Mdot
.7381 .22661 Mdot
.74286 .26781 Mdot
.74762 .26781 Mdot
.75238 .28842 Mdot
.75714 .32962 Mdot
.7619 .37082 Mdot
.76667 .32962 Mdot
.77143 .26781 Mdot
.77619 .14421 Mdot
.78095 .39142 Mdot
.78571 .30902 Mdot
.79048 .37082 Mdot
.79524 .28842 Mdot
.8 .30902 Mdot
.80476 .37082 Mdot
.80952 .22661 Mdot
.81429 .26781 Mdot
.81905 .22661 Mdot
.82381 .20601 Mdot
.82857 .41202 Mdot
.83333 .22661 Mdot
.8381 .37082 Mdot
.84286 .35022 Mdot
.84762 .26781 Mdot
.85238 .35022 Mdot
.85714 .28842 Mdot
.8619 .39142 Mdot
.86667 .24721 Mdot
.87143 .20601 Mdot
.87619 .30902 Mdot
.88095 .35022 Mdot
.88571 .49443 Mdot
.89048 .32962 Mdot
.89524 .26781 Mdot
.9 .14421 Mdot
.90476 .39142 Mdot
.90952 .37082 Mdot
.91429 .41202 Mdot
.91905 .28842 Mdot
.92381 .14421 Mdot
.92857 .37082 Mdot
.93333 .41202 Mdot
.9381 .35022 Mdot
.94286 .41202 Mdot
.94762 .35022 Mdot
.95238 .37082 Mdot
.95714 .28842 Mdot
.9619 .26781 Mdot
.96667 .28842 Mdot
.97143 .35022 Mdot
.97619 .20601 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooodCooooo000Hooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?ooooooA?ooool0013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`3ooooood;ooooo000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooolkooooo`006_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Hooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000
oooooollooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o0000oooooollooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>ooo
ool0013ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000d?ooool2o`0006Sooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0=3ooooo0_l0001Xooooo`006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooc_ooooo000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0006cooooo0_l0003=ooooo`00:ooo
ool00ol0003oooooooooo`1[ooooo`;o0000cOooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oo
oooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3Pooooo`;o00009?ooool2o`0000Gooooo0_l0000[ooooo`00:oooool2o`000>7ooooo0_l0000T
ooooo`;o00001Oooool2o`0002_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0YOooool2
o`0002;ooooo0_l000000ooooooo0000o`00001/ooooo`00:oooool2o`000:Kooooo0_l0000Roooo
o`;o000000?oooooo`000?l00000K?ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00
:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>ooo
ool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`;o0000B_ooool2o`0002Gooooo0_l0001Hooooo`;o0000K_ooool002_ooooo
00?o0000ooooooooool0BOooool2o`0002Gooooo0_l0001Hooooo`;o0000K_ooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooooc_ooooo000@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0003[ooooo0_l0000^ooooo`;o0000
3?ooool2o`0002[ooooo0_l0000Hooooo`;o0000;_ooool2o`0000gooooo0_l0000Nooooo`;o0000
6oooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0>_ooool2o`0002kooooo0_l0000<ooooo`;o0000:_ooool2o`0001Sooooo
0_l0000^ooooo`;o00003Oooool2o`0001kooooo0_l0000Kooooo`006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooc_ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`;o00006Oooool2o`0000Oooooo0_l0000_ooooo`;o00004_ooool3o`0002_ooooo0_l0
0008ooooo`;o00005Oooool2o`0001kooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_oo
ool2o`0004Oooooo000[ooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o0000;oooool2
o`0001;ooooo0ol0000[ooooo`;o00002?ooool2o`0001Gooooo0_l0000Nooooo`;o00004oooool2
o`000003ooooool0003o000000;ooooo0_l00017ooooo`00:oooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo00cooooo0_l0000;ooooo`Go00002oooool2o`0000?ooooo0_l00002ooooo`;o00006oooool2
o`0000Wooooo0_l0000=ooooo`;o00000oooool2o`00017ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000005oooool2o`0002;ooooo0_l00008ooooo`;o00000_ooool2o`0002Kooooo0_l0000m
ooooo`00:oooool2o`0000gooooo0_l0000;ooooo`Go00002oooool2o`0000?ooooo0_l00002oooo
o`;o00006oooool2o`0000Wooooo0_l0000=ooooo`;o00000oooool2o`00017ooooo0_l00002oooo
o`;o000000?oooooo`000?l000005oooool2o`0002;ooooo0_l00008ooooo`;o00000_ooool2o`00
02Kooooo0_l0000mooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool0
0ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_o
oooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000[ooooo0_l0000Oooooo`05
odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo0_l0000>
ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`?o000000?o<S8bonk^k_ooool03_ooool2o`0000Co
oooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo1?l000001Ol@413oooooooooooooooooA4A4
00Go000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h2o`0000_ooooo0_l00008ooooo`;o00003?oo
ool2o`0000cooooo1Ol000002?oooooo0000o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01?ooooo000[ooooo`03o`000?oooooooooo00Gooooo0_l000000ooo
oooo0000o`000008ooooo`;o00002_ooool2o`0002;ooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL04_ooool2o`0000kooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o
000000?ooooooiRHV?mgMgL03oooool2o`0000Cooooo0_l0000>ooooo`;o00001?ooool2o`0000Wo
oooo00?o0000ooooooooool01_ooool3o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0_l0000;
ooooo`;o00002?ooool2o`0000cooooo0_l0000<ooooo`06oiRHV?lQ8B7ok^k^oooooom4A4Cooooo
0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`00:oooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooo
ooooool0>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo03;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`00:oooool00ol0003o
ooooooooo`12ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000=_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`0cooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000004oooool002_ooooo00?o0000oooooooo
ool0?oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000j
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000=_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`00:oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@4100=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400gooooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool002_ooooo0_l00003
ooooo`Co0000>Oooool3o`000008ooooool0003o0000oooooomgMgOoV9RHoooooonHV9P2o`0000_o
oooo0_l0000Qooooo`;o00001_ooool2o`000003ooooool0003ooooo00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02ooooo`;o000000GoV9RHoooooonHV9SoMgMgooooo`02o`000004ooooool0003o
0000o`0000[ooooo0_l0000<ooooo`;o00003_ooool2o`0000Gooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l000001?nHV9SooooooiRHV?mgMgL7ooooo`;o00004Oooool2o`00013ooooo
0_l00005ooooo`05o`000?nj^[[ooooooiRHV?l@41000_l000001_oooooo0000o`000?ooooooV9RH
ogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`00:oooool00ol0003oooooooooo`02
ooooo`Co0000>Oooool6o`000005ooooooo^k^ko<S8bo`000?lb<S800_l0000;ooooo`;o00008Ooo
ool2o`0000Kooooo0_l000000omVIVKo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool2o`000005oc8b<_l0003o<S8bonk^k_ooool00_l000001?oooooo0000o`000?l0000:oooo
o`;o00003?ooool2o`0000kooooo0_l00003ooooo`04oeEEEOmVIVKo0000o`0000Cooooo1?l00002
ooooo`;o000000Co<S8bo`000?lb<S;ok^k^1oooool2o`00017ooooo0_l0000@ooooo`;o00001Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00;o000000Koooooo`000?l0003o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool002_ooooo00?o0000ooooooooool0oooooolkoooo
o`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo
<Oooool2o`0000;ooooo00?o410@o`000?l000000oooool002_ooooo00?o0000ooooooooool0oooo
oolbooooo`05o`000?ooooook^k^oc8b<_o<c<`01?ooool002Coooooool0000`o`0000cooooo00Co
0000oiRHV?lb<S;oc<c<1Oooool002_ooooo00?o0000ooooooooool01oooool2o`0000?ooooo00Go
0000ooooool0003o0000ooooo`02o`0000Oooooo00?o0000ooooooooool02Oooool3o`0000?ooooo
0_l00009ooooo`03o`000?oooooooooo00;ooooo1Ol00004ooooo`;o00003Oooool00ol0003ooooo
ooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
0_l0000:ooooo`;o000000?oooooo`000?ooool02?ooool2o`000004ooooool0003o0000o`0000go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o00000_ooool2o`0000Wo
oooo00?o0000ooooooooool02Oooool3o`0000kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?l@413oV9RH00Kooooo000[ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04Oooool01?l0003ok^k^oeEEEOn7QhL5ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc;ooooo00Go0000oooooom4A4Co0000oa0@4004ooooo`00:oooool00ol0003ooooo
ooooo`3ooooooc;ooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0oooo
oolbooooo`03o`000?oooooooooo00Kooooo000[ooooo`04o`000?oooooo0000o`0000Wooooo0_l0
000:ooooo`;o00008Oooool2o`0001;ooooo0_l00004ooooo`;o00002Oooool4o`0001;ooooo1?l0
0003ooooo`;o00003_ooool2o`0001cooooo0_l0000=ooooo`;o00008?ooool2o`000003ooooool0
003o000002Cooooo0_l0000[ooooo`;o00002?ooool002_ooooo1?l00009ooooo`;o00002_ooool2
o`00027ooooo0_l0000Booooo`;o00001?ooool2o`0000Wooooo1?l0000Booooo`Co00000oooool2
o`0000kooooo0_l0000Looooo`;o00003Oooool2o`00023ooooo0_l000000ooooooo0000o`00000T
ooooo`;o0000=Oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0Rooooo`;o00003?ooool2
o`0000?ooooo0_l0000@ooooo`;o0000:_ooool2o`0000oooooo0_l000000ooooooo0000o`000004
ooooo`;o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000006?ooool2
o`0002[ooooo0_l000000ooooooo0000o`000007ooooo`;o00003oooool2o`000003ooooool0003o
000000Gooooo0_l0000Mooooo`00:oooool2o`0002?ooooo0_l0000<ooooo`;o00000oooool2o`00
013ooooo0_l0000Zooooo`;o00003oooool2o`000003ooooool0003o000000Cooooo0_l00006oooo
o`;o00002?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Hooooo`;o0000:_ooool2o`00
0003ooooool0003o000000Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01gooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2o`0000;o
oooo0_l00008ooooo`;o00001oooool2o`0002cooooo0_l00002ooooo`;o0000>?ooool2o`0000co
oooo0_l0000Oooooo`Co0000:Oooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`0001?o
oooo0_l00004ooooo`;o00001Oooool2o`0002?ooooo000[ooooo`04o`000?ooooooooooooooo`;o
00002?ooool2o`0000Oooooo0_l0000/ooooo`;o00000_ooool2o`0003Sooooo0_l0000<ooooo`;o
00007oooool4o`0002Wooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l0000Cooooo`;o
00001?ooool2o`0000Gooooo0_l0000Sooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo
000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolk
ooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`;o00004?ooool2o`0000Co
oooo0_l0000<ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001oooool2o`00
01;ooooo0_l0000Eooooo`;o0000?Oooool2o`0001Oooooo0_l0000Uooooo`;o00005_ooool2o`00
00_ooooo0_l0000aooooo`00:oooool00ol0003oooooooooo`0?ooooo`;o00001?ooool2o`0000co
oooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`00
01Gooooo0_l0000mooooo`;o00005oooool2o`0002Gooooo0_l0000Fooooo`;o00002oooool2o`00
037ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0
oooooolkooooo`006Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6oooo
o`03o`000?oooooooooo0?oooooo>oooool001_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolkooooo`006oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0001oooooo0_l0000Boooo
o`;o00007oooool2o`0000?ooooo0_l0001Gooooo`;o00003?ooool2o`0002kooooo0_l0000Hoooo
o`;o00001?ooool4o`0002Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00007oooool2o`0001;ooooo0_l0000Oooooo`;o00000oooool2o`00
05Oooooo0_l0000<ooooo`;o0000;_ooool2o`0001Sooooo0_l00004ooooo`Co00009_ooool001_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0oooooolkooooo`006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oooooooooo`3ooooooc_ooooo000Kooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wo
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`0fooooo`;o0000:Oooool2o`0002co
oooo0_l0000Rooooo`;o00007Oooool2o`0006Kooooo000[ooooo`;o0000=oooool2o`0002Wooooo
0_l0000/ooooo`;o00008_ooool2o`0001gooooo0_l0001Vooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo0_l0001Aooooo`;o00001?ooool2o`000>;ooooo000[
ooooo`03o`000?oooooooooo053ooooo0_l00004ooooo`;o0000h_ooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`;o0000ooooool3ooooo`;o0000=oooool002_ooooo00?o0000ooooooooool0ooooool2ooooo`;o
0000=oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003ooooooooo
o`3ooooooc_ooooo000Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0oooooolkooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
I?ooool2o`000=Cooooo000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000I?ooool2o`000=Cooooo000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo>oooool001cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolkooooo`006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo>oooool001Sooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
oc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0002jooooo`;o0000
Ooooool002_ooooo00?o0000ooooooooool0^Oooool2o`0007oooooo000[ooooo`03o`000?oooooo
oooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0
003ooooooccooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o0000oooo
ooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool2
o`000?oooooo??ooool002_ooooo00?o0000ooooooooool0oooooolkooooo`00:oooool00ol0003o
ooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo0?oooooo>oooool002_ooooo00?o
0000ooooooooool0oooooolkooooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[oooo
o`03o`000?oooooooooo0?oooooo>oooool002_ooooo0_l0003ooooooccooooo000[ooooo`03o`00
0?oooooooooo0?oooooo>oooool002_ooooo00?o0000ooooooooool0oooooolkooooo`006?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo0?oooooo>oooool001Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc_ooooo000Looooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo>oooool001_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol0003ooooooc_ooooo000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`00003oooooodCooooo000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@403oooooodCooooo000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg0?ooooooA?ooool001Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003o^[Zjooooo`3ooooo
odCooooo000<ooooo`03ob4Q8OoMgMgooooo01?ooooo0_lb<S;oooooodGooooo0003ooooo`;o0000
0_ooool2o`0000?ooooo00?oV9RHoeEEEOooool00_ooool00olb<S;o0000o`000003o`000003oc8b
<_oooooooooo00;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00oooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolEooooo`000oooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3ooooo`0:odA4A?nHV9Sooooooooo
ooo^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooo
oooooooooooo000000;ooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg0?oooooo5Oooool000Cooooo00CogMgMo`000?l@413oc<c<1Oooool2ogMgM`?ooooo00Go
410@omgMgOoooooogMgMoa0@4004ooooo`04omgMgOl0003o410@olc<c1;ooooo00Go0000oooooooo
ooooooooo`00000Fooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0oooooolC
ooooo`001?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`03onk^k_l@413ok^k^00;ooooo00GoQhN7
ogMgMoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool0oooooolCooooo`001?ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`09oeEEEOnHV9Sooooo
ooooooo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo<S8b4_ooool01Ol0003o
QhN7oooooonYZJWo000001;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool00000oooooolEooooo`000oooool2o`0000;ooooo0_l00005ooooo`03omgMgOl@413o
oooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo0_l0000@ooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool04?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@4100oooooolEooooo`003oooool01omEEEGoV9RHoooooooooooogMgMo`000?oMgMd0
<_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolEooooo`00
3oooool00onj^[[oA4A4ooooo`02ooooo`03ojVYZOoooooooooo037ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0oooooolEooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.3842, -32.8181, \
0.868093, 0.401314}}]
}, Closed]]
}, Open  ]],

Cell["\<\
\tAlthough the dynamics of any one particle is completely \
unpredictable, as a group the cloud of particles spreads in a quite \
predictable and reproducible fashion. If the experiment is repeated several \
times, the cloud will spread in the same manner every time.  This remarkable \
predictability of  large numbers of randomly moving particles is actually a \
simple consequence of the laws of probability. In a large group of particles \
starting from the origin, we expect in the first step that roughly  half the \
particles will move in one direction, and the other half will move in the \
other direction. In the next step, half of these two groups will step in each \
direction again, and so on, producing the observed smooth and even spreading \
of the distribution. The random walk shown above is one of the simplest \
examples of how predictable behavior can arise from the chaotic dynamics of \
large groups of particles. This effect is at the root of several fields of \
physics,  notably statistical mechanics; not to mention other fields of \
endeavor (such as insurance).\
\>", "Text"],

Cell[TextData[{
  "\tThe smooth spreading of the particle distribution can be quantitatively \
studied by making a histogram of particle positions as a function of \
timestep. We have used histograms before, in Sec. ",
  ButtonBox["7.1",
    ButtonData:>{"Chapter7.nb", "c:9"},
    ButtonStyle->"Hyperlink"],
  ", but here we will go into a little more detail. A histogram is  a graph \
that shows the number of particles that fall into given bins. Define the \
histogram function ",
  Cell[BoxData[
      \(TraditionalForm\`H(j, n)\)]],
  " as the number of particles located at grid position ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". This function satisfies"
}], "Text",
  CellTags->"i:7"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+j H(j, n) = M\)]]], "NumberedEquation",
  CellTags->"(8.1.5)"],

Cell[TextData[{
  "where the sum runs over all possible grid points.  A histogram is simply a \
plot of ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " ",
  "vs.",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at any given time.  "
}], "Text"],

Cell[TextData[{
  "\tThe function ",
  Cell[BoxData[
      \(TraditionalForm\`H(j, n)\)]],
  " can be evaluated directly from a list of positions using the ",
  StyleBox["BinCounts",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, available in the ",
  StyleBox["Statistics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " add on packages. ",
  StyleBox["Bincounts[data,{xmin,xmax,\[CapitalDelta]x}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " determines the number elements in the list ",
  StyleBox["data",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that fall in bins of size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["\[CapitalDelta]",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["x",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ",",
  " running from ",
  Cell[BoxData[
      FormBox[
        StyleBox["xmin",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["xmax",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".   For instance,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Statistics`;\)\), "\n", 
    \(H\  = \ 
      BinCounts[{0, 1, 3, 1, 5, 5, 4, 3, 3, 2}, {\(-1\)/2, 5 + 1/2, 
          1}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.7"],

Cell[BoxData[
    \({1, 2, 1, 3, 1, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "There are one element in the range from -1/2 to 1/2, 2 in the range ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\)]],
  " to 1 1/2, and so on.  The function ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " is simply the numbers associated with each bin.  These values can be \
plotted as a bar chart using the ",
  StyleBox["Histogram",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plotting function. In order to manipulate the axes ranges in the nicest \
way, we first generate a histogram and then use ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to set the axis ranges and tick marks, as shown in Cell ",
  ButtonBox["8.8",
    ButtonData:>"Cell 8.8",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(histograms\  = \ 
        Table[p1 = 
            Histogram[pos[n], DisplayFunction \[Rule] Identity, 
              HistogramCategories \[Rule] \ 50, 
              HistogramRange \[Rule] {\(-25\), 25}, 
              PlotLabel -> "\<H[j,n],n= \>" <> ToString[n] <> "\<\n\>", 
              AxesLabel \[Rule] {"\<j\>", "\<\>"}]; \[IndentingNewLine]\
\[IndentingNewLine]Show[p1, PlotRange \[Rule] {{\(-25\), 25}, {0, 100}}, 
            DisplayFunction \[Rule] $DisplayFunction, 
            AxesOrigin \[Rule] {0, 0}], {n, 0, 50, 1}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.8"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 1.23607 L
.52 1.23607 L
.52 0 L
F
0 g
.5 0 m
0 0 rlineto s
.5 0 m
.5 .61803 L
s
.52 .61803 m
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Aooooo`03o`000?oooooooooo02;ooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0TOooool00ol@413oooooooooo`0Rooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool009Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00V?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009[ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00Voooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Iooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Hooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Wooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05o`00
0?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002G
ooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05o`000?ooooooooooooooool0
00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
09Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05oa0@4?nj^[[o
oooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
09;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000005ooooo`Koo`00^Oooool009;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005oooo
o`Koo`00^Oooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`Koo`00^Oooool009;ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`Koo`00^Oooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`Koo`00^Oooool00:Wooooo1_oo
002iooooo`00ZOooool6ool00;Wooooo002Yooooo`Koo`00^Oooool00:Wooooo1_oo002iooooo`00
ZOooool6ool00;Wooooo002Yooooo`Koo`00^Oooool00:Wooooo1_oo002iooooo`00ZOooool6ool0
0;Wooooo002Yooooo`Koo`00^Oooool00:Wooooo1_oo002iooooo`00ZOooool6ool00;Wooooo002Y
ooooo`Koo`00^Oooool00:Wooooo1_oo002iooooo`00ZOooool6ool00;Wooooo002Yooooo`Koo`00
^Oooool0097ooooo00Co410@o`000?lQ8B7oc<c<5?ooool6ool00;Wooooo002<ooooo`;o00001Ooo
ool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo00?o0000ool00?oo00001?oo
00000ol0003o^[Zjooooo`2fooooo`00S?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo0_lb<S8>ooooo`Koo`000_lb<S:gooooo`00P?ooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooooooo
ooooool6ool00003ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Uoooool0087ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<
c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool6ool00003olc<c?l0003o
410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`2Gooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool6ool0
00Sooooo00Go0000ooooooooooooooooo`00000@ooooo`05oa0@4?ooooooooooooooool@4100Uooo
ool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo1_oo0008ooooo`06o`00
0?ooooooooooooooool0003ooooo1_l00009ooooo`05o`000?ooooooooooooooool00000Uoooool0
087ooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0
003oQhN7oooooonYZJWo000000Cooooo1_oo0008ooooo`05o`000?n7QhOoooooojVYZOl000004?oo
ool01Ol0003ooooooooooooooooo000009Oooooo0021ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00;ooooo1_oo0007ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
3_ooool01Ol@413ooooooooooooooooo410@09Oooooo0021ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Jooooo`Koo`007Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
09Oooooo0020ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`00
00Kooooo00?o0000ooooooooool04Oooool00ol0003oo`00ool00004ool001gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP2Gooooo`00U?ooool00ol@413oooooooooo`0Booooo`Koo`00^Oooool00:Wo
oooo1_oo002iooooo`00ZOooool6ool00;Wooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .69838 L
.5 .69838 L
.5 0 L
F
0 g
.48 0 m
0 0 rlineto s
.48 0 m
.48 .61803 L
s
.5 .61803 m
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .53769 L
.54 .53769 L
.54 0 L
F
0 g
.52 0 m
.52 .53769 L
.54 .53769 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo033ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo02[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0S?ooool00ol0003oooooooooo`0Rooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2<ooooo`03
oa0@4?oooooooooo02;ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Y?ooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`Go00000oooool01_o^k^ko<S8bo`00
0?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Gooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOo
V9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;7ooooo002Hooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooo
oooooooooooooa0@4?l00004ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000oooooooooooooooo0_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00V_ooool00omgMgOoIVIVooooo`02ooooo`04o`000?ooooooooooooooo`;o00001?oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool009_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?l0003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002G
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Co
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^
o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l0
0004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Toooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Iooooo`;o000000[o410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool009[ooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RHoooo
oonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Gooooo`Go00000oooool01_l@413ooooooooooooooooo410@o`00
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Co0000oooooooooooooooo0_l00004
ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Goooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l00004ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00V?ooool0
0omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@413o00001?oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Sooooo00?o
k^k^odA4A?l000001?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03ogMg
Mol0003ooooo00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Tooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo
00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo
00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q
00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01Ol0003ooooooooooooo
oooo000000?ooooo00Ko410@oooooooooooooooooa0@4?l00004ool000?o00000oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ
8B400oooool01?l0003oooooooooooooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`05o`000?mEEEGo0000oa0@
4?o<c<`00oooool01?l0003oooooooooooooool2o`0000Coo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`03oeEEEOn7QhOooooo
00Gooooo00Ko410@oooooooooooooooooa0@4?l00004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool00ooMgMgo410@oiRHV005
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Sooooo00Coc<c<odA4A?l0003o410@
0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002T
ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o
0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Toooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Goooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Gooooo`05o`000?ooooooooooooooool000000oooool01_l@413ooooooooooooooooo410@o`00
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01?l0003oooooooooooooool2
o`0000Coo`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool0
09Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`04o`000?ooooooooooooooo`;o00001?oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`06oa0@4?ooooooooooooooool@413o
00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`06ogMgMonHV9SooooooiRH
V?mgMgOo00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`06onk^k_lb<S;o
0000oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo1_l0002cooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;co
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l0002moooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0002o`000;gooooo002Toooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?oo
ool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00T?ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00001?oo00000ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Ko410@oooooooooooooooooa0@4?l00004ool000?o0000_?ooool009;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000005ool00;oooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Ooo002oooooo`00T_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Goo`00_oooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ool00;oooooo002@ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Ooo002oooooo`00Y?ooool5ool00;oooooo002Tooooo`Goo`00_oooool00:Cooooo1Ooo002o
ooooo`00Y?ooool5ool00;oooooo002Tooooo`Goo`00_oooool00:Cooooo1Ooo002oooooo`00Y?oo
ool5ool00;oooooo002Tooooo`Goo`00_oooool00:Cooooo1Ooo002oooooo`00Y?ooool5ool00;oo
oooo002Tooooo`Goo`00_oooool00:Cooooo1Ooo002oooooo`00Y?ooool5ool00;oooooo002Toooo
o`Goo`00_oooool00:Cooooo1Ooo002oooooo`00TOooool01?l@413o0000ob4Q8Oo<c<`?ooooo`Go
o`00_oooool008cooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool0
2?ooool5ool00003o`000?oooooooooo00?ooooo00?o0000okZj^_ooool0]_ooool008cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b2Oooool5ool00003o`000?oo
oooooooo00?ooooo0_lb<S:gooooo`00P?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0
003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Go
oooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00kooooo1?l000000ol@413oooooooooo`2Dooooo`00POooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003ooooo
ooooo`2Fooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`2Foooo
o`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;
ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<ooooo`03o`000?oooooooooo09Kooooo
0021ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go
0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7Qooooooo
ZJVYo`00000Cooooo`03o`000?oooooooooo09Kooooo0021ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo017ooooo00?o0000ooooooooool0U_ooool0087ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`2Fooooo`00P?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?o
oooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Sooooo`03oeEEEOmVIVKo000009So
oooo002Dooooo`03oa0@4?oooooooooo0=7ooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .30284 L
.48 .30284 L
.48 0 L
F
0 g
.46 0 m
.46 .30284 L
.48 .30284 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .68602 L
.52 .68602 L
.52 0 L
F
0 g
.5 0 m
0 0 rlineto s
.5 0 m
.5 .61803 L
s
.52 .61803 m
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .24721 L
.56 .24721 L
.56 0 L
F
0 g
.54 0 m
.54 .24721 L
.56 .24721 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo02Cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Kooooo00?o0000oooo
ooooool08_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo08Kooooo00?o410@ooooooooool08_ooool009kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zooo
ool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Uoooool5o`0000;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002G
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Sooooo00?oV9RHob4Q8Oo^k^h00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09Wooooo00?oV9RHob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009[ooooo00GoMgMgofIVI_ooooooooooo`000005ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009_ooooo00Co0000oooooooo
oooo00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Gooooo`05
o`000?nj^[[ooooooiRHV?l@41000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo
002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_o
oooo002Iooooo`;o000000Co410@oooooooooooo00001Ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Jooooo`05o`000?ooooooooooooooool000001Ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Gooooo`Go00000_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Oooooo00Co
A4A4omgMgOoooooo00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000[Oooool009Oooooo00Co
gMgMoeEEEOoooooo00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00V?ooool00omgMgOoc<c<o`00
0003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Hooooo`03onk^k_m4A4Co000000?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool009Wooooo00?oMgMgo`000?ooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01OmEEEGoMgMg
oooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool009Oooooo00Go0000ooooooooooooooooo`000003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool0
1Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00?oEEEEohN7Qoooool01Ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Hooooo`04olc<c?m4
A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Goooo
o`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Oo<c<co0000o`000?l0
003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0093ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Gooooo1_oo002iooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo1_oo002iooooo`00T_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo1_oo002iooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo1_oo002iooooo`00T?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo1_oo002iooooo`00ZOooool6ool00;Wooooo002Yooooo`Koo`00^Ooo
ool00:Wooooo1_oo002iooooo`00ZOooool6ool00;Wooooo002Yooooo`Koo`00^Oooool00:Wooooo
1_oo002iooooo`00ZOooool6ool00;Wooooo002Yooooo`Koo`00^Oooool00:Wooooo1_oo002ioooo
o`00ZOooool6ool00;Wooooo002Yooooo`Koo`00^Oooool00:Wooooo1_oo002iooooo`00ZOooool6
ool00;Wooooo002Yooooo`Koo`00^Oooool00?ooooooJOooool0097ooooo00Co410@o`000?lQ8B7o
c<c<doooool008cooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0]_ooool008cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b]ooo
ool0083ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0
003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`Go0000Uoooool0087o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`00
0?ooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Gooooo`00POooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000004Oooool00onHV9So8B4Qonk^kP2Hooooo`00POooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003o
oooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^09Oooooo0021ooooo`Go00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03
o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03ogMgMomVIVKooooo
09Kooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o0000oooo
ooooool0UOooool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@09Oooooo0020oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000
ooooooooool04Oooool2o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Gooooo`00U?ooool0
0ol@413oooooooooo`3Aooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .12361 L
.46 .12361 L
.46 0 L
F
0 g
.44 0 m
.44 .12361 L
.46 .12361 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .54387 L
.5 .54387 L
.5 0 L
F
0 g
.48 0 m
.48 .54387 L
.5 .54387 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .4388 L
.54 .4388 L
.54 0 L
F
0 g
.52 0 m
.52 .4388 L
.54 .4388 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12979 L
.58 .12979 L
.58 0 L
F
0 g
.56 0 m
.56 .12979 L
.58 .12979 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo002I
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`20ooooo`03o`000?oooooooooo02;ooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0P?ooool00ol@413oooooooooo`0Rooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wo
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOoo
ool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002I
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOoo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Go
oooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Oooooo0ol0
0004ool00007o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool009Oooooo00?oV9RHob4Q8Ol000001?oo00001ol0003oMgMg
oiRHV?ooooooV9RHogMgMol000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:Gooooo002Hooooo`03oiRHV?l0003o000000Co000000Ko410@oooooooooooooooooa0@4?l00004
ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00onHV9So8B4Qonk^kP03oooo
o`04o`000?ooooooooooooooo`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002Jooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooooooooooo0_l00004
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`Oo0000Yoooool009_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?l0003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonH
V9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8b
o`000?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003o
o`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo
0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00Y?ooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`;o000000[o410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool009[ooooo00?o0000ooooooooool00_ooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`Go00000oooool01_l@413ooooooooo
oooooooo410@o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Co0000oooooooo
oooooooo0_l00004ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l00004
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00V?ooool00omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@413o00001?oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool009Sooooo00?ok^k^odA4A?l000001?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Iooooo`03ogMgMol0003ooooo00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002T
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01Oo^k^ko<S8bo`000?l@
413oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01OmEEEGoMgMg
oooooonHV9So8B4Q00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01Ol0
003ooooooooooooooooo000000?ooooo00Ko410@oooooooooooooooooa0@4?l00004ool000?o0000
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`05o`000?nH
V9SooooooiRHV?lQ8B400oooool01?l0003oooooooooooooool2o`0000Coo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`00oooool01?l0003oooooooooooooool2o`0000Coo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`03
oeEEEOn7QhOooooo00Gooooo00Ko410@oooooooooooooooooa0@4?l00004ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool00ooM
gMgo410@oiRHV005ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Sooooo00Coc<c<
odA4A?l0003o410@0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo1_l0002cooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;co
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00
Y?ooool00ol0003oo`00ool00002ool000;o0000_Oooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool0_?ooool009Oo
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?oo
00000ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Ko
410@oooooooooooooooooa0@4?l00004ool00003o`000?oooooooooo0;cooooo002Gooooo`05oc8b
<_nHV9SooooooiRHV?lb<S800oooool01?l0003oooooooooooooool2o`0000Coo`000ol0002loooo
o`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Co0000oooooooooooooooo0_l00004
ool00003o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool0
1_l@413ooooooooooooooooo410@o`0000Coo`0000?o0000ooooooooool0_?ooool009Oooooo00Go
0000okZj^_oooooo^[Zjo`000003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?oo00000ol0
003oooooooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Kok^k^oc8b
<_l0003o<S8bonk^k_l00004ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;co
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o
0000ool00?oo00000_oo0002o`000;gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2loooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo1_l0002nooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`00
0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00TOooool01?l@413o0000ob4Q8Oo<c<cCooooo`00S?ooool2o`0000Gooooo00?oQhN7oa0@4?oo
ool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2fooooo`00
S?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`00
0?oooooooooo00?ooooo0_lb<S:gooooo`00P?ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7
Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo0000
00Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00gooooo00GoV9RHoa0@4?l0003o<S8bolc<c02Gooooo`00POooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0
003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01Ol@
413o^[ZjoooooomgMgOo<S8b09Oooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`00
0?oooooooooo09Gooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?oZJVY
oa0@4?ooool0U_ooool0087ooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool0
1Ol0003oQhN7oooooonYZJWo000001;ooooo00?o410@o`000?nj^[X0Uoooool0087ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool04Oooool00onj^[[o8B4Qooooo`2Fooooo`00POooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Pooooo`05oa0@4?nHV9SooooookZj^_l00000Uoooool0083ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o0000
8_ooool01OnYZJWo410@o`000?l@413oZJVY09Oooooo002Dooooo`03oa0@4?oooooooooo0=7ooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
F
0 g
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .33374 L
.48 .33374 L
.48 0 L
F
0 g
.46 0 m
.46 .33374 L
.48 .33374 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .47589 L
.52 .47589 L
.52 0 L
F
0 g
.5 0 m
.5 .47589 L
.52 .47589 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .26575 L
.56 .26575 L
.56 0 L
F
0 g
.54 0 m
.54 .26575 L
.56 .26575 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .09271 L
.6 .09271 L
.6 0 L
F
0 g
.58 0 m
.58 .09271 L
.6 .09271 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01oooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0Noooool00ol0003oooooooooo`0Rooooo`00Toooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1kooooo`03
oa0@4?oooooooooo02;ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo002Cooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0:3ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0X?ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Poooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko0000
X_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Uoooool5o`0000;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002G
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Sooooo00?oV9RHob4Q8Oo^k^h00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09Wooooo00?oV9RHob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009[ooooo00GoMgMgofIVI_ooooooooooo`000005ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009_ooooo00Co0000oooooooo
oooo00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Gooooo`05
o`000?nj^[[ooooooiRHV?l@41000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo
002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_o
oooo002Iooooo`;o000000Co410@oooooooooooo00001Ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Jooooo`05o`000?ooooooooooooooool000001Ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Gooooo`Go00000_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Oooooo00Co
A4A4omgMgOoooooo00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009Oooooo00CogMgMoeEEEOoooooo00000oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Sooooo00?o
MgMgolc<c?l000000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Zoooool009Sooooo00?ok^k^odA4A?l000000oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Wooooo00?oMgMgo`00
0?ooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`000:gooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Noooo
o`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@03
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uooo
ool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`03omgMgOl@413oV9RH00Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool7o`000;Sooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2loooo
o`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool0
1Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01Oo<c<co0000o`000?l0
003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4034ooooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0097ooooo00Co410@o`000?lQ8B7o
c<c<doooool008cooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0]_ooool008cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b]ooo
ool0083ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0
003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?ooooo`;o000000?o410@oooo
ooooool0UOooool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000
ooooooooooooooooo`000?ooool6o`0000cooooo00?o0000ooooooooool0U_ooool0087ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo0000013ooooo1Ol0002Gooooo`00POooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo
1_l00009ooooo`04odA4A?oMgMgoooooo`0009Sooooo0021ooooo`Go00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03
o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000@ooooo`04omgMgOmEEEGooooo
o`0009Sooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00oooooo00?oMgMg
olc<c?l00000V?ooool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool08Oooool00oo^k^koA4A4o`00002Hooooo`00P?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooo
oooo017ooooo0_l0000Tooooo`03ogMgMol0003ooooo09Oooooo002Dooooo`03oa0@4?oooooooooo
0=7ooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
F
0 g
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .16069 L
.46 .16069 L
.46 0 L
F
0 g
.44 0 m
.44 .16069 L
.46 .16069 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .45116 L
.5 .45116 L
.5 0 L
F
0 g
.48 0 m
.48 .45116 L
.5 .45116 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .33992 L
.54 .33992 L
.54 0 L
F
0 g
.52 0 m
.52 .33992 L
.54 .33992 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .20395 L
.58 .20395 L
.58 0 L
F
0 g
.56 0 m
.56 .20395 L
.58 .20395 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .0309 L
.62 .0309 L
.62 0 L
F
0 g
.6 0 m
.6 .0309 L
.62 .0309 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01?ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool04oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00SOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo00?o0000oooo
ooooool08_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo07Gooooo00?o410@ooooooooool08_ooool008gooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo1ol0002Looooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool7o`0000Gooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Go
oooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wo
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002Gooooo`?o00001?oo00001ol0003ok^k^oc8b
<_l0003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Go
oooo002Gooooo`03oiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo0000
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00V?ooool00onHV9So
0000ool00003ool00003o`000?l@413ooooo00;ooooo00?o410@o`000?oo00000ooo0003o`0000?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo
0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o
0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o410@ooooo`02
ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00Uoooool00ol0003o^[Zjo`000004ool00007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`00
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Oooooo00?oV9RH
oa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o
00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:Gooooo002Iooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo
002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo1ol0002Wooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Toooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`;o000000[o410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009[ooooo00?o0000oooooooo
ool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`Go00000oooool01_l@
413ooooooooooooooooo410@o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Co
0000oooooooooooooooo0_l00004ool000?o00000oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooo
oooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00V?ooool00omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@
413o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool009Sooooo00?ok^k^odA4A?l000001?ooool01_mgMgOoV9RHoooooonHV9SoMgMg
o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o0000
1?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Toooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo1_l0002coooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool009Oo
oooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00001?oo
00000ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooooooo0;cooooo002Gooooo`05o`00
0?ooooooooooooooool000000oooool01_l@413ooooooooooooooooo410@o`0000Coo`000ol0002l
ooooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Co0000oooooooooooooooo0_l0
0004ool00003o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01?l0003oooooooooooooool2o`0000Coo`0000?o0000ooooooooool0_?ooool009Oooooo00?o
EEEEohN7Qoooool01Oooool01_l@413ooooooooooooooooo410@o`0000Coo`0000?o0000oooooooo
ool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`00
00Coo`0000?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01_o^
k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0002o`000;gooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2loooo
o`00Y?ooool00ol0003oo`00ool00002ool000;o0000_Oooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool6o`000;ko
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05
olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00TOooool0
1?l@413o0000ob4Q8Oo<c<cCooooo`00S?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool0
0ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2fooooo`00S?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo
00?ooooo0_lb<S:gooooo`00P?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj
00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?o
QhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo
00GoA4A4o`000?l0003o<S8bomgMg@2Fooooo`00POooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`00
0?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003Oooool00omgMgOo<S8boooo
o`2Eooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`2Dooooo`00
POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;oooo
o`06o`000?ooooooooooooooool0003ooooo1_l0000=ooooo`03ogMgMolb<S;ooooo09Gooooo0021
ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000
ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVY
o`00000Aooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0U_ooool0087ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool03oooool00ol0003oooooooooo`2Hooooo`00POooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo09Sooooo0020ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo1?l0002Gooooo`00
U?ooool00ol@413oooooooooo`3Aooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .01854 L
.4 .01854 L
.4 0 L
F
0 g
.38 0 m
.38 .01854 L
.4 .01854 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .14215 L
.44 .14215 L
.44 0 L
F
0 g
.42 0 m
.42 .14215 L
.44 .14215 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .26575 L
.48 .26575 L
.48 0 L
F
0 g
.46 0 m
.46 .26575 L
.48 .26575 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .41408 L
.52 .41408 L
.52 0 L
F
0 g
.5 0 m
.5 .41408 L
.52 .41408 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .25957 L
.56 .25957 L
.56 0 L
F
0 g
.54 0 m
.54 .25957 L
.56 .25957 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
F
0 g
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .01236 L
.64 .01236 L
.64 0 L
F
0 g
.62 0 m
.62 .01236 L
.64 .01236 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo0028
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`Ko0000Uoooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo07_ooooo00?o0000ooooooooool08_ooool008Sooooo1_l00005ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo07_ooooo00?o410@ooooooooool08_ooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?oo
ool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo0003o`0000;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00Toooool00ol0003oo`00ool00003
ool00003o`000?ooooooA4A400;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2P
ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?o^k^kooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0002Roooo
o`00Toooool00ol0003oo`00ool00003ool00003o`000?lQ8B7ok^k^00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ogMgMomVIVH00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooo`000002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?nHV9So
410@00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo<c<`00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?o
oooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zooo
ool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009Wooooo0_l000001?l@413oooooooooool00005ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Zoooool009[ooooo00Go0000ooooooooooooooooo`000005ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Oooooo1Ol00002ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Uooo
ool01?m4A4CogMgMooooool00003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00Uoooool01?oMgMgoEEEEooooool00003ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00V?oo
ool00omgMgOoc<c<o`000003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00V?ooool00oo^k^koA4A4o`000003ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo1ol0002]ooooo`00VOooool00omgMgOo0000ooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Nooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`05
o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Ol0003oV9RHoooooonHV9So
8B4Q00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Gooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00?ogMgMoa0@4?nHV9P01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`Oo0000^?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooo
oooo000000Gooooo0ol0002looooo`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj
^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4034ooooo`00T_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo
002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool0097ooooo00Co410@o`000?lQ8B7oc<c<doooool008cooooo
0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0]_ooool008cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b]oooool0083ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o0000
00Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0=ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Uoooool0
087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000oooooooooooooooo
o`000?ooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Gooooo`00POooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000004?ooool01Ol0003ooooooooooooooooo000009Oooooo0021ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Gooooo`00POooool5
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?n7QhOo
ooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl00000
4?ooool01Ol0003oEEEEo`000?l@413oc<c<09Oooooo0021ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo00kooooo00?oEEEEohN7Qoooool0VOooool0087ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ooMgMgo
410@oiRHV02Iooooo`00P?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?o
oooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Sooooo`04olc<c?m4A4Co0000oa0@
49Oooooo002Dooooo`03oa0@4?oooooooooo0=7ooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .01236 L
.38 .01236 L
.38 0 L
F
0 g
.36 0 m
.36 .01236 L
.38 .01236 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .08034 L
.42 .08034 L
.42 0 L
F
0 g
.4 0 m
.4 .08034 L
.42 .08034 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .21013 L
.46 .21013 L
.46 0 L
F
0 g
.44 0 m
.44 .21013 L
.46 .21013 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .35228 L
.5 .35228 L
.5 0 L
F
0 g
.48 0 m
.48 .35228 L
.5 .35228 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .3152 L
.54 .3152 L
.54 0 L
F
0 g
.52 0 m
.52 .3152 L
.54 .3152 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .19777 L
.58 .19777 L
.58 0 L
F
0 g
.56 0 m
.56 .19777 L
.58 .19777 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .06798 L
.62 .06798 L
.62 0 L
F
0 g
.6 0 m
.6 .06798 L
.62 .06798 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo0022
ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo07Gooooo00?o0000ooooooooool08_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo00?o410@oooooooo
ool08_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Joooo
o`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000W?ooool008go
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool008gooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008gooooo1ol0
0005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool3o`0000Coo`0000Oo
0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00Uoooool00onHV9So8B4Qo`000004ool00007o`000?mgMgOoV9RHoooooonH
V9SoMgMgo`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009So
oooo00?oV9RHo`000?oo00000ooo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?o
o`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`00
0_l00003ooooo`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo
002Iooooo`03o`000?oo003oo`0000;oo`000_l00003ooooo`;o00001?oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000
oa0@4?ooool00_ooool00ol@413o0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0YOooool009Oooooo00?o0000okZj^_l000001?oo00001ol0003oMgMgoiRHV?oooooo
V9RHogMgMol000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002G
ooooo`03oiRHV?l@413o000000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uoooo
o`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool0
09Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Ioooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
00;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1ol0002Wooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool6o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool2
o`00000:oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Jooooo`03
o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool5o`00
00?ooooo00Ko410@oooooooooooooooooa0@4?l00004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01?m4A4CogMgMooooool0
0004ooooo`04o`000?ooooooooooooooo`;o00001?oo0003o`0000?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Uoooool01?oMgMgoEEEEooooool00004ooooo`04o`00
0?ooooooooooooooo`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0/Oooool009Sooooo00?oMgMgolc<c?l000001?ooool01_l@413ooooo
oooooooooooo410@o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Hooooo`03onk^k_m4A4Co000000Cooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00VOooool00omgMgOo0000ooooo`03ooooo`06onk^k_lb<S;o0000
oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o
00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool6o`000;?ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Toooo
o`03o`000?oo003oo`0000;oo`000_l0002mooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
_?ooool00:Cooooo1_l0002nooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o
410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2loooo
o`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000
ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o
^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34oooo
o`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Aooooo`04oa0@4?l0003o8B4Qolc<c=?ooooo002<oooo
o`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005oooo
o`03o`000?nj^[[ooooo0;Kooooo002<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[Oooooo0020ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`00
0005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool03oooool00ol0003ok^k^ooooo`2Gooooo`00POooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000oooo
o`Ko00002oooool00omEEEGoZJVYooooo`2Gooooo`00POooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000004_oo
ool00onYZJWoEEEEooooo`2Gooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<oooo
o`03ob4Q8Ooooooooooo09Kooooo0021ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo
00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03oeEEEOo<c<cooooo09Kooooo0021oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo017ooooo00?oZJVYogMgMoooool0U_ooool0
087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08?ooool01Ol@413ooooooooooooooooo<S8b09Oooooo0020ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Ooo
ool2o`0002;ooooo1Ol0002Gooooo`00U?ooool00ol@413oooooooooo`3Aooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01236 L
.36 .01236 L
.36 0 L
F
0 g
.34 0 m
.34 .01236 L
.36 .01236 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .0309 L
.4 .0309 L
.4 0 L
F
0 g
.38 0 m
.38 .0309 L
.4 .0309 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .13597 L
.44 .13597 L
.44 0 L
F
0 g
.42 0 m
.42 .13597 L
.44 .13597 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .27193 L
.48 .27193 L
.48 0 L
F
0 g
.46 0 m
.46 .27193 L
.48 .27193 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .35228 L
.52 .35228 L
.52 0 L
F
0 g
.5 0 m
.5 .35228 L
.52 .35228 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .26575 L
.56 .26575 L
.56 0 L
F
0 g
.54 0 m
.54 .26575 L
.56 .26575 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12979 L
.6 .12979 L
.6 0 L
F
0 g
.58 0 m
.58 .12979 L
.6 .12979 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .03708 L
.64 .03708 L
.64 0 L
F
0 g
.62 0 m
.62 .03708 L
.64 .03708 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool007gooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo02;ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0L?ooool00ol@413oooooooooo`0Rooooo`00R?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOoo
ool008Sooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0UOooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0009Oo
oooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002C
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3o
oooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`000ol0
0002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooodA4A002ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ok^k^ooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo
00000ooo00000ol0003o8B4Qonk^kP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oMgMgofIVIP02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko0000
X_ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`000002ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool7
o`000005oiRHV?l@413oooooooooool000001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo
002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00VOooool2o`00
0004oa0@4?ooooooooooo`0000Goo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00Uoooool5o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Gooooo`04odA4A?oMgMgoooooo`00
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:_ooooo002Gooooo`04omgMgOmEEEGoooooo`0000?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Hooooo`03ogMgMoo<c<co000000?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_o
oooo002Hooooo`03onk^k_m4A4Co000000?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Iooooo`03ogMgMol0003ooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo1ol0002]ooooo`00W_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00W_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2fooooo`00ZOooool7o`000;Sooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go
410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgMgOl@413oV9RH00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`04
olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
0oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01Oo<c<co0000
o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002@oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4034ooooo`00
T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0097ooooo00Co410@o`00
0?lQ8B7oc<c<doooool008cooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj
^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0]_ooool008cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o
<S8b]oooool0083ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04
oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o
^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`0Uoooool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Go
oooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@2Gooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000004?ooool01Ol0003ooooooooooooooooo0000
09Oooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P2Gooooo`00POooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05
o`000?n7QhOoooooojVYZOl000004?ooool01Oo<c<co0000o`000?l0003oc<c<09Oooooo0021oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00kooooo00Go410@okZj^_oooooo^[Zjoa0@
402Gooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Pooooo`05o`000?nj^[[ooooookZj^_l00000Uoooool0083ooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Aooooo`;o00008_ooool01OnYZJWo410@o`000?l@413oZJVY09Oooooo002Dooooo`03oa0@
4?oooooooooo0=7ooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
F
0 g
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .02472 L
.38 .02472 L
.38 0 L
F
0 g
.36 0 m
.36 .02472 L
.38 .02472 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
F
0 g
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .12361 L
.46 .12361 L
.46 0 L
F
0 g
.44 0 m
.44 .12361 L
.46 .12361 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .377 L
.5 .377 L
.5 0 L
F
0 g
.48 0 m
.48 .377 L
.5 .377 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .30284 L
.54 .30284 L
.54 0 L
F
0 g
.52 0 m
.52 .30284 L
.54 .30284 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .18541 L
.58 .18541 L
.58 0 L
F
0 g
.56 0 m
.56 .18541 L
.58 .18541 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.62 .10507 L
.62 0 L
F
0 g
.6 0 m
.6 .10507 L
.62 .10507 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .00618 L
.66 .00618 L
.66 0 L
F
0 g
.64 0 m
.64 .00618 L
.66 .00618 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Sooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`Oo00002_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Cooooo1?l0
000Tooooo`00Moooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2J
ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo00?o0000oooo
ooooool08_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1eooooo`03
oa0@4?oooooooooo02;ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool008;ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Joooo
o`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Joooo
o`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o0000
1?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool008gooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002Iooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo09[ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00
09cooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool3o`0000Coo`0000Oo
0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00Uoooool00onHV9So8B4Qo`000004ool00007o`000?mgMgOoV9RHoooooonH
V9SoMgMgo`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009So
oooo00?oV9RHo`000?l000001?l000001_l@413ooooooooooooooooo410@o`0000Coo`000ol00003
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0:Gooooo002Iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000oooo
oooooooooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool0
09[ooooo00?oMgMgofIVI_ooool00_ooool01?l0003oooooooooooooool2o`0000Coo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Voooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002Gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonH
V9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOoo
ool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?oo
ool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1ol0002Wooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o
00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Iooooo`;o000000[o410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko00001?oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool009[ooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Gooooo`Go00000oooool01_l@413ooooooooooooooooo410@o`0000Coo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Co0000oooooooooooooooo0_l00004ool000?o00000oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Co0000oooooooooooooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00V?ooool00omgMgOoc<c<o`000004oooo
o`06oa0@4?ooooooooooooooool@413o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Sooooo00?ok^k^odA4A?l000001?ooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Ko
k^k^oc8b<_l0003o<S8bonk^k_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0
003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Toooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`000;?ooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0002
o`000;gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2l
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool000;o0000_Ooo
ool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002G
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Co
o`0000?o0000ooooooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`06
ogMgMonHV9SooooooiRHV?mgMgOo00001?oo00000ol0003oooooooooo`2looooo`00Uoooool01Ol0
003ooooooooooooooooo000000?ooooo00Ko410@oooooooooooooooooa0@4?l00004ool000?o0000
_?ooool009Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`04o`000?ooooooooooooooo`;o
00001?oo00000ol0003oooooooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Co0000oooooooooooooooo1ol0002nooooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo
410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2loooo
o`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooo
oonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo
00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooo
okZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Aoooo
o`04oa0@4?l0003o8B4Qolc<c=?ooooo002<ooooo`;o00001Oooool00on7QhOo410@ooooo`03oooo
o`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;Kooooo002<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000oooooooo
ool00oooool2oc8b<[Oooooo0020ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj
^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool0
0on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Ooo
ool01?l@413o0000odA4A?o<c<bHooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@
41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So410@omgMg@2G
ooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000004oooool00on7QhOoEEEEooooo`2Fooooo`00POoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06
o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl00000Uooo
ool0087ooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
1Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooo
oonYZJWo0000013ooooo00Go8B4QohN7QoooooooV9RHo`00002Gooooo`00POooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0>ooooo`05o`000?ooooooooooooooool00000Uoooool0087o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool08?ooool01OlQ8B7oV9RHoooooomgMgOoEEEE09Oooooo0020ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2
o`0002;ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Gooooo`00U?ooool00ol@413oooooooooo`3A
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
F
0 g
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01236 L
.36 .01236 L
.36 0 L
F
0 g
.34 0 m
.34 .01236 L
.36 .01236 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .08652 L
.4 .08652 L
.4 0 L
F
0 g
.38 0 m
.38 .08652 L
.4 .08652 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
F
0 g
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .25957 L
.48 .25957 L
.48 0 L
F
0 g
.46 0 m
.46 .25957 L
.48 .25957 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .36464 L
.52 .36464 L
.52 0 L
F
0 g
.5 0 m
.5 .36464 L
.52 .36464 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .22867 L
.56 .22867 L
.56 0 L
F
0 g
.54 0 m
.54 .22867 L
.56 .22867 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .13597 L
.6 .13597 L
.6 0 L
F
0 g
.58 0 m
.58 .13597 L
.6 .13597 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
F
0 g
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .00618 L
.68 .00618 L
.68 0 L
F
0 g
.66 0 m
.66 .00618 L
.68 .00618 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0=?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0000Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool0077ooooo1ol00005
ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Roooo
o`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo073ooooo00?o410@oooooooo
ool08_ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Go
oooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko0000Uoooool008Sooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?oo
ool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2Pooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?ooool6o`00013ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2Pooooo`00W_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0:3ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00W_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Pooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
002Gooooo`Go00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002G
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0:3ooooo002Hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Pooooo`00VOooool00onHV9So8B4Qonk^kP02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009[ooooo00GoMgMgofIVI_ooooooooooo`000005ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0:3ooooo002Kooooo`04o`000?ooooooooooo`0000Goo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0X?ooool009Oooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko0000X_ooool009Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zooo
ool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000[Oooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool009Wooooo0_l000001?l@413oooooooooool00005ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
V_ooool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`Go00000_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00Uoooool01?m4A4CogMgMooooool00003ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Gooooo`04omgMgOmEEEGoooooo`0000?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Sooooo00?o
MgMgolc<c?l000000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00V?ooool00oo^k^koA4A4o`000003
ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Ioooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Oooooo00Gok^k^oc8b<_l0003o
410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0;Kooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo1ol0002hooooo`00Uoooool01Ol0003ooooooooooooooooo
000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgM
gOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9So
oooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uooo
ool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008go
oooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000
okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005oooo
o`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0>
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kY?ooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l0
000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Cooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000Toooool007gooooo1Ol00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo0000
00Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000009?ooooo001mooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg09?ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^09?ooooo002@ooooo`03oa0@4?oooooooooo0=Go
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
F
0 g
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .05562 L
.38 .05562 L
.38 0 L
F
0 g
.36 0 m
.36 .05562 L
.38 .05562 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .0618 L
.42 .0618 L
.42 0 L
F
0 g
.4 0 m
.4 .0618 L
.42 .0618 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .18541 L
.46 .18541 L
.46 0 L
F
0 g
.44 0 m
.44 .18541 L
.46 .18541 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .3152 L
.5 .3152 L
.5 0 L
F
0 g
.48 0 m
.48 .3152 L
.5 .3152 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .27812 L
.54 .27812 L
.54 0 L
F
0 g
.52 0 m
.52 .27812 L
.54 .27812 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .22249 L
.58 .22249 L
.58 0 L
F
0 g
.56 0 m
.56 .22249 L
.58 .22249 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .07416 L
.62 .07416 L
.62 0 L
F
0 g
.6 0 m
.6 .07416 L
.62 .07416 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .02472 L
.66 .02472 L
.66 0 L
F
0 g
.64 0 m
.64 .02472 L
.66 .02472 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .00618 L
.7 .00618 L
.7 0 L
F
0 g
.68 0 m
.68 .00618 L
.7 .00618 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`Ko0000=oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool007Oooooo1ol00004
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06[ooooo00?o0000oooo
ooooool08_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0J_ooool00ol@413oooooooooo`0Rooooo`00
P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo1ol0002Aooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool0
08;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00
SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool008gooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0V_ooool009Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool0
09Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool009Wooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000W?ooool009Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wo
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002Gooooo`?o00001?oo00001ol0003ok^k^oc8b
<_l0003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Go
oooo002Gooooo`03oiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo0000
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00V?ooool00onHV9So
0000ool00003ool00003o`000?l@413ooooo00;ooooo00?o410@o`000?oo00000ooo0003o`0000?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo
0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o
0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o410@ooooo`02
ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00Uoooool00ol0003o^[Zjo`000004ool00007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`00
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Oooooo00?oV9RH
oa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o
00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOoo
ool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002I
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo1_l00005oooo
o`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00
Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
YOooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool0
0002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool7o`000:Oooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`;o000000[o410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009[ooooo00?o0000oooooooo
ool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`Go00000oooool01_l@
413ooooooooooooooooo410@o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo0;7ooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Co
0000oooooooooooooooo0_l00004ool000?o00000oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooo
oooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00V?ooool00omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@
413o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool009Sooooo00?ok^k^odA4A?l000001?ooool01_mgMgOoV9RHoooooonHV9SoMgMg
o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool000;o0000
1?ooool6o`000;?ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?oo
ool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002T
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool000;o
0000_Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?oo
ool6o`000;kooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmE
EEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooo
oooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0
003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`00
0?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<
c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o
0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?oo
ool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cG
ooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<oooo
o`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00
O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0
003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00kooooo1?l000001?l@413ooooooooo
ooooool4o`000003oa0@4?oooooooooo093ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@4100
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co
0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?oooooooooooooo
ool0003ooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T_ooool0
07gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0
003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonY
ZJWo000001?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Booooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo09;ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00ooo
ool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo00?oEEEEofIVI_l000001Ooo
ool00omEEEGoIVIVo`00002Dooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
F
0 g
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04944 L
.4 .04944 L
.4 0 L
F
0 g
.38 0 m
.38 .04944 L
.4 .04944 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .16069 L
.44 .16069 L
.44 0 L
F
0 g
.42 0 m
.42 .16069 L
.44 .16069 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .24721 L
.48 .24721 L
.48 0 L
F
0 g
.46 0 m
.46 .24721 L
.48 .24721 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .27193 L
.52 .27193 L
.52 0 L
F
0 g
.5 0 m
.5 .27193 L
.52 .27193 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .24721 L
.56 .24721 L
.56 0 L
F
0 g
.54 0 m
.54 .24721 L
.56 .24721 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.58 0 m
.58 .15451 L
.6 .15451 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
F
0 g
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .00618 L
.68 .00618 L
.68 0 L
F
0 g
.66 0 m
.66 .00618 L
.68 .00618 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00618 L
.72 .00618 L
.72 0 L
F
0 g
.7 0 m
.7 .00618 L
.72 .00618 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo02oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo00001?ooool7o`00037ooooo00?o
0000ooooooooool09?ooool4o`0002Cooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo001moooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo073ooooo00?o0000ooooooooool08_ooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0L?ooool00ol@413oooooooooo`0Rooooo`00OOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOoo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2Eooooo`00OOooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo
0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool6o`0000Gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool6o`0009Oooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3o
oooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002C
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
002Cooooo`03o`000?oo003oo`0000?oo`000ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooodA4A002
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool0
0?oo00000ooo00000ol0003ok^k^ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qonk^kP02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oMgMgofIVIP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`000002ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oV9RHoa0@4002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qolc<c002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko0000X_ooool009?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zooo
ool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009Wooooo0_l000001?l@413oooooooooool00005ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Zoooool009[ooooo00Go0000ooooooooooooooooo`000005ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Oooooo1Ol00002ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Uooo
ool01?m4A4CogMgMooooool00003ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo1ol0002]ooooo`00Uoooool01?oMgMgoEEEEooooool00004ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Sooooo00?ok^k^odA4A?l00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00VOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool7o`000;Sooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOo
oooo00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?o
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002l
ooooo`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo
0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@
413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_oo
ool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@oooooooooooooooo
o`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0>ooooo`Co000000?o410@ooooooooool01Ol0002Cooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?oo
ool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Toooool007gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo000001?ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP2Doooo
o`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;
ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
00?oV9RHob4Q8Oo^k^h0Toooool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool0
2oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?o0000ooooooooool01Oooool00omgMgOo
IVIVooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0TOooool007gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100Toooool007cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aoooo
o`;o00008oooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0Toooool0
093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00618 L
.3 .00618 L
.3 0 L
F
0 g
.28 0 m
.28 .00618 L
.3 .00618 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01854 L
.34 .01854 L
.34 0 L
F
0 g
.32 0 m
.32 .01854 L
.34 .01854 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04944 L
.38 .04944 L
.38 0 L
F
0 g
.36 0 m
.36 .04944 L
.38 .04944 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .09271 L
.42 .09271 L
.42 0 L
F
0 g
.4 0 m
.4 .09271 L
.42 .09271 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .22249 L
.46 .22249 L
.46 0 L
F
0 g
.44 0 m
.44 .22249 L
.46 .22249 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .29048 L
.5 .29048 L
.5 0 L
F
0 g
.48 0 m
.48 .29048 L
.5 .29048 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .21013 L
.54 .21013 L
.54 0 L
F
0 g
.52 0 m
.52 .21013 L
.54 .21013 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .19159 L
.58 .19159 L
.58 0 L
F
0 g
.56 0 m
.56 .19159 L
.58 .19159 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.62 .11125 L
.62 0 L
F
0 g
.6 0 m
.6 .11125 L
.62 .11125 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .03708 L
.66 .03708 L
.66 0 L
F
0 g
.64 0 m
.64 .03708 L
.66 .03708 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .00618 L
.7 .00618 L
.7 0 L
F
0 g
.68 0 m
.68 .00618 L
.7 .00618 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0_ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool6o`0003Oooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001g
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?
ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0Rooooo`00Moooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0J_ooool00ol@413oooooooooo`0Rooooo`00P_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00097o
oooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo09[ooooo0022ooooo`Oo00001?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool0
08gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`Oo0000
1Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo09[ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002Iooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo09[ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[o
oooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0009cooooo
002Gooooo`?o00001?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Gooooo`03oiRHV?lQ8B7o000000Coo`00
00Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00V?ooool00onHV9So0000ool00003ool00003o`000?l@413ooooo00;o
oooo00?o410@o`000?oo00000ooo0003o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo
00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00ol0003o^[Zjo`000004ool0
0007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`000004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo
002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo
0000Yoooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`Ko0000/oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`000_l0002mooooo`00VOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2l
ooooo`00VOooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2loooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2looooo`00VOooool2o`00000:oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool0_?ooool009[ooooo00?o0000oooooooo
ool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o0000ooooooooool0_?ooool0
09Oooooo1Ol00003ooooo`06oa0@4?ooooooooooooooool@413o00001?oo00000ol0003ooooooooo
o`2looooo`00Uoooool01?m4A4CogMgMooooool00004ooooo`04o`000?ooooooooooooooo`;o0000
1?oo0003o`000;cooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooo
oooo0_l00004ool00003o`000?oooooooooo0;cooooo002Hooooo`03ogMgMoo<c<co000000Cooooo
00Ko410@oooooooooooooooooa0@4?l00004ool00003o`000?oooooooooo0;cooooo002Hooooo`03
onk^k_m4A4Co000000Cooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooo
oooo0;cooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
0004ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2loooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`000_l0002mooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool6o`000;ko
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o
410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2loooo
o`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000
ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o
^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34oooo
o`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028oooo
o`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005oooo
o`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`00
0005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool03_ooool4o`000008oa0@4?oooooooooooiRHV?l@413o
0000oc8b<_o<c<bCooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?nj^[[oooooogMgMolb<S80Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`00OOooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003o
oooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool0T_ooool007gooooo
1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7
oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo0000
01?ooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P2Cooooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q
8Oooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9Sooooo
okZj^_l00000Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008oooool00omEEEGoIVIVo`000004
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Toooool0093ooooo00?o410@ooooooooool0eOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01854 L
.32 .01854 L
.32 0 L
F
0 g
.3 0 m
.3 .01854 L
.32 .01854 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .02472 L
.36 .02472 L
.36 0 L
F
0 g
.34 0 m
.34 .02472 L
.36 .02472 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .17923 L
.44 .17923 L
.44 0 L
F
0 g
.42 0 m
.42 .17923 L
.44 .17923 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .27193 L
.48 .27193 L
.48 0 L
F
0 g
.46 0 m
.46 .27193 L
.48 .27193 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .24721 L
.52 .24721 L
.52 0 L
F
0 g
.5 0 m
.5 .24721 L
.52 .24721 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
F
0 g
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .17923 L
.6 .17923 L
.6 0 L
F
0 g
.58 0 m
.58 .17923 L
.6 .17923 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .05562 L
.64 .05562 L
.64 0 L
F
0 g
.62 0 m
.62 .05562 L
.64 .05562 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
F
0 g
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo02Wooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Cooooo1?l0
000Tooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001aoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Roooo
o`00LOooool7o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo06Cooooo00?o410@ooooooooool08_ooool007gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`Ko00001Ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`29ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo1ol0002;ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eoooo
o`00R?ooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0009Oooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3o
oooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002C
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
002Cooooo`03o`000?oo003oo`0000?oo`000ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooodA4A002
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool0
0?oo00000ooo00000ol0003ok^k^ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qonk^kP02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oMgMgofIVIP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`000002ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oV9RHoa0@4002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qolc<c002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00Toooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool009?ooooo1ol00004ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00ko
oooo1_l0002Rooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
VOooool2o`000004oa0@4?ooooooooooo`0000Goo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0;Kooooo002Jooooo`05o`000?ooooooooooooooool0
00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool009Oooooo1Ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Gooooo`04odA4A?oM
gMgoooooo`0000?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000
^?ooool009Oooooo00CogMgMoeEEEOoooooo00000oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l000000ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?oo
ool009Sooooo00?ok^k^odA4A?l000000oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;co
oooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2looooo`00W_ooool7o`0000Cooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002l
ooooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?o
EEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oooooooooooooo
ool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zj
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo
00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooo
oooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00kooooo1?l000000ol@413oooooooooo`02ooooo`;o000000?o410@oooo
ooooool0TOooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000
ooooooooooooooooo`000?ooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`02oooo
o`Go0000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`04odA4A?oMgMgoooooo`0009Cooooo001mooooo`Go00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03
o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03o`000?oooooooooo
00;ooooo00CogMgMoeEEEOoooooo0000U?ooool007gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000009Cooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`00002Dooooo`00O?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooo
oooo017ooooo0_l0000Sooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool0Toooool0
093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
F
0 g
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
F
0 g
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .06798 L
.38 .06798 L
.38 0 L
F
0 g
.36 0 m
.36 .06798 L
.38 .06798 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
F
0 g
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .22249 L
.46 .22249 L
.46 0 L
F
0 g
.44 0 m
.44 .22249 L
.46 .22249 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .23485 L
.5 .23485 L
.5 0 L
F
0 g
.48 0 m
.48 .23485 L
.5 .23485 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .25957 L
.54 .25957 L
.54 0 L
F
0 g
.52 0 m
.52 .25957 L
.54 .25957 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .16069 L
.58 .16069 L
.58 0 L
F
0 g
.56 0 m
.56 .16069 L
.58 .16069 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.62 .10507 L
.62 0 L
F
0 g
.6 0 m
.6 .10507 L
.62 .10507 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .0309 L
.66 .0309 L
.66 0 L
F
0 g
.64 0 m
.64 .0309 L
.66 .0309 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
F
0 g
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001/
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0000Cooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001/oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Goooool00ol0003oooooooooo`0Roooo
o`00K?ooool6o`00013ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo05oooooo00?o410@ooooooooool08_ooool008;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo0022ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo1_l00026ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7
o`00097ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2J
ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_oo
ool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool7o`00
00Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`Oo00001Ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Jooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00VOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0002Looooo`00VOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Oooooo0ol00004ool00007o`000?o^k^ko<S8bo`000?lb<S;o
k^k^o`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Oooooo
00?oV9RHob4Q8Ol000001?oo00001ol0003oMgMgoiRHV?ooooooV9RHogMgMol000001?oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Hooooo`03oiRHV?l0003oo`0000?o
o`0000?o0000oa0@4?ooool00_ooool00ol@413o0000ool00003ool000?o00000oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool0
0002ool000;o00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@
o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Goooo
o`03o`000?nj^[[o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00onHV9So410@o`000004
ool00007o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Ioooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1ol0002Wooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002I
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l0
0004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Ioooo
o`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Y?ooool6o`0000Gooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2aooooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Uoooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Uoooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Sooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Hooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00?ooooo1_l0002c
ooooo`00VOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002G
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7
ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?o
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005oooo
o`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo
410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[o
oooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo
00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?oooooooooooooo
ool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool03_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMoooo
o`2Aooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooo
oooooooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo
097ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0T?ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo097ooooo001mooooo`Go00001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004oooo
o`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c02Booooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0U?oo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Cooooo001l
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o
0000ooooooooool04Oooool2o`0002?ooooo00?oEEEEofIVI_l000001Oooool4o`0009?ooooo002@
ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
F
0 g
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
F
0 g
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.38 0 m
.38 .09271 L
.4 .09271 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .16069 L
.44 .16069 L
.44 0 L
F
0 g
.42 0 m
.42 .16069 L
.44 .16069 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .22867 L
.48 .22867 L
.48 0 L
F
0 g
.46 0 m
.46 .22867 L
.48 .22867 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .25339 L
.52 .25339 L
.52 0 L
F
0 g
.5 0 m
.5 .25339 L
.52 .25339 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .19777 L
.56 .19777 L
.56 0 L
F
0 g
.54 0 m
.54 .19777 L
.56 .19777 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .10507 L
.6 .10507 L
.6 0 L
F
0 g
.58 0 m
.58 .10507 L
.6 .10507 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .09271 L
.64 .09271 L
.64 0 L
F
0 g
.62 0 m
.62 .09271 L
.64 .09271 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
F
0 g
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0:Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool006Kooooo1ol00004ooooo`Oo00001Oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo07kooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Rooooo`00OOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0005_ooooo00?o410@oooooooo
ool08_ooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol0002;ooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool6o`0000Go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2E
ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
08Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool6o`0000Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool6o`0009Oooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`00
0:;ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool0
0003ool000?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooodA4A002
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?o^k^kooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oMgMgofIVIP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oo
oooo000000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oiRHV?l@41000_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qolc<c002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`Oo0000[Oooool009kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool009kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
09kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool009kooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00V_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Gooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Sooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo1ol0002hooooo`00V?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00VOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;co
oooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool00omE
EEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oooooooooooooooo
o`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Co
oooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool0
0on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[o
oooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b
<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?oooooo
ooooooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool03_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oa0@4?o<c<bC
ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooo
oooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B40Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000009?ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6
o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q09?ooooo001m
ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000
ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVY
o`00000Cooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02Cooooo`00
OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[o
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo00?oEEEEohN7Qoooool0UOooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`03
omgMgOl@413oV9RH09Gooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo00?oEEEEofIVI_l0
00001Oooool01?o<c<coA4A4o`000?l@412Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04326 L
.38 .04326 L
.38 0 L
F
0 g
.36 0 m
.36 .04326 L
.38 .04326 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .14215 L
.42 .14215 L
.42 0 L
F
0 g
.4 0 m
.4 .14215 L
.42 .14215 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .19777 L
.46 .19777 L
.46 0 L
F
0 g
.44 0 m
.44 .19777 L
.46 .19777 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .20395 L
.5 .20395 L
.5 0 L
F
0 g
.48 0 m
.48 .20395 L
.5 .20395 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .25339 L
.54 .25339 L
.54 0 L
F
0 g
.52 0 m
.52 .25339 L
.54 .25339 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .16687 L
.58 .16687 L
.58 0 L
F
0 g
.56 0 m
.56 .16687 L
.58 .16687 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
F
0 g
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .04326 L
.66 .04326 L
.66 0 L
F
0 g
.64 0 m
.64 .04326 L
.66 .04326 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
F
0 g
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01854 L
.74 .01854 L
.74 0 L
F
0 g
.72 0 m
.72 .01854 L
.74 .01854 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool0;oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool006cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo07Wooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02;ooooo001/ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`0000Gooooo1_l0001Fooooo`03
oa0@4?oooooooooo02;ooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Soooool006cooooo1_l00005ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oo
oooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`Oo00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00097ooooo002=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2J
ooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2J
ooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0002Looooo`00SOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool0
0003ool00004o`000?ooooooooooooooo`?o00001?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^
k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=ooooo`03
o`000?oo003oo`0000?oo`0000Oo0000oooooooooooooooooiRHV?lQ8B7o000000Coo`0000Oo0000
ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
V9RHo`000?oo00000ooo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`000ol0
0003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oa0@4?oo
ool00_ooool00ol@413o0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0YOooool008gooooo00?o0000ool00?oo00000ooo00001ol0003ooooooooooooooooo0000okZj
^_l000001?oo00001ol0003oMgMgoiRHV?ooooooV9RHogMgMol000001?oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000Oo0000
oooooooooooooooooiRHV?l@413o000000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko0000
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool7o`0000Go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Ioooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`000:Oooooo002Iooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool0
09Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool6o`0000Gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo1_l00005ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Wooooo00?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Yooooo`03o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00ZOooool2o`0000Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00ZOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Wooooo00?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Y
ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00ZOooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool00:Wooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Iooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool009[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Gooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Goooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o00000ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Gooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00V?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`03ooooo`Ko0000
/oooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonH
V9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Go
oooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@
4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?oooooooooooooo
ool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj
^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0
093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2
o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool0
0ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l00000
1Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo00kooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?o^k^kooooo09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06
o`000?ooooooooooooooool0003ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oEEEE
ojVYZOooool0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool0
1?ooool00onYZJWoEEEEooooo`2Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<
ooooo`03o`000?oooooooooo00Gooooo00?o8B4Qooooooooool0T_ooool007gooooo1Ol00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo
000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?o
0000ooooooooool01Oooool00omEEEGoc<c<ooooo`2Booooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool0T_oo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S80
Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o0000
1_ooool00ol0003oooooooooo`0Aooooo`;o00008oooool00omEEEGoIVIVo`000004ooooo`Go0000
Toooool0093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
F
0 g
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
F
0 g
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .0309 L
.36 .0309 L
.36 0 L
F
0 g
.34 0 m
.34 .0309 L
.36 .0309 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
F
0 g
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
F
0 g
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .21013 L
.48 .21013 L
.48 0 L
F
0 g
.46 0 m
.46 .21013 L
.48 .21013 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .24103 L
.52 .24103 L
.52 0 L
F
0 g
.5 0 m
.5 .24103 L
.52 .24103 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .19159 L
.56 .19159 L
.56 0 L
F
0 g
.54 0 m
.54 .19159 L
.56 .19159 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12979 L
.6 .12979 L
.6 0 L
F
0 g
.58 0 m
.58 .12979 L
.6 .12979 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .09889 L
.64 .09889 L
.64 0 L
F
0 g
.62 0 m
.62 .09889 L
.64 .09889 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
F
0 g
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
F
0 g
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo02Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00I_ooool7o`0000Cooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00001?ooool7o`0007Gooooo001aoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Roooo
o`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06Cooooo00?o410@oooooooo
ool08_ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00LOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool7o`0008_ooooo001aooooo`Oo00001Oooool6o`0000Gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eoooo
o`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008So
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2E
ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0009Oooooo0028ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool008So
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3o
oooo0028ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00Toooool00ol0003oo`00ool0
0003ool000?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002C
ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooom4A4@00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000onk^
k_ooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0:3ooooo002Cooooo`Oo000000GoMgMgofIVI_ooooooooooo`000005ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`000:;ooooo002Kooooo`04o`00
0?ooooooooooo`0000Goo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
Uoooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo1ol0002]ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00W_ooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00V_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool7o`000;Sooooo002Gooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002l
ooooo`00Uoooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`2looooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^k^ko
<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`000?nH
V9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo
410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2loooo
o`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooo
oonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo
00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooo
okZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=oooo
o`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03oooo
o`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000oooooooo
ool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj
^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool0
0on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03_oo
ool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<bCooooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40Toooool007gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000001?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000009?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?o0000oooo
ooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b09?ooooo001mooooo`Go00001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004
ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03o`000?oo
oooooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02Cooooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL0
0_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL0
0_l000000onHV9Soooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_oooooo
^[Zjoa0@402Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_oo
oooo^[Zjo`00002Cooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00?ooooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Sooooo`03oeEEEOmVIVKo0000
00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Cooooo`00T?ooool00ol@413oooooooooo`3Eoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .03708 L
.3 .03708 L
.3 0 L
F
0 g
.28 0 m
.28 .03708 L
.3 .03708 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01854 L
.34 .01854 L
.34 0 L
F
0 g
.32 0 m
.32 .01854 L
.34 .01854 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .08652 L
.38 .08652 L
.38 0 L
F
0 g
.36 0 m
.36 .08652 L
.38 .08652 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .11743 L
.42 .11743 L
.42 0 L
F
0 g
.4 0 m
.4 .11743 L
.42 .11743 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .15451 L
.46 .15451 L
.46 0 L
F
0 g
.44 0 m
.44 .15451 L
.46 .15451 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .25957 L
.5 .25957 L
.5 0 L
F
0 g
.48 0 m
.48 .25957 L
.5 .25957 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .19777 L
.54 .19777 L
.54 0 L
F
0 g
.52 0 m
.52 .19777 L
.54 .19777 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
F
0 g
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .14833 L
.62 .14833 L
.62 0 L
F
0 g
.6 0 m
.6 .14833 L
.62 .14833 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .05562 L
.66 .05562 L
.66 0 L
F
0 g
.64 0 m
.64 .05562 L
.66 .05562 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01236 L
.7 .01236 L
.7 0 L
F
0 g
.68 0 m
.68 .01236 L
.7 .01236 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
F
0 g
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo02oooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00K?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`Ko00001Oooool6o`00073ooooo001/oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Roooo
o`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo06[ooooo00?o410@ooooooooool08_ooool006cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo001/ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00K?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002
o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00K?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool006co
oooo1_l0000@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo
0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool7o`00097ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[o
oooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo09[ooooo0022ooooo`Oo00001?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool0
08gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00001?l0003ooooooooo
ooooool3o`0000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0V_ooool008gooooo1ol00003ooooo`03oiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonH
V9SooooooiRHV?mgMgOo000000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool009Sooooo00?oV9RHo`00
0?oo00000ooo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`000ol00003oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0000Cooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Jooooo`00VOooool00ol0003oo`00ool00002ool000;o
00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00
VOooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@
413ooooo00;ooooo00?o410@o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo09[ooooo002Gooooo`03o`000?nj^[[o000000Coo`0000Oo0000ogMgMonHV9SooooooiRH
V?mgMgOo000000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00Uooo
ool00onHV9So410@o`000004ool00007o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool009Wooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03_ooool7o`0009cooooo002Iooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool6o`00
00Gooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00Y?ooool0
0ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`000;?ooooo
002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0002o`000;gooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00VOooool2o`00000:oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000ooooooooool0_?ooool0
09[ooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Coo`0000?o
0000ooooooooool0_?ooool009Oooooo1Ol00003ooooo`06oa0@4?ooooooooooooooool@413o0000
1?oo00000ol0003oooooooooo`2looooo`00Uoooool01?m4A4CogMgMooooool00004ooooo`04o`00
0?ooooooooooooooo`;o00001?oo0003o`000;cooooo002Gooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Co0000oooooooooooooooo0_l00004ool00003o`000?oooooooooo0;cooooo002Hooooo`03
ogMgMoo<c<co000000Cooooo00Ko410@oooooooooooooooooa0@4?l00004ool00003o`000?oooooo
oooo0;cooooo002Hooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
o`000;kooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0
003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?oo
ool009Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEE
EOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo
000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo
0ol0002looooo`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@
41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Gooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?oo
ool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03
ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_oo
ool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@oooooooo
ooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0>ooooo`Co000000Oo410@oooooooooooo410@o`000?m4A4Coc<c<09Cooooo
001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?oooooooooooooo
ool0003ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RHoa0@4?oMgMd0Toooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02ooo
ool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01Oooool00on7QhOoEEEE
ooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002Cooooo`00OOooool5o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?oo
ool00ol0003oooooooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl000004oooool00ol0003ooooo
ooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l00000Toooool007gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool04Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9Sooooo
ogMgMomEEED0Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008oooool00omEEEGoIVIVo`000004
ooooo`05olc<c?l@413o0000oc8b<_o^k^h0Toooool0093ooooo00?o410@ooooooooool0eOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
F
0 g
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .03708 L
.32 .03708 L
.32 0 L
F
0 g
.3 0 m
.3 .03708 L
.32 .03708 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .0618 L
.36 .0618 L
.36 0 L
F
0 g
.34 0 m
.34 .0618 L
.36 .0618 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.38 0 m
.38 .08034 L
.4 .08034 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .16069 L
.44 .16069 L
.44 0 L
F
0 g
.42 0 m
.42 .16069 L
.44 .16069 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .19777 L
.48 .19777 L
.48 0 L
F
0 g
.46 0 m
.46 .19777 L
.48 .19777 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .22867 L
.52 .22867 L
.52 0 L
F
0 g
.5 0 m
.5 .22867 L
.52 .22867 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
F
0 g
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .10507 L
.6 .10507 L
.6 0 L
F
0 g
.58 0 m
.58 .10507 L
.6 .10507 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
F
0 g
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04326 L
.68 .04326 L
.68 0 L
F
0 g
.66 0 m
.66 .04326 L
.68 .04326 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
F
0 g
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
F
0 g
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`Oo00001?ooool7o`0001_ooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001V
ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00020
ooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06Cooooo00?o0000oooo
ooooool08_ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Tooooo`03
oa0@4?oooooooooo02;ooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
ROooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00LOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001aooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0ROooool0077ooooo1ol00005ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool7o`0008_ooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo001moooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo09Gooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo001mooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo09Gooooo001mooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
08Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool008Sooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00
Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
UOooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo09Gooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0UOooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009?ooooo00?o
0000ool00?oo00000ooo0003o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2Eooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?ooooooA4A400;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo1_l0002G
ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?o^k^kooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oMgMgofIVIP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oo
oooo000000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oiRHV?l@41000_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qolc<c002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`Oo0000[Oooool009kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0]_ooool009kooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Yooooo`Oo0000^?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool009Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool0
1?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ
8B400oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<
c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o
8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[o
oooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b
<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@
413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj
^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP2Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`00
0?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Cooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000004Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100Tooo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
2oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool00000Toooool007gooooo1Ol00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000009?ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo097o
oooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo023ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Cooooo`00T?ooool00ol@413ooooooooo
o`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
F
0 g
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .0618 L
.38 .0618 L
.38 0 L
F
0 g
.36 0 m
.36 .0618 L
.38 .0618 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .12979 L
.42 .12979 L
.42 0 L
F
0 g
.4 0 m
.4 .12979 L
.42 .12979 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .16687 L
.46 .16687 L
.46 0 L
F
0 g
.44 0 m
.44 .16687 L
.46 .16687 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .24103 L
.5 .24103 L
.5 0 L
F
0 g
.48 0 m
.48 .24103 L
.5 .24103 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .19159 L
.54 .19159 L
.54 0 L
F
0 g
.52 0 m
.52 .19159 L
.54 .19159 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .14833 L
.58 .14833 L
.58 0 L
F
0 g
.56 0 m
.56 .14833 L
.58 .14833 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
F
0 g
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .06798 L
.66 .06798 L
.66 0 L
F
0 g
.64 0 m
.64 .06798 L
.66 .06798 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .03708 L
.7 .03708 L
.7 0 L
F
0 g
.68 0 m
.68 .03708 L
.7 .03708 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo02oooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo1_l0000Qooooo`03o`000?oooooooooo02Cooooo1?l0
000Tooooo`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko0000Noooool006cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Rooooo`00K?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Oooooo`03
oa0@4?oooooooooo02;ooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001/ooooo`Ko00001Ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`Ko0000Q_ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08oooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00Moooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo1ol00004oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo08oooooo0022ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Sooo
ool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00SOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00
097ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo1ol0002Looooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00004o`000?ooooooooooooooo`?o0000
1?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000Oo0000oooooooo
oooooooooiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?oV9RHo`000?oo00000ooo00000ol0003o410@oooo
o`02ooooo`03oa0@4?l0003oo`0000?oo`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool000;o00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00SOooool7o`0000Gooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo
00000_oo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00ol0003o^[Zjo`000004ool00007o`00
0?mgMgOoV9RHoooooonHV9SoMgMgo`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0YOooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0003o<S8b
onk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Ioooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol0002Wooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Ooo
ool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00VOooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool00:Cooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1_l0002cooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2l
ooooo`00Y?ooool00ol0003oo`00ool00002ool000;o0000_Oooool00:Cooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?oo
ool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Iooooo`;o000000[o410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^ko00001?oo00000ol0003oooooooooo`2looooo`00V_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_l0002nooooo`00Uooo
ool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o
0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Wo
oooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
k^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oooooooooooooo
ool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0
003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?o
gMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00
Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002G
ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zj
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;co
oooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool0
0oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0
003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Go
oooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00gooooo1Ol00004ooooo`Co000000?o410@ooooooooool0T?ooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<
c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo09;ooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000Aooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0T_ooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02ooo
ool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo09;ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_o
oooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo09;ooooo001mooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo09;ooooo001looooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2
o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03oeEEEOmVIVKo000009Cooooo002@
ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .02472 L
.28 .02472 L
.28 0 L
F
0 g
.26 0 m
.26 .02472 L
.28 .02472 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
F
0 g
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04944 L
.36 .04944 L
.36 0 L
F
0 g
.34 0 m
.34 .04944 L
.36 .04944 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .12979 L
.4 .12979 L
.4 0 L
F
0 g
.38 0 m
.38 .12979 L
.4 .12979 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .11125 L
.44 .11125 L
.44 0 L
F
0 g
.42 0 m
.42 .11125 L
.44 .11125 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .21013 L
.48 .21013 L
.48 0 L
F
0 g
.46 0 m
.46 .21013 L
.48 .21013 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.52 .19159 L
.52 0 L
F
0 g
.5 0 m
.5 .19159 L
.52 .19159 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .19159 L
.56 .19159 L
.56 0 L
F
0 g
.54 0 m
.54 .19159 L
.56 .19159 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
F
0 g
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .08652 L
.64 .08652 L
.64 0 L
F
0 g
.62 0 m
.62 .08652 L
.64 .08652 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .05562 L
.68 .05562 L
.68 0 L
F
0 g
.66 0 m
.66 .05562 L
.68 .05562 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .02472 L
.72 .02472 L
.72 0 L
F
0 g
.7 0 m
.7 .02472 L
.72 .02472 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0001_ooooo00?o
0000ooooooooool09?ooool4o`0002Cooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000MOooool006Kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo05Wooooo00?o0000oooo
ooooool08_ooool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo05Wooooo00?o410@ooooooooool08_ooool006Kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001Vooooo`Oo00001?oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00020ooooo`00LOooool7
o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo1_l00005oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo08Wooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool7o`0008_ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo
0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0009Oooooo0028ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00
R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo1_l0002Rooooo`00R?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00Oooooo1Ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00R?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00R?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?oV9RHob4Q8Oo^k^h00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
08Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:_ooooo0028ooooo`Ko00003?ooool01OmgMgOoIVIVoooooooooooo000000Goo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Voooool01?l0003oooooooooool00005ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009Oooooo00Go0000okZj^_oo
ooooV9RHoa0@4002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2[ooooo`00Uoooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo1ol00004ooooo`Oo0000[Oooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2l
ooooo`00W_ooool7o`0000Cooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool009[ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002G
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo0;cooooo002Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000oiRHV?oooooo
V9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2loooo
o`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgMgOl@413oV9RH
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hoooo
o`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb
<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01Oo<c<co
0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002@
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4034oooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008gooooo00Co410@
o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000
okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03oooo
o`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03oooo
o`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0
003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`Go0000
0oooool5o`0009?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06
o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A409?ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Aoooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0U?ooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooo
oooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^09?ooooo
001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go
0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7Qooooooo
ZJVYo`00000Cooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMgofIVI_ooool0T_ooool007gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo097ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05o`000?nj^[[ooooooiRHV?l@4100Toooool007cooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Cooooo`00T?oo
ool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .0309 L
.3 .0309 L
.3 0 L
F
0 g
.28 0 m
.28 .0309 L
.3 .0309 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
F
0 g
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .07416 L
.38 .07416 L
.38 0 L
F
0 g
.36 0 m
.36 .07416 L
.38 .07416 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .12979 L
.42 .12979 L
.42 0 L
F
0 g
.4 0 m
.4 .12979 L
.42 .12979 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .14833 L
.46 .14833 L
.46 0 L
F
0 g
.44 0 m
.44 .14833 L
.46 .14833 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .22867 L
.5 .22867 L
.5 0 L
F
0 g
.48 0 m
.48 .22867 L
.5 .22867 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .16687 L
.54 .16687 L
.54 0 L
F
0 g
.52 0 m
.52 .16687 L
.54 .16687 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .17923 L
.58 .17923 L
.58 0 L
F
0 g
.56 0 m
.56 .17923 L
.58 .17923 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .06798 L
.62 .06798 L
.62 0 L
F
0 g
.6 0 m
.6 .06798 L
.62 .06798 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .0618 L
.66 .0618 L
.66 0 L
F
0 g
.64 0 m
.64 .0618 L
.66 .0618 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .04944 L
.7 .04944 L
.7 0 L
F
0 g
.68 0 m
.68 .04944 L
.7 .04944 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
F
0 g
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool09?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`Oo00005Oooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool0067ooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`1iooooo`00K?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Roooo
o`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0E?ooool00ol@413oooooooooo`0Rooooo`00K?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0NOooool006cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool6o`0007_ooooo001/ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool0
07Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0Q?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001goooo
o`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko0000Q_ooool008;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo1ol0002Aooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`Oo0000W?ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo0022ooooo`Oo00001?ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00
SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Go
oooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000Co
0000oooooooooooooooo0ol00004ool00007o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008gooooo00?o0000ool00?oo
00000ooo00001ol0003oooooooooooooooooV9RHob4Q8Ol000001?oo00001ol0003oMgMgoiRHV?oo
ooooV9RHogMgMol000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo
002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00onHV9So0000ool0
0003ool00003o`000?l@413ooooo00;ooooo00?o410@o`000?oo00000ooo0003o`0000?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`000_l00003ooooo`;o00001?oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0:Gooooo002=ooooo`Oo00001Oooool00ol0003oo`00ool00002ool0
00;o00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uoooo
o`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@o`000?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Gooooo`03o`00
0?nj^[[o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00onHV9So410@o`000004ool00007
o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uoooo
o`00VOooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool000;o00001?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0YOooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00kooooo1ol0002Wooooo`00Y?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l0002mooooo`00Y?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;co
oooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`000_l0002moooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2looooo`00Y?ooool6o`000;kooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Iooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0_?ooool009Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o
oooooooooooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<
odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03oooo
o`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000
o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q
8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:k
ooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@
o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X0
1?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00gooooo1Ol00003ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0Toooool007gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o
410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05oa0@4?nj^[[oooooogMgMolb<S80Toooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo0000017ooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003oooooooooo`2Aooooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`00
0?ooooooooooooooool0003ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoa0@
4?ooool0T_ooool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0
003oQhN7oooooonYZJWo000001?ooooo00?oMgMgofIVI_ooool01?ooool00ol@413o0000okZj^P2C
ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4
o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o^[Zjob4Q8Oooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00Go410@oiRHV?oooooo^[Zjo`00002Cooooo`00O?ooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo017ooooo
0_l0000Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnYZJWo410@o`000?l@413oZJVY
09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
F
0 g
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .0309 L
.28 .0309 L
.28 0 L
F
0 g
.26 0 m
.26 .0309 L
.28 .0309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
F
0 g
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
F
0 g
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11743 L
.4 .11743 L
.4 0 L
F
0 g
.38 0 m
.38 .11743 L
.4 .11743 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .13597 L
.44 .13597 L
.44 0 L
F
0 g
.42 0 m
.42 .13597 L
.44 .13597 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .18541 L
.48 .18541 L
.48 0 L
F
0 g
.46 0 m
.46 .18541 L
.48 .18541 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .20395 L
.52 .20395 L
.52 0 L
F
0 g
.5 0 m
.5 .20395 L
.52 .20395 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .17923 L
.56 .17923 L
.56 0 L
F
0 g
.54 0 m
.54 .17923 L
.56 .17923 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
F
0 g
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
F
0 g
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
F
0 g
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
F
0 g
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
F
0 g
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
F
0 g
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool07_ooool7o`0000Cooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`Ko00004?ooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1cooooo`00I_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Roooo
o`00I_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0C_ooool00ol@413oooooooooo`0Rooooo`00I_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Loooool006Kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool7o`0007Gooooo001Vooooo`Oo00004?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo07kooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool007go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo1ol00020ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo1_l00005ooooo`Oo0000Roooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2Pooooo`00OOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0:3ooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?oo
ool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00OOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo001mooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0X?ooool007gooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Poooo
o`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`000ol0
0002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo1_l00005
ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooom4A4@00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000onk^
k_ooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool6o`000:;ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^
k^h00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oMgMgofIVIP02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Tooo
ool00ol0003oo`00ool00003ool00003o`000?oooooo000000;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`Oo000000GoV9RH
oa0@4?ooooooooooo`000005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zooo
ool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool7o`000:gooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`Oo
00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo1ol0002hooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00V_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009So
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002l
ooooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?o
EEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oooooooooooooo
ool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zj
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo
00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooo
oooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00gooooo1Ol00005ooooo`;o000000?o410@ooooooooool0TOooool007go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`00
0?ooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo09;o
oooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`00000Aooooo`03oiRHV?lQ8B7ok^k^00Cooooo1Ol0002C
ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00CoA4A4omgMgOoooooo0000U?ooool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000oooo
ooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?oMgMgofIVI_ooool00_ooool0
1?oMgMgoEEEEooooool0002Dooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo00?oMgMgolc<c?l00000U?ooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000U?ooool007cooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Aooooo`;o00008_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?oMgMgo`000?oo
ool0Toooool0093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
F
0 g
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .08034 L
.38 .08034 L
.38 0 L
F
0 g
.36 0 m
.36 .08034 L
.38 .08034 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
F
0 g
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .20395 L
.46 .20395 L
.46 0 L
F
0 g
.44 0 m
.44 .20395 L
.46 .20395 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .16069 L
.5 .16069 L
.5 0 L
F
0 g
.48 0 m
.48 .16069 L
.5 .16069 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .21631 L
.54 .21631 L
.54 0 L
F
0 g
.52 0 m
.52 .21631 L
.54 .21631 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .14833 L
.58 .14833 L
.58 0 L
F
0 g
.56 0 m
.56 .14833 L
.58 .14833 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .08652 L
.62 .08652 L
.62 0 L
F
0 g
.6 0 m
.6 .08652 L
.62 .08652 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .04944 L
.66 .04944 L
.66 0 L
F
0 g
.64 0 m
.64 .04944 L
.66 .04944 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .04944 L
.7 .04944 L
.7 0 L
F
0 g
.68 0 m
.68 .04944 L
.7 .04944 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
F
0 g
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
F
0 g
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool09?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`Oo00005Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool0067ooooo1_l00005
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0K_ooool006cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`19ooooo`03o`000?oooooooooo02;ooooo001/ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko
0000Boooool00ol@413oooooooooo`0Rooooo`00K?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0NOooool006cooooo1_l00005ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0007_ooooo001gooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool007Oooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0Q?ooool007Oooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool7o`0000Gooooo1_l00026ooooo`00P_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[o
oooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo1ol0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0009cooooo002=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008gooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOoo
ool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0YOooool008gooooo1ol00005ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo
002Gooooo`?o00001?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Gooooo`03oiRHV?lQ8B7o000000Coo`00
00Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00V?ooool00onHV9So0000ool00003ool00003o`000?l@413ooooo00;o
oooo00?o410@o`000?oo00000ooo0003o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo
00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00ol0003o^[Zjo`000004ool0
0007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`000004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo
002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol0002W
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo
002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00Sooooo0_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00VOooool6o`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Yooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00ZOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool00:Wooooo0_l0
0004ooooo`Ko0000/oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Gooooo0ol0002looooo`00Uoooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00VOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002G
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7
ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?o
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005oooo
o`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo
410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[o
oooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo
00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?oooooooooooooo
ool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool03Oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@2Booooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000oooo
o`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0TOooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02ooo
ool01Ol0003ooooooooooooooooo0000017ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`2@ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool0TOooool007gooooo1Ol00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<09;ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Dooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Pooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`2Dooooo`00
O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03
o`000?oooooooooo017ooooo0_l0000Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .0309 L
.28 .0309 L
.28 0 L
F
0 g
.26 0 m
.26 .0309 L
.28 .0309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .04326 L
.32 .04326 L
.32 0 L
F
0 g
.3 0 m
.3 .04326 L
.32 .04326 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11743 L
.4 .11743 L
.4 0 L
F
0 g
.38 0 m
.38 .11743 L
.4 .11743 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .14833 L
.44 .14833 L
.44 0 L
F
0 g
.42 0 m
.42 .14833 L
.44 .14833 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .19159 L
.48 .19159 L
.48 0 L
F
0 g
.46 0 m
.46 .19159 L
.48 .19159 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .15451 L
.52 .15451 L
.52 0 L
F
0 g
.5 0 m
.5 .15451 L
.52 .15451 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .20395 L
.56 .20395 L
.56 0 L
F
0 g
.54 0 m
.54 .20395 L
.56 .20395 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .11743 L
.6 .11743 L
.6 0 L
F
0 g
.58 0 m
.58 .11743 L
.6 .11743 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .0618 L
.64 .0618 L
.64 0 L
F
0 g
.62 0 m
.62 .0618 L
.64 .0618 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0618 L
.68 .0618 L
.68 0 L
F
0 g
.66 0 m
.66 .0618 L
.68 .0618 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .0309 L
.72 .0309 L
.72 0 L
F
0 g
.7 0 m
.7 .0309 L
.72 .0309 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
F
0 g
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo01Wooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001V
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo06Sooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04?ooooo00?o0000oooo
ooooool08_ooool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo1ol00004ooooo`Oo0000AOooool00ol@413oooooooooo`0Rooooo`00
I_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
O_ooool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo07kooooo001Vooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo1ol00020ooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08Wooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`0000Go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0ROooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08Wooooo001aooooo`Oo00004?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`29ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00R?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29oooo
o`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`29ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00R?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool6o`0000Gooooo1ol0002;ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2P
ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool000?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028
ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?ooooooA4A400;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0002R
ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?o^k^kooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oMgMgofIVIP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oo
oooo000000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oiRHV?l@41000_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qolc<c002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`Oo00001?ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002N
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_o
oooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:_ooooo002Nooooo`Oo00001?ooool00ol0003oooooooooo`08
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool00:Wooooo00?o0000oooo
ooooool02?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Yooooo`03
o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
ZOooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Zoooool00:Wooooo00?o0000ooooooooool02?ooool7o`000:gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool009Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool0
1?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ
8B400oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<
c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o
8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[o
oooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b
<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@
413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj
^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o410@olc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`00
0?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Cooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000004Oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool00000Tooo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
2oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?nHV9SooooooiRHV?lQ8B40Toooool007gooooo1Ol00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003oEEEEo`000?l@413oc<c<09?ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01;ooooo00Ko0000oooooooooooooooooeEEEOn7QhNFooooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Poooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool00ooMgMgo410@oiRHV02Eooooo`00O?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooo
oooo017ooooo0_l0000Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool01?o<c<coA4A4o`00
0?l@412Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .02472 L
.26 .02472 L
.26 0 L
F
0 g
.24 0 m
.24 .02472 L
.26 .02472 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00618 L
.3 .00618 L
.3 0 L
F
0 g
.28 0 m
.28 .00618 L
.3 .00618 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .07416 L
.34 .07416 L
.34 0 L
F
0 g
.32 0 m
.32 .07416 L
.34 .07416 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .05562 L
.38 .05562 L
.38 0 L
F
0 g
.36 0 m
.36 .05562 L
.38 .05562 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .14833 L
.42 .14833 L
.42 0 L
F
0 g
.4 0 m
.4 .14833 L
.42 .14833 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .16687 L
.46 .16687 L
.46 0 L
F
0 g
.44 0 m
.44 .16687 L
.46 .16687 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .17923 L
.5 .17923 L
.5 0 L
F
0 g
.48 0 m
.48 .17923 L
.5 .17923 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .15451 L
.54 .15451 L
.54 0 L
F
0 g
.52 0 m
.52 .15451 L
.54 .15451 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .17923 L
.58 .17923 L
.58 0 L
F
0 g
.56 0 m
.56 .17923 L
.58 .17923 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09271 L
.62 .09271 L
.62 0 L
F
0 g
.6 0 m
.6 .09271 L
.62 .09271 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .06798 L
.66 .06798 L
.66 0 L
F
0 g
.64 0 m
.64 .06798 L
.66 .06798 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .04326 L
.7 .04326 L
.7 0 L
F
0 g
.68 0 m
.68 .04326 L
.7 .04326 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
F
0 g
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .02472 L
.78 .02472 L
.78 0 L
F
0 g
.76 0 m
.76 .02472 L
.78 .02472 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
F
0 g
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool09?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Tooooo`Co00009?ooool0067ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo1ol0001Tooooo`00HOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0BOooool00ol0003oooooooooo`0Roooo
o`00HOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0BOooool00ol@413oooooooooo`0Rooooo`00HOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0K_ooool0067ooooo1_l0000@ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03_ooool6o`00073ooooo001gooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool007Oooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`0008Kooooo001g
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?
ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo
00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo001gooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo08oooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool0
07Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000TOooool007Oo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00Moooool7o`0000oooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo
002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0002Looooo`00SOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00004o`000?ooooooooooooooo`?o0000
1?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0:Gooooo002=ooooo`03o`000?oo003oo`0000?oo`0000Oo0000oooooooo
oooooooooiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?oV9RHo`000?oo00000ooo00000ol0003o410@oooo
o`02ooooo`03oa0@4?l0003oo`0000?oo`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool000;o00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo0002o`0000?ooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0YOooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000oa0@4?ooool00_ooool00ol@413o0000ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008gooooo00?o0000ool00?oo0000
0ooo00001ol0003ooooooooooooooooo0000okZj^_l000001?oo00001ol0003oMgMgoiRHV?oooooo
V9RHogMgMol000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=
ooooo`03o`000?oo003oo`0000?oo`0000Oo0000oooooooooooooooooiRHV?l@413o000000Coo`00
00Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Uooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00SOooool7o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool6o`0000Gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`Ko0000
1Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Uooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Y?ooool6o`00013o
oooo1ol0002Wooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Joooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Gooooo0ol0002looooo`00Uoooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00VOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;co
oooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool00omE
EEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oooooooooooooooo
o`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Co
oooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool0
0on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[o
oooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b
<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?oooooo
ooooooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool03Oooool5o`0000Gooooo00?o0000onk^k_ooool0Toooool007gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03oeEEEOnYZJWooooo09?ooooo001m
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`00000Aooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoeEEEOoo
ool0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^
kP06ooooo`03ob4Q8Ooooooooooo09;ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03ogMgMomVIVKooooo00Gooooo
00?oEEEEolc<c?ooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmgMgOooooo09;ooooo001mooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?oooooooooooooooolb<S80Toooool007co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0
003oooooooooo`0Aooooo`;o00008_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo1Ol0002C
ooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .02472 L
.24 .02472 L
.24 0 L
F
0 g
.22 0 m
.22 .02472 L
.24 .02472 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .03708 L
.32 .03708 L
.32 0 L
F
0 g
.3 0 m
.3 .03708 L
.32 .03708 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .09889 L
.36 .09889 L
.36 0 L
F
0 g
.34 0 m
.34 .09889 L
.36 .09889 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.38 0 m
.38 .07416 L
.4 .07416 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .15451 L
.44 .15451 L
.44 0 L
F
0 g
.42 0 m
.42 .15451 L
.44 .15451 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
F
0 g
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.52 .17305 L
.52 0 L
F
0 g
.5 0 m
.5 .17305 L
.52 .17305 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .15451 L
.56 .15451 L
.56 0 L
F
0 g
.54 0 m
.54 .15451 L
.56 .15451 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .14833 L
.6 .14833 L
.6 0 L
F
0 g
.58 0 m
.58 .14833 L
.6 .14833 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .06798 L
.64 .06798 L
.64 0 L
F
0 g
.62 0 m
.62 .06798 L
.64 .06798 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .07416 L
.68 .07416 L
.68 0 L
F
0 g
.66 0 m
.66 .07416 L
.68 .07416 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
F
0 g
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .02472 L
.8 .02472 L
.8 0 L
F
0 g
.78 0 m
.78 .02472 L
.8 .02472 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo01Wooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001K
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo06Sooooo001Kooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04?ooooo00?o0000oooo
ooooool08_ooool005_ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0@oooool00ol@413oooooooooo`0Rooooo`00
Foooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0Hooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
J?ooool005_ooooo1ol0000?ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool06?oo
ool7o`0006[ooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool0
077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00LOooool7o`0000Go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wo
oooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wo
oooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0000Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool7o`0008_ooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00OOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool007gooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo001mooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00
OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
X?ooool007gooooo1_l0000@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3o
oooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`000ol0
0002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooodA4A002ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ok^k^ooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo
00000ooo00000ol0003o8B4Qonk^kP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oMgMgofIVIP02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooo`000002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?oo
ool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oV9RHoa0@4002ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0
003o8B4Qolc<c002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`Ko0000X_ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00Toooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`000:gooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`Oo0000
1?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo1ol0002hooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool009Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool0
1?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ
8B400oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<
c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o
8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[o
oooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b
<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@
413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj
^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Oooool5o`0000?ooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`00
0?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2Cooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000004Oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool00000Tooo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
2oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80Toooool007gooooo1Ol00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?oMgMgofIVI_ooool00_oo
ool01Oo<c<co0000o`000?l0003oc<c<09?ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01;ooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@4100Toooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zj
o`00002Cooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo
0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Rooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01OnYZJWo410@o`000?l@413oZJVY09?ooooo002@ooooo`03oa0@4?oooooooooo0=Go
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
F
0 g
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00618 L
.3 .00618 L
.3 0 L
F
0 g
.28 0 m
.28 .00618 L
.3 .00618 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .06798 L
.34 .06798 L
.34 0 L
F
0 g
.32 0 m
.32 .06798 L
.34 .06798 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .09889 L
.38 .09889 L
.38 0 L
F
0 g
.36 0 m
.36 .09889 L
.38 .09889 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
F
0 g
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .19159 L
.46 .19159 L
.46 0 L
F
0 g
.44 0 m
.44 .19159 L
.46 .19159 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.48 0 m
.48 .14215 L
.5 .14215 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .19777 L
.54 .19777 L
.54 0 L
F
0 g
.52 0 m
.52 .19777 L
.54 .19777 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
F
0 g
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
F
0 g
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .07416 L
.66 .07416 L
.66 0 L
F
0 g
.64 0 m
.64 .07416 L
.66 .07416 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .05562 L
.7 .05562 L
.7 0 L
F
0 g
.68 0 m
.68 .05562 L
.7 .05562 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .02472 L
.78 .02472 L
.78 0 L
F
0 g
.76 0 m
.76 .02472 L
.78 .02472 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
F
0 g
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo01Wooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00HOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol0001T
ooooo`00HOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Rooooo`00HOooool6o`00013ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0BOooool00ol@413oooooooooo`0Rooooo`00Moooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1^ooooo`00Mooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo1_l0001`ooooo`00Moooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002
o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0Q?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Co
oooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool007Oooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0Q?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo1_l00026ooooo`00Moooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo001gooooo`Oo00001?ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo1ol0002Aooooo`00P_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Joooo
o`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00P_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool7o`0009cooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002=ooooo`Oo00001Oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00Uoooool3o`0000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Co
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00onHV9So8B4Q
o`000004ool00007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`000004ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0YOooool009Sooooo00?oV9RHo`000?oo00000ooo00000ol0003o
410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`000ol00003ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool7o`000:Oooooo002Iooooo`03o`000?oo003oo`0000;oo`00
0_l00003ooooo`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@
o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool009Oooooo00?o0000okZj^_l000001?oo00001ol0003oMgMgoiRHV?oooooo
V9RHogMgMol000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002I
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00Sooooo0_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOoo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7o
oooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool02?ooool2o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aoooo
o`00VOooool6o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo0;7ooooo002Yooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00ZOooool00ol0003oooooooooo`03ooooo`Ko0000/ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
0;cooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Ioooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo
000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgM
gOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9So
oooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uooo
ool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008go
oooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000
okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005oooo
o`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=
ooooo`Go00000oooool01?l@413o0000odA4A?o<c<bDooooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0
003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Gooooo00?oV9RHoa0@4?oMgMd0Toooool007gooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooo
oooooooo0000017ooooo00?oV9RHob4Q8Oo^k^h01oooool00on7QhOoEEEEooooo`2Booooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06
o`000?ooooooooooooooool0003ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Goc<c<
ob4Q8Ol0003oEEEEo`00002Cooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?n7QhOoooooojVYZOl000004oooool00omgMgOoIVIVooooo`02ooooo`05ob4Q
8On7QhOooooooiRHV?l00000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool04_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0TOooool007go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEE
E@2Cooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0
0006ooooo`03o`000?oooooooooo017ooooo0_l0000Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo<c<co410@o`000?lb<S;ok^k^09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .02472 L
.24 .02472 L
.24 0 L
F
0 g
.22 0 m
.22 .02472 L
.24 .02472 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
F
0 g
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .09271 L
.36 .09271 L
.36 0 L
F
0 g
.34 0 m
.34 .09271 L
.36 .09271 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.38 0 m
.38 .07416 L
.4 .07416 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .16687 L
.44 .16687 L
.44 0 L
F
0 g
.42 0 m
.42 .16687 L
.44 .16687 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
F
0 g
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .16069 L
.52 .16069 L
.52 0 L
F
0 g
.5 0 m
.5 .16069 L
.52 .16069 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .17305 L
.56 .17305 L
.56 0 L
F
0 g
.54 0 m
.54 .17305 L
.56 .17305 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .09889 L
.6 .09889 L
.6 0 L
F
0 g
.58 0 m
.58 .09889 L
.6 .09889 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .08652 L
.64 .08652 L
.64 0 L
F
0 g
.62 0 m
.62 .08652 L
.64 .08652 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .08034 L
.68 .08034 L
.68 0 L
F
0 g
.66 0 m
.66 .08034 L
.68 .08034 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .02472 L
.72 .02472 L
.72 0 L
F
0 g
.7 0 m
.7 .02472 L
.72 .02472 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .0309 L
.76 .0309 L
.76 0 L
F
0 g
.74 0 m
.74 .0309 L
.76 .0309 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .01236 L
.84 .01236 L
.84 0 L
F
0 g
.82 0 m
.82 .01236 L
.84 .01236 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo01kooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool7o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00Foooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00kooooo1_l0001Oooooo`00Foooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo04kooooo00?o0000ooooooooool08_ooool005_ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1>ooooo`03oa0@4?oooooooooo02;ooooo001Kooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Loooool005_ooooo1ol0000?ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1cooooo`00LOooool7o`0000Gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo1ol0001eooooo`00OOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wo
oooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo0000Roooool007gooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0009Oooooo001mooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00
OOooool6o`00013ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`Ko0000X_ooool009?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool0
0003ool000?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooodA4A002
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?o^k^kooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oMgMgofIVIP02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oo
oooo000000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000oiRHV?l@41000_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qolc<c002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
Toooool7o`0000Cooooo1ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2[ooooo`00ZOooool00ol0003oooooooooo`08ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool00:Wooooo00?o0000ooooooooool02?ooool7
o`000:gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009[ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`000;cooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Iooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo
00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo
00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo0;cooooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b
<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002loooo
o`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000
okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0
002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413o
oooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool0
08Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0
003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7
QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`00
0005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0=ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?oooooo
ooooooooool0003ooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`2Aooooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?oooooooooooooo
ool0003ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
002Cooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?n7
QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
0000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04Oooool00onj^[[o
8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100Toooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Cooooo`00O?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oo
oooooooo017ooooo0_l0000Rooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .01236 L
.22 .01236 L
.22 0 L
F
0 g
.2 0 m
.2 .01236 L
.22 .01236 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .05562 L
.34 .05562 L
.34 0 L
F
0 g
.32 0 m
.32 .05562 L
.34 .05562 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .09271 L
.38 .09271 L
.38 0 L
F
0 g
.36 0 m
.36 .09271 L
.38 .09271 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
F
0 g
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .19159 L
.46 .19159 L
.46 0 L
F
0 g
.44 0 m
.44 .19159 L
.46 .19159 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.48 0 m
.48 .13597 L
.5 .13597 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .18541 L
.54 .18541 L
.54 0 L
F
0 g
.52 0 m
.52 .18541 L
.54 .18541 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .13597 L
.58 .13597 L
.58 0 L
F
0 g
.56 0 m
.56 .13597 L
.58 .13597 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .08034 L
.62 .08034 L
.62 0 L
F
0 g
.6 0 m
.6 .08034 L
.62 .08034 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .11125 L
.66 .11125 L
.66 0 L
F
0 g
.64 0 m
.64 .11125 L
.66 .11125 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .03708 L
.7 .03708 L
.7 0 L
F
0 g
.68 0 m
.68 .03708 L
.7 .03708 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .0309 L
.74 .0309 L
.74 0 L
F
0 g
.72 0 m
.72 .0309 L
.74 .0309 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
F
0 g
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
F
0 g
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Sooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool7o`0000[ooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001F
ooooo`Ko00001Oooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00kooooo1ol0001Tooooo`00K?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Roooo
o`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0E?ooool00ol@413oooooooooo`0Rooooo`00K?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0NOooool006cooooo1_l00005ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko0000Noooool0
07Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`0008Ko
oooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08oooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2?ooooo`00Moooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00
P_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o0000
1?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Soooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo08oooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2?ooooo`00SOooool7o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool009Wo
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Soooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0=ooooo`Oo0000TOooool009Oooooo0ol00004ool00007o`000?o^k^ko<S8bo`000?lb<S;o
k^k^o`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Oooooo
00?oV9RHob4Q8Ol000001?oo00001ol0003oMgMgoiRHV?ooooooV9RHogMgMol000001?oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Hooooo`03oiRHV?l0003oo`0000?o
o`0000?o0000oa0@4?ooool00_ooool00ol@413o0000ool00003ool000?o00000oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool0
0002ool000;o00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@
o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Goooo
o`03o`000?nj^[[o000000Coo`0000Ko0000ogMgMonHV9SooooooiRHV?mgMgL6o`0000Gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo0000Yoooool009Oooooo00?oV9RH
oa0@4?l000001?oo00001_l0003ok^k^oc8b<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool2o`0000Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2a
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;7ooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo0;7ooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool0
09Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`;o00001?ooool6o`00
0;?ooooo002Iooooo`Ko00002_ooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002I
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGo
MgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mE
EEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o
410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?oo
ooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`0
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo
00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool0
09;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGoooo
o`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?oo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003o
oooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00gooooo00GoV9RHoa0@4?l0003o<S8bolc<
c004ooooo`Co000000?o410@ooooooooool0T?ooool007gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@
4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<
c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00Go410@okZj
^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo09;ooooo001mooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T_ooool007gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003o
oooooooooooooooo0000ooooo`Ko00003?ooool00onYZJWo410@ooooo`05ooooo`03o`000?oooooo
oooo09;ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000
ohN7QoooooooZJVYo`00000Booooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0T_oo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0
000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04Oooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go410@oiRHV?oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo09;ooooo001looooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002;ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03oeEEEOmVIVKo000009Cooooo002@ooooo`03oa0@
4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
F
0 g
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
F
0 g
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .04944 L
.32 .04944 L
.32 0 L
F
0 g
.3 0 m
.3 .04944 L
.32 .04944 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
F
0 g
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .08652 L
.4 .08652 L
.4 0 L
F
0 g
.38 0 m
.38 .08652 L
.4 .08652 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .15451 L
.44 .15451 L
.44 0 L
F
0 g
.42 0 m
.42 .15451 L
.44 .15451 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
F
0 g
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .15451 L
.52 .15451 L
.52 0 L
F
0 g
.5 0 m
.5 .15451 L
.52 .15451 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .17305 L
.56 .17305 L
.56 0 L
F
0 g
.54 0 m
.54 .17305 L
.56 .17305 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .10507 L
.6 .10507 L
.6 0 L
F
0 g
.58 0 m
.58 .10507 L
.6 .10507 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .09271 L
.64 .09271 L
.64 0 L
F
0 g
.62 0 m
.62 .09271 L
.64 .09271 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .08034 L
.68 .08034 L
.68 0 L
F
0 g
.66 0 m
.66 .08034 L
.68 .08034 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
F
0 g
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Cooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool6o`0000Gooooo00?o
0000ooooooooool09?ooool4o`0002Cooooo001Kooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06Sooooo001Koooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo04?ooooo00?o0000ooooooooool08_ooool005_ooooo1ol0000?ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`Oo0000AOooool00ol@413oooooooooo`0Rooooo`00
LOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1cooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00gooooo1ol0001eooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo08Wooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool0077o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00LOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08Wooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0ROooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29
ooooo`00LOooool7o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wo
oooo001mooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00R?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo1ol0002;ooooo`00R?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo09Gooooo0028ooooo`Ko00001Oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo1_l0002Gooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00Toooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Pooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo1_l0002Rooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_o
oooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o
0000ool00?oo00000ooo0003o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000
oooooom4A4@00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ok^k^ooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00Toooool00ol0003oo`00ool00003ool00003o`000?lQ8B7ok^k^00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ogMgMomVIVH00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooo`000002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?nHV9So
410@00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo<c<`00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Toooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Zoooool009?ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[
ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo1ol00004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00ZOoo
ool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zooo
ool00:Wooooo00?o0000ooooooooool02?ooool7o`000:gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000
ooooooooool0_?ooool009[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00003ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo
002Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo0;cooooo002Hooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o
EEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`04olc<c?m4A4Co0000
oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003o
oooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01Oo<c<co0000o`000?l0003oc<c<
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo
002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4034ooooo`00T_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eooo
ool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2
o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000
ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool5o`0009?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005oooo
o`06o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OnHV9So8B4Qonk^k_ooooooA4A409?ooooo001mooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000D
ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0U?ooool007gooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooo
oooooooo0000ooooo`Ko00003?ooool00onYZJWo410@ooooo`04ooooo`03oiRHV?lQ8B7ok^k^09?o
oooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7Qooo
ooooZJVYo`00000Booooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMgofIVI_ooool0T_ooool007go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:oooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04Oooool00onj^[[o8B4Qooooo`06oooo
o`03o`000?oooooooooo097ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05o`000?nj^[[ooooooiRHV?l@4100Toooool007cooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008_oo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Cooooo`00
T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .01236 L
.22 .01236 L
.22 0 L
F
0 g
.2 0 m
.2 .01236 L
.22 .01236 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
F
0 g
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .12361 L
.38 .12361 L
.38 0 L
F
0 g
.36 0 m
.36 .12361 L
.38 .12361 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .06798 L
.42 .06798 L
.42 0 L
F
0 g
.4 0 m
.4 .06798 L
.42 .06798 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .19777 L
.46 .19777 L
.46 0 L
F
0 g
.44 0 m
.44 .19777 L
.46 .19777 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.48 0 m
.48 .14833 L
.5 .14833 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .12979 L
.54 .12979 L
.54 0 L
F
0 g
.52 0 m
.52 .12979 L
.54 .12979 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .16687 L
.58 .16687 L
.58 0 L
F
0 g
.56 0 m
.56 .16687 L
.58 .16687 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09271 L
.62 .09271 L
.62 0 L
F
0 g
.6 0 m
.6 .09271 L
.62 .09271 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .08652 L
.66 .08652 L
.66 0 L
F
0 g
.64 0 m
.64 .08652 L
.66 .08652 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .06798 L
.7 .06798 L
.7 0 L
F
0 g
.68 0 m
.68 .06798 L
.7 .06798 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
F
0 g
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .0309 L
.78 .0309 L
.78 0 L
F
0 g
.76 0 m
.76 .0309 L
.78 .0309 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
F
0 g
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo00gooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`Oo00003oooool7o`0002Kooooo1?l0000Tooooo`00E_ooool6o`0000Gooooo1_l00005
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1^
ooooo`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Rooooo`00K?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0BOooool00ol@413oooooooooo`0Rooooo`00
K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
K_ooool006cooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo06kooooo001gooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`0>ooooo`Ko0000L?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Co
oooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool007Oooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo08Cooooo001gooooo`Oo00001?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool008;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo0022ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00P_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00P_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool0
08;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`00
08Kooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo1ol0002Aooooo`00P_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000
W?ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0YOooool008;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool0
08;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0YOooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0<ooooo`?o00001?oo00001ol0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo0022ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03?ooool00onHV9So8B4Qo`000004ool00007o`000?mgMgOoV9RHoooooonH
V9SoMgMgo`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool008;o
oooo1ol0000?ooooo`03oiRHV?l0003oo`0000?oo`0000?o0000oa0@4?ooool00_ooool00ol@413o
0000ool00003ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00
ool00002ool000;o00000oooool2o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`0000?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@
o`000?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0YOooool009Oooooo00?o0000okZj^_l000001?oo00001ol0003oMgMgoiRHV?oooooo
V9RHogMgMol000001?oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool6o`00013ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool2o`0000oooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Uooooo`00VOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOoo
ool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00kooooo1ol0002Wooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00Sooooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2looooo`00VOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;cooooo002Ioooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool2o`000;gooooo002Iooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`2looooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
_?ooool009Wooooo1_l0000:ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool009Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo0;cooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4
o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000
olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4005oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<
c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00co
oooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo
001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000
o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj^P04oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Oooool01OnHV9So410@o`000?lb
<S;oc<c<00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c02Cooooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<
c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P2Cooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
097ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?ooool0
1Oooool00onYZJWo410@ooooo`2Booooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P05ooooo`03
oa0@4?l0003o^[Zj09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo017o
oooo00?o^[Zjob4Q8Oooool01Oooool00onj^[[o8B4Qooooo`2Booooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01Ol@413oV9RHoooooonj^[[o000009?ooooo001loooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000
ooooooooool04Oooool2o`0002;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT0Toooool0093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
F
0 g
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
F
0 g
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .03708 L
.28 .03708 L
.28 0 L
F
0 g
.26 0 m
.26 .03708 L
.28 .03708 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
F
0 g
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .09271 L
.36 .09271 L
.36 0 L
F
0 g
.34 0 m
.34 .09271 L
.36 .09271 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
F
0 g
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
F
0 g
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .19777 L
.48 .19777 L
.48 0 L
F
0 g
.46 0 m
.46 .19777 L
.48 .19777 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .09271 L
.52 .09271 L
.52 0 L
F
0 g
.5 0 m
.5 .09271 L
.52 .09271 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
F
0 g
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12979 L
.6 .12979 L
.6 0 L
F
0 g
.58 0 m
.58 .12979 L
.6 .12979 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .08652 L
.64 .08652 L
.64 0 L
F
0 g
.62 0 m
.62 .08652 L
.64 .08652 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .08034 L
.68 .08034 L
.68 0 L
F
0 g
.66 0 m
.66 .08034 L
.68 .08034 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
F
0 g
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
F
0 g
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool02?ooool6o`00013ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0
0005ooooo`Ko00001Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool005_ooooo1ol00004
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00001?ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo06Sooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo02;ooooo001Vooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00gooooo1ol00015ooooo`03oa0@4?oooooooooo02;ooooo001Vooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo07kooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001Vooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo07kooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo07kooooo001Vooooo`Oo00004?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00083o
oooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0008_ooooo001m
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo09Gooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool6o`0009Oooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0X?ooool007gooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00R?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2Pooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3o
oooo0028ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo0003o`0000;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooodA4A002
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000onk^
k_ooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo0ol00008oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^
k^h00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2Pooooo`00Toooool7o`000005ogMgMomVIVKoooooooooool0
00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`Ko0000X_ooool009_ooooo00Co0000oooooooooooo
00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2[ooooo`00Uoooool01Ol0003o^[ZjoooooonHV9So410@00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00Uoooool01OnHV9So410@
o`000?lQ8B7oc<c<00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00
W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo0_l00009ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`Oo0000[Oooool009kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2loooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0_?ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;cooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2looooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo0_l0002mooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ooooooooool0_?ooool009kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Nooooo`Oo00001?ooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00V_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2loooo
o`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005
ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?oo
ool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oooooo
ooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00Uooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7Qooo
ool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;co
oooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0
003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3
o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@
4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2joooo
o`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03
o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo
000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00gooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o000000?o410@ooooooooool0
TOooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`04o`000?oooooooooooooo
o`Go0000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00onYZJWo410@
ooooo`02ooooo`04odA4A?oMgMgoooooo`0009Cooooo001mooooo`Go00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03
o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Booooo`03oa0@4?l0003o^[Zj
00?ooooo00CogMgMoeEEEOoooooo0000U?ooool007gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool04Oooool00onj^[[o8B4Qooooo`03ooooo`03ogMgMoo<c<co000009Cooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo023ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03onk^k_m4A4Co000009Cooooo001l
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o
0000ooooooooool04Oooool2o`0002;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMg
Mol0003ooooo09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
F
0 g
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
F
0 g
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .12361 L
.38 .12361 L
.38 0 L
F
0 g
.36 0 m
.36 .12361 L
.38 .12361 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .11125 L
.42 .11125 L
.42 0 L
F
0 g
.4 0 m
.4 .11125 L
.42 .11125 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .14215 L
.46 .14215 L
.46 0 L
F
0 g
.44 0 m
.44 .14215 L
.46 .14215 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.48 0 m
.48 .15451 L
.5 .15451 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .13597 L
.54 .13597 L
.54 0 L
F
0 g
.52 0 m
.52 .13597 L
.54 .13597 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .15451 L
.58 .15451 L
.58 0 L
F
0 g
.56 0 m
.56 .15451 L
.58 .15451 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .12361 L
.62 .12361 L
.62 0 L
F
0 g
.6 0 m
.6 .12361 L
.62 .12361 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .08652 L
.66 .08652 L
.66 0 L
F
0 g
.64 0 m
.64 .08652 L
.66 .08652 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .03708 L
.7 .03708 L
.7 0 L
F
0 g
.68 0 m
.68 .03708 L
.7 .03708 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
F
0 g
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01854 L
.82 .01854 L
.82 0 L
F
0 g
.8 0 m
.8 .01854 L
.82 .01854 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .01236 L
.86 .01236 L
.86 0 L
F
0 g
.84 0 m
.84 .01236 L
.86 .01236 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool00_ooool7o`00013ooooo1_l0
0005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`Co00009?ooool0067ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool7o`0005Wooooo001Qooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo03gooooo00?o0000oooo
ooooool08_ooool0067ooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`0>ooooo`Oo0000?oooool00ol@413oooooooooo`0Rooooo`00
K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
NOooool006cooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool6o`0007_ooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko0000Q_ooool007Oooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo
001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Soooool007Oooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Sooo
ool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000TOooool008;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o0000
1?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03?ooool3o`0000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Co
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo0000
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool008;ooooo1ol0000?ooooo`03oiRHV?l0003oo`0000?o
o`0000?o0000oa0@4?ooool00_ooool00ol@413o0000ool00003ool000?o00000oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`Oo0000W?ooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo
0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o
0000ool00?oo00000_oo0002o`0000?ooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003o410@ooooo`02
ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00Uoooool00ol0003o^[Zjo`000004ool00007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`00
0004ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0YOooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Wooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002T
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0:Gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Tooooo`Oo
00003oooool7o`000:Oooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00VOooool2
o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool0_?ooool009[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01?m4A4CogMgMooooool00004ooooo`05
o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Hoooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Hooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`?o0000_?ooool009Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003oEEEEo`00
0?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`04olc<c?m4A4Co0000oa0@40?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0
003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooo
oooooooo000000Gooooo0ol0002looooo`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@
4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4034ooooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Co
oooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008So
oooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Go
oooo00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o
000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM09;ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@4100
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co
0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801oooool00omgMgOo<S8booooo`2Aooooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo093ooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko0000oooo
ooooooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8boooo
o`2Aooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?n7
QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04Oooool00onj^[[o
8B4Qooooo`03ooooo`03o`000?oooooooooo09Cooooo001mooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go410@oiRHV?oo
oooo^[Zjo`000004ooooo`03o`000?oooooooooo09Cooooo001looooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`00
02;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co0000Toooool0093ooooo00?o410@oooo
ooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
F
0 g
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
F
0 g
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
F
0 g
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .02472 L
.28 .02472 L
.28 0 L
F
0 g
.26 0 m
.26 .02472 L
.28 .02472 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
F
0 g
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .09889 L
.36 .09889 L
.36 0 L
F
0 g
.34 0 m
.34 .09889 L
.36 .09889 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .12979 L
.4 .12979 L
.4 0 L
F
0 g
.38 0 m
.38 .12979 L
.4 .12979 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .10507 L
.44 .10507 L
.44 0 L
F
0 g
.42 0 m
.42 .10507 L
.44 .10507 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
F
0 g
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .10507 L
.52 .10507 L
.52 0 L
F
0 g
.5 0 m
.5 .10507 L
.52 .10507 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
F
0 g
.54 0 m
.54 .16687 L
.56 .16687 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .13597 L
.6 .13597 L
.6 0 L
F
0 g
.58 0 m
.58 .13597 L
.6 .13597 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
F
0 g
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
F
0 g
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
F
0 g
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .02472 L
.84 .02472 L
.84 0 L
F
0 g
.82 0 m
.82 .02472 L
.84 .02472 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool6o`00013ooooo1ol0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo001K
ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool7o`00013ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1M
ooooo`00I_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool06Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08_ooool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo01Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`03
oa0@4?oooooooooo02;ooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
GOooool006Kooooo1ol00004ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo01Wooooo1_l0001Oooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo07kooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool007go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo1ol00020ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`Oo0000Roooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo1_l00005ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00
00Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00Oooooo1Ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1_l0002Gooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00Sooooo00?oV9RHob4Q8Oo^k^h00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo0ol00008ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo0028ooooo`Ko00003?ooool01OmgMgOoIVIVoooooooooooo000000Goo`0000?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo002Kooooo`04
o`000?ooooooooooo`0000Goo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0:3ooooo002Gooooo`05o`000?nj^[[ooooooiRHV?l@41000_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0002Rooooo`00Uoooool01OnHV9So
410@o`000?lQ8B7oc<c<00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[oooo
o`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool009kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo0_l00009ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool0
09kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:_ooooo002Nooooo`Oo00001?ooool00ol0003ooooo
ooooo`08ooooo`Oo0000[Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00V_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00
Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7
Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool00000
0oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
0;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00
T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7
oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2j
ooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>oooo
o`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooo
oooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000
ooooooooooooooooo`000?ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B40Toooool007gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo097ooooo001mooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003oV9RHoooooonH
V9So8B4Q09?ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go
0000ohN7QoooooooZJVYo`00000Booooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oeEEEOl0003o
410@olc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Aooooo`03
okZj^_lQ8B7ooooo00;ooooo00?oEEEEohN7Qoooool0UOooool007gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol@413o
V9RHoooooonj^[[o000000?ooooo00?ogMgMoa0@4?nHV9P0UOooool007cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aoooo
o`;o00008_ooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@Tooo
ool0093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .02472 L
.26 .02472 L
.26 0 L
F
0 g
.24 0 m
.24 .02472 L
.26 .02472 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .03708 L
.34 .03708 L
.34 0 L
F
0 g
.32 0 m
.32 .03708 L
.34 .03708 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .13597 L
.38 .13597 L
.38 0 L
F
0 g
.36 0 m
.36 .13597 L
.38 .13597 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
F
0 g
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .12979 L
.46 .12979 L
.46 0 L
F
0 g
.44 0 m
.44 .12979 L
.46 .12979 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.48 0 m
.48 .15451 L
.5 .15451 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .14215 L
.54 .14215 L
.54 0 L
F
0 g
.52 0 m
.52 .14215 L
.54 .14215 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12979 L
.58 .12979 L
.58 0 L
F
0 g
.56 0 m
.56 .12979 L
.58 .12979 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .15451 L
.62 .15451 L
.62 0 L
F
0 g
.6 0 m
.6 .15451 L
.62 .15451 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .07416 L
.66 .07416 L
.66 0 L
F
0 g
.64 0 m
.64 .07416 L
.66 .07416 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .04326 L
.7 .04326 L
.7 0 L
F
0 g
.68 0 m
.68 .04326 L
.7 .04326 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
F
0 g
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .02472 L
.82 .02472 L
.82 0 L
F
0 g
.8 0 m
.8 .02472 L
.82 .02472 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .01236 L
.86 .01236 L
.86 0 L
F
0 g
.84 0 m
.84 .01236 L
.86 .01236 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo00;ooooo1ol00004ooooo`Oo00001Oooool6o`0000Gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00HOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`Oo0000FOooool0067ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Roooo
o`00HOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`0mooooo`03oa0@4?oooooooooo02;ooooo001Qooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo06;ooooo001Qooooo`Ko00001Oooool6o`0000Gooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`Ko00004?ooool7o`0006Cooooo001gooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
08Cooooo001gooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0Q?ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo08Cooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0
0026ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?oooo
o`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool7o`00097ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2J
ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool7o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo
0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03?ooool3o`0000Coo`0000Oo
0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7o000000Coo`00
00Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Coo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03oiRHV?l0003oo`0000?o
o`0000?o0000oa0@4?ooool00_ooool00ol@413o0000ool00003ool000?o00000oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
0_l00003ooooo`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00kooooo1ol00003ooooo`;o00001?oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0000Cooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?l0
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool7
o`0000kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002Gooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo1_l0000@ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0V_ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Iooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool00:Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0Iooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool00:Cooooo1ol0000Jooooo`Oo0000W?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Iooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0_?ooool009Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o
oooooooooooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<
odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03oooo
o`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000
o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q
8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:k
ooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@
o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X0
1?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c005ooooo`03o`000?o^k^kooooo09?ooooo001mooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`00
0?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05oa0@
4?nj^[[oooooogMgMolb<S801Oooool00omEEEGoZJVYooooo`2Cooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooooooo`03ooooo`03ojVYZOmEEEGooooo09?ooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko
0000ooooooooooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?ooool01Oooool00olQ8B7o
ooooooooo`2Booooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05
o`000?n7QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P06ooooo`03oeEEEOo<c<cooooo
09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo017ooooo00?o^[Zjob4Q
8Oooool01Oooool00onYZJWoMgMgooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01Ol@413ooooooooooooooooo<S8b09?ooooo001looooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Ooo
ool2o`0002;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`Go0000Toooool0093ooooo00?o
410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .01236 L
.16 .01236 L
.16 0 L
F
0 g
.14 0 m
.14 .01236 L
.16 .01236 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .02472 L
.24 .02472 L
.24 0 L
F
0 g
.22 0 m
.22 .02472 L
.24 .02472 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .04944 L
.32 .04944 L
.32 0 L
F
0 g
.3 0 m
.3 .04944 L
.32 .04944 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .08034 L
.36 .08034 L
.36 0 L
F
0 g
.34 0 m
.34 .08034 L
.36 .08034 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .10507 L
.4 .10507 L
.4 0 L
F
0 g
.38 0 m
.38 .10507 L
.4 .10507 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .13597 L
.44 .13597 L
.44 0 L
F
0 g
.42 0 m
.42 .13597 L
.44 .13597 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .15451 L
.48 .15451 L
.48 0 L
F
0 g
.46 0 m
.46 .15451 L
.48 .15451 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .14215 L
.52 .14215 L
.52 0 L
F
0 g
.5 0 m
.5 .14215 L
.52 .14215 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .12979 L
.56 .12979 L
.56 0 L
F
0 g
.54 0 m
.54 .12979 L
.56 .12979 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
F
0 g
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .14833 L
.64 .14833 L
.64 0 L
F
0 g
.62 0 m
.62 .14833 L
.64 .14833 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .03708 L
.68 .03708 L
.68 0 L
F
0 g
.66 0 m
.66 .03708 L
.68 .03708 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
F
0 g
.7 0 m
.7 .03708 L
.72 .03708 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
F
0 g
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .02472 L
.84 .02472 L
.84 0 L
F
0 g
.82 0 m
.82 .02472 L
.84 .02472 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o
0000ooooooooool09?ooool4o`0002Cooooo0015ooooo`Ko00004?ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0GOooool005_ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08_ooool005_ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo1ol00004ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo03Sooooo00?o410@ooooooooool08_ooool005_ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`1Mooooo`00Foooool7o`0000oooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool06Ooo
ool6o`0005oooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001aooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
07kooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`Oo00001?ooool7o`00083ooooo001aooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00LOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0077ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo001aoooo
o`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00
OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool6o`0000Gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00
R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00R?ooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Cooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool009?ooooo00?o0000ool00?oo00000ooo0003o`0000;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00ool00003
ool00003o`000?ooooooA4A400;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2E
ooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?o^k^kooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00ool00003ool00003
o`000?lQ8B7ok^k^00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00
Toooool00ol0003oo`00ool00003ool00003o`000?mgMgOoIVIV00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool7o`00013ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Tooo
ool00ol0003oo`00ool00003ool00003o`000?oooooo000000;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool06Ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Cooooo`Oo000000GoV9RH
oa0@4?ooooooooooo`000005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0Iooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOoo
ool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00W_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo1ol0000Kooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0UOooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01oooooo1_l0002Gooooo`00W_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009kooooo1ol00004ooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00V_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009So
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002l
ooooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?o
EEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oooooooooooooo
ool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zj
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo
00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooo
oooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo
00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40Toooool007gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo097ooooo001mooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko0000
ooooooooooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Olb<S;oV9RH
oooooonHV9So<S8b09?ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_o
oooo00Go0000ohN7QoooooooZJVYo`00000Booooo`03oa0@4?l0003o^[Zj00?ooooo00Goc<c<o`00
0?l0003o0000olc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0A
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@okZj^_oooooo^[Zjoa0@402Cooooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Pooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000009?o
oooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Ko
oooo00?o0000ooooooooool04Oooool2o`0002;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0Toooool0093ooooo00?o410@ooooooooool0eOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
F
0 g
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .04326 L
.3 .04326 L
.3 0 L
F
0 g
.28 0 m
.28 .04326 L
.3 .04326 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
F
0 g
.32 0 m
.32 .04944 L
.34 .04944 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .08034 L
.38 .08034 L
.38 0 L
F
0 g
.36 0 m
.36 .08034 L
.38 .08034 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .14215 L
.42 .14215 L
.42 0 L
F
0 g
.4 0 m
.4 .14215 L
.42 .14215 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .14833 L
.46 .14833 L
.46 0 L
F
0 g
.44 0 m
.44 .14833 L
.46 .14833 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.48 0 m
.48 .13597 L
.5 .13597 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .13597 L
.54 .13597 L
.54 0 L
F
0 g
.52 0 m
.52 .13597 L
.54 .13597 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
F
0 g
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .16687 L
.62 .16687 L
.62 0 L
F
0 g
.6 0 m
.6 .16687 L
.62 .16687 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .05562 L
.66 .05562 L
.66 0 L
F
0 g
.64 0 m
.64 .05562 L
.66 .05562 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
F
0 g
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .0309 L
.74 .0309 L
.74 0 L
F
0 g
.72 0 m
.72 .0309 L
.74 .0309 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
F
0 g
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .0309 L
.82 .0309 L
.82 0 L
F
0 g
.8 0 m
.8 .0309 L
.82 .0309 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .01236 L
.86 .01236 L
.86 0 L
F
0 g
.84 0 m
.84 .01236 L
.86 .01236 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo00;ooooo1ol00004ooooo`Oo00001Oooool6o`0000Gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo1?l0
000Tooooo`00HOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool7o`0005Wooooo001Qooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo001Qooooo`Ko
00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0mooooo`03
oa0@4?oooooooooo02;ooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
H_ooool006cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko00001Ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1Rooooo`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool6
o`00013ooooo1ol0001Tooooo`00K?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08oooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool006cooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00K?ooool6o`0000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo001g
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?
ooooo`00Moooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`Oo0000TOooool008;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_oo
ool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Jooooo`00P_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool0
08gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00001?l0003ooooooooo
ooooool3o`0000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Coo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00001ol0003oooooooooooooooooV9RH
ob4Q8Ol000001?oo00001ol0003oMgMgoiRHV?ooooooV9RHogMgMol000001?oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
V9RHo`000?oo00000ooo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`000ol0
0003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0000Cooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l00004
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00003oooo
o`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?l@413ooooo00;ooooo00?o410@o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo09[ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000Oo0000oooooooooooo
ooooo`000?nj^[[o000000Coo`0000Ko0000ogMgMonHV9SooooooiRHV?mgMgL6o`0000Gooooo1_l0
000@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000
ool00?oo00000ooo00001ol0003oooooooooooooooooV9RHoa0@4?l000001?oo00001_l0003ok^k^
oc8b<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool06Oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo09[ooooo002=ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo09[ooooo002Iooooo`Ko00002_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool00:Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002Yooooo`;o00006_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo002Yooooo`03o`000?oooooooooo
01Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00ZOooool00ol0003o
ooooooooo`0Iooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool00:Wooooo
00?o0000ooooooooool06Oooool7o`0009cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00VOooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool0
09[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool000001Oooool3o`000;cooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo
002Hooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo0;cooooo002Iooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q
8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o
0000_?ooool009Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo0;cooooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool0_?ooool009Oooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo0000
00Gooooo0ol0002looooo`00Uoooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooo
okZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?oo
ool009Oooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`2looooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005
ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000
okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@
ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0=ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01?l@413o
0000odA4A?o<c<bDooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Go
oooo00?oV9RHoa0@4?oMgMd0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000
ooooooooool01?ooool00on7QhOoEEEEooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003o
oooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002Coooo
o`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?n7QhOooooo
ojVYZOl000004_ooool00ol@413o0000okZj^P03ooooo`05ob4Q8On7QhOooooooiRHV?l00000Tooo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0
000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04Oooool00onj^[[o8B4Qoooo
o`02ooooo`05o`000?ooooooooooooooool00000Toooool007gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@2Cooooo`00O?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo
017ooooo0_l0000Rooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo<c<co410@o`000?lb
<S;ok^k^09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
F
0 g
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
F
0 g
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
F
0 g
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .03708 L
.28 .03708 L
.28 0 L
F
0 g
.26 0 m
.26 .03708 L
.28 .03708 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
F
0 g
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .08034 L
.36 .08034 L
.36 0 L
F
0 g
.34 0 m
.34 .08034 L
.36 .08034 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .10507 L
.4 .10507 L
.4 0 L
F
0 g
.38 0 m
.38 .10507 L
.4 .10507 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
F
0 g
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16069 L
.48 .16069 L
.48 0 L
F
0 g
.46 0 m
.46 .16069 L
.48 .16069 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .15451 L
.52 .15451 L
.52 0 L
F
0 g
.5 0 m
.5 .15451 L
.52 .15451 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .10507 L
.56 .10507 L
.56 0 L
F
0 g
.54 0 m
.54 .10507 L
.56 .10507 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
F
0 g
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
F
0 g
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0618 L
.68 .0618 L
.68 0 L
F
0 g
.66 0 m
.66 .0618 L
.68 .0618 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .0309 L
.72 .0309 L
.72 0 L
F
0 g
.7 0 m
.7 .0309 L
.72 .0309 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
F
0 g
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .02472 L
.8 .02472 L
.8 0 L
F
0 g
.78 0 m
.78 .02472 L
.8 .02472 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
F
0 g
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .01236 L
.88 .01236 L
.88 0 L
F
0 g
.86 0 m
.86 .01236 L
.88 .01236 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool6o`00013ooooo1ol0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ooooooooool09?ooool4o`0002Cooooo001Kooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`Ko0000E?ooool005_ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04?ooooo00?o0000oooo
ooooool08_ooool005_ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04?ooooo00?o410@oooooooo
ool08_ooool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0J?ooool006Kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`Oo0000J_oo
ool006Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00001Oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7
o`00083ooooo001Vooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool006Ko
oooo1ol0000@ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOoo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`Oo0000Roooool007gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool007gooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2E
ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
08Sooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Toooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Eooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Toooool00ol0003oo`00ool0
0003ool000?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002C
ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooom4A4@00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0009Oooooo002Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000onk^k_ooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>oooo
o`Ko0000X_ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qonk^kP02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Cooooo`Oo000000GoMgMgofIVI_ooooooooooo`000005ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
Voooool01?l0003oooooooooool00005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Ol0003o^[ZjoooooonHV9So410@00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo0;Kooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool7o`000;Sooooo002Nooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00W_ooool7o`0000Cooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Iooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0
003oooooooooo`2looooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?oo
ool009Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmE
EEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooo
oooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0
003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`00
0?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<
c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o
0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?oo
ool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cG
ooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<oooo
o`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00
O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0
003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP2Cooooo`00OOooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Toooool007gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
0000013ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100Toooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooo
oooooooooooo0000ooooo`Ko00002Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool00000Toooool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02ooo
ool01Ol0003oQhN7oooooonYZJWo0000013ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000009?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
00oooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@09?ooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo027ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg09?ooooo001l
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o
0000ooooooooool04Oooool2o`0002Cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .0309 L
.26 .0309 L
.26 0 L
F
0 g
.24 0 m
.24 .0309 L
.26 .0309 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .0309 L
.3 .0309 L
.3 0 L
F
0 g
.28 0 m
.28 .0309 L
.3 .0309 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .05562 L
.34 .05562 L
.34 0 L
F
0 g
.32 0 m
.32 .05562 L
.34 .05562 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .10507 L
.38 .10507 L
.38 0 L
F
0 g
.36 0 m
.36 .10507 L
.38 .10507 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
F
0 g
.4 0 m
.4 .09889 L
.42 .09889 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .16069 L
.46 .16069 L
.46 0 L
F
0 g
.44 0 m
.44 .16069 L
.46 .16069 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.48 0 m
.48 .14833 L
.5 .14833 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .14215 L
.54 .14215 L
.54 0 L
F
0 g
.52 0 m
.52 .14215 L
.54 .14215 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
F
0 g
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.62 .11125 L
.62 0 L
F
0 g
.6 0 m
.6 .11125 L
.62 .11125 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .06798 L
.66 .06798 L
.66 0 L
F
0 g
.64 0 m
.64 .06798 L
.66 .06798 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .06798 L
.7 .06798 L
.7 0 L
F
0 g
.68 0 m
.68 .06798 L
.7 .06798 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
F
0 g
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
F
0 g
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .02472 L
.82 .02472 L
.82 0 L
F
0 g
.8 0 m
.8 .02472 L
.82 .02472 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .01236 L
.9 .01236 L
.9 0 L
F
0 g
.88 0 m
.88 .01236 L
.9 .01236 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo00;ooooo1ol0000@ooooo`Ko00001Oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo02Cooooo1?l0000Tooooo`00HOooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool7o`0004kooooo001Qoooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0moooo
o`03o`000?oooooooooo02;ooooo001Qooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0mooooo`03
oa0@4?oooooooooo02;ooooo001Qooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
3_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06;ooooo001Qooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko00004?oo
ool7o`0006Cooooo001Qooooo`Ko00001Oooool6o`0000Gooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool007Oo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0Q?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24
ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`Oo
00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0Q?ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo08Cooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo08Cooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`24ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo1ol00005ooooo`Ko0000Q_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo
0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0022ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0V_oo
ool008;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo09[ooooo0022ooooo`Oo00004?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00VOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
1ol0002Looooo`00Uoooool3o`0000Coo`0000Oo0000onk^k_lb<S;o0000oc8b<_o^k^ko000000Co
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00onHV9So8B4Q
o`000004ool00007o`000?mgMgOoV9RHoooooonHV9SoMgMgo`000004ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0YOooool009Sooooo00?oV9RHo`000?oo00000ooo00000ol0003o
410@ooooo`02ooooo`03oa0@4?l0003oo`0000?oo`000ol00003ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool7o`000:Oooooo002Iooooo`03o`000?oo003oo`0000;oo`00
0_l00003ooooo`;o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l0
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2aooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@
o`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0/Oooool009Oooooo00?o0000okZj^_l000001?oo00001ol0003oMgMgoiRHV?oooooo
V9RHogMgMol000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0/Oooool009Oooooo00?oV9RHoa0@4?l000001?oo00001ol0003ok^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`000;?ooooo002I
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`000;kooooo002Ioooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`2loooo
o`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo0_l0002mooooo`00
VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
_?ooool009Wooooo1_l0000:ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
0;cooooo002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Ioooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo
000000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgM
gOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Hooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oo
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9So
oooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uooo
ool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008go
oooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000
okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005oooo
o`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?
ooooo`;o000000?o410@ooooooooool00_ooool4o`000003oa0@4?oooooooooo093ooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003o
oooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T_ooool007gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo0000013ooooo1Ol00006ooooo`03o`000?oooooooooo09;ooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko
0000ooooooooooooooooo`000?ooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`2Booooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;oooo
o`05o`000?n7QhOoooooojVYZOl000004?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00oooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0T_ooool007cooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00009?oo
ool00omgMgOo0000ooooo`04ooooo`03oeEEEOmVIVKo000009Cooooo002@ooooo`03oa0@4?oooooo
oooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
F
0 g
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
F
0 g
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
F
0 g
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
F
0 g
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .04326 L
.32 .04326 L
.32 0 L
F
0 g
.3 0 m
.3 .04326 L
.32 .04326 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .09271 L
.36 .09271 L
.36 0 L
F
0 g
.34 0 m
.34 .09271 L
.36 .09271 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
F
0 g
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
F
0 g
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .11125 L
.48 .11125 L
.48 0 L
F
0 g
.46 0 m
.46 .11125 L
.48 .11125 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.52 .17305 L
.52 0 L
F
0 g
.5 0 m
.5 .17305 L
.52 .17305 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .12361 L
.56 .12361 L
.56 0 L
F
0 g
.54 0 m
.54 .12361 L
.56 .12361 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
F
0 g
.58 0 m
.58 .12361 L
.6 .12361 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .10507 L
.64 .10507 L
.64 0 L
F
0 g
.62 0 m
.62 .10507 L
.64 .10507 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
F
0 g
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.72 .05562 L
.72 0 L
F
0 g
.7 0 m
.7 .05562 L
.72 .05562 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
F
0 g
.74 0 m
.74 .02472 L
.76 .02472 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .0309 L
.8 .0309 L
.8 0 L
F
0 g
.78 0 m
.78 .0309 L
.8 .0309 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
F
0 g
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool003[ooooo1_l0000@ooooo`Oo00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool6o`0000Gooooo1ol0
000Pooooo`Co00009?ooool005_ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo06Sooooo001Kooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo02;ooooo001Kooooo`Oo
00001?ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`13ooooo`03
oa0@4?oooooooooo02;ooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
J?ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1Xooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`Oo0000J_ooool0
077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0O_ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool0077ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0O_ooool0077ooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0O_ooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1n
ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo07kooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo1ol00020ooooo`00
OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eoooo
o`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool6o`0000Gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
08Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo1_l0002Gooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0X?ooool008Sooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oo003oo`0000?oo`000ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0X?ooool009?ooooo00?o
0000ool00?oo00000ooo00000ol0003ok^k^ooooo`03ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00005ooooo`Ko0000
X_ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003o8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Cooooo`Oo000000?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Voooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00
Uoooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_oo
ool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Y
ooooo`Oo0000^?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00V_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00
Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7
Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool00000
0oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
0;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00
T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7
oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2j
ooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>oooo
o`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooo
oooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00oooooo0_l000001?l@413oooooooooooooool5o`0009?ooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l0
000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Cooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000004?ooool5o`0000Cooooo00?oV9RHob4Q8Oo^k^h0U?ooool007go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool0
1_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01?m4A4CogMgMooooool00006ooooo`03
oiRHV?lQ8B7ok^k^09?ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_o
oooo00Go0000ohN7QoooooooZJVYo`00000@ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?oMgMg
ofIVI_ooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03oooool0
0omgMgOoc<c<o`000008ooooo`03o`000?oooooooooo097ooooo001mooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?ok^k^
odA4A?l000001?ooool01Ol0003o^[ZjoooooonHV9So410@09?ooooo001looooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Ooo
ool2o`0002Cooooo00?oMgMgo`000?ooool00oooool01OnHV9So410@o`000?lQ8B7oc<c<09?ooooo
002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 .00618 L
.1 .00618 L
.1 0 L
F
0 g
.08 0 m
.08 .00618 L
.1 .00618 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
F
0 g
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .03708 L
.3 .03708 L
.3 0 L
F
0 g
.28 0 m
.28 .03708 L
.3 .03708 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .08034 L
.34 .08034 L
.34 0 L
F
0 g
.32 0 m
.32 .08034 L
.34 .08034 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .09271 L
.38 .09271 L
.38 0 L
F
0 g
.36 0 m
.36 .09271 L
.38 .09271 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
F
0 g
.4 0 m
.4 .10507 L
.42 .10507 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .12979 L
.46 .12979 L
.46 0 L
F
0 g
.44 0 m
.44 .12979 L
.46 .12979 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .16687 L
.5 .16687 L
.5 0 L
F
0 g
.48 0 m
.48 .16687 L
.5 .16687 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .12361 L
.54 .12361 L
.54 0 L
F
0 g
.52 0 m
.52 .12361 L
.54 .12361 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
F
0 g
.56 0 m
.56 .12361 L
.58 .12361 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
F
0 g
.6 0 m
.6 .09889 L
.62 .09889 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .10507 L
.66 .10507 L
.66 0 L
F
0 g
.64 0 m
.64 .10507 L
.66 .10507 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .0309 L
.7 .0309 L
.7 0 L
F
0 g
.68 0 m
.68 .0309 L
.7 .0309 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .05562 L
.74 .05562 L
.74 0 L
F
0 g
.72 0 m
.72 .05562 L
.74 .05562 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .02472 L
.78 .02472 L
.78 0 L
F
0 g
.76 0 m
.76 .02472 L
.78 .02472 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
F
0 g
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .01236 L
.9 .01236 L
.9 0 L
F
0 g
.88 0 m
.88 .01236 L
.9 .01236 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00=?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003Cooooo1ol0000?ooooo`Oo00001Oooool6o`0000Gooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0Tooooo`Co00009?ooool0067ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool7o`0000oooooo1ol0001>ooooo`00HOooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`19oooo
o`03o`000?oooooooooo02;ooooo001Qooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo04Wooooo00?o410@ooooooooool08_ooool006cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`1^ooooo`00K?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool6o`00073ooooo001/ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo07Wooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo07Wooooo001/ooooo`Ko00001Oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0NOooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`1iooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo07Wooooo001goooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0NOooool007Oooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo1_l0001kooooo`00
Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Soooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Sooo
ool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo08oooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08oooooo001gooooo`Oo00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2?ooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?oooo
o`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2?ooooo`00P_ooool7o`0000Cooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo08oooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Soooool008gooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo002=ooooo`Oo00001Oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00gooooo1ol0002Aooooo`00VOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0YOooool009Oooooo0ol00004ool00007o`000?o^k^ko<S8bo`000?lb<S;o
k^k^o`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Oooooo
00?oV9RHob4Q8Ol000001?oo00001ol0003oMgMgoiRHV?ooooooV9RHogMgMol000001?oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Hooooo`03oiRHV?l0003oo`0000?o
o`0000?o0000oa0@4?ooool00_ooool00ol@413o0000ool00003ool000?o00000oooool6o`0000Go
oooo1ol0002Wooooo`00VOooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`00
00?o0000ooooooooool0_?ooool009Wooooo1ol00003ooooo`;o00001?oo00000ol0003ooooooooo
o`2looooo`00Voooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`000?oo00000ooo
00000ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooooooo0;cooooo002Gooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Coo`0000?o0000
ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2loooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo
0002o`000;gooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool0
0:Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool6o`000;ko
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00VOooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009[ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo
002Gooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?o
oooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009Oooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002H
ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Gooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`2looooo`00Uoooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oc8b<_nHV9SooooooiRH
V?lb<S800oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01Oo<
c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000okZj^_oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
Uoooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4034
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008gooooo00Co
410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o
0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03
ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03
ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7
Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?ooooo`;o
000000Wo410@oooooooooooooooooiRHV?l@413o0000oc8b<_o<c<`0Toooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`00
00cooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b09?ooooo001moooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00000@ooooo`Go00001oooool00ol0003oooooooooo`2Aooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06
o`000?ooooooooooooooool0003ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
ZJVYoa0@4?ooool0T_ooool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02ooo
ool01Ol0003oQhN7oooooonYZJWo0000013ooooo00CogMgMoeEEEOoooooo00001_ooool00ol@413o
0000okZj^P2Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0?ooooo`03
ogMgMoo<c<co000000Oooooo00?o^[Zjob4Q8Oooool0T_ooool007gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00oo^k^ko
A4A4o`000004ooooo`05oa0@4?nHV9SooooookZj^_l00000Toooool007cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aoooo
o`;o00009?ooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Toooool0
093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
F
0 g
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
F
0 g
.18 0 m
.18 .00618 L
.2 .00618 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
F
0 g
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .0309 L
.28 .0309 L
.28 0 L
F
0 g
.26 0 m
.26 .0309 L
.28 .0309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
F
0 g
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .12361 L
.36 .12361 L
.36 0 L
F
0 g
.34 0 m
.34 .12361 L
.36 .12361 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .09889 L
.4 .09889 L
.4 0 L
F
0 g
.38 0 m
.38 .09889 L
.4 .09889 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .11125 L
.44 .11125 L
.44 0 L
F
0 g
.42 0 m
.42 .11125 L
.44 .11125 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16069 L
.48 .16069 L
.48 0 L
F
0 g
.46 0 m
.46 .16069 L
.48 .16069 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .12979 L
.52 .12979 L
.52 0 L
F
0 g
.5 0 m
.5 .12979 L
.52 .12979 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .11743 L
.56 .11743 L
.56 0 L
F
0 g
.54 0 m
.54 .11743 L
.56 .11743 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
F
0 g
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
F
0 g
.62 0 m
.62 .11743 L
.64 .11743 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .05562 L
.68 .05562 L
.68 0 L
F
0 g
.66 0 m
.66 .05562 L
.68 .05562 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.72 .05562 L
.72 0 L
F
0 g
.7 0 m
.7 .05562 L
.72 .05562 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
F
0 g
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .0309 L
.8 .0309 L
.8 0 L
F
0 g
.78 0 m
.78 .0309 L
.8 .0309 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
F
0 g
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .01236 L
.92 .01236 L
.92 0 L
F
0 g
.9 0 m
.9 .01236 L
.92 .01236 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool003[ooooo1_l0000@ooooo`Oo00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`00013ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0Nooooo`Co00009?ooool005_ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo1ol00018
ooooo`00Foooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Rooooo`00Foooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0@oooool00ol@413oooooooooo`0Rooooo`00
I_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
3Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06Sooooo001Vooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0J?oo
ool006Kooooo1ol0000@ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool7
o`0006[ooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool007go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1nooooo`00OOooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo07kooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0O_ooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1n
ooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001mooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo1ol00004ooooo`Oo0000P?ooool007gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
09Gooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`Oo00001?ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo01;ooooo1Ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0B
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00004?oo
ool6o`0009Oooooo001mooooo`Ko00005Oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Iooooo`03oiRHV?lQ8B7ok^k^00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009[o
oooo00GoMgMgofIVI_ooooooooooo`000005ool00003o`000?oooooooooo00;ooooo1ol0002hoooo
o`00Voooool01?l0003oooooooooool00005ool00003o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00Uoooool01OnHV9So
410@o`000?lQ8B7oc<c<00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0;cooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2looooo`00W_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Nooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool2o`000;gooooo002Nooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00W_ooool7o`0000Co
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Iooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`2looooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
_?ooool009Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo
00?o0000ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4
A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05
o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`00
0?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<
c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<
ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:koooo
o`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`00
0?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?oo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo0_l000000ol@413ooooo
ooooo`03ooooo`;o000000?o410@ooooooooool0TOooool007gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000
oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03
olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
4?ooool5o`0000?ooooo1Ol0002Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4omgMgOoooooo0000U?ooool007gooooo1Ol0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooo
oonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo0000013o
oooo00CogMgMoeEEEOoooooo00001?ooool01?oMgMgoEEEEooooool0002Dooooo`00OOooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0?ooooo`03ogMgMoo<c<co000000Gooooo00?oMgMg
olc<c?l00000U?ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool08Oooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co
000009Cooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2
o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002Cooooo00?oMgMgo`000?ooool01Oooool0
0omgMgOo0000ooooo`2Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .01854 L
.22 .01854 L
.22 0 L
F
0 g
.2 0 m
.2 .01854 L
.22 .01854 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .03708 L
.3 .03708 L
.3 0 L
F
0 g
.28 0 m
.28 .03708 L
.3 .03708 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .06798 L
.34 .06798 L
.34 0 L
F
0 g
.32 0 m
.32 .06798 L
.34 .06798 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .12979 L
.38 .12979 L
.38 0 L
F
0 g
.36 0 m
.36 .12979 L
.38 .12979 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .08652 L
.42 .08652 L
.42 0 L
F
0 g
.4 0 m
.4 .08652 L
.42 .08652 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .14833 L
.46 .14833 L
.46 0 L
F
0 g
.44 0 m
.44 .14833 L
.46 .14833 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.48 0 m
.48 .12979 L
.5 .12979 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .12361 L
.54 .12361 L
.54 0 L
F
0 g
.52 0 m
.52 .12361 L
.54 .12361 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .09271 L
.58 .09271 L
.58 0 L
F
0 g
.56 0 m
.56 .09271 L
.58 .09271 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.62 .11743 L
.62 0 L
F
0 g
.6 0 m
.6 .11743 L
.62 .11743 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .09889 L
.66 .09889 L
.66 0 L
F
0 g
.64 0 m
.64 .09889 L
.66 .09889 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .05562 L
.7 .05562 L
.7 0 L
F
0 g
.68 0 m
.68 .05562 L
.7 .05562 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .04326 L
.74 .04326 L
.74 0 L
F
0 g
.72 0 m
.72 .04326 L
.74 .04326 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .03708 L
.78 .03708 L
.78 0 L
F
0 g
.76 0 m
.76 .03708 L
.78 .03708 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
F
0 g
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
F
0 g
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 .00618 L
.94 .00618 L
.94 0 L
F
0 g
.92 0 m
.92 .00618 L
.94 .00618 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo00;ooooo1ol00004ooooo`Oo00001Oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0000Cooooo1ol0
0004ooooo`Oo00001Oooool6o`0001_ooooo1?l0000Tooooo`00E_ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0K_ooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0BOooool00ol0003oooooooooo`0Roooo
o`00E_ooool6o`00013ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`19ooooo`03
oa0@4?oooooooooo02;ooooo001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
K_ooool006cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1^ooooo`00K?ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0K_ooool006cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`1^ooooo`00K?ooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`00073o
oooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0007_ooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0Q?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24oooo
o`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool6o`0008Kooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo1ol00004ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo
0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo0022ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo1ol0002Aooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00ko
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00P_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Jooooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00cooooo0ol0
0004ool00007o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0V_ooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7o000000Coo`0000Oo0000ogMgMonHV9SooooooiRHV?mgMgOo0000
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00kooooo1ol0002Looooo`00P_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00go
oooo00?oV9RHo`000?oo00000ooo00000ol0003o410@ooooo`02ooooo`03oa0@4?l0003oo`0000?o
o`000ol00003ooooo`Ko0000/oooool008;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0>ooooo`03o`000?oo003oo`0000;oo`000_l00003ooooo`;o00001?oo00000ol0003ooooo
ooooo`2looooo`00P_ooool7o`00013ooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo1ol0
002nooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?l@413ooooo00;ooooo00?o410@
ooooooooool00oooool00ol0003oooooooooo`2looooo`00Uoooool00ol0003o^[Zjo`000004ool0
0006o`000?mgMgOoV9RHoooooonHV9SoMgMg1Oooool00ol0003oooooooooo`2looooo`00Uoooool0
0onHV9So410@o`000004ool00006o`000?o^k^ko<S8bo`000?lb<S;ok^k^1Oooool00ol0003ooooo
ooooo`2looooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo00?o
0000ooooooooool0_?ooool009Wooooo1_l0000:ooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Iooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oo
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0_?ooool009Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`00
0?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o
410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00Uoooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool0
1Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonH
V9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool0_?ooool009Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P0
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo
00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool009Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P03ooooo`05o`000?ooooooooooooooool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0
003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000a?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo
002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0a?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o
0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo
0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo
00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`00
0?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo0_l00000
0ol@413oooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd0T_ooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`00
00cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`2Aooooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000004?ooool5o`0000Sooooo00?o0000ooooooooool0T?ooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooo
oooooooooooo0000ooooo`Ko00002Oooool01?m4A4CogMgMooooool00008ooooo`03ogMgMolb<S;o
oooo097ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000
ohN7QoooooooZJVYo`00000@ooooo`04omgMgOmEEEGoooooo`0000Gooooo00Go0000ob4Q8Ol0003o
<S8bolc<c02Booooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0?ooooo`03
ogMgMoo<c<co000000Gooooo00?o0000ooooooooool0U?ooool007gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00oo^k^ko
A4A4o`000005ooooo`03o`000?oooooooooo09Cooooo001looooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002Co
oooo00?oMgMgo`000?ooool01?ooool4o`0009?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
F
0 g
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .01854 L
.2 .01854 L
.2 0 L
F
0 g
.18 0 m
.18 .01854 L
.2 .01854 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
F
0 g
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .02472 L
.28 .02472 L
.28 0 L
F
0 g
.26 0 m
.26 .02472 L
.28 .02472 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
F
0 g
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .12979 L
.36 .12979 L
.36 0 L
F
0 g
.34 0 m
.34 .12979 L
.36 .12979 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.38 0 m
.38 .09271 L
.4 .09271 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .14215 L
.44 .14215 L
.44 0 L
F
0 g
.42 0 m
.42 .14215 L
.44 .14215 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .11125 L
.48 .11125 L
.48 0 L
F
0 g
.46 0 m
.46 .11125 L
.48 .11125 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .14833 L
.52 .14833 L
.52 0 L
F
0 g
.5 0 m
.5 .14833 L
.52 .14833 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .07416 L
.56 .07416 L
.56 0 L
F
0 g
.54 0 m
.54 .07416 L
.56 .07416 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
F
0 g
.58 0 m
.58 .11125 L
.6 .11125 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .13597 L
.64 .13597 L
.64 0 L
F
0 g
.62 0 m
.62 .13597 L
.64 .13597 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0618 L
.68 .0618 L
.68 0 L
F
0 g
.66 0 m
.66 .0618 L
.68 .0618 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .0618 L
.72 .0618 L
.72 0 L
F
0 g
.7 0 m
.7 .0618 L
.72 .0618 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .03708 L
.76 .03708 L
.76 0 L
F
0 g
.74 0 m
.74 .03708 L
.76 .03708 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.78 0 m
.78 .01854 L
.8 .01854 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
F
0 g
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 .00618 L
.96 .00618 L
.96 0 L
F
0 g
.94 0 m
.94 .00618 L
.96 .00618 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Kooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool02?ooool6o`0000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`Ko00001Oooool7o`0000Cooooo1ol0
000Eooooo`Co00009?ooool0053ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1Xooooo`00D?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`0Roooo
o`00D?ooool7o`0000oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo
0000AOooool00ol@413oooooooooo`0Rooooo`00I_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo07?ooooo001Vooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Loooool0077ooooo1ol00005ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo07?ooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo07?ooooo001mooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool7o`0007Gooooo001mooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0O_ooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1nooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001moooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1nooooo`00OOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo07kooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol00004ooooo`Oo0000P?oo
ool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo001moooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo001mooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool0
07gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
09Gooooo001mooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00001?ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00kooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0UOooool007gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0>ooooo`03o`000?oo003oo`0000?oo`000ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003ok^k^oooo
o`03ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo01Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00OOoo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo
00000ol0003o8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo01Wooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2Eooooo`00OOooool6o`00013ooooo00?o0000ool00?oo00000ooo00000ol0003oMgMgofIV
IP03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo01Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00Tooo
ool00ol0003oo`00ool00003ool00003o`000?oooooo000000?ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool06Oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo09Gooooo002Cooooo`03o`000?oo003oo`0000?oo`0000?o
0000oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0Iooooo`Ko0000Uoooool009?ooooo00?o0000ool00?oo00000ooo
00000ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Cooooo`Oo00003oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`Oo0000^?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool009Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo0;cooooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4
o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000
olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4005oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<
c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00co
oooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo
001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000
o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj^P04oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03oooool2o`000009oa0@4?oooooo
ooooooooooo^k^ko<S8bo`000?l@413oc<c<09?ooooo001mooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@
41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<
c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<ooooo`03o`000?oo
oooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Cooooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000004?ooool5o`0000?ooooo00Go0000ooooooooooooooooo`00002Cooooo`00OOooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?oo
ooooooooooooool0003ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oiRH
V?ooooooV9RHob4Q8@2Cooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;
ooooo`05o`000?n7QhOoooooojVYZOl000004?ooool01?oMgMgoEEEEooooool00004ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool03oooool00omgMgOoc<c<o`000004ooooo`03oeEEEOn7QhOooooo09Gooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027o
oooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV02Eooooo`00O?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo017o
oooo0_l0000Tooooo`03ogMgMol0003ooooo00Cooooo00Coc<c<odA4A?l0003o410@Toooool0093o
oooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .01854 L
.22 .01854 L
.22 0 L
F
0 g
.2 0 m
.2 .01854 L
.22 .01854 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
F
0 g
.24 0 m
.24 .01854 L
.26 .01854 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
F
0 g
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .08652 L
.34 .08652 L
.34 0 L
F
0 g
.32 0 m
.32 .08652 L
.34 .08652 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .09271 L
.38 .09271 L
.38 0 L
F
0 g
.36 0 m
.36 .09271 L
.38 .09271 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .12361 L
.42 .12361 L
.42 0 L
F
0 g
.4 0 m
.4 .12361 L
.42 .12361 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .13597 L
.46 .13597 L
.46 0 L
F
0 g
.44 0 m
.44 .13597 L
.46 .13597 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.48 0 m
.48 .13597 L
.5 .13597 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .10507 L
.54 .10507 L
.54 0 L
F
0 g
.52 0 m
.52 .10507 L
.54 .10507 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .09271 L
.58 .09271 L
.58 0 L
F
0 g
.56 0 m
.56 .09271 L
.58 .09271 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .12979 L
.62 .12979 L
.62 0 L
F
0 g
.6 0 m
.6 .12979 L
.62 .12979 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .09889 L
.66 .09889 L
.66 0 L
F
0 g
.64 0 m
.64 .09889 L
.66 .09889 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .05562 L
.7 .05562 L
.7 0 L
F
0 g
.68 0 m
.68 .05562 L
.7 .05562 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .05562 L
.74 .05562 L
.74 0 L
F
0 g
.72 0 m
.72 .05562 L
.74 .05562 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .03708 L
.78 .03708 L
.78 0 L
F
0 g
.76 0 m
.76 .03708 L
.78 .03708 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
F
0 g
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 .01236 L
.94 .01236 L
.94 0 L
F
0 g
.92 0 m
.92 .01236 L
.94 .01236 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo01Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`02ooooo`Oo00001?ooool7o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo01Wooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool06Oooool4o`0002Cooooo001Fooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`0Uooooo`Ko0000@oooool005Kooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo04Wooooo00?o0000oooo
ooooool08_ooool005Kooooo1_l00005ooooo`Ko00001Oooool6o`0000Gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo04Wooooo00?o410@oooooooo
ool08_ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo06kooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`1^ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`1^ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0K_ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`00073o
oooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo07Wooooo001g
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo07Wooooo001gooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko
00001Oooool6o`0007_ooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2?ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo08oooooo001gooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00Moooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool007Oooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08oooooo001g
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?
ooooo`00Moooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Soooool008;ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo0000
1?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2?ooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000TOoo
ool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1_l0000@ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0V_ooool008gooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo01Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool06Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09[ooooo
002=ooooo`03o`000?oo003oo`0000?oo`0000Co0000oooooooooooooooo0ol00004ool00007o`00
0?o^k^ko<S8bo`000?lb<S;ok^k^o`000004ool00003o`000?oooooooooo01Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00007
o`000?oooooooooooooooonHV9So8B4Qo`000004ool00007o`000?mgMgOoV9RHoooooonHV9SoMgMg
o`000004ool00003o`000?oooooooooo01Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Jooooo`00SOooool7o`0000Cooooo00?oV9RHo`000?oo00000ooo00000ol0003o410@oooo
o`02ooooo`03oa0@4?l0003oo`0000?oo`000ol0000Iooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0V_ooool009Wooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0_l00004
ool00003o`000?oooooooooo01Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2J
ooooo`00VOooool00ol0003oo`00ool00002ool000;o00000oooool2o`0000Coo`0000?o0000oooo
ooooool06Oooool7o`0009cooooo002Iooooo`03o`000?oo003oo`0000;oo`0000?o0000oa0@4?oo
ool00_ooool00ol@413o0000ool00003ool00003o`000?oooooooooo0;cooooo002Gooooo`03o`00
0?nj^[[o000000Go000000GoMgMgoiRHV?ooooooV9RHogMgM`06o`000;kooooo002Gooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool009Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Goooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0
002looooo`00Uoooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`2looooo`00V?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00VOoo
ool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo^
k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oooooooooooooooo
o`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Gooooo`05o`00
0?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool00omEEEGoQhN7ooooo`05oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool00ooM
gMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Uoooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Olb<S;oV9RH
oooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oo
oooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[o
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?oo
ool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100a?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00T?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=
ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03
ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000oooo
ooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`00
0?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Ooo
ool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
3oooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000onk^k_ooool0Toooool007gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6
o`0000cooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`2Cooooo`00OOooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000004?ooool5o`0000Gooooo00?oZJVYoeEEEOooool0Toooool007gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003o
oooooooooooooooo0000ooooo`Ko00002Oooool01?m4A4CogMgMooooool00007ooooo`03ob4Q8Ooo
oooooooo09;ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go
0000ohN7QoooooooZJVYo`00000@ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?oEEEEolc<c?oo
ool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03oooool00omgMgOo
c<c<o`000007ooooo`03ojVYZOmgMgOooooo09;ooooo001mooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?ok^k^odA4A?l0
00001?ooool01Ol@413ooooooooooooooooo<S8b09?ooooo001looooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`00
02Cooooo00?oMgMgo`000?ooool00oooool5o`0009?ooooo002@ooooo`03oa0@4?oooooooooo0=Go
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
F
0 g
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .02472 L
.2 .02472 L
.2 0 L
F
0 g
.18 0 m
.18 .02472 L
.2 .02472 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
F
0 g
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0618 L
.32 .0618 L
.32 0 L
F
0 g
.3 0 m
.3 .0618 L
.32 .0618 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
F
0 g
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
F
0 g
.38 0 m
.38 .11125 L
.4 .11125 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .12361 L
.44 .12361 L
.44 0 L
F
0 g
.42 0 m
.42 .12361 L
.44 .12361 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16069 L
.48 .16069 L
.48 0 L
F
0 g
.46 0 m
.46 .16069 L
.48 .16069 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .12361 L
.52 .12361 L
.52 0 L
F
0 g
.5 0 m
.5 .12361 L
.52 .12361 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .11743 L
.56 .11743 L
.56 0 L
F
0 g
.54 0 m
.54 .11743 L
.56 .11743 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
F
0 g
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .16687 L
.64 .16687 L
.64 0 L
F
0 g
.62 0 m
.62 .16687 L
.64 .16687 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
F
0 g
.66 0 m
.66 .04944 L
.68 .04944 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .06798 L
.72 .06798 L
.72 0 L
F
0 g
.7 0 m
.7 .06798 L
.72 .06798 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .04326 L
.76 .04326 L
.76 0 L
F
0 g
.74 0 m
.74 .04326 L
.76 .04326 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .01236 L
.92 .01236 L
.92 0 L
F
0 g
.9 0 m
.9 .01236 L
.92 .01236 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 .00618 L
.96 .00618 L
.96 0 L
F
0 g
.94 0 m
.94 .00618 L
.96 .00618 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`00>_ooool6o`00013ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo01Wooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo00005Oooool4o`0002Cooooo001@
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo1ol0000Kooooo`Oo0000B?ooool0053ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0Rooooo`00D?ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo1ol0000?ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1>ooooo`03oa0@4?oooooooooo02;ooooo001@ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool06?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Loooool0053ooooo1ol0000Jooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1cooooo`00LOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Loooool0
077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
07?ooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1cooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Loooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0007Gooooo001a
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo07kooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo07kooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool0077ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
3_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001aooooo`Oo00001Ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1nooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1nooooo`00OOooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00kooooo1ol00020ooooo`00OOooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo09Gooooo001mooooo`Ko00001Oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2E
ooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo0028ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00R?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo
1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo09Gooooo002Cooooo`03o`000?oo003oo`0000?oo`000ol0
0002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooodA4A002ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0000@
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009?ooooo1ol000001Oo^
k^kooooooooooooooooo000000Goo`0000?o0000ooooooooool00_ooool7o`0001_ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00VOooool00onHV9So8B4Qonk^kP02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009[ooooo00GoMgMgofIVI_oo
ooooooooo`000005ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Kooooo`04o`000?ooooooooooo`00
00Goo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0UOooool009Oooooo00Go0000okZj^_ooooooV9RHoa0@4002oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009Oooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009ko
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oo
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00W_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo09Gooooo002Nooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0UOooool009kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`;o00008?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Noooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009kooooo1ol00004ooooo`03
o`000?oooooooooo01oooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00
ZOooool00ol0003oooooooooo`0Oooooo`Ko0000Uoooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2l
ooooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonH
V9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Go
oooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@
4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?oooooooooooooo
ool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj
^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0
093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2
o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool0
0ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l00000
1Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo00oooooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q
8Ol0003o8B4Qolc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Ooo
ool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40Toooool007gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000013ooooo1Ol0
0003ooooo`05o`000?ooooooooooooooool00000Toooool007gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000
ooooo`Ko00002Oooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
Toooool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7
oooooonYZJWo0000013ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`000?l0003o
c<c<09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00oooooo00?oMgMg
olc<c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o410@09?ooooo001mooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o
k^k^odA4A?l000001?ooool01Ol0003o^[Zjoooooonj^[[o000009?ooooo001looooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool0
4Oooool2o`0002Cooooo00?oMgMgo`000?ooool00oooool01OnYZJWo410@o`000?l@413oZJVY09?o
oooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(49) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
F
0 g
.12 0 m
.12 .00618 L
.14 .00618 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .01236 L
.18 .01236 L
.18 0 L
F
0 g
.16 0 m
.16 .01236 L
.18 .01236 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .0309 L
.22 .0309 L
.22 0 L
F
0 g
.2 0 m
.2 .0309 L
.22 .0309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
F
0 g
.28 0 m
.28 .02472 L
.3 .02472 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .08652 L
.34 .08652 L
.34 0 L
F
0 g
.32 0 m
.32 .08652 L
.34 .08652 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .08034 L
.38 .08034 L
.38 0 L
F
0 g
.36 0 m
.36 .08034 L
.38 .08034 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .14215 L
.42 .14215 L
.42 0 L
F
0 g
.4 0 m
.4 .14215 L
.42 .14215 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .11125 L
.46 .11125 L
.46 0 L
F
0 g
.44 0 m
.44 .11125 L
.46 .11125 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.48 0 m
.48 .14215 L
.5 .14215 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .11125 L
.54 .11125 L
.54 0 L
F
0 g
.52 0 m
.52 .11125 L
.54 .11125 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .11125 L
.58 .11125 L
.58 0 L
F
0 g
.56 0 m
.56 .11125 L
.58 .11125 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .09271 L
.62 .09271 L
.62 0 L
F
0 g
.6 0 m
.6 .09271 L
.62 .09271 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .11743 L
.66 .11743 L
.66 0 L
F
0 g
.64 0 m
.64 .11743 L
.66 .11743 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .08034 L
.7 .08034 L
.7 0 L
F
0 g
.68 0 m
.68 .08034 L
.7 .08034 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .04944 L
.74 .04944 L
.74 0 L
F
0 g
.72 0 m
.72 .04944 L
.74 .04944 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
F
0 g
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
F
0 g
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 .00618 L
.94 .00618 L
.94 0 L
F
0 g
.92 0 m
.92 .00618 L
.94 .00618 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 .00618 L
.98 .00618 L
.98 0 L
F
0 g
.96 0 m
.96 .00618 L
.98 .00618 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo017ooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool00_ooool7o`0000Cooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol0
000?ooooo`Oo00001Oooool6o`0000Gooooo1_l0000@ooooo`Co00009?ooool004[ooooo1ol00005
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`00073ooooo001Foooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Roooo
o`00E_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo05Cooooo00?o410@oooooooo
ool08_ooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0>ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1iooooo`00E_oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00kooooo1_l00005ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo07Wooooo001Fooooo`Ko00006oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
07Wooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo07Wooooo
001gooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo07Wooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo07Wooooo001goooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0007_ooooo001gooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?ooool007Oooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Q?oo
ool007Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`24ooooo`00Moooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0Q?ooool007Oooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`24ooooo`00Moooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6o`0008Kooooo001g
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08oooooo001gooooo`Oo00003oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo08oooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Soooool008gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o0000
1?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo08oooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00gooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2?ooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Soooool008gooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03Oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo08oooooo002=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00go
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00SOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool6o`0000Gooooo1ol0000?ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Soooool008gooooo00?o0000ool00?oo00000ooo00001?l0003ooooooooo
ooooool5o`0000?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ool00003o`000?oooooooooo
02Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00SOooool00ol0003o
o`00ool00003ool00009o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMol00004ool00003o`000?oooooooooo02Cooooo1ol0002Aooooo`00
SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01_l@413ooooooooooooooooo410@o`0000Coo`000ol0002looooo`00SOooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003o
ooooooooooooool2o`0000Coo`0000?o0000ooooooooool0_?ooool008gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`04ooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooo
oooooooo0_l00004ool00003o`000?oooooooooo0;cooooo002=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`00
0?oo00000ooo00000ol0003oooooooooo`2looooo`00SOooool00ol0003oo`00ool00003ool00009
o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@00?ooooo00KoMgMgoiRHV?ooooooV9RH
ogMgMol00004ool00003o`000?oooooooooo0;cooooo002=ooooo`03o`000?oo003oo`0000?oo`00
00Wo0000oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb
<S;ok^k^o`0000Coo`0000?o0000ooooooooool0_?ooool008gooooo1ol0000@ooooo`Ko0000__oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000Gooooo0ol0002looooo`00Uoooool01?oMgMgoEEEEooooool00004oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2l
ooooo`00V?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00VOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00Uoooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool3o`000;cooooo002Gooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oeEEEOl0003o410@
olc<c003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00
Uoooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`2looooo`00Uoooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool01?o<c<coA4A4o`000?l@4103ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
Uoooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`?o0000_?ooool009Oooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413o^[Zj
oooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
0;cooooo002Gooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000<Cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100a?ooool009;ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00
T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o
00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03
o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005
oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool03oooool2o`000008oa0@4?ooooooooooooooool@413o0000
odA4A?o<c<bDooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0
003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l@
413ogMgM09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000@ooooo`Go00001_ooool00on7QhOo
EEEEooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002Cooooo`00OOooool5o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl0
00001?ooool00ol0003oooooooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl000004?ooool01?oM
gMgoEEEEooooool00004ooooo`05ob4Q8On7QhOooooooiRHV?l00000Toooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool03oooool00omgMgOoc<c<o`000004ooooo`05o`000?oo
ooooooooooooool00000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00oo^k^koA4A4o`000004ooooo`05ob4Q
8OnHV9SoooooogMgMomEEED0Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00009?ooool00omgMgOo
0000ooooo`03ooooo`05olc<c?l@413o0000oc8b<_o^k^h0Toooool0093ooooo00?o410@oooooooo
ool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00618034 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -12 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -12 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -12 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -12 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(20)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(40)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(60)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(80)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(100)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
F
0 g
.1 0 m
.1 .00618 L
.12 .00618 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
F
0 g
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .01854 L
.2 .01854 L
.2 0 L
F
0 g
.18 0 m
.18 .01854 L
.2 .01854 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
F
0 g
.22 0 m
.22 .01854 L
.24 .01854 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
F
0 g
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .04944 L
.32 .04944 L
.32 0 L
F
0 g
.3 0 m
.3 .04944 L
.32 .04944 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
F
0 g
.34 0 m
.34 .07416 L
.36 .07416 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .11743 L
.4 .11743 L
.4 0 L
F
0 g
.38 0 m
.38 .11743 L
.4 .11743 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
F
0 g
.42 0 m
.42 .12979 L
.44 .12979 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .13597 L
.48 .13597 L
.48 0 L
F
0 g
.46 0 m
.46 .13597 L
.48 .13597 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .11743 L
.52 .11743 L
.52 0 L
F
0 g
.5 0 m
.5 .11743 L
.52 .11743 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .10507 L
.56 .10507 L
.56 0 L
F
0 g
.54 0 m
.54 .10507 L
.56 .10507 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .11743 L
.6 .11743 L
.6 0 L
F
0 g
.58 0 m
.58 .11743 L
.6 .11743 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .09889 L
.64 .09889 L
.64 0 L
F
0 g
.62 0 m
.62 .09889 L
.64 .09889 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .09271 L
.68 .09271 L
.68 0 L
F
0 g
.66 0 m
.66 .09271 L
.68 .09271 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .06798 L
.72 .06798 L
.72 0 L
F
0 g
.7 0 m
.7 .06798 L
.72 .06798 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .0309 L
.76 .0309 L
.76 0 L
F
0 g
.74 0 m
.74 .0309 L
.76 .0309 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
F
0 g
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 .00618 L
.96 .00618 L
.96 0 L
F
0 g
.94 0 m
.94 .00618 L
.96 .00618 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`00>_ooool6o`0000Gooooo1_l0
0005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool6o`0000Gooooo1ol0
0004ooooo`Oo00005Oooool4o`0002Cooooo001@ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000J_ooool0053ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04kooooo00?o0000oooo
ooooool08_ooool0053ooooo1ol00004ooooo`Oo00001?ooool7o`0000Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04kooooo00?o410@oooooooo
ool08_ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo07?ooooo001aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1cooooo`00LOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000MOooool0
077ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0O_ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool0077ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0O_ooool0077ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0O_ooool0077ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0O_ooool0077ooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0O_ooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1nooooo`00
OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo07kooooo001mooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0O_ooool007gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1nooooo`00OOooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool7o`00083ooooo001mooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`00OOooool6o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0ROooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool008Sooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0ROooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool008Sooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0ROooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo0000
Roooool008Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1_l0002Gooooo`00R?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0X?ooool008Sooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo0:3ooooo0028ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0:3ooooo
0028ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool000?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0X?ooool008Sooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000
oooooom4A4@00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0000@
ooooo`Ko0000X_ooool009?ooooo00?o0000ool00?oo00000ooo00000ol0003ok^k^ooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool3o`000;cooooo002Cooooo`03
o`000?oo003oo`0000?oo`0000?o0000ob4Q8Oo^k^h00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009?ooooo1ol000001OmgMgOoIVIV
oooooooooooo000000Goo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00
Voooool01?l0003oooooooooool00005ool00003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`Oo00001?ooool00ol0003o
ooooooooo`2looooo`00Uoooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2l
ooooo`00V_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00Uoooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`000005ooooo`?o0000_?ooool009Oooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
_?ooool009Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool009Oooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Uoooool01OmEEEGoMgMgoooooonH
V9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Gooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Go
oooo0ol0002looooo`00Uoooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?mEEEGo0000oa0@
4?o<c<`00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09Oooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0_?ooool009Oooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00Coc<c<odA4A?l0003o410@0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
09Oooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00Uoooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0_?ooool009Oooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?oooooooooooooo
ool000001Oooool3o`000;cooooo002Gooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@okZj
^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`2looooo`00Uoooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000034ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@0<Cooooo002Booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool0
093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2
o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool0
0ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l00000
1Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo00kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Toooool007gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o
410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000gooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL0Toooool007gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Gooooo
00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`2Aooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?oooooooooo
ooooool0003ooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`2Aooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05o`00
0?n7QhOoooooojVYZOl000004Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00002Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0?
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@402Cooooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Cooooo`00O?oo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`00
0?oooooooooo017ooooo0_l0000Sooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^09?o
oooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -8.54402, \
0.223898, 0.724551}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The figure shows that the distribution of particles spreads out smoothly \
over time in a manner reminiscent of solutions to the heat equation, although \
there is some noise. The noise is associated with the finite number of \
particles used in the simulation ( ",
  Cell[BoxData[
      \(TraditionalForm\`M = 200\)]],
  "). It is only by using many particles that smooth results are obtained.  \
In the limit ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ", the fraction of particles at any given position, ",
  Cell[BoxData[
      \(TraditionalForm\`\(H(j, n)\)/M\)]],
  ", is a well defined quantity  between zero to 1. Following along with the \
definition of probability given in Eq. ",
  ButtonBox["(8.1.3)",
    ButtonData:>{"Chapter8.nb", "(8.1.3)"},
    ButtonStyle->"Hyperlink"],
  ", we define  the probability",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " of finding particles at a given grid position at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ":"
}], "Text",
  CellTags->"i:10"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\  \[Congruent] \ 
        lim\+\(M \[Rule] \ \[Infinity]\)\ \(H(j, n)\)/M\)]],
  ".  "
}], "NumberedEquation",
  CellTags->"(8.1.6)"],

Cell[TextData[{
  "According to Eq. ",
  ButtonBox["(8.1.5)",
    ButtonData:>{"Chapter8.nb", "(8.1.5)"},
    ButtonStyle->"Hyperlink"],
  ", the probability satisfies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+j P(j, n) = 1\)]],
  ";"
}], "NumberedEquation",
  CellTags->"(8.1.7)"],

Cell["\<\
that is, there is unit probability of finding the particles \
somewhere on the grid.\
\>", "Text"],

Cell[TextData[{
  "\tFrom Eq. ",
  ButtonBox["(8.1.6)",
    ButtonData:>{"Chapter8.nb", "(8.1.6)"},
    ButtonStyle->"Hyperlink"],
  ", we can see that the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " is the fraction of times that particles fall at position ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", taken out of an infinite number of different trajectories.  For \
instance, at ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " we have ",
  Cell[BoxData[
      \(TraditionalForm\`P(0, 0)\  = \ 1\)]],
  ", there is unit probability of finding particles at the origin (and \
therefore, there is zero probability of finding them anywhere else).  At ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  ", we would expect from our random walk dynamics that ",
  Cell[BoxData[
      \(TraditionalForm\`P(1, 1) = \(P(\(-1\), 1)\  = \ 1/2\)\)]],
  ".  How to characterize ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 1\)]],
  " will be the subject of the next section. "
}], "Text"],

Cell[TextData[{
  "\tFirst, however, we consider another way to examine the spreading of the \
distribution: by evaluating the average position of the particles vs. time ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x\[RightAngleBracket] \
\((n)\)\)]],
  ", and the mean squared position ",
  "vs.",
  " time, ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x\^2\[RightAngleBracket] \
\((n)\)\)]],
  ". "
}], "Text"],

Cell["\tThe average position is defined as ", "Text",
  CellTags->"i:13"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\[LeftAngleBracket]x\[RightAngleBracket]\),
              "TraditionalForm"], \((n)\)}], " ", 
          "=", \(lim\+\(M \[Rule] \ \[Infinity]\)\ 
            1\/M\ \(\[Sum]\+\(k = 1\)\%M x\_j\%n\)\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.8)"],

Cell[TextData[{
  "This quantity can be obtained from the simulation data using the function \
",
  StyleBox["Mean",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " available in the ",
  StyleBox["Statistics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " add-on packages. ",
  StyleBox["Mean",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " determines the mean value of a list of numbers (though one can just take \
the sum and divide by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " ), as shown in Cell ",
  ButtonBox["8.9",
    ButtonData:>"Cell 8.9",
    ButtonStyle->"Hyperlink"],
  ". Of course, we cannot take the ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  " limit in a simulation, so our numerical results will have some \
statistical error. The size of the error will be considered in Sec. ",
  ButtonBox["8.3.2",
    ButtonData:>"c:28",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:9"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Statistics`;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(xav[n_]\  := \ Mean[pos[n]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[{n, xav[n]}, {n, 0, 50}], 
        AxesLabel \[Rule] {"\<n\>", "\<<x>/\[CapitalDelta]x\>"}];\)\)}], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 8.9"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.456168 1.13193 [
[.21429 .44367 -6 -9 ]
[.21429 .44367 6 0 ]
[.40476 .44367 -6 -9 ]
[.40476 .44367 6 0 ]
[.59524 .44367 -6 -9 ]
[.59524 .44367 6 0 ]
[.78571 .44367 -6 -9 ]
[.78571 .44367 6 0 ]
[.97619 .44367 -6 -9 ]
[.97619 .44367 6 0 ]
[1.025 .45617 0 -6 ]
[1.025 .45617 10 6 ]
[.01131 .0034 -24 -4.5 ]
[.01131 .0034 0 4.5 ]
[.01131 .11659 -24 -4.5 ]
[.01131 .11659 0 4.5 ]
[.01131 .22978 -24 -4.5 ]
[.01131 .22978 0 4.5 ]
[.01131 .34297 -24 -4.5 ]
[.01131 .34297 0 4.5 ]
[.01131 .56936 -18 -4.5 ]
[.01131 .56936 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .45617 m
.21429 .46242 L
s
[(10)] .21429 .44367 0 1 Mshowa
.40476 .45617 m
.40476 .46242 L
s
[(20)] .40476 .44367 0 1 Mshowa
.59524 .45617 m
.59524 .46242 L
s
[(30)] .59524 .44367 0 1 Mshowa
.78571 .45617 m
.78571 .46242 L
s
[(40)] .78571 .44367 0 1 Mshowa
.97619 .45617 m
.97619 .46242 L
s
[(50)] .97619 .44367 0 1 Mshowa
.125 Mabswid
.0619 .45617 m
.0619 .45992 L
s
.1 .45617 m
.1 .45992 L
s
.1381 .45617 m
.1381 .45992 L
s
.17619 .45617 m
.17619 .45992 L
s
.25238 .45617 m
.25238 .45992 L
s
.29048 .45617 m
.29048 .45992 L
s
.32857 .45617 m
.32857 .45992 L
s
.36667 .45617 m
.36667 .45992 L
s
.44286 .45617 m
.44286 .45992 L
s
.48095 .45617 m
.48095 .45992 L
s
.51905 .45617 m
.51905 .45992 L
s
.55714 .45617 m
.55714 .45992 L
s
.63333 .45617 m
.63333 .45992 L
s
.67143 .45617 m
.67143 .45992 L
s
.70952 .45617 m
.70952 .45992 L
s
.74762 .45617 m
.74762 .45992 L
s
.82381 .45617 m
.82381 .45992 L
s
.8619 .45617 m
.8619 .45992 L
s
.9 .45617 m
.9 .45992 L
s
.9381 .45617 m
.9381 .45992 L
s
.25 Mabswid
0 .45617 m
1 .45617 L
s
gsave
1.025 .45617 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0034 m
.03006 .0034 L
s
[(-0.4)] .01131 .0034 1 0 Mshowa
.02381 .11659 m
.03006 .11659 L
s
[(-0.3)] .01131 .11659 1 0 Mshowa
.02381 .22978 m
.03006 .22978 L
s
[(-0.2)] .01131 .22978 1 0 Mshowa
.02381 .34297 m
.03006 .34297 L
s
[(-0.1)] .01131 .34297 1 0 Mshowa
.02381 .56936 m
.03006 .56936 L
s
[(0.1)] .01131 .56936 1 0 Mshowa
.125 Mabswid
.02381 .02603 m
.02756 .02603 L
s
.02381 .04867 m
.02756 .04867 L
s
.02381 .07131 m
.02756 .07131 L
s
.02381 .09395 m
.02756 .09395 L
s
.02381 .13923 m
.02756 .13923 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1845 m
.02756 .1845 L
s
.02381 .20714 m
.02756 .20714 L
s
.02381 .25242 m
.02756 .25242 L
s
.02381 .27506 m
.02756 .27506 L
s
.02381 .2977 m
.02756 .2977 L
s
.02381 .32034 m
.02756 .32034 L
s
.02381 .36561 m
.02756 .36561 L
s
.02381 .38825 m
.02756 .38825 L
s
.02381 .41089 m
.02756 .41089 L
s
.02381 .43353 m
.02756 .43353 L
s
.02381 .47881 m
.02756 .47881 L
s
.02381 .50145 m
.02756 .50145 L
s
.02381 .52408 m
.02756 .52408 L
s
.02381 .54672 m
.02756 .54672 L
s
.02381 .592 m
.02756 .592 L
s
.02381 .61464 m
.02756 .61464 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(\\220) show
87.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .45617 Mdot
.04286 .30902 Mdot
.0619 .35429 Mdot
.08095 .37693 Mdot
.1 .42221 Mdot
.11905 .38825 Mdot
.1381 .34297 Mdot
.15714 .25242 Mdot
.17619 .36561 Mdot
.19524 .36561 Mdot
.21429 .2411 Mdot
.23333 .33166 Mdot
.25238 .20714 Mdot
.27143 .13923 Mdot
.29048 .07131 Mdot
.30952 .01472 Mdot
.32857 .02603 Mdot
.34762 .10527 Mdot
.36667 .13923 Mdot
.38571 .10527 Mdot
.40476 .04867 Mdot
.42381 .10527 Mdot
.44286 .11659 Mdot
.4619 .07131 Mdot
.48095 .01472 Mdot
.5 .22978 Mdot
.51905 .22978 Mdot
.5381 .20714 Mdot
.55714 .22978 Mdot
.57619 .25242 Mdot
.59524 .35429 Mdot
.61429 .28638 Mdot
.63333 .2977 Mdot
.65238 .34297 Mdot
.67143 .2977 Mdot
.69048 .2977 Mdot
.70952 .2977 Mdot
.72857 .37693 Mdot
.74762 .34297 Mdot
.76667 .34297 Mdot
.78571 .2977 Mdot
.80476 .42221 Mdot
.82381 .45617 Mdot
.84286 .38825 Mdot
.8619 .39957 Mdot
.88095 .44485 Mdot
.9 .47881 Mdot
.91905 .60332 Mdot
.9381 .58068 Mdot
.95714 .50145 Mdot
.97619 .46749 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0oooooom;ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001_ooool00ol0003oooooooooo`1Fooooo`;o0000<oooool2o`000;Oooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo
05Kooooo0_l0000cooooo`;o0000]oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000G?ooool2o`000>Kooooo000Qooooo`03o`000?oo
oooooooo05cooooo0_l0003Vooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0001dooooo`;o0000c_ooool0027ooooo00?o0000ooooooooool0M?ooool2o`00
0<kooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00053o
oooo0_l0000dooooo`;o0000_?ooool0027ooooo00?o0000ooooooooool0D?ooool2o`0003Cooooo
0_l0002looooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo06;ooooo0_l0000:ooooo`;o00002_ooool2o`000<Sooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03
o`000?oooooooooo06;ooooo0_l0000:ooooo`;o00002_ooool2o`000<Sooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05oooo
o`03o`000?oooooooooo0?ooooooAOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20ooooo`;o0000`_ooool000Oo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Cooooo0ol00020oooo
o`;o0000`_ooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00kooooo00?o^[Zjob4Q8Oooool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`1:ooooo`;o00007?ooool2o`00
0=[ooooo000Qooooo`?o0000B_ooool2o`0001cooooo0_l0003Jooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000A?ooool2o`0005Oooooo0_l0002Uooooo`008Oooool00ol0003ooooooooo
o`14ooooo`;o0000Eoooool2o`000:Gooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o0000TOooool2
o`0000Cooooo0_l0000:ooooo`;o0000Woooool000Oooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0TOooool2o`0000Cooooo0_l0000:
ooooo`;o0000Woooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo03Sooooo0_l0
003oooooo`_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0>?ooool2o`000?oooooo2oooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o00009_ooool2o`00087ooooo0_l0002Iooooo`008Oooool00ol0003oooooooooo`0Vooooo`;o
0000POooool2o`0009Wooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0;Gooooo0_l0002=oooo
o`008Oooool00ol0003oooooooooo`2eooooo`;o0000SOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000^oooool2
o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0001Kooooo0_l0001Gooooo`008Oooool00ol0
003oooooooooo`2kooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`;o00005_ooool2o`00
05Oooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
0oooool2o`000?oooooo@?ooool0027ooooo00?o0000ooooooooool00oooool2o`000?oooooo@?oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0?_ooool2
o`000?oooooo1Oooool0027ooooo00?o0000ooooooooool0?_ooool2o`000?oooooo1Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`04oooo
o`?o00008?ooool2o`0009oooooo0_l0000Looooo`;o00001?ooool2o`0005gooooo0007ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
023ooooo0_l0002Oooooo`;o00007?ooool2o`0000Cooooo0_l0001Mooooo`001oooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool2o`000:Cooooo0_l0002Coooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001_ooool00ol0
003oooooooooo`09ooooo`;o0000Y?ooool2o`0009?ooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0000/ooooo`;o00001?ooool2o`000?oooooo4Oooool0027ooooo00?o
0000ooooooooool0;?ooool2o`0000Cooooo0_l0003ooooooa7ooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`0?ooooo`;o0000b?ooool2o`0006Wooooo000Qooooo`03o`000?oooooooooo00oooooo
0_l00038ooooo`;o0000JOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`0001[ooooo0_l0003Pooooo`;o0000A_ooool0027ooooo00?o0000ooooooooool06_ooool2o`00
0>3ooooo0_l00016ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0ooooool3ooooo`;o0000@?oo
ool0027ooooo00?o0000ooooooooool0ooooool3ooooo`;o0000@?ooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`0cooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kRkooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0`ooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0<?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`008Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02oooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`0Gooooo`008Oooool00ol0003oooooooooo`0Eooooo`;o00007_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100;oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool0;?ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4002o`0003;o
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0Eooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000<?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000<_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000;_ooool01?m4A4CogMgMoooo
ool00004ooooo`04o`000?ooooooooooooooo`?o0000<Oooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool05Oooool0027ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000<Oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool00000<Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool00000;_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
0000<?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000G
ooooo`008Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400booooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0`ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400_ooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400`ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400Gooooo`008Oooool3o`0003Gooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0_ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0`ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0G
ooooo`008Oooool00ol0003oooooooooo`0cooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0^ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0<?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<?ooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo2Oooool2o`0003[ooooo000Qooooo`03
o`000?oooooooooo0?oooooo2Oooool2o`00033ooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`01ooooo`008Oooool00ol0003oooooooooo`3ooooooccooooo00Go0000oooooooo
ooooooooo`000004ooooo`008Oooool2o`000?Oooooo0_l00013ooooo`05o`000?oooooooooooooo
ool000001?ooool001[oooooool0000jo`0000cooooo00Go0000ooooooooooooooooo`000004oooo
o`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00Go0000ohN7Qooo
ooooZJVYo`000004ooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool04?ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;o
oooo000Qooooo`03o`000?oooooooooo0?oooooo9oooool2o`0001cooooo000Qooooo`03o`000?oo
oooooooo0?oooooo9oooool2o`0001cooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0ooooool?ooooo`;o0000=?ooool0027ooooo0ol0003oooooo`oo
oooo0_l0000dooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooolQooooo`;o00008_ooool0027ooooo0ol0003oooooob7ooooo0_l0
000Rooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo6oooool2o`0002Sooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo6oooool2o`00
02Sooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
oooo5Oooool2o`0002kooooo000Qooooo`03o`000?oooooooooo0?oooooo5Oooool2o`0002kooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`008oooool00olQ8B7ogMgMooooo`3ooooood?ooooo000@ooooo`03oiRHV?lQ8B7o
oooo00;o00000_ooool2o`0000;ooooo00?o8B4QoiRHV?ooool01Oooool00onHV9SoEEEEooooo`03
ooooo`03oc8b<_l0003o000000?o000000?o<S8booooooooool00_l00002ooooo`;o0000oooooola
ooooo`003Oooool03?oMgMgoIVIVo`000?mEEEGo^[Zjooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@;ooooo00GoZJVYoeEEEOl0003oIVIVomgMg@04ooooo`03o`000?oMgMgooooo00;ooooo00?oV9RH
odA4A?ooool00_ooool02_m4A4CoV9RHooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMgooooo
oc7ooooo000<ooooo`04oiRHV?l0003o410@omgMg@Cooooo00CogMgMo`000?l@413oc<c<1Oooool0
1?oMgMgo410@o`000?nHV9P3ooooo`;oMgMg1?ooool01Ol@413ogMgMoooooooMgMgo410@00Cooooo
00CogMgMo`000?l@413oc<c<oooooolbooooo`003Oooool01OoMgMgoIVIVo`000?mEEEGo^[Zj00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^0oooool01Onj^[[oEEEEo`000?mVIVKogMgM00Cooooo00?ok^k^
oa0@4?o^k^h00oooool01On7QhOoMgMgoooooomVIVKoQhN700Cooooo00Cok^k^ob4Q8Ol@413ok^k^
oooooolbooooo`004?ooool01OnHV9So8B4Qoooooooooooo8B4Q00;oMgMg00Ko<S8boooooooooooo
ooooob4Q8OnHV9P8ooooo`03oeEEEOnHV9Sooooo00;ooooo00Gok^k^oa0@4?o^k^ko410@onk^kP04
ooooo`04ob4Q8OmgMgOoMgMgoc8b<_oooooo<_ooool001?ooooo0_l00002ooooo`;o00003?ooool0
0ooMgMgo410@ooooo`03ooooo`03ogMgMolQ8B7oEEEE00Cooooo0_l00002ooooo`;o0000oooooola
ooooo`009_ooool00omEEEGoV9RHooooo`02ooooo`03omgMgOl0003ogMgM0?oooooo>oooool002Ko
oooo00?o^[ZjodA4A?ooool00oooool00onYZJWoooooooooo`3ooooooc[ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.70097, -0.417388, \
0.210187, 0.00353693}}]
}, Open  ]],

Cell[TextData[{
  "The average position fluctuates around zero, because the particles spread \
equally in both directions in an unbiased random walk. Fluctuations in this \
quantity are related to the finite number of particles in the simulation, in \
this case, ",
  Cell[BoxData[
      \(TraditionalForm\`M = 200\)]],
  ". For example, if there were only one particle, the average position would \
fluctuate considerably, but as ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  " these fluctuations are averaged out and we would expect that",
  ",",
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x\[RightAngleBracket] \((n)\) = 
        0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.9)"],

Cell["In the next section we will prove this result.", "Text"],

Cell[TextData[{
  "\tThe spreading of the particle distribution is characterized by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            FormBox[\(\[LeftAngleBracket]x\^2\[RightAngleBracket]\),
              "TraditionalForm"],
            "TraditionalForm"], \((n)\)}], TraditionalForm]]],
  ", defined as"
}], "Text",
  CellTags->"i:31"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(x\^2\), 
              "\[RightAngleBracket]"}], \((n)\)}], " ", 
          "=", \(lim\+\(M \[Rule] \ \[Infinity]\)\ 
            1\/M\ \(\[Sum]\+\(k = 1\)\%M\((x\_j\%n)\)\^2\)\)}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.10)"],

Cell[TextData[{
  "This function is the mean squared distance of particles from the origin.  \
The rms (root-mean-square) width of the distribution is the square root of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", and is a measure of the mean distance of particles from the origin. ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " can also be evaluated using ",
  StyleBox["Mean",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(x2av[n_]\  := \ Mean[pos[n]^2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.10"],

Cell[TextData[{
  "(Note: This command squares each element in ",
  StyleBox["pos[n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and then takes the mean. )  The result is plotted in Fig. ",
  ButtonBox["8.1",
    ButtonData:>"Fig. 8.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 0.0114514 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .12923 -12 -4.5 ]
[.01131 .12923 0 4.5 ]
[.01131 .24374 -12 -4.5 ]
[.01131 .24374 0 4.5 ]
[.01131 .35826 -12 -4.5 ]
[.01131 .35826 0 4.5 ]
[.01131 .47277 -12 -4.5 ]
[.01131 .47277 0 4.5 ]
[.01131 .58729 -12 -4.5 ]
[.01131 .58729 0 4.5 ]
[.02381 .64303 -25.25 0 ]
[.02381 .64303 25.25 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(10)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(20)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(30)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(40)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(50)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12923 m
.03006 .12923 L
s
[(10)] .01131 .12923 1 0 Mshowa
.02381 .24374 m
.03006 .24374 L
s
[(20)] .01131 .24374 1 0 Mshowa
.02381 .35826 m
.03006 .35826 L
s
[(30)] .01131 .35826 1 0 Mshowa
.02381 .47277 m
.03006 .47277 L
s
[(40)] .01131 .47277 1 0 Mshowa
.02381 .58729 m
.03006 .58729 L
s
[(50)] .01131 .58729 1 0 Mshowa
.125 Mabswid
.02381 .03762 m
.02756 .03762 L
s
.02381 .06052 m
.02756 .06052 L
s
.02381 .08342 m
.02756 .08342 L
s
.02381 .10633 m
.02756 .10633 L
s
.02381 .15213 m
.02756 .15213 L
s
.02381 .17504 m
.02756 .17504 L
s
.02381 .19794 m
.02756 .19794 L
s
.02381 .22084 m
.02756 .22084 L
s
.02381 .26665 m
.02756 .26665 L
s
.02381 .28955 m
.02756 .28955 L
s
.02381 .31245 m
.02756 .31245 L
s
.02381 .33536 m
.02756 .33536 L
s
.02381 .38116 m
.02756 .38116 L
s
.02381 .40406 m
.02756 .40406 L
s
.02381 .42697 m
.02756 .42697 L
s
.02381 .44987 m
.02756 .44987 L
s
.02381 .49568 m
.02756 .49568 L
s
.02381 .51858 m
.02756 .51858 L
s
.02381 .54148 m
.02756 .54148 L
s
.02381 .56438 m
.02756 .56438 L
s
.02381 .61019 m
.02756 .61019 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -86.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
75.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.438 moveto
(\\220) show
92.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
104.250 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
109.500 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.04286 .02617 Mdot
.0619 .03624 Mdot
.08095 .0477 Mdot
.1 .05915 Mdot
.11905 .07747 Mdot
.1381 .09098 Mdot
.15714 .09762 Mdot
.17619 .11251 Mdot
.19524 .1219 Mdot
.21429 .12465 Mdot
.23333 .13106 Mdot
.25238 .14893 Mdot
.27143 .1558 Mdot
.29048 .16129 Mdot
.30952 .17595 Mdot
.32857 .19565 Mdot
.34762 .19519 Mdot
.36667 .2071 Mdot
.38571 .22405 Mdot
.40476 .23115 Mdot
.42381 .25474 Mdot
.44286 .26252 Mdot
.4619 .27489 Mdot
.48095 .29779 Mdot
.5 .31749 Mdot
.51905 .32024 Mdot
.5381 .33215 Mdot
.55714 .34681 Mdot
.57619 .35001 Mdot
.59524 .36444 Mdot
.61429 .3862 Mdot
.63333 .38964 Mdot
.65238 .40406 Mdot
.67143 .40635 Mdot
.69048 .41643 Mdot
.70952 .41735 Mdot
.72857 .44162 Mdot
.74762 .43567 Mdot
.76667 .45857 Mdot
.78571 .47277 Mdot
.80476 .4943 Mdot
.82381 .4998 Mdot
.84286 .50667 Mdot
.8619 .52911 Mdot
.88095 .5511 Mdot
.9 .56713 Mdot
.91905 .57996 Mdot
.9381 .58316 Mdot
.95714 .60332 Mdot
.97619 .60332 Mdot
.5 Mabswid
.02381 .01472 m
.06244 .03794 L
.10458 .06327 L
.14415 .08706 L
.18221 .10994 L
.22272 .1343 L
.26171 .15774 L
.30316 .18266 L
.34309 .20666 L
.3815 .22976 L
.42237 .25433 L
.46172 .27798 L
.49955 .30073 L
.53984 .32495 L
.57861 .34826 L
.61984 .37305 L
.65954 .39692 L
.69774 .41988 L
.73838 .44432 L
.77751 .46784 L
.81909 .49284 L
.85916 .51693 L
.89771 .54011 L
.93871 .56476 L
.97619 .58729 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00F03oool400000008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^
k^h]0?ooo`D000000`3oool01@3^k^h0<c<c0000000c<c<0k^k^02d0oooo00D0VIVI014A4@000000
<c<c0<c<c0030?ooo`050>k^kP0c<c<0000003<c<`3^k^h0;`3oool200000009014A4@3oool0oooo
0?ooo`3^k^h0<c<c0000000c<c<0k^k^02h0oooo00D0A4A4000000000000<c<c0=gMg@020?ooo`05
0>k^kP0c<c<0000003<c<`3^k^h0703oool005X0oooo00<000000?ooo`3oool00P3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg02d0oooo00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2IVIT0
oooo09VIV@1gMgL0;@3oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00<0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0`0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`0a0?oo
o`0907MgM`0c<c<0oooo0?ooo`1gMgL0VIVI0?ooo`2IVIT0MgMg01`0oooo001J0?ooo`030000003o
ool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0^0?ooo`0309VIV@0R8R80k^k^00@0oooo
00D04A4A0?ooo`3oool0oooo014A4@0a0?ooo`050000003oool0oooo0?ooo`0A4A400`3oool00`0A
4A40oooo0?ooo`0[0?ooo`D000000`3oool01@0A4A40oooo0?ooo`3oool04A4A0380oooo00@00000
0?ooo`3oool04A4A0`3oool00`0A4A40oooo0?ooo`0J0?ooo`00FP3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`2IVIT08R8R0>k^kP030?ooo`050000003o
ool0oooo0?ooo`000000<03oool00`2ZZZX04A4A0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000;@3oool01014A4@0gMgM0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000<@3oool0
1@1gMgL0<c<c0?ooo`3oool0000000<0oooo00<000000?ooo`3oool06P3oool005X0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000300oooo00<0MgMg06IVIP3oool00P3o
ool01@000000oooo0?ooo`3oool0000002l0oooo00<04A4A0000002k^k/00`3oool01@000000oooo
0?ooo`3oool0000002d0oooo00@0gMgM05EEE@3oool00000103oool01@000000oooo0?ooo`3oool0
000002h0oooo00D00000028R8P000000<c<c0<c<c0020?ooo`050000003oool0oooo0?ooo`000000
703oool005X0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A0340oooo
00D000000?ooo`3oool0oooo014A4@030?ooo`03014A4@3oool0oooo02h0oooo00<0^k^k028R8P3o
ool00P3oool01@0A4A40oooo0?ooo`3oool04A4A02h0oooo00<0MgMg0<c<c0000000103oool01@0A
4A40oooo0?ooo`3oool04A4A02h0oooo00<000000?ooo`3oool0103oool01@0A4A40oooo0?ooo`3o
ool04A4A01`0oooo001J0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`0]0?ooo`050000002k^k/0oooo09VIV@0A4A400`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02d0
oooo00D04A4A09VIV@3oool0^k^k000000030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0;P3oool0
0`3^k^h0A4A4000000040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0;P3oool00`000000oooo0?oo
o`040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0703oool005P0oooo0P1EEED00`000000oooo0?oo
o`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0;@3oool01@2IVIT04A4A0000000R8R80c<c<00<0
oooo00D0k^k^03<c<`000000<c<c0>k^kP0]0?ooo`050:ZZZP0A4A400000014A4@2ZZZX00`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^02l0oooo00<0MgMg0000003oool00`3oool01@3^k^h0<c<c0000
000c<c<0k^k^02h0oooo100000030?ooo`050>k^kP0c<c<0000003<c<`3^k^h0703oool00?l0oooo
J@3oool002D0oooo00<000000?ooo`3oool0o`3ooom10?ooo`009@3oool00`000000oooo0?ooo`3o
0?oooc40oooo00@04A4A000000000000oooo0P0000000`0A4A40oooo0?ooo`070?ooo`009@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo00D000000?ooo`3oool0oooo0000000:0?ooo`009@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo00D000000?ooo`3oool0oooo0000000:0?ooo`007@3ooooo
0000038000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo000T0?ooo`80000000<0oooo
0000003oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`0500000028R8P0oooo0:ZZZP0000002P3o
ool002D0oooo00<000000?ooo`3oool00P00000d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool03`3oool00`0A4A40000007MgM`020000000309VIV@3oool0oooo00P0oooo000U0?oo
o`030000003oool0oooo0080oooo0P00003o0?ooocd0oooo000U0?ooo`030000003oool0oooo0080
oooo0`00003o0?oooc`0oooo000U0?ooo`030000003oool0oooo00D0oooo0P00003o0?ooocX0oooo
000U0?ooo`030000003oool0oooo00L0oooo0P00003o0?ooocP0oooo000U0?ooo`800000203oool3
00000?l0oooo=`3oool002D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oc@0oooo000U0?ooo`030000003oool0oooo00/0oooo0P00003o0?oooc@0oooo000U0?ooo`030000
003oool0oooo00d0oooo0P00003o0?oooc80oooo000U0?ooo`030000003oool0oooo00d0oooo0`00
003o0?oooc40oooo000U0?ooo`030000003oool0oooo0100oooo0P00003o0?ooobl0oooo000U0?oo
o`030000003oool0oooo0180oooo0`00003o0?ooob`0oooo000U0?ooo`800000503oool200000?l0
oooo;03oool002D0oooo00<000000?ooo`3oool05@3oool200000?l0oooo:P3oool002D0oooo00<0
00000?ooo`3oool05`3oool200000?l0oooo:03oool002D0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`3o0?ooobD0oooo000U0?ooo`030000003oool0oooo01X0oooo0P00003o0?oo
obD0oooo000U0?ooo`030000003oool0oooo01T0oooo0P0000000`3oool000000000003o0?ooob<0
oooo000U0?ooo`030000003oool0oooo01T0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo
803oool002D0oooo0P00000P0?ooo`800000o`3ooolP0?ooo`009@3oool00`000000oooo0?ooo`0Q
0?ooo`800000o`3ooolN0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooo`8000000P3oool20000
0?l0oooo703oool002D0oooo00<000000?ooo`3oool07`3oool2000000@0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`009@3oool00`000000oooo0?ooo`0T0?ooo`@00000o`3ooolI0?ooo`009@3o
ool00`000000oooo0?ooo`0T0?ooo`8000000P3oool200000?l0oooo5`3oool002D0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooa@0oooo000U0?ooo`800000;03oool20000
0?l0oooo503oool002D0oooo00<000000?ooo`3oool0;@3oool200000?l0oooo4P3oool002D0oooo
00<000000?ooo`3oool0:P3oool2000000<0oooo0P00003o0?oooa00oooo000U0?ooo`030000003o
ool0oooo02X0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo3@3oool001<0oooo10000000
200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^1P3oool00`000000oooo0?ooo`0`0?ooo`@0
0000o`3oool=0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL01P3oool00`000000oooo0?ooo`0`0?ooo`8000000P3oool400000?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3o
ool0=P3oool200000?l0oooo2@3oool001D0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000H0oooo0P00000h0?ooo`8000000P3oool200000?l0oooo103oool001D0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool0>@3oool400000?l0oooo103oool001D0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo
0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo000E0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`060?ooo`03
0000003oool0oooo03`0oooo0P00003o0?ooo`<0oooo000C0?ooo`80EEEE00<000000?ooo`3oool0
0P3oool01@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`3o0?ooo`009@3oool00`000000oooo0?ooo`0o0?ooo`800000o`3oool002D0oooo00<0
00000?ooo`3oool0@@3oool200000?d0oooo000U0?ooo`800000@P3oool300000?`0oooo000U0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool00P00003g0?ooo`009@3oool00`000000
oooo0?ooo`150?ooo`@00000103oool200000?40oooo000U0?ooo`030000003oool0oooo04L0oooo
0P0000040?ooo`800000l@3oool002D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3d0?ooo`009@3oool00`000000oooo0?ooo`1:0?ooo`800000m03oool002D0oooo00<000000?oo
o`3oool0C03oool200000?80oooo000U0?ooo`800000C`3oool00`000000oooo0?ooo`020?ooo`80
0000j`3oool002D0oooo00<000000?ooo`3oool0C`3oool200000080oooo0P00003[0?ooo`009@3o
ool00`000000oooo0?ooo`1A0?ooo`800000k@3oool002D0oooo00<000000?ooo`3oool0D`3oool2
00000>/0oooo000U0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0j03oool002D0
oooo00<000000?ooo`3oool0EP3oool200000>P0oooo000U0?ooo`030000003oool0oooo05P0oooo
0P0000040?ooo`800000h03oool002D0oooo0P00001I0?ooo`<000000`3oool200000>00oooo000U
0?ooo`030000003oool0oooo05/0oooo0P00003S0?ooo`009@3oool00`000000oooo0?ooo`1M0?oo
o`8000001@3oool200000=X0oooo000U0?ooo`030000003oool0oooo05l0oooo0P0000030?ooo`80
0000fP3oool002D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3L0?ooo`009@3o
ool00`000000oooo0?ooo`1R0?ooo`800000g03oool002D0oooo00<000000?ooo`3oool0I03oool2
00000=X0oooo000U0?ooo`800000I`3oool010000000oooo0?ooo`3oool200000=@0oooo000U0?oo
o`030000003oool0oooo06L0oooo0P0000000`3oool000000000003D0?ooo`009@3oool00`000000
oooo0?ooo`1Y0?ooo`800000e@3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`020?ooo`800000cP3oool00180oooo1@0000030?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
1P3oool00`000000oooo0?ooo`1/0?ooo`8000000P3oool200000<h0oooo000B0?ooo`0509VIV@0R
8R80k^k^0?ooo`14A4@00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3o
ool0KP3oool200000=00oooo000C0?ooo`0309VIV@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0
oooo014A4@060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0c@3oool001@0oooo
00<0VIVI028R8P3^k^h00`3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00001b0?ooo`80
0000c@3oool001D0oooo00<0MgMg06IVIP3oool00P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool0L`3oool200000</0oooo000F0?ooo`050000003oool0oooo0?ooo`0A
4A400`3oool00`0A4A40oooo0?ooo`040?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0b03oool00180oooo00D000000;^k^`3oool0VIVI014A4@030?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL01P3oool00`000000oooo0?ooo`1e0?ooo`<00000b03oool00180oooo00D0VIVI014A4@00
00008R8R0<c<c0030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`1e
0?ooo`80000000<0oooo0000003oool0aP3oool002D0oooo00<000000?ooo`3oool0N@3oool40000
0<<0oooo000U0?ooo`030000003oool0oooo07/0oooo0P0000330?ooo`009@3oool2000007h0oooo
00<000000?ooo`3oool0`03oool002D0oooo00<000000?ooo`3oool0OP3oool200000<00oooo000U
0?ooo`030000003oool0oooo0800oooo0`00002m0?ooo`009@3oool00`000000oooo0?ooo`210?oo
o`800000_@3oool002D0oooo00<000000?ooo`3oool0P`3oool200000;/0oooo000U0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0^03oool002D0oooo00<000000?ooo`3oool0QP3o
ool200000;P0oooo000U0?ooo`800000R@3oool200000;H0oooo000U0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0/`3oool002D0oooo00<000000?ooo`3oool0Q`3oool200000080
oooo0P00002c0?ooo`009@3oool00`000000oooo0?ooo`270?ooo`800000103oool200000;40oooo
000U0?ooo`030000003oool0oooo08l0oooo0P00002_0?ooo`009@3oool00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo0:`0oooo000U0?ooo`030000003oool0oooo0980oooo0P00002/0?oo
o`009@3oool2000009D0oooo0P00002Z0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000
203oool00`000000oooo0?ooo`2W0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000103o
ool2000000<0oooo0P00002W0?ooo`009@3oool00`000000oooo0?ooo`2B0?ooo`8000001@3oool2
00000:D0oooo000U0?ooo`030000003oool0oooo09/0oooo0P00002S0?ooo`009@3oool00`000000
oooo0?ooo`2H0?ooo`8000000`3oool00`000000oooo0?ooo`2P0?ooo`009@3oool00`000000oooo
0?ooo`2H0?ooo`800000103oool200000:00oooo000U0?ooo`800000X@3oool2000009h0oooo000U
0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0V`3oool002D0oooo00<000000?oo
o`3oool0X`3oool2000009/0oooo000U0?ooo`030000003oool0oooo09h0oooo0P0000050?ooo`80
0000V@3oool00180oooo00D0VIVI014A4@000000<c<c0<c<c0030?ooo`050>k^kP0c<c<0000003<c
<`3^k^h01P3oool00`000000oooo0?ooo`2N0?ooo`800000103oool2000000030?ooo`000000oooo
09L0oooo000B0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<00`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00H0oooo00<000000?ooo`3oool0Y03oool200000080oooo0P00002F0?ooo`005P3oool01@00
0000oooo0?ooo`3oool04A4A00<0oooo00<04A4A0?ooo`3oool0103oool200000:/0oooo0P00002D
0?ooo`005@3oool00`2ZZZX04A4A0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0940oooo000D0?ooo`03014A4@000000^k^k
00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0:T0oooo0P000002
0?ooo`800000T@3oool001D0oooo00<0^k^k028R8P3oool00P3oool01@0A4A40oooo0?ooo`3oool0
4A4A00H0oooo00<000000?ooo`3oool0Z@3oool2000000@0oooo0P00002?0?ooo`004P3oool01@0A
4A40VIVI0?ooo`2k^k/0000000<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`060?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool0S03oool00180oooo00D0ZZZZ014A4@0000004A4A0:ZZ
ZP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`2b0?ooo`800000
S03oool002D0oooo00<000000?ooo`3oool0]03oool2000008X0oooo000U0?ooo`800000]`3oool0
0`000000oooo0?ooo`270?ooo`009@3oool00`000000oooo0?ooo`2g0?ooo`800000Q`3oool002D0
oooo00<000000?ooo`3oool0[`3oool2000000P0oooo0P0000250?ooo`009@3oool00`000000oooo
0?ooo`2_0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0PP3oool002D0oooo00<0
00000?ooo`3oool0]@3oool2000000D0oooo0P0000220?ooo`009@3oool00`000000oooo0?ooo`2n
0?ooo`800000P03oool002D0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`1m0?oo
o`009@3oool200000;`0oooo0P0000040?ooo`800000O@3oool002D0oooo00<000000?ooo`3oool0
^`3oool2000000<0oooo0P0000000`3oool000000000001k0?ooo`009@3oool00`000000oooo0?oo
o`300?ooo`8000000`3oool00`000000oooo0?ooo`1h0?ooo`009@3oool00`000000oooo0?ooo`36
0?ooo`800000N03oool002D0oooo00<000000?ooo`3oool0aP3oool3000000<0oooo0P00001b0?oo
o`009@3oool00`000000oooo0?ooo`360?ooo`80000000@0oooo000000000000oooo0P00001b0?oo
o`009@3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo0780oooo000U0?ooo`800000
c@3oool200000780oooo000U0?ooo`030000003oool0oooo0<h0oooo0P00001`0?ooo`009@3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo06d0oooo000U0?ooo`030000003oool0oooo
0=40oooo0P0000050?ooo`800000IP3oool002D0oooo00<000000?ooo`3oool0dP3oool3000000<0
oooo0P00001V0?ooo`009@3oool00`000000oooo0?ooo`3B0?ooo`80000000<0oooo0000003oool0
J@3oool002D0oooo00<000000?ooo`3oool0eP3oool2000006P0oooo000U0?ooo`800000f@3oool0
0`000000oooo0?ooo`1U0?ooo`009@3oool00`000000oooo0?ooo`3I0?ooo`800000I@3oool002D0
oooo00<000000?ooo`3oool0f`3oool2000006<0oooo000U0?ooo`030000003oool0oooo0=d0oooo
0P00001Q0?ooo`009@3oool00`000000oooo0?ooo`3M0?ooo`<00000H03oool001@0oooo0P000000
2@0A4A40oooo0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo0>00
oooo00<000000?ooo`3oool0G@3oool001D0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool0h@3oool2000005d0oooo000B0?ooo`D00000
0`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo0P00003T0?ooo`800000F`3oool00180oooo
00@0A4A40=gMg@3oool00000103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0h`3oool4000005T0oooo000B0?ooo`040=gMg@1EEED0oooo000000@0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0>L0oooo0P00001G0?ooo`004`3oool00`1g
MgL0c<c<000000040?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000oooo0?ooo`3Y
0?ooo`030000003oool0oooo05@0oooo000C0?ooo`030>k^kP14A4@0000000@0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`060?ooo`030000003oool0oooo0>X0oooo0P00001D0?ooo`00503oool00`1g
MgL000000?ooo`030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`3/
0?ooo`800000DP3oool002D0oooo00<000000?ooo`3oool0j@3oool2000000<0oooo0P00001@0?oo
o`009@3oool200000>X0oooo0P0000050?ooo`030000003oool0oooo04d0oooo000U0?ooo`030000
003oool0oooo0>l0oooo1000001=0?ooo`009@3oool00`000000oooo0?ooo`3_0?ooo`8000000P3o
ool00`000000oooo0?ooo`1:0?ooo`009@3oool00`000000oooo0?ooo`3d0?ooo`<00000B@3oool0
02D0oooo00<000000?ooo`3oool0m@3oool2000004T0oooo000U0?ooo`030000003oool0oooo0?L0
oooo0P0000170?ooo`009@3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo04@0oooo
000U0?ooo`800000n`3oool2000004@0oooo000U0?ooo`030000003oool0oooo0?`0oooo0P000012
0?ooo`009@3oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo03l0oooo000U0?ooo`03
0000003oool0oooo0?X0oooo0P0000030?ooo`800000?`3oool002D0oooo00<000000?ooo`3oool0
nP3oool2000000D0oooo0P00000m0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<0
00000?ooo`3oool0>P3oool002D0oooo00<000000?ooo`3oool0o`3oool50?ooo`800000>P3oool0
02D0oooo0P00003o0?ooo`P0oooo0P00000h0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo0P00000f0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0
<`3oool002D0oooo00<000000?ooo`3oool0o`3oool10?ooo`8000002@3oool2000003<0oooo000U
0?ooo`030000003oool0oooo0?l0oooo0@3oool2000000/0oooo0P00000a0?ooo`009@3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0;P3oool002D0oooo00<000000?ooo`3o
ool0o`3ooolA0?ooo`800000;P3oool002D0oooo0P00003o0?oooa@0oooo0P00000/0?ooo`009@3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo0P00000<0?ooo`800000:P3oool002D0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`8000003P3oool00`000000oooo0?ooo`0W0?ooo`009@3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo0P00000W0?ooo`009@3oool00`000000oooo0?ooo`3o0?ooo`d0
oooo0P00000;0?ooo`8000009@3oool001<0oooo00D0A4A4000000000000<c<c0=gMg@020?ooo`05
0>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0P0000030?oo
o`800000203oool00`000000oooo0?ooo`0R0?ooo`005P3oool02@1gMgL0<c<c0?ooo`3oool0MgMg
09VIV@3oool0VIVI07MgM`060?ooo`030000003oool0oooo0?l0oooo4P3oool2000000T0oooo0P00
000R0?ooo`005`3oool010000000oooo0?ooo`0A4A430?ooo`03014A4@3oool0oooo00@0oooo0P00
003o0?ooob00oooo00<000000?ooo`3oool07`3oool001H0oooo00D0MgMg03<c<`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom10?ooo`004`3oool0
1@0000008R8R0000000c<c<0c<c<0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo0?l0oooo@@3oool001<0oooo00<000000?ooo`3oool0103oool01@0A4A40oooo0?oo
o`3oool04A4A00H0oooo00<000000?ooo`3oool0o`3ooom10?ooo`004`3oool00`000000oooo0?oo
o`040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`3o0?oood40oooo
000C0?ooo`@000000`3oool01@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool0
o`3ooolH0?ooo`800000103oool200000240oooo000U0?ooo`030000003oool0oooo0?l0oooo603o
ool2000000@0oooo0P00000Q0?ooo`009@3oool200000?l0oooo@P3oool002D0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`009@3oool00`000000oooo0?ooo`3o0?oood40oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
000W0?ooo`03028R8P3MgMd0oooo0?l0oooo?`3oool000d0oooo00<0VIVI028R8P3oool00P000002
0?ooo`800000203oool00`0R8R80VIVI0?ooo`060?ooo`0309VIV@1EEED0oooo0080oooo00<0<c<c
0000000000000`0000000`0c<c<0oooo0?ooo`0200000080oooo0P00003o0?ooobh0oooo000:0?oo
o`0<0=gMg@1VIVH0000005EEE@2ZZZX0oooo0>k^kP0R8R80R8R80<c<c0000000c<c<203oool01@2Z
ZZX0EEEE0000001VIVH0gMgM00D0oooo00H000000=gMg@3oool0oooo09VIV@14A4@30?ooo`0:04A4
A02IVIT0oooo0?ooo`3^k^h08R8R08R8R03<c<`000000<c<c?l0oooo;P3oool000T0oooo00@0VIVI
0000000A4A40gMgM103oool0103MgMd000000000003<c<`;0?ooo`040=gMg@0A4A40000009VIV@@0
oooo0P1gMgL30?ooo`05014A4@3MgMd0oooo0=gMg@0A4A40103oool0103MgMd000000000003<c<co
0?ooobl0oooo000:0?ooo`050=gMg@1VIVH0000005EEE@2ZZZX00P3oool0103^k^h08R8R0000003^
k^h90?ooo`050:ZZZP1EEED0000006IVIP3MgMd01@3oool00`3^k^h04A4A0>k^kP020?ooo`0509VI
V@1gMgL0oooo05EEE@28R8P0103oool0103^k^h08R8R0000003^k^ko0?ooobl0oooo000=0?ooo`05
09VIV@0R8R80oooo0>k^kP0R8R800P1gMgL00`0c<c<0oooo0?ooo`070?ooo`03028R8P2IVIT0oooo
00P0oooo00T0EEEE09VIV@3oool0oooo0>k^kP0A4A40k^k^014A4@3^k^h00`3oool01@3^k^h08R8R
07MgM`1gMgL0<c<c0?l0oooo;`3oool00100oooo0P0000020?ooo`80000000<0oooo000000000000
0P00000>0?ooo`030=gMg@0A4A40oooo0080oooo00<0MgMg028R8P1VIVH0103oool200000080oooo
1P00003o0?ooobX0oooo000H0?ooo`030000003oool0oooo00l0oooo00L0EEEE09VIV@3oool0oooo
0=gMg@000000gMgM00/0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`006@3oool00`000000oooo
0?ooo`0>0?ooo`030;^k^`14A4@0oooo0080oooo00<0ZZZZ0?ooo`3oool02`3oool00`000000oooo
0?ooo`3o0?ooobT0oooo000J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3o
oolX0?ooo`005`3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo00000?l0oooo
:P3oool001P0oooo0P00000R0?ooo`800000o`3oool[0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.40254, -4.32686, \
0.216127, 0.359493}}],

Cell["\<\
Fig. 8.1 Spreading of particles in a random walk simulation (dots) \
together with theory (line) \
\>", "Caption",
  CellTags->"Fig. 8.1"],

Cell[TextData[{
  "(Of course, we cannot take the ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  "limit in a simulation, so out numerical results have some statistical \
error. The size of this error will be considered in Sec. ",
  ButtonBox["8.3.2",
    ButtonData:>"i:70",
    ButtonStyle->"Hyperlink"],
  ".) The dots are values from the simulation, and the straight line is a \
theory for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  " that we will derive presently [see Eq. ",
  ButtonBox["(8.1.31)",
    ButtonData:>{"Chapter8.nb", "(8.1.31)"},
    ButtonStyle->"Hyperlink"],
  "]. It seems that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " "}], 
        TraditionalForm]]],
  "increases linearly with time, so that the rms width of the particle \
distribution increases like ",
  Cell[BoxData[
      \(TraditionalForm\`\@t\)]],
  ".  This is a signature of diffusive processes, and was observed previously \
in solutions of the heat equation [see Eq. ",
  ButtonBox["(5.1.100)",
    ButtonData:>{"Chapter5.nb", "(5.1.100)"},
    ButtonStyle->"Hyperlink"],
  "].  In fact, the width ",
  Cell[BoxData[
      \(TraditionalForm\`w(t)\)]],
  " defined in Eq. ",
  ButtonBox["(5.1.100)",
    ButtonData:>{"Chapter5.nb", "(5.1.100)"},
    ButtonStyle->"Hyperlink"],
  " is simply the rms width of the solution. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Binomial Distribution", "Section",
  CellTags->{"i:81", "c:7"}],

Cell[TextData[{
  "\tWe can analytically determine the probability distribution ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " for the preceding random walk process  by applying elementary ideas from \
probability theory. To illustrate the random walk, we first construct a ",
  StyleBox["decision tree . ",
    FontSlant->"Italic"],
  "Such a tree is shown in Fig. ",
  ButtonBox["8.2",
    ButtonData:>"Fig. 8.2",
    ButtonStyle->"Hyperlink"],
  " for the first three steps of the walk. Starting at ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  ", a particle can more either to the left or to the right to ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(\[PlusMinus]1\)\)]],
  ", and each location has an equal probability of 1/2. In the next step, the \
particles can either return to the origin, or move further away, to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]2\)\)]],
  ". There are now four possible paths taken by the particles, shown as \
dashed lines. Each path is equally likely. Only one out of four of the paths \
leads to ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(-2\)\)]],
  " and similarly for ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(+2\)\)]],
  ". However, two out of four of the paths return to ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  ". Therefore, "
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(\(-2\), 2) = \(P(2, 2) = 1/4\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P(0, 2) = \(2/4 = 1/2\)\)]],
  ". "
}], "UNNEQ"],

Cell["In fact, one can see that for an unbiased random walk", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(P(j, n)\), " ", "=", " ", 
          
          RowBox[{\(\(number\ of\ paths\ arriving\ at\ \ j\ after\ n\ steps\)\
\/\(total\ number\ \ of\ \ paths\)\), Cell[""]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.11)"],

Cell[TextData[{
  "For instance, for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)]],
  "there are now eight possible paths, and "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`P(\(-3\), 3) = \(P(3, 3) = 
        1/8\), \[IndentingNewLine]P(\(-1\), 3) = \(P(1, 3) = 
        3/8. \)\)]]], "UNNEQ"],

Cell[TextData[{
  "(Exercise: in Fig. ",
  ButtonBox["8.2",
    ButtonData:>"Fig. 8.2",
    ButtonStyle->"Hyperlink"],
  " can you see the three paths that lead to ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)]],
  "?)"
}], "Text"],

Cell[TextData[{
  "\tIt is easy to generalize these results to consider a random walk with a \
bias, where the probability of a step to the right equals ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and that for a step to the left equals ",
  Cell[BoxData[
      \(TraditionalForm\`q = 1 - p\)]],
  ". Physically, such bias can occur if there is some reason why more \
particles should move in one direction than the other, as would be the case \
if gravity or an electric field acts on the system. "
}], "Text"],

Cell[TextData[{
  "\t Clearly,  after one step ",
  Cell[BoxData[
      \(TraditionalForm\`P(\(-1\), 1) = q, \ P(1, 1)\  = \(\(p\)\(.\)\)\)]],
  " After two steps, ",
  Cell[BoxData[
      \(TraditionalForm\`P(\(-2\), 2)\  = \ q\^2\)]],
  "(two steps to the left in a row have total probability ",
  Cell[BoxData[
      \(TraditionalForm\`q\[Cross]q = q\^2\)]],
  "), while ",
  Cell[BoxData[
      \(TraditionalForm\`P(2, 2)\  = \ p\^2\)]],
  " for the same reason.  Also, the two paths that lead back to the origin \
each have probability ",
  Cell[BoxData[
      \(TraditionalForm\`p\ q\)]],
  ", so the total probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(0, 2)\)]],
  " is a sum of the probabilities for each separate path, ",
  Cell[BoxData[
      \(TraditionalForm\`P(0, 2)\  = \ 2\ p\ q\)]],
  ". These results agree with the unbiased case given above when ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  ". \n\tSimilar reasoning leads to the following results for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(P(\(-3\), 3)\  = \ q\^3\)\(,\)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P(\(-1\), 
          3)\  = \ \(\(q\^2\) p\  + \ q\ p\ q\  + \ 
            p\ q\^\(\(2\)\(\ \)\)\  = \ 
          3\ \(q\^\(\(2\)\(\ \)\)\) p\)\)\(,\)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P(1, 
          3)\  = \ \(p\ q\ p\  + \ q\ p\^2\  + \ p\ p\ q\  = \ 
          3\ p\^2\ q\)\)\(,\)\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`P(3, 3)\  = \ p\^3\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "These results also agree with Eq. ",
  ButtonBox["(8.1.11)",
    ButtonData:>{"Chapter8.nb", "(8.1.11)"},
    ButtonStyle->"Hyperlink"],
  " for the unbiased case ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@U00022B000`400?l00000o`00003ooooooooo
oooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooo
oooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooo
oolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYoooo
o`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooo
oooooooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooo
oooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooo
oooooolYooooo`006Ooooooo0?ooool0ooooo`3ooood0?oooa_ooooo000Iooooool0ooooo`3ooooo
0?oooo@0oooo6oooool001Wooooo7@3oool00`20P800oooo0?ooo`3o0?ooool0ooooo`3ooooD0?oo
oa_ooooo000Ioooooad0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0ooooe03ooolKooooo`00
6OoooolL0?ooo`030820P0000000P8200?l0ooooo`3ooooo0?ooomD0oooo6oooool001Wooooo6`3o
ool01030`<00000000000010@43o0?ooool0ooooo`3ooooE0?oooa_ooooo000Ioooooa/0oooo00@0
P8200000000000000000o`3ooooo0?ooool0ooooe@3ooolKooooo`006OoooolK0?ooo`050410@000
0000000000000020P800o`3ooooo0?ooool0ooooe03ooolKooooo`006OoooolK0?ooo`D00000o`3o
oooo0?ooool0ooooe03ooolKooooo`006OoooolJ0?ooo`030820P0000000000000<0000000<0`<30
0?ooo`3oool0o`3ooooo0?ooool0ooood@3ooolKooooo`006OoooolJ0?ooo`H0000000<0P8200?oo
o`3oool0o`3ooooo0?ooool0ooood@3ooolKooooo`006OoooolI0?ooo`030820P0000000000000D0
0000o`3ooooo0?ooool0ooood`3ooolKooooo`006OoooolI0?ooo`030410@0000000000000D00000
4@3oool01020P800000000000020P8050?ooo`040410@000000000000<30`?l0ooooo`3ooooo0?oo
okD0oooo6oooool001Wooooo6@3oool900000140oooo0`0000050?ooo`<0000000<0P8200?ooo`3o
ool0o`3ooooo0?ooool0oooo/`3ooolKooooo`006OoooolH0?ooo`030<30`0000000000000L00000
4@3oool3000000D0oooo00H0@41000000020P800oooo0820P030`<3o0?ooool0ooooo`3ooonc0?oo
oa_ooooo000IoooooaP0oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`0>0?ooo`04
0820P000000000000820P0@0oooo00<0P8200000000000000P3oool00`30`<00oooo0?ooo`3o0?oo
ool0ooooo`3ooona0?oooa_ooooo000IoooooaP0oooo2`00000A0?ooo`80000000<0P8200?ooo`3o
ool00P3oool01020P800000000000020P83o0?ooool0ooooo`3ooone0?oooa_ooooo000IoooooaL0
oooo00<0P8200000000000002@00000A0?ooo`030410@0000000000000D0oooo0P0000000`20P800
oooo0?ooo`3o0?ooool0ooooo`3ooonc0?oooa_ooooo000IoooooaL0oooo300000000`20P800oooo
0?ooo`0>0?ooo`040820P000000000000820P0@0oooo0P0000000`20P800oooo0?ooo`3o0?ooool0
ooooo`3ooonc0?oooa_ooooo000IoooooaL0oooo300000000`20P800oooo0?ooo`0>0?ooo`040820
P000000000000820P0@0oooo00<0P820000000000000o`3ooooo0?ooool0oooo]@3ooolKooooo`00
6OoooolF0?ooo`030820P0000000000000/000004@3oool2000000030410@0000000oooo0080oooo
00<0P820000000000000o`3ooooo0?ooool0oooo]@3ooolKooooo`006OoooolF0?ooo`030820P000
0000000000/000004@3oool2000000030820P03oool0P82000<0oooo0`00003o0?ooool0ooooo`3o
oond0?oooa_ooooo000IoooooaH0oooo3`00000@0?ooo`050820P000000000000?ooo`20P8000`3o
ool300000?l0ooooo`3ooooo0?oook@0oooo6oooool001Wooooo5P3oool?00000140oooo0P000002
0?ooo`030000003oool0oooo00<0000000<0P8200?ooo`3oool0o`3ooooo0?ooool0oooo/@3ooolK
ooooo`006OoooolE0?oooa00000000<0P8200?ooo`3oool03P3oool2000000050820P03oool0oooo
0820P03oool00`0000000`20P800oooo0?ooo`3o0?ooool0ooooo`3ooona0?oooa_ooooo000Ioooo
oa@0oooo00<0P8200000000000003P0000000`10@400oooo0?ooo`0<0?ooo`<0P8200P0000030?oo
o`040410@000000000000820P?l0ooooo`3ooooo0?oook@0oooo6oooool001Wooooo503oool00`20
P80000000000000?00000?l0ooooo`3ooooo0?ooolh0oooo6oooool001Wooooo503ooolB00000003
0820P03oool0oooo0?l0ooooo`3ooooo0?oool/0oooo6oooool001Wooooo503ooolC00000?l0oooo
o`3ooooo0?ooold0oooo6oooool001Wooooo4`3oool00`30`<0000000000000A000000030<30`03o
ool0oooo0?l0ooooo`3ooooo0?ooolX0oooo6oooool001Wooooo4`3oool00`30`<00P8200000000@
000000030820P030`<00oooo0?l0ooooo`3ooooo0?oool/0oooo6oooool001Wooooo5`3oool<0000
00030820P03oool0oooo0?l0ooooo`3ooooo0?ooolh0oooo6oooool001Wooooo6`3oool01020P800
000000000010@4020820P?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo703oool2000000030820
P03oool0oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo703oool2000000030820P03o
ool0oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo
0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0
ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo00<0P820000000000000100000020820P1<0oooo
0P0000000`20P800oooo0?ooo`3o0?ooool0ooooo`3ooooC0?oooa_ooooo000Iooooo`80000000<0
@4100820P03oool00`3oool00`20P80000000<30`00A0?ooo`80000000<0P8200?ooo`3oool0o`3o
oooo0?ooool0ooood`3ooolKooooo`006Oooool90?ooo`030820P0000000oooo0100oooo0P000000
0`20P800oooo0?ooo`3o0?ooool0ooooo`3ooooC0?oooa_ooooo000Iooooo`X0oooo00<0@4100000
0030`<003`3oool2000000030820P03oool0oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wo
oooo2P3oool00`20P80000000820P00?0?ooo`80000000<0P8200?ooo`3oool0o`3ooooo0?ooool0
ooood`3ooolKooooo`006Oooool:0?ooo`030820P0000000000000l0oooo0P0000000`20P800oooo
0?ooo`3o0?ooool0ooooo`3ooooC0?oooa_ooooo000Iooooo`X0oooo00<0@4100000000000003`3o
ool2000000030820P03oool0oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo2P3oool3
000000l0oooo4`00003o0?ooool0ooooo`3oooo50?oooa_ooooo000Iooooo`T0oooo00@0@4100000
00000000P8203`3ooolC000003h0oooo0P20P8000`30`<00oooo0?ooo`3o0?ooo`X0oooo0P20P803
0?ooo`80P82000<0`<300?ooo`3oool0o`3oool<0?ooo`030820P010@400P8200080P820o`3oool=
0?ooo`80P820CP3ooolKooooo`006Oooool70?ooo`D00000403ooolC000003l0oooo0P0000000`20
P800oooo0?ooo`3o0?ooo`P0oooo0P0000000`20P800oooo0?ooo`020?ooo`<00000o`3oool<0?oo
o`<000000P3oool2000000030820P03oool0oooo0?l0oooo1`3oool00`20P80000000000001?0?oo
oa_ooooo000Iooooo`<0oooo0P20P805000000030820P03oool0oooo00l0oooo0P0000000`20P800
oooo0?ooo`1=0?ooo`070820P0000000000000000010@400P8200<30`03o0?ooo`80oooo0P20P804
000000D0oooo00<0P8200000000000000P0000000`20P800`<300?ooo`3o0?ooo`<0oooo0P20P804
000000040820P03oool0oooo0410@0<0000000<0@4100820P03oool0o`3oool20?ooo`80P8200`00
00000`20P800oooo0?ooo`1=0?oooa_ooooo000Iooooo`H0oooo00@0P8200410@0000000`<304P3o
ool2000000030820P03oool0oooo04h0oooo00<0@4100000000000000`0000000`10@400P8200?oo
o`3l0?ooo`030820P0000000000000@000001`3oool7000000030820P03oool0oooo0?d0oooo00<0
`<300000000000001@0000030?ooo`030<30`0000000000000@0000000<0@4100820P03oool0n`3o
ool00`30`<00@4100000000500000500oooo6oooool001Wooooo203oool2000000030820P03oool0
oooo00l0oooo0P0000000`20P800oooo0?ooo`1>0?ooo`030820P0000000000000D0000000<0P820
0?ooo`3oool0n@3oool7000000030820P03oool0oooo00D0oooo00<0P8200000000000001P00003m
0?ooo`P000001@3oool8000000030820P03oool0oooo0?P0oooo2000001A0?oooa_ooooo000Ioooo
o`T0oooo0P10@40A0?ooo`80000000<0P8200?ooo`3oool0C`3oool9000000030820P030`<00oooo
0?@0oooo00<0`<300820P00000001`0000000`30`<00oooo0?ooo`050?ooo`030<30`00000000000
00L0000000<0P8200?ooo`3oool0mP3oool00`30`<00P82000000007000000030410@03oool0oooo
00@0oooo200000000`10@400P8200<30`03d0?ooo`030<30`020P800000000L0000000<0@4100?oo
o`3oool0C`3ooolKooooo`006Oooool90?ooo`030820P000000000000100oooo0P0000000`20P800
oooo0?ooo`1?0?ooo`030820P0000000000000T00000lP3oool00`20P800000000000009000000T0
oooo3000003d0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0103oool00`20P800
00000000000900000?80oooo00<0P820000000000000200000000`20P800oooo0?ooo`1?0?oooa_o
oooo000Iooooo`030<30`03oool0oooo00H0oooo00<0P820000000000000403oool2000000030820
P03oool0oooo04l0oooo00<0`<300000000000002`0000000`20P800oooo0?ooo`3Z0?ooo`030<30
`020P800000000/000002`3oool<000000030410@030`<00oooo0>d0oooo00<0`<300820P0000000
300000070?ooo`030<30`0000000000000X0000000<0@4100820P03oool0j`3oool00`20P800@410
0000000;00000580oooo6oooool001Wooooo0P20P8070?ooo`030410@000000000000100oooo0P00
00000`20P800oooo0?ooo`1@0?ooo`030820P0000000000000`0000000<0P8200?ooo`3oool0iP3o
ool00`30`<00P8200000000<000000030820P03oool0oooo00T0oooo00<0P8200000000000003000
00000`20P800oooo0?ooo`3X0?ooo`030<30`020P800000000d0000000<0P8200?ooo`3oool01P3o
ool00`20P80000000000000<000000030820P03oool0oooo0>H0oooo00<0`<300410@00000003000
00000`20P800oooo0?ooo`1@0?oooa_ooooo000Iooooo`030?ooo`000000P82000D0oooo0`00000A
0?ooo`80000000<0P8200?ooo`3oool0D@3oool@00000>H0oooo4000000=0?oooa00000000<0P820
0?ooo`3oool0i@3oool00`20P80000000000000>000000X0oooo4000003V0?oooa000000D`3ooolK
ooooo`006Oooool0103oool0P8200410@00000030820P0<0000000<0@4100?ooo`3oool03`3oool2
000000030820P03oool0oooo0540oooo00<0P8200000000000003P0000000`10@400`<300?ooo`3P
0?ooo`030820P0000000000000h0000000<0@4100?ooo`3oool02`3oool00`20P80000000000000>
000000030410@020P800oooo0>80oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`08
0?ooo`030820P0000000000000h0000000<0P8200<30`03oool0g`3oool00`30`<00P8200000000?
000000030820P03oool0oooo0540oooo6oooool001Wooooo0`3oool700000180oooo0P0000000`20
P800oooo0?ooo`1B0?oooa<00000gP3ooolC000000030820P03oool0oooo00`0oooo4`00003P0?oo
o`030820P0000000000001400000303ooolC00000=h0oooo4`00001D0?oooa_ooooo000Iooooo`@0
oooo00<0`<300820P020P8000P20P80C0?ooo`80000000<0P8200?ooo`3oool0DP3oool00`20P800
00000000000B000000030820P03oool0oooo0=H0oooo00<0`<300410@00000004`00000?0?ooo`03
0820P000000000000140000000<0@4100<30`03oool0f@3oool00`30`<00P8200410@00C00000003
0820P03oool0oooo00X0oooo00<0@4100000000000004@0000000`10@400P8200?ooo`3G0?ooo`03
0820P010@40000000180000000<0P8200?ooo`3oool0DP3ooolKooooo`006OoooolL0?ooo`800000
00<0P8200?ooo`3oool0D`3oool00`10@40000000000000A000000030410@03oool0oooo0=L0oooo
500000000`20P800oooo0?ooo`0>0?oooa@0000000<0`<300?ooo`3oool0f@3ooolE000000d0oooo
00<0`<300000000000004P0000000`20P800oooo0?ooo`3G0?oooa@0000000<0`<300?ooo`3oool0
DP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0D`3oool00`20P80000000000
000A000000030820P03oool0oooo0=L0oooo00<0P8200000000000004@00000A0?oooa@00000g@3o
oolC000000l0oooo5000003J0?ooo`030820P0000000000001400000E@3ooolKooooo`006OoooolL
0?ooo`80000000<0P8200?ooo`3oool0E03ooolC00000=X0oooo00<0`<3000000000000040000000
0`20P800oooo0?ooo`0?0?ooo`030820P000000000000100000000<0@4100?ooo`3oool0f`3oool0
0`10@40000000000000?000000030410@03oool0oooo00h0oooo4P0000000`20P800oooo0?ooo`3H
0?ooo`030<30`0000000000001000000EP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0E03oool00`20P80000000000000?00000=`0oooo4P00000C0?oooa80000000<0P8200?oo
o`3oool0f`3oool00`20P80000000000000?000000030820P03oool0oooo00h0oooo00<0P8200000
000000003`00003L0?oooa40000000<0P8200?ooo`3oool0E03ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0E03oool00`30`<0000000000000>000000030820P03oool0oooo0=/0
oooo400000000`20P800oooo0?ooo`0A0?ooo`030820P0000000000000l00000g`3ooolA00000140
oooo00<0`<300000000000003P0000000`10@400oooo0?ooo`3K0?oooa00000000<0`<300?ooo`3o
ool0E03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0E@3oool00`20P8000000
0000000<000000030820P03oool0oooo0=`0oooo00<0P820000000000000300000000`10@400oooo
0?ooo`0C0?ooo`030410@0000000000000`0000000<0@4100?ooo`3oool0gP3oool00`20P8000000
0000000=000000030820P03oool0oooo0100oooo00<0P8200000000000003@00003N0?ooo`030820
P0000000000000`0000000<0@4100?ooo`3oool0E@3ooolKooooo`006OoooolL0?ooo`80000000<0
P8200?ooo`3oool0EP3oool=000000030820P03oool0oooo0=h0oooo3P0000000`20P800oooo0?oo
o`0C0?ooo`030820P0000000000000`00000hP3oool?000001@0oooo3P00003P0?ooo`h0000000<0
P8200?ooo`3oool0E@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0EP3oool0
0`20P80000000000000:000000030<30`03oool0oooo0=l0oooo3@00000G0?ooo`d0000000<0P820
0?ooo`3oool0h@3oool=000000030820P03oool0oooo0180oooo00<0P8200000000000002P000000
0`20P800oooo0?ooo`3N0?ooo`030410@0000000000000/00000F03ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0E`3oool=00000>00oooo3@0000000`20P800oooo0?ooo`0F0?oo
o`d0000000<0P8200?ooo`3oool0g`3oool>000001H0oooo3@00003O0?ooo`030820P00000000000
00/00000F@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0E`3oool00`20P800
000000000007000000050820P0000000000000000030`<00g@3oool01010@400000000000020P80:
000000030<30`03oool0oooo01H0oooo00<0@4100000000000001`0000001@20P800000000000000
0000P8200=l0oooo00D0@41000000000000000000410@009000000030820P03oool0oooo01@0oooo
00<0@4100000000000001`0000001@10@4000000000000000000`<300=`0oooo00D0P82000000000
000000000820P009000000030410@03oool0oooo05L0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo05P0oooo00<0@410000000000000100000001020P800`<300?ooo`30`<030000
00030820P03oool0oooo0=P0oooo00D0`<3000000000000000000<30`0020?ooo`030<30`0000000
000000D0000000<0P8200?ooo`3oool05`3oool00`30`<00000000000005000000040410@03oool0
oooo0<30`0<0000000<0@4100?ooo`3oool0f`3oool01010@400000000000010@4020?ooo`030<30
`0000000000000H000005`3oool00`30`<00000000000005000000040820P030`<00oooo0820P0<0
000000<0`<300?ooo`3oool0f03oool01010@400000000000010@4030?ooo`030<30`00000000000
00D0000000<0`<300?ooo`3oool0E`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0F03oool00`20P800000000000003000000D0oooo00D0P82000000000000000000820P03I0?oo
o`<000001P3oool00`20P800000000000003000001/0oooo1P0000060?ooo`<0000000<0P8200?oo
o`3oool0f@3oool4000000D0oooo00<0P8200000000000000`00000I0?ooo`H0000000<0P8200?oo
o`3oool00P3oool01020P800000000000000003I0?ooo`@000001P3oool6000005X0oooo6oooool0
01Wooooo703oool2000000030820P03oool0oooo05T0oooo0`0000000`20P800oooo0?ooo`050?oo
o`050820P0000000000000000030`<00e`3oool01010@400000000000030`<070?ooo`050820P010
@400000000000020P8006`3oool01@20P8000000000000000000@41000L0oooo00D0`<3000000000
000000000820P03I0?ooo`040410@000000000000410@0L0oooo00D0P8200410@000000000000410
@00J0?ooo`<0000000<0@4100?ooo`3oool01@3oool01@20P8000000000000000000`<300=H0oooo
00D0@41000000000000000000<30`0070?ooo`040820P00000000000000005/0oooo6oooool001Wo
oooo703oool2000000030820P03oool0oooo05T0oooo00<0P8200000003oool02@3oool01020P800
000000000000003F0?ooo`<000002`3oool2000001d0oooo0P00000;0?ooo`<0000000<0P8200?oo
o`3oool0e@3oool4000000X0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`030820P0000000P820
00T0oooo00@0P8200000000000000000e@3oool01020P800000000000000000;0?ooo`0300000020
P800oooo05X0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo06H0oooo00D0P820
00000000000000000<30`03C0?ooo`040410@000000000000<30`0`0oooo00<0P8200?ooo`3oool0
6`3oool00`20P800oooo0?ooo`0:0?ooo`050<30`0000000000000000020P800e@3oool01@10@400
0000000000000000`<3000/0oooo00<0P8200?ooo`3oool06@3oool00`30`<00oooo0?ooo`0:0?oo
o`050410@0000000000000000030`<00dP3oool01@20P8000000000000000000`<3000`0oooo00<0
`<300?ooo`3oool0F@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0I`3oool0
1@30`<000000000000000000P8200=00oooo00D0`<3000000000000000000<30`00i0?ooo`050<30
`0000000000000000010@400d`3oool01010@400000000000010@40g0?ooo`050820P00000000000
00000030`<00d03oool01010@400000000000010@41Z0?oooa_ooooo000Ioooooa`0oooo0P000000
0`20P800oooo0?ooo`1X0?ooo`050820P0000000000000000020P800c`3oool3000003d0oooo0`00
00000`20P800oooo0?ooo`3?0?ooo`@00000>@3oool01020P800000000000000003?0?ooo`@00000
J`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0J@3oool01@20P80000000000
00000000`<300<d0oooo00@0@410000000000000`<30?@3oool01@30`<000000000000000000P820
0<l0oooo00@0@410000000000000@410>`3oool01@20P8000000000000000000`<300<`0oooo00D0
@41000000000000000000<30`01[0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?oo
o`1Z0?ooo`040820P0000000000000000<`0oooo0`0000110?ooo`<0000000<0P8200?ooo`3oool0
b`3oool4000003d0oooo00@0P8200000000000000000b`3oool01020P800000000000000001]0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1[0?ooo`050820P000000000000000
0030`<00b@3oool01010@400000000000030`<110?ooo`050<30`0000000000000000020P800b`3o
ool01@10@4000000000000000000`<3003h0oooo00D0@41000000000000000000<30`0380?ooo`05
0820P0000000000000000030`<00K@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0K03oool01@30`<000000000000000000P8200<H0oooo00D0`<3000000000000000000<30`013
0?ooo`050<30`0000000000000000010@400b@3oool01010@400000000000010@4110?ooo`050820
P0000000000000000030`<00aP3oool01010@400000000000010@41_0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`1]0?ooo`050820P0000000000000000020P800a@3oool30000
04L0oooo0`0000000`20P800oooo0?ooo`350?ooo`@00000@`3oool01020P8000000000000000035
0?ooo`@00000L03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0KP3oool01@20
P8000000000000000000`<300<<0oooo00@0@410000000000000`<30A`3oool01@30`<0000000000
00000000P8200<D0oooo00@0@410000000000000@410A@3oool01@20P8000000000000000000`<30
0<80oooo00D0@41000000000000000000<30`01`0?oooa_ooooo000Ioooooa`0oooo0P0000000`20
P800oooo0?ooo`1_0?ooo`040820P0000000000000000<80oooo0`00001;0?ooo`<0000000<0P820
0?ooo`3oool0`@3oool4000004L0oooo00@0P8200000000000000000`@3oool01020P80000000000
0000001b0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1`0?ooo`050820P000
0000000000000030`<00_`3oool01010@400000000000030`<1;0?ooo`050<30`000000000000000
0020P800`@3oool01@10@4000000000000000000`<3004P0oooo00D0@41000000000000000000<30
`02n0?ooo`050820P0000000000000000030`<00LP3ooolKooooo`006OoooolL0?ooo`80000000<0
P8200?ooo`3oool0L@3oool01@30`<000000000000000000P8200;`0oooo00D0`<30000000000000
00000<30`01=0?ooo`050<30`0000000000000000010@400_`3oool01010@400000000000010@41;
0?ooo`050820P0000000000000000030`<00_03oool01010@400000000000010@41d0?oooa_ooooo
000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1b0?ooo`050820P0000000000000000020P800
^`3oool300000540oooo0`0000000`20P800oooo0?ooo`2k0?ooo`@00000C@3oool01020P8000000
00000000002k0?ooo`@00000M@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0
L`3oool01@20P8000000000000000000`<300;T0oooo00@0@410000000000000`<30D@3oool01@30
`<000000000000000000P8200;/0oooo00@0@410000000000000@410C`3oool01@20P80000000000
00000000`<300;P0oooo00D0@41000000000000000000<30`01e0?oooa_ooooo000Ioooooa`0oooo
0P0000000`20P800oooo0?ooo`1d0?ooo`040820P0000000000000000;P0oooo0`00001E0?ooo`<0
000000<0P8200?ooo`3oool0]`3oool400000540oooo00@0P8200000000000000000]`3oool01020
P800000000000000001g0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1e0?oo
o`050820P0000000000000000030`<00]@3oool01010@400000000000030`<1E0?ooo`050<30`000
0000000000000020P800]`3oool01@10@4000000000000000000`<300580oooo00D0@41000000000
000000000<30`02d0?ooo`050820P0000000000000000030`<00M`3ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0MP3oool01@30`<000000000000000000P8200;80oooo00D0`<30
00000000000000000<30`01G0?ooo`050<30`0000000000000000010@400]@3oool01010@4000000
00000010@41E0?ooo`050820P0000000000000000030`<00/P3oool01010@400000000000010@41i
0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1g0?ooo`050820P00000000000
00000020P800/@3oool3000005/0oooo0`0000000`20P800oooo0?ooo`2a0?ooo`@00000E`3oool0
1020P800000000000000002a0?ooo`@00000NP3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0N03oool01@20P8000000000000000000`<300:l0oooo00@0@410000000000000`<30
F`3oool01@30`<000000000000000000P8200;40oooo00@0@410000000000000@410F@3oool01@20
P8000000000000000000`<300:h0oooo00D0@41000000000000000000<30`01j0?oooa_ooooo000I
oooooa`0oooo0P0000000`20P800oooo0?ooo`1i0?ooo`040820P0000000000000000:h0oooo0`00
001O0?ooo`<0000000<0P8200?ooo`3oool0[@3oool4000005/0oooo00@0P8200000000000000000
[@3oool01020P800000000000000001l0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo
0?ooo`1j0?ooo`050820P0000000000000000030`<00Z`3oool01010@400000000000030`<1O0?oo
o`050<30`0000000000000000020P800[@3oool01@10@4000000000000000000`<3005`0oooo00D0
@41000000000000000000<30`02Z0?ooo`050820P0000000000000000030`<00O03ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0N`3oool01@30`<000000000000000000P8200:P0
oooo00D0`<3000000000000000000<30`01Q0?ooo`050<30`0000000000000000010@400Z`3oool0
1010@400000000000010@41O0?ooo`050820P0000000000000000030`<00Z03oool01010@4000000
00000010@41n0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1l0?ooo`050820
P0000000000000000020P800Y`3oool3000006D0oooo0`0000000`20P800oooo0?ooo`2W0?ooo`@0
0000H@3oool01020P800000000000000002W0?ooo`@00000O`3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0O@3oool01@20P8000000000000000000`<300:D0oooo00@0@4100000
00000000`<30I@3oool01@30`<000000000000000000P8200:L0oooo00@0@410000000000000@410
H`3oool01@20P8000000000000000000`<300:@0oooo00D0@41000000000000000000<30`01o0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1n0?ooo`040820P000000000000000
0:@0oooo0`00001Y0?ooo`<0000000<0P8200?ooo`3oool0X`3oool4000006D0oooo00@0P8200000
000000000000X`3oool01020P80000000000000000210?oooa_ooooo000Ioooooa`0oooo0P000000
0`20P800oooo0?ooo`1o0?ooo`050820P0000000000000000030`<00X@3oool01010@40000000000
0030`<1Y0?ooo`050<30`0000000000000000020P800X`3oool01@10@4000000000000000000`<30
06H0oooo00D0@41000000000000000000<30`02P0?ooo`050820P0000000000000000030`<00P@3o
oolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0P03oool01@30`<00000000000000
0000P82009h0oooo00D0`<3000000000000000000<30`01[0?ooo`050<30`0000000000000000010
@400X@3oool01010@400000000000010@41Y0?ooo`050820P0000000000000000030`<00WP3oool0
1010@400000000000010@4230?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`21
0?ooo`050820P0000000000000000020P800W@3oool3000006l0oooo0`0000000`20P800oooo0?oo
o`2M0?ooo`@00000J`3oool01020P800000000000000002M0?ooo`@00000Q03ooolKooooo`006Ooo
oolL0?ooo`80000000<0P8200?ooo`3oool0PP3oool01@20P8000000000000000000`<3009/0oooo
00@0@410000000000000`<30K`3oool01@30`<000000000000000000P82009d0oooo00@0@4100000
00000000@410K@3oool01@20P8000000000000000000`<3009X0oooo00D0@4100000000000000000
0<30`0240?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`230?ooo`040820P000
00000000000009X0oooo0`00001c0?ooo`<0000000<0P8200?ooo`3oool0V@3oool4000006l0oooo
00@0P8200000000000000000V@3oool01020P80000000000000000260?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`240?ooo`050820P0000000000000000030`<00U`3oool01010
@400000000000030`<1c0?ooo`050<30`0000000000000000020P800V@3oool01@10@40000000000
00000000`<300700oooo00D0@41000000000000000000<30`02F0?ooo`050820P000000000000000
0030`<00QP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0Q@3oool01@30`<00
0000000000000000P82009@0oooo00D0`<3000000000000000000<30`01e0?ooo`050<30`0000000
000000000010@400U`3oool01010@400000000000010@41c0?ooo`050820P0000000000000000030
`<00U03oool01010@400000000000010@4280?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`260?ooo`050820P0000000000000000020P800T`3oool3000007T0oooo0`0000000`20
P800oooo0?ooo`2C0?ooo`@00000M@3oool01020P800000000000000002C0?ooo`@00000R@3ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0Q`3oool01@20P8000000000000000000
`<300940oooo00@0@410000000000000`<30N@3oool01@30`<000000000000000000P82009<0oooo
00@0@410000000000000@410M`3oool01@20P8000000000000000000`<300900oooo00D0@4100000
0000000000000<30`0290?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`280?oo
o`040820P0000000000000000900oooo0`00001m0?ooo`<0000000<0P8200?ooo`3oool0S`3oool4
000007T0oooo00@0P8200000000000000000S`3oool01020P800000000000000002;0?oooa_ooooo
000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`290?ooo`050820P0000000000000000030`<00
S@3oool01010@400000000000030`<1m0?ooo`050<30`0000000000000000020P800S`3oool01@10
@4000000000000000000`<3007X0oooo00D0@41000000000000000000<30`02<0?ooo`050820P000
0000000000000030`<00R`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0RP3o
ool01@30`<000000000000000000P82008X0oooo00D0`<3000000000000000000<30`01o0?ooo`05
0<30`0000000000000000010@400S@3oool01010@400000000000010@41m0?ooo`050820P0000000
000000000030`<00RP3oool01010@400000000000010@42=0?oooa_ooooo000Ioooooa`0oooo0P00
00000`20P800oooo0?ooo`2;0?ooo`050820P0000000000000000020P800R@3oool3000008<0oooo
0`0000000`20P800oooo0?ooo`290?ooo`@00000O`3oool01020P80000000000000000290?ooo`@0
0000SP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0S03oool01@20P8000000
000000000000`<3008L0oooo00@0@410000000000000`<30P`3oool01@30`<000000000000000000
P82008T0oooo00@0@410000000000000@410P@3oool01@20P8000000000000000000`<3008H0oooo
00D0P82000000000000000000<30`02>0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo
0?ooo`2=0?ooo`040820P000000000000820P8H0oooo0`0000270?ooo`<00000R03oool4000008<0
oooo00@0P8200000000000000000QP3oool300000900oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo08h0oooo00@0P820000000000000P820Q03oool01010@400000000000020P827
0?ooo`040<30`000000000000410@8H0oooo00D0@41000000000000000000<30`0240?ooo`050410
@0000000000000000030`<00P`3oool01010@400000000000020P82@0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`2?0?ooo`040410@000000000000410@840oooo00D0`<300000
0000000000000410@0290?ooo`050410@0000000000000000030`<00P`3oool01010@40000000000
0010@4270?ooo`050820P0000000000000000030`<00P03oool01@30`<000000000000000000P820
0940oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0900oooo100000200?ooo`@0
0000R`3oool400000880oooo100000290?ooo`040820P0000000000000000800oooo0`0000000`20
P800oooo0?ooo`2@0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2@0?ooo`05
0<30`0000000000000000010@400OP3oool01010@400000000000010@42=0?ooo`040410@0000000
00000410@800oooo00@0@410000000000000@410R`3oool01@20P8000000000000000000`<3007`0
oooo00D0`<3000000000000000000410@02C0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`2B0?ooo`<0000000<0P8200?ooo`3oool0NP3oool4000008l0oooo1000001n0?ooo`@0
0000S@3oool01020P800000000000000001l0?ooo`@00000U03ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0TP3oool01@30`<000000000000000000P82007X0oooo00@0@4100000
00000000@410T@3oool01010@400000000000010@41l0?ooo`050410@0000000000000000030`<00
SP3oool01@10@4000000000000000000`<3007T0oooo00@0@410000000000000@410U@3ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0U03oool01010@400000000000010@41g0?oo
o`050<30`0000000000000000010@400T`3oool01@10@4000000000000000000`<3007T0oooo00@0
@410000000000000@410T@3oool01@20P8000000000000000000`<3007H0oooo00D0`<3000000000
000000000820P02F0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2E0?ooo`@0
0000MP3oool4000009D0oooo1000001h0?ooo`@00000T`3oool01020P800000000000000001f0?oo
o`<0000000<0P8200?ooo`3oool0U@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0U@3oool01@30`<000000000000000000@41007@0oooo00@0@410000000000000@410U`3oool0
1010@400000000000010@41f0?ooo`040410@000000000000410@9D0oooo00D0P820000000000000
00000<30`01b0?ooo`050<30`0000000000000000010@400V03ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0U`3oool3000000030820P03oool0oooo0700oooo1000002I0?ooo`@0
0000M03oool4000009L0oooo00@0P8200000000000000000LP3oool4000009T0oooo6oooool001Wo
oooo703oool2000000030820P03oool0oooo09L0oooo00D0`<3000000000000000000820P01`0?oo
o`040410@000000000000410@9/0oooo00@0@410000000000000@410LP3oool01@10@40000000000
00000000`<3009P0oooo00D0@41000000000000000000<30`01_0?ooo`040410@000000000000410
@9X0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo09T0oooo00@0@41000000000
0000@410K@3oool01@30`<000000000000000000@41009d0oooo00D0@41000000000000000000<30
`01_0?ooo`040410@000000000000410@9/0oooo00D0P82000000000000000000<30`01/0?ooo`05
0<30`0000000000000000020P800V`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0VP3oool4000006`0oooo1000002O0?ooo`@00000KP3oool4000009d0oooo00@0P82000000000
00000000K03oool3000000030820P03oool0oooo09X0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo09X0oooo00D0`<3000000000000000000410@01Z0?ooo`040410@00000000000
0410@:40oooo00@0@410000000000000@410K03oool01010@400000000000010@42O0?ooo`050820
P0000000000000000030`<00J03oool01@30`<000000000000000000@41009d0oooo6oooool001Wo
oooo703oool2000000030820P03oool0oooo09`0oooo0`0000000`20P800oooo0?ooo`1V0?ooo`@0
0000X`3oool4000006X0oooo1000002Q0?ooo`040820P00000000000000006P0oooo1000002N0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2L0?ooo`050<30`000000000000000
0020P800IP3oool01010@400000000000010@42U0?ooo`040410@000000000000410@6P0oooo00D0
@41000000000000000000<30`02R0?ooo`050410@0000000000000000030`<00I@3oool01010@400
000000000010@42O0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2N0?ooo`04
0410@000000000000410@6<0oooo00D0`<3000000000000000000410@02W0?ooo`050410@0000000
000000000030`<00I@3oool01010@400000000000010@42U0?ooo`050820P0000000000000000030
`<00HP3oool01@30`<000000000000000000P8200:00oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo09l0oooo1000001R0?ooo`@00000Z@3oool4000006@0oooo1000002W0?ooo`04
0820P0000000000000000680oooo0`0000000`20P800oooo0?ooo`2O0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`2O0?ooo`050<30`0000000000000000010@400H03oool01010
@400000000000010@42[0?ooo`040410@000000000000410@680oooo00@0@410000000000000@410
Z@3oool01@20P8000000000000000000`<3005h0oooo00D0`<3000000000000000000410@02R0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2Q0?ooo`<0000000<0P8200?ooo`3o
ool0G03oool400000:d0oooo1000001P0?ooo`@00000Z`3oool01020P800000000000000001N0?oo
o`@00000X`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0X@3oool01@30`<00
0000000000000000P82005`0oooo00@0@410000000000000@410[`3oool01010@400000000000010
@41N0?ooo`050410@0000000000000000030`<00[03oool01@10@4000000000000000000`<3005/0
oooo00@0@410000000000000@410Y03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0X`3oool01010@400000000000010@41I0?ooo`050<30`0000000000000000010@400/@3oool0
1@10@4000000000000000000`<3005/0oooo00@0@410000000000000@410[`3oool01@20P8000000
000000000000`<3005P0oooo00D0`<3000000000000000000820P02U0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`2T0?ooo`@00000F03oool400000;<0oooo1000001J0?ooo`@0
0000/@3oool01020P800000000000000001H0?ooo`<0000000<0P8200?ooo`3oool0Y03ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0Y03oool01@30`<000000000000000000@410
05H0oooo00@0@410000000000000@410]@3oool01010@400000000000010@41H0?ooo`040410@000
000000000410@;<0oooo00D0P82000000000000000000<30`01D0?ooo`050<30`000000000000000
0010@400Y`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0YP3oool300000003
0820P03oool0oooo0580oooo1000002g0?ooo`@00000EP3oool400000;D0oooo00@0P82000000000
00000000E03oool400000:P0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0:H0
oooo00D0`<3000000000000000000820P01B0?ooo`040410@000000000000410@;T0oooo00@0@410
000000000000@410E03oool01@10@4000000000000000000`<300;H0oooo00D0@410000000000000
00000<30`01A0?ooo`040410@000000000000410@:T0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0:P0oooo00@0@410000000000000@410C`3oool01@30`<000000000000000000
@4100;/0oooo00D0@41000000000000000000<30`01A0?ooo`040410@000000000000410@;T0oooo
00D0P82000000000000000000<30`01>0?ooo`050<30`0000000000000000020P800ZP3ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0Z@3oool4000004h0oooo1000002m0?ooo`@0
0000D03oool400000;/0oooo00@0P8200000000000000000CP3oool3000000030820P03oool0oooo
0:T0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0:T0oooo00D0`<3000000000
000000000410@01<0?ooo`040410@000000000000410@;l0oooo00@0@410000000000000@410CP3o
ool01010@400000000000010@42m0?ooo`050820P0000000000000000030`<00BP3oool01@30`<00
0000000000000000@4100:`0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0:/0
oooo0`0000000`20P800oooo0?ooo`180?ooo`@00000`@3oool4000004`0oooo1000002o0?ooo`04
0820P00000000000000004X0oooo1000002]0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`2[0?ooo`050<30`0000000000000000020P800B03oool01010@400000000000010@433
0?ooo`040410@000000000000410@4X0oooo00D0@41000000000000000000<30`0300?ooo`050410
@0000000000000000030`<00A`3oool01010@400000000000010@42^0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`2]0?ooo`040410@000000000000410@4D0oooo00D0`<300000
0000000000000410@0350?ooo`050410@0000000000000000030`<00A`3oool01010@40000000000
0010@4330?ooo`050820P0000000000000000030`<00A03oool01@30`<000000000000000000P820
0:l0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0:h0oooo100000140?ooo`@0
0000a`3oool4000004H0oooo100000350?ooo`040820P00000000000000004@0oooo0`0000000`20
P800oooo0?ooo`2^0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2^0?ooo`05
0<30`0000000000000000010@400@P3oool01010@400000000000010@4390?ooo`040410@0000000
00000410@4@0oooo00@0@410000000000000@410a`3oool01@20P8000000000000000000`<300400
oooo00D0`<3000000000000000000410@02a0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`2`0?ooo`<0000000<0P8200?ooo`3oool0?P3oool400000</0oooo100000120?ooo`@0
0000b@3oool01020P80000000000000000100?ooo`@00000/P3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0/03oool01@30`<000000000000000000P82003h0oooo00@0@4100000
00000000@410c@3oool01010@400000000000010@4100?ooo`050410@0000000000000000030`<00
bP3oool01@10@4000000000000000000`<3003d0oooo00@0@410000000000000@410/`3ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0/P3oool01010@400000000000010@40k0?oo
o`050<30`0000000000000000010@400c`3oool01@10@4000000000000000000`<3003d0oooo00@0
@410000000000000@410c@3oool01@20P8000000000000000000`<3003X0oooo00D0`<3000000000
000000000820P02d0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2c0?ooo`@0
0000>P3oool400000=40oooo1000000l0?ooo`@00000c`3oool01020P800000000000000000j0?oo
o`<0000000<0P8200?ooo`3oool0/`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0/`3oool01@30`<000000000000000000@41003P0oooo00@0@410000000000000@410d`3oool0
1010@400000000000010@40j0?ooo`040410@000000000000410@=40oooo00D0P820000000000000
00000<30`00f0?ooo`050<30`0000000000000000010@400]P3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0]@3oool4000003H0oooo1000003E0?ooo`@00000>03oool400000=<0
oooo00@0P8200000000000000000=P3oool400000;L0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0;D0oooo00D0`<3000000000000000000410@00d0?ooo`040410@00000000000
0410@=L0oooo00@0@410000000000000@410=P3oool01@10@4000000000000000000`<300=@0oooo
00D0@41000000000000000000<30`00c0?ooo`040410@000000000000410@;P0oooo6oooool001Wo
oooo703oool2000000030820P03oool0oooo0;L0oooo00@0@410000000000000@410<@3oool01@30
`<000000000000000000@4100=T0oooo00D0@41000000000000000000<30`00c0?ooo`040410@000
000000000410@=L0oooo00D0P82000000000000000000<30`00`0?ooo`050<30`000000000000000
0020P800^@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0^03oool400000300
oooo1000003K0?ooo`@00000<P3oool400000=T0oooo00@0P8200000000000000000<03oool30000
00030820P03oool0oooo0;P0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0;T0
oooo00@0@410000000000000@410;P3oool01010@400000000000010@43M0?ooo`040410@0000000
00000410@300oooo00@0@410000000000000@410f`3oool01@20P8000000000000000000`<3002`0
oooo00D0`<3000000000000000000410@02k0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`2j0?ooo`@00000;03oool400000=l0oooo1000000^0?ooo`@00000g@3oool01020P800
000000000000000/0?ooo`@00000_03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0^P3oool01@30`<000000000000000000@41002X0oooo00@0@410000000000000@410h@3oool0
1010@400000000000010@40/0?ooo`050410@0000000000000000030`<00gP3oool01@10@4000000
000000000000`<3002T0oooo00@0@410000000000000@410_@3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0_03oool01010@400000000000010@40W0?ooo`050<30`00000000000
00000010@400h`3oool01@10@4000000000000000000`<3002T0oooo00@0@410000000000000@410
h@3oool01@20P8000000000000000000`<3002H0oooo00D0`<3000000000000000000820P02n0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2m0?ooo`@000009P3oool400000>D0
oooo1000000X0?ooo`@00000h`3oool01020P800000000000000000V0?ooo`<0000000<0P8200?oo
o`3oool0_@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0_P3oool01010@400
000000000010@40T0?ooo`040410@000000000000410@>L0oooo00@0@410000000000000@4109P3o
ool01010@400000000000010@43U0?ooo`050820P0000000000000000030`<008P3oool01@30`<00
0000000000000000@4100<00oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0;l0
oooo1000000R0?ooo`@00000j@3oool4000002@0oooo1000003W0?ooo`040820P000000000000000
0280oooo100000310?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`2o0?ooo`05
0<30`0000000000000000010@400803oool01010@400000000000010@43[0?ooo`040410@0000000
00000410@280oooo00D0@41000000000000000000<30`03X0?ooo`050410@0000000000000000030
`<007`3oool01010@400000000000010@4320?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`310?ooo`040410@000000000000410@1d0oooo00D0`<3000000000000000000410@03]
0?ooo`050410@0000000000000000030`<007`3oool01010@400000000000010@43[0?ooo`050820
P0000000000000000030`<00703oool01@30`<000000000000000000P8200<<0oooo6oooool001Wo
oooo703oool2000000030820P03oool0oooo0<80oooo1000000L0?ooo`@00000k`3oool4000001h0
oooo1000003]0?ooo`040820P00000000000000001`0oooo0`0000000`20P800oooo0?ooo`320?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`330?ooo`040410@000000000000410
@1X0oooo00@0@410000000000000@410l@3oool01@10@4000000000000000000`<3001/0oooo00@0
@410000000000000@410k`3oool01@20P8000000000000000000`<3001P0oooo00D0`<3000000000
000000000410@0350?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`340?ooo`@0
0000603oool400000?<0oooo1000000J0?ooo`@00000l@3oool01020P800000000000000000H0?oo
o`@00000aP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0a03oool01@30`<00
0000000000000000@41001H0oooo00@0@410000000000000@410m@3oool01010@400000000000010
@40H0?ooo`050410@0000000000000000030`<00lP3oool01@10@4000000000000000000`<3001D0
oooo00@0@410000000000000@410a`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0aP3oool01010@400000000000010@40C0?ooo`050<30`0000000000000000010@400m`3oool0
1@20P8000000000000000000`<3001D0oooo00@0@410000000000000@410m@3oool01@20P8000000
000000000000`<300180oooo00D0`<3000000000000000000820P0380?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`370?ooo`@000004P3oool400000?T0oooo00@0P82000000000
00000000503oool400000?L0oooo00@0P82000000000000000004P3oool3000000030820P03oool0
oooo0<L0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0<P0oooo00@0@4100000
00000000@410403oool01010@400000000000010@43k0?ooo`050410@0000000000000000030`<00
4@3oool01010@400000000000010@43i0?ooo`050820P0000000000000000030`<003P3oool01@30
`<000000000000000000@4100<X0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo
0<T0oooo1000000>0?ooo`@00000o@3oool400000100oooo1000003k0?ooo`040820P00000000000
000000h0oooo1000003;0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`390?oo
o`050<30`0000000000000000010@400303oool01010@400000000000010@43o0?ooo`040410@000
000000000410@0h0oooo00D0@41000000000000000000<30`03l0?ooo`050410@000000000000000
0030`<002`3oool01010@400000000000010@43<0?oooa_ooooo000Ioooooa`0oooo0P0000000`20
P800oooo0?ooo`3;0?ooo`040410@000000000000410@0T0oooo00D0`<3000000000000000000410
@03o0?ooo`80oooo00D0P82000000000000000000<30`00;0?ooo`040410@000000000000410@?l0
oooo00D0P82000000000000000000<30`0080?ooo`050<30`0000000000000000020P800c@3ooolK
ooooo`006Oooool00`20P80000000000000:000000l0oooo0P0000000`20P800oooo0?ooo`3<0?oo
o`@00000203oool400000?l0oooo103oool01020P800000000000000000:0?ooo`@00000o`3oool2
0?ooo`040820P00000000000000000P0oooo0`0000000`20P800oooo0?ooo`3<0?oooa_ooooo000I
ooooo`030?ooo`20P800000000/000003P3oool2000000030820P03oool0oooo0<d0oooo00@0@410
000000000000@4101P3oool01010@400000000000010@43o0?ooo`H0oooo00D0@410000000000000
00000<30`0070?ooo`040410@000000000000410@?l0oooo103oool01@20P8000000000000000000
`<3000@0oooo00D0`<3000000000000000000410@03?0?oooa_ooooo000Iooooo`80oooo00<0P820
0000000000002@00000>0?ooo`80000000<0P8200?ooo`3oool0cP3oool2000000030820P03oool0
oooo00@0oooo00<0P820000000000000o`3oool80?ooo`<00000203oool00`20P80000000000003o
0?ooo`H0oooo00<0P8200000000000001P3oool300000=00oooo6oooool001Wooooo0`3oool00`20
P800`<300?ooo`070?ooo`80P8203@3oool2000000030820P03oool0oooo0<h0oooo00<0`<300820
P03oool01`3oool00`20P800oooo0?ooo`3o0?ooo`P0oooo00<0P8200?ooo`3oool0203oool00`20
P800`<300?ooo`3o0?ooo`H0oooo00<0P8200?ooo`3oool01P3oool00`20P800oooo0?ooo`3?0?oo
oa_ooooo000Iooooo`@0oooo0P30`<080?ooo`030<30`03oool0oooo00/0oooo0P0000000`20P800
oooo0?ooo`3o0?ooool0ooooo`3ooooC0?oooa_ooooo000Iooooo`D0oooo00<0P8200?ooo`3oool0
503oool2000000030820P03oool0oooo0?l0ooooo`3ooooo0?ooom<0oooo6oooool001Wooooo1P3o
ool00`20P800`<300?ooo`0C0?ooo`80000000<0P8200?ooo`20P8003`20P83o0?ooool0ooooo`3o
ooo40?oooa_ooooo000Iooooo`L0oooo00<0P8200?ooo`3oool04P3oool2000000030820P03oool0
000000l00000o`3ooooo0?ooool0ooooa03ooolKooooo`006Oooool80?ooo`0300000030`<00oooo
0140oooo0P0000000`20P800oooo0000000?00000<H0oooo00<0`<300820P030`<00o`3ooooo0?oo
ooX0oooo6oooool001Wooooo2@3oool00`10@400`<300?ooo`0@0?ooo`80000000<0P8200?ooo`3o
ool0eP3oool01020P80000000410@020P83o0?ooo`/0oooo00<0P8200<30`03oool00`3oool20820
P?l0oooo303oool00`30`<00P8200820P03F0?oooa_ooooo000Iooooo`T0oooo00<0P8200000003o
ool0403oool2000000030820P03oool0oooo0=L0oooo1@00003o0?ooo`L0oooo00<0P82000000000
00001@3oool300000?l0oooo2P3oool3000000030820P03oool0oooo0=@0oooo6oooool001Wooooo
2P3oool200000100oooo0P0000000`20P800oooo0?ooo`3G0?ooo`030820P0000000000000<00000
00<0P8200?ooo`3oool0o`3oool10?ooo`050820P0000000000000000010@4001@3oool01P20P800
0000000000000000@4100<30`?l0oooo1@3oool00`20P800000000000002000000030<30`03oool0
oooo0=@0oooo6oooool001Wooooo2P3oool00`20P80000000820P00?0?ooo`80000000<0P8200?oo
o`3oool0f03oool800000?l0oooo1@0000000`20P800oooo0?ooo`040?ooo`H00000o`3oool20?oo
o`030820P0000000000000@00000e`3ooolKooooo`006Oooool:0?ooo`030820P0000000@41000l0
oooo0P0000000`20P800oooo0?ooo`3H0?ooo`030410@0000000000000H0000000<0@4100<30`03o
ool0m`3oool00`30`<00P8200410@006000000L0oooo00<0P820000000000000100000020820P?`0
oooo00<0P8200000000000001@00003H0?oooa_ooooo000Iooooo`030<30`03oool0oooo00L0oooo
00<0P8200000000000003`3oool2000000030820P03oool0oooo0</0oooo0P3oP80;0?ooo`030<30
`0000000000000T0000000<0`<300?ooo`3oool0l@3oool00`30`<00P82000000008000000T0oooo
00<0@4100000000000001P0000000`20P800`<300?ooo`3e0?ooo`030820P0000000000000L00000
00<0P8200?ooo`3oool0eP3ooolKooooo`006Oooool00`20P80000000?ooo`070?ooo`030820P000
0000000000l0oooo0P0000000`20P800oooo0?ooo`3;0?ooo`030?n0P03o0000oh2000/0oooo3@00
003b0?ooo`X0000000<0P8200?ooo`3oool01`3oool00`20P80000000000000900000?<0oooo00<0
P8200000000000002@00000=0?ooo`030?l0003oool0oooo0<T0oooo6oooool001Wooooo00<0oooo
00000020P8001`3oool3000000l0oooo0P0000000`20P800oooo0?ooo`3<0?ooo`80o`0000<0od10
0?ooo`3oool02@3oool=000000030410@020P800oooo0>/0oooo00<0P8200410@00000002P000000
0`30`<00oooo0?ooo`080?ooo``0000000<0P8200?ooo`3oool0k@3oool00`20P800@4100000000:
000000030820P03oool0oooo00T0oooo00<0oh200?m0@03oool0b`3ooolKooooo`006Oooool20?oo
o`030000003oool0oooo00@0oooo00@0P820000000000000P8203`3oool2000000030820P03oool0
oooo0<d0oooo0`3o00000`3oP800oooo0?ooo`070?oooa400000j@3oool>000000`0oooo3@000000
0`20P800oooo0?ooo`3Z0?ooo`h000002`3oool00`3oP800o`000?l0003<0?oooa_ooooo000Ioooo
o`80oooo00<0@41000000010@4000`20P804000000030<30`03oool0oooo00d0oooo0P0000000`20
P800oooo0?ooo`3=0?ooo`030?m0@03o0000o`000080o`0000<0ol300?ooo`3oool01@3oool00`20
P80000000000000?000000030820P03oool0oooo0>80oooo0P20P80>000000d0oooo00<0@4100000
00000000300000000`10@400`<300?ooo`3U0?ooo`030820P010@400000000d0000000<0P8200?oo
o`3oool0203oool0103o@400o`000?l0003oP83<0?oooa_ooooo000Iooooo`<0oooo00<0P8200000
00000000100000000`10@400oooo0?ooo`0?0?ooo`80000000<0P8200?ooo`3oool0c@3oool00`3o
`<00o`000?l000030?l000030?m0@03oool0oooo00D0oooo4`0000000`10@400oooo0?ooo`3M0?oo
o`030<30`010@400000000l0000000<0P8200?ooo`3oool02`3oool00`30`<0000000000000?0000
0080P820h03oool00`20P800@4100000000@000000P0oooo00<0oh200?m0@03o00000P3o00000`3o
P800oooo0?ooo`3;0?oooa_ooooo000Iooooo`D0oooo00D0P82000000000000000000820P00B0?oo
o`80000000<0P8200?ooo`3oool0cP3oool00`3oP800o`000?l000040?l000030?n0P03oool0oooo
00@0oooo500000000`20P800oooo0?ooo`3I0?ooo`030820P00000000000014000003`3ooolD0000
0=d0oooo00<0P8200000000000004@0000000`20P800oooo0?ooo`050?ooo`030?n0P03o0000o`00
0080o`0000<0oh200?ooo`3oool0c03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0cP3oool00`3o`<00o`000?l000050?l000030?n0P03o`<00oooo00<0oooo00<0@41000000000
00004P00003J0?ooo`030820P000000000000140000000<0@4100?ooo`3oool03@3oool00`20P800
00000000000A000000030410@020P800oooo0=T0oooo00<0P8200000000000004P0000000`30`<00
oooo0?ooo`040?ooo`030?m0@03o0000o`0000<0o`0000<0ol300?ooo`3oool0c03ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0c`3oool90?l000050?n0P03oool0oooo0?ooo`20
P8004`0000000`20P800oooo0?ooo`3G0?oooaD0000000<0P8200?ooo`3oool03P3ooolE00000003
0820P03oool0oooo0=H0oooo5P0000050?ooo`030?n0P03o0000o`0000@0o`0000<0oh200?ooo`3o
ool0c@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0d03oool00`3o@400o`00
0?l000060?l000040?n0P03o`<00oooo0?oooa<0000000<0P8200?ooo`3oool0e`3oool00`20P800
00000000000B000000030<30`03oool0oooo00h0oooo00<0P8200000000000004P0000000`30`<00
oooo0?ooo`3F0?ooo`030820P0000000000001800000103oool00`3o`<00oh200?l000060?l00003
0?o0`03oool0oooo0<d0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0=00oooo
00<0ol300?l0003o0000203o00000`3oP800ol300820P00A000000030820P03oool0oooo0=T0oooo
4`0000000`20P800oooo0?ooo`0@0?ooo`030410@000000000000100000000<0P8200?ooo`3oool0
f03ooolC000000040820P03oool0oooo0?o0`0T0o`00d@3ooolKooooo`006OoooolL0?ooo`800000
00<0P8200?ooo`3oool0dP3oool;0?l000030?n0P0000000000000l00000g@3ooolB000001<0oooo
00<0P8200000000000004000003L0?oooa8000000P3oool00`3oP800o`000?l000070?l000030?n0
P03oool0oooo0<l0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0=80oooo00<0
oh200?l0003o00002@3o000@000000030<30`03oool0oooo0=/0oooo00<0@4100000000000003P00
00000`20P800oooo0?ooo`0B0?oooa40000000<0`<300?ooo`3oool0fP3oool00`10@40000000000
000>000000030820P03o`<00oh2000X0o`00dP3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0d`3oool<0?l000h00000h03oool@000001H0oooo4000003N0?oooa00000000<0oooo
0?l0003o00002@3o003C0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3C0?oo
o`030?n0P03o0000o`0000T0o`0000<0@0000000000000002P0000000`20P800oooo0?ooo`3N0?oo
o`030820P0000000000000`0000000<0P8200?ooo`3oool0503oool00`10@40000000000000<0000
00030<30`03oool0oooo0=`0oooo00<0@410000000000000300000000`200000o`000?l000090?l0
00030?m0@03oool0oooo0=40oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0=@0
oooo00<0oh200?l0003o0000203o00000`30000000000000000;000000030820P03oool0oooo0=h0
oooo00<0P8200000000000002P0000000`10@400oooo0?ooo`040?ooo`030?n0P03oool0oooo00P0
oooo00<0oh200?o0`03oool00`3oool00`30`<0000000000000:000000030410@03oool0oooo0=l0
oooo00<0P8200000000000002`00000<0?l00=@0oooo6oooool001Wooooo703oool2000000030820
P03oool0oooo0=D0oooo2`3o000:000000050?ooo`000000000000000020P800g`3oool=00000003
0820P03oool0oooo00<0oooo00<0o`000?n0P03oool02P3oool00`3o0000oooo0?ooo`030?ooo`d0
0000h@3oool=000000030800003o0000o`0000T0o`0000<0oh200?ooo`3oool0dP3ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0e@3oool00`3oP800o`000?l000090?l000P00000
00<0@4100?ooo`30`<000`0000000`20P800oooo0?ooo`3J0?ooo`050<30`0000000000000000020
P8002P0000040?ooo`040?o0`03o0000o`000?o0`0/0oooo00<0oh200?l0003oP8000`3oool00`20
P80000000000000;000000030<30`03oool0oooo0=`0oooo00<0@4100000000000002`0000000`30
0000o`000?l000090?l000030?o0`03oool0oooo0=80oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0=H0oooo2`3o00000`200000000000000005000000<0oooo00D0P82000000000
000000000820P03K0?ooo`<0000000<0P8200?ooo`20P800200000001020P800oooo0?ooo`3oool3
0?l000h0oooo0`3o00030?ooo`T0000000<0oooo0000000000000P00003M0?ooo`060820P0000000
00000000003oool0P8202@00000;0?l00=H0oooo6oooool001Wooooo703oool2000000030820P03o
ool0oooo0=H0oooo00<0oh200?l0003o0000203o00000`3000000000000000020000000404000030
0000o`000?n0P0<0oooo00D0P82000000000000000000<30`03H0?ooo`050<30`000000000000000
0010@4000`3oool00`20P800000000000005000000030<30`03oool0oh2000<0o`0000<0od100?oo
o`3oool0303oool01`3oP800o`000?l0003o0000od100?ooo`20P8001`0000001030`<00oooo0?oo
o`10@402000000030410@03oool0oooo0=T0oooo00D0P82000000000000000000<30`0020?ooo`03
0410@0000000000000D000002`3o00000`3o@400oooo0?ooo`3D0?oooa_ooooo000Ioooooa`0oooo
0P0000000`20P800oooo0?ooo`3G0?ooo`030?m0@03o0000o`0000P0o`0000@0@000000000100000
P0001@3o0000103o@400oooo0?ooo`30`<03000000030820P03oool0oooo0=@0oooo00D0`<300000
0000000000000820P0060?ooo`030410@000000000000080000000<0P8200?o0`03o00000`3o0000
0`3o@400oooo0?ooo`0>0?ooo`030?n0P03o0000o`000080o`0000<0oh200400000000000`000000
0`20P800oooo0?ooo`030?ooo`050820P0000000000000000030`<00f03oool01010@40000000000
0010@4040?ooo`030?m0@03o0000@00000@0000000<0P0000?l0003o00002@3o00000`3o`<00oooo
0?ooo`3D0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3G0?ooo`030?n0P03o
0000o`0001<0o`000`3oool3000000030820P03oool0oooo0=<0oooo0`0000000`20P800oooo0?oo
o`070?ooo`<000001P3o00000`3oP800oooo0?ooo`0?0?ooo`D0o`0000@0P0000000000000000000
203oool01020P800000000000000003G0?ooo`@00000103oool50?l000<000002`3o003H0?oooa_o
oooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3H0?ooo`030?m0@03o0000o`0001<0o`00
00<0oh200?ooo`30`<000`0000000`20P800oooo0?ooo`3@0?ooo`050<30`0000000000000000020
P8002P3oool00`30`<00P0000<0000060?l00180oooo00<0ol300?l0003o00000`3o00000`000000
P0000?ooo`090?ooo`050410@0000000000000000030`<00e03oool01@10@4000000000000000000
`<300080oooo00<0od100?l0003o0000103o00000`300000@0000800000:0?l000030?m0@03oool0
oooo0=H0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0=P0oooo00<0oh200?l0
003o00005@3o00000`3oool0P82000000002000000030820P03oool0oooo0<l0oooo0`0000000`20
P800oooo0?ooo`090?ooo`P0o`00503oool80?l000X0oooo1000003C0?ooo`040820P00000000000
00000080oooo00<0oh200?l0003o00004`3o00000`3oP800oooo0?ooo`3F0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3I0?ooo`030?n0P03o0000o`0000/0o`000P3oP8090?oo
o`050820P0000000000000000030`<00cP3oool01@30`<000000000000000000@41000X0oooo00<0
oh200?l0003o00001P3o00000`3oP800oooo0?ooo`0C0?ooo`P0o`0000<0od100?ooo`3oool01`3o
ool01010@400000000000010@43A0?ooo`070820P0000000000000000030`<00oooo0?n0P00E0?l0
00030?n0P03oool0oooo0=L0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0=X0
oooo00<0oh200?l0003o00002@3o00000`3o`<00oooo0?ooo`0:0?ooo`050<30`000000000000000
0020P800c03oool01@30`<000000000000000000P82000T0oooo00<0oh200?m0@03o00001`3o0000
0`3oP800oooo0?ooo`0D0?ooo`030?o0`03o0000o`0000L0o`0000<0od100?ooo`3oool01P3oool0
1@20P8000000000000000000`<300<h0oooo00@0@410000000000000@4100P3oool60?n0P100o`00
00<0od100?ooo`3oool0f03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0f`3o
ool:0?l00100oooo0`0000000`20P800oooo0?ooo`390?ooo`<0000000<0P8200?ooo`3oool01`3o
ool;0?l001P0oooo2`3o00080?ooo`040820P0000000000000000<d0oooo1000000<0?ooo`d0o`00
00<0oh200?ooo`3oool0f03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0g03o
ool80?l000030?o0`03oool0oooo00h0oooo00D0`<3000000000000000000820P0380?ooo`050<30
`0000000000000000020P800203oool00`3oP800o`000?l000090?l000030?n0P03oool0oooo01H0
oooo00<0ol300?l0003o00002@3o00000`3o@400oooo0?ooo`050?ooo`050410@000000000000000
0030`<00bP3oool01@10@4000000000000000000`<3000`0oooo00<0oh200?l0003o00002@3o0000
0`3o@400oooo0?ooo`3I0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3L0?oo
o`030?n0P03o0000o`0000@0o`004`3oool01@20P8000000000000000000P8200<L0oooo0`000000
0`20P800oooo0?ooo`060?ooo`030?n0P03o0000o`0000X0o`006`3oool<0?l000030?n0P03oool0
oooo00@0oooo100000390?ooo`040820P00000000000000000l0oooo2`3o00000`3oP800oooo0?oo
o`3I0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3M0?ooo`D0o`0000<0od10
0?ooo`3oool04P3oool01@20P8000000000000000000`<300<@0oooo00D0`<300000000000000000
0410@0070?ooo`030?n0P03o0000o`0000/0o`0000<0oh200?ooo`3oool06@3oool00`3o@400o`00
0?l0000:0?l000030?m0@03oool0oooo00@0oooo00@0@410000000000000@410a`3oool01@20P800
0000000000000000`<300100oooo00<0oh200?l0003o00001P3o00000`3oP800oooo0?ooo`3J0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3M0?ooo`030?n0P03o0000o`000080
o`0000<0oh200?ooo`3oool04`3oool01@30`<000000000000000000P8200<80oooo00D0`<300000
0000000000000820P0060?ooo`030?n0P03o0000o`0000d0o`007@3oool>0?l000030?m0@03oool0
oooo00<0oooo00D0P82000000000000000000<30`0340?ooo`040410@000000000000410@1<0oooo
00<0od100?l0003o0000103o00000`3o@400oooo0?ooo`3K0?oooa_ooooo000Ioooooa`0oooo0P00
00000`20P800oooo0?ooo`3N0?ooo`@0o`002@3oool00`3o0000oooo0?ooo`0<0?ooo`<0000000<0
P8200?ooo`3oool0_`3oool3000000030820P03oool0oooo00@0oooo00<0oh200?l0003o00003@3o
000O0?ooo`l0o`0000<0oh200?ooo`3oool00P3oool01020P80000000000000000330?ooo`@00000
5@3oool60?l00=h0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0=h0oooo00@0
oh200?l0003o0000o`001`3oool0103o`<00o`000?l0003o@40=0?ooo`050<30`000000000000000
0020P800_P3oool01@30`<000000000000000000P82000D0oooo00<0ol300?l0003o00003P3o0000
0`3oP800oooo0?ooo`0M0?ooo`030?n0P03o0000o`0000d0o`0000<0od100?ooo`3oool00P3oool0
1@10@4000000000000000000`<300<00oooo00D0@41000000000000000000<30`00E0?ooo`030?n0
P03o0000o`000080o`0000<0oh200?ooo`3oool0g03ooolKooooo`006OoooolL0?ooo`80000000<0
P8200?ooo`3oool0g`3oool30?l000P0oooo103o000=0?ooo`050820P0000000000000000020P800
_@3oool3000000030820P03oool0oooo00<0oooo4P3o000Q0?oooa40o`0000@0oh200?ooo`3oool0
oooo1000002o0?ooo`040820P00000000000000001P0oooo103o003O0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`3O0?ooo`030?o0`03o0000o`0000T0oooo00@0od100?l0003o
0000od103@3oool01@20P8000000000000000000`<300;X0oooo00D0`<3000000000000000000410
@0040?ooo`030?o0`03o0000o`000100o`0000<0oh200?ooo`3oool07`3oool00`3o@400o`000?l0
000?0?l000050?n0P03o`<00oooo0?ooo`10@4000P0000000`10@400oooo0?ooo`2k0?ooo`050820
P0000000000000000030`<00303oool00`3o`<00o`000?m0@0090?ooo`<0o`0000<0ol300?ooo`3o
ool0g@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0h03oool00`3oP800o`00
0?ooo`090?ooo`050?m0@03o0000o`000?l0003o`<00303oool01@30`<000000000000000000P820
0;P0oooo00D0`<3000000000000000000820P0030?ooo`030?o0`03o0000o`000140o`0000<0oh20
0?ooo`3oool0803oool00`3o`<00o`000?l0000A0?l000040?m0@03oool0oooo0820P0<0000000<0
`<300?ooo`3oool0^03oool01010@400000000000010@40=0?ooo`050?o0`03o0000o`000?l0003o
P800203oool20?l000030?m0@03oool0oooo0=h0oooo6oooool001Wooooo703oool2000000030820
P03oool0oooo0>40oooo00<0oh200?ooo`3oool02@3oool40?l000h0oooo0`0000000`20P800oooo
0?ooo`2e0?ooo`<0000000@0P8200?ooo`3oool0oooo5@3o000T0?oooaD0o`0000<0oh200?ooo`20
P8000`00002i0?ooo`@000003P3oool30?l000030?n0P03oool0oooo00L0oooo0P3o003Q0?oooa_o
oooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3Q0?ooo`030?o0`03oool0oooo00X0oooo
00@0od100?l0003o0000od103@3oool01@30`<000000000000000000P8200;@0oooo00D0`<300000
0000000000000820P0020?ooo`030?o0`03o0000o`0001<0o`009P3ooolF0?l000030?o0`010@400
00000080000000<0`<300?ooo`3oool0]03oool01@10@4000000000000000000`<3000`0oooo00D0
ol300?l0003o0000o`000?n0P00:0?ooo`030?l0003oP800oooo0>00oooo6oooool001Wooooo703o
ool2000000030820P03oool0oooo0>l0oooo103o000=0?ooo`050820P0000000000000000020P800
/`3oool3000000030820P03oool0oooo01H0o`0000<0oh200?ooo`3oool0903oool00`3oP800o`00
0?l0000D0?l000030?n0P0000000000000800000]@3oool01020P800000000000000000>0?ooo`<0
o`0000<0oh200?ooo`3oool02@3oool00`3oP800oooo0?ooo`3P0?oooa_ooooo000Ioooooa`0oooo
0P0000000`20P800oooo0?ooo`3`0?ooo`040?m0@03o0000o`000?m0@0d0oooo00D0P82000000000
000000000<30`02`0?ooo`080<30`0000000000000000010@400oooo0?n0P03o@40F0?l002P0oooo
5`3o00001@3oP800@000000000000000@4100;<0oooo00D0P82000000000000000000<30`00<0?oo
o`050?o0`03o0000o`000?l0003o@4002`3oool00`3o0000ol300?ooo`3Q0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3a0?ooo`040?m0@03o0000o`000?n0P0d0oooo00D0`<30
00000000000000000820P02^0?ooo`050<30`0000000000000000020P8002P3oool00`3o`<00od10
0?l0000<0?l000030?n0P03oool0oooo02L0oooo00<0od100?l0003o00002P3o00000`3o@400oh20
0?o0`0080?ooo`050820P0000000000000000030`<00/03oool01010@400000000000010@40=0?oo
o`050?o0`03o0000o`000?l0003oP800l03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0lP3oool00`3o0000oh200?ooo`0?0?ooo`<0000000<0P8200?ooo`3oool0Z`3oool30000
00030820P03oool0oooo00`0oooo303o000[0?ooo``0o`00303oool01020P800000000000000002_
0?ooo`@000003P3oool30?l000030?n0P03oool0oooo0>l0oooo6oooool001Wooooo703oool20000
00030820P03oool0oooo0?l0oooo1@3oool01@30`<000000000000000000P8200:X0oooo00D0`<30
00000000000000000820P00@0?ooo`030?n0P03o0000o`0000L0o`00;03oool00`3o@400o`000?l0
00070?l000030?o0`03oool0oooo00`0oooo00D0@41000000000000000000<30`02/0?ooo`050410
@0000000000000000030`<003@3oool0103oP800o`000?l0003oP83b0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`3o0?ooo`H0oooo00D0P82000000000000000000820P02Y0?oo
o`<0000000<0P8200?ooo`3oool0403oool00`3oP800o`000?l000050?l000030?n0P03oool0oooo
02/0oooo2@3o000@0?ooo`@00000Z`3oool01020P800000000000000000@0?ooo`80oh20l`3ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oool70?ooo`050820P00000000000
00000030`<00YP3oool01@30`<000000000000000000@41001<0oooo00<0ol300?l0003o00001@3o
00000`3o`<00oooo0?ooo`0[0?ooo`030?n0P03o0000o`0000D0o`0000<0ol300?ooo`3oool03`3o
ool01010@400000000000010@42Y0?ooo`050820P0000000000000000030`<00o`3oool60?oooa_o
oooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`P0oooo00D0`<30000000000000
00000820P02T0?ooo`050<30`0000000000000000020P8003@3oool00`3o@400o`000?o0`0050?oo
o`H0o`00<03oool00`3oP800o`000?l000030?l000030?n0P03oool0oooo00<0oooo0P3o@40<0?oo
o`050820P0000000000000000030`<00YP3oool01010@400000000000010@43o0?ooo`P0oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo0?X0oooo00<0o`000?ooo`3oool0303oool3
000000030820P03oool0oooo0:40oooo0`0000000`20P800oooo0?ooo`0;0?ooo`@0o`001@3oool0
0`3oP800o`000?l000020?l000030?n0P03oool0oooo02l0oooo1@3o00050?ooo`@0o`00303oool0
1020P800000000000000002U0?ooo`@00000o`3oool90?oooa_ooooo000Ioooooa`0oooo0P000000
0`20P800oooo0?ooo`3h0?ooo`040?o0`03o0000o`000?m0@0d0oooo00D0`<300000000000000000
0820P02P0?ooo`050<30`0000000000000000020P8003@3oool01@3o@400o`000?l0003o0000ol30
00D0oooo00<0oh200?l0003o00000P3o000c0?ooo`<0o`0000<0od100?ooo`3oool0103oool0103o
@400o`000?l0003o@40<0?ooo`050410@0000000000000000030`<00XP3oool01@10@40000000000
00000000`<300?l0oooo2@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0n@3o
ool40?l000d0oooo00D0P82000000000000000000820P02O0?ooo`<0000000<0P8200?ooo`3oool0
2`3oool0103oP800o`000?l0003o00070?ooo`050?n0P03o0000o`000?l0003oP800<`3oool0103o
P800o`000?l0003oP8070?ooo`@0o`00303oool400000:40oooo00@0P82000000000000000003P3o
ool00`3o0000oooo0?ooo`3i0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3j
0?ooo`040?m0@03o0000o`000?m0@0d0oooo00D0P82000000000000000000<30`02L0?ooo`050<30
`0000000000000000010@4003@3oool01@3oP800o`000?l0003o0000ol3000L0oooo00@0oh200?l0
003o0000o`00=@3oool20?l000030?n0P03oool0oooo00D0oooo00D0ol300?l0003o0000o`000?m0
@00<0?ooo`040410@000000000000410@9l0oooo00D0P82000000000000000000<30`00<0?ooo`05
0?o0`03o0000o`000?l0003o`<00n@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0n`3oool01@3o@400o`000?l0003o0000ol3000`0oooo00D0`<3000000000000000000820P02J
0?ooo`050<30`0000000000000000020P8003@3oool0103o@400o`000?l0003o@4090?ooo`030?n0
P03o0000od1003H0oooo00<0ol300?l0003oP8002@3oool0103o@400o`000?l0003o@40<0?ooo`05
0820P0000000000000000030`<00W03oool01010@400000000000010@40=0?ooo`050?o0`03o0000
o`000?l0003oP800nP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o03oool4
0?l000h0oooo0`0000000`20P800oooo0?ooo`2G0?ooo`<0000000<0P8200?ooo`3oool02`3oool4
0?l000X0oooo00<0oh200?l0003oP800=`3oool00`3o0000oh200?ooo`090?ooo`@0o`00303oool0
1020P800000000000000002K0?ooo`@000003P3oool30?l000030?n0P03oool0oooo0?T0oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo0?d0oooo00@0od100?l0003o0000od103@3o
ool01@30`<000000000000000000P82009H0oooo00D0`<3000000000000000000820P00=0?ooo`05
0?m0@03o0000o`000?l0003o`<002P3oool20?n0P3T0oooo00<0oh200?ooo`3oool02@3oool0103o
@400o`000?l0003o@40<0?ooo`050410@0000000000000000030`<00V03oool01@10@40000000000
00000000`<3000`0oooo00D0ol300?l0003o0000o`000?n0P03l0?oooa_ooooo000Ioooooa`0oooo
0P0000000`20P800oooo0?ooo`3n0?ooo`@0o`003@3oool01@20P8000000000000000000P82009D0
oooo0`0000000`20P800oooo0?ooo`0;0?ooo`040?n0P03o0000o`000?l000`0oooo00<0oh200?oo
o`3oool0>03oool00`3oP800oooo0?ooo`0:0?ooo`@0o`00303oool4000009L0oooo00@0P8200000
0000000000003P3oool30?l000030?n0P03oool0oooo0?/0oooo6oooool001Wooooo703oool20000
00030820P03oool0oooo0?l0oooo00@0od100?l0003o0000od103@3oool01@20P800000000000000
0000`<300980oooo00D0`<3000000000000000000410@00>0?ooo`040?m0@03o0000o`000?o0`5@0
oooo00D0ol300?l0003o0000o`000?o0`00<0?ooo`040410@000000000000410@9D0oooo00D0P820
00000000000000000<30`00<0?ooo`050?o0`03o0000o`000?l0003o@400oP3ooolKooooo`006Ooo
oolL0?ooo`80000000<0P8200?ooo`3oool0o`3oool10?ooo`040?m0@03o0000o`000?n0P0d0oooo
00D0`<3000000000000000000820P02@0?ooo`050<30`0000000000000000020P800403oool00`3o
P800oooo0?ooo`1F0?ooo`030?n0P03oool0oooo00d0oooo00D0P82000000000000000000<30`02B
0?ooo`040410@000000000000410@0d0oooo00D0ol300?l0003o0000o`000?n0P03o0?oooa_ooooo
000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`80oooo00<0o`000?n0P03oool03`3o
ool3000000030820P03oool0oooo08d0oooo0`0000000`20P800oooo0?ooo`1i0?ooo`040820P000
0000000000000940oooo1000000>0?ooo`<0o`0000<0oh200?ooo`3oool0oP3ooolKooooo`006Ooo
oolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolD0?ooo`050<30`0000000000000000020P800
S03oool01@30`<000000000000000000P82007d0oooo00D0@41000000000000000000<30`02>0?oo
o`050410@0000000000000000030`<003@3oool0103oP800o`000?l0003oP83o0?ooo`80oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo5@3oool01@20P800000000000000
0000P82008/0oooo0`0000000`20P800oooo0?ooo`1m0?ooo`@00000S@3oool01020P80000000000
0000000@0?ooo`80oh20o`3oool30?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?oo
o`3o0?oooaH0oooo00D0P82000000000000000000<30`0280?ooo`050<30`0000000000000000010
@400303oool00`3o`<00oh200?ooo`1V0?ooo`030?o0`03oool0oooo00T0oooo00@0@41000000000
0000@410R`3oool01@20P8000000000000000000`<300?l0oooo5@3ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0o`3oool:0?ooo`030?n0P03oool0oooo00X0oooo00D0`<300000
0000000000000820P0260?ooo`050<30`0000000000000000020P800303oool0103oP800o`000?l0
003o@41U0?ooo`030?m0@03o0000oh2000/0oooo00D0P82000000000000000000<30`0280?ooo`04
0410@000000000000410@?l0oooo5`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0o`3oool90?ooo`80o`0000<0oh200?ooo`3oool02`3oool3000000030820P03oool0oooo08<0
oooo0`0000000`20P800oooo0?ooo`0:0?ooo`050?n0P03o0000o`000?l0003oP800I@3oool0103o
P800o`000?l0003oP80;0?ooo`030820P0000000000000800000QP3oool400000?l0oooo603ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oool80?ooo`050?o0`03o0000o`00
0?l0003oP800303oool01@30`<000000000000000000P8200880oooo00D0`<300000000000000000
0820P00<0?ooo`050?o0`03o0000o`000?l0003oP800I`3oool0103o@400o`000?l0003oP80;0?oo
o`050410@0000000000000000010@400P`3oool00`30`<00000000000002000000030<30`03oool0
oooo0?l0oooo5P3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oool:0?oo
o`<0o`0000<0oh200?ooo`3oool02P3oool01@20P8000000000000000000P8200840oooo0`000000
0`20P800oooo0?ooo`0;0?ooo`<0o`0000<0oh200?ooo`3oool0I`3oool40?l000`0oooo0`000000
0`20P800oooo0?ooo`200?ooo`@000003P3oool00`3o0000oooo0?ooo`3o0?ooo`T0oooo6oooool0
01Wooooo703oool2000000030820P03oool0oooo0?l0oooo2P3oool01@3o`<00o`000?l0003o0000
oh2000`0oooo00D0P82000000000000000000<30`01n0?ooo`050<30`0000000000000000010@400
303oool01@3o@400o`000?l0003o0000oh2006/0oooo00@0od100?l0003o0000od102`3oool01@30
`<000000000000000000P82007l0oooo00D0`<3000000000000000000820P00=0?ooo`050?o0`03o
0000o`000?l0003o`<00o`3oool90?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?oo
o`3o0?ooo`/0oooo00D0ol300?l0003o0000o`000?o0`00<0?ooo`050<30`0000000000000000020
P800O03oool01@30`<000000000000000000P82000/0oooo00H0ol300?l0003o0000o`000?m0@03o
`<1]0?ooo`050?n0P03o0000o`000?l0003o`<002`3oool01010@400000000000010@41m0?ooo`05
0820P0000000000000000030`<003@3oool01@3o`<00o`000?l0003o0000oh200?l0oooo2P3ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oool=0?ooo`<0o`003P3oool30000
00030820P03oool0oooo07T0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`@0o`00L03oool0103o
P800o`000?l0003o000<0?ooo`@00000N`3oool01@20P8000000000000000000P82000h0oooo0`3o
00000`3oP800oooo0?ooo`3o0?ooo`T0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo0?l0oooo3@3oool0103o@400o`000?l0003o@40=0?ooo`050<30`0000000000000000020P800
N03oool01@30`<000000000000000000P82000`0oooo00@0od100?l0003o0000od10LP3oool01@3o
@400o`000?l0003o0000oh2000X0oooo00D0`<3000000000000000000410@01i0?ooo`050<30`000
0000000000000020P8003P3oool0103oP800o`000?l0003oP83o0?ooo``0oooo6oooool001Wooooo
703oool2000000030820P03oool0oooo0?l0oooo3P3oool40?l000d0oooo00D0P820000000000000
00000820P01g0?ooo`<0000000<0P8200?ooo`3oool02`3oool00`3oP800o`000?l0001d0?ooo`<0
o`0000<0oh200?ooo`3oool02P3oool3000000030820P03oool0oooo07H0oooo0`0000000`20P800
oooo0?ooo`0<0?ooo`040?n0P03o0000o`000?n0P?l0oooo3@3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0o`3oool?0?ooo`040?m0@03o0000o`000?m0@0d0oooo00D0P8200000
0000000000000<30`01d0?ooo`050<30`0000000000000000010@4003`3oool00`3oP800oooo0?oo
o`1d0?ooo`80oh203@3oool01@30`<000000000000000000P82007D0oooo00D0`<30000000000000
00000820P00>0?ooo`050?n0P03o0000o`000?l0003o`<00o`3oool=0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`3o0?oooa00oooo00<0od100?l0003o`<003P3oool01@30`<00
0000000000000000P8200780oooo00D0`<3000000000000000000820P02H0?ooo`040410@0000000
00000410@7<0oooo00D0P82000000000000000000<30`00>0?ooo`050?m0@03o0000o`000?l0003o
`<00o`3oool>0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooob<0oooo
0`0000000`20P800oooo0?ooo`1_0?ooo`<0000000<0P8200?ooo`3oool0V03oool400000740oooo
00D0P82000000000000000000820P00>0?ooo`040?n0P03o0000o`000?l00?l0oooo403ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolS0?ooo`050<30`000000000000000
0020P800KP3oool01@30`<000000000000000000P82009/0oooo00D0`<3000000000000000000410
@01_0?ooo`050<30`0000000000000000020P8003`3oool0103o@400o`000?l0003o`<3o0?oooa00
oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo903oool01@20P8000000
000000000000P82006d0oooo0`0000000`20P800oooo0?ooo`2L0?ooo`<0000000<0P8200?ooo`3o
ool0K03oool3000000030820P03oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3oool@0?oooa_o
oooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooobD0oooo00D0P820000000000000
00000<30`01Z0?ooo`050<30`0000000000000000010@4002`3oool00`3oP800o`000?n0P0240?oo
o`030?o0`03o0000oh2000X0oooo00D0`<3000000000000000000820P01[0?ooo`050<30`0000000
000000000020P800o`3ooolU0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaP0oooo00<0oh200?o0`03oool02`3oool01@30`<000000000000000000P82006P0oooo00D0
`<3000000000000000000820P00;0?ooo`050?m0@03o0000o`000?l0003o`<00P`3oool01@3o@400
o`000?l0003o@400oh2000X0oooo00@0@410000000000000@410J@3oool01@20P800000000000000
0000`<300?l0oooo9P3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolG
0?ooo`030?n0P03o0000o`0000h0oooo0`0000000`20P800oooo0?ooo`1U0?ooo`<0000000<0P820
0?ooo`3oool02@3oool0103oP800o`000?l0003o00260?ooo`@0o`0000<0oh200?ooo`3oool0203o
ool4000006L0oooo00D0P82000000000000000000820P03o0?ooobL0oooo6oooool001Wooooo703o
ool2000000030820P03oool0oooo0?l0oooo5`3oool0103o@400o`000?l0003o@40=0?ooo`050<30
`0000000000000000020P800I03oool01@30`<000000000000000000P82000/0oooo00D0oh200?l0
003o0000o`000?o0`0260?ooo`030?o0`03oP800o`000080o`0000<0ol300?ooo`3oool01`3oool0
1@30`<000000000000000000@41006D0oooo00D0`<3000000000000000000820P00=0?ooo`030?o0
`03oP800oooo0?l0oooo603ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3o
oolH0?ooo`@0o`003@3oool01@20P8000000000000000000P82006<0oooo0`0000000`20P800oooo
0?ooo`090?ooo`@0o`00RP3oool0103oP800o`000?l0003o000;0?ooo`<0000000<0P8200?ooo`3o
ool0HP3oool3000000030820P03oool0oooo00`0oooo0P3o00000`3oP800oooo0?ooo`3o0?oooaH0
oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo6@3oool0103o@400o`00
0?l0003o@40=0?ooo`050820P0000000000000000030`<00H03oool01@30`<000000000000000000
@41000X0oooo00<0ol300?l0003o00000P3o00000`3o`<00oooo0?ooo`290?ooo`050?n0P03o0000
o`000?l0003oP8002@3oool01@30`<000000000000000000P8200640oooo00D0`<30000000000000
00000820P00=0?ooo`050?o0`03o0000o`000?l0003o@400o`3ooolH0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`3o0?oooaX0oooo00D0od100?l0003o0000o`000?o0`00<0?oo
o`050<30`0000000000000000020P800GP3oool01@30`<000000000000000000P82000X0oooo00D0
ol300?l0003o0000o`000?n0P02>0?ooo`030?o0`03o0000o`000080o`0000<0ol300?ooo`3oool0
1`3oool01010@400000000000010@41O0?ooo`050820P0000000000000000030`<003@3oool01@3o
`<00o`000?l0003o0000oh200?l0oooo6@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0o`3ooolK0?ooo`@0o`003P3oool3000000030820P03oool0oooo05/0oooo0`0000000`20
P800oooo0?ooo`090?ooo`<0o`0000<0oh200?ooo`3oool0S`3oool40?l000X0oooo1000001M0?oo
o`050820P0000000000000000020P8003P3oool30?l000030?n0P03oool0oooo0?l0oooo603ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolL0?ooo`040?m0@03o0000o`00
0?m0@0d0oooo00D0`<3000000000000000000820P01J0?ooo`050<30`0000000000000000020P800
2`3oool0103oP800o`000?l0003oP82C0?ooo`030?m0@03o0000od1000X0oooo00D0`<3000000000
000000000410@01K0?ooo`050<30`0000000000000000020P8003@3oool01@3o`<00o`000?l0003o
0000oh200?l0oooo6`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolM
0?ooo`@0o`003@3oool01@20P8000000000000000000P82005T0oooo0`0000000`20P800oooo0?oo
o`0;0?ooo`80oh20U@3oool00`3o0000oooo0?ooo`0;0?ooo`<0000000<0P8200?ooo`3oool0F03o
ool3000000030820P03oool0oooo00`0oooo0`3o00000`3oP800oooo0?ooo`3o0?oooaX0oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo7P3oool0103o@400o`000?l0003o
@40=0?ooo`050820P0000000000000000030`<00EP3oool01@30`<000000000000000000@4100;<0
oooo00D0`<3000000000000000000820P01G0?ooo`050<30`0000000000000000020P8003@3oool0
1@3o`<00o`000?l0003o0000od100?l0oooo7@3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooolO0?ooo`030?m0@03o0000ol3000h0oooo00D0`<3000000000000000000820
P01D0?ooo`050<30`0000000000000000020P800]P3oool01010@400000000000010@41E0?ooo`05
0820P0000000000000000030`<003@3oool01@3o`<00o`000?l0003o0000oh200?l0oooo7P3ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolb0?ooo`<0000000<0P8200?oo
o`3oool0D@3oool3000000030820P03oool0oooo0;H0oooo1000001C0?ooo`050820P00000000000
00000020P8003P3oool30?l000030?n0P03oool0oooo0?l0oooo7@3ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0o`3ooolb0?ooo`050<30`0000000000000000020P800D03oool0
1@30`<000000000000000000P82000X0oooo00<0oh200?ooo`3oool0XP3oool00`3o`<00oooo0?oo
o`070?ooo`050<30`0000000000000000010@400D@3oool01@30`<000000000000000000P82000l0
oooo00<0ol300?l0003oP800o`3ooolP0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo
0?ooo`3o0?oooc<0oooo00D0P82000000000000000000820P01?0?ooo`<0000000<0P8200?ooo`3o
ool0203oool30?l00:<0oooo0P3o000:0?ooo`<0000000<0P8200?ooo`3oool0CP3oool300000003
0820P03oool0oooo0?l0oooo<@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0
o`3ooold0?ooo`050820P0000000000000000030`<00C03oool01@30`<000000000000000000@410
00X0oooo00D0od100?l0003o0000o`000?o0`02Q0?ooo`040?o0`03o0000o`000?m0@0T0oooo00D0
`<3000000000000000000820P01=0?ooo`050<30`0000000000000000020P800o`3ooold0?oooa_o
oooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooobL0oooo00<0oh200?o0`03oool0
2`3oool01@30`<000000000000000000P82004X0oooo00D0`<3000000000000000000820P00:0?oo
o`040?m0@03o0000o`000?m0@:@0oooo00D0ol300?l0003o0000o`000?n0P0090?ooo`040410@000
000000000410@4/0oooo00D0P82000000000000000000<30`03o0?ooocD0oooo6oooool001Wooooo
703oool2000000030820P03oool0oooo0?l0oooo9P3oool30?l000h0oooo0`0000000`20P800oooo
0?ooo`170?ooo`<0000000<0P8200?ooo`3oool0203oool40?l00:L0oooo0`3o00000`3oP800oooo
0?ooo`070?ooo`@00000B@3oool01@20P8000000000000000000P8200?l0oooo=P3ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolV0?ooo`040?o0`03o0000o`000?m0@0d0
oooo00D0`<3000000000000000000820P0160?ooo`050<30`0000000000000000020P8002P3oool0
103o@400o`000?l0003o@42X0?ooo`050?o0`03o0000o`000?l0003oP800203oool01@30`<000000
000000000000@41004L0oooo00D0`<3000000000000000000820P00=0?ooo`030?o0`03oP800oooo
0?l0oooo9`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolX0?ooo`<0
o`003@3oool01@20P8000000000000000000P82004D0oooo0`0000000`20P800oooo0?ooo`080?oo
o`@0o`00Z`3oool30?l000030?n0P03oool0oooo00L0oooo0`0000000`20P800oooo0?ooo`140?oo
o`<0000000<0P8200?ooo`3oool0303oool20?l000030?n0P03oool0oooo0?l0oooo9@3ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolX0?ooo`040?o0`03o0000o`000?m0
@0d0oooo00D0P82000000000000000000<30`0120?ooo`050<30`0000000000000000010@4002P3o
ool01@3o@400o`000?l0003o0000ol300:/0oooo00D0ol300?l0003o0000o`000?n0P0080?ooo`05
0<30`0000000000000000020P800@`3oool01@30`<000000000000000000P82000d0oooo00D0ol30
0?l0003o0000o`000?m0@03o0?ooobL0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo0?l0oooo:@3oool01@3o`<00o`000?l0003o0000ol3000`0oooo00D0`<300000000000000000
0820P0100?ooo`050<30`0000000000000000020P8002P3oool0103o@400o`000?l0003o@42^0?oo
o`050?o0`03o0000o`000?l0003o@4002@3oool01010@400000000000010@4110?ooo`050820P000
0000000000000030`<003@3oool01@3o`<00o`000?l0003o0000oh200?l0oooo:03ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooolZ0?ooo`@0o`003P3oool3000000030820
P03oool0oooo03d0oooo0`0000000`20P800oooo0?ooo`080?ooo`@0o`00/@3oool30?l000030?n0
P03oool0oooo00L0oooo1000000o0?ooo`050820P0000000000000000020P8003P3oool30?l00003
0?n0P03oool0oooo0?l0oooo9`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0
o`3oool[0?ooo`040?m0@03o0000o`000?m0@0d0oooo00D0`<3000000000000000000820P00l0?oo
o`050<30`0000000000000000020P800303oool20?m0@;80oooo00<0ol300?l0003o@4002P3oool0
1@30`<000000000000000000@41003d0oooo00D0`<3000000000000000000820P00=0?ooo`050?o0
`03o0000o`000?l0003oP800o`3ooolZ0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo
0?ooo`3o0?ooob`0oooo103o000=0?ooo`050820P0000000000000000020P800>`3oool300000003
0820P03oool0oooo0<h0oooo0`0000000`20P800oooo0?ooo`0j0?ooo`<0000000<0P8200?ooo`3o
ool0303oool30?l000030?n0P03oool0oooo0?l0oooo:@3ooolKooooo`006OoooolL0?ooo`800000
00<0P8200?ooo`3oool0o`3oool]0?ooo`040?m0@03o0000o`000?o0`0d0oooo00D0P82000000000
000000000<30`00h0?ooo`050<30`0000000000000000010@400d@3oool01@30`<00000000000000
0000P82003T0oooo00D0`<3000000000000000000820P00=0?ooo`050?o0`03o0000o`000?l0003o
@400o`3oool/0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooobh0oooo
00<0oh200?ooo`3oool03P3oool01@30`<000000000000000000P82003H0oooo00D0`<3000000000
000000000820P03D0?ooo`040410@000000000000410@3L0oooo00D0P82000000000000000000<30
`00=0?ooo`050?o0`03o0000o`000?l0003oP800o`3oool]0?oooa_ooooo000Ioooooa`0oooo0P00
00000`20P800oooo0?ooo`3o0?oood40oooo0`0000000`20P800oooo0?ooo`0c0?ooo`<0000000<0
P8200?ooo`3oool0e03oool4000003D0oooo00D0P82000000000000000000820P00>0?ooo`<0o`00
00<0oh200?ooo`3oool0o`3oool/0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?oo
o`3o0?oood40oooo00D0`<3000000000000000000820P00b0?ooo`050<30`0000000000000000020
P8002P3oool00`3oP800oooo0?ooo`300?ooo`030?n0P03oool0oooo00L0oooo00D0`<3000000000
000000000410@00c0?ooo`050<30`0000000000000000020P8003`3oool00`3o`<00o`000?n0P03o
0?ooobl0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo@P3oool01@20
P8000000000000000000P8200340oooo0`0000000`20P800oooo0?ooo`080?ooo`<0o`00`03oool0
0`3oP800o`000?l0000:0?ooo`<0000000<0P8200?ooo`3oool0<03oool3000000030820P03oool0
oooo0?l0oooo@03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooom30?oo
o`050820P0000000000000000030`<00;P3oool01@30`<000000000000000000@41000X0oooo00D0
od100?l0003o0000o`000?o0`02o0?ooo`040?m0@03o0000o`000?m0@0T0oooo00D0`<3000000000
000000000820P00_0?ooo`050<30`0000000000000000020P800o`3ooom30?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooocD0oooo00<0od100?l0003o`<00303oool01@30
`<000000000000000000P82002`0oooo00D0`<3000000000000000000820P00:0?ooo`040?m0@03o
0000o`000?m0@<80oooo00D0od100?l0003o0000o`000?o0`0090?ooo`040410@000000000000410
@2d0oooo00D0P82000000000000000000<30`03o0?oood@0oooo6oooool001Wooooo703oool20000
00030820P03oool0oooo0?l0oooo=03oool40?l000h0oooo0`0000000`20P800oooo0?ooo`0Y0?oo
o`<0000000<0P8200?ooo`3oool0203oool40?l00<@0oooo103o000:0?ooo`@00000:`3oool01@20
P8000000000000000000P8200?l0ooooA@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0o`3ooole0?ooo`040?m0@03o0000o`000?m0@0d0oooo00D0`<3000000000000000000820
P00X0?ooo`050<30`0000000000000000020P8002P3oool0103o`<00o`000?l0003o@4360?ooo`04
0?m0@03o0000o`000?n0P0T0oooo00D0`<3000000000000000000410@00Y0?ooo`050<30`0000000
000000000020P8003P3oool00`3oP800ol300?ooo`3o0?ooocD0oooo6oooool001Wooooo703oool2
000000030820P03oool0oooo0?l0oooo=P3oool40?l000d0oooo00D0P82000000000000000000820
P00W0?ooo`<0000000<0P8200?ooo`3oool02@3oool30?l00<P0oooo0`3o000;0?ooo`<0000000<0
P8200?ooo`3oool09P3oool3000000030820P03oool0oooo00`0oooo00<0oh200?l0003o0000o`3o
oolf0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooocL0oooo00@0od10
0?l0003o0000od103@3oool01@20P8000000000000000000P82002@0oooo00D0`<30000000000000
00000410@00:0?ooo`050?o0`03o0000o`000?l0003o`<00b@3oool0103o@400o`000?l0003o`<09
0?ooo`050<30`0000000000000000020P8009@3oool01@30`<000000000000000000P82000h0oooo
00D0oh200?l0003o0000o`000?o0`03o0?ooocD0oooo6oooool001Wooooo703oool2000000030820
P03oool0oooo0?l0oooo>03oool01@3o@400o`000?l0003o0000ol3000`0oooo00D0`<3000000000
000000000410@00R0?ooo`050<30`0000000000000000020P8002`3oool30?l00<`0oooo00@0od10
0?l0003o0000oh202P3oool01010@400000000000010@40S0?ooo`050820P0000000000000000030
`<003P3oool01@3o@400o`000?l0003o0000ol300?l0oooo=P3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0o`3oooli0?ooo`@0o`003P3oool3000000030820P03oool0oooo01l0
oooo0`0000000`20P800oooo0?ooo`090?ooo`040?n0P03o0000o`000?n0P<d0oooo0`3o000;0?oo
o`@000008@3oool01@20P8000000000000000000P82000h0oooo00@0oh200?l0003o0000o`00o`3o
oolh0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooocX0oooo00@0od10
0?l0003o0000od103@3oool01@30`<000000000000000000P82001h0oooo00D0`<30000000000000
00000820P00<0?ooo`040?n0P03o0000o`000?o0`<h0oooo0P3o00000`3o`<00oooo0?ooo`080?oo
o`050<30`0000000000000000010@4007`3oool01@30`<000000000000000000P82000d0oooo00<0
ol300?l0003o00000P3o00000`3o`<00oooo0?ooo`3o0?ooocH0oooo6oooool001Wooooo703oool2
000000030820P03oool0oooo0?l0oooo>`3oool40?l000h0oooo0`0000000`20P800oooo0?ooo`0K
0?ooo`<0000000<0P8200?ooo`3oool0k03oool3000000030820P03oool0oooo01`0oooo0`000000
0`20P800oooo0?ooo`0<0?ooo`@0o`00o`3ooolj0?oooa_ooooo000Ioooooa`0oooo0P0000000`20
P800oooo0?ooo`3o0?oooc`0oooo00@0od100?l0003o0000ol303@3oool01@30`<00000000000000
0000P82001X0oooo00D0`<3000000000000000000410@03_0?ooo`050<30`0000000000000000020
P8006`3oool01@30`<000000000000000000P82000d0oooo00D0ol300?l0003o0000o`000?m0@03o
0?oooc/0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo?@3oool00`3o
P800oooo0?ooo`0>0?ooo`050<30`0000000000000000010@400603oool01@30`<00000000000000
0000P8200?80oooo00@0@410000000000000@4106@3oool01@20P8000000000000000000`<3000d0
oooo00D0ol300?l0003o0000o`000?n0P03o0?oooc`0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0?l0ooooD03oool3000000030820P03oool0oooo01D0oooo0`0000000`20P800
oooo0?ooo`3b0?ooo`@000005`3oool01@20P8000000000000000000P82000l0oooo0P3o00000`3o
P800oooo0?ooo`3o0?oooc/0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0
ooooD03oool01@30`<000000000000000000P82001@0oooo00D0`<3000000000000000000820P03e
0?ooo`050<30`0000000000000000010@4005@3oool01@30`<000000000000000000P8200100oooo
00<0ol300?n0P03oool0o`3ooolm0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?oo
o`3o0?oooe80oooo0`0000000`20P800oooo0?ooo`0A0?ooo`<0000000<0P8200?ooo`3oool0mP3o
ool4000001@0oooo0`0000000`20P800oooo0?ooo`3o0?ooodl0oooo6oooool001Wooooo703oool2
000000030820P03oool0oooo0?l0ooooDP3oool01@30`<000000000000000000P8200100oooo00D0
`<3000000000000000000410@00>0?ooo`80od1000<0oh200?ooo`3oool0eP3oool0103oP800od10
0?l0003oP80<0?ooo`050<30`0000000000000000010@4004@3oool01@30`<000000000000000000
P8200?l0ooooDP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooom40?oo
o`030?m0@03o0000ol3000`0oooo00D0`<3000000000000000000410@00>0?ooo`050<30`0000000
000000000020P8003P3oool0103oP800o`000?l0003oP83I0?ooo`<0o`003P3oool01010@4000000
00000010@40?0?ooo`050820P0000000000000000030`<00o`3ooomC0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`3o0?oood<0oooo103o000>0?ooo`<0000000<0P8200?ooo`3o
ool02`3oool3000000030820P03oool0oooo00d0oooo0`3o003J0?ooo`040?n0P03o0000o`000?n0
P0h0oooo1000000=0?ooo`050820P0000000000000000020P800o`3ooomD0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3o0?oood@0oooo00@0od100?l0003o0000od103@3oool0
1@30`<000000000000000000P82000X0oooo00D0`<3000000000000000000820P00?0?ooo`040?n0
P03o0000o`000?n0P=X0oooo00@0ol300?l0003o0000oh203`3oool01010@400000000000010@40;
0?ooo`050<30`0000000000000000020P8003@3oool00`3o`<00o`000?m0@03o0?ooodD0oooo6ooo
ool001Wooooo103oool8000000030820P03oool0oooo00d0oooo0P0000000`20P800oooo0?ooo`3o
0?ooodD0oooo103o000>0?ooo`<0000000<0P8200?ooo`3oool01`3oool3000000030820P03oool0
oooo00h0oooo00<0oh200?l0003o0000g03oool20?l000030?n0P03oool0oooo00h0oooo1000000:
0?ooo`<0000000<0P8200?ooo`3oool0303oool30?l000030?n0P03oool0oooo0?l0oooo@P3ooolK
ooooo`006Oooool60?ooo`040820P000000000000410@180oooo0P0000000`20P800oooo0?ooo`3o
0?ooodH0oooo00D0od100?l0003o0000o`000?n0P00<0?ooo`050<30`0000000000000000020P800
1P3oool01@30`<000000000000000000@4100140oooo00<0oh200?l0003o0000g03oool00`3oP800
o`000?l0000@0?ooo`050<30`0000000000000000010@4001`3oool01@30`<000000000000000000
P82000d0oooo00D0ol300?l0003o0000o`000?m0@03o0?ooodD0oooo6oooool001Wooooo1`3oool2
000000030820P03oool0oooo0100oooo0P0000000`20P800oooo0?ooo`3o0?ooodL0oooo00D0oh20
0?l0003o0000o`000?m0@00<0?ooo`030<30`0000000@41000H0oooo00D0`<300000000000000000
0820P00B0?ooo`80o`0000<0od100?ooo`3oool0f`3oool20?l000030?n0P03oool0oooo00l0oooo
00@0@410000000000000@4101@3oool01@20P8000000000000000000`<3000d0oooo00D0ol300?l0
003o0000o`000?n0P03o0?ooodH0oooo6oooool001Wooooo1`3oool2000000030820P03oool0oooo
0100oooo0P0000000`20P800oooo0?ooo`3o0?ooodT0oooo103o000E0?ooo`80000000<0P8200?oo
o`3oool04@3oool20?l000030?n0P03oool0oooo0=/0oooo00<0oh200?l0003o00004P3oool20000
00030820P03oool0oooo00@0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<0o`0000<0oh200?oo
o`3oool0o`3ooom50?oooa_ooooo000Iooooo`L0oooo0P0000000`20P800oooo0?ooo`0@0?ooo`80
000000<0P8200?ooo`3oool0o`3ooom90?ooo`050?o0`03o0000o`000?l0003o@400503oool00`30
`<00P8200?ooo`0C0?ooo`80o`0000<0oh200?ooo`3oool0f`3oool00`3oP800o`000?l0000C0?oo
o`030820P03oool0oooo00D0oooo00<0`<300820P03oool0303oool01@3o`<00o`000?l0003o0000
oh200?l0ooooB03ooolKooooo`006Oooool70?ooo`80000000<0P8200?ooo`3oool0403oool20000
00030820P03oool0oooo0?l0ooooB`3oool30?l000030?n0P03oool0oooo02L0oooo0P3o00000`3o
P800oooo0?ooo`3K0?ooo`030?n0P03o0000o`0002X0oooo0`3o00000`3oP800oooo0?ooo`3o0?oo
odL0oooo6oooool001Wooooo1`3oool2000000030820P03oool0oooo0100oooo0P0000000`10@400
P8200820P00>0820P?l0oooo?@3oool00`3o`<00o`000?m0@00Y0?ooo`<0o`00gP3oool00`3oP800
o`000?l0000X0?ooo`050?o0`03o0000o`000?l0003o@400o`3ooom:0?oooa_ooooo000Iooooo`L0
oooo0P0000000`20P800oooo0?ooo`0@0?oooa<00000o`3ooomY0?ooo`<0o`0000<0ol300?ooo`3o
ool0f`3oool00`3oP800o`000?l0000W0?ooo`050?o0`03o0000o`000?l0003oP800o`3ooom;0?oo
oa_ooooo000Iooooo`L0oooo0P0000000`20P800oooo0?ooo`0@0?oooa<00000o`3ooomZ0?ooo`80
o`0000<0oh200?ooo`3oool0f`3oool30?l002P0oooo0P3o00000`3oP800oooo0?ooo`3o0?ooodX0
oooo6oooool001Wooooo1`3oool2000000030820P03oool0oooo0100oooo0P0000000`20P800oooo
0?ooo`3o0?ooool0ooooQ03oool00`3o`<00oh200?ooo`3o0?oood`0oooo6oooool001Wooooo1`3o
ool2000000030820P03oool0oooo0100oooo0P0000000`20P800oooo0?ooo`3o0?ooool0ooooo`3o
oooC0?oooa_ooooo000Iooooo`L0oooo0P0000000`20P800oooo0?ooo`0@0?ooo`80000000<0P820
0?ooo`3oool0o`3ooomC0?ooo`030?n0P03oool0oooo00`0oooo00<0`<300820P030`<00o`3oool<
0?ooo`030820P010@400P8200?l0ooooG`3ooolKooooo`006Oooool70?ooo`80000000<0P8200?oo
o`3oool0403oool2000000030820P03oool0oooo0?l0ooooDP3oool0103o@400o`000?l0003o`<0=
0?ooo`040820P000000000000820P?l0oooo203oool01020P800000000000010@43o0?ooof00oooo
6oooool001Wooooo1`3oool2000000030820P03oool0oooo0100oooo0P0000000`20P800oooo0?oo
o`3o0?oooe80oooo00@0oh200?l0003o0000o`003P3oool400000?l0oooo1@3oool00`20P8000000
00000002000000030820P03oool0oooo0?l0ooooGP3ooolKooooo`006Oooool70?ooo`80000000<0
P8200?ooo`3oool0403oool2000000030820P03oool0oooo0?l0ooooD`3oool01@3o@400o`000?l0
003o0000ol3000`0oooo00<0P8200000000000000P0000000`10@400P8200<30`03n0?ooo`030820
P0000000000000@000002P3oool00`3o`<00o`000?m0@03o0?oooe@0oooo6oooool001Wooooo1`3o
ool2000000030820P03oool0oooo0100oooo0P0000000`20P800oooo0?ooo`3o0?oooe@0oooo103o
000=0?ooo`L0000000<0P8200?ooo`3oool0nP3oool7000000/0oooo0`3o00000`3oP800oooo0?oo
o`3o0?oooe40oooo6oooool001Wooooo1`3oool2000000030820P03oool0oooo0100oooo0P000000
0`20P800oooo0?ooo`3o0?oooeD0oooo00@0od100?l0003o0000od10303oool00`20P80000000000
0006000000030410@020P800oooo00X0oooo00<0oh200?l0003o@400eP3oool00`3o`<00o`000?m0
@00>0?ooo`030<30`020P800000000L0000000<0@4100?ooo`3oool01`3oool01@3o`<00o`000?l0
003o0000od100?l0ooooE03ooolKooooo`006Oooool40?ooo`030<30`03oool0oooo0080000000<0
P8200?ooo`3oool0403oool2000000030820P03oool0oooo0?l0ooooEP3oool01@3oP800o`000?l0
003o0000ol3000/0oooo00<0@410000000000000200000000`30`<00oooo0?ooo`070?ooo`040?n0
P03o0000o`000?n0P=@0oooo00@0ol300?l0003o0000o`00303oool00`20P8000000000000090000
00030<30`03oool0oooo00H0oooo00D0ol300?l0003o0000o`000?n0P03o0?oooeD0oooo6oooool0
01Wooooo103oool00`20P800000000000002000000030820P03oool0oooo0100oooo0P0000000`20
P800oooo0?ooo`3o0?oooeL0oooo00@0oh200?l0003o0000o`002`3oool00`20P80000000000000:
000000T0oooo0`3o003D0?ooo`040?n0P03o0000o`000?n0P0/0oooo3@0000090?ooo`<0o`0000<0
oh200?ooo`3oool0o`3ooomD0?oooa_ooooo000Iooooo`D0oooo00D0`<300820P000000000000820
P00B0?ooo`80000000<0P8200?ooo`3oool0o`3ooomH0?ooo`050?m0@03o0000o`000?l0003o`<00
2P3oool=00000080P8201`3oool20?l000030?m0@03oool0oooo0=40oooo0`3o00090?ooo`030820
P010@400000000`0000000<0P8200?ooo`3oool01@3oool01@3o`<00o`000?l0003o0000oh200?l0
ooooE`3ooolKooooo`006Oooool90?ooo`030820P03oool0oooo0100oooo0P0000000`20P800oooo
0?ooo`3o0?oooeT0oooo103o000:0?ooo`030820P0000000000000d000001P3oool0103oP800o`00
0?l0003oP83A0?ooo`<0o`00203oool00`20P80000000000000>000000P0oooo0`3o00000`3oP800
oooo0?ooo`3o0?oooeH0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo
FP3oool00`3o@400o`000?o0`00:0?ooo`030<30`0000000000000h0000000<0@4100820P030`<00
0`3oool20?l000030?m0@03oool0oooo0<h0oooo00@0oh200?l0003o0000ol301P3oool00`20P800
00000000000?000000030820P03oool0oooo00@0oooo00D0ol300?l0003o0000o`000?m0@03o0?oo
oeT0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooJ03oool00`20P800
00000000000@000000040410@020P800oooo0?ooo`<0o`0000<0ol300?ooo`3oool0b`3oool0103o
P800o`000?l0003o@4040?ooo`030<30`010@40000000140000000<0@4100?ooo`3oool01@3oool0
103o@400o`000?l0003oP83o0?oooeX0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo0?l0ooooJ@3ooolE000000050?ooo`3oP800o`000?l0003oP800c@3oool30?l000<0oooo00<0
P8200000000000004`0000000`20P800oooo0?ooo`060?ooo`030?l0003oP800oooo0?l0ooooFP3o
oolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomY0?ooo`030820P0000000
00000140000000<0@4100?ooo`3oool0103o003;0?ooo`<0o`0000<0oh200?ooo`3oool00P3ooolE
00000?l0ooooIP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomY0?oo
o`030820P000000000000140000000@0P8200?ooo`3oool0oh200`3o00000`3oP800oooo0?ooo`37
0?ooo`040?n0P03o0000o`000?n0P0H0oooo4`00003o0?ooofL0oooo6oooool001Wooooo703oool2
000000030820P03oool0oooo0?l0ooooHP3oool00`3oP800oooo0?ooo`050?oooa<000001@3oool2
0?l000030?o0`03oool0oooo0<L0oooo00@0oh200?l0003o0000ol301P3oool00`10@40000000000
000?000000030410@03oool0oooo0?l0ooooI@3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooomQ0?ooo`040?m0@03o0000o`000?o0`0H0oooo4@00003L0?ooo`030<30`000
0000000000l0000000<0`<300?ooo`3oool0o`3ooomU0?oooa_ooooo000Ioooooa`0oooo0P000000
0`20P800oooo0?ooo`3o0?ooof40oooo00@0oh200?l0003o0000o`001P3oool00`20P80000000000
000=000000030820P03oool0oooo0=/0oooo4@0000040?ooo`030?l0003oool0oooo0?l0ooooH@3o
oolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomR0?ooo`050?m0@03o0000
o`000?l0003o`<00103oool00`30`<0000000000000=00000=h0oooo00<0P8200000000000003@00
00001020P800oooo0?ooo`3o`<020?l000030?m0@03oool0oooo0?l0ooooH03ooolKooooo`006Ooo
oolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomS0?ooo`@0o`001@3oool>000000030820P03o
ool0oooo0=d0oooo3`0000030?ooo`<0o`0000<0oh200?ooo`3oool0o`3ooomP0?oooa_ooooo000I
oooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooof@0oooo00@0od100?l0003o0000od10103o
ool00`20P80000000000000;00000>40oooo00<0@4100000000000002P0000000`20P800oooo0?o0
`0030?l000030?m0@03oool0oooo0?l0ooooH@3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooomU0?ooo`050?n0P03o0000o`000?l0003o`<000`3oool=000000030410@03o
ool0oooo00/0oooo00<0oh200?l0003o`<00_@3oool00`3oP800o`000?o0`00?0?ooo`030820P000
0000000000X0000000<0@4100?ooo`3o`<000`3o00000`3oP800oooo0?ooo`3o0?ooof80oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooIP3oool0103oP800o`000?l0003o
00040?ooo`T0000000D0oooo00000000000000000820P00;0?ooo`040?n0P03o0000o`000?n0P;`0
oooo00@0oh200?l0003o0000o`003P3oool00`20P80000000000000;000000030820P03oool0o`00
0080o`0000<0oh200?ooo`3oool0o`3ooomS0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`3o0?ooofL0oooo00D0od100?l0003o0000o`000?o0`0020?ooo`030410@00000000000
00@0000000@0@4100<30`03oool0`<300`0000000`20P800oooo0?ooo`090?ooo`040?n0P03o0000
o`000?n0P;/0oooo00@0od100?l0003o0000ol303@3oool01`30`<000000000000000000P8200?oo
o`30`<00200000001@3o`<00o`000?l0003o0000oh200?l0ooooIP3ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0o`3ooomX0?ooo`@0o`000P3oool00`20P8000000000000040000
00D0oooo0`0000000`20P800oooo0?ooo`090?ooo`040?n0P03o0000o`000?n0P;T0oooo0`3o0000
0`3oP800oooo0?ooo`0<0?ooo`<0000000<0P8200?ooo`3oool00P3oool6000000050?ooo`3o0000
o`000?l0003oP800o`3ooomW0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o
0?ooofT0oooo00<0od100?l0003o`<000`3oool4000000030410@03oool0oooo00@0oooo00D0`<30
00000000000000000820P00:0?ooo`040?o0`03o0000o`000?l00;P0oooo00@0od100?l0003o0000
oh203@3oool01@30`<000000000000000000P82000D0oooo00<0`<300000000000000P0000001@10
0000o`000?l0003o0000od100?l0ooooJ03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0o`3ooom`0?ooo`030410@030`<00oooo00P0oooo00D0`<3000000000000000000410@00:
0?ooo`050?o0`03o0000o`000?l0003o`<00]@3oool0103o@400o`000?l0003o@40=0?ooo`050820
P0000000000000000030`<002@3oool00`20P80000000<10@0020?l000030?n0P03oool0oooo0?l0
ooooI`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomm0?ooo`<00000
00<0P8200?ooo`3oool02@3oool30?l00;D0oooo0`3o000=0?ooo`050820P0000000000000000020
P8003@3oool00`3o0000oh200?ooo`3o0?ooofT0oooo6oooool001Wooooo703oool2000000030820
P03oool0oooo0?l0ooooO@3oool01@30`<000000000000000000P82000X0oooo00@0oh200?l0003o
0000ol30/P3oool0103o`<00o`000?l0003o@40=0?ooo`050<30`0000000000000000020P800o`3o
oomj0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooogl0oooo0`000000
0`20P800oooo0?ooo`080?ooo`<0o`00/P3oool30?l000h0oooo0`0000000`20P800oooo0?ooo`3o
0?ooogT0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooL03oool00`3o
`<00o`000?n0P00<0?ooo`050<30`0000000000000000020P8002P3oool0103o@400o`000?l0003o
`<2^0?ooo`050?o0`03o0000o`000?l0003o`<00303oool01@30`<000000000000000000P8200?l0
ooooO03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooom`0?ooo`040?m0
@03o0000o`000?m0@0`0oooo00D0`<3000000000000000000410@0090?ooo`030?o0`03o0000oh20
0;00oooo00<0oh200?l0003oP800303oool01@20P8000000000000000000`<300?l0ooooO@3ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oooma0?ooo`@0o`003@3oool30000
00030820P03oool0oooo0<L0oooo00D0P82000000000000000000820P00:0?ooo`030?n0P03o0000
oooo0?l0ooooL@3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oooma0?oo
o`050?o0`03o0000o`000?l0003o@400303oool01@30`<000000000000000000P8200<L0oooo00D0
`<3000000000000000000820P00:0?ooo`040?o0`03o0000o`000?m0@?l0ooooL@3ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomc0?ooo`<0o`003P3oool3000000030820
P03oool0oooo0<@0oooo0`0000000`20P800oooo0?ooo`090?ooo`<0o`0000<0oh200?ooo`3oool0
o`3ooom_0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooog<0oooo00@0
ol300?l0003o0000od103@3oool01@30`<000000000000000000P8200<<0oooo00D0`<3000000000
000000000820P00:0?ooo`050?o0`03o0000o`000?l0003oP800o`3ooomb0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooog@0oooo00D0oh200?l0003o0000o`000?o0`00<
0?ooo`050<30`0000000000000000010@400303oool00`3o`<00oh200?ooo`2R0?ooo`030?n0P03o
ool0oooo00d0oooo00D0P82000000000000000000<30`00;0?ooo`040?m0@03o0000o`000?o0`?l0
ooooL`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooome0?ooo`040?n0
P03o0000o`000?l000h0oooo0`0000000`20P800oooo0?ooo`090?ooo`80o`00XP3oool00`3oP800
o`000?l0000=0?ooo`050820P0000000000000000020P8002`3oool30?l000030?n0P03oool0oooo
0?l0ooooLP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomf0?ooo`05
0?m0@03o0000o`000?l0003o`<00303oool01@30`<000000000000000000P82000T0oooo00@0oh20
0?l0003o0000od10X03oool01@3oP800o`000?l0003o0000ol3000/0oooo00D0`<30000000000000
00000820P00;0?ooo`050?m0@03o0000o`000?l0003o`<00o`3ooomd0?oooa_ooooo000Ioooooa`0
oooo0P0000000`20P800oooo0?ooo`3o0?ooogL0oooo0`3o000?0?ooo`<0000000<0P8200?ooo`3o
ool01`3oool30?l000030?n0P03oool0oooo09`0oooo00@0oh200?l0003o0000o`003@3oool30000
00030820P03oool0oooo00T0oooo00@0oh200?l0003o0000o`00o`3ooomf0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooogP0oooo00<0oh200?ooo`3oool03P3oool01@30
`<000000000000000000P82000P0oooo00D0ol300?l0003o0000o`000?n0P02M0?ooo`040?m0@03o
0000o`000?o0`0/0oooo00D0`<3000000000000000000820P00;0?ooo`050?n0P03o0000o`000?l0
003o`<00o`3ooomf0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooohX0
oooo00D0`<3000000000000000000410@0090?ooo`040?m0@03o0000o`000?m0@9X0oooo00D0ol30
0?l0003o0000o`000?o0`00;0?ooo`050820P0000000000000000030`<002`3oool0103o`<00o`00
0?l0003o@43o0?ooogP0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo
S03oool3000000030820P03oool0oooo00L0oooo0`3o002J0?ooo`<0o`00303oool01@20P8000000
000000000000P82000h0oooo00<0o`000?ooo`3oool0o`3ooomg0?oooa_ooooo000Ioooooa`0oooo
0P0000000`20P800oooo0?ooo`3o0?oooh`0oooo00D0`<3000000000000000000820P0080?ooo`05
0?o0`03o0000o`000?l0003o`<00U`3oool0103o@400o`000?l0003oP80;0?ooo`050<30`0000000
000000000020P800o`3ooon90?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o
0?ooohh0oooo0`0000000`20P800oooo0?ooo`070?ooo`<0o`00U`3oool30?l000`0oooo0`000000
0`20P800oooo0?ooo`3o0?ooohP0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo
0?l0ooooO`3oool20?m0@0d0oooo00D0`<3000000000000000000820P0080?ooo`040?o0`03o0000
o`000?m0@9@0oooo00@0ol300?l0003o0000od102`3oool01@30`<000000000000000000P8200?l0
ooooR`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooomn0?ooo`050?n0
P03o0000o`000?l0003o`<00303oool01@30`<000000000000000000@41000T0oooo00<0od100?l0
003oP800T`3oool00`3oP800o`000?m0@00;0?ooo`050820P0000000000000000030`<002P3oool0
0`3oP800ol300?ooo`3o0?ooogl0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo
0?l0ooooO`3oool0103oP800o`000?l0003o000>0?ooo`<0000000<0P8200?ooo`3oool0Z@3oool0
1@20P8000000000000000000P82000X0oooo00<0oh200?l0003o0000o`3ooon00?oooa_ooooo000I
oooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?oooh00oooo00D0od100?l0003o0000o`000?o0
`00<0?ooo`050<30`0000000000000000020P800Z@3oool01@30`<000000000000000000P82000X0
oooo00D0ol300?l0003o0000o`000?n0P03o0?ooogl0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0?l0ooooP@3oool40?l000h0oooo0`0000000`20P800oooo0?ooo`2V0?ooo`<0
000000<0P8200?ooo`3oool02@3oool30?l000030?n0P03oool0oooo0?l0ooooOP3ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooon20?ooo`040?m0@03o0000o`000?m0@0d0
oooo00D0`<3000000000000000000820P02U0?ooo`050<30`0000000000000000020P8002P3oool0
1@3o`<00o`000?l0003o0000oh200?l0ooooP@3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooon30?ooo`050?n0P03o0000o`000?l0003o`<00303oool01@30`<0000000000
00000000@4100:<0oooo00D0P82000000000000000000<30`00:0?ooo`050?n0P03o0000o`000?l0
003o`<00o`3ooon20?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?oooh@0
oooo00@0oh200?l0003o0000o`003P3oool3000000030820P03oool0oooo00P0oooo00<0o`000?n0
P03oool0Q@3oool00`3oP800o`000?ooo`0<0?ooo`050820P0000000000000000020P8002P3oool0
1@3oP800o`000?l0003o0000oh200?l0ooooP`3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooon50?ooo`050?m0@03o0000o`000?l0003o`<00303oool01@30`<0000000000
00000000P82000P0oooo00@0od100?l0003o0000oh20Q03oool0103o`<00o`000?l0003o@40;0?oo
o`050<30`0000000000000000020P8002P3oool01@3o`<00o`000?l0003o0000oh200?l0ooooQ03o
oolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooon60?ooo`<0o`003`3oool3
000000030820P03oool0oooo00D0oooo00D0oh200?l0003o0000o`000?n0P0230?ooo`<0o`0000<0
oh200?ooo`3oool02@3oool3000000030820P03oool0oooo00T0oooo0`3o00000`3oP800oooo0?oo
o`3o0?oooh<0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooQ`3oool0
0`3oP800oooo0?ooo`0>0?ooo`050<30`0000000000000000020P8001`3oool01@3oP800o`000?l0
003o0000od100800oooo00D0ol300?l0003o0000o`000?n0P00:0?ooo`050<30`000000000000000
0020P8002P3oool01@3o`<00o`000?l0003o0000oh200?l0ooooQP3ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0o`3ooonI0?ooo`050<30`0000000000000000010@4001`3oool0
0`3o`<00oh200?l000020?l000030?o0`03oool0oooo07/0oooo00D0oh200?l0003o0000o`000?o0
`00:0?ooo`050820P0000000000000000030`<00303oool00`3oP800o`000?o0`03o0?ooohL0oooo
6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooV`3oool3000000030820P03o
ool0oooo00H0oooo00@0oh200?l0003o0000o`00O03oool01@3oP800o`000?l0003o0000oh2000X0
oooo00D0P82000000000000000000820P03o0?oooiL0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0?l0ooooV`3oool01@30`<000000000000000000P82000P0oooo00D0od100?l0
003o0000o`000?o0`01i0?ooo`050?o0`03o0000o`000?l0003oP8002P3oool01@30`<0000000000
00000000P8200?l0ooooV03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3o
oonM0?ooo`<0000000<0P8200?ooo`3oool01P3oool40?l007T0oooo0`3o00000`3oP800oooo0?oo
o`090?ooo`<0000000<0P8200?ooo`3oool0o`3ooonG0?oooa_ooooo000Ioooooa`0oooo0P000000
0`20P800oooo0?ooo`3o0?ooohd0oooo00<0oh200?m0@03o@4003@3oool01@30`<00000000000000
0000P82000P0oooo00@0od100?l0003o0000ol30MP3oool01@3o`<00o`000?l0003o0000oh2000X0
oooo00D0`<3000000000000000000820P03o0?oooiX0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0?l0ooooSP3oool0103o@400o`000?l0003o`<0<0?ooo`050<30`00000000000
00000010@400203oool00`3oP800o`000?m0@01f0?ooo`040?n0P03o0000od100?o0`0X0oooo00D0
P82000000000000000000<30`00:0?ooo`030?n0P03o`<00oooo0?l0ooooSP3ooolKooooo`006Ooo
oolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooon?0?ooo`<0o`003P3oool3000000030820P03o
ool0oooo08/0oooo00D0P82000000000000000000820P00:0?ooo`030?n0P03o0000o`000?l0oooo
S`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooon?0?ooo`050?o0`03o
0000o`000?l0003o`<00303oool01@30`<000000000000000000P82008/0oooo00D0`<3000000000
000000000820P00:0?ooo`050?o0`03o0000o`000?l0003oP800o`3ooon>0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3o0?oooi40oooo0`3o000>0?ooo`<0000000<0P8200?oo
o`3oool0R03oool3000000030820P03oool0oooo00T0oooo0`3o00000`3oP800oooo0?ooo`3o0?oo
ohd0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooT@3oool0103oP800
o`000?l0003o@40=0?ooo`050<30`0000000000000000020P800Q`3oool01@30`<00000000000000
0000P82000X0oooo00D0ol300?l0003o0000o`000?n0P03o0?oooi00oooo6oooool001Wooooo703o
ool2000000030820P03oool0oooo0?l0ooooTP3oool01@3oP800o`000?l0003o0000ol3000`0oooo
00D0`<3000000000000000000410@0240?ooo`030<30`020P80000000080000000<0`<300?ooo`3o
ool0203oool01@3oP800o`000?l0003o0000ol300?l0ooooT@3ooolKooooo`006OoooolL0?ooo`80
000000<0P8200?ooo`3oool0o`3ooonC0?ooo`040?n0P03o0000o`000?l000h0oooo0`0000000`20
P800oooo0?ooo`080?ooo`030?l0003oP800oooo06P0oooo0P3o000<0?ooo`@0000000<0P8200?oo
o`3oool0203oool01@3oP800o`000?l0003o0000oh200?l0ooooTP3ooolKooooo`006OoooolL0?oo
o`80000000<0P8200?ooo`3oool0o`3ooonD0?ooo`040?m0@03o0000o`000?n0P0d0oooo00D0`<30
00000000000000000820P0080?ooo`040?m0@03o0000o`000?n0P6L0oooo00@0od100?l0003o0000
o`002P3oool01@10@400000000000010@400P82000X0oooo00D0ol300?l0003o0000o`000?n0P03o
0?oooi<0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooU@3oool00`3o
0000oh200?ooo`0?0?ooo`<0000000<0P8200?ooo`3oool01@3oool01@3oP800o`000?l0003o0000
oh2006D0oooo00@0oh200?l0003o0000o`002P3oool4000000`0oooo0`3o00000`3oP800oooo0?oo
o`3o0?oooi80oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooY`3oool0
1@30`<000000000000000000P82000L0oooo00D0oh200?l0003o0000o`000?o0`01S0?ooo`050?n0
P03o0000o`000?l0003o`<002@3oool01010@400000000000010@40;0?ooo`050?o0`03o0000o`00
0?l0003oP800o`3ooonE0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?oo
ojP0oooo00D0`<3000000000000000000410@0070?ooo`050?o0`03o0000o`000?l0003oP800H@3o
ool0103o@400o`000?l0003o@4090?ooo`050<30`0000000000000000010@4003@3oool00`3oP800
o`000?o0`03o0?oooiH0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo
ZP3oool3000000030820P03oool0oooo00H0oooo0`3o00000`3oP800oooo0?ooo`1L0?ooo`030?n0
P03o0000o`000080o`002P3oool400000?l0ooooY`3ooolKooooo`006OoooolL0?ooo`80000000<0
P8200?ooo`3oool0o`3ooonZ0?ooo`050<30`0000000000000000020P8001`3oool01@3o`<00o`00
0?l0003o0000oh2005`0oooo00<0ol300?l0003o00000P3o00000`3o`<00oooo0?ooo`070?ooo`04
0410@000000000000410@?l0ooooZ03ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooonM0?ooo`030?l0003oool0oooo00`0oooo0`0000000`20P800oooo0?ooo`050?ooo`05
0?n0P03o0000o`000?l0003oP800F`3oool30?l000030?n0P03oool0oooo00P0oooo1000003o0?oo
ojT0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooV`3oool0103o`<00
o`000?l0003o@40=0?ooo`050<30`0000000000000000020P8001`3oool01@3oP800o`000?l0003o
0000ol3005P0oooo00D0ol300?l0003o0000o`000?n0P00:0?ooo`040410@000000000000410@?l0
ooooZP3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooonL0?ooo`050?n0
P03o0000o`000?l0003o`<00303oool01@30`<000000000000000000@41000L0oooo00<0ol300?l0
003o@400FP3oool00`3oP800o`000?o0`0090?ooo`050<30`0000000000000000010@400303oool0
0`3oP800oooo0?ooo`3o0?oooi`0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo
0?l0ooooW@3oool0103oP800o`000?l0003o000>0?ooo`<0000000<0P8200?ooo`3oool0K@3oool4
000000`0oooo0`3o003o0?oooid0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo
0?l0ooooWP3oool01@3o@400o`000?l0003o0000ol3000`0oooo00D0`<3000000000000000000820
P01]0?ooo`040410@000000000000410@0`0oooo00D0od100?l0003o0000o`000?o0`03o0?oooi`0
oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooW`3oool40?l000h0oooo
0`0000000`20P800oooo0?ooo`1Y0?ooo`@00000303oool0103oP800o`000?l0003o003o0?oooih0
oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooX03oool0103o@400o`00
0?l0003o@40=0?ooo`050<30`0000000000000000020P800J@3oool01010@400000000000010@40<
0?ooo`050?n0P03o0000o`000?l0003o`<00o`3ooonN0?oooa_ooooo000Ioooooa`0oooo0P000000
0`20P800oooo0?ooo`3o0?oooj40oooo00D0oh200?l0003o0000o`000?o0`00<0?ooo`050<30`000
0000000000000010@4002P3oool00`3o`<00oh200?ooo`1;0?ooo`030?n0P03o`<00oooo00/0oooo
00D0`<3000000000000000000410@00;0?ooo`050?n0P03o0000o`000?l0003o@400o`3ooonP0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?oooj80oooo00@0oh200?l0003o
0000o`003P3oool3000000030820P03oool0oooo00L0oooo0P3o00000`3oP800oooo0?ooo`180?oo
o`030?n0P03o0000o`0000`0oooo1000000;0?ooo`030?n0P03o0000o`000080o`00o`3ooonQ0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?oooj<0oooo00@0od100?l0003o
0000oh203@3oool01@30`<000000000000000000P82000L0oooo00D0ol300?l0003o0000o`000?n0
P0190?ooo`<0o`0000<0oh200?ooo`3oool0203oool01010@400000000000010@40;0?ooo`050?o0
`03o0000o`000?l0003oP800o`3ooonR0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo
0?ooo`3o0?oooj@0oooo00<0o`000?n0P03oool03`3oool3000000030820P03oool0oooo00D0oooo
00D0oh200?l0003o0000o`000?n0P0170?ooo`040?n0P03o0000o`000?n0P0X0oooo1000000<0?oo
o`<0o`0000<0oh200?ooo`3oool0o`3ooonQ0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800
oooo0?ooo`3o0?oookH0oooo00D0`<3000000000000000000820P0070?ooo`050?n0P03o@400o`00
0?l0003o`<00A@3oool0103oP800o`000?l0003oP80:0?ooo`040410@000000000000410@0`0oooo
00@0oh200?l0003o0000oh20o`3ooonT0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo
0?ooo`3o0?oookL0oooo00D0`<3000000000000000000410@0080?ooo`040?n0P03o0000o`000?n0
P4<0oooo00@0od100?l0003o0000ol302@3oool01@30`<000000000000000000@41000h0oooo0P3o
`<3o0?ooojD0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo^@3oool3
000000030820P03oool0oooo00H0oooo00@0oh200?l0003o0000oh20@@3oool30?l000030?n0P03o
ool0oooo00P0oooo1000003o0?oookH0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo0?l0oooo^@3oool01@30`<000000000000000000P82000P0oooo00@0od100?l0003o0000oh20
?`3oool0103o@400o`000?l0003oP80:0?ooo`040410@000000000000410@?l0oooo]`3ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030?l0003oool0oooo00`0
oooo0`0000000`20P800oooo0?ooo`060?ooo`<0o`0000<0oh200?ooo`3oool0>`3oool30?l00003
0?n0P03oool0oooo00P0oooo1000003o0?oookP0oooo6oooool001Wooooo703oool2000000030820
P03oool0oooo0?l0ooooZP3oool0103o`<00o`000?l0003o@40=0?ooo`050<30`000000000000000
0020P800203oool30?l000030?o0`03oool0oooo03P0oooo00D0ol300?l0003o0000o`000?n0P00:
0?ooo`040410@000000000000410@?l0oooo^@3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooon[0?ooo`050?n0P03o0000o`000?l0003o`<00303oool01@30`<0000000000
00000000@41000L0oooo00<0ol300?l0003o@400?03oool00`3oP800o`000?o0`0090?ooo`050<30
`0000000000000000010@4002`3oool00`3oP800o`000?n0P03o0?oooj`0oooo6oooool001Wooooo
703oool2000000030820P03oool0oooo0?l0oooo[03oool0103oP800o`000?l0003o000>0?ooo`<0
000000<0P8200?ooo`3oool0C`3oool4000000/0oooo00D0oh200?l0003o0000o`000?n0P03o0?oo
oj/0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo[@3oool01@3o@400
o`000?l0003o0000od1000`0oooo00D0`<3000000000000000000820P01?0?ooo`040410@0000000
00000410@0/0oooo00D0ol300?l0003o0000o`000?n0P03o0?ooohh0oooo0P20P80L0?oooa_ooooo
000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooojh0oooo103o00000`3oP800oooo0?oo
o`0;0?ooo`<0000000<0P8200?ooo`3oool0B`3oool4000000`0oooo0`3o00000`3oP800oooo0?oo
o`3o0?ooohd0oooo00<0P82000000020P8006`3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3ooon_0?ooo`050?o0`03o0000o`000?l0003oP800303oool01@30`<0000000000
00000000P82004/0oooo00@0@410000000000000@4102`3oool01@3o`<00o`000?l0003o0000oh20
0?l0ooooT@3oool2000000030820P03oool0oooo01P0oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo0?l0oooo/@3oool0103o@400o`000?l0003o@40<0?ooo`050<30`00000000000
00000010@4002P3oool00`3o`<00oh200?ooo`0^0?ooo`030?n0P03oool0oooo00X0oooo00D0`<30
00000000000000000410@00;0?ooo`050?n0P03o0000o`000?l0003o`<00o`3ooonC0?ooo`800000
00<0`<300?ooo`3oool05`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3o
oonb0?ooo`@0o`003@3oool3000000030820P03oool0oooo00L0oooo0P3o00000`3oP800oooo0?oo
o`0[0?ooo`<0o`002`3oool4000000/0oooo00D0oh200?l0003o0000o`000?n0P03o0?oooi@0oooo
0P0000000`20P800oooo0?ooo`0G0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?oo
o`3o0?oook80oooo00<0ol300?l0003o@4003P3oool01@30`<000000000000000000P82000L0oooo
00D0ol300?l0003o0000o`000?n0P00[0?ooo`050?m0@03o0000o`000?l0003o`<002@3oool01010
@400000000000010@40;0?ooo`050?o0`03o0000o`000?l0003oP800o`3ooonE0?ooo`030410@000
0000@41001T0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooa@3oool3
000000030820P03oool0oooo00D0oooo00D0oh200?l0003o0000o`000?n0P00Y0?ooo`040?n0P03o
0000o`000?l000X0oooo1000000<0?ooo`<0o`0000<0oh200?ooo`3oool0o`3ooonD0?ooo`030820
P0000000000001T0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0ooooa@3o
ool01@30`<000000000000000000P82000L0oooo00D0oh200?l0003o0000o`000?o0`00V0?ooo`03
0?o0`03o0000o`000080o`0000<0ol300?ooo`3oool01`3oool01010@400000000000010@40<0?oo
o`040?n0P03o0000o`000?n0P?l0ooooU`3oool00`20P80000000000000I0?oooa_ooooo000Ioooo
oa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooolH0oooo00D0`<3000000000000000000410@007
0?ooo`050?o0`03o0000o`000?l0003oP800903oool01@3oP800o`000?l0003o0000oh2000T0oooo
00D0`<3000000000000000000410@00>0?ooo`80ol30o`3ooonI0?ooo`80000000<0P8200?ooo`3o
ool05P3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oooo80?ooo`<00000
00<0P8200?ooo`3oool01P3oool30?l000030?n0P03oool0oooo0200oooo00D0oh200?l0003o0000
o`000?n0P00:0?ooo`@00000o`3ooonZ0?ooo`80000000<0P8200?ooo`3oool05P3ooolKooooo`00
6OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3ooonj0?ooo`030?n0P03o`<00oooo00/0oooo
00D0`<3000000000000000000820P0070?ooo`060?o0`03o0000o`000?l0003oP800ol307`3oool0
1@3o`<00o`000?l0003o0000oh2000X0oooo00@0@410000000000000@410o`3ooon[0?ooo`030820
P0000000000001P0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo^@3o
ool00`3oP800o`000?l0000>0?ooo`<0000000<0P8200?ooo`3oool01@3oool00`3oP800o`000?l0
00020?l001l0oooo0`3o00000`3oP800oooo0?ooo`080?ooo`@00000o`3ooon]0?ooo`800000603o
oolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0o`3oooni0?ooo`040?m0@03o0000
o`000?m0@0d0oooo00D0`<3000000000000000000820P0070?ooo`050?n0P03o@400o`000?l0003o
P8007@3oool0103oP800o`000?l0003oP80:0?ooo`040410@000000000000410@?l0oooo[P3oool0
0`10@40000000820P00G0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?oo
okX0oooo00D0oh200?l0003o0000o`000?o0`00<0?ooo`050<30`0000000000000000010@400203o
ool00`3oP800ol300?ooo`0N0?ooo`80ol302@3oool01@30`<000000000000000000@41000/0oooo
00<0oh200?l0003oP800o`3ooonQ0?ooo`030820P0000000000001L0oooo6oooool001Wooooo703o
ool2000000030820P03oool0oooo0?l0oooo^`3oool0103oP800o`000?l0003o000>0?ooo`<00000
00<0P8200?ooo`3oool0<@3oool4000000/0oooo00D0oh200?l0003o0000o`000?n0P03o0?oooj00
oooo00<0P8200000000000005`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0
o`3ooonl0?ooo`050?m0@03o0000o`000?l0003o`<00303oool01@30`<000000000000000000P820
0340oooo00@0@410000000000000@4102`3oool01@3o`<00o`000?l0003o0000oh200?l0ooooXP3o
ool2000000030820P03oool0oooo01@0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo0?l0oooo_@3oool40?l000h0oooo0`0000000`20P800oooo0?ooo`0]0?ooo`@00000303oool3
0?l000030?n0P03oool0oooo0?l0ooooX@3oool2000000030820P03oool0oooo01@0oooo6oooool0
01Wooooo703oool2000000030820P03oool0oooo0?l0oooo_P3oool0103o@400o`000?l0003o@40=
0?ooo`050<30`0000000000000000020P800;@3oool01010@400000000000010@40;0?ooo`050?o0
`03o0000o`000?l0003oP800o`3ooonT0?ooo`030820P0000000000001H0oooo6oooool001Wooooo
703oool2000000030820P03oool0oooo0?l0oooo_`3oool01@3oP800o`000?l0003o0000ol3000`0
oooo00D0`<3000000000000000000410@0090?ooo`030?o0`03o0000od100100oooo00<0oh200?l0
003oP8002`3oool01@30`<000000000000000000@41000/0oooo00D0oh200?l0003o0000o`000?o0
`03o0?ooojD0oooo00<0P8200000000000005P3ooolKooooo`006OoooolL0?ooo`80000000<0P820
0?ooo`3oool0o`3oooo00?ooo`040?n0P03o0000o`000?l000h0oooo0`0000000`20P800oooo0?oo
o`060?ooo`<0o`0000<0oh200?ooo`3oool0303oool01@3oP800o`000?l0003o0000oh2000X0oooo
1000000;0?ooo`050?n0P03o0000o`000?l0003oP800o`3ooonV0?ooo`040820P000000000000000
01D0oooo6oooool001Wooooo703oool2000000030820P03oool0oooo0?l0oooo`@3oool00`3o@400
o`000?o0`00>0?ooo`050<30`0000000000000000020P8001`3oool01@3o`<00o`000?l0003o0000
oh2000`0oooo00D0ol300?l0003o0000o`000?n0P00:0?ooo`040410@000000000000410@0/0oooo
00D0ol300?l0003o0000o`000?n0P03o0?ooojH0oooo0`20P802000001D0oooo6oooool001Wooooo
703oool2000000030820P03oool0oooo0?l0ooooe03oool3000000030820P03oool0oooo00H0oooo
0`3o00000`3oP800oooo0?ooo`090?ooo`<0o`0000<0oh200?ooo`3oool0203oool4000000`0oooo
0`3o00000`3oP800oooo0?ooo`3o0?oookl0oooo6oooool001Wooooo703oool2000000030820P03o
ool0oooo0?l0ooooe03oool01@30`<000000000000000000P82000L0oooo00D0ol300?l0003o0000
o`000?n0P0080?ooo`050?o0`03o0000o`000?l0003oP8002P3oool01010@400000000000010@40=
0?ooo`030?o0`03o0000oh200?l0oooo`P3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0o`3ooooE0?ooo`050<30`0000000000000000010@4001`3oool01@3o`<00o`000?l0003o
0000od1000L0oooo0`3o00000`3o`<00oooo0?ooo`070?ooo`050<30`0000000000000000010@400
o`3ooooC0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`3o0?ooomL0oooo1000
00080?ooo`<0o`0000<0oh200?ooo`3oool00`3oool30?l000030?n0P03oool0oooo00P0oooo1000
003o0?oookd0oooo0P00000E0?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`1:
0?ooo`80P82000<0`<300?ooo`3oool0o`3oool>0?ooo`030<30`020P800P82006T0oooo00<0oh20
0?o0`03oool02`3oool01@30`<000000000000000000@41000L0oooo00H0ol300?l0003o0000o`00
0?n0P03oool20820P0040<10@03o0000o`000?l000X0oooo00@0@410000000000000@410o`3ooonm
0?ooo`<0000000<0P8200?ooo`3oool04P3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?oo
o`3oool0BP3oool2000000030820P03oool0oooo0?l0oooo3P3oool00`20P80000000000001X0?oo
o`030?n0P03o0000o`0000h0oooo0`0000000`20P800oooo0?ooo`060?ooo`<0o`0000@0oh200000
00000000P0000P3o000:0?ooo`@00000o`3ooonn0?ooo`<0000000<0P8200?ooo`3oool04P3ooolK
ooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0BP3oool2000000030820P03oool0oooo
08@0oooo00<0P820000000000000QP3oool00`20P80000000000001X0?ooo`040?m0@03o0000o`00
0?m0@0d0oooo00D0`<3000000000000000000820P0070?ooo`040?o0`03o0000oh200?ooo`800000
00<0P0000?l0003o`<002@3oool01010@400000000000010@40;0?ooo`030?o0`03oP800oooo0?40
oooo0P0000000`20P800oooo0?ooo`2k0?ooo`80P8205@3ooolKooooo`006OoooolL0?ooo`800000
00<0P8200?ooo`3oool0BP3oool2000000030820P03oool0oooo08@0oooo00<0P820000000000000
QP3oool00`20P80000000000001Y0?ooo`050?n0P03o0000o`000?l0003o`<003@3oool01010@400
000000000010@40:0?ooo`80000000<0P8200?ooo`3oool01`3oool01@30`<000000000000000000
@41000/0oooo00@0oh200?l0003o0000od10J03oool00`30`<00P8200820P0260?ooo`80000000<0
P8200?ooo`3oool0Q03oool3000004/0oooo6oooool001Wooooo703oool2000000030820P03oool0
oooo04X0oooo0P0000000`20P800oooo0?ooo`240?ooo`030820P0000000000008H0oooo00<0P820
000000000000JP3oool0103oP800o`000?l0003o000>0?ooo`@000002@3oool2000000030820P03o
ool0oooo00L0oooo1000000;0?ooo`050?n0P03o0000o`000?l0003oP800J03oool00`20P8000000
000000260?ooo`80000000<0P8200?ooo`3oool0Q03oool3000004/0oooo6oooool001Wooooo703o
ool2000000030820P03oool0oooo04X0oooo0P0000000`20P800oooo0?ooo`240?ooo`030820P000
0000000008H0oooo00<0P820000000000000J`3oool01@3o@400o`000?l0003o0000ol3000`0oooo
00D0`<3000000000000000000410@0080?ooo`80000000<0P8200?ooo`3oool01P3oool01010@400
000000000010@40;0?ooo`050?o0`03o0000o`000?l0003oP800J@3oool00`20P800000000000026
0?ooo`80000000<0P8200?ooo`3oool0Q03oool3000004/0oooo6oooool001Wooooo703oool20000
00030820P03oool0oooo04X0oooo0P0000000`20P800oooo0?ooo`240?ooo`030820P00000000000
08H0oooo00<0P820000000000000K@3oool30?l000h0oooo0`0000000`20P800oooo0?ooo`050?oo
o`80000000<0P8200?ooo`3oool01@3oool4000000`0oooo0`3o00000`3oP800oooo0?ooo`1X0?oo
o`030820P0000000000008H0oooo0P0000000`20P800oooo0?ooo`240?ooo`<00000B`3ooolKoooo
o`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0BP3oool2000000030820P03oool0oooo08@0
oooo00<0P820000000000000QP3oool00`20P80000000000001]0?ooo`040?o0`03o0000o`000?m0
@0d0oooo00D0`<3000000000000000000820P0060?ooo`80000000<0P8200?ooo`3oool0103oool0
1010@400000000000010@40;0?ooo`050?o0`03o0000o`000?l0003oP800J`3oool00`20P8000000
000000260?ooo`80000000<0P8200?ooo`3oool0Q03oool3000004/0oooo6oooool001Wooooo703o
ool2000000030820P03oool0oooo03<0oooo00<0`<300820P03oool0503oool2000000030820P03o
ool0oooo08@0oooo00<0P820000000000000QP3oool00`20P80000000000001_0?ooo`040?m0@03o
0000o`000?o0`0d0oooo00@0@410000000000000@4101@3oool2000000030820P03oool0oooo0080
oooo00D0`<3000000000000000000410@00;0?ooo`050?n0P03o0000o`000?l0003o`<00K03oool0
0`20P8000000000000260?ooo`80000000<0P8200?ooo`3oool0Q03oool3000002d0oooo00<0`<30
0820P03oool06`3ooolKooooo`006OoooolL0?ooo`80000000<0P8200?ooo`3oool0<@3oool01@20
P8000000000000000000P82001@0oooo0P0000000`20P800oooo0?ooo`240?ooo`030820P0000000
000008H0oooo00<0P820000000000000L03oool30?l000h0oooo100000040?ooo`80000000<0P820
0?ooo`3oool00P3oool4000000/0oooo00D0oh200?l0003o0000o`000?n0P01]0?ooo`030820P000
0000000008H0oooo0P0000000`20P800oooo0?ooo`240?ooo`<00000;@3oool3000001/0oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo02d0oooo0`20P805000000030820P03oool0
oooo0180oooo0P0000000`20P800oooo0?ooo`240?ooo`030820P0000000000008H0oooo00<0P820
000000000000L03oool00`3o`<00oh200?o0`00>0?ooo`050<30`0000000000000000010@4000`3o
ool2000000050820P03oool0oooo0?ooo`10@4000P0000000`10@400oooo0?ooo`090?ooo`050?o0
`03o0000o`000?l0003oP800KP3oool01030`<00000000000030`<250?ooo`80000000<0P8200?oo
o`3oool0Q03oool3000002`0oooo00<0`<300000000000000`0000000`10@400P8200<30`00F0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`0/0?ooo`X00000503oool200000003
0820P03oool0oooo08@0oooo00<0P820000000000000QP3oool00`20P8000000000000230?ooo`<0
000000<0P8200?ooo`3oool00P0000000`20P800oooo0?ooo`04000000`0oooo0`3o00000`3oP800
oooo0?ooo`1^0?ooo`80000000<0P8200?ooo`3oool0P`3oool2000000030820P03oool0oooo08@0
oooo0`00000/0?ooo`030820P0000000000000L000005@3ooolKooooo`006OoooolL0?ooo`800000
00<0P8200?ooo`3oool0:@3oool20820P0/00000503oool2000000030820P03oool0oooo08@0oooo
00<0P820000000000000QP3oool00`20P8000000000000230?ooo`060<30`0000000000000000020
P800oooo0P0000000`20P800oooo0410@002000000030410@03oool0oooo00/0oooo00<0ol300?l0
003oP800L@3oool2000000030820P03oool0oooo08<0oooo0P0000000`20P800oooo0?ooo`240?oo
o`<00000;03oool;000000030410@020P800oooo0140oooo6oooool001Wooooo703oool200000003
0820P03oool0oooo02@0oooo0P20P80@000000030<30`03oool0oooo0140oooo0P0000000`20P800
oooo0?ooo`240?ooo`030820P0000000000008H0oooo00<0P820000000000000Q@3oool20410@080
oooo0P0000001@20P800oooo0<30`0000000@4100880oooo0P0000000`20P800oooo0?ooo`230?oo
o`80000000<0P8200?ooo`3oool0Q03oool3000002`0oooo3`0000000`10@400P8200820P00=0?oo
oa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`0R0?ooo`030820P000000000000140
000000<0P8200?ooo`3oool04@3oool2000000030820P03oool0oooo08@0oooo00<0P82000000000
0000QP3oool00`20P8000000000000290?ooo`80000000<0P8200?ooo`3oool0Q03oool200000003
0820P03oool0oooo08<0oooo0P0000000`20P800oooo0?ooo`240?ooo`<00000:`3ooolE000000/0
oooo6oooool001Wooooo703oool2000000030820P03oool0oooo01l0oooo00<0P8200410@0000000
500000000`20P800oooo0?ooo`0A0?ooo`80000000<0P8200?ooo`3oool0Q03oool00`20P8000000
000000260?ooo`030820P0000000000008T0oooo0P0000000`20P800oooo0?ooo`240?ooo`800000
00<0P8200?ooo`3oool0P`3oool2000000030820P03oool0oooo08@0oooo0`00000[0?oooaH00000
0P20P8080?oooa_ooooo000Ioooooa`0oooo0P0000000`20P800oooo0?ooo`0M0?oooaT0000000<0
P8200?ooo`3oool04@3oool2000000030820P03oool0oooo08@0oooo00<0P820000000000000QP3o
ool00`20P8000000000000290?ooo`80000000<0P8200?ooo`3oool0Q03oool2000000030820P03o
ool0oooo08<0oooo0P0000000`20P800oooo0?ooo`240?ooo`<00000:`3ooolJ000000H0oooo6ooo
ool001Wooooo703oool2000000030820P03oool0oooo01X0oooo00<0P8200000000000006@000000
0`10@400P8200820P02J0820P0030410@000000000000?l0P8204`20P802000000030410@020P800
P82008@0P8200P0000000`10@400P8200820P0230820P080000000<0@4100820P020P800Q020P803
000002/0P8206`0000000`10@400P8200?ooo`020?oooa_ooooo000IooooocP0oooo00<0P8200410
@0000000o`00003o00000?l00000]`0000000`20P800`<30ooooo`0Jooooo`006Ooooolj0?ooool0
0000o`00003o00000;L0000000<0P8200?ooo`3oool06oooool001Wooooo?03oool20820P1T00000
00<0P8200?ooo`3oool0o`3ooooo0?ooool0ooooNP3oool00`20P80000000000000G000000030820
P030`<00oooo00<0oooo6oooool001Wooooo@03ooolG000000030820P03oool0oooo0?l0ooooo`3o
oooo0?ooog/0oooo5`0000080?oooa_ooooo000Ioooood40oooo00<0`<300820P010@4004`000000
0`20P800oooo0?ooo`3o0?ooool0ooooo`3ooomk0?oooa<000000P20P80:0?oooa_ooooo000Ioooo
odD0oooo00<0`<300820P00000003`0000000`20P800oooo0?ooo`3o0?ooool0ooooo`3ooomk0?oo
oa00000000<0P8200?ooo`3oool0303ooolKooooo`006Ooooom80?ooo`030820P0000000000000`0
0000o`3ooooo0?ooool0ooooOP3oool>00000140oooo6oooool001WoooooBP3oool00`30`<00P820
0410@00:00000?l0ooooo`3ooooo0?ooogh0oooo2P0000000`10@400P8200?ooo`0B0?oooa_ooooo
000Iooooodh0oooo2@00000@0?ooo`H00000o`3ooooo0?ooool0oooo=03oool00`20P80000000000
0003000002h0oooo00<0P8200000000000001@0000000`20P800oooo0?ooo`0D0?oooa_ooooo000I
oooooe00oooo0P20P804000000030820P03oool0oooo00d0oooo100000040820P00300000020P800
oooo07h0oooo3020P8000`30`<00oooo0?ooo`3o0?oooi80oooo00<0`<300820P020P8001P20P800
0`30`<00oooo0?ooo`3o0?ooo`<0oooo100000040820P00300000020P800oooo02X0oooo00<0`<30
0000000000000P0000000`20P800`<300?ooo`0G0?oooa_ooooo000Ioooooe@0oooo0P20P80@0?oo
o`80P82000<0`<300?ooo`3oool0103oool20410@7h0oooo00<0`<300000000000002P00003o0?oo
o`d0oooo1020P8260?ooo`040820P000000000000820P7d0oooo00<0`<300820P020P8002P20P81m
0?ooo`80P82000<0`<300?ooo`3oool0103oool00`10@40000000<30`00Z0?ooo`80P820703ooolK
ooooo`006Ooooom`0?ooo`800000O`3oool;000007h0oooo00<0P8200000000000001P0000230?oo
o`030820P0000000P8200080oooo00<0P82000000020P800Q@3oool2000007l0oooo3@0000260?oo
o`800000B03ooolKooooo`006Ooooom`0?ooo`030820P0000000P82007h0oooo00<0`<300820P03o
ool01`3oool00`30`<0000000?ooo`1o0?ooo`040410@000000000000820P8@0oooo00<0`<300000
0020P8001@3oool00`10@400P8200?ooo`230?ooo`800000P03oool00`10@4000000000000090000
08L0oooo0P0000170?oooa_ooooo000Iooooog00oooo00<0P820000000000000P03oool00`20P800
oooo0?ooo`070?ooo`030820P03oool0oooo07d0oooo00<0P820000000000000Q@3oool00`000000
P8200?ooo`050?ooo`030820P0000000P82008<0oooo0P0000210?ooo`030820P03oool0oooo00L0
oooo00<000000820P03oool0Q@3oool2000000030820P03oool0oooo04@0oooo6oooool001Wooooo
G03oool00`30`<00P8200820P0050820P0`0oooo00<0P820000000000000P03oool20<30`8P0oooo
00<0P820000000000000Q03oool00`20P80000000<30`0070?ooo`0300000010@400oooo0880oooo
0P0000210?ooo`030<30`020P800oooo00P0oooo00<0P8200?ooo`3oool0Q03oool2000000030820
P03oool0oooo04@0oooo6oooool001WoooooG03oool00`20P800000000000005000000`0oooo0`00
001b0?ooo`L0P82000<0`<300?ooo`3oool01@3oool00`30`<00P8200?ooo`260?ooo`030820P000
0000000008<0oooo00<0`<30000000000000203oool2000000030<30`03oool0oooo0800oooo0P00
00230?ooo`030820P03oool0oooo08`0oooo0`0000000`20P800oooo0?ooo`140?oooa_ooooo000I
ooooofl0oooo00@0P820000000000000P820LP3oool7000000030820P03oool0oooo00L0oooo00<0
P8200?ooo`3oool0Q03oool00`20P8000000000000230?ooo`030820P0000000P82000T0oooo00<0
00000820P03oool0P@3oool2000008@0oooo00<000000?ooo`3oool0RP3oool01020P80000000000
000000170?oooa_ooooo000Iooooofd0oooo0P20P803000000030<30`03oool0oooo0700oooo1`20
P8000`30`<00oooo0?ooo`070?ooo`80P820M@3oool00`30`<00P8200820P0050820P0P0oooo00<0
P820000000000000P`3oool00`10@40000000820P0090?ooo`0300000020P800oooo0840oooo0P00
00250?ooo`030820P03oool0oooo08L0oooo0P20P803000000030820P03oool0oooo04D0oooo6ooo
ool001WoooooJ@3oool8000008H0oooo00<000000820P03oool0L`3oool00`20P800000000000005
000000P0oooo00<0P820000000000000P`3oool2000000030820P03oool0oooo00L0oooo0P000022
0?ooo`800000QP3oool00`000000oooo0?ooo`220?ooo`P0000000<0P8200?ooo`3oool0AP3ooolK
ooooo`006Ooooom[0?ooo`050820P0000000000000000020P800R03oool00`000000`<300?ooo`1b
0?ooo`030<30`020P800P82000D0P820203oool00`20P8000000000000230?ooo`80000000<0P820
0?ooo`3oool01`3oool200000880oooo0P0000260?ooo`030820P010@400oooo08@0oooo00D0P820
0410@000000000000820P01:0?oooa_ooooo000Iooooofd0oooo00@0`<3000000010@400`<30Q`3o
ool00`20P80000000?ooo`220?ooo`030820P0000000000008<0oooo0P0000000`20P800oooo0?oo
o`070?ooo`800000PP3oool2000008L0oooo00<0P8200410@03oool0Q@3oool01030`<0000000410
@020P8190?oooa_ooooo000Iooooofl0oooo00<000000820P03oool0Q`3oool200000880oooo00<0
P820000000000000P`3oool2000000030820P03oool0oooo00L0oooo0P0000220?ooo`800000R03o
ool2000008L0oooo0P0000190?oooa_ooooo000Iooooofl0oooo00<0P82000000020P800Q`3oool2
000000030<30`03oool0oooo07l0oooo00<0P820000000000000P`3oool2000000030820P03oool0
oooo00L0oooo0P0000220?ooo`800000R03oool00`10@40000000<30`0260?ooo`030820P0000000
@41004P0oooo6oooool001WoooooK`3oool00`20P8000000000000270?ooo`80000000<0P8200?oo
o`3oool0O`3oool00`20P8000000000000230?ooo`80000000<0P8200?ooo`3oool01`3oool20000
0880oooo0P0000280?ooo`030820P0000000P82008H0oooo00<0P820000000000000B03ooolKoooo
o`006OoooomV0?ooo`030820P03oool0oooo00H0oooo00<0P820000000000000O@3oool00`10@400
oooo0?ooo`070?ooo`80000000<0P8200?ooo`3oool0O`3oool00`20P8000000000000230?ooo`03
0410@0000000P82000T0oooo00<000000410@03oool0P@3oool2000008P0oooo00<0P82000000000
0000O@3oool00`20P800`<300?ooo`060?ooo`030820P0000000000004P0oooo6oooool001Wooooo
IP3oool00`30`<0000000<30`0050?ooo`040820P000000000000820P7d0oooo00<0P8200000003o
ool01P3oool01020P800000000000020P8210?ooo`030820P0000000000008<0oooo00<0P8200000
00000000203oool2000000030820P03oool0oooo0800oooo0P00001n0?ooo`80P820203oool00`20
P80000000000001n0?ooo`030410@030`<00oooo00@0oooo00@0P820000000000000@410B03ooolK
ooooo`006OoooomW0?ooo`<000000`3oool4000007l0oooo00<000000820P03oool01@3oool30000
0880oooo00<0P820000000000000Q03oool2000000P0oooo0P0000230?ooo`800000O`3oool00`00
0000P8200?ooo`060?ooo`<00000OP3oool00`20P8000000000000030?ooo`@0000000<0P8200?oo
o`3oool0AP3ooolKooooo`006OoooomX0?ooo`030<30`0000000000000D0000000<0`<300?ooo`3o
ool0O@3oool00`20P8000000000000030820P0050410@0000000000000000020P800PP3oool00`20
P8000000000000240?ooo`030820P0000000`<3000H0oooo00<0`<3000000010@400O`3oool01030
`<00P8200820P020P802000007l0oooo00<0P8200410@03oool01@3oool01030`<00000000000010
@41o0?ooo`030<30`0000000000000D0000000<0P8200?ooo`3oool0A`3ooolKooooo`006OoooomZ
0?ooo`030820P0000000000000800000PP3oool00`20P800000000000005000000030820P03oool0
oooo0840oooo00<0P820000000000000Q@3oool00`000000P8200?ooo`050?ooo`030820P0000000
P8200840oooo00@0P8200000000000000000P03oool2000000@0oooo100000000`20P800oooo0?oo
o`1o0?ooo`030820P0000000000000800000B`3ooolKooooo`006Oooooob0?ooo`80P82010000000
0`20P800oooo0?ooo`1o0?ooo`040<30`020P800P8200410@0800000Q@3oool00`30`<0000000820
P0040?ooo`030820P0000000P82008@0oooo00<0P8200410@03oool0O`3oool00`30`<0000000000
0006000000030820P03oool0oooo0=00oooo6oooool001Woooooo`3ooomm0?ooo`040<30`010@400
0000000008H0oooo00<0`<300820P010@4000P20P8000`10@400P8200<30`03o0?ooo`T0oooo00<0
`<300820P010@4000`0000000`10@400`<300?ooo`3B0?oooa_ooooo000Iooooool0ooooP03oool0
0`20P800oooo0?ooo`3o0?ooool0ooooL@3ooolKooooo`006Ooooooo0?ooool0ooooo`3ooood0?oo
oa_ooooo000Iooooool0ooooo`3ooooo0?oooo@0oooo6oooool001Woooooo`3ooooo0?ooool0oooo
m03ooolKooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooooolY
ooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00
oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooo
oooooooooooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooo
oooooooooolYooooo`00oooooooooooooooooooooooooolYooooo`00oooooooooooooooooooooooo
oolYooooo`00oooooooooooooooooooooooooolYooooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{353.75, 173.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 8.2 Decision tree for the first three steps of a random walk, \
starting at ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  ". Dahsed lines:possible paths for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)]],
  " steps."
}], "Caption",
  CellTags->"Fig. 8.2"],

Cell[TextData[{
  "\tWe are now prepared to consider an arbitrary number of steps. In order \
to get to grid point ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps, a particle must move ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " steps to the right and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_L\)]],
  " steps to the left, with"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`n\  = \ n\_R + \ n\_L\)]]], "NumberedEquation",
  CellTags->"(8.1.12)"],

Cell["and ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`j\  = \ n\_R\  - \ n\_L\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.13)"],

Cell[TextData[{
  "These two equations imply that the position ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " can be written in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " and the total number of steps ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`j = \ \ 2  n\_R\  - n\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.14)"],

Cell[TextData[{
  "\tThe decision tree for this random walk has the following form.  Any \
given path that ends up at ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " will consist of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " steps to the right, and ",
  Cell[BoxData[
      \(TraditionalForm\`n - n\_R\)]],
  " steps to the left. Each path is simply a sum of steps, as shown below for \
",
  Cell[BoxData[
      \(TraditionalForm\`n = 15\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`j\  = \ \(\(-1\) + 1 - 1 - 1 + 1 + 1 + 1 - 1 - 1 + 
            1 - 1 - 1 + 1 - 1 - 1 = \(-3\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "The steps to the left or right in this sum can be in ",
  "any order",
  " and the path will still end up at ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(-3\)\)]],
  ", provided that there are ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R = 6\)]],
  " steps to the right and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_L = 9\)]],
  " steps to the left. The total probability of any such path is  ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\^n\_R\) q\^n\_L\)]],
  ". Therefore, ",
  StyleBox["all paths",
    FontSlant->"Italic"],
  " ending at ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps have the ",
  StyleBox["same probability",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\^n\_R\) q\^n\_L\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNow all we need is the number of different paths that lead to position \
",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ". This is simply the number of distinct permutations of the left and right \
steps making up the path. This combinatoric factor is given by  the formula"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(number\ of\ paths\)\(\ \
\)\(=\)\(\(n!\)\/\(\(n\_R!\) \(n\_L!\)\)\)\(\ \)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "This factor can be understood as follows. If there were ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " distinct elements in the list of steps making up a path, then there would \
be ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\)]],
  " ways of arranging these elements: ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " possibilities for the first element, ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " possibilities for the second element, and so on. Now, however, there are \
subgroups consisting of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " right steps and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_L\)]],
  " left steps within this list for which the elements are all identical.  \
Permutations  which correspond to a mere rearrangement of these elements \
within their own subgroups are not distinct paths. The number of such \
permutations is  ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\_R!\)\)]],
  " for the right steps and ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\_L!\)\)]],
  " for the left steps. We divide by these factors in order to be left with \
only the distinct permutations of the list. "
}], "Text"],

Cell["\<\
\t Since the total probability is the  probability per path times \
the number of paths, we arrive at\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\  = \(p\^n\_R\) 
          q\^n\_L\ \(n!\)\/\(\(n\_R!\) \(n\_L!\)\)\)]],
  ", assuming ",
  Cell[BoxData[
      \(TraditionalForm\`n + j\)]],
  " even, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(j\)\(|\)\(\(\[LessEqual]\)\(\ \
\)\(n\)\)\)\)]]
}], "NumberedEquation",
  CellTags->"(8.1.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  "is given in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " by Eq. ",
  ButtonBox["(8.1.14)",
    ButtonData:>{"Chapter8.nb", "(8.1.14)"},
    ButtonStyle->"Hyperlink"],
  ",  and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_L\  = \ n\  - \ n\_R\)]],
  ". Note that the equation is valid only for ",
  Cell[BoxData[
      \(TraditionalForm\`n + j\)]],
  " even, because ",
  Cell[BoxData[
      \(TraditionalForm\`if\ n + j\)]],
  " is odd then ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " is not an integer: see Eq. ",
  ButtonBox["(8.1.14)",
    ButtonData:>{"Chapter8.nb", "(8.1.14)"},
    ButtonStyle->"Hyperlink"],
  ". This is related to the fact that for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " even, only even grid points are populated, and for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " odd, only odd grid points are populated. Thus, we also have "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\  = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n + j\)]],
  " odd, or ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(j\)\(|\)\(\(>\)\(n\)\(\ \)\)\)\)]]
}], "NumberedEquation",
  CellTags->"(8.1.16)"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(8.1.15)",
    ButtonData:>{"Chapter8.nb", "(8.1.15)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.1.16)",
    ButtonData:>{"Chapter8.nb", "(8.1.16)"},
    ButtonStyle->"Hyperlink"],
  " give the famous ",
  StyleBox["binomial distribution",
    FontSlant->"Italic"],
  ", first derived by Jacob Bernouilli.  In Cell ",
  ButtonBox["8.11",
    ButtonData:>"Cell 8.11",
    ButtonStyle->"Hyperlink"],
  " we compare this theoretical formula with the histograms obtained \
previously. "
}], "Text",
  CellTags->"i:82"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p\  = \ \(q\  = \ 1/2\);\)\), "\n", 
    \(\(nR = \((n + j)\)/2;\)\), "\n", 
    \(\(nL\  = \ n - nR;\)\), "\n", 
    \(\(\(P[n_, j_]\  = \ p^nR\ q^nL\ \(n!\)/\((\(nR!\)\ \(nL!\))\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Table[
        Plot[M\ \ P[n, x], {x, \(-n\) - 1, n + 1}, 
          PlotRange \[Rule] {0, 200}, DisplayFunction \[Rule] Identity], {n, 
          0, 50}];\)\(\n\)
    \)\), "\n", 
    \(\(Table[
        Show[histograms[\([n]\)], %[\([n]\)], 
          PlotRange \[Rule] {{\(-25\), 25}, {0, 200}}, 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[%]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.11"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .61803 L
.52 .61803 L
.52 0 L
F
0 g
.5 0 m
.5 .61803 L
.52 .61803 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.48 .39345 m
.48162 .42472 L
.48339 .4571 L
.48505 .48557 L
.48665 .5109 L
.48835 .53539 L
.48999 .55633 L
.49173 .57551 L
.49341 .5908 L
.49502 .60241 L
.49584 .6071 L
.49674 .6113 L
.49759 .61436 L
.49797 .61543 L
.49839 .61639 L
.49862 .61682 L
.49883 .61716 L
.49905 .61746 L
.49924 .61767 L
.49944 .61783 L
.49953 .61789 L
.49962 .61794 L
.49972 .61798 L
.49976 .618 L
.49981 .61801 L
.49986 .61802 L
.49991 .61803 L
.49994 .61803 L
.49997 .61803 L
.50002 .61803 L
.50007 .61803 L
.50012 .61802 L
.50017 .61802 L
.50021 .61801 L
.50032 .61797 L
.50043 .61792 L
.50053 .61785 L
.50063 .61778 L
.50086 .61757 L
.50123 .61707 L
.50163 .61635 L
.50206 .61534 L
.50253 .61398 L
.50337 .61083 L
.50421 .60684 L
.50509 .60169 L
.50668 .59004 L
.50838 .5744 L
.51001 .55633 L
.51174 .53409 L
Mistroke
.51341 .50992 L
.51502 .48437 L
.51673 .45498 L
.51837 .42481 L
.52 .39345 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2Aooooo`03o`000?oooooooooo02;ooooo002Yooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0TOooool00ol@413oooooooooo`0Rooooo`00
ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Gooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Hooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Iooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Ko
oooo002Jooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool009Oooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2fooooo`00V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
09_ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Looooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Kooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Sooooo00Go0000ob4Q8Ol0003o<S8b
olc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Hooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Sooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00V?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Iooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool009Wooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009Wooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0]_ooool009[ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool009[ooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Uoooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo0;Kooooo002Gooooo`Go00001?ooool4o`0000Gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOoo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0]_ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Y
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00ZOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo
002@ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Booooo`03o`000?oo
oooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00T_ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo0;Kooooo002Booooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool009;ooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0;Kooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2f
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2fooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool5o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2fooooo`00Y?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0]_ooool0
0:Cooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
0;Kooooo002Tooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;So
oooo002Tooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo
002Tooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002T
ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002Toooo
o`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002Tooooo`03
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002Tooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002Tooooo`03o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002Uooooo`05o`000?oooooo
ooooooooool000001?oo0002o`000;Sooooo002Uooooo`05o`000?ooooooooooooooool000001?oo
0002o`000;Sooooo002Uooooo`05o`000?ooooooooooooooool000001?oo0002o`000;Sooooo002U
ooooo`05o`000?ooooooooooooooool000001?oo0002o`000;Sooooo002@ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`00000;oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
ooooool000000oooool00ol0003oo`00ool00002ool000;o0000^?ooool009;ooooo00?o0000oooo
ooooool01_ooool02omgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgMooooooo000000?o
oooo00?o0000ool00?oo00000_oo0002o`000;Sooooo002Booooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooo410@0oooool00ol@413oooooo`000003ooooo`03o`000?oo003oo`0000;o
o`000_l0002hooooo`00T_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oo003oo`0000;oo`000_l0002hooooo`00
T_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01ol0003o
oooooooooooooooo0000ooooool000000oooool00ol0003oo`00ool00002ool000;o0000^?ooool0
09;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`07oa0@4?oooooooooo
ooooool@413oooooo`000003ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`00002hooooo`00
T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00OoMgMgoiRHV?oooooo
V9RHogMgMooooooo000000?ooooo00Oo0000ool00?oo003oo`00o`000?oo003o00000;Sooooo002@
ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`07onk^k_lb<S;o0000oc8b<_o^k^kooooo
o`000003ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`00002hooooo`00YOooool01Ol0003o
oooooooooooooooo000000?oo`0000?o0000ool00?l00000^?ooool00:Gooooo00Go0000oooooooo
ooooooooo`000003ool00003o`000?oo003o00000;Sooooo002Uooooo`05o`000?oooooooooooooo
ool000000ooo00000ol0003oo`00o`00002hooooo`00YOooool01Ol0003ooooooooooooooooo0000
00?oo`0000?o0000ool00?l00000^?ooool00:Kooooo00Co0000oooooooooooo00000ooo00000ol0
003oo`00o`00002hooooo`00Y_ooool01?l0003oooooooooool00003ool00003o`000?oo003o0000
0;Sooooo002Vooooo`04o`000?ooooooooooo`0000?oo`0000?o0000ool00?l00000^?ooool00:Ko
oooo00Co0000oooooooooooo00000ooo00000ol0003oo`00o`00002hooooo`00Y_ooool01?l0003o
ooooooooool00003ool00003o`000?oo003o00000;Sooooo002Vooooo`04o`000?ooooooooooo`00
00?oo`0000?o0000ool00?l00000^?ooool00:Kooooo00Co0000oooooooooooo00000ooo00000ol0
003oo`00o`00002hooooo`00Y_ooool01?l0003oooooooooool00003ool00003o`000?oo003o0000
0;Sooooo002Vooooo`04o`000?ooooooooooo`0000?oo`0000?o0000ool00?l00000^?ooool0093o
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00OoA4A4o`000?l0
003o<S8bomgMgOoooooo000000;ooooo00Oo0000ool00?oo003oo`00o`000?oo003o00000;Sooooo
002Booooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01oooool01?mgMgOo<S8boooo
ool00002ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`00002hooooo`00T_ooool00ol0003o
ooooooooo`04ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooool000000_ooool01ol0003o
o`00ool00?oo003o0000ool00?l00000^?ooool009;ooooo00?o0000ooooooooool01Oooool00olQ
8B7oooooooooo`06ooooo`04ogMgMolb<S;oooooo`0000;ooooo00Oo0000ool00?oo003oo`00o`00
0?oo003o00000;Sooooo002Booooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00ooo
ool01ol0003o8B4Qo`000?lb<S;oc<c<ooooool000000_ooool01ol0003oo`00ool00?oo003o0000
ool00?l00000^?ooool009;ooooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo00001?l0003oo`00ool00?l0
002hooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;oo`0000Co0000ool00?oo003o
0000^?ooool0093ooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l00002ooooo`04o`00
0?ooooooooooo`0000;oo`0000Co0000ool00?oo003o0000^?ooool00:Kooooo00Co0000oooooooo
oooo00000_oo00001?l0003oo`00ool00?l0002hooooo`00Y_ooool01?l0003oooooooooool00002
ool00004o`000?oo003oo`00o`000;Sooooo002Vooooo`04o`000?ooooooooooo`0000;oo`0000Co
0000ool00?oo003o0000^?ooool00:Oooooo00?o0000ooooool000000_oo00001?l0003oo`00ool0
0?l0002hooooo`00Yoooool00ol0003oooooo`000002ool00004o`000?oo003oo`00o`000;Sooooo
002Wooooo`03o`000?oooooo000000;oo`0000Co0000ool00?oo003o0000^?ooool00:Oooooo00?o
0000ooooool000000_oo00001?l0003oo`00ool00?l0002hooooo`00Yoooool01Ol0003oooooo`00
0?oo003o000000?oo`0000?o0000ooooooooool0]_ooool00:Oooooo00Go0000ooooool0003oo`00
o`000003ool00003o`000?oooooooooo0;Kooooo002Wooooo`05o`000?oooooo0000ool00?l00000
0ooo00000ol0003oooooooooo`2fooooo`00Yoooool01Ol0003oooooo`000?oo003o000000?oo`00
00?o0000ooooooooool0]_ooool00:Sooooo0_l000000ooo003o0000ool00002ool00003o`000?oo
oooooooo0;Kooooo002Xooooo`;o000000?oo`00o`000?oo00000_oo00000ol0003oooooooooo`2f
ooooo`00Z?ooool3o`0000Coo`0000?o0000ooooooooool0]_ooool008oooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0ol00004
ool00003o`000?oooooooooo0;Kooooo002?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`?o0000
1?oo00000ol0003oooooooooo`2fooooo`00T?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo1ol0002hooooo`00
TOooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo00000<Cooooo002Booooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009?ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`32ooooo`00Soooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool008oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Aooooo`04oa0@4?l0003o8B4Qolc<c=?ooooo002<ooooo`;o00001Oooool00on7
QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo
0;Kooooo002<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pko
oooo00?o0000ooooooooool00oooool2oc8b<[Oooooo0020ooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?oooooooooo
ooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool03Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^09Oooooo0021ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Uoooool0087ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000013o
oooo00Go410@oooooooooooooooooa0@402Gooooo`00POooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo
1_l00009ooooo`05o`000?ooooooooooooooool00000Uoooool0087ooooo1Ol00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Co
oooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo0000013ooooo00Go0000oooo
ooooooooooooo`00002Gooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0>
ooooo`05oa0@4?ooooooooooooooool@4100Uoooool0087ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg09Oooooo0020ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP2Gooooo`00U?ooool00ol@413oooooooooo`3Aooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .34919 L
.5 .34919 L
.5 0 L
F
0 g
.48 0 m
.48 .34919 L
.5 .34919 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .26884 L
.54 .26884 L
.54 0 L
F
0 g
.52 0 m
.52 .26884 L
.54 .26884 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.46 .13115 m
.46325 .16016 L
.46678 .19276 L
.47011 .22357 L
.47331 .25268 L
.47671 .28235 L
.47998 .30889 L
.48347 .33416 L
.48682 .35497 L
.49005 .37115 L
.49168 .37777 L
.49348 .38377 L
.49519 .38815 L
.49595 .38969 L
.49678 .39108 L
.49724 .3917 L
.49766 .39219 L
.49809 .39262 L
.49848 .39293 L
.49887 .39316 L
.49905 .39325 L
.49924 .39332 L
.49944 .39338 L
.49953 .3934 L
.49962 .39342 L
.49973 .39344 L
.49982 .39345 L
.49988 .39345 L
.49994 .39345 L
.50004 .39345 L
.50014 .39345 L
.50024 .39344 L
.50034 .39343 L
.50043 .39341 L
.50063 .39336 L
.50085 .39329 L
.50107 .39319 L
.50126 .39309 L
.50171 .39278 L
.50246 .39206 L
.50326 .39101 L
.50412 .38956 L
.50505 .38761 L
.50675 .38309 L
.51018 .37013 L
.51349 .35319 L
.51668 .33321 L
.52006 .30852 L
.52333 .28206 L
.52679 .2518 L
Mistroke
.53013 .22134 L
.53335 .19155 L
.53676 .16007 L
.54 .13115 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .15142 L
.48 .15142 L
.48 0 L
F
0 g
.46 0 m
.46 .15142 L
.48 .15142 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .34301 L
.52 .34301 L
.52 0 L
F
0 g
.5 0 m
.5 .34301 L
.52 .34301 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .12361 L
.56 .12361 L
.56 0 L
F
0 g
.54 0 m
.54 .12361 L
.56 .12361 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.44 .05246 m
.44487 .07359 L
.45018 .09984 L
.45516 .12688 L
.45996 .15427 L
.46506 .18391 L
.46998 .21184 L
.4752 .23961 L
.48023 .2633 L
.48507 .28223 L
.48752 .2901 L
.49022 .29728 L
.49278 .30257 L
.49392 .30445 L
.49518 .30613 L
.49585 .30688 L
.49648 .30748 L
.49714 .308 L
.49773 .30837 L
.49831 .30866 L
.49858 .30876 L
.49886 .30885 L
.49916 .30893 L
.49929 .30895 L
.49944 .30898 L
.49959 .309 L
.49973 .30901 L
.49982 .30901 L
.49991 .30902 L
.50006 .30902 L
.50021 .30901 L
.50036 .309 L
.50051 .30899 L
.50064 .30897 L
.50095 .3089 L
.50128 .30881 L
.5016 .3087 L
.5019 .30857 L
.50257 .3082 L
.50369 .30732 L
.50489 .30605 L
.50618 .30429 L
.50758 .30193 L
.51012 .29647 L
.51528 .28103 L
.52024 .26125 L
.52501 .23854 L
.5301 .21143 L
.53499 .18361 L
.54019 .15341 L
Mistroke
.5452 .12485 L
.55002 .09882 L
.55515 .07353 L
.56 .05246 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .0618 L
.46 .0618 L
.46 0 L
F
0 g
.44 0 m
.44 .0618 L
.46 .0618 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .27193 L
.5 .27193 L
.5 0 L
F
0 g
.48 0 m
.48 .27193 L
.5 .27193 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .2194 L
.54 .2194 L
.54 0 L
F
0 g
.52 0 m
.52 .2194 L
.54 .2194 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .06489 L
.58 .06489 L
.58 0 L
F
0 g
.56 0 m
.56 .06489 L
.58 .06489 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.42 .02248 m
.42649 .03653 L
.43357 .05602 L
.44022 .07803 L
.44661 .10204 L
.45342 .12972 L
.45997 .15724 L
.46693 .18587 L
.47364 .21121 L
.48009 .23203 L
.48336 .24082 L
.48696 .24892 L
.49037 .25494 L
.4919 .25707 L
.49357 .25899 L
.49447 .25986 L
.49531 .26054 L
.49618 .26113 L
.49697 .26156 L
.49775 .26189 L
.4981 .26201 L
.49848 .26212 L
.49888 .2622 L
.49906 .26223 L
.49925 .26226 L
.49945 .26228 L
.49965 .26229 L
.49976 .2623 L
.49987 .2623 L
.50008 .2623 L
.50027 .2623 L
.50048 .26228 L
.50067 .26227 L
.50085 .26224 L
.50127 .26217 L
.5017 .26207 L
.50213 .26194 L
.50253 .26179 L
.50343 .26136 L
.50492 .26036 L
.50652 .2589 L
.50824 .25689 L
.51011 .2542 L
.51349 .24801 L
.52037 .23069 L
.52699 .20899 L
.53335 .18475 L
.54013 .15684 L
.54665 .12944 L
.55359 .10126 L
Mistroke
.56027 .07631 L
.56669 .05522 L
.57353 .03649 L
.58 .02248 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .03399 L
.44 .03399 L
.44 0 L
F
0 g
.42 0 m
.42 .03399 L
.44 .03399 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
F
0 g
.46 0 m
.46 .16687 L
.48 .16687 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .23794 L
.52 .23794 L
.52 0 L
F
0 g
.5 0 m
.5 .23794 L
.52 .23794 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .13288 L
.56 .13288 L
.56 0 L
F
0 g
.54 0 m
.54 .13288 L
.56 .13288 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .04635 L
.6 .04635 L
.6 0 L
F
0 g
.58 0 m
.58 .04635 L
.6 .04635 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.4 .00999 m
.40395 .0139 L
.40811 .0189 L
.41696 .03279 L
.42495 .04932 L
.43346 .07092 L
.44165 .09499 L
.45035 .1229 L
.45874 .15043 L
.4668 .17571 L
.47539 .19928 L
.47965 .20911 L
.48365 .2169 L
.48748 .22294 L
.4916 .22775 L
.49372 .22951 L
.49492 .23029 L
.49603 .23086 L
.49659 .2311 L
.4971 .23128 L
.49758 .23143 L
.49808 .23155 L
.49834 .2316 L
.49862 .23165 L
.49888 .23169 L
.49912 .23172 L
.49926 .23173 L
.4994 .23174 L
.49956 .23175 L
.49971 .23176 L
.49984 .23176 L
.49999 .23176 L
.50025 .23176 L
.50049 .23175 L
.50075 .23173 L
.50103 .2317 L
.50128 .23167 L
.50173 .23159 L
.50222 .23148 L
.50333 .23113 L
.50434 .23069 L
.50632 .22949 L
.50818 .22796 L
.51238 .22313 L
.51626 .21706 L
.52453 .19948 L
.53249 .1778 L
.54096 .15141 L
.54911 .12466 L
.55778 .09676 L
Mistroke
.56613 .07205 L
.57416 .05138 L
.58271 .0334 L
.59094 .02018 L
.59968 .01028 L
.6 .00999 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .02472 L
.42 .02472 L
.42 0 L
F
0 g
.4 0 m
.4 .02472 L
.42 .02472 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .08034 L
.46 .08034 L
.46 0 L
F
0 g
.44 0 m
.44 .08034 L
.46 .08034 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .22558 L
.5 .22558 L
.5 0 L
F
0 g
.48 0 m
.48 .22558 L
.5 .22558 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .16996 L
.54 .16996 L
.54 0 L
F
0 g
.52 0 m
.52 .16996 L
.54 .16996 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .10198 L
.58 .10198 L
.58 0 L
F
0 g
.56 0 m
.56 .10198 L
.58 .10198 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .01545 L
.62 .01545 L
.62 0 L
F
0 g
.6 0 m
.6 .01545 L
.62 .01545 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.38 .00454 m
.38474 .00687 L
.38974 .01004 L
.3948 .01412 L
.40035 .01971 L
.41056 .03332 L
.42039 .05073 L
.43083 .07359 L
.4409 .09892 L
.45058 .12488 L
.46087 .15212 L
.47079 .17565 L
.48032 .19365 L
.48522 .20056 L
.48794 .20363 L
.49048 .20595 L
.49302 .20774 L
.49437 .20847 L
.4958 .20908 L
.49646 .2093 L
.49717 .20949 L
.49784 .20964 L
.49816 .20969 L
.49846 .20974 L
.49875 .20977 L
.49902 .2098 L
.49931 .20982 L
.49963 .20984 L
.49993 .20984 L
.50026 .20984 L
.50058 .20983 L
.50087 .20981 L
.50116 .20978 L
.50147 .20975 L
.50203 .20966 L
.50263 .20954 L
.50329 .20937 L
.50447 .20898 L
.50557 .2085 L
.50808 .20703 L
.51076 .20488 L
.51614 .19882 L
.52122 .19112 L
.53091 .1719 L
.54122 .14673 L
.55115 .12021 L
.5607 .09474 L
.57087 .06959 L
.58065 .04869 L
.59105 .03087 L
Mistroke
.59625 .02374 L
.60107 .01816 L
.60613 .0133 L
.61071 .00973 L
.62 .00454 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`00
0_l0000Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Gooooo00Go
0000ooooooooooooooooo`000005ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`00000Eoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4o`0002Cooooo002:ooooo`;o
000000?oooooo`000?oo00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool01?l0003oo`00ool00?l00002ool00003o`000?oooooooooo
09[ooooo002<ooooo`;o00001Ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`Oo0000Moooool00ol0003oooooooooo`0Rooooo`00SOooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07_ooooo00?o410@ooooooooool08_ooool008gooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000Go
0000ooooooooooooooooo`00002Sooooo`00SOooool7o`0000Gooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00001Ol0003ooooooooooooooooo00000:?ooooo002?ooooo`03o`000?oooooooooo00Oooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l0
0004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00004o`000?ooooooooooo`000:Cooooo002@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00001?l0003oooooooooool0002Tooooo`00T?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooool00000YOooool0097ooooo00?o0000
ooooooooool01Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool000;o0000Y_ooool009;ooooo00?o0000oooo
ooooool01?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool000;o0000Y_ooool009;ooooo00?o0000oooooooo
ool01?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009?ooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`000:Oooooo002Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`000:Oooooo002Dooooo`03o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool01ol0
003oo`00ool00?oo003o0000ool00?l00000Yoooool009Gooooo00Go0000ooooooooooooooooo`00
0004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool01ol0003oo`00ool0
0?oo003o0000ool00?l00000Yoooool009Gooooo00?o0000ooooool000000_l00004ool00003o`00
0?ooooooA4A400;o000000?o<S8bo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool01?l0003oo`00ool00?l00002ool00003
o`000?oooooooooo0:Gooooo002Fooooo`04o`000?nHV9So8B4Qo`0000Coo`0000?o0000oooooooo
ool00_ooool00omgMgOo0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`04o`000?oo003oo`00o`0000;oo`0000?o0000oooo
ooooool0YOooool009Kooooo00Co0000oooooonHV9So00001?oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00o`000003ool00003o`000?oooooooooo0:Gooooo002Gooooo`03
o`000?oooooo000000Go00001?ooool00omgMgOo0000ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o000000?o
o`0000?o0000ooooooooool0YOooool009Oooooo00Go0000ooooooooooooMgMgofIVIP04ooooo`05
o`000?lQ8B7o0000oc8b<_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool2o`0000Coo`0000?o0000ooooooooool0YOooool009So
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Coo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo0_l00004
ool00003o`000?oooooooooo0:Gooooo002Gooooo`;o000000?ooooooiRHV?l@41001?ooool01Ol0
003ooooooooooooooooo000000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo0_l00004ool00003o`000?oooooooooo0:Gooooo002Goooo
o`05oiRHV?l0003o0000ob4Q8Oo<c<`01?ooool5o`0000Coo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo0:Gooooo002Iooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Iooooo`03o`000?oooooooooo00So
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool7o`000:Oooooo002Iooooo`03o`000?oooooooooo00Sooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2/ooooo`00V_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00_ooool00ol0003oooooooooo`2/ooooo`00V_ooool00ol0003oooooooooo`07
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0[?ooool009[ooooo00?o0000oooo
ooooool01oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00001Ol0003ooooooooooooooooo00000:oooooo002Jooooo`03o`000?oooooooooo
00Oooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000Go0000ooooooooooooooooo`00002_ooooo`00Voooool00ol0003oooooooooo`06oooo
o`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000Go0000oooo
ooooooooooooo`00002_ooooo`00Voooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00004o`000?oooooooooo
o`000;3ooooo002Kooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000Co0000oooooooooooo0000/?ooool0
09cooooo00?o0000ooooooooool01Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00001?l0003oooooooooool0002`ooooo`00W?ooool00ol0
003oooooooooo`05ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooo00000;7ooooo002Mooooo`03o`000?oooooooooo00Co
oooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooo`00002aooooo`00V?ooool03Om4A4Co0000o`000?lb<S;ogMgMo`000?ooooook^k^oc8b<_l0
003o<S8bonk^k_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooool00000/Oooool009_ooooo00[oMgMgoc8b<_l0003oooooogMgMonHV9SooooooiRH
V?mgMgOo00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l0002b
ooooo`00W?ooool01?l0003oooooo`000?l@4103ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool000;o0000/_ooool009_ooooo00?oMgMgoc8b
<_ooool00_l00003ooooo`;o00001?oo0003o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`2aooooo`00V?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Co0000oooo
oooooooooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`2aooooo`00V?ooool00ol0003oooooooooo`04ooooo`06o`000?oooooooooo
ooooool@413o00001?oo00000ol0003oooooooooo`03ooooo`04o`000?oo003oo`00ool000;o0000
/oooool009Sooooo00?o0000ooooooooool01?ooool01_mgMgOo0000oooooonHV9SoMgMgo`0000Co
o`0000?o0000ooooooooool00oooool01?l0003oo`00ool00?oo0002o`000;?ooooo002Hooooo`Co
00000oooool01_o^k^ko0000o`000?lb<S;ok^k^o`0000Coo`000_l00004ooooo`Ko0000/oooool0
0:3ooooo00Go0000ooooooooooooooooo`000004ool00003o`000?oooooooooo00Kooooo00?o0000
ooooooooool0/oooool00:7ooooo00Co0000oooooooooooo00001?oo00000ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0;?ooooo002Qooooo`04o`000?ooooooooooo`0000Coo`0000?o0000
ooooooooool01Oooool00ol0003oooooooooo`2dooooo`00X_ooool00ol0003oooooo`000004ool0
0003o`000?oooooooooo00Cooooo00?o0000ooooooooool0]Oooool00:?ooooo0_l00004ool000;o
00001Oooool00ol0003oooooooooo`2eooooo`00Xoooool2o`0000Coo`0000?o0000ooooooooool0
0oooool00ol0003oooooooooo`2fooooo`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0]_ooool00:Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;Oooooo002Tooooo`;o00000ooo0002o`00
00;ooooo00?o0000ooooooooool0^?ooool00:Cooooo00Ko0000ool00?l0003o0000ool00?l00002
ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oo003oo`0000Ko0000^oooool00:Co
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2looooo`00Y?ooool00ol0003oo`00
ool00002ool000;o0000_Oooool00:Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2looooo`00VOooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_l000001?oo
00000ol0003oooooooooo`2looooo`00VOooool00omEEEGoZJVYooooo`07ooooo`03ogMgMol0003o
000000Co0000__ooool009Wooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0;cooooo002Jooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool00oooool3o`000;cooooo002Jooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uooo
ool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`000;gooooo002@
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00T?ooool4o`000003oa0@4?oooooooooo00Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Booooo`03o`000?oo
oooooooo00Gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000005oa0@4?oooooooooooooooom4A4@0
0_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooooooo
o`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool00oooool3o`000;cooooo
002Booooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000005ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00T?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool01?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
1Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_oo
ool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool5
o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool008oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool008oooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`?o0000_?ooool0097ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo
002Cooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool0`_ooool008oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002?oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00TOooool01?l@413o0000ob4Q8Oo<c<cCooooo`00S?oo
ool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Ooo
ool00ol0003o^[Zjooooo`2fooooo`00S?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:gooooo`00P?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l0
00001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00kooooo00GoA4A4o`000?l0003o<S8bomgMg@2Foooo
o`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooooooo
oooo0000ooooo`Ko00003Oooool00omgMgOo<S8booooo`2Eooooo`00POooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000005Oooool00ol0003oooooooooo`2Dooooo`00POooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo
1_l0000=ooooo`03ogMgMolb<S;ooooo09Gooooo0021ooooo`Go00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Aooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0U_ooool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03oooool00ol0
003oooooooooo`2Hooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo09Sooooo0020ooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000oooo
ooooool04Oooool2o`0002?ooooo1?l0002Gooooo`00U?ooool00ol@413oooooooooo`3Aooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .00927 L
.4 .00927 L
.4 0 L
F
0 g
.38 0 m
.38 .00927 L
.4 .00927 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .07107 L
.44 .07107 L
.44 0 L
F
0 g
.42 0 m
.42 .07107 L
.44 .07107 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .13288 L
.48 .13288 L
.48 0 L
F
0 g
.46 0 m
.46 .13288 L
.48 .13288 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .20704 L
.52 .20704 L
.52 0 L
F
0 g
.5 0 m
.5 .20704 L
.52 .20704 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .12979 L
.56 .12979 L
.56 0 L
F
0 g
.54 0 m
.54 .12979 L
.56 .12979 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
F
0 g
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .00618 L
.64 .00618 L
.64 0 L
F
0 g
.62 0 m
.62 .00618 L
.64 .00618 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.36 .0021 m
.36553 .00345 L
.37136 .00543 L
.37727 .00814 L
.38375 .01206 L
.3895 .0165 L
.39566 .02237 L
.40784 .03768 L
.41958 .05716 L
.43087 .07975 L
.44289 .10651 L
.45446 .13281 L
.46558 .1562 L
.47177 .16751 L
.47743 .17638 L
.48327 .18376 L
.48883 .1889 L
.49164 .19076 L
.49319 .19155 L
.49465 .19216 L
.49601 .19259 L
.49678 .19278 L
.49748 .19292 L
.49808 .19301 L
.49842 .19305 L
.49873 .19308 L
.49906 .19311 L
.49942 .19312 L
.49974 .19313 L
.50005 .19314 L
.50039 .19313 L
.50075 .19312 L
.50109 .19309 L
.5014 .19307 L
.50213 .19298 L
.50249 .19292 L
.50289 .19285 L
.50445 .19246 L
.50591 .19194 L
.50853 .19066 L
.51132 .18879 L
.51433 .18621 L
.5176 .18279 L
.52352 .175 L
.53555 .15397 L
.54714 .12924 L
.55828 .10384 L
.57014 .0776 L
.58155 .05509 L
.59369 .03549 L
Mistroke
.59975 .02755 L
.60538 .0213 L
.61662 .0118 L
.62267 .00817 L
.62814 .00563 L
.63381 .00364 L
.63993 .00211 L
.64 .0021 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo013ooooo
0ol000000ooooooo0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00o`000003o`00013ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool04oooool7o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`00013ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool008Wooooo00?o0000
ooooooooool01oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo09_ooooo002:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000Go0000ooooooooooooooooo`00001iooooo`03o`000?oooooo
oooo02;ooooo002;ooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000Co0000oooooooooooo0000N_ooool0
0ol@413oooooooooo`0Rooooo`00S?ooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo0000
0:3ooooo002=ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l0002Qooooo`00S_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo0:3ooooo002?ooooo`05o`000?ooooooooooooooool00000
1Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`04o`000?oo003oo`00ool000;o0000X_ooool0093ooooo
00Co0000oooooooooooo00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`06o`000?oo003oo`00o`00
0?oo003o0000X_ooool0093ooooo00Co0000oooooooooooo00001Ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`06o`000?oo003oo`00o`000?oo003o0000X_ooool0097ooooo00?o0000ooooool000001Ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003o000000;oo`0000?o0000ooooooooool0X?oo
ool0097ooooo00?o0000ooooool000001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`;o00000ooo0000
0ol0003oooooooooo`2Pooooo`00T_ooool2o`0000Goo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool2o`00
00?oo`0000?o0000ooooooooool0X?ooool009;ooooo0_l00005ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Pooooo`00Toooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`2Pooooo`00Toooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0
002Rooooo`00Toooool2o`0000Coo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2V
ooooo`00Toooool2o`0000Coo`000ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00001Ol0003ooooooooooooooooo00000:Wooooo002Cooooo`Oo000000GoooooodA4
A?ooooooooooo`000005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000Go0000ooooooooooooooooo`00
002Yooooo`00UOooool01_l0003ooooooooooonHV9So8B4Qonk^kP?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00005o`000?ooooooooooooooool00000ZOooool009Kooooo
00Ko0000ooooooooooooV9RHob4Q8Oo^k^h2ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00001?l0003oooooooooool0002Zooooo`00U_ooool01_l0003ooooooooooooooooo
MgMgofIVIP;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00004o`000?oo
ooooooooo`000:[ooooo002Gooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooool00000Zoooool009Oooooo00Go
0000okZj^_ooooooV9RHoa0@4002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooo`00002[ooooo`00Uoooool01Ol0003o410@o`000?lQ8B7oc<c<00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool000;o0000[?ooool009Sooooo00?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`000_l0
002/ooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo0002o`000:cooooo002Hooooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:_ooooo002Iooooo`03
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo0:_ooooo002Iooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00002ool000;o0000[Oooool009[ooooo00Go0000oooooooooooooooo
o`000005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000;oo`000_l0002]ooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000Goo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00Oo0000ool00?oo003oo`00o`000?oo003o00000:gooooo002Kooooo`04
o`000?ooooooooooo`0000Goo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`2[
ooooo`00W?ooool00ol0003oooooo`000005ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`04o`000?oo003oo`00o`0000;oo`0000?o0000
ooooooooool0Zoooool009cooooo00?o0000ooooool000001Ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`000:gooooo002Mooooo`So
00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0[oooool009gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009kooooo00?o0000ooooooooool02?oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?oo
ool009Sooooo00coA4A4o`000?l0003o<S8bomgMgOoooooo0000onk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2a
ooooo`00Voooool02OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2aooooo`00W?oo
ool01?l0003oooooooooool00003ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;7ooooo002Kooooo`04ogMgMolb
<S;oooooooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00Go0000ooooooooooooooooo`00002dooooo`00V?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00001Ol0003o
oooooooooooooooo00000;Cooooo002Hooooo`03o`000?oooooooooo00Cooooo00Go410@o`000?oo
oooooooooa0@4005ooooo`03o`000?oo003oo`0000?oo`0000Co0000oooooooooooo0000]Oooool0
09Sooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHo`000?nHV9SoMgMg00Gooooo00?o0000
ool00?oo00000ooo00001?l0003oooooooooool0002eooooo`00V?ooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooool00000]_oo
ool00:;ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
00000;Kooooo002Sooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0002o`00
0;Oooooo002Tooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`2fooooo`00YOooool01Ol0003ooooooooooooooooo000000Coo`000_l0002hooooo`00
YOooool01Ol0003ooooooooooooooooo000000?oo`0000?o0000ool00?l00000^?ooool00:Kooooo
0_l000000ooooooo0000ool00002o`0000;oo`0000?o0000ooooooooool0]_ooool00:Sooooo1?l0
0003ool00003o`000?oooooooooo0;Kooooo002Yooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0]_ooool00:Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2foooo
o`00ZOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002Yooooo`Oo0000
^?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00VOooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00VOooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009Wooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Jooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002J
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2l
ooooo`00Uoooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2looooo`00Uoooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2o`000;gooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000003oa0@4?oooooooooo00Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00T_ooool0
0ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool3
o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGo
IVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`00
0005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T?ooool0
0omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00T?ooool4o`000003oa0@4?oooooooooo00;ooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?oo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0093o
oooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000
ooooooooool0_?ooool008oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool0097ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034oooo
o`00T_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo00000<Cooooo002Cooooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0`_ooool008oooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg0<Cooooo002?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00TOooool01?l@
413o0000ob4Q8Oo<c<cCooooo`00S?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0
003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2fooooo`00S?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?o
oooo0_lb<S:gooooo`00P?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?o
oooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7
o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00gooooo00Go
k^k^oc8b<_l0003o410@olc<c02Gooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@
41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonH
V9So8B4Q09Oooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000@ooooo`05o`000?oooooooooooooo
ool00000Uoooool0087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01Ol0003oV9RH
oooooonHV9So8B4Q09Oooooo0021ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_o
oooo00Go0000ohN7QoooooooZJVYo`00000@ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0Uoooool0
087ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03_ooool00omEEEGoQhN7ooooo`2I
ooooo`00POooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Pooooo`03omgMgOl@413oV9RH09Wooooo0020ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2
o`0002?ooooo00Coc<c<odA4A?l0003o410@Uoooool009Cooooo00?o410@ooooooooool0dOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .00618 L
.38 .00618 L
.38 0 L
F
0 g
.36 0 m
.36 .00618 L
.38 .00618 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04017 L
.42 .04017 L
.42 0 L
F
0 g
.4 0 m
.4 .04017 L
.42 .04017 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .10507 L
.46 .10507 L
.46 0 L
F
0 g
.44 0 m
.44 .10507 L
.46 .10507 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .17614 L
.5 .17614 L
.5 0 L
F
0 g
.48 0 m
.48 .17614 L
.5 .17614 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .1576 L
.54 .1576 L
.54 0 L
F
0 g
.52 0 m
.52 .1576 L
.54 .1576 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .09889 L
.58 .09889 L
.58 0 L
F
0 g
.56 0 m
.56 .09889 L
.58 .09889 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .03399 L
.62 .03399 L
.62 0 L
F
0 g
.6 0 m
.6 .03399 L
.62 .03399 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.34 .00098 m
.34302 .00131 L
.34632 .00176 L
.35298 .00297 L
.35652 .00383 L
.36031 .00493 L
.36714 .00747 L
.3743 .01105 L
.38106 .01543 L
.39397 .02691 L
.4077 .04405 L
.42092 .0652 L
.43364 .08886 L
.44717 .11563 L
.4602 .14025 L
.46682 .15139 L
.47405 .16192 L
.48097 .17 L
.48406 .17288 L
.48739 .17547 L
.48924 .17666 L
.49095 .17759 L
.49254 .17831 L
.49429 .17895 L
.49505 .17918 L
.49586 .17939 L
.49657 .17953 L
.49733 .17966 L
.49778 .17973 L
.49819 .17977 L
.49859 .17981 L
.49901 .17984 L
.49939 .17985 L
.49974 .17986 L
.50013 .17986 L
.50054 .17986 L
.50096 .17984 L
.50135 .17981 L
.50179 .17977 L
.50221 .17973 L
.50295 .17962 L
.50376 .17947 L
.50559 .17899 L
.50728 .17839 L
.51072 .17668 L
.51437 .17418 L
.52094 .16798 L
.5271 .16038 L
.54014 .13964 L
.55401 .11329 L
Mistroke
.56737 .08691 L
.58022 .06321 L
.59389 .04179 L
.60706 .02584 L
.61427 .01909 L
.62105 .01395 L
.62724 .0102 L
.63402 .00698 L
.64073 .0046 L
.64444 .00358 L
.64781 .0028 L
.6537 .00175 L
.65694 .00132 L
.66 .00098 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00cooooo
1?l00004ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo1?l0000=ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00kooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02o`00017ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Tooooo`Co00009?ooool008Kooooo0_l00005ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo0003o`0009[ooooo0028ooooo`;o00000oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000_oo0002o`0007Oooooo00?o0000ooooooooool08_ooool008[o
oooo00Co0000oooooooooooo00001Ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool01ol0003oo`00ool00?oo003o0000ool00?l00000Mooo
ool00ol@413oooooooooo`0Rooooo`00Roooool00ol0003oooooo`000005ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`04o`000?oo003o
o`00o`0000;oo`0000?o0000ooooooooool0V_ooool008cooooo0_l00005ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
000000?oo`0000?o0000ooooooooool0V_ooool008cooooo0_l00005ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?l000000ooo00000ol0
003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000W?ooool008gooooo
0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:3ooooo002=ooooo`Oo00001Oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00005o`000?ooooooooooooooool00000Xoooool008oooooo00?o0000ooooooooool01ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00004o`000?ooooooooooo`000:Cooooo002?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00004o`000?ooooooooooo`000:Cooooo002@ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`00002Uooooo`00TOooool0
0ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooool00000YOooool0
097ooooo00?o0000ooooooooool01Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool000;o0000Y_ooool009;o
oooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`000_l0002Vooooo`00Toooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009?ooooo00Co
0000oooooooooooooooo0ol00004ool00003o`000?ooooooA4A400;o000000?o<S8bo`000?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Dooooo`06o`000?oo
oooooooooiRHV?lQ8B7o00001?oo00000ol0003oooooooooo`02ooooo`03ogMgMol0003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo0002o`000:Oooooo002Dooooo`06o`000?oooooooooooooooonH
V9So00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000ol00003oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool01ol0003oo`00ool00?oo003o
0000ool00?l00000Yoooool009Gooooo00Go0000ooooooooooooooooo`000004ool00003o`000?oo
oooooooo00;ooooo00?oMgMgo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool01ol0003oo`00ool00?oo003o0000ool00?l0
0000Yoooool009Kooooo00Co0000oooooooooooo00001?oo00001ol0003oooooo`000?lQ8B7o0000
oc8b<_l000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool01?l0003oo`00ool00?l00002ool00003o`000?oooooooooo0:Gooooo002F
ooooo`04o`000?ooooooooooo`0000Coo`0000?o0000ooooool000000oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003o000000?oo`0000?o0000ooooooooool0YOooool009Oooooo00?o0000
okZj^_l000001?oo00000ol0003oooooo`000003ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?l000000ooo00000ol0003oooooooooo`2Uooooo`00Uoooool00ol0003o410@o`000004ool0
0003o`000?oooooo000000Co00001?oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`;o00001?oo00000ol0003oooooooooo`2Uooooo`00V?ooool2o`0000Co
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Oo0000Yoooool009Sooooo
0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2[ooooo`00VOooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2/ooooo`00V_ooool00ol0003oooooooooo`07ooooo`03o`000?oo003oo`0000;oo`000_l00004
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2/
ooooo`00V_ooool00ol0003oooooooooo`07ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00005o`000?ooooooooooooooool00000[oooool0
09_ooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00001Ol0003ooooooooooooooooo00000:oooooo002Koooo
o`03o`000?oooooooooo00Kooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000Co0000oooooooooooo0000/?ooool009cooooo00?o0000oooo
ooooool01Oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool0
0004o`000?ooooooooooo`000;3ooooo002Looooo`03o`000?oooooooooo00Gooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ool00000/Oooool009gooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooo`00002aooooo`00
WOooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool000;o0000/_ooool009gooooo00?o0000ooooooooool01?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
0002o`000;;ooooo002Nooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002
o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2aooooo`00V?ooool03Om4
A4Co0000o`000?lb<S;ogMgMooooool0003ok^k^oc8b<_l0003o<S8bonk^k_l000001?oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009_o
oooo00[oMgMgoc8b<_ooooooooooo`000?nHV9SooooooiRHV?mgMgOo00001?oo00000ol0003ooooo
ooooo`03ooooo`04o`000?oo003oo`00ool000;o0000/oooool009cooooo00Go0000oooooooooooo
410@o`000002ooooo`03oa0@4?l0003oo`0000?oo`0000?o0000ooooooooool00oooool01?l0003o
o`00ool00?oo0002o`000;?ooooo002Kooooo`04ogMgMolb<S;oooooooooo`;o00000_ooool2o`00
00Coo`000ol00003ooooo`06o`000?oo003oo`00o`000?oo003o0000/oooool009Sooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`04o`000?oooooo0000ooooo`;o00001?oo00000ol0003ooooo
ooooo`03ooooo`Ko0000/oooool009Sooooo00?o0000ooooooooool01?ooool01_l@413ooooooooo
ool0003o410@o`0000Coo`0000?o0000ooooooooool01Oooool00ol0003oooooooooo`2dooooo`00
V?ooool00ol0003oooooooooo`04ooooo`04ogMgMonHV9SooooooiRHV0;o00001?oo00000ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0;Gooooo002Hooooo`Co00000oooool01_o^k^ko<S8b
o`000?lb<S;ok^k^o`0000Coo`000_l00003ooooo`;o0000^?ooool00:Cooooo0_l00003ool00005
o`000?ooooooooooooooool00000^_ooool00:Cooooo1_l00002ooooo`03o`000?oooooooooo0;Wo
oooo002Wooooo`Go0000_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?oo
ool009Wooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo0;cooooo002Iooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2looooo`00V_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?o
oooo0ol0002looooo`00V_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`2looooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol0
0004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo
0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093o
oooo1?l000000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003ooooooooo
o`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool0093ooooo1?l000001Ol@413oooooooooooooooooA4A400;o0000
00Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00T_oo
ool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
093ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00Cooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o
0000ooooooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol00004
ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002?ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002?ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3
o`000;cooooo002Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00Tooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo0<;ooooo002?ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool0097ooooo00Co410@o`000?lQ8B7oc<c<doooool008cooooo0_l0
0005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o
0000okZj^_ooool0]_ooool008cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b]oooool0083ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go
410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0?ooooo`03o`000?o^k^kooooo09Oooooo0021ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l0
000;ooooo`03oeEEEOnYZJWooooo09Oooooo0021ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Booooo`03
ojVYZOmEEEGooooo09Oooooo0021ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?o
8B4Qooooooooool0U_ooool0087ooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02ooo
ool01Ol0003oQhN7oooooonYZJWo000001?ooooo00?oEEEEolc<c?ooool0U_ooool0087ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool04Oooool00onYZJWoMgMgooooo`2Fooooo`00POoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Pooooo`05oa0@4?oooooooooooooooolb<S80Uoooool0083ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o
00008_ooool5o`0009Oooooo002Dooooo`03oa0@4?oooooooooo0=7ooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .00618 L
.36 .00618 L
.36 0 L
F
0 g
.34 0 m
.34 .00618 L
.36 .00618 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .01545 L
.4 .01545 L
.4 0 L
F
0 g
.38 0 m
.38 .01545 L
.4 .01545 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
F
0 g
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .13597 L
.48 .13597 L
.48 0 L
F
0 g
.46 0 m
.46 .13597 L
.48 .13597 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .17614 L
.52 .17614 L
.52 0 L
F
0 g
.5 0 m
.5 .17614 L
.52 .17614 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .13288 L
.56 .13288 L
.56 0 L
F
0 g
.54 0 m
.54 .13288 L
.56 .13288 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .06489 L
.6 .06489 L
.6 0 L
F
0 g
.58 0 m
.58 .06489 L
.6 .06489 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .01854 L
.64 .01854 L
.64 0 L
F
0 g
.62 0 m
.62 .01854 L
.64 .01854 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.32 .00046 m
.32339 .00064 L
.32711 .0009 L
.33099 .00124 L
.3346 .00164 L
.3423 .00281 L
.34661 .0037 L
.35053 .00467 L
.35777 .00697 L
.36562 .01033 L
.37312 .01451 L
.38107 .02015 L
.39537 .03374 L
.4106 .05325 L
.42526 .07623 L
.44084 .10322 L
.45585 .12871 L
.47029 .14948 L
.47772 .15776 L
.48185 .16146 L
.48565 .16424 L
.48954 .16645 L
.49158 .16735 L
.49375 .16808 L
.49465 .16833 L
.49563 .16855 L
.49647 .1687 L
.49738 .16883 L
.49794 .16889 L
.49845 .16894 L
.49894 .16897 L
.49919 .16898 L
.49947 .16899 L
.49994 .16899 L
.50021 .16899 L
.50045 .16899 L
.5009 .16897 L
.50137 .16895 L
.50184 .16891 L
.50234 .16887 L
.50326 .16875 L
.50415 .16859 L
.50498 .16842 L
.50685 .1679 L
.50883 .16718 L
.51214 .16558 L
.51577 .16327 L
.52313 .15691 L
.53102 .14783 L
.54663 .12468 L
Mistroke
.56166 .09884 L
.57611 .07395 L
.5915 .05027 L
.60631 .03191 L
.61387 .02443 L
.62204 .01779 L
.62928 .01306 L
.63721 .009 L
.64476 .00609 L
.64893 .00482 L
.65273 .00385 L
.66012 .00239 L
.66418 .0018 L
.66803 .00135 L
.67105 .00105 L
.67425 .0008 L
.68 .00046 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .00618 L
.34 .00618 L
.34 0 L
F
0 g
.32 0 m
.32 .00618 L
.34 .00618 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .01236 L
.38 .01236 L
.38 0 L
F
0 g
.36 0 m
.36 .01236 L
.38 .01236 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
F
0 g
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .0618 L
.46 .0618 L
.46 0 L
F
0 g
.44 0 m
.44 .0618 L
.46 .0618 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .1885 L
.5 .1885 L
.5 0 L
F
0 g
.48 0 m
.48 .1885 L
.5 .1885 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .15142 L
.54 .15142 L
.54 0 L
F
0 g
.52 0 m
.52 .15142 L
.54 .15142 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .09271 L
.58 .09271 L
.58 0 L
F
0 g
.56 0 m
.56 .09271 L
.58 .09271 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .05253 L
.62 .05253 L
.62 0 L
F
0 g
.6 0 m
.6 .05253 L
.62 .05253 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .00309 L
.66 .00309 L
.66 0 L
F
0 g
.64 0 m
.64 .00309 L
.66 .00309 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.3 .00022 m
.30377 .00032 L
.3079 .00047 L
.31221 .00067 L
.31623 .00092 L
.3207 .00127 L
.32478 .00167 L
.32953 .00226 L
.33392 .00295 L
.34197 .0046 L
.35069 .00713 L
.35856 .01021 L
.36722 .01464 L
.37537 .01994 L
.38414 .02699 L
.40146 .0452 L
.41813 .06768 L
.43418 .09226 L
.45125 .11855 L
.46768 .14029 L
.47667 .14938 L
.48079 .15269 L
.48515 .15554 L
.48917 .15756 L
.49145 .15843 L
.49358 .15906 L
.49458 .1593 L
.49554 .15948 L
.4964 .15962 L
.49732 .15974 L
.4978 .15978 L
.49832 .15982 L
.4988 .15985 L
.49924 .15987 L
.49977 .15988 L
.50025 .15988 L
.50078 .15987 L
.50105 .15986 L
.50134 .15984 L
.50189 .15981 L
.5024 .15976 L
.50356 .15963 L
.50457 .15946 L
.50565 .15924 L
.50752 .15876 L
.50957 .15806 L
.51412 .15595 L
.51837 .15329 L
.52689 .14606 L
.53468 .13753 L
Mistroke
.55138 .11465 L
.56744 .08972 L
.58453 .06382 L
.60099 .04229 L
.6094 .03312 L
.61848 .02473 L
.62651 .01861 L
.63533 .01321 L
.64372 .00923 L
.65257 .00608 L
.66078 .00397 L
.66538 .00307 L
.66957 .00239 L
.6776 .00143 L
.68214 .00104 L
.68633 .00075 L
.69283 .00044 L
.69653 .00031 L
.7 .00022 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
F
0 g
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .00618 L
.36 .00618 L
.36 0 L
F
0 g
.34 0 m
.34 .00618 L
.36 .00618 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04326 L
.4 .04326 L
.4 0 L
F
0 g
.38 0 m
.38 .04326 L
.4 .04326 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .04017 L
.44 .04017 L
.44 0 L
F
0 g
.42 0 m
.42 .04017 L
.44 .04017 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .12979 L
.48 .12979 L
.48 0 L
F
0 g
.46 0 m
.46 .12979 L
.48 .12979 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .18232 L
.52 .18232 L
.52 0 L
F
0 g
.5 0 m
.5 .18232 L
.52 .18232 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .11434 L
.56 .11434 L
.56 0 L
F
0 g
.54 0 m
.54 .11434 L
.56 .11434 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .06798 L
.6 .06798 L
.6 0 L
F
0 g
.58 0 m
.58 .06798 L
.6 .06798 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .02472 L
.64 .02472 L
.64 0 L
F
0 g
.62 0 m
.62 .02472 L
.64 .02472 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .00309 L
.68 .00309 L
.68 0 L
F
0 g
.66 0 m
.66 .00309 L
.68 .00309 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.28 .0001 m
.28415 .00016 L
.28869 .00024 L
.29343 .00036 L
.29785 .00051 L
.30277 .00074 L
.30725 .001 L
.31243 .00139 L
.31732 .00187 L
.3218 .00241 L
.32654 .00312 L
.33506 .00479 L
.34409 .00725 L
.35254 .01034 L
.3619 .01482 L
.37046 .02001 L
.3888 .03508 L
.40645 .05464 L
.42522 .0797 L
.4433 .10523 L
.45253 .11758 L
.46251 .1296 L
.47134 .13854 L
.47635 .14273 L
.48102 .14601 L
.48547 .1485 L
.48775 .14953 L
.49024 .15046 L
.49159 .15088 L
.49285 .15122 L
.49403 .15148 L
.49533 .15172 L
.49649 .15188 L
.49758 .15199 L
.49818 .15204 L
.49873 .15207 L
.49933 .15209 L
.49964 .15209 L
.49997 .15209 L
.50058 .15209 L
.50114 .15207 L
.50143 .15206 L
.50176 .15204 L
.50241 .15199 L
.50298 .15194 L
.5036 .15187 L
.50471 .15171 L
.50697 .15126 L
.50903 .1507 L
.5114 .14987 L
Mistroke
.51399 .14875 L
.51871 .14617 L
.52781 .1393 L
.53751 .12958 L
.55674 .10516 L
.57528 .07899 L
.59311 .05519 L
.61208 .03423 L
.62153 .02591 L
.63035 .01947 L
.63938 .01414 L
.64792 .01015 L
.65734 .00681 L
.66592 .00457 L
.67039 .00366 L
.67513 .00285 L
.68365 .00177 L
.68799 .00136 L
.69266 .00101 L
.69704 .00075 L
.70111 .00056 L
.70551 .0004 L
.71032 .00027 L
.715 .00017 L
.71762 .00013 L
.72 .0001 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .00618 L
.34 .00618 L
.34 0 L
F
0 g
.32 0 m
.32 .00618 L
.34 .00618 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .02781 L
.38 .02781 L
.38 0 L
F
0 g
.36 0 m
.36 .02781 L
.38 .02781 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .0309 L
.42 .0309 L
.42 0 L
F
0 g
.4 0 m
.4 .0309 L
.42 .0309 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .09271 L
.46 .09271 L
.46 0 L
F
0 g
.44 0 m
.44 .09271 L
.46 .09271 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .1576 L
.5 .1576 L
.5 0 L
F
0 g
.48 0 m
.48 .1576 L
.5 .1576 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .13906 L
.54 .13906 L
.54 0 L
F
0 g
.52 0 m
.52 .13906 L
.54 .13906 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .11125 L
.58 .11125 L
.58 0 L
F
0 g
.56 0 m
.56 .11125 L
.58 .11125 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .03708 L
.62 .03708 L
.62 0 L
F
0 g
.6 0 m
.6 .03708 L
.62 .03708 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .01236 L
.66 .01236 L
.66 0 L
F
0 g
.64 0 m
.64 .01236 L
.66 .01236 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .00309 L
.7 .00309 L
.7 0 L
F
0 g
.68 0 m
.68 .00309 L
.7 .00309 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.26 5e-05 m
.26234 6e-05 L
.26452 8e-05 L
.26948 .00013 L
.27431 .00019 L
.27947 .00029 L
.28519 .00044 L
.29059 .00064 L
.29544 .00087 L
.30071 .00119 L
.30547 .00156 L
.31071 .00208 L
.31624 .00276 L
.3213 .00353 L
.33109 .00551 L
.34161 .00852 L
.35118 .01223 L
.36162 .01751 L
.38211 .03217 L
.40183 .05183 L
.42279 .07736 L
.44298 .10334 L
.46241 .12542 L
.47246 .1343 L
.47758 .13794 L
.48308 .14108 L
.48573 .1423 L
.48825 .14327 L
.4907 .14405 L
.49297 .1446 L
.49512 .14499 L
.4962 .14513 L
.49683 .14519 L
.4974 .14524 L
.49798 .14528 L
.49859 .14531 L
.49921 .14534 L
.49956 .14534 L
.49988 .14534 L
.50047 .14534 L
.50101 .14533 L
.50163 .1453 L
.50221 .14527 L
.50279 .14523 L
.50342 .14517 L
.50455 .14503 L
.50589 .14482 L
.50711 .14458 L
.50977 .14391 L
.5123 .14308 L
Mistroke
.51675 .14116 L
.5216 .13846 L
.53154 .13103 L
.54211 .12077 L
.5631 .09563 L
.58332 .06959 L
.60277 .04679 L
.61264 .03689 L
.62346 .02759 L
.63389 .02021 L
.64339 .0148 L
.65324 .01039 L
.66379 .00685 L
.67343 .00451 L
.67887 .0035 L
.6839 .00274 L
.69333 .00167 L
.69869 .00123 L
.70372 .00091 L
.70868 .00067 L
.71391 .00047 L
.71837 .00034 L
.72324 .00023 L
.72749 .00017 L
.73135 .00012 L
.7358 8e-05 L
.74 5e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00309 L
.32 .00309 L
.32 0 L
F
0 g
.3 0 m
.3 .00309 L
.32 .00309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01854 L
.36 .01854 L
.36 0 L
F
0 g
.34 0 m
.34 .01854 L
.36 .01854 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .02472 L
.4 .02472 L
.4 0 L
F
0 g
.38 0 m
.38 .02472 L
.4 .02472 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
F
0 g
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .12361 L
.48 .12361 L
.48 0 L
F
0 g
.46 0 m
.46 .12361 L
.48 .12361 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .13597 L
.52 .13597 L
.52 0 L
F
0 g
.5 0 m
.5 .13597 L
.52 .13597 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .12361 L
.56 .12361 L
.56 0 L
F
0 g
.54 0 m
.54 .12361 L
.56 .12361 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .07725 L
.6 .07725 L
.6 0 L
F
0 g
.58 0 m
.58 .07725 L
.6 .07725 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .02472 L
.64 .02472 L
.64 0 L
F
0 g
.62 0 m
.62 .02472 L
.64 .02472 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .00309 L
.68 .00309 L
.68 0 L
F
0 g
.66 0 m
.66 .00309 L
.68 .00309 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00309 L
.72 .00309 L
.72 0 L
F
0 g
.7 0 m
.7 .00309 L
.72 .00309 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.24 2e-05 m
.24254 3e-05 L
.2449 4e-05 L
.24771 5e-05 L
.25027 7e-05 L
.2555 .00011 L
.25838 .00013 L
.26109 .00016 L
.26683 .00025 L
.27213 .00036 L
.27794 .00052 L
.2841 .00076 L
.28924 .00102 L
.29477 .00138 L
.30476 .00229 L
.31028 .00297 L
.3163 .0039 L
.32727 .00616 L
.33801 .00927 L
.34946 .01378 L
.36115 .01986 L
.37216 .02711 L
.39321 .04517 L
.4156 .06951 L
.43716 .09509 L
.45789 .11752 L
.46854 .12676 L
.47448 .13096 L
.47996 .13415 L
.48552 .13664 L
.48845 .13765 L
.49156 .13847 L
.49286 .13874 L
.49425 .13898 L
.49557 .13916 L
.49678 .13928 L
.49748 .13933 L
.49812 .13937 L
.49883 .1394 L
.49923 .13941 L
.49959 .13942 L
.49997 .13942 L
.50032 .13942 L
.5007 .13941 L
.50111 .1394 L
.5018 .13938 L
.50218 .13936 L
.50255 .13933 L
.50396 .13921 L
.50527 .13905 L
Mistroke
.5067 .13882 L
.50823 .13852 L
.51106 .13779 L
.51362 .13696 L
.51884 .13475 L
.52375 .13207 L
.53473 .12414 L
.54482 .11486 L
.56641 .09088 L
.58717 .06629 L
.60927 .04276 L
.63054 .02518 L
.64216 .01797 L
.65316 .01263 L
.66405 .0086 L
.67411 .00583 L
.68432 .00379 L
.69013 .00292 L
.69558 .00225 L
.70096 .00172 L
.70662 .00128 L
.71192 .00096 L
.71673 .00073 L
.72196 .00053 L
.72753 .00037 L
.7327 .00026 L
.73757 .00018 L
.74289 .00012 L
.74557 .0001 L
.74852 7e-05 L
.75103 6e-05 L
.75373 5e-05 L
.7586 3e-05 L
.76 2e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00309 L
.3 .00309 L
.3 0 L
F
0 g
.28 0 m
.28 .00309 L
.3 .00309 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .00927 L
.34 .00927 L
.34 0 L
F
0 g
.32 0 m
.32 .00927 L
.34 .00927 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .02472 L
.38 .02472 L
.38 0 L
F
0 g
.36 0 m
.36 .02472 L
.38 .02472 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04635 L
.42 .04635 L
.42 0 L
F
0 g
.4 0 m
.4 .04635 L
.42 .04635 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .11125 L
.46 .11125 L
.46 0 L
F
0 g
.44 0 m
.44 .11125 L
.46 .11125 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .14524 L
.5 .14524 L
.5 0 L
F
0 g
.48 0 m
.48 .14524 L
.5 .14524 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .10507 L
.54 .10507 L
.54 0 L
F
0 g
.52 0 m
.52 .10507 L
.54 .10507 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .0958 L
.58 .0958 L
.58 0 L
F
0 g
.56 0 m
.56 .0958 L
.58 .0958 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .05562 L
.62 .05562 L
.62 0 L
F
0 g
.6 0 m
.6 .05562 L
.62 .05562 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .01854 L
.66 .01854 L
.66 0 L
F
0 g
.64 0 m
.64 .01854 L
.66 .01854 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .00309 L
.7 .00309 L
.7 0 L
F
0 g
.68 0 m
.68 .00309 L
.7 .00309 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.22 1e-05 m
.22273 2e-05 L
.22528 2e-05 L
.2283 3e-05 L
.23106 4e-05 L
.23669 6e-05 L
.23979 7e-05 L
.24272 9e-05 L
.24572 .00012 L
.24889 .00015 L
.2546 .00022 L
.26073 .00032 L
.26749 .00049 L
.27345 .00069 L
.27891 .00093 L
.2852 .00128 L
.29118 .00172 L
.29682 .00224 L
.30283 .00293 L
.31364 .00459 L
.31969 .00582 L
.32623 .00741 L
.33809 .01116 L
.34981 .01612 L
.3622 .0229 L
.38453 .03944 L
.4083 .06253 L
.43117 .08758 L
.44282 .10005 L
.4555 .11237 L
.46663 .12146 L
.47297 .12569 L
.47892 .12895 L
.48452 .13133 L
.48767 .13236 L
.49055 .1331 L
.49343 .13365 L
.49505 .13387 L
.49657 .13402 L
.49739 .13408 L
.4978 .13411 L
.49817 .13412 L
.49887 .13415 L
.49963 .13416 L
.50039 .13416 L
.50082 .13416 L
.50122 .13415 L
.50165 .13413 L
.50203 .13411 L
.5029 .13406 L
Mistroke
.50366 .134 L
.50438 .13394 L
.50572 .13377 L
.50715 .13355 L
.50871 .13326 L
.51151 .13259 L
.51409 .13181 L
.52002 .12945 L
.52628 .12614 L
.53785 .11803 L
.54864 .10854 L
.57155 .08458 L
.5959 .05813 L
.61936 .03616 L
.64193 .02046 L
.65358 .01455 L
.66594 .00976 L
.67741 .00649 L
.68817 .00427 L
.69396 .00336 L
.70006 .00258 L
.71095 .00155 L
.71657 .00117 L
.72258 .00086 L
.72824 .00063 L
.73339 .00046 L
.73927 .00032 L
.74469 .00023 L
.75064 .00015 L
.75363 .00012 L
.75693 .0001 L
.75991 8e-05 L
.76275 6e-05 L
.76806 4e-05 L
.77103 3e-05 L
.77378 2e-05 L
.77679 2e-05 L
.78 1e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
F
0 g
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00927 L
.32 .00927 L
.32 0 L
F
0 g
.3 0 m
.3 .00927 L
.32 .00927 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01236 L
.36 .01236 L
.36 0 L
F
0 g
.34 0 m
.34 .01236 L
.36 .01236 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .02781 L
.4 .02781 L
.4 0 L
F
0 g
.38 0 m
.38 .02781 L
.4 .02781 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .08961 L
.44 .08961 L
.44 0 L
F
0 g
.42 0 m
.42 .08961 L
.44 .08961 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .13597 L
.48 .13597 L
.48 0 L
F
0 g
.46 0 m
.46 .13597 L
.48 .13597 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .12361 L
.52 .12361 L
.52 0 L
F
0 g
.5 0 m
.5 .12361 L
.52 .12361 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
F
0 g
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .08961 L
.6 .08961 L
.6 0 L
F
0 g
.58 0 m
.58 .08961 L
.6 .08961 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .02781 L
.64 .02781 L
.64 0 L
F
0 g
.62 0 m
.62 .02781 L
.64 .02781 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .01545 L
.68 .01545 L
.68 0 L
F
0 g
.66 0 m
.66 .01545 L
.68 .01545 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.2 1e-05 m
.20293 1e-05 L
.20565 1e-05 L
.20865 1e-05 L
.21185 2e-05 L
.21521 3e-05 L
.21839 3e-05 L
.22434 5e-05 L
.22755 7e-05 L
.23096 9e-05 L
.23707 .00013 L
.24046 .00017 L
.24364 .0002 L
.25089 .00032 L
.25742 .00046 L
.26364 .00064 L
.26922 .00086 L
.27531 .00116 L
.28181 .00157 L
.28771 .00205 L
.29459 .00275 L
.30092 .00356 L
.31304 .00565 L
.31942 .00709 L
.32616 .0089 L
.33853 .01314 L
.35008 .0183 L
.37459 .03358 L
.40065 .05606 L
.42575 .08145 L
.4499 .10496 L
.46211 .11485 L
.4686 .11925 L
.47559 .12319 L
.48225 .12611 L
.48517 .12711 L
.48835 .12801 L
.49138 .12866 L
.49282 .12891 L
.49419 .1291 L
.49575 .12927 L
.49643 .12932 L
.49716 .12937 L
.49795 .12942 L
.49868 .12944 L
.49947 .12946 L
.49991 .12946 L
.50033 .12946 L
.50112 .12945 L
.50156 .12943 L
Mistroke
.50196 .12942 L
.50274 .12938 L
.50347 .12933 L
.50511 .12918 L
.50689 .12895 L
.51013 .12836 L
.51311 .12762 L
.5188 .12571 L
.52479 .123 L
.53719 .11535 L
.54875 .10614 L
.57329 .08242 L
.59938 .05603 L
.62452 .03425 L
.6487 .01892 L
.66118 .01326 L
.67442 .00873 L
.68672 .0057 L
.69824 .00368 L
.70445 .00286 L
.71098 .00217 L
.7171 .00165 L
.72265 .00128 L
.72868 .00095 L
.73511 .00069 L
.74107 .0005 L
.74669 .00036 L
.75283 .00025 L
.75932 .00017 L
.76486 .00012 L
.77095 8e-05 L
.77425 6e-05 L
.77737 5e-05 L
.78323 3e-05 L
.7865 2e-05 L
.78954 2e-05 L
.79286 1e-05 L
.7964 1e-05 L
.8 1e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00927 L
.3 .00927 L
.3 0 L
F
0 g
.28 0 m
.28 .00927 L
.3 .00927 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .00618 L
.34 .00618 L
.34 0 L
F
0 g
.32 0 m
.32 .00618 L
.34 .00618 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .03399 L
.38 .03399 L
.38 0 L
F
0 g
.36 0 m
.36 .03399 L
.38 .03399 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
F
0 g
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .11125 L
.46 .11125 L
.46 0 L
F
0 g
.44 0 m
.44 .11125 L
.46 .11125 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .11743 L
.5 .11743 L
.5 0 L
F
0 g
.48 0 m
.48 .11743 L
.5 .11743 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .12979 L
.54 .12979 L
.54 0 L
F
0 g
.52 0 m
.52 .12979 L
.54 .12979 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .08034 L
.58 .08034 L
.58 0 L
F
0 g
.56 0 m
.56 .08034 L
.58 .08034 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .05253 L
.62 .05253 L
.62 0 L
F
0 g
.6 0 m
.6 .05253 L
.62 .05253 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .01545 L
.66 .01545 L
.66 0 L
F
0 g
.64 0 m
.64 .01545 L
.66 .01545 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01236 L
.7 .01236 L
.7 0 L
F
0 g
.68 0 m
.68 .01236 L
.7 .01236 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.18 0 m
.18312 0 L
.18603 1e-05 L
.18922 1e-05 L
.19264 1e-05 L
.19623 1e-05 L
.19962 2e-05 L
.20596 3e-05 L
.20939 4e-05 L
.21302 5e-05 L
.21954 8e-05 L
.22316 .0001 L
.22655 .00013 L
.23025 .00016 L
.23428 .0002 L
.24125 .0003 L
.24788 .00044 L
.25434 .00061 L
.26033 .00082 L
.26743 .00114 L
.27412 .00154 L
.28013 .00199 L
.28663 .0026 L
.30003 .00434 L
.30677 .00553 L
.31418 .00711 L
.32729 .01075 L
.34135 .01607 L
.35562 .02319 L
.36914 .03164 L
.3949 .05205 L
.4223 .07782 L
.44869 .10188 L
.46193 .1118 L
.47406 .11881 L
.48039 .12152 L
.48362 .12262 L
.48706 .12359 L
.49053 .12435 L
.49208 .12461 L
.49375 .12484 L
.49478 .12495 L
.49573 .12504 L
.49661 .12511 L
.49709 .12514 L
.49759 .12516 L
.49847 .1252 L
.49928 .12522 L
.49976 .12522 L
.50022 .12522 L
Mistroke
.50108 .12521 L
.50192 .12518 L
.50239 .12516 L
.50282 .12514 L
.50361 .12509 L
.50447 .12503 L
.50596 .12487 L
.50754 .12467 L
.51109 .12402 L
.51441 .12321 L
.52038 .12122 L
.52678 .1184 L
.54108 .10973 L
.55461 .09911 L
.5804 .07521 L
.60784 .04964 L
.62148 .03846 L
.63426 .02935 L
.64665 .02194 L
.65967 .01564 L
.67326 .01058 L
.6857 .00713 L
.69213 .00574 L
.69899 .0045 L
.71134 .00282 L
.71824 .00213 L
.72571 .00155 L
.73277 .00113 L
.73926 .00083 L
.7458 .0006 L
.7519 .00044 L
.75859 .00031 L
.76232 .00025 L
.76578 .0002 L
.7726 .00013 L
.77621 .00011 L
.78003 8e-05 L
.78646 5e-05 L
.79011 4e-05 L
.79355 3e-05 L
.80015 2e-05 L
.80346 1e-05 L
.8071 1e-05 L
.81021 1e-05 L
.81353 1e-05 L
.81667 0 L
.81953 0 L
.82 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
F
0 g
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01854 L
.36 .01854 L
.36 0 L
F
0 g
.34 0 m
.34 .01854 L
.36 .01854 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04635 L
.4 .04635 L
.4 0 L
F
0 g
.38 0 m
.38 .04635 L
.4 .04635 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
F
0 g
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .11434 L
.48 .11434 L
.48 0 L
F
0 g
.46 0 m
.46 .11434 L
.48 .11434 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .1267 L
.52 .1267 L
.52 0 L
F
0 g
.5 0 m
.5 .1267 L
.52 .1267 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .09889 L
.56 .09889 L
.56 0 L
F
0 g
.54 0 m
.54 .09889 L
.56 .09889 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05253 L
.6 .05253 L
.6 0 L
F
0 g
.58 0 m
.58 .05253 L
.6 .05253 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04635 L
.64 .04635 L
.64 0 L
F
0 g
.62 0 m
.62 .04635 L
.64 .04635 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .01236 L
.68 .01236 L
.68 0 L
F
0 g
.66 0 m
.66 .01236 L
.68 .01236 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00927 L
.72 .00927 L
.72 0 L
F
0 g
.7 0 m
.7 .00927 L
.72 .00927 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.16 0 m
.16332 0 L
.16641 0 L
.1698 0 L
.17343 1e-05 L
.17724 1e-05 L
.18084 1e-05 L
.18408 1e-05 L
.18759 2e-05 L
.1912 2e-05 L
.19518 3e-05 L
.19933 4e-05 L
.20323 5e-05 L
.21019 8e-05 L
.21409 .00011 L
.21767 .00013 L
.2247 .0002 L
.23123 .00028 L
.23839 .00041 L
.24602 .0006 L
.25337 .00084 L
.26131 .0012 L
.26881 .00165 L
.27571 .00218 L
.28915 .00362 L
.29678 .00473 L
.30391 .00601 L
.31844 .00947 L
.33169 .01379 L
.34531 .0196 L
.36014 .02763 L
.38925 .0485 L
.41729 .07307 L
.44424 .0965 L
.45922 .10738 L
.46578 .11135 L
.47295 .11501 L
.47992 .11783 L
.48641 .11973 L
.48999 .12048 L
.49169 .12076 L
.49325 .12096 L
.49506 .12115 L
.49601 .12123 L
.49702 .12129 L
.49789 .12133 L
.49871 .12136 L
.49961 .12137 L
.50011 .12137 L
.50057 .12137 L
Mistroke
.5015 .12135 L
.50236 .12132 L
.50314 .12128 L
.50399 .12123 L
.50588 .12106 L
.50762 .12085 L
.5108 .12033 L
.51416 .1196 L
.52122 .11742 L
.52896 .11411 L
.54292 .10597 L
.55786 .0948 L
.58743 .06879 L
.61592 .04435 L
.64332 .02559 L
.65747 .0183 L
.67248 .0123 L
.68641 .00818 L
.69947 .00538 L
.70651 .00422 L
.71391 .00323 L
.72713 .00194 L
.73396 .00147 L
.74125 .00107 L
.74813 .00078 L
.75438 .00058 L
.76152 .00041 L
.7681 .00029 L
.77532 .0002 L
.77896 .00016 L
.78296 .00013 L
.78669 .0001 L
.79024 8e-05 L
.79687 5e-05 L
.80058 4e-05 L
.80402 3e-05 L
.80776 2e-05 L
.8118 2e-05 L
.81538 1e-05 L
.81866 1e-05 L
.822 1e-05 L
.82511 1e-05 L
.82853 0 L
.83227 0 L
.83592 0 L
.83981 0 L
.84 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
F
0 g
.32 0 m
.32 .01236 L
.34 .01236 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .02163 L
.38 .02163 L
.38 0 L
F
0 g
.36 0 m
.36 .02163 L
.38 .02163 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .07107 L
.42 .07107 L
.42 0 L
F
0 g
.4 0 m
.4 .07107 L
.42 .07107 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .09889 L
.46 .09889 L
.46 0 L
F
0 g
.44 0 m
.44 .09889 L
.46 .09889 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .10198 L
.5 .10198 L
.5 0 L
F
0 g
.48 0 m
.48 .10198 L
.5 .10198 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .1267 L
.54 .1267 L
.54 0 L
F
0 g
.52 0 m
.52 .1267 L
.54 .1267 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .08343 L
.58 .08343 L
.58 0 L
F
0 g
.56 0 m
.56 .08343 L
.58 .08343 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
F
0 g
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .02163 L
.66 .02163 L
.66 0 L
F
0 g
.64 0 m
.64 .02163 L
.66 .02163 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .00927 L
.7 .00927 L
.7 0 L
F
0 g
.68 0 m
.68 .00927 L
.7 .00927 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00927 L
.74 .00927 L
.74 0 L
F
0 g
.72 0 m
.72 .00927 L
.74 .00927 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.14 0 m
.14351 0 L
.14679 0 L
.15038 0 L
.15422 0 L
.15825 0 L
.16207 1e-05 L
.16549 1e-05 L
.16921 1e-05 L
.17303 1e-05 L
.17725 2e-05 L
.18165 2e-05 L
.18577 3e-05 L
.19314 5e-05 L
.19728 7e-05 L
.20106 9e-05 L
.20851 .00013 L
.21542 .00019 L
.223 .00028 L
.23108 .00042 L
.23886 .00061 L
.24727 .00089 L
.25521 .00124 L
.26252 .00167 L
.26988 .00221 L
.27675 .00285 L
.28477 .00379 L
.29237 .00489 L
.30776 .00791 L
.32179 .01178 L
.33684 .01736 L
.35076 .02398 L
.38045 .0429 L
.40899 .06593 L
.43938 .09122 L
.45335 .1013 L
.46126 .10618 L
.46863 .11007 L
.47657 .11345 L
.48378 .11572 L
.48775 .11663 L
.49149 .11726 L
.49355 .11751 L
.49545 .11768 L
.49644 .11775 L
.49753 .1178 L
.49808 .11782 L
.49867 .11784 L
.49922 .11785 L
.49973 .11785 L
Mistroke
.50071 .11785 L
.50163 .11783 L
.50245 .1178 L
.50335 .11776 L
.50432 .1177 L
.50535 .11762 L
.50719 .11743 L
.51049 .11696 L
.51411 .11624 L
.51803 .11522 L
.52223 .11388 L
.52979 .11081 L
.54588 .1018 L
.5611 .09085 L
.59011 .06669 L
.62099 .04185 L
.63633 .03142 L
.65071 .02321 L
.66464 .01674 L
.67929 .01144 L
.69458 .00738 L
.70858 .00474 L
.71581 .00371 L
.72353 .00283 L
.73076 .00216 L
.73743 .00167 L
.74519 .00122 L
.75359 .00085 L
.761 .00061 L
.76884 .00042 L
.77599 .0003 L
.78367 .0002 L
.79091 .00014 L
.79752 9e-05 L
.80115 7e-05 L
.805 6e-05 L
.81193 4e-05 L
.81577 3e-05 L
.81938 2e-05 L
.82335 2e-05 L
.82762 1e-05 L
.83136 1e-05 L
.83484 1e-05 L
.83866 1e-05 L
.84275 0 L
.84704 0 L
.8511 0 L
.85474 0 L
.8587 0 L
.86 0 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
F
0 g
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01545 L
.36 .01545 L
.36 0 L
F
0 g
.34 0 m
.34 .01545 L
.36 .01545 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
F
0 g
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .10507 L
.48 .10507 L
.48 0 L
F
0 g
.46 0 m
.46 .10507 L
.48 .10507 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .12052 L
.52 .12052 L
.52 0 L
F
0 g
.5 0 m
.5 .12052 L
.52 .12052 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .0958 L
.56 .0958 L
.56 0 L
F
0 g
.54 0 m
.54 .0958 L
.56 .0958 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .06489 L
.6 .06489 L
.6 0 L
F
0 g
.58 0 m
.58 .06489 L
.6 .06489 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
F
0 g
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .01236 L
.68 .01236 L
.68 0 L
F
0 g
.66 0 m
.66 .01236 L
.68 .01236 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00618 L
.72 .00618 L
.72 0 L
F
0 g
.7 0 m
.7 .00618 L
.72 .00618 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
F
0 g
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.12 0 m
.12371 0 L
.12716 0 L
.13095 0 L
.13501 0 L
.13927 0 L
.14329 0 L
.14691 0 L
.15083 1e-05 L
.15487 1e-05 L
.15932 1e-05 L
.16396 2e-05 L
.16831 2e-05 L
.17237 3e-05 L
.17609 3e-05 L
.18014 4e-05 L
.18445 6e-05 L
.18858 7e-05 L
.19231 9e-05 L
.1996 .00013 L
.2037 .00016 L
.20812 .0002 L
.21614 .0003 L
.22373 .00043 L
.23205 .00062 L
.24075 .0009 L
.24886 .00125 L
.2572 .00173 L
.2651 .00232 L
.27991 .00386 L
.28762 .00495 L
.2958 .00637 L
.3105 .00971 L
.32604 .01454 L
.34062 .02048 L
.3715 .03789 L
.40433 .0624 L
.43595 .08742 L
.45188 .0984 L
.46636 .1064 L
.47441 .10979 L
.48201 .11221 L
.48618 .1132 L
.49003 .11388 L
.49204 .11415 L
.49425 .11438 L
.49537 .11447 L
.49656 .11454 L
.49714 .11457 L
.49769 .11459 L
Mistroke
.49872 .11461 L
.49972 .11463 L
.50028 .11463 L
.5008 .11462 L
.50175 .1146 L
.50275 .11457 L
.50365 .11453 L
.50449 .11448 L
.50639 .11432 L
.50846 .11409 L
.51034 .11382 L
.51456 .11304 L
.51818 .11216 L
.52211 .111 L
.52924 .10836 L
.54505 .10028 L
.56183 .08906 L
.592 .06536 L
.62412 .04087 L
.65503 .02253 L
.67106 .01561 L
.68791 .01014 L
.69554 .0082 L
.70369 .00647 L
.71836 .00409 L
.72655 .00311 L
.73542 .00227 L
.7438 .00167 L
.75151 .00124 L
.75927 .0009 L
.76652 .00066 L
.77447 .00047 L
.783 .00031 L
.79111 .00021 L
.79569 .00017 L
.79993 .00013 L
.80771 9e-05 L
.81164 7e-05 L
.81598 5e-05 L
.8199 4e-05 L
.82402 3e-05 L
.8314 2e-05 L
.83551 2e-05 L
.83934 1e-05 L
.84354 1e-05 L
.84804 1e-05 L
.85214 0 L
.85592 0 L
.86007 0 L
.86447 0 L
Mistroke
.86829 0 L
.87186 0 L
.87578 0 L
.87799 0 L
.88 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
F
0 g
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .00927 L
.34 .00927 L
.34 0 L
F
0 g
.32 0 m
.32 .00927 L
.34 .00927 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04326 L
.38 .04326 L
.38 0 L
F
0 g
.36 0 m
.36 .04326 L
.38 .04326 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .05871 L
.42 .05871 L
.42 0 L
F
0 g
.4 0 m
.4 .05871 L
.42 .05871 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .07725 L
.46 .07725 L
.46 0 L
F
0 g
.44 0 m
.44 .07725 L
.46 .07725 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.48 0 m
.48 .12979 L
.5 .12979 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .09889 L
.54 .09889 L
.54 0 L
F
0 g
.52 0 m
.52 .09889 L
.54 .09889 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
F
0 g
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .07416 L
.62 .07416 L
.62 0 L
F
0 g
.6 0 m
.6 .07416 L
.62 .07416 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .02781 L
.66 .02781 L
.66 0 L
F
0 g
.64 0 m
.64 .02781 L
.66 .02781 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .00618 L
.7 .00618 L
.7 0 L
F
0 g
.68 0 m
.68 .00618 L
.7 .00618 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
F
0 g
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.1 0 m
.1039 0 L
.10754 0 L
.11153 0 L
.1158 0 L
.12028 0 L
.12452 0 L
.12832 0 L
.13245 0 L
.1367 0 L
.14139 1e-05 L
.14628 1e-05 L
.15086 1e-05 L
.15513 2e-05 L
.15904 2e-05 L
.16356 3e-05 L
.16785 4e-05 L
.1759 6e-05 L
.1804 7e-05 L
.18448 9e-05 L
.19244 .00014 L
.19993 .0002 L
.20813 .0003 L
.21679 .00044 L
.22419 .0006 L
.23231 .00084 L
.24088 .00118 L
.2487 .00159 L
.25772 .00219 L
.26627 .00294 L
.27438 .00383 L
.28299 .00501 L
.29846 .00784 L
.31482 .01207 L
.33018 .0174 L
.34713 .02499 L
.36267 .03357 L
.39596 .05635 L
.42797 .08061 L
.44582 .0929 L
.46204 .10203 L
.47013 .1056 L
.4744 .10717 L
.47891 .10859 L
.48286 .10962 L
.4872 .11051 L
.4891 .11083 L
.49114 .11111 L
.49308 .11132 L
.49484 .11147 L
Mistroke
.49594 .11154 L
.49698 .11159 L
.49807 .11163 L
.49869 .11164 L
.49925 .11165 L
.5002 .11165 L
.50125 .11164 L
.50233 .11161 L
.50335 .11157 L
.50455 .11151 L
.50569 .11143 L
.50783 .11122 L
.51013 .11094 L
.51262 .11055 L
.51688 .10968 L
.5214 .1085 L
.52951 .10574 L
.5459 .09786 L
.56126 .08824 L
.59381 .06412 L
.62841 .03915 L
.64568 .02877 L
.66173 .02079 L
.67724 .01464 L
.69379 .00967 L
.70242 .00765 L
.71175 .00586 L
.71983 .00459 L
.72869 .00347 L
.73676 .00265 L
.74542 .00196 L
.75456 .00141 L
.76311 .00101 L
.77164 .00072 L
.78093 .00048 L
.7897 .00033 L
.79782 .00022 L
.8059 .00015 L
.81348 .0001 L
.81782 8e-05 L
.8218 7e-05 L
.82614 5e-05 L
.83078 4e-05 L
.83509 3e-05 L
.839 2e-05 L
.84666 1e-05 L
.85094 1e-05 L
.85559 1e-05 L
.85999 1e-05 L
.86404 0 L
Mistroke
.86795 0 L
.87217 0 L
.87614 0 L
.87978 0 L
.88403 0 L
.88643 0 L
.88867 0 L
.89275 0 L
.89504 0 L
.89711 0 L
.9 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0[ooooo`So000000?oo`00o`000?ooool0
1?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooo000000Wo00001Oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo01oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0_ooooo`04o`000?oo003oo`00ool000Go0000
0_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool7o`0000Cooooo1_l00005ooooo`Ko0000
8Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool006cooooo00?o0000ool00?oo00000_oo
00001?l0003oooooooooooooool3o`0000[ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool01?ooool4o`0008Oooooo
001/ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool01?ooool2o`0000Sooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00001?l0003ooooooooo
ooooool3o`0006Kooooo00?o0000ooooooooool08_ooool006cooooo1_l00008ooooo`;o00001_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
0004o`0006Wooooo00?o410@ooooooooool08_ooool007cooooo0ol00003ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00002ool000;o0000TOooool0
07oooooo0_l000000ooooooo0000ool00004ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000_l000000ooo003o0000ooooo`2@ooooo`00POooool2o`0000Goo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo
0000TOooool008;ooooo0ol00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00004o`000?ooooooooooooooo`;o0000Uoooool008;ooooo
00Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00001?l0003oooooooooool0002Iooooo`00P_ooool01ol0003o
o`00ool00?oo003o0000ool00?l000001?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`000ol0002Jooooo`00P_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo09[ooooo0029ooooo`05o`000?oooooooooooooo
ool000001Ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`04o`000?oo003oo`00ool000?o0000W?ooool008[ooooo00Co0000oooooooooooo00001Ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
1?l0003oo`00ool00?l00002ool00003o`000?oooooooooo09[ooooo002;ooooo`03o`000?oooooo
000000Goo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?l000000ooo00000ol0003oooooooooo`2Jooooo`00S?ooool8o`00
00Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`;o00001?oo00000ol0
003oooooooooo`2Jooooo`00S_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo1ol00003ooooo`;o00001Ooo00000ol0003o
ooooooooo`2Jooooo`00Soooool2o`0000Sooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00_ooooo0_l000000ooooooo0000ool00004ool00003o`00
0?oooooooooo09[ooooo002Aooooo`03o`000?oooooooooo00?ooooo0ol00004ool00003o`000?oo
ooooA4A400;o000000?o<S8bo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Goo`00
00?o0000ooooooooool0V_ooool009;ooooo0_l00003ooooo`03oiRHV?lQ8B7o000000Coo`0000?o
0000ooooooooool00_ooool00omgMgOo0000ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`;o00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo09[ooooo002Dooooo`05o`000?oooooooooooooooonHV9P01_l0
0005ooooo`03o`000?oo003oo`0000;oo`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`Oo0000W?ooool009Gooooo0_l00002
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgo`000?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool01Oooool2o`000:[ooooo002Goooo
o`05o`000?ooooooooooogMgMomVIVH01?ooool01Ol0003o8B4Qo`000?lb<S;o000000Coo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Z_ooool009Sooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00;ooooo0_l0002]ooooo`00Uoooool01Ol0003o^[Zjo`000?nHV9So410@00Cooooo
00Go0000ooooooooooooooooo`000004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00001Ol0003ooooooooooooooooo00000:oooooo002Gooooo`03oiRHV?l@413o000000;o
00001?ooool5o`0000Coo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000Co0000oooooooo
oooo0000/?ooool009cooooo0ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool8o`000;7ooooo002Oooooo`;o00000oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00Oooooo0_l0002cooooo`00XOooool01?l0003oooooooooool00004ool00003o`00
0?oooooooooo00Gooooo0_l0002eooooo`00X_ooool4o`0000?oo`000_l00003ooooo`?o0000]ooo
ool00:Cooooo00?o0000ool00?l000001ol0002jooooo`00Y?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo0;cooooo002Tooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo0002o`000;gooooo002Tooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo1_l0002nooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool009_ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00W?ooool01?l0003oooooooooool@4103
ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool009_ooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0002looooo`00V?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`Co00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00VOooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00VOooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009Wooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Joooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Jooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
0;cooooo002Jooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2looooo`00Uoooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000Cooooo1?l00005ooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2o`000;gooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000003oa0@4?oooooooooo
00Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?oo
ool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
T?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Kooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2loooo
o`00T?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00T?ooool4o`000003oa0@4?oooooo
oooo00;ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool01?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l00005ooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0_?ooool008oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool0097ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000034ooooo`00T_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo00000<Cooooo002Cooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0`_ooool008oo
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool0
0oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0
003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Go
oooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00kooooo1?l000001ol@413oooooooooool@413o0000odA4A?o<c<`0U?ooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`00
00cooooo00?o0000ooooooooool01?ooool00onHV9So410@omgMg@2Cooooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000004oooool00ol0003oooooooooo`05ooooo`03ohN7QomEEEGooooo09;ooooo001m
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo
00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?o0000ooooooooool00_ooool01Oo<
c<co8B4Qo`000?mEEEGo000009?ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03o`000?oooooooooo00;ooooo00Go
8B4QohN7QoooooooV9RHo`00002Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002Cooooo`00
OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@2Coooo
o`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006oooo
o`03o`000?oooooooooo017ooooo0_l0000Sooooo`03oeEEEOmVIVKo000000Cooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP2Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
F
0 g
.26 0 m
.26 .00618 L
.28 .00618 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01854 L
.32 .01854 L
.32 0 L
F
0 g
.3 0 m
.3 .01854 L
.32 .01854 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .0309 L
.36 .0309 L
.36 0 L
F
0 g
.34 0 m
.34 .0309 L
.36 .0309 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04017 L
.4 .04017 L
.4 0 L
F
0 g
.38 0 m
.38 .04017 L
.4 .04017 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
F
0 g
.42 0 m
.42 .08034 L
.44 .08034 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .09889 L
.48 .09889 L
.48 0 L
F
0 g
.46 0 m
.46 .09889 L
.48 .09889 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .11434 L
.52 .11434 L
.52 0 L
F
0 g
.5 0 m
.5 .11434 L
.52 .11434 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
F
0 g
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05253 L
.6 .05253 L
.6 0 L
F
0 g
.58 0 m
.58 .05253 L
.6 .05253 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
F
0 g
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02163 L
.68 .02163 L
.68 0 L
F
0 g
.66 0 m
.66 .02163 L
.68 .02163 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00618 L
.72 .00618 L
.72 0 L
F
0 g
.7 0 m
.7 .00618 L
.72 .00618 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00309 L
.76 .00309 L
.76 0 L
F
0 g
.74 0 m
.74 .00309 L
.76 .00309 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
F
0 g
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.08 0 m
.08198 0 L
.0841 0 L
.08792 0 L
.09025 0 L
.09246 0 L
.09659 0 L
.10095 0 L
.10497 0 L
.10939 0 L
.11408 0 L
.11848 0 L
.12321 0 L
.12767 1e-05 L
.13176 1e-05 L
.13654 1e-05 L
.14175 1e-05 L
.14667 2e-05 L
.15124 2e-05 L
.15572 3e-05 L
.16056 4e-05 L
.16483 5e-05 L
.16934 6e-05 L
.17341 8e-05 L
.17789 .0001 L
.18575 .00015 L
.19037 .00019 L
.19475 .00023 L
.20296 .00033 L
.21179 .00048 L
.22141 .00071 L
.2297 .00098 L
.23885 .00138 L
.2484 .00194 L
.25738 .00262 L
.26605 .00346 L
.27518 .00458 L
.2915 .00729 L
.29992 .00912 L
.30891 .01144 L
.32511 .01669 L
.34394 .02469 L
.36171 .03418 L
.39564 .05659 L
.43173 .08243 L
.44968 .09364 L
.45846 .09826 L
.46648 .10185 L
.47419 .10466 L
.48259 .10695 L
Mistroke
.4872 .10784 L
.48944 .10818 L
.49147 .10843 L
.49357 .10863 L
.49555 .10877 L
.49664 .10882 L
.49764 .10886 L
.49874 .10889 L
.4999 .1089 L
.50098 .10889 L
.50159 .10888 L
.50215 .10887 L
.50319 .10883 L
.50429 .10878 L
.50619 .10865 L
.50828 .10845 L
.51051 .10818 L
.51291 .10782 L
.51725 .10698 L
.5257 .1047 L
.53344 .10188 L
.55016 .09373 L
.56843 .08232 L
.60425 .05667 L
.63873 .03392 L
.65633 .02457 L
.67538 .01651 L
.69376 .01071 L
.70252 .00856 L
.71069 .00687 L
.72727 .00425 L
.73606 .00324 L
.74549 .00238 L
.75445 .00175 L
.7642 .00123 L
.77341 .00087 L
.78194 .00062 L
.79042 .00044 L
.79838 .00031 L
.80712 .00021 L
.81204 .00017 L
.81655 .00013 L
.82072 .00011 L
.82518 9e-05 L
.83322 6e-05 L
.83813 4e-05 L
.84278 3e-05 L
.84691 3e-05 L
.85147 2e-05 L
.85559 2e-05 L
Mistroke
.86003 1e-05 L
.86471 1e-05 L
.8691 1e-05 L
.87346 0 L
.8776 0 L
.88131 0 L
.88537 0 L
.8899 0 L
.89416 0 L
.89799 0 L
.90213 0 L
.90666 0 L
.90894 0 L
.91144 0 L
.91358 0 L
.91587 0 L
.92 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .0309 L
.38 .0309 L
.38 0 L
F
0 g
.36 0 m
.36 .0309 L
.38 .0309 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .06489 L
.42 .06489 L
.42 0 L
F
0 g
.4 0 m
.4 .06489 L
.42 .06489 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .08343 L
.46 .08343 L
.46 0 L
F
0 g
.44 0 m
.44 .08343 L
.46 .08343 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .12052 L
.5 .12052 L
.5 0 L
F
0 g
.48 0 m
.48 .12052 L
.5 .12052 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .0958 L
.54 .0958 L
.54 0 L
F
0 g
.52 0 m
.52 .0958 L
.54 .0958 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .07416 L
.58 .07416 L
.58 0 L
F
0 g
.56 0 m
.56 .07416 L
.58 .07416 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
F
0 g
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .03399 L
.66 .03399 L
.66 0 L
F
0 g
.64 0 m
.64 .03399 L
.66 .03399 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
F
0 g
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
F
0 g
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
F
0 g
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.06 0 m
.06207 0 L
.06429 0 L
.06829 0 L
.07074 0 L
.07305 0 L
.07738 0 L
.0796 0 L
.08195 0 L
.08616 0 L
.0907 0 L
.0957 0 L
.10076 0 L
.10538 0 L
.11072 0 L
.1158 0 L
.12047 1e-05 L
.1248 1e-05 L
.12956 1e-05 L
.13463 2e-05 L
.13958 2e-05 L
.14414 3e-05 L
.14913 3e-05 L
.15442 5e-05 L
.1633 7e-05 L
.16834 9e-05 L
.17305 .00012 L
.17768 .00015 L
.18271 .00018 L
.19186 .00028 L
.20077 .0004 L
.20901 .00057 L
.2179 .0008 L
.22625 .00109 L
.23541 .00151 L
.24529 .00211 L
.25413 .0028 L
.2638 .00377 L
.2739 .00506 L
.2833 .00656 L
.3022 .01063 L
.31938 .01578 L
.33711 .02273 L
.35632 .03223 L
.39413 .05592 L
.43054 .08076 L
.44883 .09162 L
.46555 .0994 L
.47477 .10256 L
.479 .10371 L
Mistroke
.48352 .10471 L
.48603 .10516 L
.48831 .10551 L
.49062 .10581 L
.49275 .10602 L
.49394 .10611 L
.49525 .1062 L
.49656 .10626 L
.49727 .10629 L
.49794 .10631 L
.49857 .10632 L
.49917 .10633 L
.5003 .10633 L
.50151 .10632 L
.50219 .10631 L
.50282 .10629 L
.50391 .10624 L
.50506 .10618 L
.50712 .10603 L
.50933 .10581 L
.51174 .10551 L
.51607 .10479 L
.5201 .10392 L
.52932 .10127 L
.53915 .09746 L
.55891 .08726 L
.57754 .07544 L
.61313 .05099 L
.63117 .03944 L
.65099 .02838 L
.67005 .01971 L
.68745 .01355 L
.70545 .0088 L
.71537 .0068 L
.72477 .00525 L
.73368 .00406 L
.74314 .00305 L
.75202 .0023 L
.76016 .00175 L
.7688 .0013 L
.77813 .00093 L
.78635 .00068 L
.79501 .00048 L
.80381 .00033 L
.80865 .00027 L
.81323 .00022 L
.82211 .00015 L
.83019 .0001 L
.83446 8e-05 L
.83916 6e-05 L
Mistroke
.84374 5e-05 L
.84866 4e-05 L
.85326 3e-05 L
.85746 2e-05 L
.8657 2e-05 L
.87011 1e-05 L
.87481 1e-05 L
.87924 1e-05 L
.88326 0 L
.888 0 L
.89313 0 L
.89796 0 L
.90241 0 L
.90676 0 L
.91142 0 L
.91581 0 L
.91982 0 L
.92452 0 L
.92718 0 L
.92963 0 L
.93414 0 L
.93641 0 L
.93892 0 L
.94 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Xooooo`So00001?oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool:o`000003oooo
ool0003o000000Co00008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02;ooooo
000jooooo`03o`000?oooooooooo02oooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`003?l0
000/ooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00K?ooool:o`000003ooooool0003o
o`0000Coo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000?o0000Q_ooool007Kooooo0ol00004ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`?o00000_oo00000ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02;ooooo001gooooo`03
o`000?oo003o000000;o000000?oo`00o`000?ooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`000009o`00067o
oooo00?o410@ooooooooool08_ooool007Oooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
0_l0002@ooooo`00Moooool9o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`04o`000?oo003oo`00ool000?o0000TOooool0083ooooo00?o0000ooooool000001_l0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00Co
0000ool00?l0003o00000_oo00000ol0003oooooooooo`2?ooooo`00POooool2o`0000[ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0
002Aooooo`00Poooool2o`0000Sooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00005o`000?ooooooooooooooool00000V?ooool008Gooooo0_l00006ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00001?l0003oooooo`000?l0002Iooooo`00Qoooool0
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0002
o`0009_ooooo0028ooooo`;o00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo0002o`00
09cooooo002:ooooo`;o000000?oooooo`000?oo00001?oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0009cooooo002<ooooo`;o0000
1Ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2Nooooo`00SOooool2o`0000Coo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo0_l0002Qooooo`00SOooool0
1?l0003oo`00o`000?l00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00005o`000?oo
ooooooooooooool00000Xoooool008gooooo1ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000Co
0000oooooooooooo0000Y?ooool009;ooooo00?o0000ooooooooool00_ooool3o`0000Coo`0000?o
0000oooooom4A4@00_l000000olb<S;o0000ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`000ol0
002Uooooo`00Toooool2o`0000;ooooo00?oV9RHob4Q8Ol000001?oo00000ol0003oooooooooo`02
ooooo`03ogMgMol0003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2U
ooooo`00UOooool01Ol0003ooooooooooonHV9So000000Coo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo1ol0002Wooooo`00U_ooool2o`000003ooooool0003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00omgMgOo0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`05ooooo`;o0000Z_ooool009Sooooo1ol000001_oooooo
0000ob4Q8Ol0003o<S8bo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0Z_ooool009[ooooo0_l00004oooo
o`05o`000?ooooooooooooooool000001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00_ooool2o`000:gooooo002Gooooo`04o`000?nj^[[ooooo
oiRHV0;o00000oooool01Ol0003ooooooooooooooooo000000Coo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00;o0000[oooool009Oooooo00KoV9RH
oa0@4?l0003o8B4Qolc<c?ooool2o`000003ooooool0003o000000?o00001?oo0002o`0000Cooooo
00?o0000ool00?oo00000_oo0003o`000;7ooooo002Oooooo`03o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko0000/oooool00:3ooooo0ol00000
0ooooooo0000ool00003ool00003o`000?oooooooooo00Cooooo0ol0002eooooo`00Xoooool7o`00
0003ooooool0003o000000?o0000^?ooool00:Cooooo00Co0000ool00?oo003oo`001?l0002loooo
o`00Y?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo0;cooooo002Tooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0_?ooool00:Cooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`2looooo`00Y?ooool7o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool009Sooooo00GoA4A4o`00
0?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00Voooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Looooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool00oooool00ol0003oooooooooo`2looooo`00Voooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool00oooool3o`000;cooooo002Hooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009So
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool0_?ooool009Sooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0_?ooool009Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Iooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`2looooo`00VOooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009[ooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009[ooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009[ooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;cooooo002Gooooo`Go00001?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o0000_Oooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002@ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`?o0000_?oo
ool009;ooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo0000
00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2looooo`00T_ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002@ooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00ooo
ool3o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool01Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?ooool00omE
EEGoIVIVo`000004ooooo`Go00001?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00Soooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00Soooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
T?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Gooooo0ol0002looooo`00TOooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Boooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000a?ooool009?ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`32ooooo`00Soooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0a?ooool008oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o
8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[o
oooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b
<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@
413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj
^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Oooool5o`0000Cooooo
1?l000000ol@413oooooooooo`2@ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@
41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0T_ooool007gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000017o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`000?oooooooooo
ooooool0003ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0T_oo
ool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
1Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooo
oonYZJWo000001?ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2Booooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo
00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0T_ooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo00?oEEEEofIVI_l00000U?ooool0093ooooo00?o410@oooooooo
ool0eOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
F
0 g
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
F
0 g
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .02472 L
.36 .02472 L
.36 0 L
F
0 g
.34 0 m
.34 .02472 L
.36 .02472 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .06489 L
.4 .06489 L
.4 0 L
F
0 g
.38 0 m
.38 .06489 L
.4 .06489 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .05562 L
.44 .05562 L
.44 0 L
F
0 g
.42 0 m
.42 .05562 L
.44 .05562 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .10507 L
.48 .10507 L
.48 0 L
F
0 g
.46 0 m
.46 .10507 L
.48 .10507 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .0958 L
.52 .0958 L
.52 0 L
F
0 g
.5 0 m
.5 .0958 L
.52 .0958 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .0958 L
.56 .0958 L
.56 0 L
F
0 g
.54 0 m
.54 .0958 L
.56 .0958 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
F
0 g
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04326 L
.64 .04326 L
.64 0 L
F
0 g
.62 0 m
.62 .04326 L
.64 .04326 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02781 L
.68 .02781 L
.68 0 L
F
0 g
.66 0 m
.66 .02781 L
.68 .02781 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
F
0 g
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
F
0 g
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
F
0 g
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.04 0 m
.04217 0 L
.04449 0 L
.04867 0 L
.05123 0 L
.05364 0 L
.05817 0 L
.06049 0 L
.06294 0 L
.06735 0 L
.0721 0 L
.07479 0 L
.07732 0 L
.08257 0 L
.08756 0 L
.09204 0 L
.09693 0 L
.10222 0 L
.10787 1e-05 L
.11319 1e-05 L
.11802 1e-05 L
.12273 1e-05 L
.12771 2e-05 L
.13195 2e-05 L
.13662 3e-05 L
.14164 4e-05 L
.14702 5e-05 L
.15673 8e-05 L
.16183 .0001 L
.16656 .00013 L
.17164 .00016 L
.17725 .0002 L
.18667 .0003 L
.19183 .00037 L
.19668 .00045 L
.20618 .00065 L
.21618 .00094 L
.22472 .00127 L
.23406 .00174 L
.24398 .0024 L
.253 .00316 L
.26341 .00428 L
.27324 .00562 L
.29257 .00921 L
.3104 .0139 L
.32852 .02024 L
.34846 .02917 L
.38743 .05186 L
.42493 .07643 L
.44401 .08763 L
Mistroke
.45408 .09268 L
.4648 .09718 L
.47019 .09905 L
.47526 .10055 L
.4802 .10176 L
.48473 .10264 L
.48906 .10327 L
.49123 .10351 L
.49362 .10372 L
.49487 .1038 L
.49602 .10386 L
.49665 .10388 L
.49733 .10391 L
.49858 .10393 L
.49975 .10395 L
.50099 .10394 L
.50205 .10392 L
.50321 .10389 L
.50439 .10384 L
.50549 .10378 L
.50798 .10359 L
.5104 .10334 L
.51299 .103 L
.51768 .1022 L
.52194 .10126 L
.53232 .09821 L
.5421 .09439 L
.57931 .07374 L
.61889 .04782 L
.63859 .03603 L
.657 .02652 L
.67581 .01857 L
.69365 .01271 L
.70305 .01023 L
.71329 .00797 L
.7312 .00498 L
.74027 .00385 L
.75028 .00286 L
.76074 .00206 L
.77057 .00149 L
.78005 .00108 L
.79004 .00075 L
.79857 .00054 L
.80791 .00038 L
.813 .0003 L
.81782 .00025 L
.82683 .00017 L
.83188 .00013 L
.83653 .00011 L
.84161 9e-05 L
Mistroke
.84706 7e-05 L
.85194 5e-05 L
.85641 4e-05 L
.86516 3e-05 L
.87005 2e-05 L
.87538 1e-05 L
.88042 1e-05 L
.88509 1e-05 L
.89 1e-05 L
.89531 0 L
.90032 0 L
.90493 0 L
.9091 0 L
.91368 0 L
.91845 0 L
.92291 0 L
.92769 0 L
.93038 0 L
.93288 0 L
.93746 0 L
.93977 0 L
.94232 0 L
.94671 0 L
.94918 0 L
.95144 0 L
.95561 0 L
.95771 0 L
.96 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
F
0 g
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01545 L
.3 .01545 L
.3 0 L
F
0 g
.28 0 m
.28 .01545 L
.3 .01545 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .03708 L
.38 .03708 L
.38 0 L
F
0 g
.36 0 m
.36 .03708 L
.38 .03708 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .06489 L
.42 .06489 L
.42 0 L
F
0 g
.4 0 m
.4 .06489 L
.42 .06489 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .07416 L
.46 .07416 L
.46 0 L
F
0 g
.44 0 m
.44 .07416 L
.46 .07416 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .11434 L
.5 .11434 L
.5 0 L
F
0 g
.48 0 m
.48 .11434 L
.5 .11434 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .08343 L
.54 .08343 L
.54 0 L
F
0 g
.52 0 m
.52 .08343 L
.54 .08343 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .08961 L
.58 .08961 L
.58 0 L
F
0 g
.56 0 m
.56 .08961 L
.58 .08961 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .03399 L
.62 .03399 L
.62 0 L
F
0 g
.6 0 m
.6 .03399 L
.62 .03399 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .0309 L
.66 .0309 L
.66 0 L
F
0 g
.64 0 m
.64 .0309 L
.66 .0309 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
F
0 g
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
F
0 g
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
F
0 g
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
.02 0 m
.02226 0 L
.02468 0 L
.02905 0 L
.03172 0 L
.03424 0 L
.03896 0 L
.04138 0 L
.04394 0 L
.04854 0 L
.0511 0 L
.05349 0 L
.05894 0 L
.06156 0 L
.06442 0 L
.06963 0 L
.0747 0 L
.07941 0 L
.08499 0 L
.09006 0 L
.09591 0 L
.10142 1e-05 L
.10611 1e-05 L
.11126 1e-05 L
.11664 2e-05 L
.12166 2e-05 L
.13064 3e-05 L
.13568 4e-05 L
.14028 5e-05 L
.14512 7e-05 L
.15027 8e-05 L
.15951 .00013 L
.16464 .00016 L
.16946 .0002 L
.1747 .00024 L
.18044 .00031 L
.19035 .00045 L
.20078 .00067 L
.21045 .00095 L
.21944 .00129 L
.23004 .00182 L
.24006 .00248 L
.24905 .00324 L
.25879 .00427 L
.27883 .00722 L
.28893 .00923 L
.30004 .0119 L
.31964 .01794 L
.3407 .02647 L
.38231 .0491 L
Mistroke
.42239 .07423 L
.44262 .08566 L
.46094 .09394 L
.47118 .0974 L
.47586 .09867 L
.48081 .09978 L
.48334 .10025 L
.48611 .10069 L
.48866 .10103 L
.49098 .10128 L
.49372 .1015 L
.49523 .10159 L
.49593 .10162 L
.49666 .10165 L
.49798 .10169 L
.4992 .10171 L
.50052 .10171 L
.50126 .1017 L
.50196 .10169 L
.50315 .10166 L
.50442 .10161 L
.50562 .10154 L
.50671 .10147 L
.50938 .10125 L
.5119 .10096 L
.51692 .10021 L
.52235 .0991 L
.53206 .09641 L
.54101 .09317 L
.55996 .08431 L
.58078 .0723 L
.6215 .04677 L
.66069 .02584 L
.68207 .01734 L
.70235 .01128 L
.71206 .00901 L
.72239 .00701 L
.74095 .0043 L
.75038 .0033 L
.76055 .00244 L
.77016 .00181 L
.77897 .00136 L
.78883 .00097 L
.79802 .0007 L
.8081 .00048 L
.81371 .00039 L
.81888 .00032 L
.82919 .00021 L
.83462 .00016 L
.84037 .00013 L
Mistroke
.85003 8e-05 L
.85553 6e-05 L
.86067 5e-05 L
.86568 4e-05 L
.87115 3e-05 L
.87631 2e-05 L
.8811 2e-05 L
.88576 1e-05 L
.89014 1e-05 L
.8952 1e-05 L
.89978 1e-05 L
.90447 0 L
.90963 0 L
.91501 0 L
.92003 0 L
.92474 0 L
.92902 0 L
.93397 0 L
.93866 0 L
.94329 0 L
.9484 0 L
.95097 0 L
.95373 0 L
.95612 0 L
.95874 0 L
.96346 0 L
.96604 0 L
.96843 0 L
.97273 0 L
.97513 0 L
.97731 0 L
.98 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00309 L
.24 .00309 L
.24 0 L
F
0 g
.22 0 m
.22 .00309 L
.24 .00309 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01545 L
.28 .01545 L
.28 0 L
F
0 g
.26 0 m
.26 .01545 L
.28 .01545 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
F
0 g
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05871 L
.4 .05871 L
.4 0 L
F
0 g
.38 0 m
.38 .05871 L
.4 .05871 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
F
0 g
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .09271 L
.48 .09271 L
.48 0 L
F
0 g
.46 0 m
.46 .09271 L
.48 .09271 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .10198 L
.52 .10198 L
.52 0 L
F
0 g
.5 0 m
.5 .10198 L
.52 .10198 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08961 L
.56 .08961 L
.56 0 L
F
0 g
.54 0 m
.54 .08961 L
.56 .08961 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
F
0 g
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .02472 L
.64 .02472 L
.64 0 L
F
0 g
.62 0 m
.62 .02472 L
.64 .02472 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
F
0 g
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
F
0 g
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00236 0 L
.00488 0 L
.00942 0 L
.0122 0 L
.01483 0 L
.01975 0 L
.02227 0 L
.02494 0 L
.02973 0 L
.03239 0 L
.03489 0 L
.04057 0 L
.0433 0 L
.04627 0 L
.0517 0 L
.05698 0 L
.06188 0 L
.0677 0 L
.07298 0 L
.07907 0 L
.08481 0 L
.0897 1e-05 L
.09506 1e-05 L
.10066 1e-05 L
.10589 1e-05 L
.11079 2e-05 L
.11525 2e-05 L
.12529 4e-05 L
.13033 5e-05 L
.1357 6e-05 L
.14533 9e-05 L
.15067 .00012 L
.15569 .00015 L
.16115 .00019 L
.16712 .00024 L
.17745 .00036 L
.18308 .00044 L
.18832 .00053 L
.19771 .00075 L
.20775 .00105 L
.2185 .00149 L
.23016 .00214 L
.24117 .00296 L
.25132 .00393 L
.27102 .00656 L
.28222 .00859 L
.29269 .01089 L
.31399 .01695 L
.33346 .02425 L
Mistroke
.37521 .04537 L
.41536 .06952 L
.43779 .08206 L
.4581 .09124 L
.46829 .09473 L
.47364 .09621 L
.47929 .0975 L
.48425 .09839 L
.48688 .09876 L
.48969 .09909 L
.49227 .09932 L
.49463 .09947 L
.49576 .09953 L
.497 .09957 L
.49816 .0996 L
.49924 .09961 L
.50048 .09961 L
.50178 .0996 L
.5029 .09957 L
.50412 .09953 L
.50544 .09947 L
.50684 .09938 L
.50937 .09918 L
.51194 .09891 L
.51435 .09859 L
.51887 .09786 L
.52429 .09672 L
.52927 .09544 L
.54052 .09176 L
.56026 .08305 L
.58195 .07111 L
.62436 .04562 L
.66518 .02483 L
.68746 .01647 L
.70858 .01059 L
.7187 .0084 L
.72946 .00648 L
.74879 .00392 L
.75861 .00298 L
.76921 .00218 L
.77921 .00161 L
.78839 .00119 L
.79867 .00085 L
.80824 .0006 L
.81874 .00041 L
.82462 .00033 L
.82996 .00027 L
.83505 .00022 L
.84043 .00017 L
.85008 .00012 L
Mistroke
.85545 9e-05 L
.86047 7e-05 L
.86594 6e-05 L
.87191 4e-05 L
.87757 3e-05 L
.88282 3e-05 L
.88784 2e-05 L
.89319 1e-05 L
.89844 1e-05 L
.90339 1e-05 L
.90784 1e-05 L
.91264 0 L
.91781 0 L
.92263 0 L
.92792 0 L
.93359 0 L
.93644 0 L
.93954 0 L
.94227 0 L
.94517 0 L
.95065 0 L
.95572 0 L
.96086 0 L
.96557 0 L
.96804 0 L
.97074 0 L
.97359 0 L
.97618 0 L
.98099 0 L
.98363 0 L
.98613 0 L
.99057 0 L
.99307 0 L
.99538 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Nooooo`go00001?oo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo1ol0000@ooooo`Ko00004?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo02Wooooo00?o
0000ool00?l000001_l00002ooooo`Oo00001Oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool01?l0003oo`00ool00?oo0008o`0000Goo`00
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`Co00009?ooool006Kooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03o`0000_ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1?l00002ool00003o`000?oo
oooooooo00;ooooo1ol0001eooooo`00I_ooool7o`0000Gooooo0ol00008ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo0006o`0000Goo`0000?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Rooooo`00MOooool3o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool01?l0
003oo`00ool00?oo0003o`0000Cooooo1ol0001Kooooo`03oa0@4?oooooooooo02;ooooo001hoooo
o`?o00000_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`04o`000?oo003o0000o`0000;oo`0000?o0000
ooooooooool0ROooool007_ooooo0ol00004ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1_l00005oooo
o`Oo0000Roooool007gooooo0_l00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00cooooo0_l0002Booooo`00
OOooool01_l0003oo`00o`000?l0003oo`00o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00[ooooo0_l0002Dooooo`00OOooool6o`0000Go
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0U?ooool008;ooooo0_l00004ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`07ooooo`;o0000Uoooool008Cooooo0_l0
0002ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`05ooooo`;o0000VOooool008Kooooo0ol00004ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool2o`0009_ooooo0028ooooo`;o00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0004o`000?ooooooooooooooo`;o0000WOooool008Sooooo00Ko0000ool00?l0003o0000ool00?l0
0005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00004o`000?ooooooooooo`0009oooooo0028ooooo`Ko00001Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0003o`000:3ooooo002>
ooooo`;o00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0002R
ooooo`00T?ooool2o`000003ooooool0003oo`0000Coo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Rooooo`00T_ooool:o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00Cooooo0_l0002Uooooo`00U?ooool02?l0003ooooo
oooooonHV9So8B4Qonk^k_ooooooA4A40_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool2o`000:Oooooo002Eooooo`;o000000CooooooiRH
V?lQ8B7ok^k^0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_l0002Yooooo`00Uoooool01Ol0003ooooooiRHV?lQ8B7ok^k^00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool000?o0000Zoooool009Sooooo0ol000001?mV
IVKoooooooooool00005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`000_l0002]ooooo`00Voooool4o`00
00Goo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?l000000_l000000ooo003o0000ooooo`2/ooooo`00Uoooool01Ol0003o
^[ZjoooooonHV9So410@00;ooooo0_l00004ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000[Oooool009Oooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c002ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;o0000]?ooool00:;ooooo1Ol00002ooooo`04o`000?oo003oo`00ool000Go0000]_ooool00:Ko
oooo2_l0002hooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00V?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002Kooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0_?ooool009cooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;cooooo002Kooooo`05ogMgMolb<S;oooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`?o0000_?ooool009Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`2looooo`00V?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool009Wooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0_?ooool009Wooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2looooo`00V_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00V_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00V_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0_?ooool009Oooooo1Ol00004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_l0002mooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool0093ooooo1?l000000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool01?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00
T_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000001Ol@413ooooo
ooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?o
oooo0ol0002looooo`00T_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l0
00001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool0093ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00Gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o
0000_?ooool009;ooooo00?o0000ooooooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`05ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmV
IVKo000000Cooooo1Ol00004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002?ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`000;cooooo002Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000034ooooo`00Toooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo0<;ooooo002?ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`34ooooo`00Soooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7o
c<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^ooo
ool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0
003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`Go00001Oooool2o`00
0003oa0@4?oooooooooo097ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005
ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000004Oooool0
0onHV9So8B4Qonk^kP04ooooo`Go0000Toooool007gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko
00002oooool00onHV9So8B4Qonk^kP03ooooo`04odA4A?oMgMgoooooo`0009Cooooo001mooooo`Go
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7Qooo
ooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000C
ooooo`03ogMgMomVIVKooooo00;ooooo00CogMgMoeEEEOoooooo0000U?ooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool04_ooool00ol0003oooooooooo`02ooooo`03ogMgMoo<
c<co000009Cooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo023ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^
k_m4A4Co000009Cooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool2o`0000Kooooo00?o0000ooooooooool04Oooool2o`0002;ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c005ooooo`03ogMgMol0003ooooo09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
F
0 g
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04017 L
.38 .04017 L
.38 0 L
F
0 g
.36 0 m
.36 .04017 L
.38 .04017 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
F
0 g
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .10198 L
.46 .10198 L
.46 0 L
F
0 g
.44 0 m
.44 .10198 L
.46 .10198 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .08034 L
.5 .08034 L
.5 0 L
F
0 g
.48 0 m
.48 .08034 L
.5 .08034 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .10816 L
.54 .10816 L
.54 0 L
F
0 g
.52 0 m
.52 .10816 L
.54 .10816 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .07416 L
.58 .07416 L
.58 0 L
F
0 g
.56 0 m
.56 .07416 L
.58 .07416 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04326 L
.62 .04326 L
.62 0 L
F
0 g
.6 0 m
.6 .04326 L
.62 .04326 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .02472 L
.66 .02472 L
.66 0 L
F
0 g
.64 0 m
.64 .02472 L
.66 .02472 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
F
0 g
.68 0 m
.68 .02472 L
.7 .02472 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00927 L
.78 .00927 L
.78 0 L
F
0 g
.76 0 m
.76 .00927 L
.78 .00927 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
F
0 g
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00054 0 L
.00554 0 L
.00838 0 L
.01105 0 L
.01642 0 L
.01943 0 L
.02219 0 L
.02502 0 L
.02804 0 L
.03347 0 L
.03679 0 L
.03992 0 L
.04578 0 L
.05139 0 L
.05655 0 L
.06222 0 L
.0682 0 L
.07361 0 L
.07855 1e-05 L
.08425 1e-05 L
.08965 1e-05 L
.09463 1e-05 L
.09924 2e-05 L
.10429 2e-05 L
.10967 3e-05 L
.1199 4e-05 L
.12565 5e-05 L
.13093 7e-05 L
.14065 .00011 L
.14554 .00013 L
.15089 .00016 L
.15666 .0002 L
.16211 .00025 L
.1723 .00037 L
.18328 .00055 L
.18947 .00069 L
.19518 .00083 L
.20577 .00118 L
.21567 .00161 L
.22654 .00223 L
.23821 .00311 L
.24927 .00418 L
.26133 .00569 L
.27285 .00751 L
.28328 .00953 L
.30481 .01495 L
.32773 .02283 L
.37154 .04382 L
.41369 .06815 L
Mistroke
.43508 .0797 L
.4464 .08503 L
.45852 .08989 L
.47022 .09357 L
.47575 .09492 L
.48087 .09594 L
.486 .09673 L
.4887 .09705 L
.49157 .09731 L
.49277 .0974 L
.49406 .09748 L
.49517 .09753 L
.49639 .09758 L
.49774 .09762 L
.49916 .09764 L
.50048 .09764 L
.5017 .09763 L
.5031 .0976 L
.50381 .09757 L
.50458 .09754 L
.50723 .0974 L
.50873 .09729 L
.51033 .09714 L
.51322 .09683 L
.5189 .09598 L
.52408 .09496 L
.53451 .09221 L
.54439 .08881 L
.56611 .0791 L
.58622 .0682 L
.62906 .04349 L
.67025 .02363 L
.69135 .01612 L
.70222 .01298 L
.71411 .01009 L
.73597 .00608 L
.7479 .0045 L
.759 .00335 L
.77048 .00243 L
.78132 .00176 L
.79105 .00131 L
.80161 .00093 L
.81192 .00065 L
.82328 .00044 L
.829 .00035 L
.83515 .00028 L
.84091 .00022 L
.84625 .00018 L
.8573 .00012 L
.86313 9e-05 L
Mistroke
.86935 7e-05 L
.87528 5e-05 L
.88086 4e-05 L
.89129 2e-05 L
.89638 2e-05 L
.90197 1e-05 L
.90779 1e-05 L
.91323 1e-05 L
.91833 1e-05 L
.92298 0 L
.92834 0 L
.93341 0 L
.93843 0 L
.94396 0 L
.94975 0 L
.95517 0 L
.96022 0 L
.96485 0 L
.96994 0 L
.97529 0 L
.9781 0 L
.98076 0 L
.98572 0 L
.98851 0 L
.99107 0 L
.99406 0 L
.99686 0 L
Mfstroke
.99686 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Sooooo`[o00000_ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`003?l00005ooooo`Oo00005Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo02Cooooo1_l0
0003ooooo`?o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0000Gooooo1_l0000Qooooo`03o`000?oooooooooo02Cooooo1?l0
000Tooooo`00K?ooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo000<o`0007_ooooo001aoooo
o`Go000000?oooooo`000?oo00001?oo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00o`000003o`00067ooooo00?o0000ooooooooool08_ooool007Kooooo0ol00004ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool3o`0000?oo`0000?o0000oooooooo
ool0Goooool00ol@413oooooooooo`0Rooooo`00Moooool01?l0003oo`00o`000?l00002ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooool000000_l000000ooooooo0000ool00003ool00003
o`000?oooooooooo08Cooooo001gooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo2?l00004ooooo`Ko0000Q_ooool007gooooo0_l00003ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`06ooooo`;o0000T_ooool007oooooo0_l000000ooooooo0000ool00004
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00Cooooo0_l0002Dooooo`00POooool2o`0000Goo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool2o`0009Kooooo0022ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_l0002Hooooo`00QOooool2o`0000Kooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool9o`0009[ooooo0027ooooo`;o00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Oooooo0_l0
002Looooo`00ROooool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Kooooo00?o0000ooooooooool0W?oo
ool008[ooooo0_l000000ooooooo0000o`000005o`0000Gooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`04ooooo`;o0000Woooool008cooooo0_l0000;ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool2o`000:7ooooo002>ooooo`03o`000?oooooooooo00So
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00005o`000?ooooooooooooooool00000Xoooool008oooooo0_l00008ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000Co0000ooooool0003o0000Y?ooool0097ooooo0_l00004ooooo`?o
00001?oo00000ol0003oooooodA4A002o`000003oc8b<_l0003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo0002o`000:Kooooo002Cooooo`;o00000_ooool00onHV9So8B4Qo`000004ool00003o`00
0?oooooooooo00;ooooo00?oMgMgo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool01?l0003oo`00ool00?oo0003o`000:Oo
oooo002Eooooo`;o000000?ooooooiRHV?l000001?oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`000ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool7o`000:Oooooo002Gooooo`?o00001?oo00000ol0003oooooooooo`02ooooo`03ogMgMol0
003o000000Co00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Cooooo0_l0
002[ooooo`00VOooool00ol0003oo`00ool00002ool00007o`000?oooooo0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`02ooooo`;o0000[Oooool009Wooooo1?l000001?oo003o0000ooooool00008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`02o`000:oooooo
002Gooooo`03o`000?nj^[[o000000?oo`001?l00008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo0003o`000;7ooooo002Gooooo`03oiRHV?l@413o000000Coo`0000?o0000
ooooool000000ol00005ooooo`;o00001?ooool6o`000;?ooooo002Iooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool<o`0000Coo`0000?o0000ooooooooool0/Oooool009Wo
oooo1_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`2aooooo`00ZOooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0/Oooool00:Wooooo0_l00004ooooo`Ko0000/oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Hooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009_ooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00W?ooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0_?ooool009_ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo0ol0002looooo`00V?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002H
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00VOoo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooo
ooooo`2looooo`00VOooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0_?ooool009Wooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool00oooool3o`000;cooooo002Jooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00
Uoooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`000;gooooo
002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00T?ooool4o`000003oa0@4?oooooooooo00Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Booooo`03o`00
0?oooooooooo00Gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool00oooool3o`000;co
oooo002Booooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000005ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00T?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool01?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool01Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00
T_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?oo
ool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool008oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool008oooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0093ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`?o0000_?ooool0097ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Co
oooo002Cooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0`_ooool008oooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002?
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00
R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo
0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00gooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko
0000ooooooooooooooooo`000?ooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo097ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Aooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool0T?ooool007gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo097ooooo001mooooo`Go
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7Qooo
ooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000C
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c02Booooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0U?ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool0U?ooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l0002Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01545 L
.28 .01545 L
.28 0 L
F
0 g
.26 0 m
.26 .01545 L
.28 .01545 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02163 L
.32 .02163 L
.32 0 L
F
0 g
.3 0 m
.3 .02163 L
.32 .02163 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .01854 L
.36 .01854 L
.36 0 L
F
0 g
.34 0 m
.34 .01854 L
.36 .01854 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05871 L
.4 .05871 L
.4 0 L
F
0 g
.38 0 m
.38 .05871 L
.4 .05871 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .07416 L
.44 .07416 L
.44 0 L
F
0 g
.42 0 m
.42 .07416 L
.44 .07416 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .0958 L
.48 .0958 L
.48 0 L
F
0 g
.46 0 m
.46 .0958 L
.48 .0958 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .07725 L
.52 .07725 L
.52 0 L
F
0 g
.5 0 m
.5 .07725 L
.52 .07725 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .10198 L
.56 .10198 L
.56 0 L
F
0 g
.54 0 m
.54 .10198 L
.56 .10198 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05871 L
.6 .05871 L
.6 0 L
F
0 g
.58 0 m
.58 .05871 L
.6 .05871 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .0309 L
.64 .0309 L
.64 0 L
F
0 g
.62 0 m
.62 .0309 L
.64 .0309 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
F
0 g
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01545 L
.72 .01545 L
.72 0 L
F
0 g
.7 0 m
.7 .01545 L
.72 .01545 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
F
0 g
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
F
0 g
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00095 0 L
.00381 0 L
.00675 0 L
.00989 0 L
.01552 0 L
.01898 0 L
.02223 0 L
.02519 0 L
.02831 0 L
.03413 0 L
.03949 0 L
.04526 0 L
.05159 0 L
.05754 0 L
.06317 0 L
.06822 0 L
.07372 1e-05 L
.07969 1e-05 L
.08604 1e-05 L
.09145 2e-05 L
.09743 2e-05 L
.10301 3e-05 L
.10888 4e-05 L
.11937 6e-05 L
.12523 7e-05 L
.13067 9e-05 L
.1366 .00012 L
.14302 .00016 L
.14923 .0002 L
.15496 .00025 L
.16622 .00037 L
.17646 .00054 L
.1873 .00077 L
.198 .00109 L
.2095 .00156 L
.22035 .00214 L
.23027 .00283 L
.24146 .00381 L
.25184 .00497 L
.26396 .00665 L
.27536 .00862 L
.29867 .01402 L
.31979 .0207 L
.36356 .0401 L
.41012 .06579 L
.43332 .07793 L
.44465 .0831 L
.45496 .08719 L
.46494 .09048 L
Mistroke
.47578 .09322 L
.48174 .09432 L
.48435 .0947 L
.48724 .09506 L
.48977 .09532 L
.4925 .09553 L
.494 .09562 L
.49538 .09569 L
.49669 .09574 L
.49808 .09577 L
.49948 .09578 L
.50028 .09578 L
.50101 .09578 L
.50235 .09576 L
.50377 .09572 L
.50504 .09567 L
.50623 .09561 L
.50893 .09543 L
.51185 .09516 L
.51452 .09485 L
.52051 .09394 L
.52563 .09291 L
.53121 .09156 L
.54135 .08849 L
.56375 .07933 L
.58756 .06707 L
.63033 .0433 L
.65409 .03144 L
.67589 .02229 L
.69723 .01518 L
.7081 .01225 L
.71972 .0096 L
.73143 .0074 L
.74208 .00576 L
.75219 .00449 L
.7629 .0034 L
.7742 .0025 L
.78463 .00185 L
.79585 .00132 L
.8082 .0009 L
.81971 .00061 L
.83023 .00042 L
.83604 .00034 L
.84237 .00027 L
.85391 .00018 L
.85995 .00014 L
.86563 .00011 L
.87624 7e-05 L
.88219 5e-05 L
.88767 4e-05 L
Mistroke
.89368 3e-05 L
.90003 2e-05 L
.90566 2e-05 L
.91079 1e-05 L
.91671 1e-05 L
.92231 1e-05 L
.92749 1e-05 L
.93228 0 L
.93753 0 L
.94311 0 L
.94866 0 L
.95375 0 L
.95933 0 L
.96521 0 L
.97034 0 L
.97511 0 L
.98035 0 L
.98594 0 L
.98888 0 L
.99199 0 L
.99757 0 L
Mfstroke
.99757 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Qooooo`Wo00001Ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo3?l00005ool00003o`000?oooooooooo01Wooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Yooooo`So00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooo`000009o`0000Cooooo1ol0000Kooooo`03o`000?oo
oooooooo02Cooooo1?l0000Tooooo`00I_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
000000?o00001Ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`So0000Ooooool006Kooooo1ol00004oooo
o`?o00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`09o`0005_ooooo00?o0000ooooooooool08_ooool0077o
oooo00?o0000ool00?oo00001?l00005ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0003o`0006Cooooo00?o410@oooooooo
ool08_ooool0077ooooo2?l0000?ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00004o`0008_ooooo001iooooo`?o00003?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo0ol00003ool00003o`000?oooooooooo08Wooooo001l
ooooo`;o00002_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool6o`0000Cooooo2?l0002;ooooo`00O_ooool2o`0000Sooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00_ooooo0_l0002Coooo
o`00P?ooool3o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00Wooooo0_l0002Eooooo`00Poooool2o`0000?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Oooooo0_l0002Gooooo`00QOoo
ool2o`000003ooooool0003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`05ooooo`;o0000VOooool008Oooooo0_l00004ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool2o`0009_ooooo0028ooooo`?o00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00;ooooo00?o0000ooooooooool0Voooool008Sooooo00Ko0000ool00?oo
003o0000ool00?l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00;o0000W_ooool008Sooooo1_l00005oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool8o`000:3ooooo002>ooooo`;o
00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0X?ooool0093ooooo0_l000000ooooooo0000ool00004ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Kooooo
0_l0002Sooooo`00T_ooool2o`0000Goo`000ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`04ooooo`;o0000YOooool009?ooooo0_l00004
ool00003o`000?ooooooA4A400;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00004o`000?ooooooooooooooo`?o0000Yoooool009?ooooo1ol000001Oo^k^kooooooooooooo
oooo000000Goo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo00000ooo
00001?l0003oooooo`000?l0002Zooooo`00Uoooool3o`000005ob4Q8Oo^k^koooooooooool00000
1Ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo0000
0ooo0002o`000:cooooo002Jooooo`?o000000?oooooo`000?oo00001?oo00000ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00Co0000ool00?oo003oo`000ol0002]ooooo`00Vooo
ool01?l0003oooooo`000?l00005ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool01?l0003oo`00o`000?l00002ool00003o`000?oooooooooo0:_ooooo002Gooooo`05o`00
0?nj^[[ooooooiRHV?l@41000_ooool4o`0000;oo`0000?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`Go00001?oo00000ol0003oooooooooo`2[ooooo`00Uoooool01OnHV9So410@
o`000?lQ8B7oc<c<00;ooooo00Co0000ool00?oo003oo`001Ol00002ooooo`;o00000_ooool4o`00
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2[ooooo`00W_ooool7o`0000;o
oooo1_l00007ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Zoooool00:Wooooo
00?o0000ooooooooool02?ooool7o`000:gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002H
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool009_ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00W?ooool01?l0003oooooooooool@4103oooo
o`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool009_ooooo00GoMgMgoc8b<_oo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0002looooo`00V?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00VOooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00VOooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009Wooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Jooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;co
oooo002Jooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000Cooooo1?l00005ooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`000;gooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000003oa0@4?oooooooooo00Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
0oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?ooool0
0omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?oo
ool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Kooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
T?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00T?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool01?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?oo
ool0093ooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool008oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool0097ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0034ooooo`00T_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo00000<Cooooo002Cooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0`_ooool008oooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg0<Cooooo002?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOoo
ool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o
^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo
00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00go
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Toooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<
c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Toooool007go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo0000017ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooo
oooooooo000009?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000_ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003oV9RHoooooonHV9So8B4Q09?ooooo001mooooo`Go00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`00
0004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02Cooooo`00OOooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0Booooo`06o`000?oooooooooooooooomEEEGoQhN7U_ooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00?ogMgMoa0@4?nHV9P0UOoo
ool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_oo
ool00ol0003oooooooooo`0Aooooo`;o00008_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00Coc<c<odA4A?l0003o410@Toooool0093ooooo00?o410@ooooooooool0eOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00309 L
.3 .00309 L
.3 0 L
F
0 g
.28 0 m
.28 .00309 L
.3 .00309 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .03708 L
.34 .03708 L
.34 0 L
F
0 g
.32 0 m
.32 .03708 L
.34 .03708 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .02781 L
.38 .02781 L
.38 0 L
F
0 g
.36 0 m
.36 .02781 L
.38 .02781 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .07416 L
.42 .07416 L
.42 0 L
F
0 g
.4 0 m
.4 .07416 L
.42 .07416 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .08343 L
.46 .08343 L
.46 0 L
F
0 g
.44 0 m
.44 .08343 L
.46 .08343 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .08961 L
.5 .08961 L
.5 0 L
F
0 g
.48 0 m
.48 .08961 L
.5 .08961 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .07725 L
.54 .07725 L
.54 0 L
F
0 g
.52 0 m
.52 .07725 L
.54 .07725 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .08961 L
.58 .08961 L
.58 0 L
F
0 g
.56 0 m
.56 .08961 L
.58 .08961 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04635 L
.62 .04635 L
.62 0 L
F
0 g
.6 0 m
.6 .04635 L
.62 .04635 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .03399 L
.66 .03399 L
.66 0 L
F
0 g
.64 0 m
.64 .03399 L
.66 .03399 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02163 L
.7 .02163 L
.7 0 L
F
0 g
.68 0 m
.68 .02163 L
.7 .02163 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00309 L
.74 .00309 L
.74 0 L
F
0 g
.72 0 m
.72 .00309 L
.74 .00309 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
F
0 g
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00116 0 L
.00453 0 L
.0076 0 L
.01084 0 L
.01688 0 L
.02244 0 L
.02842 0 L
.03182 0 L
.03499 0 L
.04087 0 L
.04728 0 L
.05332 0 L
.05892 0 L
.06395 1e-05 L
.0695 1e-05 L
.0753 1e-05 L
.08074 1e-05 L
.08626 2e-05 L
.0923 2e-05 L
.09861 3e-05 L
.10448 4e-05 L
.115 7e-05 L
.12089 8e-05 L
.12624 .0001 L
.13194 .00013 L
.13798 .00017 L
.1488 .00025 L
.15482 .00031 L
.16045 .00038 L
.16658 .00047 L
.17326 .00059 L
.1855 .00087 L
.19712 .00125 L
.20843 .00175 L
.21891 .00235 L
.23137 .00328 L
.2431 .00442 L
.26499 .0074 L
.2765 .0095 L
.28865 .01218 L
.31039 .0183 L
.33353 .02679 L
.35511 .03645 L
.40092 .06054 L
.42427 .07274 L
.43657 .07854 L
.44963 .08395 L
.46123 .08792 L
.46738 .08966 L
Mistroke
.47401 .09123 L
.48008 .09238 L
.48274 .09278 L
.48564 .09317 L
.48821 .09345 L
.49096 .09368 L
.49248 .09379 L
.49385 .09387 L
.49524 .09393 L
.49655 .09398 L
.49791 .09401 L
.49937 .09402 L
.50075 .09402 L
.50201 .09401 L
.50348 .09398 L
.50432 .09395 L
.50509 .09392 L
.50659 .09384 L
.50801 .09376 L
.5108 .09354 L
.51388 .09322 L
.52013 .09234 L
.52557 .09132 L
.53057 .09018 L
.54184 .08695 L
.56407 .07826 L
.5884 .06625 L
.63606 .04082 L
.65807 .03037 L
.68194 .02089 L
.70702 .01327 L
.71829 .01059 L
.73071 .00814 L
.74196 .00632 L
.75405 .00474 L
.76683 .00344 L
.77879 .0025 L
.79068 .00179 L
.80366 .00122 L
.81592 .00083 L
.82729 .00057 L
.83327 .00047 L
.83973 .00038 L
.84543 .00031 L
.85145 .00025 L
.85688 .0002 L
.86285 .00016 L
.87333 .00011 L
.8795 8e-05 L
.88535 6e-05 L
Mistroke
.89629 4e-05 L
.90242 3e-05 L
.90808 2e-05 L
.9143 2e-05 L
.9209 1e-05 L
.92665 1e-05 L
.93193 1e-05 L
.93772 1e-05 L
.94381 0 L
.94913 0 L
.95408 0 L
.95951 0 L
.96531 0 L
.97159 0 L
.97737 0 L
.98372 0 L
.98692 0 L
.99043 0 L
.99634 0 L
.99966 0 L
Mfstroke
.99966 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Nooooo`co00001Oooool6o`0000Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko00000_ooool:o`0000Cooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool09?ooool00ol0003oo`00ool0
0002ool000Go00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool01?ooool7o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`Oo00005Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool0067ooooo1_l00004
ooooo`Ko00001_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`?o00002_oo
ool6o`00073ooooo001aooooo`?o00000oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`001?l0001Nooooo`03o`000?oooooo
oooo02;ooooo001dooooo`Co00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?l000000ol0001Qooooo`03oa0@4?oooooooooo02;ooooo001gooooo`?o
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00004o`000?ooooooooooooooo`So0000Q_ooool007Oo
oooo00?o0000ool00?oo00001?l00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool000Co0000S_ooool007Oooooo00?o0000ool00?oo0000
0ooo0002o`0000?ooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00Co0000ool00?oo003oo`000ol0002Aooooo`00Moooool00ol0003oo`00
ool00003ool00004o`000?oooooo0000o`0000cooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0002Aooooo`00Moooool7o`0000?ooooo
0_l0000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`;o0000U_ooool008?ooooo0_l00008ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02o`0009Sooooo0025ooooo`;o00001_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`000ol0002Jooooo`00Qoooool2o`00
00Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`Oo0000W?ooool008Wooooo00Go0000ooooooooooooooooo`000005ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`05oooo
o`;o0000W_ooool008[ooooo0_l000000ooooooo0000ool00004ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`04ooooo`03o`000?oooooooooo09ko
oooo002<ooooo`;o00001Ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool2o`000:7ooooo002=ooooo`?o00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02o`000:?ooooo002=ooooo`03o`000?oo003o
o`0000;o000000?oo`00o`000?ooool01?ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool000?o0000YOooool0
08gooooo00?o0000ool00?oo00000_oo0002o`0000?ooooo0ol00004ool00003o`000?ooooooA4A4
00;o000000?o<S8bo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o0000Yoooool008go
oooo00?o0000ool00?oo00000ooo0003o`000004oooooonHV9So8B4Qo`0000Coo`0000?o0000oooo
ooooool00_ooool00omgMgOo0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`00
002Wooooo`00SOooool7o`0000;ooooo0_l000000onHV9So0000ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0003o`0000?ooooo1_l00005ooooo`04o`000?oo003o
0000o`0000;oo`0000?o0000ooooooooool0YOooool009Sooooo0ol00003ool00003o`000?oooooo
oooo00;ooooo00?oMgMgo`000?oo00000ooo00000ol0003oooooooooo`0>ooooo`;o00001?oo0000
0ol0003oooooooooo`2Uooooo`00VOooool6o`000006ooooool0003o8B4Qo`000?lb<S;o00001?oo
00000ol0003oooooooooo`0;ooooo`Co00001Ooo00000ol0003oooooooooo`2Uooooo`00Voooool0
0ol0003oooooooooo`03o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08
ooooo`?o00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0:Gooooo002Goooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool:o`0000Kooooo1?l00006ooooo`Oo0000Yoooool0
09Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooooa3o0000^?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool009Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00Voooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Looooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool00oooool00ol0003oooooooooo`2looooo`00Voooool01Omg
MgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool00oooool3o`000;cooooo002Hoooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0_?ooool009Sooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00VOooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool0
09[ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009[o
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0_?ooool009[ooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00001?ooool4o`0000Gooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000_Oooool0093ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000?o410@oooo
ooooool01Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01Oooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo
002@ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002@ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool0
1_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
0;cooooo002@ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002@ooooo`Co000000?o410@
ooooooooool00_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2looooo`00T?ooool00omEEEGoIVIVo`000004ooooo`Go00001?ooool4o`0000Gooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00Sooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`2looooo`00Soooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00T?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00TOooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo00000<Cooooo002Booooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009?ooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`32oooo
o`00Soooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool008oooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Co
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@
ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo
0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o
0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
QhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool0
00001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool03Oooool5o`0000Gooooo00?o0000onk^k_ooool0Toooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<
c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03oeEEEOnYZJWooooo09?ooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000Aooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoeEEEOooool0Toooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02ooo
ool01_l0003ooooooooooooooooo0000ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06ooooo`03
ob4Q8Ooooooooooo09;ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_o
oooo00Go0000ohN7QoooooooZJVYo`00000Cooooo`03ogMgMomVIVKooooo00Gooooo00?oEEEEolc<
c?ooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03ojVYZOmgMgOooooo09;ooooo001mooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05oa0@4?oooooooooooooooolb<S80Toooool007cooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003ooooooooo
o`0Aooooo`;o00008_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo1Ol0002Cooooo`00T?oo
ool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
F
0 g
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01854 L
.32 .01854 L
.32 0 L
F
0 g
.3 0 m
.3 .01854 L
.32 .01854 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04944 L
.36 .04944 L
.36 0 L
F
0 g
.34 0 m
.34 .04944 L
.36 .04944 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .03708 L
.4 .03708 L
.4 0 L
F
0 g
.38 0 m
.38 .03708 L
.4 .03708 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .07725 L
.44 .07725 L
.44 0 L
F
0 g
.42 0 m
.42 .07725 L
.44 .07725 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
F
0 g
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .08652 L
.52 .08652 L
.52 0 L
F
0 g
.5 0 m
.5 .08652 L
.52 .08652 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .07725 L
.56 .07725 L
.56 0 L
F
0 g
.54 0 m
.54 .07725 L
.56 .07725 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .07416 L
.6 .07416 L
.6 0 L
F
0 g
.58 0 m
.58 .07416 L
.6 .07416 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .03399 L
.64 .03399 L
.64 0 L
F
0 g
.62 0 m
.62 .03399 L
.64 .03399 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .03708 L
.68 .03708 L
.68 0 L
F
0 g
.66 0 m
.66 .03708 L
.68 .03708 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00927 L
.72 .00927 L
.72 0 L
F
0 g
.7 0 m
.7 .00927 L
.72 .00927 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
F
0 g
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00137 0 L
.00462 0 L
.01126 0 L
.01492 0 L
.01838 0 L
.02397 0 L
.03014 0 L
.03658 0 L
.04263 0 L
.04826 0 L
.05342 1e-05 L
.05909 1e-05 L
.06506 1e-05 L
.07115 1e-05 L
.07669 2e-05 L
.08308 2e-05 L
.08911 3e-05 L
.09984 5e-05 L
.1059 6e-05 L
.11148 8e-05 L
.11717 .0001 L
.12329 .00012 L
.13433 .00018 L
.14107 .00024 L
.14747 .0003 L
.15377 .00037 L
.15947 .00045 L
.17118 .00066 L
.18364 .00097 L
.19519 .00137 L
.20606 .00187 L
.21798 .00258 L
.23056 .00358 L
.2413 .00466 L
.25307 .00613 L
.27688 .01022 L
.29023 .01328 L
.30237 .01659 L
.35097 .03509 L
.39772 .05871 L
.42138 .07071 L
.43393 .0765 L
.44745 .08199 L
.46036 .08631 L
.466 .08787 L
.47217 .08933 L
.47764 .09039 L
.48347 .09128 L
.48669 .09166 L
Mistroke
.48962 .09194 L
.49104 .09204 L
.49257 .09214 L
.49399 .09222 L
.49534 .09228 L
.49685 .09232 L
.49823 .09235 L
.49971 .09236 L
.50054 .09236 L
.50132 .09236 L
.50261 .09234 L
.50403 .0923 L
.50551 .09224 L
.5069 .09217 L
.51009 .09196 L
.51301 .09169 L
.5196 .09085 L
.52556 .0898 L
.53209 .08835 L
.54525 .08456 L
.5691 .07515 L
.59461 .0627 L
.64512 .03692 L
.67042 .02594 L
.69377 .01775 L
.7165 .01166 L
.72811 .00923 L
.74059 .00706 L
.75302 .00533 L
.7644 .00405 L
.77519 .00309 L
.78669 .00228 L
.7987 .00163 L
.80984 .00118 L
.82308 .00079 L
.83508 .00054 L
.84103 .00044 L
.84731 .00035 L
.85854 .00024 L
.8648 .00019 L
.87064 .00015 L
.877 .00012 L
.88391 9e-05 L
.89053 7e-05 L
.89665 5e-05 L
.90239 4e-05 L
.90872 3e-05 L
.91399 3e-05 L
.91968 2e-05 L
.92569 2e-05 L
Mistroke
.93132 1e-05 L
.93737 1e-05 L
.94299 1e-05 L
.94916 0 L
.95575 0 L
.96268 0 L
.96922 0 L
.97509 0 L
.98146 0 L
.98742 0 L
.993 0 L
.99911 0 L
Mfstroke
.99911 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
F
0 g
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
F
0 g
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00309 L
.3 .00309 L
.3 0 L
F
0 g
.28 0 m
.28 .00309 L
.3 .00309 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .03399 L
.34 .03399 L
.34 0 L
F
0 g
.32 0 m
.32 .03399 L
.34 .03399 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04944 L
.38 .04944 L
.38 0 L
F
0 g
.36 0 m
.36 .04944 L
.38 .04944 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
F
0 g
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .0958 L
.46 .0958 L
.46 0 L
F
0 g
.44 0 m
.44 .0958 L
.46 .0958 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .07107 L
.5 .07107 L
.5 0 L
F
0 g
.48 0 m
.48 .07107 L
.5 .07107 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .09889 L
.54 .09889 L
.54 0 L
F
0 g
.52 0 m
.52 .09889 L
.54 .09889 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
F
0 g
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
F
0 g
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .03708 L
.66 .03708 L
.66 0 L
F
0 g
.64 0 m
.64 .03708 L
.66 .03708 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02781 L
.7 .02781 L
.7 0 L
F
0 g
.68 0 m
.68 .02781 L
.7 .02781 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
F
0 g
.72 0 m
.72 .00618 L
.74 .00618 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
F
0 g
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00177 0 L
.00755 0 L
.01393 0 L
.0206 0 L
.02686 0 L
.03268 0 L
.03803 0 L
.04389 1e-05 L
.05007 1e-05 L
.05637 1e-05 L
.06209 1e-05 L
.0687 2e-05 L
.07494 2e-05 L
.08072 3e-05 L
.08604 4e-05 L
.09808 6e-05 L
.10397 7e-05 L
.1103 9e-05 L
.12172 .00015 L
.1287 .00019 L
.13531 .00024 L
.14183 .0003 L
.14773 .00037 L
.15984 .00054 L
.16648 .00067 L
.17274 .00082 L
.18388 .00114 L
.19592 .0016 L
.20793 .00223 L
.22109 .00313 L
.23483 .00438 L
.24765 .00588 L
.26085 .00784 L
.27334 .01012 L
.29674 .01569 L
.32188 .02373 L
.3451 .03304 L
.39464 .05704 L
.41951 .06926 L
.44227 .079 L
.45395 .0831 L
.4667 .08668 L
.47334 .08814 L
.47952 .08921 L
.48604 .09005 L
.48969 .09038 L
.4914 .0905 L
.493 .0906 L
.49452 .09067 L
Mistroke
.49592 .09072 L
.49746 .09076 L
.49912 .09078 L
.50072 .09078 L
.50162 .09077 L
.50245 .09076 L
.50398 .09072 L
.50561 .09067 L
.50697 .0906 L
.50845 .09051 L
.51112 .09032 L
.5143 .09001 L
.51722 .08967 L
.52331 .08875 L
.52998 .08745 L
.54344 .08392 L
.56812 .0748 L
.5945 .06249 L
.64675 .03668 L
.67293 .02566 L
.69709 .01747 L
.7206 .0114 L
.73261 .00898 L
.74551 .00684 L
.75838 .00513 L
.77015 .00388 L
.78131 .00294 L
.79321 .00216 L
.80563 .00154 L
.81715 .0011 L
.82421 .00089 L
.83085 .00073 L
.83677 .00061 L
.84327 .00049 L
.85558 .00033 L
.86231 .00026 L
.86859 .00021 L
.87983 .00014 L
.88613 .00011 L
.89187 9e-05 L
.89793 7e-05 L
.90437 5e-05 L
.90994 4e-05 L
.91593 3e-05 L
.92235 2e-05 L
.92837 2e-05 L
.93554 1e-05 L
.9421 1e-05 L
.94808 1e-05 L
.95446 1e-05 L
Mistroke
.96049 0 L
.96596 0 L
.9724 0 L
.97938 0 L
.98598 0 L
.99205 0 L
.99795 0 L
Mfstroke
.99795 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Iooooo`co00001?oo00000ol0003ooooo
ooooo`03ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00001?l0003oooooooooooooool:o`0000?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool08_ooool003[ooooo00?o0000ooooooooool09?ooool9o`0000Oooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo2Ol00002ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0001Gooooo00?o0000ooooooooool0
9?ooool4o`0002Cooooo001Zooooo`Go00002?ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00004o`000?oo
ooooooooooooo`Co00002Oooool6o`00073ooooo001_ooooo`Go00000oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`001?l0
001Nooooo`03o`000?oooooooooo02;ooooo001dooooo`Co00001Ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ol0001Qooooo`03oa0@4?oooooo
oooo02;ooooo001gooooo`?o00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo0ol00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000;o
000000?oo`00o`000?ooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`04o`0000Coo`0000?o0000oooooooo
ool0Q?ooool007Oooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0003o`0000?ooooo1_l00026ooooo`00Mooo
ool9o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000Co0000TOooool0083ooooo0ol00005ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0002A
ooooo`00P_ooool2o`0000Coo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000Co0000oooooooooooooooo0_l0002Gooooo`00P_ooool01?l0
003oo`00o`000?l00002ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00004o`000?oooooo0000o`0009Wooooo0022ooooo`04o`000?oo003o
o`00ool000?o00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l0
0004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0002o`0009_ooooo0022
ooooo`So00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000W?ooool008[ooooo0_l000000ooo
oooo0000o`000005o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`04oooo
o`;o0000Woooool008cooooo0_l0000;ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool2o`000:7ooooo002>ooooo`?o00002?ooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`Oo00000_ooool2o`000:?ooooo002Aooooo`;o00001_oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02_oo
ool2o`000:Gooooo002Cooooo`;o00000_ooool3o`0000Coo`0000?o0000oooooom4A4@00_l00000
0olb<S;o0000ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`08ooooo`;o0000Yoooool009Gooooo0_l000000onHV9So8B4Qo`000004ool0
0003o`000?oooooooooo00;ooooo00?oMgMgo`000?l000001?l00005ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool01_ooool2o`000:Wooooo002Gooooo`?o00001?oo00000ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool3o`000:_ooooo002Iooooo`?o00000_oo00000ol0003ooooo
ooooo`02ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?o0000[_ooool009Wooooo00?o0000ool00?oo00000ol0
00001_oooooo0000ob4Q8Ol0003o<S8bolc<c0Cooooo00?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool000?o0000/Oooool009Wooooo00?o0000ool00?oo00000_oo0006o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oo`00o`000003o`000;?ooooo002Gooooo`03o`000?nj
^[[o000000Coo`0000?o0000ooooool000000oooool=o`0000?oo`0000?o0000ooooooooool0/Ooo
ool009Oooooo00?oV9RHoa0@4?l000001?oo00000ol0003oooooo`000003o`0000Gooooo0_l00004
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0/Oooool009Wooooo1_l0000:oooo
o`03o`000?oooooooooo00?ooooo1_l0002cooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Kooooo`09ogMg
Molb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09cooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0;cooooo002Kooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03
ooooo`?o0000_?ooool009Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool0
0ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`2looooo`00V?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
_?ooool009Wooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo0;cooooo002Iooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2looooo`00V_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0002looooo`00V_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo
1Ol00004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Go
oooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
093ooooo1?l000000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003ooooo
ooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool0093ooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00
T_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool0093ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00Cooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Go
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo
00?o0000ooooooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol0
0004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002?ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002?ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool3o`000;cooooo002Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00
Toooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo0<;ooooo002?ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo
0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o0000
00Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0=ooooo`Go00000oooool01?l@413o0000odA4A?o<c<bD
ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooo
oooooooo0000ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?oV9RHoa0@
4?oMgMd0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo0000017ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00on7QhOoEEEEooooo`2Booooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000;oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002Cooooo`00OOooool5o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?n7QhOooooo
ojVYZOl000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl000004ooo
ool00omgMgOoIVIVooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l00000Toooool007gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool04_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool0TOooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@2Cooooo`00O?ooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000R
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo<c<co410@o`000?lb<S;ok^k^09?ooooo
002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
F
0 g
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
F
0 g
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
F
0 g
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04635 L
.36 .04635 L
.36 0 L
F
0 g
.34 0 m
.34 .04635 L
.36 .04635 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .03708 L
.4 .03708 L
.4 0 L
F
0 g
.38 0 m
.38 .03708 L
.4 .03708 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .08343 L
.44 .08343 L
.44 0 L
F
0 g
.42 0 m
.42 .08343 L
.44 .08343 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
F
0 g
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .08034 L
.52 .08034 L
.52 0 L
F
0 g
.5 0 m
.5 .08034 L
.52 .08034 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08652 L
.56 .08652 L
.56 0 L
F
0 g
.54 0 m
.54 .08652 L
.56 .08652 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .04944 L
.6 .04944 L
.6 0 L
F
0 g
.58 0 m
.58 .04944 L
.6 .04944 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04326 L
.64 .04326 L
.64 0 L
F
0 g
.62 0 m
.62 .04326 L
.64 .04326 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04017 L
.68 .04017 L
.68 0 L
F
0 g
.66 0 m
.66 .04017 L
.68 .04017 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
F
0 g
.7 0 m
.7 .01236 L
.72 .01236 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01545 L
.76 .01545 L
.76 0 L
F
0 g
.74 0 m
.74 .01545 L
.76 .01545 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
F
0 g
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
F
0 g
.82 0 m
.82 .00618 L
.84 .00618 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.0039 0 L
.01091 0 L
.01786 0 L
.02518 0 L
.03143 0 L
.03826 1e-05 L
.04514 1e-05 L
.05164 1e-05 L
.05747 1e-05 L
.06379 2e-05 L
.07069 3e-05 L
.07799 3e-05 L
.08422 4e-05 L
.09107 6e-05 L
.09786 8e-05 L
.1043 .0001 L
.11639 .00015 L
.12315 .00019 L
.12941 .00024 L
.13623 .0003 L
.14359 .00038 L
.15078 .00049 L
.15739 .0006 L
.17037 .00089 L
.18216 .00125 L
.19461 .00176 L
.20698 .00243 L
.22023 .00339 L
.23273 .00455 L
.24412 .00588 L
.26901 .00986 L
.28307 .01286 L
.29606 .01618 L
.34726 .03452 L
.39647 .05785 L
.42383 .07063 L
.43581 .0756 L
.44889 .08035 L
.46078 .08391 L
.47347 .08679 L
.4805 .08793 L
.48687 .08867 L
.48995 .08892 L
.49157 .08903 L
.49328 .08912 L
.49478 .08919 L
.49643 .08924 L
.49793 .08927 L
.49933 .08928 L
Mistroke
.50096 .08928 L
.50179 .08927 L
.5027 .08926 L
.50432 .08922 L
.50583 .08916 L
.50761 .08908 L
.50924 .08898 L
.51291 .08869 L
.51591 .08838 L
.51918 .08797 L
.52579 .08692 L
.5383 .08416 L
.54994 .08073 L
.57655 .07046 L
.60074 .0592 L
.65275 .03452 L
.67657 .02497 L
.70279 .0165 L
.72864 .01032 L
.74278 .00778 L
.75603 .00587 L
.76956 .00432 L
.78241 .00318 L
.79395 .00238 L
.80653 .0017 L
.81998 .00117 L
.83217 .00082 L
.83893 .00067 L
.84624 .00053 L
.85309 .00043 L
.85948 .00035 L
.87187 .00023 L
.87843 .00018 L
.88546 .00014 L
.89283 .00011 L
.89981 8e-05 L
.90603 6e-05 L
.91289 5e-05 L
.91938 4e-05 L
.92547 3e-05 L
.93191 2e-05 L
.93883 2e-05 L
.94493 1e-05 L
.95135 1e-05 L
.95683 1e-05 L
.96282 1e-05 L
.96971 0 L
.97622 0 L
.98205 0 L
.98838 0 L
Mistroke
.99528 0 L
.99875 0 L
Mfstroke
.99875 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Jooooo`_o00001?ooool7o`0000Cooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool000co00001Oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo003oo`0000?oo`001_l0
000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00004o`000?ooooooooooooooo`So00004?ooool6o`00013ooooo00?o0000ooooooooool0
9?ooool4o`0002Cooooo001Kooooo`Oo00001Oooool9o`000003ooooool0003oo`0000Coo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool:o`000003ooooool0003oo`0000Coo`0000?o0000ooooooooool0Looo
ool0073ooooo2?l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`Go00001_ooool7o`00053ooooo00?o0000ooooooooool08_ooool0
07?ooooo0ol00007ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooo`000002o`0006;ooooo00?o410@ooooooooool08_ooool007Kooooo0ol00004ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0002o`0008[ooooo001iooooo`?o0000
00?oooooo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00004o`0008_ooooo001looooo`?o00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool3o`0000?oo`0000?o0000ooooooooool0ROooool007gooooo00Ko0000ool00?l0003o0000ool0
0?l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool01?l00005ool00003o`00
0?oooooooooo08Wooooo001mooooo`04o`000?oo003oo`00ool000;o00001Oooool6o`0000Gooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool000?o00000oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo08Wooooo001mooooo`03o`000?oo003oo`0000;oo`000ol0
000>ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00Co0000ool00?oo003oo`000_l00005ooooo`Oo0000
Roooool007gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`02o`0000cooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool6o`0009Oooooo001mooooo`Ko00001?ooool00ol0003oooooooooo`09
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00;ooooo0_l0002Looooo`00R?ooool2o`0000Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko00000_ooool2o`0009kooooo002:ooooo`;o
00001oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Wooooo0_l0002Pooooo`00
S?ooool2o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`07ooooo`;o0000
X_ooool008kooooo0_l00003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Rooooo`00T?ooool2o`000003ooooool0003oo`0000Coo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool01?ooool2o`000:Gooooo002Booooo`;o00001Ooo0003o`0000;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0YOooool009?ooooo1?l00002ool00003o`000?ooooooA4A400;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o0000Z?ooool009?ooooo
00Co0000ool00?oo003oo`000ol000001Oo^k^kooooooooooooooooo000000Goo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000_oo0004o`000:_ooooo002Cooooo`03o`000?oo003oo`0000?oo`001_l00005ool00003
o`000?oooooooooo00;ooooo1ol00004ooooo`03o`000?oo003o000000;o000000?oo`00o`000?oo
ool0[?ooool009?ooooo1ol000001?mgMgOoIVIVooooooooool7o`0000Cooooo00?o0000oooooooo
ool01_ooool4o`0000Coo`0000?o0000ooooooooool0Zoooool009_ooooo00?o0000ooooooooool0
0_ooool6o`0000?ooooo00?o0000ooooooooool00oooool3o`0000;ooooo1ol0002]ooooo`00Uooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool00oooool9o`000;Wooooo
002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Kooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009cooooo00Co
0000oooooooooooo410@0oooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;cooooo
002Kooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`?o0000
_?ooool009Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
V?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009Wo
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;co
oooo002Iooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2looooo`00V_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0
002looooo`00V_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`2looooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00004oooo
o`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002l
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l0
00000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool0093ooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8b
omgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00T_ooool00ol0
003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0093ooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000oooo
ooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol00004ooooo`Co
00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002?ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002?ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;co
oooo002Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000a?ooool009;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00Toooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo0<;ooooo002?ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005oooo
o`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj
^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o
<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@oooo
ooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0=ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005oooo
o`06o`000?ooooooooooooooool0003ooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg09?ooooo001mooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000D
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`2Aooooo`00OOooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`06o`00
0?ooooooooooooooool0003ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooo
ooooooooooooo`00002Cooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;
ooooo`05o`000?n7QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool00000Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo1?l0000:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
4Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100Toooool007gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2C
ooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006
ooooo`03o`000?oooooooooo017ooooo0_l0000Rooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^09?ooooo002@ooooo`03oa0@4?oooooooooo0=Gooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
F
0 g
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02781 L
.34 .02781 L
.34 0 L
F
0 g
.32 0 m
.32 .02781 L
.34 .02781 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04635 L
.38 .04635 L
.38 0 L
F
0 g
.36 0 m
.36 .04635 L
.38 .04635 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
F
0 g
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .0958 L
.46 .0958 L
.46 0 L
F
0 g
.44 0 m
.44 .0958 L
.46 .0958 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .06798 L
.5 .06798 L
.5 0 L
F
0 g
.48 0 m
.48 .06798 L
.5 .06798 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .09271 L
.54 .09271 L
.54 0 L
F
0 g
.52 0 m
.52 .09271 L
.54 .09271 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .06798 L
.58 .06798 L
.58 0 L
F
0 g
.56 0 m
.56 .06798 L
.58 .06798 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04017 L
.62 .04017 L
.62 0 L
F
0 g
.6 0 m
.6 .04017 L
.62 .04017 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .05562 L
.66 .05562 L
.66 0 L
F
0 g
.64 0 m
.64 .05562 L
.66 .05562 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
F
0 g
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01545 L
.74 .01545 L
.74 0 L
F
0 g
.72 0 m
.72 .01545 L
.74 .01545 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
F
0 g
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00309 L
.86 .00309 L
.86 0 L
F
0 g
.84 0 m
.84 .00309 L
.86 .00309 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00212 0 L
.00862 0 L
.01575 0 L
.02337 0 L
.03053 1e-05 L
.03713 1e-05 L
.04438 1e-05 L
.05206 2e-05 L
.05872 2e-05 L
.06495 3e-05 L
.07179 4e-05 L
.07914 5e-05 L
.0862 6e-05 L
.09276 8e-05 L
.09994 .0001 L
.1076 .00014 L
.1149 .00018 L
.12178 .00023 L
.13462 .00034 L
.14089 .00042 L
.14777 .00052 L
.16165 .00079 L
.17451 .00115 L
.1865 .0016 L
.20058 .0023 L
.2139 .0032 L
.22587 .00424 L
.23886 .00566 L
.26549 .00975 L
.27893 .01252 L
.29374 .01619 L
.34785 .03527 L
.39991 .05932 L
.42637 .07106 L
.44035 .07644 L
.45527 .08125 L
.46273 .08322 L
.46976 .08477 L
.47661 .086 L
.47962 .08644 L
.48292 .08686 L
.48581 .08717 L
.48891 .08743 L
.49062 .08755 L
.49219 .08765 L
.49367 .08772 L
.49525 .08778 L
.49695 .08782 L
.49853 .08785 L
Mistroke
.50023 .08786 L
.50119 .08785 L
.5021 .08784 L
.50373 .08781 L
.50523 .08776 L
.50687 .08769 L
.5086 .0876 L
.51205 .08736 L
.51531 .08706 L
.52141 .0863 L
.52797 .08521 L
.5351 .08373 L
.54793 .08031 L
.55977 .0764 L
.61269 .05337 L
.66356 .03055 L
.69186 .02041 L
.71774 .01329 L
.73052 .01052 L
.74447 .00802 L
.75756 .00611 L
.76987 .00467 L
.78375 .00339 L
.79633 .00249 L
.80988 .00176 L
.82453 .00118 L
.83732 .00082 L
.85135 .00054 L
.85842 .00043 L
.86599 .00034 L
.87966 .00021 L
.88677 .00017 L
.89335 .00013 L
.90042 .0001 L
.90823 8e-05 L
.915 6e-05 L
.92135 5e-05 L
.92805 4e-05 L
.93528 3e-05 L
.94195 2e-05 L
.94816 2e-05 L
.95496 1e-05 L
.96223 1e-05 L
.96988 1e-05 L
.9771 0 L
.98358 0 L
.9906 0 L
.99718 0 L
Mfstroke
.99718 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Hooooo`ko00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`co00001Ooo00000ol0003oooooooooo`02ooooo`Oo00002_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo01Wooooo1_l0
0005ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`001ol0
000:ooooo`Oo00005Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool006Oooooo2ol00005
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool6o`0007_ooooo001_oooo
o`?o00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool02Ol0001Fooooo`03o`000?oooooooooo
02;ooooo001booooo`?o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool8o`0005oooooo00?o410@ooooooooool08_ooool007Gooooo
0ol00005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool01?ooool4o`0008Oooooo
001gooooo`?o00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Co0000Rooo
ool007Oooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`000ol0002?ooooo`00O?ooool3o`0000?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`04o`000?oo003oo`00ool000?o0000TOooool007oooooo0_l000000ooo
oooo0000ool00004ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00Co0000ool00?l0003o00000_oo0000
0ol0003oooooooooo`2?ooooo`00POooool3o`0000Coo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`Oo00001?ooool2o`0000Coo`0000?o0000ooooooooool0Soooool008;o
oooo00Co0000ool00?l0003o00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00_ooooo0ol00005ool00003o`000?oooooooooo08oooooo0022ooooo`Oo00001?ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Wo
oooo0_l00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Soooool008Sooooo
0ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Soooool008_ooooo2Ol00005ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool01Oooool2o`0000Kooooo1ol0002Aooooo`00SOooool2o`0000[ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`?o0000X?ooool008oooooo0_l00008oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
00;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02o`000:?ooooo002Aooooo`;o00001_ooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool000?o0000YOooool009?ooooo0_l00002ooooo`?o00001?oo00000ol0003ooooo
odA4A002o`000003oc8b<_l0003o000000Co00001Oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo1ol0002Wooooo`00UOooool3o`000003ob4Q8Ol0003oo`0000?oo`0000?o
0000ooooooooool00_ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`04ooooo`?o0000Z_ooool009Sooooo0ol00003
ool00003o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`;o0000[Oooool009Wooooo00Ko0000ool0
0?l0003o0000ool00?l00004ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool000Go0000[oooool009Wooooo00Co0000ool00?oo003oo`001?l0
00001?lQ8B7o0000oc8b<_o<c<`4ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ol0002cooooo`00VOooool00ol0003oo`00ool00002ool00003o`000?oooooo0000017o00000_oo
00000ol0003oooooooooo`2aooooo`00Uoooool00ol0003o^[Zjo`000004ool00003o`000?oooooo
000000Sooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo0;7ooooo002Gooooo`03oiRHV?l@413o000000Coo`0000?o0000ooooool000000ol00005oooo
o`;o00001?ooool6o`000;?ooooo002Iooooo`Ko00002_ooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00V?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0;cooooo002Kooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0_?ooool009cooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0;cooooo002Kooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`?o0000_?ooool009Sooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00V?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool009Wooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009Wooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00V_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00V_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00
V_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_?ooool009Oooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0_?ooool009Oooooo1Ol00004ooooo`Co00001Oooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_l0002mooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000000ol@413oooooooooo`05o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo
0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEE
ofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`06oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0093ooooo
00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool0093ooooo1?l000000ol@413oooooooooo`02oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Co
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00Gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01Oooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002@
ooooo`03oeEEEOmVIVKo000000Cooooo1Ol00004ooooo`Co00001Oooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002?ooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0;cooooo002?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Aooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?oo
ool009;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000034ooooo`00Toooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo0<;ooooo002?ooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`34ooooo`00Soooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008gooooo00Co
410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o
0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03
ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000okZj^P03
ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005ooooo`03ohN7
Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0=ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`01?ooool4o`000003oa0@4?oooooooooo093ooooo001mooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo
1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2Booooo`00
OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;oooo
o`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?oo
ool01Oooool00ol0003oooooooooo`2Booooo`00OOooool5o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003o
ooooooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P06oooo
o`03o`000?oooooooooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
017ooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Poooo
o`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2Booooo`00O?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooo
oooo017ooooo0_l0000Rooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool00omEEEGoIVIVo`00
002Dooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
F
0 g
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
F
0 g
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
F
0 g
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
F
0 g
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04326 L
.4 .04326 L
.4 0 L
F
0 g
.38 0 m
.38 .04326 L
.4 .04326 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .07725 L
.44 .07725 L
.44 0 L
F
0 g
.42 0 m
.42 .07725 L
.44 .07725 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
F
0 g
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .07725 L
.52 .07725 L
.52 0 L
F
0 g
.5 0 m
.5 .07725 L
.52 .07725 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08652 L
.56 .08652 L
.56 0 L
F
0 g
.54 0 m
.54 .08652 L
.56 .08652 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05253 L
.6 .05253 L
.6 0 L
F
0 g
.58 0 m
.58 .05253 L
.6 .05253 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04635 L
.64 .04635 L
.64 0 L
F
0 g
.62 0 m
.62 .04635 L
.64 .04635 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04017 L
.68 .04017 L
.68 0 L
F
0 g
.66 0 m
.66 .04017 L
.68 .04017 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .00927 L
.72 .00927 L
.72 0 L
F
0 g
.7 0 m
.7 .00927 L
.72 .00927 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
F
0 g
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
F
0 g
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00061 0 L
.00847 0 L
.01586 0 L
.02267 1e-05 L
.03014 1e-05 L
.03806 1e-05 L
.04493 2e-05 L
.05136 2e-05 L
.05841 3e-05 L
.06599 4e-05 L
.07327 5e-05 L
.08003 6e-05 L
.08744 8e-05 L
.09534 .00011 L
.10287 .00014 L
.10996 .00018 L
.1232 .00029 L
.12967 .00035 L
.13676 .00044 L
.14368 .00054 L
.15108 .00068 L
.16434 .00099 L
.1767 .00139 L
.19084 .002 L
.2062 .00293 L
.2207 .0041 L
.2341 .0055 L
.26002 .00929 L
.27477 .01218 L
.28859 .01545 L
.34229 .03342 L
.39938 .05886 L
.42789 .07101 L
.44177 .07606 L
.45437 .07993 L
.4607 .08158 L
.46754 .08311 L
.47346 .08422 L
.47996 .08519 L
.48329 .08558 L
.48687 .08593 L
.48884 .08609 L
.49065 .08621 L
.49248 .08631 L
.49417 .08638 L
.49573 .08643 L
.49739 .08647 L
.49905 .08649 L
.5 .08649 L
Mistroke
.50089 .08649 L
.50249 .08647 L
.50396 .08644 L
.50557 .08639 L
.50726 .08632 L
.51082 .08611 L
.51418 .08584 L
.52047 .08513 L
.52724 .0841 L
.53459 .08266 L
.54782 .07931 L
.56004 .07544 L
.6146 .05247 L
.66707 .02971 L
.69399 .02036 L
.72294 .01269 L
.73696 .00983 L
.75225 .0073 L
.76686 .00539 L
.7801 .00403 L
.79416 .0029 L
.80739 .0021 L
.82136 .00146 L
.83646 .00097 L
.84965 .00066 L
.85714 .00053 L
.86412 .00043 L
.87822 .00027 L
.88612 .00021 L
.89332 .00016 L
.89999 .00013 L
.90708 .0001 L
.91979 6e-05 L
.92685 5e-05 L
.93348 4e-05 L
.94075 3e-05 L
.94858 2e-05 L
.95546 2e-05 L
.96185 1e-05 L
.96888 1e-05 L
.97637 1e-05 L
.98426 0 L
.9917 0 L
.99838 0 L
Mfstroke
.99838 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0CoooooaCo00000_ooool7o`0000Cooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool000co00004?ooool6o`0000Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Nooooo`Oo00000_ooool5o`0000Sooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`Oo00001?ooool00ol0003oo`00o`000004o`0000Cooooo1ol0000Kooooo`03o`000?oo
oooooooo02Cooooo1?l0000Tooooo`00JOooool4o`0000Cooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`07ooooo`go0000MOooool006gooooo1Ol00005ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00Cooooo0ol0001Mooooo`03o`000?oooooooooo02;ooooo001aooooo`?o00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00001?l0003o
ooooooooooooool3o`00063ooooo00?o410@ooooooooool08_ooool0077ooooo00?o0000ool00?oo
00001?l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0004o`0008So
oooo001aooooo`Wo00000oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`04o`000?oo003oo`00ool000?o
0000Roooool007[ooooo1?l00004ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`Co00000_oo00000ol0003oooooooooo`29ooooo`00OOoo
ool2o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00;ooooo0_l00005ool00003o`000?oooooooooo08Wooooo001mooooo`Ko00001Oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00;o000000?oooooo`000?oo00001?oo0000
0ol0003oooooooooo`29ooooo`00POooool3o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0003o`00
00?ooooo1ol0002;ooooo`00Q?ooool2o`0000;ooooo1_l00005ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ol0002Gooooo`00Q_ooool2o`0000_ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool6o`0009Oooooo0028ooooo`?o00002?ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`;o0000W?oo
ool008_ooooo0_l00006ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool6
o`0000;ooooo0_l0002Nooooo`00SOooool2o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`08ooooo`?o0000X?ooool008oooooo0_l00002ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool01_ooool2o`000:?ooooo002Aooooo`?o00001Ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`?o0000YOooool009?ooooo0_l00004ool000?o00000_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000Co0000oooooooooooooooo0_l0002Xooooo`00Tooo
ool00ol0003oo`00o`000002o`000004ool00?l0003oooooodA4A0;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool000Co0000Z_ooool009?ooooo2Ol00002ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Cooooo00?o0000ool00?oo00000_oo
0002o`000:gooooo002Iooooo`03oiRHV?lQ8B7ok^k^00?o00001Ooo00000ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo1Ol000000ooo003o0000ooooo`2/ooooo`00V_ooool01?mg
MgOoIVIVooooooooool7o`0000Cooooo00?o0000ooooooooool01?ooool5o`0000Goo`0000?o0000
ooooooooool0Zoooool009_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool<
o`0000Cooooo1ol0002]ooooo`00Uoooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool009Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00Voooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo0;cooooo002Looooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool00oooool00ol0003oooooooooo`2looooo`00Voooool01OmgMgOo<S8boooooooooooo
000000?ooooo00?o0000ooooooooool00oooool3o`000;cooooo002Hooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?oo
ool009Sooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0_?ooool009Sooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo1?l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Iooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@04ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00VOooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009[ooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009[ooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009[o
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0;cooooo002Gooooo`Go00001?ooool4o`0000Gooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2l
ooooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o0000_Oooool0093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000?o410@ooooooooool01Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`?o
0000_?ooool009;ooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmV
IVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01_ooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413o
ooooooooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03
oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002@ooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?oo
ool00omEEEGoIVIVo`000004ooooo`Go00001?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00Soooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`2looooo`00Soooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2l
ooooo`00T?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00TOooool00onHV9So8B4Qonk^kP03
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo
002Booooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000a?ooool009?ooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`32ooooo`00Soooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0a?ooool008oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@
4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`00
0?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00ooo
ool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00ooo
ool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo
0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool03Oooool01OnH
V9So410@o`000?lb<S;oc<c<00?ooooo1Ol0002Cooooo`00OOooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o
410@00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o
c<c<o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Cooooo`00OOooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000005?ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^09Cooooo
001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_o
oooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo00?oZJVYoa0@4?ooool01?ooool0
0onHV9So8B4Qonk^kP2Cooooo`00OOooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool00ol0003oooooooooo`0;
ooooo`05o`000?n7QhOoooooojVYZOl000004_ooool00ol@413o0000okZj^P06ooooo`03ogMgMomV
IVKooooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo017ooooo00?o
^[Zjob4Q8Oooool01_ooool00ol0003oooooooooo`2Aooooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So410@09?ooooo001looooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000oooooooo
ool04Oooool2o`0002;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0Toooool0093ooooo00?o410@ooooooooool0eOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
F
0 g
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
F
0 g
.2 0 m
.2 .00618 L
.22 .00618 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
F
0 g
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .0618 L
.38 .0618 L
.38 0 L
F
0 g
.36 0 m
.36 .0618 L
.38 .0618 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .03399 L
.42 .03399 L
.42 0 L
F
0 g
.4 0 m
.4 .03399 L
.42 .03399 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .09889 L
.46 .09889 L
.46 0 L
F
0 g
.44 0 m
.44 .09889 L
.46 .09889 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .07416 L
.5 .07416 L
.5 0 L
F
0 g
.48 0 m
.48 .07416 L
.5 .07416 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .06489 L
.54 .06489 L
.54 0 L
F
0 g
.52 0 m
.52 .06489 L
.54 .06489 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .08343 L
.58 .08343 L
.58 0 L
F
0 g
.56 0 m
.56 .08343 L
.58 .08343 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04635 L
.62 .04635 L
.62 0 L
F
0 g
.6 0 m
.6 .04635 L
.62 .04635 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .04326 L
.66 .04326 L
.66 0 L
F
0 g
.64 0 m
.64 .04326 L
.66 .04326 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .03399 L
.7 .03399 L
.7 0 L
F
0 g
.68 0 m
.68 .03399 L
.7 .03399 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .00309 L
.74 .00309 L
.74 0 L
F
0 g
.72 0 m
.72 .00309 L
.74 .00309 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01545 L
.78 .01545 L
.78 0 L
F
0 g
.76 0 m
.76 .01545 L
.78 .01545 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
F
0 g
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
F
0 g
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00567 0 L
.01192 1e-05 L
.01881 1e-05 L
.02621 1e-05 L
.03415 1e-05 L
.04165 2e-05 L
.04851 2e-05 L
.05533 3e-05 L
.0626 4e-05 L
.06946 5e-05 L
.07567 7e-05 L
.08301 9e-05 L
.09093 .00012 L
.09841 .00015 L
.10529 .00019 L
.11202 .00024 L
.11922 .0003 L
.13222 .00045 L
.14016 .00057 L
.14768 .00071 L
.16175 .00105 L
.17557 .00151 L
.19024 .00219 L
.20276 .00296 L
.21656 .00406 L
.23101 .00554 L
.24424 .00725 L
.25969 .00974 L
.27404 .01258 L
.30112 .01949 L
.3307 .02938 L
.38653 .05296 L
.41502 .06529 L
.43001 .07113 L
.44586 .07648 L
.46005 .08034 L
.46756 .08196 L
.47563 .08335 L
.47943 .08388 L
.48303 .0843 L
.48654 .08463 L
.48979 .08487 L
.49287 .08503 L
.49442 .0851 L
.49613 .08515 L
.49784 .08518 L
.49969 .08519 L
.50143 .08519 L
.50303 .08516 L
Mistroke
.50485 .08512 L
.50657 .08506 L
.50811 .08499 L
.50979 .08489 L
.51354 .08462 L
.51701 .08429 L
.52333 .08351 L
.53002 .08242 L
.54409 .07932 L
.55957 .07476 L
.61713 .05132 L
.67252 .02819 L
.70273 .01838 L
.71662 .01473 L
.73142 .01144 L
.74627 .00871 L
.75972 .0067 L
.7725 .00514 L
.78599 .00383 L
.80032 .00275 L
.81349 .002 L
.82767 .00139 L
.83567 .00112 L
.84323 .00091 L
.85022 .00075 L
.85782 .0006 L
.87111 .00041 L
.87864 .00032 L
.88663 .00025 L
.89412 .00019 L
.90099 .00015 L
.91438 .0001 L
.92141 8e-05 L
.92881 6e-05 L
.94129 4e-05 L
.94835 3e-05 L
.95492 2e-05 L
.96214 2e-05 L
.96996 1e-05 L
.97735 1e-05 L
.98416 1e-05 L
.9903 0 L
.99706 0 L
Mfstroke
.99706 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0=ooooo`Oo00001Oooool<o`0000Coo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oo`00
o`00000?o`0000oooooo1ol0000Yooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oo
oooooooo01Wooooo1_l00005ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`08ooooo`So00000ooo
00000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00IOooool=
o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`04ooooo`Co00001_ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo06kooooo001]ooooo`Co00001_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`00
00Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool01?l0000:ooooo`Ko0000Boooool00ol0003oooooooooo`0Roooo
o`00LOooool3o`0000?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0003o`0005oooooo00?o410@oooooooo
ool08_ooool007Cooooo1?l00005ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00o`000003o`0008Kooooo001gooooo`Oo00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`?o00000ooo00000ol0003oooooooooo`24ooooo`00N_ooool2o`0000Kooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`000002
o`000003ooooool0003oo`0000?oo`0000?o0000ooooooooool0Q?ooool007cooooo0_l00004oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00002ool000?o00001?ooool6o`0008Kooooo001nooooo`?o
000000?oooooo`000?oo00001?oo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000_l000000ooo003o0000ooooo`2@ooooo`00POooool2o`0000Goo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`?o00000ooo00000ol0003ooooo
ooooo`2?ooooo`00P_ooool3o`0000?oo`0000?o0000ooooooooool03_ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`09o`00097ooooo0022ooooo`03o`000?oo003oo`0000Co00004?ooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool9o`0009[ooooo0022ooooo`03o`000?oo003oo`0000?oo`000_l0000?oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool01_ooool2o`0009gooooo0022ooooo`03
o`000?oo003oo`0000?oo`0000Co0000ooooool0003o00003Oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00Cooooo0_l0002Oooooo`00P_ooool00ol0003oo`00ool00003ool00004
o`000?ooooooooooooooo`?o00002_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00004o`000?oooooooooo
ooooo`?o0000XOooool008;ooooo1ol00006ooooo`?o00001oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000Co0000oooo
ool0003o0000Y?ooool009;ooooo0_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1_l00005oooo
o`03o`000?oo003oo`0000?oo`000_l0002Vooooo`00U?ooool2o`000004ooooool0003o0000o`00
00Coo`0000?o0000oooooom4A4@00_l000000olb<S;o0000ool00003ool00003o`000?oooooooooo
00kooooo00?o0000ool00?oo00001?l0002Wooooo`00U_ooool4o`0000Coo`0000?o0000oooooooo
ool00_ooool00omgMgOo0000ool00003ool00003o`000?oooooooooo00kooooo0ol00003ool00003
o`000?oooooooooo0:Gooooo002Hooooo`03oiRHV?l0003o000000;o000000?oo`00o`000?ooool0
1?ooool8o`0000cooooo0ol00005ool00003o`000?oooooooooo0:Gooooo002Iooooo`04o`000?oo
003oo`00ool000?o00000oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00Sooooo
1?l00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0YOooool009Wooooo00?o
0000ool00?oo00000_oo00000ol0003oooooo`000006o`0000;ooooo00Co0000oooooooooooooooo
1ol00006ooooo`Oo0000Yoooool009Wooooo00?o0000ool00?oo00000_oo00000ol0003oooooo`00
0005ooooo`Oo0000^oooool009Oooooo00?o0000okZj^_l000001?oo00000ol0003oooooo`000008
ooooo`03o`000?oooooooooo0;cooooo002Gooooo`03oiRHV?l@413o000000Coo`0000?o0000oooo
ool000000ol00005ooooo`;o0000_Oooool009Wooooo1_l0000:ooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002H
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool009_ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`2looooo`00W?ooool01?l0003oooooooooool@4103oooo
o`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool009_ooooo00GoMgMgoc8b<_oo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0002looooo`00V?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00VOooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00VOooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009Wooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Jooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;co
oooo002Jooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2looooo`00Uoooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2looooo`00Uoooool5o`0000Cooooo1?l00005ooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Boooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`000;gooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000003oa0@4?oooooooooo00Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
0oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?ooool0
0omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?oo
ool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Kooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
T?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00T?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool01?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0_?ooool009;ooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?oo
ool0093ooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0_?ooool008oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool0097ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0034ooooo`00T_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo00000<Cooooo002Cooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0`_ooool008oooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg0<Cooooo002?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOoo
ool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o
^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo
00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0Toooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000oooooooooooooooo
o`000?ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2Aooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l0000<
ooooo`03ojVYZOl@413ooooo00Gooooo00?oZJVYoa0@4?ooool0T_ooool007gooooo1Ol00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo
000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001;ooooo00?o
410@o`000?nj^[X01Oooool00ol@413o0000okZj^P2Cooooo`00OOooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Aooooo`03okZj^_lQ8B7ooooo00Gooooo00?o^[Zjob4Q8Oooool0T_oo
ool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool08?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go410@oiRHV?oooooo
^[Zjo`00002Cooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?o
oooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Rooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY09?ooooo002@ooooo`03oa0@4?oooooooooo
0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00309 L
.16 .00309 L
.16 0 L
F
0 g
.14 0 m
.14 .00309 L
.16 .00309 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
F
0 g
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
F
0 g
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
F
0 g
.3 0 m
.3 .00618 L
.32 .00618 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04635 L
.36 .04635 L
.36 0 L
F
0 g
.34 0 m
.34 .04635 L
.36 .04635 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
F
0 g
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .09889 L
.48 .09889 L
.48 0 L
F
0 g
.46 0 m
.46 .09889 L
.48 .09889 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .04635 L
.52 .04635 L
.52 0 L
F
0 g
.5 0 m
.5 .04635 L
.52 .04635 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
F
0 g
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .06489 L
.6 .06489 L
.6 0 L
F
0 g
.58 0 m
.58 .06489 L
.6 .06489 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04326 L
.64 .04326 L
.64 0 L
F
0 g
.62 0 m
.62 .04326 L
.64 .04326 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04017 L
.68 .04017 L
.68 0 L
F
0 g
.66 0 m
.66 .04017 L
.68 .04017 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
F
0 g
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
F
0 g
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
F
0 g
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
F
0 g
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 0 m
.00318 0 L
.01063 1e-05 L
.01875 1e-05 L
.02642 1e-05 L
.03353 2e-05 L
.04101 2e-05 L
.0491 3e-05 L
.05674 4e-05 L
.06375 6e-05 L
.07707 9e-05 L
.08377 .00011 L
.09112 .00014 L
.09885 .00019 L
.10616 .00024 L
.11986 .00036 L
.12752 .00045 L
.1346 .00056 L
.14232 .0007 L
.15062 .00088 L
.16481 .00128 L
.17812 .0018 L
.19394 .00264 L
.20842 .00367 L
.22287 .00501 L
.2363 .00659 L
.25197 .00889 L
.26675 .01159 L
.29688 .01883 L
.32422 .02753 L
.38084 .05044 L
.40954 .06263 L
.42475 .06856 L
.44107 .07415 L
.45675 .07852 L
.47105 .08147 L
.47794 .0825 L
.48157 .08294 L
.48543 .08332 L
.4888 .08357 L
.49058 .08368 L
.49251 .08378 L
.49427 .08385 L
.49589 .0839 L
.49744 .08393 L
.49907 .08395 L
.50088 .08395 L
.5019 .08394 L
.50284 .08393 L
.50457 .08389 L
Mistroke
.5064 .08383 L
.50804 .08376 L
.50958 .08368 L
.51307 .08344 L
.51684 .0831 L
.52029 .08272 L
.52805 .08162 L
.54189 .07885 L
.55504 .07534 L
.58418 .06515 L
.61121 .05388 L
.66876 .03006 L
.70026 .01965 L
.71469 .01577 L
.72992 .01227 L
.744 .00958 L
.75945 .00716 L
.77341 .00541 L
.78662 .00409 L
.80163 .00292 L
.81532 .00212 L
.83005 .00147 L
.83831 .00118 L
.84607 .00096 L
.8599 .00066 L
.86725 .00053 L
.87516 .00042 L
.88301 .00033 L
.89128 .00026 L
.89902 .0002 L
.90605 .00016 L
.92009 .0001 L
.92781 8e-05 L
.93509 6e-05 L
.94139 5e-05 L
.94805 4e-05 L
.95536 3e-05 L
.9621 2e-05 L
.96935 2e-05 L
.97598 1e-05 L
.98363 1e-05 L
.99089 1e-05 L
.99758 0 L
Mfstroke
.99758 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
F
0 g
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
F
0 g
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .0618 L
.38 .0618 L
.38 0 L
F
0 g
.36 0 m
.36 .0618 L
.38 .0618 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .05562 L
.42 .05562 L
.42 0 L
F
0 g
.4 0 m
.4 .05562 L
.42 .05562 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .07107 L
.46 .07107 L
.46 0 L
F
0 g
.44 0 m
.44 .07107 L
.46 .07107 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .07725 L
.5 .07725 L
.5 0 L
F
0 g
.48 0 m
.48 .07725 L
.5 .07725 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .06798 L
.54 .06798 L
.54 0 L
F
0 g
.52 0 m
.52 .06798 L
.54 .06798 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .07725 L
.58 .07725 L
.58 0 L
F
0 g
.56 0 m
.56 .07725 L
.58 .07725 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .0618 L
.62 .0618 L
.62 0 L
F
0 g
.6 0 m
.6 .0618 L
.62 .0618 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .04326 L
.66 .04326 L
.66 0 L
F
0 g
.64 0 m
.64 .04326 L
.66 .04326 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
F
0 g
.68 0 m
.68 .01854 L
.7 .01854 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
F
0 g
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00927 L
.82 .00927 L
.82 0 L
F
0 g
.8 0 m
.8 .00927 L
.82 .00927 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
F
0 g
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 1e-05 m
.005 1e-05 L
.01289 1e-05 L
.0202 1e-05 L
.0279 2e-05 L
.03622 3e-05 L
.04407 3e-05 L
.05129 4e-05 L
.05782 6e-05 L
.06499 7e-05 L
.07944 .00012 L
.08739 .00015 L
.09491 .0002 L
.109 .0003 L
.11688 .00039 L
.12416 .00048 L
.1321 .0006 L
.14064 .00076 L
.15524 .00112 L
.16892 .00159 L
.18519 .00236 L
.20009 .00331 L
.21495 .00456 L
.22876 .00604 L
.24488 .00822 L
.26008 .0108 L
.29107 .01779 L
.3192 .02628 L
.37744 .04901 L
.40696 .06123 L
.4226 .06719 L
.43938 .07284 L
.45551 .07726 L
.47023 .08025 L
.47731 .08129 L
.48104 .08173 L
.48502 .08212 L
.48848 .08238 L
.49031 .08249 L
.4923 .08259 L
.49411 .08266 L
.49577 .08271 L
.49737 .08274 L
.49904 .08276 L
.5009 .08276 L
.50195 .08275 L
.50292 .08273 L
.5047 .0827 L
.50659 .08263 L
.50827 .08256 L
Mistroke
.50985 .08248 L
.51345 .08224 L
.51733 .0819 L
.52087 .08152 L
.52885 .0804 L
.54309 .07759 L
.55661 .07404 L
.61439 .05245 L
.64664 .03902 L
.67588 .02797 L
.70671 .01839 L
.73507 .01173 L
.74924 .00916 L
.76419 .00693 L
.77921 .00514 L
.79568 .00363 L
.81113 .00257 L
.8252 .00184 L
.83299 .00152 L
.84145 .00122 L
.84939 .00099 L
.85683 .00081 L
.87106 .00055 L
.87861 .00044 L
.88675 .00035 L
.89483 .00027 L
.90333 .00021 L
.91129 .00016 L
.91853 .00013 L
.92546 .0001 L
.93297 8e-05 L
.94091 6e-05 L
.9484 4e-05 L
.95542 3e-05 L
.96285 3e-05 L
.9692 2e-05 L
.97618 2e-05 L
.98407 1e-05 L
.99156 1e-05 L
.99828 1e-05 L
Mfstroke
.99828 1e-05 m
1 1e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
F
0 g
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
F
0 g
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
F
0 g
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
F
0 g
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
F
0 g
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04944 L
.36 .04944 L
.36 0 L
F
0 g
.34 0 m
.34 .04944 L
.36 .04944 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .06489 L
.4 .06489 L
.4 0 L
F
0 g
.38 0 m
.38 .06489 L
.4 .06489 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .05253 L
.44 .05253 L
.44 0 L
F
0 g
.42 0 m
.42 .05253 L
.44 .05253 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
F
0 g
.46 0 m
.46 .08343 L
.48 .08343 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .05253 L
.52 .05253 L
.52 0 L
F
0 g
.5 0 m
.5 .05253 L
.52 .05253 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
F
0 g
.54 0 m
.54 .08343 L
.56 .08343 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .06798 L
.6 .06798 L
.6 0 L
F
0 g
.58 0 m
.58 .06798 L
.6 .06798 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
F
0 g
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
F
0 g
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
F
0 g
.74 0 m
.74 .00618 L
.76 .00618 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
F
0 g
.78 0 m
.78 .00309 L
.8 .00309 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .01236 L
.84 .01236 L
.84 0 L
F
0 g
.82 0 m
.82 .01236 L
.84 .01236 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
F
0 g
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 1e-05 m
.0014 1e-05 L
.00888 1e-05 L
.01621 2e-05 L
.02405 2e-05 L
.03145 3e-05 L
.03819 3e-05 L
.04611 5e-05 L
.0547 6e-05 L
.06282 8e-05 L
.07033 .00011 L
.07755 .00013 L
.08533 .00017 L
.09939 .00027 L
.10754 .00034 L
.11611 .00044 L
.12414 .00055 L
.13143 .00067 L
.1463 .001 L
.16217 .00149 L
.17687 .00213 L
.19073 .00292 L
.20588 .00405 L
.22189 .00561 L
.25059 .00958 L
.26529 .01229 L
.28107 .01578 L
.30954 .02364 L
.37377 .04752 L
.40589 .06047 L
.43564 .07095 L
.45051 .07513 L
.46448 .07821 L
.47149 .07941 L
.47906 .08042 L
.48314 .08084 L
.48745 .08118 L
.49113 .0814 L
.49321 .08149 L
.49515 .08155 L
.49713 .0816 L
.49813 .08161 L
.49923 .08162 L
.50117 .08161 L
.50298 .08159 L
.50408 .08157 L
.50512 .08155 L
.50708 .08148 L
.50918 .08139 L
.51148 .08126 L
Mistroke
.51535 .08097 L
.51948 .08058 L
.5269 .07965 L
.53471 .07836 L
.54205 .07688 L
.55578 .07347 L
.587 .06317 L
.61572 .05183 L
.64748 .03896 L
.67711 .028 L
.70744 .01871 L
.73615 .012 L
.75132 .00926 L
.7678 .00685 L
.78268 .00512 L
.79665 .00384 L
.81127 .00279 L
.8274 .00192 L
.84312 .00131 L
.85195 .00105 L
.86005 .00085 L
.86743 .00069 L
.8753 .00056 L
.88948 .00037 L
.89816 .00029 L
.90635 .00022 L
.91364 .00018 L
.92166 .00014 L
.92895 .00011 L
.93678 8e-05 L
.94505 6e-05 L
.95278 5e-05 L
.96048 4e-05 L
.96778 3e-05 L
.97433 2e-05 L
.98147 2e-05 L
.98976 1e-05 L
.99756 1e-05 L
Mfstroke
.99756 1e-05 m
1 1e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
F
0 g
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
F
0 g
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
F
0 g
.24 0 m
.24 .01236 L
.26 .01236 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .01854 L
.34 .01854 L
.34 0 L
F
0 g
.32 0 m
.32 .01854 L
.34 .01854 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .06798 L
.38 .06798 L
.38 0 L
F
0 g
.36 0 m
.36 .06798 L
.38 .06798 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
F
0 g
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .06489 L
.46 .06489 L
.46 0 L
F
0 g
.44 0 m
.44 .06489 L
.46 .06489 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .07725 L
.5 .07725 L
.5 0 L
F
0 g
.48 0 m
.48 .07725 L
.5 .07725 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .07107 L
.54 .07107 L
.54 0 L
F
0 g
.52 0 m
.52 .07107 L
.54 .07107 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .06489 L
.58 .06489 L
.58 0 L
F
0 g
.56 0 m
.56 .06489 L
.58 .06489 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .07725 L
.62 .07725 L
.62 0 L
F
0 g
.6 0 m
.6 .07725 L
.62 .07725 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .03708 L
.66 .03708 L
.66 0 L
F
0 g
.64 0 m
.64 .03708 L
.66 .03708 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02163 L
.7 .02163 L
.7 0 L
F
0 g
.68 0 m
.68 .02163 L
.7 .02163 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
F
0 g
.76 0 m
.76 .00309 L
.78 .00309 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
F
0 g
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
F
0 g
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 1e-05 m
.00313 1e-05 L
.01119 2e-05 L
.01879 2e-05 L
.02571 3e-05 L
.03384 4e-05 L
.04267 5e-05 L
.05101 7e-05 L
.05871 9e-05 L
.06613 .00011 L
.07412 .00014 L
.08856 .00023 L
.09693 .00029 L
.10574 .00037 L
.11398 .00047 L
.12147 .00058 L
.13674 .00088 L
.14513 .00109 L
.15304 .00132 L
.16712 .00186 L
.18237 .00263 L
.19752 .00365 L
.21415 .00513 L
.23153 .00714 L
.24776 .00954 L
.2802 .01607 L
.30981 .0242 L
.37335 .0474 L
.40239 .05881 L
.41893 .06484 L
.43447 .06991 L
.45091 .07438 L
.46599 .07752 L
.47384 .07873 L
.48211 .07968 L
.48641 .08004 L
.49042 .08028 L
.49272 .08038 L
.49481 .08045 L
.49597 .08048 L
.49723 .0805 L
.49841 .08052 L
.49951 .08052 L
.5015 .08052 L
.5034 .08049 L
.5051 .08045 L
.50695 .08039 L
.50896 .08031 L
.5111 .0802 L
.51495 .07993 L
Mistroke
.51886 .07959 L
.52254 .07919 L
.52942 .07826 L
.54524 .07528 L
.56234 .07085 L
.62782 .04693 L
.66043 .03432 L
.69087 .02399 L
.72014 .01599 L
.7515 .00967 L
.76776 .00724 L
.78543 .00517 L
.80212 .00368 L
.81755 .00263 L
.83293 .00185 L
.84736 .00131 L
.86319 .00088 L
.87209 .00069 L
.88025 .00056 L
.88782 .00045 L
.89591 .00036 L
.91048 .00023 L
.91939 .00018 L
.92779 .00014 L
.93528 .00011 L
.94352 8e-05 L
.95155 6e-05 L
.95905 5e-05 L
.96698 4e-05 L
.97549 3e-05 L
.98339 2e-05 L
.99088 1e-05 L
.99761 1e-05 L
Mfstroke
.99761 1e-05 m
1 1e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
F
0 g
.14 0 m
.14 .00618 L
.16 .00618 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
F
0 g
.22 0 m
.22 .01236 L
.24 .01236 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
F
0 g
.26 0 m
.26 .00309 L
.28 .00309 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
F
0 g
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04017 L
.36 .04017 L
.36 0 L
F
0 g
.34 0 m
.34 .04017 L
.36 .04017 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05253 L
.4 .05253 L
.4 0 L
F
0 g
.38 0 m
.38 .05253 L
.4 .05253 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
F
0 g
.42 0 m
.42 .06798 L
.44 .06798 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .07725 L
.48 .07725 L
.48 0 L
F
0 g
.46 0 m
.46 .07725 L
.48 .07725 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .07107 L
.52 .07107 L
.52 0 L
F
0 g
.5 0 m
.5 .07107 L
.52 .07107 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .06489 L
.56 .06489 L
.56 0 L
F
0 g
.54 0 m
.54 .06489 L
.56 .06489 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
F
0 g
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .07416 L
.64 .07416 L
.64 0 L
F
0 g
.62 0 m
.62 .07416 L
.64 .07416 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .01854 L
.68 .01854 L
.68 0 L
F
0 g
.66 0 m
.66 .01854 L
.68 .01854 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
F
0 g
.7 0 m
.7 .01854 L
.72 .01854 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
F
0 g
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
F
0 g
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .01236 L
.84 .01236 L
.84 0 L
F
0 g
.82 0 m
.82 .01236 L
.84 .01236 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 1e-05 m
.00636 2e-05 L
.01424 2e-05 L
.0227 3e-05 L
.03181 4e-05 L
.0404 6e-05 L
.04827 8e-05 L
.05606 .0001 L
.06437 .00013 L
.07933 .0002 L
.08849 .00026 L
.09712 .00034 L
.10481 .00042 L
.11326 .00053 L
.12923 .00081 L
.13796 .00101 L
.14611 .00124 L
.1607 .00175 L
.17636 .0025 L
.19299 .00357 L
.21111 .00514 L
.22821 .00709 L
.24405 .00936 L
.27459 .01524 L
.30832 .02419 L
.37412 .04772 L
.40434 .05923 L
.42148 .0652 L
.43743 .07009 L
.45461 .07439 L
.4621 .07589 L
.47022 .07724 L
.47469 .07785 L
.47881 .07833 L
.483 .07874 L
.48692 .07904 L
.49104 .07927 L
.49323 .07935 L
.49445 .07939 L
.49559 .07942 L
.49676 .07944 L
.49805 .07946 L
.49918 .07947 L
.50038 .07947 L
.50157 .07946 L
.50268 .07945 L
.50477 .07941 L
.50668 .07936 L
.50872 .07928 L
.5124 .07908 L
Mistroke
.51678 .07876 L
.52078 .07838 L
.52946 .07729 L
.53768 .07593 L
.55218 .07283 L
.56795 .06853 L
.63478 .04427 L
.66798 .03195 L
.69913 .02199 L
.72891 .01446 L
.761 .00858 L
.77669 .00647 L
.79385 .00466 L
.81176 .00323 L
.82842 .00225 L
.84567 .00151 L
.86195 .00101 L
.87657 .0007 L
.88481 .00056 L
.89241 .00045 L
.90007 .00037 L
.9083 .00029 L
.92317 .00019 L
.93224 .00014 L
.94084 .00011 L
.94857 8e-05 L
.95698 6e-05 L
.96573 5e-05 L
.97395 4e-05 L
.98133 3e-05 L
.9893 2e-05 L
.99802 1e-05 L
Mfstroke
.99802 1e-05 m
1 1e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000;oo`00
00Co0000oooooooooooooooo3_l00005ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003o000000[o00001?oo00000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool08_ooool003[ooooo00?o0000ooooooooool02?ooool6o`00013ooooo
2_l0000<ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo4_l00005ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`Co00009?ooool005_ooooo1ol0
0003ooooo`Co00002?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00001?l0003oooooooooooooool5o`0001?ooooo1_l0001Oooooo`00JOoo
ool4o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`001?l0001Hooooo`03o`000?oooooooooo02;ooooo001]ooooo`?o000000?ooooo
o`000?oo00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1ol00004
ooooo`Oo0000Foooool00ol@413oooooooooo`0Rooooo`00L?ooool3o`0000Coo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0=ooooo`?o0000QOooool0077ooooo1ol00005ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00[ooooo0ol00028ooooo`00Moooool3o`0000?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
1oooool3o`0008_ooooo001jooooo`Co00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool01?ooool3o`0008kooooo001mooooo`?o00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000Co0000oooooooooooooooo0ol0
002Aooooo`00OOooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0004o`0009Cooooo0023oooo
o`?o00000_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003o`0009Oooooo0026ooooo`?o00001?oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo0ol00002ool00003o`000?oooooooooo09Go
oooo0028ooooo`Co000000?oo`00o`000?ooool01?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`04o`0000Coo`00
00?o0000ooooooooool0UOooool008Sooooo1ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool8o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`2Eooooo`00Soooool2o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`06
ooooo`;o00001_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Aoooo
o`?o00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo09Gooooo002Cooooo`Co00000_oo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo1ol00002ooooo`?o00002oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo09Gooooo002Cooooo`Wo00000_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`08ooooo`?o0000
3_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002Gooooo`03oiRHV?lQ
8B7ok^k^00?o000000?oooooo`000?oo00001?oo00000ol0003oooooooooo`02ooooo`Oo00001_oo
ool4o`00017ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00V?ooool0
0onHV9So8B4Qonk^kP02ooooo`So00001?ooool3o`0000Cooooo1_l0000Eooooo`Ko0000Uoooool0
09Wooooo00?oV9RHob4Q8Oo^k^h01_ooool>o`000;Sooooo002Jooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Kooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2looooo`00Uoooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool009Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Voooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Looooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool00oooool00ol0003o
ooooooooo`2looooo`00Voooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooooooo
ool00oooool3o`000;cooooo002Hooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009So
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool009Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Ioooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo0;cooooo002Iooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`2looooo`00VOooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0_?ooool009[ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`03ooooo`?o0000_?ooool009[ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009[ooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002G
ooooo`Go00001?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000_Oooool0
093ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002@ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000
ooooooooool01Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`03ooooo`?o0000_?oo
ool009;ooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002@ooooo`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003o
ooooooooo`04ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooooooo
o`05ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002B
ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000004oooo
o`Go00001?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00Soooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Soooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Gooooo0ol0002looooo`00TOooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Booooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000a?oo
ool009?ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`32ooooo`00Soooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool008oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028
ooooo`;o00001Oooool00on7QhOo410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005
ooooo`03o`000?nj^[[ooooo0;[ooooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2
o`000005oa0@4?ooooooooooooooool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool03Oooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41001Oooool01_l0003ooooooooooooooooo0000ooooo`Ko00002Oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2Cooooo`00OOooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
TOooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00onYZJWo410@ooooo`02
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80Toooool007gooooo1Ol00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00?o
0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001;ooooo00?o410@o`000?nj^[X0
0oooool01Oo<c<co0000o`000?l0003oc<c<09?ooooo001mooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo017ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@
09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo023ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nj^[[o
oooookZj^_l00000Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Cooooo`00T?ooool00ol@413ooooo
ooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
F
0 g
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
F
0 g
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
F
0 g
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .02163 L
.3 .02163 L
.3 0 L
F
0 g
.28 0 m
.28 .02163 L
.3 .02163 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
F
0 g
.32 0 m
.32 .02472 L
.34 .02472 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04017 L
.38 .04017 L
.38 0 L
F
0 g
.36 0 m
.36 .04017 L
.38 .04017 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .07107 L
.42 .07107 L
.42 0 L
F
0 g
.4 0 m
.4 .07107 L
.42 .07107 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .07416 L
.46 .07416 L
.46 0 L
F
0 g
.44 0 m
.44 .07416 L
.46 .07416 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .06798 L
.5 .06798 L
.5 0 L
F
0 g
.48 0 m
.48 .06798 L
.5 .06798 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .06798 L
.54 .06798 L
.54 0 L
F
0 g
.52 0 m
.52 .06798 L
.54 .06798 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
F
0 g
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .08343 L
.62 .08343 L
.62 0 L
F
0 g
.6 0 m
.6 .08343 L
.62 .08343 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .02781 L
.66 .02781 L
.66 0 L
F
0 g
.64 0 m
.64 .02781 L
.66 .02781 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01236 L
.7 .01236 L
.7 0 L
F
0 g
.68 0 m
.68 .01236 L
.7 .01236 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01545 L
.74 .01545 L
.74 0 L
F
0 g
.72 0 m
.72 .01545 L
.74 .01545 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00927 L
.78 .00927 L
.78 0 L
F
0 g
.76 0 m
.76 .00927 L
.78 .00927 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01545 L
.82 .01545 L
.82 0 L
F
0 g
.8 0 m
.8 .01545 L
.82 .01545 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
F
0 g
.84 0 m
.84 .00618 L
.86 .00618 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 2e-05 m
.00063 2e-05 L
.00841 2e-05 L
.01554 3e-05 L
.02337 4e-05 L
.0316 5e-05 L
.04003 7e-05 L
.04768 9e-05 L
.0565 .00012 L
.06483 .00015 L
.07966 .00024 L
.08801 .0003 L
.09571 .00037 L
.10358 .00046 L
.11204 .00058 L
.12729 .00086 L
.13661 .00109 L
.14544 .00134 L
.16199 .00197 L
.17818 .00281 L
.1954 .00401 L
.2101 .00534 L
.22633 .0072 L
.25879 .01238 L
.27706 .01626 L
.29382 .02048 L
.36033 .04252 L
.4243 .06558 L
.44122 .07042 L
.45721 .07409 L
.46604 .07568 L
.4707 .07638 L
.47563 .07702 L
.47978 .07746 L
.48435 .07786 L
.4885 .07813 L
.49054 .07824 L
.49239 .07832 L
.49449 .07838 L
.49564 .07841 L
.49672 .07843 L
.49865 .07845 L
.50074 .07846 L
.50184 .07845 L
.50304 .07844 L
.50431 .07841 L
.50548 .07838 L
.50759 .07832 L
.50984 .07822 L
.5143 .07796 L
Mistroke
.51852 .07762 L
.52643 .07676 L
.53418 .07565 L
.54134 .07438 L
.55756 .07074 L
.58894 .06125 L
.62356 .0486 L
.65882 .03549 L
.69113 .02478 L
.72282 .01629 L
.73895 .01282 L
.75616 .00974 L
.77356 .00722 L
.78935 .0054 L
.80523 .00396 L
.82022 .00291 L
.83657 .00204 L
.85387 .00137 L
.86864 .00095 L
.88488 .00063 L
.89364 .0005 L
.90196 .0004 L
.91757 .00026 L
.92629 .0002 L
.93437 .00016 L
.94324 .00012 L
.95268 9e-05 L
.96172 7e-05 L
.97002 5e-05 L
.97913 4e-05 L
.98875 3e-05 L
.99712 2e-05 L
Mfstroke
.99712 2e-05 m
1 2e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`Oo00001?oooolBo`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
3_l00003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo01oooooo2ol0
0005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol0
000:ooooo`03o`000?oooooooooo02Cooooo1?l0000Tooooo`00Hoooool7o`0000;ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oo`00ool0000:
o`0000Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Rooooo`00J_ooool3o`00
00Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`0=ooooo`Oo00004?ooool7o`0003oooooo00?o0000ooooooooool08_ooool006co
oooo1?l000000ooo003o0000ooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`0:ooooo`?o0000GOooool00ol@413oooooooooo`0Rooooo`00
K?ooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00Oooooo0ol00025ooooo`00Loooool3o`000003ooooool0003o000000Go00001?oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`05ooooo`;o0000R?ooool007Kooooo0ol00009ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`Oo00001?ooool3o`0008[ooooo001iooooo`?o00001_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00[ooooo0ol0002=ooooo`00O?ooool3o`0000?o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`06ooooo`Co0000T?ooool007oooooo
2_l00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`?o0000U?ooool008;ooooo0ol00008ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03o`0009Oooooo0025ooooo`?o00001Oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo0003o`0009[ooooo0028ooooo`?o00000_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000Co0000W?ooool008_ooooo0ol00005ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`?o
00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool4o`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o00001Ooo00000ol0003ooooo
ooooo`2Jooooo`00SOooool01?l0003oo`00ool00?oo0003o`0000Gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool9o`0000;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`2Jooooo`00SOooool00ol0003oo`00ool00003ool000?o00000ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool01ooo
ool3o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Jooooo`00SOooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00Co00001?oo00000ol0003oooooodA4A002
o`000003oc8b<_l0003o000000Co00001Oooool6o`0000Kooooo0ol00007ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0V_ooool008gooooo1ol00003ooooo`03oiRHV?lQ8B7o0000
00;o00000_oo00000ol0003oooooooooo`02ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool02oooool4o`0000[ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Joooo
o`00V?ooool00onHV9So0000o`00000:o`0000Cooooo0ol00004ooooo`Oo00003_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo09[ooooo002Iooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_l000002_l0000Eooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
V_ooool009[ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool06Oooool7o`0009cooooo002Kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool009Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Voooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Looooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool00oooool00ol0003oooooooooo`2looooo`00Voooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool00oooool3o`000;cooooo002H
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool0_?ooool009Sooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009Sooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Iooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00VOoo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?oo
ool009[ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool0
09[ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool0_?ooool009[ooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;cooooo002Gooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`Go00001?ooool4o`0000Go
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2loooo
o`00T?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000_?ooool009;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000_Oooool0093ooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co000000?o410@
ooooooooool01Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01Oooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;co
oooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002@ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooo410@0oooool00ol@413oooooooooo`03ooooo`?o0000_?ooool009;ooooo00?o0000oooooooo
ool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002@ooooo`Co000000?o
410@ooooooooool00_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00T_ooool0
0ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Go
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000004ooooo`Go00001?ooool4o`0000Gooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
Soooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00Soooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`2looooo`00T?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00TOoo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo00000<Cooooo002Booooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000a?ooool009?ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`32
ooooo`00Soooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0a?ooool008oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
0<Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002=ooooo`04oa0@4?l0003o8B4Qolc<c=Oooooo0028ooooo`;o00001Oooool00on7QhOo
410@ooooo`03ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;[o
oooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2oc8b<Pkooooo
00?o0000ooooooooool00oooool2oc8b<[_ooooo001looooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?oQhN7o`000?nj^[X00oooool01?l@413o0000o`000?ooool2o`000005oa0@4?oooooooooooooo
ool000001Oooool00on7QhOo0000okZj^P04ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool03Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Co410@o`000?m4A4Coc<c<
U?ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03oiRHV?l@
413ogMgM09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Co
oooo00?oQhN7oeEEEOooool0T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003?oo
ool00onYZJWo410@ooooo`02ooooo`05olc<c?lQ8B7o0000oeEEEOl00000Toooool007gooooo1Ol0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooo
oonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo000001;o
oooo00?o410@o`000?nj^[X00oooool01OlQ8B7oQhN7oooooonHV9So000009?ooooo001mooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@
413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@
413o0000ogMgM`02o`000003oiRHV?oooooooooo017ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol0
003ooooooooooooooooo000009?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0Toooool007cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o0000
8_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Coooo
o`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
F
0 g
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
F
0 g
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
F
0 g
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
F
0 g
.26 0 m
.26 .01854 L
.28 .01854 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
F
0 g
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04017 L
.36 .04017 L
.36 0 L
F
0 g
.34 0 m
.34 .04017 L
.36 .04017 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05253 L
.4 .05253 L
.4 0 L
F
0 g
.38 0 m
.38 .05253 L
.4 .05253 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
F
0 g
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08034 L
.48 .08034 L
.48 0 L
F
0 g
.46 0 m
.46 .08034 L
.48 .08034 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .07725 L
.52 .07725 L
.52 0 L
F
0 g
.5 0 m
.5 .07725 L
.52 .07725 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .05253 L
.56 .05253 L
.56 0 L
F
0 g
.54 0 m
.54 .05253 L
.56 .05253 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
F
0 g
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
F
0 g
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
F
0 g
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .01545 L
.72 .01545 L
.72 0 L
F
0 g
.7 0 m
.7 .01545 L
.72 .01545 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.78 0 m
.78 .01236 L
.8 .01236 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
F
0 g
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
F
0 g
.86 0 m
.86 .00618 L
.88 .00618 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 2e-05 m
.00343 2e-05 L
.01145 3e-05 L
.01989 4e-05 L
.02853 6e-05 L
.03637 7e-05 L
.04542 .0001 L
.05395 .00013 L
.06915 .0002 L
.07771 .00026 L
.0856 .00032 L
.09367 .0004 L
.10234 .00051 L
.11798 .00076 L
.12752 .00096 L
.13657 .0012 L
.15354 .00178 L
.17014 .00255 L
.18778 .00368 L
.20285 .00494 L
.21949 .0067 L
.25276 .01168 L
.27148 .01544 L
.28866 .01955 L
.35684 .04135 L
.42241 .06447 L
.43975 .06936 L
.45614 .07307 L
.4652 .07467 L
.46997 .07538 L
.47502 .07602 L
.47928 .07648 L
.48396 .07688 L
.48821 .07716 L
.4903 .07726 L
.4922 .07734 L
.49435 .07741 L
.49553 .07744 L
.49664 .07746 L
.49862 .07748 L
.50076 .07748 L
.50188 .07747 L
.50312 .07746 L
.50441 .07744 L
.50562 .07741 L
.50778 .07734 L
.51009 .07724 L
.51466 .07698 L
.51899 .07664 L
.52709 .07577 L
Mistroke
.53503 .07464 L
.54238 .07335 L
.559 .06968 L
.59116 .06011 L
.62665 .04743 L
.66279 .03436 L
.69591 .02378 L
.72839 .01547 L
.74492 .0121 L
.76257 .00913 L
.7804 .00672 L
.79659 .00499 L
.81287 .00363 L
.82822 .00264 L
.84498 .00184 L
.86271 .00122 L
.87785 .00084 L
.8945 .00055 L
.90349 .00043 L
.91201 .00034 L
.92801 .00022 L
.93695 .00017 L
.94523 .00013 L
.95432 .0001 L
.964 7e-05 L
.97326 5e-05 L
.98177 4e-05 L
.99111 3e-05 L
Mfstroke
.99111 3e-05 m
1 2e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
F
0 g
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .01545 L
.26 .01545 L
.26 0 L
F
0 g
.24 0 m
.24 .01545 L
.26 .01545 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01545 L
.3 .01545 L
.3 0 L
F
0 g
.28 0 m
.28 .01545 L
.3 .01545 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .02781 L
.34 .02781 L
.34 0 L
F
0 g
.32 0 m
.32 .02781 L
.34 .02781 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .05253 L
.38 .05253 L
.38 0 L
F
0 g
.36 0 m
.36 .05253 L
.38 .05253 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
F
0 g
.4 0 m
.4 .04944 L
.42 .04944 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .08034 L
.46 .08034 L
.46 0 L
F
0 g
.44 0 m
.44 .08034 L
.46 .08034 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .07416 L
.5 .07416 L
.5 0 L
F
0 g
.48 0 m
.48 .07416 L
.5 .07416 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .07107 L
.54 .07107 L
.54 0 L
F
0 g
.52 0 m
.52 .07107 L
.54 .07107 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
F
0 g
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .05562 L
.62 .05562 L
.62 0 L
F
0 g
.6 0 m
.6 .05562 L
.62 .05562 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .03399 L
.66 .03399 L
.66 0 L
F
0 g
.64 0 m
.64 .03399 L
.66 .03399 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .03399 L
.7 .03399 L
.7 0 L
F
0 g
.68 0 m
.68 .03399 L
.7 .03399 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
F
0 g
.72 0 m
.72 .01236 L
.74 .01236 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00927 L
.78 .00927 L
.78 0 L
F
0 g
.76 0 m
.76 .00927 L
.78 .00927 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
F
0 g
.8 0 m
.8 .01236 L
.82 .01236 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
F
0 g
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 3e-05 m
.00758 3e-05 L
.01683 5e-05 L
.02618 6e-05 L
.035 8e-05 L
.04292 .00011 L
.05149 .00014 L
.06085 .00018 L
.07074 .00024 L
.07919 .00031 L
.08847 .0004 L
.0977 .00051 L
.10644 .00063 L
.12284 .00095 L
.13201 .00118 L
.1405 .00144 L
.15972 .00221 L
.17668 .00314 L
.19261 .00431 L
.21008 .00596 L
.22893 .00826 L
.26424 .01432 L
.282 .01831 L
.30145 .02342 L
.37294 .04726 L
.40595 .0588 L
.44176 .06919 L
.45125 .07132 L
.46132 .07321 L
.46991 .07451 L
.47485 .07512 L
.47937 .07558 L
.4836 .07593 L
.48821 .07623 L
.49074 .07635 L
.49309 .07644 L
.49533 .07649 L
.49658 .07652 L
.49772 .07653 L
.49993 .07654 L
.50197 .07654 L
.50421 .0765 L
.50533 .07648 L
.50657 .07645 L
.50865 .07637 L
.51088 .07628 L
.5149 .07604 L
.51943 .07569 L
.52423 .07522 L
.53287 .07412 L
Mistroke
.54215 .0726 L
.5524 .07054 L
.5879 .0608 L
.65885 .03596 L
.69147 .02547 L
.72713 .01618 L
.76251 .00951 L
.7818 .00688 L
.79974 .00498 L
.81832 .00348 L
.83585 .00243 L
.85159 .00172 L
.86865 .00117 L
.88536 .00078 L
.89486 .00061 L
.90374 .00049 L
.92164 .0003 L
.93169 .00023 L
.94086 .00017 L
.94931 .00014 L
.95829 .0001 L
.96606 8e-05 L
.97445 6e-05 L
.98435 5e-05 L
.99365 3e-05 L
Mfstroke
.99365 3e-05 m
1 3e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02ooooo`Oo00002?ooool>o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00Co0000oooooooooooooooo3_l0000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`0Jooooo`_o0000
1?oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`Wo00000_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00gooooo1ol0000Vooooo`Co00009?ooool0067ooooo1_l00005ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo1_l000000ooooooo0000o`000006o`0000Oooooo1ol0001Tooooo`00HOooool:
o`000003ooooool0003o000000Co00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7
o`0005Gooooo00?o0000ooooooooool08_ooool006_ooooo1Ol00007ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00ol0001Looooo`03oa0@4?oooooooooo02;ooooo001`ooooo`Co
00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool000?o0000Q?ooool007Cooooo1?l00005ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00o`000003o`0008Kooooo
001gooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo0ol00003ool00003o`000?oooooooooo08Cooooo001j
ooooo`?o00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00000
1Ooooooo0000o`000?l0003ooooo00Ko0000Q_ooool007gooooo0ol00002ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool01oooool3o`00093ooooo0020ooooo`?o00001Ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`04ooooo`?o0000Toooool008;ooooo1?l00002ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00004o`000?oooooooooooooo
o`?o0000U_ooool008;ooooo00Co0000ool00?oo003oo`000ol00004ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo0002o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool000Co0000VOooool008;ooooo00?o0000ool00?oo00000ooo0004o`000003
ooooool0003o000000Go00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00Co0000ool00?oo003oo`000ol0002Looooo`00P_ooool7o`0000?ooooo0ol0000:ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0009cooooo002?ooooo`?o0000
1oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o0000X_ooool009;ooooo0ol0
0004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo2Ol0
002Uooooo`00UOooool3o`000003ooooool0003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`06ooooo`?o0000Z?ooool009Oooooo1Ol00002ool00003o`000?ooooooA4A4
00;o000000?o<S8bo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool3o`000:_ooooo002Gooooo`03oiRHV?lQ8B7o000000;o
o`001Ol00002ooooo`03ogMgMol0003oo`0000?oo`0000?o0000ooooooooool00oooool;o`000:ko
oooo002Hooooo`03oiRHV?l0003oo`0000?oo`0000?o0000ooooooooool04ol0002dooooo`00VOoo
ool6o`0000Cooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00V_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`2looooo`00Voooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0_?ooool009Oooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Hooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool0_?ooool009_ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00W?ooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0_?ooool009_ooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo0ol0002looooo`00V?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002H
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03o`000?oooooooooo0;cooooo002Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00VOooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`2looooo`00VOooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009Wooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Jooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00
Uoooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2looooo`00Uoooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo
002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001Oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2o`000;gooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00T?ooool4o`000003oa0@4?oooooooooo00Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool3o`000;co
oooo002Booooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`00
0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00WoMgMg
oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00
T_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGo
IVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00T?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?oo
ool009;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?o
oooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00Gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?o
EEEEofIVI_l000001?ooool5o`0000Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool0_?ooool008oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
093ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4005ooooo`?o0000_?ooool0097ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00T_oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo00000<Cooooo002Cooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool0`_ooool008oooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg0<Cooooo002?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00SOooool01?l@413o0000
ob4Q8Oo<c<cGooooo`00R?ooool2o`0000Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2jooooo`00R?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb
<S:kooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co
410@o`000?l0003ooooo0_l000001Ol@413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj
^[X01?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo0_l000000ol@
413oooooooooo`02ooooo`Co000000?o410@ooooooooool0T?ooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo<
c<co0000oa0@4004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00Gooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Booooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000004?ooool5o`0000Kooooo00?o0000ooooooooool0T_ooool007gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooo
oooo0000ooooo`Ko00002Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo09;o
oooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_ooooo00Go0000ohN7Qooo
ooooZJVYo`00000@ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0T_ooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo09;ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`2Booooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Tooooo`03ogMgMol0003o
oooo00Cooooo00?oEEEEofIVI_l00000U?ooool0093ooooo00?o410@ooooooooool0eOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
F
0 g
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
F
0 g
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
F
0 g
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00927 L
.28 .00927 L
.28 0 L
F
0 g
.26 0 m
.26 .00927 L
.28 .00927 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02163 L
.32 .02163 L
.32 0 L
F
0 g
.3 0 m
.3 .02163 L
.32 .02163 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .04635 L
.36 .04635 L
.36 0 L
F
0 g
.34 0 m
.34 .04635 L
.36 .04635 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
F
0 g
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .05562 L
.48 .05562 L
.48 0 L
F
0 g
.46 0 m
.46 .05562 L
.48 .05562 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .08652 L
.52 .08652 L
.52 0 L
F
0 g
.5 0 m
.5 .08652 L
.52 .08652 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .0618 L
.56 .0618 L
.56 0 L
F
0 g
.54 0 m
.54 .0618 L
.56 .0618 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
F
0 g
.58 0 m
.58 .0618 L
.6 .0618 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .05253 L
.64 .05253 L
.64 0 L
F
0 g
.62 0 m
.62 .05253 L
.64 .05253 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
F
0 g
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .02781 L
.72 .02781 L
.72 0 L
F
0 g
.7 0 m
.7 .02781 L
.72 .02781 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
F
0 g
.74 0 m
.74 .01236 L
.76 .01236 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01545 L
.8 .01545 L
.8 0 L
F
0 g
.78 0 m
.78 .01545 L
.8 .01545 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
F
0 g
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00309 L
.92 .00309 L
.92 0 L
F
0 g
.9 0 m
.9 .00309 L
.92 .00309 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 3e-05 m
.0005 3e-05 L
.00928 4e-05 L
.01857 6e-05 L
.0265 8e-05 L
.03521 .0001 L
.04459 .00013 L
.05464 .00018 L
.06414 .00023 L
.0728 .00029 L
.08146 .00037 L
.09067 .00047 L
.10722 .00072 L
.1164 .0009 L
.12503 .0011 L
.1447 .00172 L
.16243 .00252 L
.18111 .00366 L
.19705 .00496 L
.21451 .00676 L
.24989 .01196 L
.26969 .01589 L
.28771 .02013 L
.35986 .04263 L
.3929 .05415 L
.41168 .06027 L
.42927 .06539 L
.44799 .06992 L
.46512 .07301 L
.47451 .07422 L
.47883 .07466 L
.48343 .07504 L
.48599 .07521 L
.48831 .07534 L
.49067 .07545 L
.49284 .07553 L
.49405 .07556 L
.49538 .07559 L
.49672 .07561 L
.49813 .07563 L
.49937 .07564 L
.5007 .07564 L
.50196 .07563 L
.50311 .07562 L
.50524 .07558 L
.50724 .07552 L
.50944 .07544 L
.5118 .07533 L
.51662 .07503 L
.52103 .07467 L
Mistroke
.52911 .0738 L
.5376 .07259 L
.55552 .06915 L
.57511 .06419 L
.64839 .03975 L
.68226 .02859 L
.71895 .01849 L
.73902 .01406 L
.75752 .01068 L
.77634 .0079 L
.79393 .00583 L
.81028 .00432 L
.82784 .00307 L
.84733 .00205 L
.86512 .00138 L
.87377 .00114 L
.88297 .00091 L
.89951 .00061 L
.90964 .00047 L
.91917 .00037 L
.92766 .00029 L
.93697 .00023 L
.94552 .00018 L
.95467 .00014 L
.96433 .0001 L
.97333 8e-05 L
.98231 6e-05 L
.99081 4e-05 L
.99844 3e-05 L
Mfstroke
.99844 3e-05 m
1 3e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool6o`0000[ooooo3ol00002ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?l000003_l00006ooooo`Ko00001Oooool7o`0002?ooooo00?o0000ooooooooool0
8_ooool003[ooooo00?o0000ooooooooool07?ooool9o`0000Cooooo1ol00004ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooo`000004o`0000Coo`0000?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Tooooo`Co00009?ooool0063ooooo1ol0000:
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo2?l00003ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0J?ooool006Oooooo1_l00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo000000Go00002?ooool7o`00
04Gooooo00?o0000ooooooooool08_ooool006gooooo0ol000000ooooooo0000ool00004ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00001Ol0001Jooooo`03oa0@4?oooooooooo02;o
oooo001`ooooo`So00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool3o`0000?oo`0000?o0000ooooooooool0O_ooool007?ooooo0ol0
0007ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo1ol000000ooooooo0000o`000002o`0000Goo`0000?o
0000ooooooooool0O_ooool007Kooooo0ol00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00Sooooo0ol00003
ooooo`Oo0000P?ooool007Wooooo0ol000000ooooooo0000ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`05ooooo`?o0000SOooool007co
oooo0ol00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`02ooooo`?o0000T?ooool007gooooo00?o0000ool00?l000000ol00005ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooool000000_l0002Cooooo`00OOooool00ol0003oo`00ool0
0002ool000?o00000oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool01?l0003oo`00ool00?oo0003o`0009Kooooo001mooooo`Ko00000_oo
ool4o`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`Co000000?o
o`00o`000?ooool0U_ooool008Sooooo0ol00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000Co0000
oooooooooooooooo0ol00004ool00003o`000?oooooooooo09Gooooo0028ooooo`Ko00001Oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo0004o`0000;ooooo1_l0002Gooooo`00S_ooool3o`00
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ol0002Rooooo`00TOooool4o`0000Coo`0000?o0000oooooooo
ool03Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00005ooooo`Ko
0000X_ooool009?ooooo1ol0000?ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
2_ooool4o`000:Sooooo002Gooooo`So000000KoooooodA4A?l0003o0000oc8b<_oMgMd4ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool01Oooool5o`000:cooooo002Gooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool3o`000003oooooomgMgOo<S8b00Cooooo00?o0000ool00?oo
00000ooo0008o`000;7ooooo002Hooooo`03oiRHV?lQ8B7ok^k^00Oooooo3_l0002hooooo`00VOoo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2fooooo`00V_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo0;Kooooo002K
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool7o`000;Sooooo002Goooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0;cooooo002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Kooooo`09ogMg
Molb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
09cooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0;cooooo002Kooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03
ooooo`?o0000_?ooool009Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool0
0ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`2looooo`00V?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
_?ooool009Wooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo0;cooooo002Iooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2looooo`00V_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0002looooo`00V_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2looooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo
1Ol00004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Go
oooo0ol0002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
093ooooo1?l000000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003ooooo
ooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool0093ooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00
T_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool0093ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00Cooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Go
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo
00?o0000ooooooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol0
0004ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002?ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002?ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool3o`000;cooooo002Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00
Toooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo0<;ooooo002?ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo
0_l00005ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o0000
00Go410@ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0?ooooo`;o000000Co410@oooooooooooooooo1Ol0002C
ooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l0003ooooooooo
oooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo0000013ooooo1Ol00004ooooo`03oiRHV?lQ
8B7ok^k^09Cooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00_ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Wooooo00CoA4A4omgM
gOoooooo00001_ooool00onHV9So8B4Qonk^kP2Cooooo`00OOooool5o`0000Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?n7QhOoooooojVYZOl000001?ooool0
0ol0003oooooooooo`0;ooooo`05o`000?n7QhOoooooojVYZOl000004?ooool01?oMgMgoEEEEoooo
ool00007ooooo`03ogMgMomVIVKooooo09;ooooo001mooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo00oooooo00?oMgMgolc<c?l000002?ooool00ol0003oooooooooo`2Aooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Qooooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj^_ooooooV9RHoa0@402Cooooo`00
O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03
o`000?oooooooooo017ooooo0_l0000Tooooo`03ogMgMol0003ooooo00?ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c02Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 .00309 L
.1 .00309 L
.1 0 L
F
0 g
.08 0 m
.08 .00309 L
.1 .00309 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
F
0 g
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
F
0 g
.2 0 m
.2 .00309 L
.22 .00309 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
F
0 g
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
F
0 g
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04017 L
.34 .04017 L
.34 0 L
F
0 g
.32 0 m
.32 .04017 L
.34 .04017 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04635 L
.38 .04635 L
.38 0 L
F
0 g
.36 0 m
.36 .04635 L
.38 .04635 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
F
0 g
.4 0 m
.4 .05253 L
.42 .05253 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .06489 L
.46 .06489 L
.46 0 L
F
0 g
.44 0 m
.44 .06489 L
.46 .06489 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .08343 L
.5 .08343 L
.5 0 L
F
0 g
.48 0 m
.48 .08343 L
.5 .08343 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .0618 L
.54 .0618 L
.54 0 L
F
0 g
.52 0 m
.52 .0618 L
.54 .0618 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
F
0 g
.56 0 m
.56 .0618 L
.58 .0618 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
F
0 g
.6 0 m
.6 .04944 L
.62 .04944 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .05253 L
.66 .05253 L
.66 0 L
F
0 g
.64 0 m
.64 .05253 L
.66 .05253 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .01545 L
.7 .01545 L
.7 0 L
F
0 g
.68 0 m
.68 .01545 L
.7 .01545 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02781 L
.74 .02781 L
.74 0 L
F
0 g
.72 0 m
.72 .02781 L
.74 .02781 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
F
0 g
.76 0 m
.76 .01236 L
.78 .01236 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
F
0 g
.8 0 m
.8 .00618 L
.82 .00618 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
F
0 g
.88 0 m
.88 .00618 L
.9 .00618 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 4e-05 m
.00535 5e-05 L
.01464 6e-05 L
.02461 9e-05 L
.03506 .00012 L
.04496 .00016 L
.05385 .0002 L
.06352 .00026 L
.08087 .00041 L
.09074 .00053 L
.10002 .00067 L
.11869 .00105 L
.12919 .00133 L
.13883 .00164 L
.15692 .00241 L
.17376 .00338 L
.19224 .00479 L
.212 .00678 L
.23089 .00924 L
.2514 .01261 L
.28862 .02075 L
.36418 .04418 L
.40176 .0568 L
.42013 .06236 L
.43694 .06677 L
.45423 .07044 L
.46218 .07179 L
.47065 .07296 L
.47537 .07349 L
.47964 .07389 L
.48399 .07422 L
.48798 .07446 L
.49026 .07456 L
.49266 .07465 L
.49508 .07471 L
.49645 .07474 L
.49772 .07475 L
.50004 .07476 L
.50215 .07475 L
.50459 .07472 L
.5069 .07466 L
.509 .07459 L
.51128 .07449 L
.51539 .07426 L
.52027 .0739 L
.52475 .07347 L
.53399 .07235 L
.54372 .07081 L
.55998 .0675 L
.57777 .06295 L
Mistroke
.65276 .0384 L
.68741 .02736 L
.72495 .01748 L
.7455 .01319 L
.76443 .00995 L
.78368 .0073 L
.80168 .00535 L
.81841 .00393 L
.83638 .00277 L
.85632 .00183 L
.87453 .00122 L
.88338 .001 L
.89279 .0008 L
.90971 .00053 L
.92008 .0004 L
.92983 .00031 L
.93852 .00025 L
.94804 .00019 L
.95679 .00015 L
.96615 .00011 L
.97604 8e-05 L
.98525 6e-05 L
.99445 5e-05 L
Mfstroke
.99445 5e-05 m
1 4e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00=?ooool7o`0000gooooo5?l00005ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`oo
00002Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo02Oooooo00?o0000oooooooo
ool08_ooool003[ooooo00?o0000ooooooooool06_ooool@o`0000Gooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00Co0000ool00?oo003o
o`001Ol00002ooooo`Oo00003oooool7o`0002Kooooo1?l0000Tooooo`00H_ooool5o`0000Gooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00;ooooo
1ol0001`ooooo`00Ioooool3o`0000;ooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1_l0
0005ooooo`04o`000?oo003oo`00ool000Ko0000D_ooool00ol0003oooooooooo`0Rooooo`00J_oo
ool8o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00gooooo1Ol000000ooo003o0000ooooo`1Eooooo`03oa0@4?oooooooooo02;ooooo001]
ooooo`Co00001_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool02_ooool3o`000003ooooool0003oo`0000?oo`0000?o0000ooooooooool0NOooool0
077ooooo0ol00003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`07ooooo`?o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
07Wooooo001dooooo`Co00001Ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;o
o`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool4o`0000Oo
oooo1_l0001kooooo`00Moooool4o`0000;oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03o`0008cooooo001gooooo`04o`000?oo003oo`00ool000Co00000oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0003o`0008oooooo
001gooooo`Oo000000?oooooo`000?l000000_l00005ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o
0000ool00?l000001?l0002Aooooo`00P_ooool3o`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000Co0000oooooooooooooooo0ol0
0004ool00003o`000?oooooooooo08oooooo0022ooooo`Oo00001?ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo0004o`000003ooooool0003oo`0000Coo`0000?o0000ooooooooool0Soooool0
08Sooooo0ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1ol00004ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Soooool008_ooooo2Ol00005ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000Co0000oooooooooooooooo1?l00008ooooo`Oo0000TOooool008kooooo1?l00007ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`001?l0002Tooooo`00T_ooool3o`0000Cooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`Ko0000
1Oooool7o`000:Oooooo002Eooooo`?o000000?oooooo`000?l000001?l00005ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool03oooool3o`000:[ooooo002Gooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;o000000Coo`0000?o0000ooooooooool03?ooool3o`000:gooooo002G
ooooo`04oiRHV?lQ8B7ok^k^ooooo`[o00001?oo00000ol0003oooooooooo`03ooooo`Wo0000/?oo
ool009Sooooo00?oV9RHob4Q8Oo^k^h02Oooool;o`000;Wooooo002Iooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgo`000?oo00000ooo00000ol0003oooooooooo`2looooo`00V_ooool00omgMgOo
IVIVooooo`03ooooo`04o`000?lQ8B7o0000oc8b<PKo0000__ooool009_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;co
oooo002Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Kooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009cooooo
00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;co
oooo002Kooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`?o
0000_?ooool009Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2loooo
o`00V?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool0
09Wooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0;cooooo002Iooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2looooo`00V_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo
0ol0002looooo`00V_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`2looooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00004
ooooo`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0
002looooo`00T_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo
1?l000000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo
00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0
002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool0093ooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00T_ooool0
0ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00T_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0093o
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Co
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000
ooooooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol00004oooo
o`Co00001Oooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002?ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002?ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`00
0;cooooo002Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000a?ooool009;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00Toooool0
1Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo0<;ooooo002?ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0a?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005
ooooo`03ohN7Qol@413ooooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000
okZj^_ooool0^_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00on7QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@
ooooooooooooooooo`000005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0?ooooo`;o000000Wo410@oooooooooooooooooiRHV?l@413o0000
oc8b<_o<c<`0Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko
0000ooooooooooooooooo`000?ooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@413o
^[ZjoooooomgMgOo<S8b09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000@ooooo`Go00001ooo
ool00ol0003oooooooooo`2Aooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooooooool0003ooooo1_l00009oooo
o`04odA4A?oMgMgoooooo`0000Oooooo00?oZJVYoa0@4?ooool0T_ooool007gooooo1Ol00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooooonYZJWo
000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo0000013ooooo00Co
gMgMoeEEEOoooooo00001_ooool00ol@413o0000okZj^P2Cooooo`00OOooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL0
0_l000000onHV9Soooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL0
0_l000000onHV9Soooooooooo`0?ooooo`03ogMgMoo<c<co000000Oooooo00?o^[Zjob4Q8Oooool0
T_ooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool08Oooool00oo^k^koA4A4o`000004ooooo`05oa0@4?nHV9SooooookZj^_l0
0000Toooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o
00001_ooool00ol0003oooooooooo`0Aooooo`;o00009?ooool00omgMgOo0000ooooo`03ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0Toooool0093ooooo00?o410@ooooooooool0eOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
F
0 g
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
F
0 g
.18 0 m
.18 .00309 L
.2 .00309 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
F
0 g
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01545 L
.28 .01545 L
.28 0 L
F
0 g
.26 0 m
.26 .01545 L
.28 .01545 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
F
0 g
.3 0 m
.3 .01236 L
.32 .01236 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .0618 L
.36 .0618 L
.36 0 L
F
0 g
.34 0 m
.34 .0618 L
.36 .0618 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04944 L
.4 .04944 L
.4 0 L
F
0 g
.38 0 m
.38 .04944 L
.4 .04944 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .05562 L
.44 .05562 L
.44 0 L
F
0 g
.42 0 m
.42 .05562 L
.44 .05562 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08034 L
.48 .08034 L
.48 0 L
F
0 g
.46 0 m
.46 .08034 L
.48 .08034 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .06489 L
.52 .06489 L
.52 0 L
F
0 g
.5 0 m
.5 .06489 L
.52 .06489 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .05871 L
.56 .05871 L
.56 0 L
F
0 g
.54 0 m
.54 .05871 L
.56 .05871 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
F
0 g
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
F
0 g
.62 0 m
.62 .05871 L
.64 .05871 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02781 L
.68 .02781 L
.68 0 L
F
0 g
.66 0 m
.66 .02781 L
.68 .02781 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .02781 L
.72 .02781 L
.72 0 L
F
0 g
.7 0 m
.7 .02781 L
.72 .02781 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
F
0 g
.74 0 m
.74 .00927 L
.76 .00927 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .01545 L
.8 .01545 L
.8 0 L
F
0 g
.78 0 m
.78 .01545 L
.8 .01545 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
F
0 g
.82 0 m
.82 .00309 L
.84 .00309 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
F
0 g
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 5e-05 m
.00361 5e-05 L
.01381 7e-05 L
.02449 .0001 L
.03462 .00013 L
.04371 .00017 L
.0536 .00023 L
.07134 .00036 L
.08144 .00047 L
.09093 .00059 L
.11002 .00094 L
.12077 .0012 L
.13062 .00149 L
.14912 .00221 L
.16634 .00311 L
.18524 .00445 L
.20545 .00635 L
.22478 .00872 L
.24575 .01198 L
.28382 .01993 L
.32134 .03028 L
.3611 .04316 L
.39847 .05548 L
.43264 .06516 L
.45147 .06924 L
.46013 .07073 L
.46935 .07202 L
.47449 .0726 L
.47914 .07303 L
.48388 .07339 L
.48823 .07364 L
.49071 .07374 L
.49333 .07383 L
.49468 .07386 L
.49595 .07389 L
.49734 .0739 L
.49884 .07392 L
.50012 .07392 L
.50152 .07391 L
.50284 .0739 L
.50406 .07389 L
.50637 .07384 L
.50882 .07376 L
.51098 .07367 L
.51333 .07356 L
.51807 .07325 L
.52655 .07249 L
.53645 .07124 L
.54565 .06976 L
.56236 .06635 L
Mistroke
.58021 .06181 L
.65868 .0366 L
.69802 .02465 L
.73428 .01581 L
.76962 .00951 L
.78744 .00715 L
.80702 .00511 L
.82625 .00359 L
.8438 .00255 L
.8535 .00209 L
.86407 .00167 L
.8833 .00109 L
.89339 .00087 L
.90287 .00069 L
.92058 .00045 L
.93053 .00035 L
.93966 .00027 L
.94968 .00021 L
.96026 .00015 L
.96967 .00012 L
.97824 9e-05 L
.98812 7e-05 L
.99748 5e-05 L
Mfstroke
.99748 5e-05 m
1 5e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
F
0 g
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00927 L
.22 .00927 L
.22 0 L
F
0 g
.2 0 m
.2 .00927 L
.22 .00927 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
F
0 g
.24 0 m
.24 .00618 L
.26 .00618 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
F
0 g
.28 0 m
.28 .01854 L
.3 .01854 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .03399 L
.34 .03399 L
.34 0 L
F
0 g
.32 0 m
.32 .03399 L
.34 .03399 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .06489 L
.38 .06489 L
.38 0 L
F
0 g
.36 0 m
.36 .06489 L
.38 .06489 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .04326 L
.42 .04326 L
.42 0 L
F
0 g
.4 0 m
.4 .04326 L
.42 .04326 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .07416 L
.46 .07416 L
.46 0 L
F
0 g
.44 0 m
.44 .07416 L
.46 .07416 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .06489 L
.5 .06489 L
.5 0 L
F
0 g
.48 0 m
.48 .06489 L
.5 .06489 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .0618 L
.54 .0618 L
.54 0 L
F
0 g
.52 0 m
.52 .0618 L
.54 .0618 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .04635 L
.58 .04635 L
.58 0 L
F
0 g
.56 0 m
.56 .04635 L
.58 .04635 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .05871 L
.62 .05871 L
.62 0 L
F
0 g
.6 0 m
.6 .05871 L
.62 .05871 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .04944 L
.66 .04944 L
.66 0 L
F
0 g
.64 0 m
.64 .04944 L
.66 .04944 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02781 L
.7 .02781 L
.7 0 L
F
0 g
.68 0 m
.68 .02781 L
.7 .02781 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02163 L
.74 .02163 L
.74 0 L
F
0 g
.72 0 m
.72 .02163 L
.74 .02163 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
F
0 g
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
F
0 g
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 .00309 L
.86 .00309 L
.86 0 L
F
0 g
.84 0 m
.84 .00309 L
.86 .00309 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
F
0 g
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 .00309 L
.94 .00309 L
.94 0 L
F
0 g
.92 0 m
.92 .00309 L
.94 .00309 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 6e-05 m
.00397 6e-05 L
.01349 8e-05 L
.02243 .00011 L
.03225 .00014 L
.04283 .00019 L
.05239 .00025 L
.06129 .00031 L
.07188 .00041 L
.0815 .00052 L
.1012 .00084 L
.11202 .00107 L
.12225 .00135 L
.141 .002 L
.16087 .00298 L
.17783 .0041 L
.1965 .00571 L
.21611 .00789 L
.23403 .0104 L
.27438 .01808 L
.31109 .02753 L
.35113 .03993 L
.39235 .05332 L
.4297 .06391 L
.44842 .068 L
.45826 .06972 L
.46866 .07118 L
.47777 .07213 L
.48294 .07253 L
.48542 .07268 L
.48777 .07281 L
.48989 .0729 L
.4922 .07298 L
.4943 .07304 L
.49625 .07307 L
.49834 .0731 L
.50066 .0731 L
.50307 .07308 L
.50534 .07305 L
.50761 .07299 L
.51004 .0729 L
.51442 .07269 L
.51962 .07234 L
.52435 .07193 L
.53465 .07076 L
.54436 .0693 L
.56152 .06595 L
.58012 .06139 L
.65921 .03659 L
.69857 .02483 L
Mistroke
.73538 .01595 L
.77069 .00969 L
.79051 .00709 L
.80862 .00522 L
.82771 .0037 L
.8454 .00264 L
.86481 .00178 L
.87566 .00141 L
.88547 .00114 L
.89493 .00092 L
.90491 .00073 L
.92276 .00047 L
.9327 .00037 L
.94197 .00029 L
.95206 .00022 L
.96302 .00016 L
.97355 .00012 L
.98328 9e-05 L
.99258 7e-05 L
Mfstroke
.99258 7e-05 m
1 6e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00309 L
.16 .00309 L
.16 0 L
F
0 g
.14 0 m
.14 .00309 L
.16 .00309 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00927 L
.2 .00927 L
.2 0 L
F
0 g
.18 0 m
.18 .00927 L
.2 .00927 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
F
0 g
.22 0 m
.22 .00618 L
.24 .00618 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
F
0 g
.26 0 m
.26 .01236 L
.28 .01236 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
F
0 g
.3 0 m
.3 .01545 L
.32 .01545 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .06489 L
.36 .06489 L
.36 0 L
F
0 g
.34 0 m
.34 .06489 L
.36 .06489 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .04635 L
.4 .04635 L
.4 0 L
F
0 g
.38 0 m
.38 .04635 L
.4 .04635 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .07107 L
.44 .07107 L
.44 0 L
F
0 g
.42 0 m
.42 .07107 L
.44 .07107 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .05562 L
.48 .05562 L
.48 0 L
F
0 g
.46 0 m
.46 .05562 L
.48 .05562 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .07416 L
.52 .07416 L
.52 0 L
F
0 g
.5 0 m
.5 .07416 L
.52 .07416 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .03708 L
.56 .03708 L
.56 0 L
F
0 g
.54 0 m
.54 .03708 L
.56 .03708 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
F
0 g
.58 0 m
.58 .05562 L
.6 .05562 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .06798 L
.64 .06798 L
.64 0 L
F
0 g
.62 0 m
.62 .06798 L
.64 .06798 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
F
0 g
.66 0 m
.66 .0309 L
.68 .0309 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .0309 L
.72 .0309 L
.72 0 L
F
0 g
.7 0 m
.7 .0309 L
.72 .0309 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
F
0 g
.74 0 m
.74 .01854 L
.76 .01854 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
F
0 g
.78 0 m
.78 .00927 L
.8 .00927 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
F
0 g
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00309 L
.92 .00309 L
.92 0 L
F
0 g
.9 0 m
.9 .00309 L
.92 .00309 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 .00309 L
.96 .00309 L
.96 0 L
F
0 g
.94 0 m
.94 .00309 L
.96 .00309 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 7e-05 m
.00223 7e-05 L
.0106 9e-05 L
.01979 .00012 L
.02946 .00015 L
.03931 .0002 L
.04827 .00025 L
.05792 .00032 L
.06838 .00042 L
.07808 .00053 L
.08702 .00066 L
.10463 .00099 L
.11383 .00122 L
.12373 .0015 L
.14162 .00218 L
.16289 .00329 L
.18234 .00468 L
.2018 .00652 L
.21985 .00869 L
.26077 .01552 L
.30131 .02511 L
.33805 .03588 L
.37927 .04903 L
.41718 .06024 L
.43634 .06492 L
.45421 .06839 L
.46322 .06976 L
.47286 .07091 L
.47836 .07142 L
.48356 .07179 L
.48824 .07205 L
.49088 .07215 L
.49332 .07223 L
.49565 .07228 L
.4981 .07231 L
.50019 .07231 L
.50247 .0723 L
.50495 .07227 L
.50633 .07224 L
.50759 .0722 L
.51003 .07212 L
.51234 .07202 L
.5168 .07177 L
.52091 .07148 L
.53019 .07058 L
.5396 .06936 L
.54995 .06767 L
.57087 .06326 L
.65054 .03948 L
.68724 .02829 L
Mistroke
.72722 .01807 L
.74893 .01365 L
.76905 .01027 L
.78813 .00767 L
.80874 .00547 L
.82967 .00378 L
.84936 .0026 L
.86852 .00177 L
.88612 .00122 L
.89544 .00099 L
.90541 .00079 L
.92338 .00052 L
.93437 .00039 L
.94476 .0003 L
.95401 .00024 L
.96421 .00018 L
.97409 .00014 L
.98334 .00011 L
.99311 8e-05 L
Mfstroke
.99311 8e-05 m
1 7e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
F
0 g
.16 0 m
.16 .00309 L
.18 .00309 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .00927 L
.22 .00927 L
.22 0 L
F
0 g
.2 0 m
.2 .00927 L
.22 .00927 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
F
0 g
.24 0 m
.24 .00927 L
.26 .00927 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .00927 L
.3 .00927 L
.3 0 L
F
0 g
.28 0 m
.28 .00927 L
.3 .00927 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04326 L
.34 .04326 L
.34 0 L
F
0 g
.32 0 m
.32 .04326 L
.34 .04326 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04635 L
.38 .04635 L
.38 0 L
F
0 g
.36 0 m
.36 .04635 L
.38 .04635 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .0618 L
.42 .0618 L
.42 0 L
F
0 g
.4 0 m
.4 .0618 L
.42 .0618 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .06798 L
.46 .06798 L
.46 0 L
F
0 g
.44 0 m
.44 .06798 L
.46 .06798 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .06798 L
.5 .06798 L
.5 0 L
F
0 g
.48 0 m
.48 .06798 L
.5 .06798 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .05253 L
.54 .05253 L
.54 0 L
F
0 g
.52 0 m
.52 .05253 L
.54 .05253 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .04635 L
.58 .04635 L
.58 0 L
F
0 g
.56 0 m
.56 .04635 L
.58 .04635 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .06489 L
.62 .06489 L
.62 0 L
F
0 g
.6 0 m
.6 .06489 L
.62 .06489 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .04944 L
.66 .04944 L
.66 0 L
F
0 g
.64 0 m
.64 .04944 L
.66 .04944 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .02781 L
.7 .02781 L
.7 0 L
F
0 g
.68 0 m
.68 .02781 L
.7 .02781 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02781 L
.74 .02781 L
.74 0 L
F
0 g
.72 0 m
.72 .02781 L
.74 .02781 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
F
0 g
.76 0 m
.76 .01854 L
.78 .01854 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
F
0 g
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 .00618 L
.94 .00618 L
.94 0 L
F
0 g
.92 0 m
.92 .00618 L
.94 .00618 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 8e-05 m
.00703 9e-05 L
.01674 .00012 L
.02728 .00016 L
.03712 .00021 L
.04633 .00027 L
.05729 .00036 L
.0673 .00046 L
.08774 .00074 L
.099 .00095 L
.10971 .00121 L
.12905 .00181 L
.14967 .00272 L
.16912 .0039 L
.18675 .0053 L
.20697 .00738 L
.22558 .0098 L
.26756 .01728 L
.30554 .02655 L
.34721 .03886 L
.38987 .05214 L
.42874 .06268 L
.44806 .06669 L
.45824 .06837 L
.46905 .06979 L
.47848 .07069 L
.48385 .07106 L
.4863 .0712 L
.48888 .07132 L
.49108 .0714 L
.49349 .07147 L
.49568 .07151 L
.49771 .07154 L
.50012 .07155 L
.50231 .07154 L
.50484 .0715 L
.50722 .07145 L
.50955 .07138 L
.51205 .07128 L
.51657 .07104 L
.52194 .07066 L
.52684 .07022 L
.53749 .06898 L
.5476 .06745 L
.56541 .064 L
.58481 .05931 L
.6669 .03451 L
.7049 .02378 L
.74593 .01455 L
.76849 .01068 L
Mistroke
.78921 .00783 L
.80901 .00569 L
.8299 .00397 L
.84908 .00278 L
.8696 .00186 L
.88897 .00124 L
.9066 .00084 L
.91633 .00067 L
.92666 .00053 L
.94518 .00034 L
.95547 .00026 L
.96511 .0002 L
.97569 .00015 L
.98707 .00011 L
.99763 8e-05 L
Mfstroke
.99763 8e-05 m
1 8e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
F
0 g
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .01236 L
.2 .01236 L
.2 0 L
F
0 g
.18 0 m
.18 .01236 L
.2 .01236 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
F
0 g
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
F
0 g
.3 0 m
.3 .0309 L
.32 .0309 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.38 0 m
.38 .05562 L
.4 .05562 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .0618 L
.44 .0618 L
.44 0 L
F
0 g
.42 0 m
.42 .0618 L
.44 .0618 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .08034 L
.48 .08034 L
.48 0 L
F
0 g
.46 0 m
.46 .08034 L
.48 .08034 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .0618 L
.52 .0618 L
.52 0 L
F
0 g
.5 0 m
.5 .0618 L
.52 .0618 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .05871 L
.56 .05871 L
.56 0 L
F
0 g
.54 0 m
.54 .05871 L
.56 .05871 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .02781 L
.6 .02781 L
.6 0 L
F
0 g
.58 0 m
.58 .02781 L
.6 .02781 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .08343 L
.64 .08343 L
.64 0 L
F
0 g
.62 0 m
.62 .08343 L
.64 .08343 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
F
0 g
.66 0 m
.66 .02472 L
.68 .02472 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .03399 L
.72 .03399 L
.72 0 L
F
0 g
.7 0 m
.7 .03399 L
.72 .03399 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .02163 L
.76 .02163 L
.76 0 L
F
0 g
.74 0 m
.74 .02163 L
.76 .02163 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
F
0 g
.9 0 m
.9 .00618 L
.92 .00618 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 .00309 L
.96 .00309 L
.96 0 L
F
0 g
.94 0 m
.94 .00309 L
.96 .00309 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 9e-05 m
.00439 .0001 L
.01431 .00013 L
.02391 .00017 L
.03423 .00022 L
.05288 .00036 L
.06425 .00047 L
.07506 .00061 L
.0857 .00077 L
.09534 .00096 L
.11509 .00146 L
.12593 .00182 L
.13613 .00223 L
.15432 .00314 L
.17398 .00447 L
.19356 .0062 L
.21505 .00866 L
.23748 .01195 L
.25841 .01573 L
.33852 .0363 L
.37932 .04879 L
.40084 .05508 L
.42368 .06102 L
.44395 .06535 L
.45471 .0672 L
.46631 .06879 L
.47148 .06935 L
.47692 .06985 L
.48196 .07022 L
.48664 .07048 L
.48891 .07058 L
.49105 .07066 L
.49352 .07073 L
.49576 .07077 L
.49825 .0708 L
.50054 .07081 L
.50306 .07079 L
.50573 .07075 L
.50822 .07068 L
.51094 .07059 L
.51589 .07035 L
.5207 .07004 L
.52517 .06967 L
.53528 .06859 L
.54604 .06708 L
.56583 .06339 L
.58374 .0592 L
.66634 .03484 L
.70427 .02423 L
.74583 .01491 L
Mistroke
.76571 .01143 L
.78697 .0084 L
.80943 .0059 L
.83036 .00414 L
.85138 .00283 L
.86245 .00229 L
.87419 .00182 L
.88444 .00147 L
.89574 .00116 L
.91563 .00075 L
.92632 .00059 L
.93648 .00046 L
.95556 .00029 L
.96621 .00022 L
.9761 .00017 L
.98695 .00013 L
.99852 9e-05 L
Mfstroke
.99852 9e-05 m
1 9e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool6o`0000Sooooo2_l00004ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool=o`0000Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`Oo00006?ooool00ol0003oooooooooo`0Rooooo`00>_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oo003o000000oo00003oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000Co0000oooooooooooooooo3Ol0000Fooooo`Oo00008?ooool4o`0002Cooooo
001@ooooo`Oo00001oooool6o`0000gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0002ool000Go0000L_ooool006Cooooo1Ol00008ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo1Ol00000
0ooo003o0000ooooo`1?ooooo`03o`000?oooooooooo02;ooooo001Yooooo`Co00001?ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0006o`00
00Goo`0000?o0000ooooooooool0C_ooool00ol@413oooooooooo`0Rooooo`00KOooool3o`000003
ooooool0003oo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00004o`0000Co
oooo1ol0001eooooo`00L?ooool4o`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`Oo00000oooool4o`0000?oo`0000?o0000ooooooooool0O_ooool0077ooooo1ol0
0005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool0
0002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`Ko00001Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00[ooooo0ol0
00000ooooooo0000ool00004ool00003o`000?oooooooooo07kooooo001hooooo`?o00000_ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00Oooooo0ol00004ooooo`Oo0000P?ooool0
07_ooooo2?l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`Co0000S_ooool007oooooo1?l00005ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00ko
oooo00?o0000ool00?oo00000_oo00000ol0003oooooo`000003o`0009;ooooo0023ooooo`Co0000
00?oooooo`000?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03_ooool00ol0003oo`00ool00004o`0009Kooooo0027ooooo`Co00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool03_oo
ool3o`0000;oo`0000?o0000ooooooooool0UOooool008Sooooo00?o0000ool00?oo00000ol00005
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool02_ooool5o`0000Coo`0000?o0000
ooooooooool0UOooool008Sooooo2Ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool01_ooool4o`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eoooo
o`00TOooool3o`0000Goo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo
00001Oooool3o`0000Sooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00
Toooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Oo0000
3Oooool3o`0000_ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`2Eooooo`00V?oo
ool5o`000003ooooool0003oo`0000Coo`0000?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`Co00003_ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo09Gooooo002G
ooooo`Go000000?oooooo`000?l000001ol00003ooooo`03o`000?oooooooooo00?ooooo2_l0000B
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009Oooooo00GoV9RHob4Q
8Oo^k^koooooodA4A002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooool000002?l0000L
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009Sooooo00?oV9RHob4Q
8Oo^k^h00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo0ol0000Ooooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0UOooool009Wooooo00?oV9RHob4Q8Oo^
k^h00_ooool7o`0000Cooooo00?o0000ooooooooool07oooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo09Gooooo002Jooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo01oooooo1_l0002Gooooo`00Voooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_?ooool009Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009_ooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00W?oo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
_?ooool009_ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo
0ol0002looooo`00V?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0;cooooo002Hooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;co
oooo002Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00VOooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2loooo
o`00VOooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0_?ooool009Wooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;cooooo002Jooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00ooo
ool3o`000;cooooo002Jooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo0;cooooo002Jooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2looooo`00Uoooool5o`00
00Cooooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool0093ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool009;ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3
o`000;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`000;gooooo002@ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00T?oo
ool4o`000003oa0@4?oooooooooo00Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool00oooool3o`000;cooooo002Booooo`03o`000?oooooooooo
00Gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooooooo
ool00_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00T?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l00000
2Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`07oooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool00oooool3o`000;cooooo002Boooo
o`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`2looooo`00T?ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
T?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
1?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01Oooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0
003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oEEEEofIVI_l000001?ooool5o`0000Co
oooo1?l00005ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool008oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0_?ooool008oooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o
0000_?ooool0097ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000034ooooo`00T_ooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Cooooo002Coooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool0`_ooool008oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Cooooo002?ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP34ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00SOooool01?l@413o0000ob4Q8Oo<c<cGooooo`00R?ooool2o`00
00Gooooo00?oQhN7oa0@4?ooool00oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0
003o^[Zjooooo`2jooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:kooooo`00O?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03ohN7Qol0003o^[Zj00?ooooo00Co410@o`000?l0003ooooo0_l000001Ol@
413ooooooooooooooooo000000Gooooo00?oQhN7o`000?nj^[X01?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00oooooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0
003o8B4Qolc<c02Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1_l0003ooooooooooooooooo0000ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B40Toooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000013ooooo1Ol00003
ooooo`05o`000?ooooooooooooooool00000Toooool007gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000oooo
o`Ko00002Oooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80Tooo
ool007gooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
1Ol0003oQhN7oooooonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooo
oonYZJWo0000013ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`000?l0003oc<c<
09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`Co00002_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00oooooo00?oMgMgolc<
c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o410@09?ooooo001mooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?ok^k^
odA4A?l000001?ooool01Ol0003o^[Zjoooooonj^[[o000009?ooooo001looooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool04Ooo
ool2o`0002Cooooo00?oMgMgo`000?ooool00oooool01OnYZJWo410@o`000?l@413oZJVY09?ooooo
002@ooooo`03oa0@4?oooooooooo0=Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(49) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.12 0 L
.12 0 L
F
0 g
.1 0 m
.1 0 L
.12 0 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
F
0 g
.12 0 m
.12 .00309 L
.14 .00309 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
F
0 g
.16 0 m
.16 .00618 L
.18 .00618 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 0 L
.2 0 L
.2 0 L
F
0 g
.18 0 m
.18 0 L
.2 0 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 .01545 L
.22 .01545 L
.22 0 L
F
0 g
.2 0 m
.2 .01545 L
.22 .01545 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 0 L
.24 0 L
.24 0 L
F
0 g
.22 0 m
.22 0 L
.24 0 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 0 L
.28 0 L
.28 0 L
F
0 g
.26 0 m
.26 0 L
.28 0 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
F
0 g
.28 0 m
.28 .01236 L
.3 .01236 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 0 L
.32 0 L
.32 0 L
F
0 g
.3 0 m
.3 0 L
.32 0 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 .04326 L
.34 .04326 L
.34 0 L
F
0 g
.32 0 m
.32 .04326 L
.34 .04326 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 .04017 L
.38 .04017 L
.38 0 L
F
0 g
.36 0 m
.36 .04017 L
.38 .04017 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 0 L
.4 0 L
.4 0 L
F
0 g
.38 0 m
.38 0 L
.4 0 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 .07107 L
.42 .07107 L
.42 0 L
F
0 g
.4 0 m
.4 .07107 L
.42 .07107 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 0 L
.44 0 L
.44 0 L
F
0 g
.42 0 m
.42 0 L
.44 0 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 .05562 L
.46 .05562 L
.46 0 L
F
0 g
.44 0 m
.44 .05562 L
.46 .05562 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 0 L
.48 0 L
.48 0 L
F
0 g
.46 0 m
.46 0 L
.48 0 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 .07107 L
.5 .07107 L
.5 0 L
F
0 g
.48 0 m
.48 .07107 L
.5 .07107 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 0 L
.52 0 L
.52 0 L
F
0 g
.5 0 m
.5 0 L
.52 0 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 .05562 L
.54 .05562 L
.54 0 L
F
0 g
.52 0 m
.52 .05562 L
.54 .05562 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 .05562 L
.58 .05562 L
.58 0 L
F
0 g
.56 0 m
.56 .05562 L
.58 .05562 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 0 L
.6 0 L
.6 0 L
F
0 g
.58 0 m
.58 0 L
.6 0 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 .04635 L
.62 .04635 L
.62 0 L
F
0 g
.6 0 m
.6 .04635 L
.62 .04635 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 0 L
.64 0 L
.64 0 L
F
0 g
.62 0 m
.62 0 L
.64 0 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 .05871 L
.66 .05871 L
.66 0 L
F
0 g
.64 0 m
.64 .05871 L
.66 .05871 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.68 0 L
.68 0 L
F
0 g
.66 0 m
.66 0 L
.68 0 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 .04017 L
.7 .04017 L
.7 0 L
F
0 g
.68 0 m
.68 .04017 L
.7 .04017 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 0 L
.72 0 L
.72 0 L
F
0 g
.7 0 m
.7 0 L
.72 0 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
F
0 g
.72 0 m
.72 .02472 L
.74 .02472 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
F
0 g
.76 0 m
.76 .00618 L
.78 .00618 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 0 L
.8 0 L
.8 0 L
F
0 g
.78 0 m
.78 0 L
.8 0 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
F
0 g
.8 0 m
.8 .00309 L
.82 .00309 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.88 0 L
.88 0 L
F
0 g
.86 0 m
.86 0 L
.88 0 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
F
0 g
.88 0 m
.88 .00309 L
.9 .00309 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 0 L
.92 0 L
.92 0 L
F
0 g
.9 0 m
.9 0 L
.92 0 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 .00309 L
.94 .00309 L
.94 0 L
F
0 g
.92 0 m
.92 .00309 L
.94 .00309 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 .00309 L
.98 .00309 L
.98 0 L
F
0 g
.96 0 m
.96 .00309 L
.98 .00309 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 .0001 m
.00942 .00013 L
.0201 .00017 L
.03125 .00023 L
.04169 .0003 L
.06036 .00047 L
.07084 .0006 L
.08043 .00075 L
.09045 .00093 L
.10112 .00117 L
.12033 .00174 L
.13209 .00219 L
.14316 .00271 L
.16386 .00393 L
.18438 .00557 L
.20605 .00783 L
.24486 .01352 L
.26478 .01735 L
.28613 .02214 L
.32464 .03236 L
.36627 .04476 L
.41154 .05762 L
.43263 .06257 L
.44419 .06483 L
.45503 .06663 L
.46501 .06797 L
.47416 .06893 L
.47911 .06933 L
.48431 .06966 L
.48684 .06978 L
.48954 .0699 L
.49109 .06995 L
.4925 .06999 L
.49526 .07005 L
.49776 .07008 L
.50011 .07009 L
.50269 .07007 L
.50545 .07004 L
.50683 .07001 L
.50834 .06997 L
.51109 .06987 L
.51624 .06963 L
.5211 .06931 L
.52627 .06889 L
.53557 .0679 L
.54739 .06626 L
.55851 .06434 L
.57926 .05989 L
.66037 .03675 L
.70153 .02522 L
Mistroke
.72331 .01994 L
.74663 .01508 L
.76914 .01121 L
.78963 .00835 L
.80908 .00619 L
.8297 .0044 L
.85059 .00304 L
.86989 .00211 L
.89065 .00139 L
.90246 .00109 L
.91353 .00086 L
.92394 .00068 L
.93531 .00052 L
.94534 .00041 L
.95603 .00032 L
.9666 .00024 L
.97619 .00019 L
.98512 .00015 L
.99492 .00012 L
Mfstroke
.99492 .00012 m
1 .0001 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool00ol0003oooooooooo`02oooooaKo000000?oooooo`000?oo0000
0ooo00000ol0003oooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
0ooooolAo`0000Gooooo1ol00005ooooo`Ko00001Oooool6o`0001?ooooo00?o0000ooooooooool0
8_ooool003[ooooo00?o0000ooooooooool03Oooool7o`0000Cooooo1ol0000@ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooooa7o00005_oo
ool00ol0003oooooooooo`0Tooooo`Co00009?ooool005Kooooo00?o0000ool00?oo00000_oo0005
o`0000cooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo00;ooooo1_l0001aooooo`00E_ooool6o`00
00Cooooo1_l0000Aooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool000;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`04o`000?oo003oo`00
ool000Ko0000D_ooool00ol0003oooooooooo`0Rooooo`00I_ooool6o`0000_ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`Co000000?oo`00o`000?ooool0EOooool00ol@
413oooooooooo`0Rooooo`00K?ooool5o`0000Kooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`04o`0000Coo`0000?o0000ooooooooool0NOooool0077ooooo0ol00003ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`04o`00
0?oo003oo`00ool000Co00000oooool6o`0007_ooooo001dooooo`Co00001Ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00oooool4o`000003ool00?l0003ooooo08Gooooo001gooooo`Co00000_oo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooo000000Co00001?oo00000ol0003ooooooooo
o`24ooooo`00Moooool01?l0003oo`00ool00?oo0004o`0000?ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`04o`000?oo003oo`00ool000Co00001?ooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo08Cooooo001gooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooool000002Ol00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`Co00000_oo00000ol0003oooooooooo`03ooooo`Ko0000Q_oo
ool007Oooooo1ol00005ooooo`Co00001_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00ol00005ool00003o`000?oooooooooo08oooooo0027oooo
o`?o00000oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00004oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo2Ol00002ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Soooool008[ooooo1?l00005ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`04ooooo`?o00001_ooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo08oooooo002=ooooo`?o00000ooo00000ol0003oooooooooo`03ooooo`Ko0000
1Oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo1_l00005ooooo`Oo0000
0oooool3o`0000Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?ooooo`00SOoo
ool00ol0003oo`00ool00005o`0000oooooo00?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0Eooooo`?o00003?ooool7o`00097ooooo002=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooool000000ol0000;ooooo`03o`000?oo003oo`0000;oo`000_l0000Booooo`Co0000Yoooool0
08gooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00Wooooo2?l0002[ooooo`00SOooool00ol0003o
o`00ool00003ool00004o`000?ooooooooooooooo`Go00000ooooolFo`000;?ooooo002=ooooo`Oo
00000oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgo`000?l000001?l0002noooo
o`00V?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0ol0002looooo`00
VOooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
_?ooool009[ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0_?ooool009_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooo
oooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002Kooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009cooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;cooooo002Kooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`?o0000_?ooool009Sooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wo
oooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009Wooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00V_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00V_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2l
ooooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0_?ooool009Oooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00004ooooo`Co00001Oooool2o`000;go
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000
_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000000ol@413oooooooooo`05
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00oooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0_?ooool0
09;ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0093ooooo
00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`;o
0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093o
oooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooo
ooooool0_?ooool009;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103oooo
o`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`06ooooo`05
ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool0
093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0093ooooo1?l000000ol@413ooooooooo
o`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooo
oooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01Oooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;co
oooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol00004ooooo`Co00001Oooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002?ooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo0;cooooo002?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Aooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000a?ooool009;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000034ooooo`00Toooool01Ol0003ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo0<;ooooo002?oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008go
oooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413ooooo00?o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool008Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7QhOo0000
okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`000005oooo
o`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0?
ooooo`;o000000So410@oooooooooooooooooa0@4?l0003oA4A4olc<c9Cooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?ooooooooooooooool0003ooooo1_l0
000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RHoa0@4?oMgMd0Toooool007gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo0000013ooooo1Ol00006ooooo`03ohN7QomEEEGooooo09;ooooo001mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Ko0000oooo
ooooooooooooo`000?ooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo<c<co8B4Q
o`000?mEEEGo000009?ooooo001mooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`03o`000?oooooooooo00_o
oooo00Go0000ohN7QoooooooZJVYo`00000@ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go8B4Q
ohN7QoooooooV9RHo`00002Cooooo`00OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool4o`0000[ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0?ooooo`03ogMgMoo<c<co000000Cooooo00Go0000ooooooooooooooooo`00002Cooooo`00OOoo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Qooooo`03onk^k_m4A4Co000000Cooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@2Cooooo`00
O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l00006ooooo`03
o`000?oooooooooo017ooooo0_l0000Tooooo`03ogMgMol0003ooooo00?ooooo00Goc<c<oa0@4?l0
003o<S8bonk^kP2Cooooo`00T?ooool00ol@413oooooooooo`3Eooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.02 0 0.00309017 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .07725 -12 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -12 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-20)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-10)] .3 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(10)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(20)] .9 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
[(25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(50)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(100)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(125)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(150)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(175)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(200)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 0 L
.02 0 L
.02 0 L
F
0 g
.5 Mabswid
0 0 m
0 0 L
.02 0 L
.02 0 L
0 0 L
s
1 0 0 r
.02 0 m
.02 0 L
.04 0 L
.04 0 L
F
0 g
.02 0 m
.02 0 L
.04 0 L
.04 0 L
.02 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.08 0 L
.08 0 L
F
0 g
.06 0 m
.06 0 L
.08 0 L
.08 0 L
.06 0 L
s
1 0 0 r
.08 0 m
.08 0 L
.1 0 L
.1 0 L
F
0 g
.08 0 m
.08 0 L
.1 0 L
.1 0 L
.08 0 L
s
1 0 0 r
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
F
0 g
.1 0 m
.1 .00309 L
.12 .00309 L
.12 0 L
.1 0 L
s
1 0 0 r
.12 0 m
.12 0 L
.14 0 L
.14 0 L
F
0 g
.12 0 m
.12 0 L
.14 0 L
.14 0 L
.12 0 L
s
1 0 0 r
.14 0 m
.14 .00309 L
.16 .00309 L
.16 0 L
F
0 g
.14 0 m
.14 .00309 L
.16 .00309 L
.16 0 L
.14 0 L
s
1 0 0 r
.16 0 m
.16 0 L
.18 0 L
.18 0 L
F
0 g
.16 0 m
.16 0 L
.18 0 L
.18 0 L
.16 0 L
s
1 0 0 r
.18 0 m
.18 .00927 L
.2 .00927 L
.2 0 L
F
0 g
.18 0 m
.18 .00927 L
.2 .00927 L
.2 0 L
.18 0 L
s
1 0 0 r
.2 0 m
.2 0 L
.22 0 L
.22 0 L
F
0 g
.2 0 m
.2 0 L
.22 0 L
.22 0 L
.2 0 L
s
1 0 0 r
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
F
0 g
.22 0 m
.22 .00927 L
.24 .00927 L
.24 0 L
.22 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.26 0 m
.26 .00927 L
.28 .00927 L
.28 0 L
F
0 g
.26 0 m
.26 .00927 L
.28 .00927 L
.28 0 L
.26 0 L
s
1 0 0 r
.28 0 m
.28 0 L
.3 0 L
.3 0 L
F
0 g
.28 0 m
.28 0 L
.3 0 L
.3 0 L
.28 0 L
s
1 0 0 r
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
F
0 g
.3 0 m
.3 .02472 L
.32 .02472 L
.32 0 L
.3 0 L
s
1 0 0 r
.32 0 m
.32 0 L
.34 0 L
.34 0 L
F
0 g
.32 0 m
.32 0 L
.34 0 L
.34 0 L
.32 0 L
s
1 0 0 r
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
F
0 g
.34 0 m
.34 .03708 L
.36 .03708 L
.36 0 L
.34 0 L
s
1 0 0 r
.36 0 m
.36 0 L
.38 0 L
.38 0 L
F
0 g
.36 0 m
.36 0 L
.38 0 L
.38 0 L
.36 0 L
s
1 0 0 r
.38 0 m
.38 .05871 L
.4 .05871 L
.4 0 L
F
0 g
.38 0 m
.38 .05871 L
.4 .05871 L
.4 0 L
.38 0 L
s
1 0 0 r
.4 0 m
.4 0 L
.42 0 L
.42 0 L
F
0 g
.4 0 m
.4 0 L
.42 0 L
.42 0 L
.4 0 L
s
1 0 0 r
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
F
0 g
.42 0 m
.42 .06489 L
.44 .06489 L
.44 0 L
.42 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.46 0 m
.46 .06798 L
.48 .06798 L
.48 0 L
F
0 g
.46 0 m
.46 .06798 L
.48 .06798 L
.48 0 L
.46 0 L
s
1 0 0 r
.48 0 m
.48 0 L
.5 0 L
.5 0 L
F
0 g
.48 0 m
.48 0 L
.5 0 L
.5 0 L
.48 0 L
s
1 0 0 r
.5 0 m
.5 .05871 L
.52 .05871 L
.52 0 L
F
0 g
.5 0 m
.5 .05871 L
.52 .05871 L
.52 0 L
.5 0 L
s
1 0 0 r
.52 0 m
.52 0 L
.54 0 L
.54 0 L
F
0 g
.52 0 m
.52 0 L
.54 0 L
.54 0 L
.52 0 L
s
1 0 0 r
.54 0 m
.54 .05253 L
.56 .05253 L
.56 0 L
F
0 g
.54 0 m
.54 .05253 L
.56 .05253 L
.56 0 L
.54 0 L
s
1 0 0 r
.56 0 m
.56 0 L
.58 0 L
.58 0 L
F
0 g
.56 0 m
.56 0 L
.58 0 L
.58 0 L
.56 0 L
s
1 0 0 r
.58 0 m
.58 .05871 L
.6 .05871 L
.6 0 L
F
0 g
.58 0 m
.58 .05871 L
.6 .05871 L
.6 0 L
.58 0 L
s
1 0 0 r
.6 0 m
.6 0 L
.62 0 L
.62 0 L
F
0 g
.6 0 m
.6 0 L
.62 0 L
.62 0 L
.6 0 L
s
1 0 0 r
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
F
0 g
.62 0 m
.62 .04944 L
.64 .04944 L
.64 0 L
.62 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.66 0 m
.66 .04635 L
.68 .04635 L
.68 0 L
F
0 g
.66 0 m
.66 .04635 L
.68 .04635 L
.68 0 L
.66 0 L
s
1 0 0 r
.68 0 m
.68 0 L
.7 0 L
.7 0 L
F
0 g
.68 0 m
.68 0 L
.7 0 L
.7 0 L
.68 0 L
s
1 0 0 r
.7 0 m
.7 .03399 L
.72 .03399 L
.72 0 L
F
0 g
.7 0 m
.7 .03399 L
.72 .03399 L
.72 0 L
.7 0 L
s
1 0 0 r
.72 0 m
.72 0 L
.74 0 L
.74 0 L
F
0 g
.72 0 m
.72 0 L
.74 0 L
.74 0 L
.72 0 L
s
1 0 0 r
.74 0 m
.74 .01545 L
.76 .01545 L
.76 0 L
F
0 g
.74 0 m
.74 .01545 L
.76 .01545 L
.76 0 L
.74 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.78 0 L
.78 0 L
F
0 g
.76 0 m
.76 0 L
.78 0 L
.78 0 L
.76 0 L
s
1 0 0 r
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.78 0 m
.78 .00618 L
.8 .00618 L
.8 0 L
.78 0 L
s
1 0 0 r
.8 0 m
.8 0 L
.82 0 L
.82 0 L
F
0 g
.8 0 m
.8 0 L
.82 0 L
.82 0 L
.8 0 L
s
1 0 0 r
.82 0 m
.82 0 L
.84 0 L
.84 0 L
F
0 g
.82 0 m
.82 0 L
.84 0 L
.84 0 L
.82 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
F
0 g
.86 0 m
.86 .00309 L
.88 .00309 L
.88 0 L
.86 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.9 0 L
.9 0 L
F
0 g
.88 0 m
.88 0 L
.9 0 L
.9 0 L
.88 0 L
s
1 0 0 r
.9 0 m
.9 .00309 L
.92 .00309 L
.92 0 L
F
0 g
.9 0 m
.9 .00309 L
.92 .00309 L
.92 0 L
.9 0 L
s
1 0 0 r
.92 0 m
.92 0 L
.94 0 L
.94 0 L
F
0 g
.92 0 m
.92 0 L
.94 0 L
.94 0 L
.92 0 L
s
1 0 0 r
.94 0 m
.94 .00309 L
.96 .00309 L
.96 0 L
F
0 g
.94 0 m
.94 .00309 L
.96 .00309 L
.96 0 L
.94 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.98 0 L
.98 0 L
F
0 g
.96 0 m
.96 0 L
.98 0 L
.98 0 L
.96 0 L
s
1 0 0 r
.98 0 m
.98 0 L
1 0 L
1 0 L
F
0 g
.98 0 m
.98 0 L
1 0 L
1 0 L
.98 0 L
s
1 0 0 r
1 0 m
1 0 L
1.02 0 L
1.02 0 L
F
0 g
1 0 m
1 0 L
s
1 0 m
0 0 rlineto s
0 .00012 m
.0105 .00015 L
.02188 .0002 L
.03253 .00027 L
.05157 .00042 L
.06226 .00054 L
.07204 .00068 L
.08226 .00085 L
.09315 .00107 L
.11273 .0016 L
.12473 .00203 L
.13603 .00251 L
.15713 .00368 L
.17807 .00524 L
.20017 .00742 L
.23975 .01295 L
.26008 .01671 L
.28185 .02142 L
.32113 .03155 L
.3636 .04392 L
.40977 .05682 L
.43129 .0618 L
.44307 .06409 L
.45413 .0659 L
.46431 .06726 L
.47364 .06822 L
.47869 .06862 L
.484 .06896 L
.48658 .06908 L
.48933 .0692 L
.49091 .06925 L
.49235 .06929 L
.49516 .06935 L
.49772 .06938 L
.50011 .06939 L
.50274 .06938 L
.50556 .06934 L
.50697 .06931 L
.50851 .06927 L
.51131 .06917 L
.51656 .06892 L
.52152 .06861 L
.5268 .06818 L
.53629 .06719 L
.54834 .06553 L
.55968 .06359 L
.58084 .05911 L
.66358 .03592 L
.70556 .02446 L
.72778 .01925 L
Mistroke
.75156 .01448 L
.77452 .0107 L
.79542 .00793 L
.81643 .00573 L
.8363 .00412 L
.85705 .00285 L
.87906 .00188 L
.89785 .00129 L
.91855 .00083 L
.92967 .00065 L
.94025 .00051 L
.96011 .00032 L
.97119 .00024 L
.98148 .00019 L
.99278 .00014 L
Mfstroke
.99278 .00014 m
1 .00012 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0[oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kV3ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^:oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP19ooooo`00=oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0]ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Rooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg04Wooooo000_ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41008_ooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@04Wooooo000iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001R
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000019ooooo`00>_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000H_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000;_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000BOooool0
03_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@06;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo04Oooooo000gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg06;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool003Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0H?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`04oa0@4?l0003o8B4Qolc<c2Cooooo003ooooood?o
oooo00?oQhN7oa0@4?ooool08oooool00?ooooooA?ooool00ol0003oooooooooo`0Rooooo`00oooo
oom4ooooo`03o`000?oooooooooo02;ooooo003oooooodCooooo00?o0000ooooooooool08_ooool0
0?ooooooA?ooool00ol0003oooooooooo`0Rooooo`007_ooooooo`0001Wo00003Oooool00ol0003o
ooooooooo`0Rooooo`00>_ooool6o`0000Cooooo4?l00002ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo000001Co0000
1Oooool7o`0000Cooooo1ol0000Hooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oo
oooooooo01?ooooo4_l00004ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool8o`0001[ooooo00?o0000ooooooooool09?oo
ool4o`0002Cooooo001Mooooo`Ko00003_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`001ol0001_ooooo`00Hoooool3o`0000_ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`00
053ooooo00?o0000ooooooooool08_ooool006Kooooo1?l00007ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool000Go0000Eoooool00ol@413o
ooooooooo`0Rooooo`00J_ooool5o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`04o`000?oo003oo`00ool000?o0000P?ooool006oooooo2Ol00005ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`Co0000
0_oo00000ol0003oooooooooo`1nooooo`00Loooool3o`0000Oooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_oo
ool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool000Ko00001Ooo00000ol0003oooooooooo`1nooooo`00M_ooool4
o`0000?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00004o`0000Cooooo1ol00020
ooooo`00N_ooool9o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`02oooo
o`Co00000ooo00000ol0003oooooooooo`29ooooo`00O_ooool4o`0000Kooooo00?o0000ool00?oo
00000_oo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo0005o`000003ooooool0003oo`0000Coo`0000?o0000ooooooooool0ROooool008;ooooo
1?l00002ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003o000000?o00001Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo08Wooooo0026ooooo`?o00001?oo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo
oooooooo00;ooooo0ol00003ool00003o`000?oooooooooo00?ooooo1ol0002;ooooo`00R?ooool4
o`000003ool00?l0003ooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000;oo`001Ol000000ooooooo0000o`000004o`0009Oooooo0028oooo
o`04o`000?oo003oo`00ool000?o00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ool00?l000000ol0002R
ooooo`00R?ooool6o`000003ooooool0003o000000?o00001Ooo00000ol0003oooooooooo`02oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool7o`0000oooooo1ol0002Roooo
o`00Toooool7o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`;o
00004Oooool3o`000:Wooooo002Cooooo`co00001Ooo00000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo1ol0002/ooooo`00Uoooool5o`0000;ooooo5ol0002cooooo`00Uoooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`2looooo`00V?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0ol0002l
ooooo`00VOooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0_?ooool009[ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0_?ooool009_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;cooooo002Gooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l0002mooooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2l
ooooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002m
ooooo`00V?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002Kooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0_?ooool009cooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;cooooo002Kooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`?o0000_?ooool009Sooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`2looooo`00V?ooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2looooo`00V?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Ooo
ool00:Wooooo00?o0000ooooooooool0_?ooool009Wooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool009Wooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Iooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2looooo`00
V_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0002looooo`00V_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`2looooo`00V_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0_?ooool009Oooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0_?ooool009Oooooo1Ol00004ooooo`Co00001Oooool2
o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002@
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0002looooo`00T_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2loooo
o`00T_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0002mooooo`00T?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0093ooooo1?l000000ol@413ooooo
ooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;co
oooo002Booooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool0
0oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
_?ooool009;ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;cooooo002B
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00;ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0_?ooool0
093ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005
ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooooooo
ool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?oo
ool0093ooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOoooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003o
ooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0_?ooool009;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00?ooooo0ol0002looooo`00T_ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2looooo`00T_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
_?ooool0093ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00
ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool0
0ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;co
oooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool0093ooooo1?l000000ol@413o
ooooooooo`02ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;cooooo002Booooo`03o`00
0?oooooooooo00Cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;cooooo002Booooo`03o`000?oooooooooo00Gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`03ooooo`?o0000_?ooool009;ooooo00?o0000ooooooooool01Oooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`2looooo`00T_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2looooo`00T_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0;cooooo002@ooooo`03oeEEEOmVIVKo000000Cooooo1Ol00004ooooo`Co00001Oooool2o`00
0;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooo
ooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002?oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo0;cooooo002?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo0;cooooo002@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`000;cooooo002Aooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000a?ooool009;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000034ooooo`00Toooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo0<;ooooo
002?ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`34ooooo`00Soooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0a?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool008gooooo00Co410@o`000?lQ8B7oc<c<eoooool008Sooooo0_l00005ooooo`03ohN7Qol@413o
oooo00?ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0^_ooool0
08Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o<S8b3_ooool00ol0
003oooooooooo`03ooooo`;o<S8b^oooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00on7
QhOo0000okZj^P03ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@ooooooooooooooooo`00
0005ooooo`03ohN7Qol0003o^[Zj00Cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0>ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06o`000?oooooo
ooooooooool0003ooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9So
MgMg09?ooooo001mooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool0TOooool007gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Ko00003Ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0TOooool007gooooo1Ol0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003oQhN7oooo
oonYZJWo000000Cooooo00?o0000ooooooooool02oooool01Ol0003oQhN7oooooonYZJWo0000017o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000Toooool0
07gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo1?l0000:
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool03oooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@4100Toooool007gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Toooool007cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`;o0000
8oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Cooooo`00T?ooool00ol@413ooooo
ooooo`3Eooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.4073, -17.088, 0.223898, \
1.4491}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "For simplicity in the graphics, we evaluated  ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " using Eq. ",
  ButtonBox["(8.1.15)",
    ButtonData:>{"Chapter8.nb", "(8.1.15)"},
    ButtonStyle->"Hyperlink"],
  " only, for real values of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", although only integer values of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`j + n\)]],
  " even should have been allowed.  Fortunately, Eq. ",
  ButtonBox["(8.1.15)",
    ButtonData:>{"Chapter8.nb", "(8.1.15)"},
    ButtonStyle->"Hyperlink"],
  " is a smooth function of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", and we can see that ",
  Cell[BoxData[
      FormBox[
        RowBox[{Cell[""], "M", " ", \(P(j, n)\)}], TraditionalForm]]],
  " nicely tracks the  histograms from the simulation. [Question: why do we \
need the factor of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`M\ \(P(j, n)\)\)]],
  " in order to match the histograms?]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Averages", "Section",
  CellTags->"c:8"],

Cell[TextData[{
  " We can use the binomial distribution to understand the behavior of \
average quantities such as  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((n)\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  ". The average of a general function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " of the particle positions can be written as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "f", "\[RightAngleBracket]"}], \((n)\)}], 
          " ", "=", \(lim\+\(M \[Rule] \ \[Infinity]\)\ \(1\/M\) \
\(\[Sum]\_\(k = 1\)\%M f(x\_k\%n)\)\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.17)"],

Cell[TextData[{
  "where the sum is over the particles. This is the method used previously to \
evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "x", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  "; see Eqs. ",
  ButtonBox["(8.1.8)",
    ButtonData:>{"Chapter8.nb", "(8.1.8)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.1.10)",
    ButtonData:>{"Chapter8.nb", "(8.1.10)"},
    ButtonStyle->"Hyperlink"],
  ". However, there is a better way to evaluate this average, in terms of the \
probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  ". First, we note that the particles can be grouped onto their grid \
locations ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`H(j, n)\)]],
  " giving the number of particles on each grid point. Then an equivalent way \
to do the sum over particles in Eq. ",
  ButtonBox["(8.1.17)",
    ButtonData:>{"Chapter8.nb", "(8.1.17)"},
    ButtonStyle->"Hyperlink"],
  "  is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "f", "\[RightAngleBracket]"}], \((n)\)}], 
          " ", "=", \(lim\+\(M \[Rule] \ \[Infinity]\)\ \(1\/M\) \
\(\[Sum]\_\(j = \(-n\)\)\%n\ \(H(j, n)\) \(f(x\_j)\)\)\)}], ","}], 
      TraditionalForm]]]], "UNNEQ"],

Cell[TextData[{
  "where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " and now the sum runs over all the possible grid positions. Using Eq. ",
  ButtonBox["(8.1.6)",
    ButtonData:>{"Chapter8.nb", "(8.1.6)"},
    ButtonStyle->"Hyperlink"],
  " then yields the important result"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "f", "\[RightAngleBracket]"}], \((n)\)}], 
        " ", "=", \(\[Sum]\+j\ \(P(j, n)\) \(\(f(x\_j)\)\(.\)\)\)}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->{"i:14", "(8.1.18)"}],

Cell[TextData[{
  "We need not sum over all the particle positions to determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "f", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  "; rather, we can sum over the probabilities of different states of the \
system. With this formula, we can prove several other useful results. For \
example, for any two functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  ", and for any constant ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", Eq. ",
  ButtonBox["(8.1.18)",
    ButtonData:>{"Chapter8.nb", "(8.1.18)"},
    ButtonStyle->"Hyperlink"],
  " immediately implies that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(f + c\ \ g\), "\[RightAngleBracket]"}], " ",
         "=", " ", 
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "f", "\[RightAngleBracket]"}], " ", "+", 
          " ", 
          RowBox[{"c", " ", 
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "g", "\[RightAngleBracket]"}], 
              "."}]}]}]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(8.1.19)"],

Cell["Thus, taking an average is a linear operation. ", "Text",
  CellTags->"i:15"],

Cell[TextData[{
  "\tWe can apply  Eq. ",
  ButtonBox["(8.1.18)",
    ButtonData:>{"Chapter8.nb", "(8.1.18)"},
    ButtonStyle->"Hyperlink"],
  ", along with Eq. ",
  ButtonBox["(8.1.15)",
    ButtonData:>{"Chapter8.nb", "(8.1.15)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.1.16)",
    ButtonData:>{"Chapter8.nb", "(8.1.16)"},
    ButtonStyle->"Hyperlink"],
  ",   to calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((n)\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  ".  These averages can be calculated by means of the ",
  StyleBox["binomial theorem. ",
    FontSlant->"Italic"],
  "This theorem states that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sum]\_\(n\_R = 0\)\%n\(\( 
                  n!\)\/\(\(n\_R!\) \((n - \(n\_R!\))\)\)\) \(p\^n\_R\) 
            q\^\(n - n\_R\)\)\(=\)\(\((p + q)\)\^n\)\(\ \)\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.20)"],

Cell[TextData[{
  "However, the argument of the sum can be directly related to ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  ". According to Eq. ",
  ButtonBox["(8.1.14)",
    ButtonData:>{"Chapter8.nb", "(8.1.14)"},
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n\_R = 0\)\%n\ \(\(=\)\(\ \)\(\[Sum]\_\(j \
= \(-n\), \ \(-n\) + 2, \(-n\) + 4,  ... , n\)\)\)\)]],
  " ."
}], "NumberedEquation",
  CellTags->"(8.1.21)"],

Cell[TextData[{
  "Also, the argument of the sum in Eq. ",
  ButtonBox["(8.1.20)",
    ButtonData:>{"Chapter8.nb", "(8.1.20)"},
    ButtonStyle->"Hyperlink"],
  " is just the value of the binomial distribution ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`j + n\)]],
  " even. Therefore, Eq. ",
  ButtonBox["(8.1.20)",
    ButtonData:>{"Chapter8.nb", "(8.1.20)"},
    ButtonStyle->"Hyperlink"],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(j = \(-n\)\)\%n P(j, 
            n) = \(\((p + q)\)\^n = 1\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(8.1.22)"],

Cell[TextData[{
  "where in the last step we used the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`p + q = 1\)]],
  ". Of course, Eq. ",
  ButtonBox["(8.1.22)",
    ButtonData:>{"Chapter8.nb", "(8.1.22)"},
    ButtonStyle->"Hyperlink"],
  " is merely a restatement of the general property of probability \
distributions, Eq. ",
  ButtonBox["(8.1.7)",
    ButtonData:>{"Chapter8.nb", "(8.1.7)"},
    ButtonStyle->"Hyperlink"],
  ". However,  we can also use Eq. ",
  ButtonBox["(8.1.22)",
    ButtonData:>{"Chapter8.nb", "(8.1.22)"},
    ButtonStyle->"Hyperlink"],
  " to calculate averages. ",
  StyleBox["\n\t",
    FontSlant->"Italic"],
  "For ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((n)\)}], 
        TraditionalForm]]],
  ", we note that Eq. ",
  ButtonBox["(8.1.14)",
    ButtonData:>{"Chapter8.nb", "(8.1.14)"},
    ButtonStyle->"Hyperlink"],
  " implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], " ", "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              RowBox[{"j", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "\[RightAngleBracket]"}], 
            " ", "=", "  ", 
            RowBox[{
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(2  n\_R - \ n\), 
                  "\[RightAngleBracket]"}]}], " ", "=", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", 
                      RowBox[{
                        FormBox["\[LeftAngleBracket]",
                          "TraditionalForm"], \(n\_R\), 
                        "\[RightAngleBracket]"}]}], " ", "-", " ", "n"}], 
                  ")"}]}]}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(8.1.23)"],

Cell[TextData[{
  "where in the third and fourth steps we applied Eq. ",
  ButtonBox["(8.1.19)",
    ButtonData:>{"Chapter8.nb", "(8.1.19)"},
    ButtonStyle->"Hyperlink"],
  ". However, according to Eqs. ",
  ButtonBox["(8.1.18)",
    ButtonData:>{"Chapter8.nb", "(8.1.18)"},
    ButtonStyle->"Hyperlink"],
  ",  ",
  ButtonBox["(8.1.15)",
    ButtonData:>{"Chapter8.nb", "(8.1.15)"},
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(8.1.16)",
    ButtonData:>{"Chapter8.nb", "(8.1.16)"},
    ButtonStyle->"Hyperlink"],
  " the average number of steps to the right after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(n\_R\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  ", can be evaluated as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(n\_R\), 
                "\[RightAngleBracket]"}], \((n)\)}], 
            "=", \(\[Sum]\_\(j = \(-n\), \ \(-n\) + 2, \(-n\) + 4,  ... , \
n\)n\_R\ \(P(j, 
                    n)\)\ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  = \[Sum]\_\(n\_R = 0\)\%n\( 
                      n\_R\) \(\(n!\)\/\(\(n\_R!\) \(\((n - 
                              n\_R)\)!\)\)\) \(p\^n\_R\) q\^\(n - n\_R\)\)}], 
          ","}], TraditionalForm]]],
  " "
}], "NumberedEquation",
  CellTags->"(8.1.24)"],

Cell[TextData[{
  "where in the second step we have applied Eq. ",
  ButtonBox["(8.1.21)",
    ButtonData:>{"Chapter8.nb", "(8.1.21)"},
    ButtonStyle->"Hyperlink"],
  ". This sum can be carried out analytically by noticing that ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\ p\^n\_R = \ 
        p\ \[PartialD]\ \((p\^n\_R)\)/\[PartialD]p\)]],
  ". Applying this identity to Eq. ",
  ButtonBox["(8.1.22)",
    ButtonData:>{"Chapter8.nb", "(8.1.22)"},
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(n\_R\), 
              "\[RightAngleBracket]"}], \((n)\)}], 
          "=", \(p \(\[PartialD]\/\[PartialD]p\) \(\[Sum]\_\(n\_R = \
0\)\%n\(\( n!\)\/\(\(n\_R!\) \((n - \(n\_R!\))\)\)\) \(p\^n\_R\) 
                  q\^\(n - n\_R\)\) = \(p \(\[PartialD]\/\[PartialD]p\) \((p \
+ q)\)\^n = \(n\ p\ \((p + q)\)\^\(n - 1\) = \ n\ p\)\)\)}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.25)"],

Cell[TextData[{
  "In the second step we have employed the binomial theorem, Eq. ",
  ButtonBox["(8.1.20)",
    ButtonData:>{"Chapter8.nb", "(8.1.20)"},
    ButtonStyle->"Hyperlink"],
  ". Equation ",
  ButtonBox["(8.1.25)",
    ButtonData:>{"Chapter8.nb", "(8.1.25)"},
    ButtonStyle->"Hyperlink"],
  " is eminently reasonable: in any one step, the probability of a step to \
the right is ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", so after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps one expects to have taken an average number of steps ",
  Cell[BoxData[
      \(TraditionalForm\`n\ p\)]],
  " to the right."
}], "Text"],

Cell[TextData[{
  "\tSubstitution of this result into Eq. ",
  ButtonBox["(8.1.23)",
    ButtonData:>{"Chapter8.nb", "(8.1.23)"},
    ButtonStyle->"Hyperlink"],
  " then yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], " ", "=", 
          " ", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", \((\ 2  p\ n\  - \ n)\)}], 
            " ", "=", " ", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", \((p\  - \ q)\)}]}]}], 
        TraditionalForm]]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:16", "(8.1.26)"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ \(q = 1/2\)\)]],
  ", then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], " ", "=", 
          " ", "0"}], TraditionalForm]]],
  " for all time, as we expected; see Eq. ",
  ButtonBox["(8.1.9)",
    ButtonData:>{"Chapter8.nb", "(8.1.9)"},
    ButtonStyle->"Hyperlink"],
  ". However, for ",
  Cell[BoxData[
      \(TraditionalForm\`p \[NotEqual] \ q\)]],
  ", there is a net drift of the particle distribution at constant velocity \
",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], " ", "=", 
          " ", \(v\ t\)}], TraditionalForm]]],
  ", where the drift velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"v", " ", "=", 
          RowBox[{\((p - q)\), 
            FractionBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]], " "}]}], TraditionalForm]]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.27)"],

Cell[TextData[{
  "\tWe will have more to say concerning this drift later, but first let us \
turn to the evaluation of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ".  We follow the same procedure as for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "x", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ". Using Eqs.  ",
  ButtonBox["(8.1.14)",
    ButtonData:>{"Chapter8.nb", "(8.1.14)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.1.19)",
    ButtonData:>{"Chapter8.nb", "(8.1.19)"},
    ButtonStyle->"Hyperlink"],
  "  we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              RowBox[{\(j\^\(\(2\)\(\ \)\)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]}], 
              "\[RightAngleBracket]"}], " ", "=", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"], 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(\((2\ n\_R - n)\)\^2\), 
                  "\[RightAngleBracket]"}]}], " ", "=", " ", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"], "(", 
                RowBox[{
                  RowBox[{"4", " ", 
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], \(n\_R\^2\), 
                      "\[RightAngleBracket]"}]}], " ", "-", " ", 
                  RowBox[{"4", " ", 
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], \(n\_R\), 
                      "\[RightAngleBracket]"}], " ", "n"}], " ", "+", 
                  " ", \(n\^2\)}], ")"}]}]}]}], TraditionalForm]]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.28)"],

Cell[TextData[{
  "We already know ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(n\_R\), "\[RightAngleBracket]"}], " ", 
          "=", " ", \(n\ p\)}], TraditionalForm]]],
  ", so we only need to determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(n\_R\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ". Using a procedure analogous to Eq. ",
  ButtonBox["(8.1.24)",
    ButtonData:>{"Chapter8.nb", "(8.1.24)"},
    ButtonStyle->"Hyperlink"],
  " leads to \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(n\_R\^2\), 
              "\[RightAngleBracket]"}], \((n)\)}], 
          "=", \(\[Sum]\_\(n\_R = 0\)\%n\( n\_R\^2\) \(\(n!\)\/\(\(n\_R!\) \
\((n - \(n\_R!\))\)\)\) \(p\^n\_R\) 
                q\^\(n - n\_R\)\  = \ \(p \(\[PartialD]\/\[PartialD]p\) 
                p \(\[PartialD]\/\[PartialD]p\) \(\[Sum]\_\(n\_R = 0\)\%n\(\( 
                          n!\)\/\(\(n\_R!\) \((n - \(n\_R!\))\)\)\) \(p\^n\_R\
\) q\^\(n - n\_R\)\)\ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  = \(p \(\[PartialD]\/\[PartialD]p\) 
                  p \(\[PartialD]\/\[PartialD]p\) \((p + q)\)\^n = \(p \(\
\[PartialD]\/\[PartialD]p\) 
                    n\ p\ \((p + q)\)\^\(n - 1\)\  = \(n\ p\ \((p + q)\)\^\(n \
- 1\)\  + \ \ n\ \(\(p\^2\)(
                          n - 1)\) \((p + q)\)\^\(n - 2\)\[IndentingNewLine]\ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = 
                    n\ p\  + \ \(n(n - 1)\) \(\(p\^2\)\(.\)\)\)\)\)\)\)}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "where in the second step we employed the identity ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\^2\ p\^n\_R = \ 
        p \(\[PartialD]\/\[PartialD]p\) p \(\[PartialD]\/\[PartialD]p\) 
          p\^n\_R\)]],
  ". Applying this result to Eq. ",
  ButtonBox["(8.1.27)",
    ButtonData:>{"Chapter8.nb", "(8.1.27)"},
    ButtonStyle->"Hyperlink"],
  " yields, after some algebra, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " ", 
          "=", 
          RowBox[{
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "x", "\[RightAngleBracket]"}], "2"], 
            " ", "+", " ", 
            RowBox[{"4", " ", "n", " ", "p", " ", "q", "  ", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]}]}]}], 
        TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"i:17", "(8.1.29)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "x", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " is given by Eq.  ",
  ButtonBox["(8.1.26)",
    ButtonData:>{"Chapter8.nb", "(8.1.26)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor the case where ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  ", Eqs. ",
  ButtonBox["(8.1.29)",
    ButtonData:>{"Chapter8.nb", "(8.1.29)"},
    ButtonStyle->"Hyperlink"],
  " amd ",
  ButtonBox["(8.1.26)",
    ButtonData:>{"Chapter8.nb", "(8.1.26)"},
    ButtonStyle->"Hyperlink"],
  " yield ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " ", 
          "=", " ", 
          RowBox[{"n", " ", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], TraditionalForm]]],
  ". If we define a diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " as"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", " ", "=", 
          RowBox[{
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], "/", 
            RowBox[{"(", 
              RowBox[{"2", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], ")"}]}]}], 
        TraditionalForm]]],
  ", "
}], "NumberedEquation",
  CellTags->{"i:18", "(8.1.30)"}],

Cell[TextData[{
  "then Eq. ",
  ButtonBox["(8.1.29)",
    ButtonData:>{"Chapter8.nb", "(8.1.29)"},
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " ", 
          "=", " ", \(2\ D\ t\)}], TraditionalForm]]],
  ": the squared width of the distribution increases linearly with time, with \
slope ",
  Cell[BoxData[
      \(TraditionalForm\`2\ D\_o\)]],
  ".  This linear increase agrees with the behavior observed in the previous \
simulation (see Fig. ",
  ButtonBox["8.1",
    ButtonData:>"Fig. 8.1",
    ButtonStyle->"Hyperlink"],
  ") and also agrees with the solution to the heat equation starting from a \
concentrated heat pulse, Eq. ",
  ButtonBox["(5.1.100)",
    ButtonData:>{"Chapter5.nb", "(5.1.100)"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\t For ",
  Cell[BoxData[
      \(TraditionalForm\`p \[NotEqual] \ q\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " "}], 
        TraditionalForm]]],
  "by itself is no-longer a good measure of the change in the width of the \
distribution.  A better measure is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " ", "\[Congruent]", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"x", "-", 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], "x", "\[RightAngleBracket]"}]}], 
                ")"}], "2"], "\[RightAngleBracket]"}]}], TraditionalForm]]],
  ", the mean squared change in the position from the average position. \
However, if we expand the expression and use Eq.  ",
  ButtonBox["(8.1.29)",
    ButtonData:>{"Chapter8.nb", "(8.1.29)"},
    ButtonStyle->"Hyperlink"],
  " we obtain"
}], "Text",
  CellTags->"i:79"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
        " ", "=", 
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"x", "-", 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], "x", "\[RightAngleBracket]"}]}], 
                ")"}], \(\(2\)\(\ \)\)], "\[RightAngleBracket]"}], " ", "=", 
          " ", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            RowBox[{\(x\^2\), "-", 
              RowBox[{"2", " ", "x", " ", 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], "x", "\[RightAngleBracket]"}]}], " ", 
              "+", " ", 
              SuperscriptBox[
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], "x", "\[RightAngleBracket]"}], "2"]}],
             "\[RightAngleBracket]"}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"                   ", 
        RowBox[{
          RowBox[{"=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], 
                "-", 
                SuperscriptBox[
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], "x", "\[RightAngleBracket]"}], 
                  "2"]}], " ", "=", " ", \(2  D\^\[Prime]\ t\)}]}], ","}]}], 
      TraditionalForm]}]]], "NumberedEquation",
  CellTags->"(8.1.31)"],

Cell["where ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`D\^\[Prime] = 4\ p\ q\ D\)]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:19", "(8.1.32)"}],

Cell[TextData[{
  "Thus, for ",
  Cell[BoxData[
      \(TraditionalForm\`p \[NotEqual] \ q\)]],
  ", in addition to the mean drift of the distribution given by Eq. ",
  ButtonBox["(8.1.26)",
    ButtonData:>{"Chapter8.nb", "(8.1.26)"},
    ButtonStyle->"Hyperlink"],
  ", there is also a diffusive spreading around the mean with diffusion \
coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D\^\[Prime]\)]],
  ".  The form of ",
  Cell[BoxData[
      \(TraditionalForm\`D\^\[Prime]\)]],
  " makes intuitive sense: for instance,  if ",
  Cell[BoxData[
      \(TraditionalForm\`p = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q = 0\)]],
  ", then particles always step to the right, and the entire distribution \
moves to the right without spreading: ",
  Cell[BoxData[
      \(TraditionalForm\`D\^\[Prime] = 0\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The Heat and Fokker-Planck Equations from the Random Walk \
Model\
\>", "Section",
  CellTags->"c:9"],

Cell[CellGroupData[{

Cell["The Master Equation", "Subsubsection",
  CellTags->"i:21"],

Cell[TextData[{
  "\tSo far we have considered the evolution of the probability distribution \
",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " in a random walk that starts with all particles at ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  ". Now let's consider a random walk  that starts from a general initial \
distribution.  We will derive a dynamical equation for ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, \ n)\)]],
  ",  called the ",
  StyleBox["master equation. ",
    FontSlant->"Italic"],
  " In the limit that grid spacing ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and time step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " approach zero, the master equation becomes the  ",
  StyleBox["Fokker-Planck equation",
    FontSlant->"Italic"],
  ". This PDE is a generalization of the heat equation.   "
}], "Text"],

Cell[TextData[{
  "\tGiven the distribution on the grid at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, \ n)\)]],
  ", the master equation predicts the distribution at the next time step, ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n + 1)\)]],
  ". In general,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(P(j, \ n + 1)\), "=", 
          RowBox[{\(P(j, n)\), " ", "+", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["P",
                      FontSlant->"Italic"]}]], "+"], " ", \((j, n)\)}], "-", 
            " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["P",
                      FontSlant->"Italic"]}]], "-"], "(", \(j, n\), ")"}]}]}],
         TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(8.1.33)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["P",
                FontSlant->"Italic"]}]], "+"], TraditionalForm]]],
  " is the number of particles arriving at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "  in this step (divided by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " according to Eq. ",
  ButtonBox["(8.1.6)",
    ButtonData:>{"Chapter8.nb", "(8.1.6)"},
    ButtonStyle->"Hyperlink"],
  " ), and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["P",
                FontSlant->"Italic"]}]], "-"], TraditionalForm]]],
  " is the number of particles leaving ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " in the step (also divided by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "). However, in one step, the random walk prescribes that all particles \
that were at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " move to the left or right, so ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]], "-"], "(", \(j, n\), ")"}], " ", 
          "=", " ", \(P(j, n)\)}], TraditionalForm]]],
  ". Also, particles arrive at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "only from the adjacent sites to the right and left. The site to the left \
at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(j - 1\)\)]],
  " contributes a fraction ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " of the particles resident there, and the site to the right contributes a \
fraction ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " of its particles. Consequently, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]], "+"], " ", \((j, n)\)}], 
          "=", \(p\ \(P(j - 1, n)\) + \ \(\(q\)\(\ \)\(P(j + 1, 
                n)\)\(\ \)\)\)}], TraditionalForm]]],
  ".  Substituting our results for ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["P",
                FontSlant->"Italic"]}]], "+"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["P",
                FontSlant->"Italic"]}]], "-"], TraditionalForm]]],
  " into Eq. ",
  ButtonBox["(8.1.33)",
    ButtonData:>{"Chapter8.nb", "(8.1.33)"},
    ButtonStyle->"Hyperlink"],
  " yields the master equation for the random walk,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`P(j, n + 1) = 
      p\ \(P(j - 1, n)\) + \ 
        q\ \(\(P(j + 1, \ n)\)\(\ \)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(8.1.34)"],

Cell[TextData[{
  "This simple difference equation can be used as a recursion relation to \
solve for ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " starting from any initial distribution. It can be shown that the solution \
corresponding to an initial condition with all particles at ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " is the binomial distribution, Eqs. ",
  ButtonBox["(8.1.15)",
    ButtonData:>{"Chapter8.nb", "(8.1.15)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.1.16)",
    ButtonData:>{"Chapter8.nb", "(8.1.16)"},
    ButtonStyle->"Hyperlink"],
  " (see the exercises). "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Fokker-Planck Equation", "Subsubsection"],

Cell[TextData[{
  "If we assume that the distribution ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " is slowly varying in position and time compared to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " (i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0", " "}], 
        TraditionalForm]]],
  "), we can derive a PDE from the master equation: the Fokker-Planck \
equation.  First, let us define a ",
  StyleBox["probability density",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  " according to"
}], "Text",
  CellTags->"i:28"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho](x\_j, t\_n)\), " ", "=", 
          RowBox[{\(P(j, n)\), "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " "}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.35)"],

Cell[TextData[{
  "This probability density is the unknown function whose dynamics are \
described by the Fokker-Planck equation. In the limit that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  ", the probability density can be used to determine the probability ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_\(a\ b\)\)(t)\)]],
  "that a particle falls in the range ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  "  at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(P\_\(a\ b\)\)(
          t)\  = \ \[Integral]\_a\%b\[DifferentialD]x\ \(\[Rho](x, t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.36)"],

Cell["\<\
Note for future reference that probability densities are always \
normalized so that\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]x\ \(\[Rho](x, t)\) = 1\)]],
  ";"
}], "NumberedEquation",
  CellTags->"(8.1.37)"],

Cell[TextData[{
  "i.e., there is unit probability that a particle is somewhere on the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis. This equation also follows from Eq. ",
  ButtonBox["(8.1.7)",
    ButtonData:>{"Chapter8.nb", "(8.1.7)"},
    ButtonStyle->"Hyperlink"],
  ". \n\tIf we write the master equation in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", it becomes\t"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Rho](x\_j, t\_\(n + 1\))\), "=", 
        RowBox[{
          RowBox[{"p", " ", 
            RowBox[{"\[Rho]", "(", 
              RowBox[{
                RowBox[{\(x\_j\), "-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ",", \(t\_n\)}], ")"}]}], 
          "+", " ", 
          RowBox[{"q", " ", 
            RowBox[{
              RowBox[{"\[Rho]", "(", 
                RowBox[{
                  RowBox[{\(x\_j\), "+", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]]}], ",", " ", \(t\_n\)}], 
                ")"}], " ", "."}]}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(8.1.38)"],

Cell[TextData[{
  "Dropping the ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " index and taking the limit ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "\[Rule]", "0"}], 
        TraditionalForm]]],
  ", a Taylor expansion of the right-hand side to second order in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Rho](x, t\_\(n + 1\))\), "=", 
        RowBox[{
          RowBox[{"p", " ", "[", 
            RowBox[{\(\[Rho](x, t\_n)\), "-", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      
                      FontSlant->
                        "Italic"]}]], \(\[PartialD]\/\[PartialD]x\), \(\[Rho](
                  x, t\_n)\)}], "+", 
              RowBox[{\(1\/2\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"], \(\[PartialD]\^2\/\[PartialD]x\^2\), \(\[Rho](x, 
                  t\_n)\)}]}], "]"}], " ", "+", " ", 
          RowBox[{
            RowBox[{"q", " ", "[", 
              RowBox[{\(\[Rho](x, t\_n)\), "+", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        
                        FontSlant->
                          "Italic"]}]], \(\[PartialD]\/\[PartialD]x\), \(\
\[Rho](x, t\_n)\)}], "+", 
                RowBox[{\(1\/2\), 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], 
                    "2"], \(\[PartialD]\^2\/\[PartialD]x\^2\), \(\[Rho](x, 
                    t\_n)\)}]}], "]"}], " ", "."}]}]}], 
      TraditionalForm]]]], "UNNEQ"],

Cell[TextData[{
  "After collecting terms and using the identity ",
  Cell[BoxData[
      \(TraditionalForm\`p + q = 1\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho](x, t\_\(n + 1\)) - \ \[Rho](x, t\_n)\), "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"-", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], 
              " ", \((p - q)\), \(\[PartialD]\/\[PartialD]x\), \(\[Rho](x, 
                t\_n)\)}], " ", "+", 
            RowBox[{\(1\/2\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                "2"], \(\[PartialD]\^2\/\[PartialD]x\^2\), \(\[Rho](x, 
                t\_n)\), "  "}]}]}], TraditionalForm]]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.39)"],

Cell[TextData[{
  "If we now divide the left and right-hand sides by ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", and take the limit as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  ", the left-hand side becomes a forward-differenced time derivative and we \
obtain the Fokker-Planck equation,"
}], "Text",
  CellTags->"i:20"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Rho]\/\[PartialD]t = \(-\ 
              v\)\ \[PartialD]\[Rho]\/\[PartialD]x\  + \ \(\(D\)\(\ \)\(\
\[PartialD]\^2 \[Rho]\/\[PartialD]x\^2\)\(\ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.40)"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      FormBox[
        RowBox[{"v", " ", "=", " ", 
          RowBox[{\((p - q)\), 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " "}]}]}], TraditionalForm]]],
  " is the drift velocity of the distribution, (see Eq. ",
  ButtonBox["(8.1.26)",
    ButtonData:>{"Chapter8.nb", "(8.1.26)"},
    ButtonStyle->"Hyperlink"],
  "), and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", " ", "=", " ", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "/", "2"}], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " is the diffusion coefficient obtained previously in Eq. ",
  ButtonBox["(8.1.32)",
    ButtonData:>{"Chapter8.nb", "(8.1.32)"},
    ButtonStyle->"Hyperlink"],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  ".  In fact, when ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`v = 0\)]],
  " and Eq. ",
  ButtonBox["(8.1.40)",
    ButtonData:>{"Chapter8.nb", "(8.1.40)"},
    ButtonStyle->"Hyperlink"],
  " becomes the heat equation for the temperature, Eq. ",
  ButtonBox["(8.1.1)",
    ButtonData:>{"Chapter8.nb", "(8.1.1)"},
    ButtonStyle->"Hyperlink"],
  " [or the diffusion equation for the particle density ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ N\ \[Rho]\)]],
  ", Eq. ",
  ButtonBox["(8.1.2)",
    ButtonData:>{"Chapter8.nb", "(8.1.2)"},
    ButtonStyle->"Hyperlink"],
  "]. We have therefore shown that  unbiased random walk dynamics does lead \
to the heat and diffusion equations. "
}], "Text",
  CellTags->"i:29"],

Cell["\<\
\tThe Fokker-Planck equation can be used to model many  physical \
systems for which diffusion is coupled with a net drift. One example is the \
application of an electric field to a conductor, causing a current to flow, \
along with the diffusion caused by collisions. Another example is the \
behavior of a layer of dust added to a fluid such as water. Gravity causes \
the dust to settle, but collisions of the dust grains with the molecules in \
the fluid also cause the dust to diffuse, and create a drag force on the dust \
grains.  For dust grains in gravity, we would expect that the drag force \
would balance gravity, causing a net drift  at the terminal velocity\
\>", \
"Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`v\  = \ \(-\ g\)/\[Gamma]\)]],
  ","
}], "NumberedEquation",
  CellTags->{"i:24", "(8.1.41)"}],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the drag coefficient. For conduction electrons, we would expect ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " to be related to the applied electric field and the electrical \
resistivity (see the exercises)."
}], "Text",
  CellTags->"i:22"],

Cell[TextData[{
  "\tWhile diffusion of electrons can be observed only indirectly through its \
effect on thermal diffusion, the random motion of dust in a liquid can be \
directly observed with a microscope, and was first noted by the Scottish \
botanist Robert Brown in his famous work on ",
  StyleBox["Brownian motion",
    FontSlant->"Italic"],
  ". Einstein, along with von Smoluchowski,  then applied the statistical \
theory of random walks to describe this motion (more on this later). "
}], "Text",
  CellTags->"i:23"],

Cell[TextData[{
  "\tAlthough the Fokker-Planck equation has been derived from artificial \
random walk dynamics,  it can often also be justified on more fundamental \
grounds. The  probability for steps of different sizes can in many cases be \
calculated directly from the microscopic collisional dynamics of the \
particles. For instance, Boltzmann carried out such calculations for a \
low-density gas of classical particles interacting via a short-ranged \
potential through two-body collisions. With such calculations, the thermal \
conductivity, diffusion coefficient, and viscosity of the gas can be directly \
related to the density, temperature, and form of the interparticle-potential. \
  We will not discuss this rather involved subject here, but interested \
readers can find more material in ",
  ButtonBox["Lifshitz and Pitaevskii (1981)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".\n\t In other cases, such as in the Brownian motion of dust grains in a \
fluid, or the motion of electrons in a conductor, the probability for steps \
of different sizes cannot be easily determined from first principles \
calculations. Nevertheless the drift velocity and diffusion coefficient are \
not arbitrary functions. We have observed that the drift velocity is related \
to the applied external fields that  are causing the drift. Also, we will \
find that the diffusion and the drift  are related to one another by an ",
  StyleBox["Einstein relation",
    FontSlant->"Italic"],
  StyleBox[". ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "We will discuss Einstein relations in the exercises and in Sec. ",
  ButtonBox["8.2.3",
    ButtonData:>"c:21",
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIt may give one pause that when ",
  Cell[BoxData[
      \(TraditionalForm\`p \[NotEqual] \ q\)]],
  ", the diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " in the Fokker-Planck equation differs from ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(D\^\[Prime]\), "=", 
          RowBox[{"2", " ", "p", " ", "q", " ", 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", which describes the diffusion coefficient associated with the binomial \
distribution [see Eq. ",
  ButtonBox["(8.1.32)",
    ButtonData:>{"Chapter8.nb", "(8.1.32)"},
    ButtonStyle->"Hyperlink"],
  "]. After all, both the binomial distribution and the Fokker-Planck \
equation are supposed to describe the same random walk. The resolution of \
this apparent paradox lies in the assumption inherent in Eq. ",
  ButtonBox["(8.1.40)",
    ButtonData:>{"Chapter8.nb", "(8.1.40)"},
    ButtonStyle->"Hyperlink"],
  ",  that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is slowly varying in both space and time compared to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". In the limit that ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  "approach zero, the ratio ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"], "/", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " must remain finite in order to provide a finite diffusion coefficient. \
This implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  " is of order ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]], TraditionalForm]]],
  ". However, this also implies that the drift velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is of order ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((p - q)\), "/", 
          SqrtBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]]}], TraditionalForm]]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " to remain finite in the limit as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  ", we therefore require ",
  Cell[BoxData[
      \(TraditionalForm\`p - q\)]],
  " to be of order ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]], TraditionalForm]]],
  ", in other words, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p~\ q\ ~\ 1/2\), " ", "+", " ", 
          RowBox[{"O", "(", 
            SqrtBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]], ")"}]}], TraditionalForm]]],
  ". This implies that  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(D\^\[Prime]\), "=", "  ", 
          RowBox[{"D", " ", "+", " ", 
            RowBox[{"O", "(", 
              SqrtBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]], ")"}]}]}], 
        TraditionalForm]]],
  ", so there is no paradox.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Entropy and Irreversibility", "Subsubsection"],

Cell[TextData[{
  "\tIn describing the evolution of solutions to the Fokker-Planck and heat \
equations, it is useful to define a function of the probability density \
called the ",
  StyleBox["entropy",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`S(
          t)\  = \ \(-k\_B\)\ \(\[Integral]\[DifferentialD]x\ \(\[Rho](x, 
                t)\)\ ln\ \(\[Rho](x, t)\)\)\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(8.1.42)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  "is Boltzmann's constant. The importance of the entropy stems from the \
following fact, which we will prove below:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]S/\[DifferentialD]t\  > \ 
      0\)]]], "NumberedEquation",
  CellTags->"(8.1.43)"],

Cell[TextData[{
  "for any solution of the Fokker-Planck (or heat) equation. The proof of Eq. \
",
  ButtonBox["(8.1.43)",
    ButtonData:>{"Chapter8.nb", "(8.1.43)"},
    ButtonStyle->"Hyperlink"],
  "  is as follows. If we take a time-derivative of Eq. ",
  ButtonBox["(8.1.42)",
    ButtonData:>{"Chapter8.nb", "(8.1.42)"},
    ButtonStyle->"Hyperlink"],
  " we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]S/\[DifferentialD]t\  = \(-k\_B\) \(\
\[Integral]\(\(\[DifferentialD]x\ [\ 
                  ln\ \(\[Rho](x, t)\) + 
                    1]\) \(\[PartialD]\/\[PartialD]t\) \(\[Rho](x, 
                t)\)\(\ \)\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "However, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\[DifferentialD]x \(\[PartialD]\/\
\[PartialD]t\) \(\[Rho](x, 
              t)\) = \(\(\[DifferentialD]\/\[DifferentialD]t\) \(\[Integral]\
\[DifferentialD]x\ \[Rho]\) = 0\)\)]],
  " according to Eq. ",
  ButtonBox["(8.1.37)",
    ButtonData:>{"Chapter8.nb", "(8.1.37)"},
    ButtonStyle->"Hyperlink"],
  ", so we can drop the second term in the square brackets. Then substituting \
from the Fokker-Planck equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Rho]\/\[PartialD]t\)]],
  " yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]S/\[DifferentialD]t\  = \(k\_B\) \(\
\[Integral]\[DifferentialD]x\ \ ln\ \(\[Rho](x, t)\)\ [\ 
                v\ \[PartialD]\[Rho]\/\[PartialD]x\  - \ 
                  D\ \[PartialD]\^2 \[Rho]\/\[PartialD]x\^2]\)\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Integrating once by parts, and assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rho]\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  " at infinity, yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]S/\[DifferentialD]t\  = \(\(-k\_B\) \(\
\[Integral]\[DifferentialD]x\ \ 1\/\[Rho]\ \
\(\[PartialD]\[Rho]\/\[PartialD]x\)[\ 
                v\ \[Rho] - \ 
                  D\ \[PartialD]\[Rho]\/\[PartialD]x]\) = \(k\_B\) \(\
\[Integral]\(\(\[DifferentialD]x\ \ [\(-v\)\ \[PartialD]\[Rho]\/\[PartialD]x\ \
 + \ D\/\[Rho]\ \((\[PartialD]\[Rho]\/\[PartialD]x)\)\^2]\)\(.\)\(\ \
\)\)\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "However, the first term in the square bracket vanishes upon performing the \
integral, since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " vanishes at infinity, and the second term is positive definite because ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[GreaterEqual] \ 0\)]],
  ",  and ",
  Cell[BoxData[
      \(TraditionalForm\`D > \ 0\)]],
  ".  Therefore,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]S/\[DifferentialD]t\  = \(k\_B\) 
          D \(\[Integral]\[DifferentialD]x\ \ 1\/\[Rho]\ \((\[PartialD]\[Rho]\
\/\[PartialD]x)\)\^2\) > \ 0. \)]]], "NumberedEquation",
  CellTags->"(8.1.44)"],

Cell[TextData[{
  "Because ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " must always increase, the Fokker -Planck and heat equations have the \
property of ",
  StyleBox["irreversibility",
    FontSlant->"Italic"],
  ": solutions of these equations never repeat themselves over time because \
this would require that ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " return to a previous value. Initial conditions never recur. This is as \
opposed to solutions of other PDEs such as the wave equation or the KdV \
equation, where we observed that initial conditions often repeat themselves, \
as in a normal mode of oscillation.  "
}], "Text",
  CellTags->"i:26"],

Cell[TextData[{
  "\tThe irreversibility of the heat and Fokker-Planck equations is caused by \
the random motion of many particles. We have seen that this random motion \
causes diffusive spreading of the distribution, and this is what is \
responsible for the increase of the entropy. The broader the distribution \
becomes, the smaller its mean amplitude must be in order to satisfy the \
normalization condition ",
  ButtonBox["(8.1.37)",
    ButtonData:>{"Chapter8.nb", "(8.1.37)"},
    ButtonStyle->"Hyperlink"],
  ", and hence the larger the value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(ln\ \[Rho]\), "\[RightAngleBracket]"}]}], 
        TraditionalForm]]],
  ". Irreversibility implies that once the distribution has spread, it  never \
becomes narrower again. Irreversibility is an important property of many \
systems that exhibit chaotic  dynamics, and is a fact of  everyday life. Once \
the eggs are scrambled they can't be unscrambled, or more precisely, they \
can't unscramble themselves. "
}], "Text"],

Cell[TextData[{
  "\tOr can they? Actually, in chaotic systems with many degrees of freedom, \
it is possible for initial conditions to recur. It is not impossible for a \
broken glass lying on the floor to suddenly draw kinetic energy from the \
random motion of molecules in the floor tiles, and fly back up onto the \
table; it is just (highly) unlikely. This is analogous to the notion that a \
roomful of monkeys seated in front of typewriters could eventually bang out \
the works of Shakespeare (or a physics textbook). It ",
  StyleBox["could",
    FontSlant->"Italic"],
  " happen. (Maybe it has already!)\t"
}], "Text"],

Cell[TextData[{
  "\t In fact, Poincar\[EAcute]  ",
  StyleBox["proved",
    FontSlant->"Italic"],
  "  that for closed Hamiltonian systems,  recurrence back to within an \
arbitrarily small difference from the  initial conditions  ",
  StyleBox["must",
    FontSlant->"Italic"],
  " always occur. It is not only possible for the glass to fly up off the \
floor,  it is",
  StyleBox[" required by the laws of physics. ",
    FontSlant->"Italic"],
  "But don't get out your video cameras yet. The catch is that this \
recurrence can take a long time to happen. For chaotic systems with many \
degrees of freedom, the Poincar\[EAcute]  recurrence time is typically",
  StyleBox[" ",
    FontSlant->"Italic"],
  "much longer than the age of the universe. "
}], "Text",
  CellTags->"i:27"],

Cell[TextData[{
  "\t We can see why this is so from our unbiased random walk simulation. It \
is possible for all the particles to just happen to end up back at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " at the same timestep. If there were only one particle,  this recurrence \
would occur quite often, but for ",
  Cell[BoxData[
      \(TraditionalForm\`M >> 1\)]],
  " particles, the likelihood is incredibly small, equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(P(0, n)\)\^M\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  " and only ",
  Cell[BoxData[
      \(TraditionalForm\`n = 10\)]],
  " steps, ",
  Cell[BoxData[
      \(TraditionalForm\`P(0, n)\)]],
  " is already down to 63/256 = 0.236... . Thus, for only ",
  Cell[BoxData[
      \(TraditionalForm\`M = 100\)]],
  " particles executing 10 unbiased steps, the probability of recurrence is \
",
  Cell[BoxData[
      \(TraditionalForm\`\(P(0, n)\)\^M = \(0.236\^100 = 
          1.3\ \[Times]10\^\(-61\)\)\)]],
  "! "
}], "Text"],

Cell["\<\
\t On the other hand, if the dynamics were not random, but were \
instead a simple oscillation of the particles as in the wave equation, \
recurrence could be a relatively common event even for a great many \
particles. It is the chaotic nature of the dynamics, coupled with the many \
degrees of freedom in the system, that makes recurrence unlikely.\
\>", "Text"],

Cell[TextData[{
  "\tBut this leaves us with one final question: if  recurrence occurs (with \
small probability) in a random walk, and the Fokker-Planck equation describes \
a random walk, then doesn't that contradict Eq. ",
  ButtonBox["(8.1.44)",
    ButtonData:>{"Chapter8.nb", "(8.1.44)"},
    ButtonStyle->"Hyperlink"],
  ", which states that initial conditions cannot recur? No. The point is that \
Eq. ",
  ButtonBox["(8.1.44)",
    ButtonData:>{"Chapter8.nb", "(8.1.44)"},
    ButtonStyle->"Hyperlink"],
  " describes the evolution of the ",
  StyleBox["probability distribution",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " for a system of particles. The probability distribution describes the \
fraction of particles found in given states in the limit as the number of \
particles ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " approaches infinity. But for finite ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " there are fluctuations away from the expected behavior based on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ". Recurrence is simply a very large fluctuation. We will consider the size \
of these fluctuations in Sec. ",
  ButtonBox["8.3.2",
    ButtonData:>"c:28",
    ButtonStyle->"Hyperlink"],
  ", Example 1."
}], "Text"],

Cell["\<\
 \tThe fact that the Fokker-Planck equation describes the \
probability distribution, and therefore does not  directly exhibit \
recurrence,  was a source of considerable controversy in the early days of \
the theory of statistical mechanics.  This tiny weakness in the probabilistic \
theory of thermal relaxation caused Boltzmann considerable heartache, and is \
thought by many to have been a factor contributing to his eventual suicide.\
\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 8.1", "Subsubtitle",
  CellTags->"c:10"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  "  Analytically determine the probability of throwing 8 points or less with \
three dice, each die numbered from 1 to 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Write a simulation using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " random number generator in order to  numerically determine this \
probability (Hint: Average results over 1000 realizations to get a good value \
for the probability.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Write a simulation to numerically determine the probability that  two or \
more students in a 20 student class have the same birthday (assuming a \
365-day year; with no leap years.) (Hint: Assign a number from 1 to 365 for \
each day. Use ",
  StyleBox["Sort",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to sort the list of 20 birthdays before hunting for identical birthdays; \
this will speed up the search. The ",
  StyleBox["While",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["If ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "statements may come in handy. Average results over 1000 realizations of \
the class.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find an analytic expression for this probability, and compare with the \
numerics. (Hint: Determine the probability that all the birthdays are \
different, and subtract this from unity.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)(a)",
    FontWeight->"Bold"],
  " The game of craps is played with two dice (numbered from 1 to 6). If you \
roll 2,3, or 12 on the first try, you lose. If you roll 7 or 11 on the first \
try, you win.  If you roll something else (i.e. 4,5,6,8,9,10), to win you \
must roll that number again before you roll 7, but if you roll ",
  Cell[BoxData[
      \(TraditionalForm\`7\)]],
  " you lose.  You can roll as many times as you need to until you either win \
or lose. Using a decision tree, analytically evaluate the probability that \
you will win. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Evaluate this probability numerically with a simulation, using 1000 \
realizations of the game. "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a)",
    FontWeight->"Bold"],
  " In a game of blackjack, drawing from a fresh 52 card deck, the dealer \
gives himself  two  tens. He deals you a 6 and a 10. Work out the decision \
tree to analytically determine the probability that you will beat the dealer, \
scoring 21. You can draw as many cards as you like from this single deck \
until you win (or lose).  Remember, aces can be either 1 or 11 points,  and \
face cards (jack, queen, king) are worth 10 points."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Simulate the game, and evaluate the probability of winning numerically \
out of 1000 tries. "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)(a)",
    FontWeight->"Bold"],
  " Two particles start random walks from the origin at the same instant, \
with steps of equal probability to the left and right. Determine the \
probability that the particles will meet again after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps. (Consider the relative displacement between the walkers)."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the same calculation for an unbiased 2D random walk on a square \
grid."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find an expression involving a sum for  the mean number of times, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "N", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", that the particles meet after taking ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps,  in 1D, 2D and 3D unbiased walks. By evaluating the sum \
numerically, show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "N", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " diverges like ",
  Cell[BoxData[
      \(TraditionalForm\`\@n\)]],
  " in 1D and like ",
  Cell[BoxData[
      \(TraditionalForm\`ln\ n\)]],
  " in 2D as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases (i.e., over a long time period the particles meet many times ), \
but for 3D, on average, particles only meet about 0.4 times, even if one \
waits forever (ie., particles lose one another). "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " The binomial distribution is the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " that a particle ends up at position ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps. However, since ",
  Cell[BoxData[
      \(TraditionalForm\`j = \ \ 2  n\_R\  - n\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`P(j, n)\)]],
  " can also can be thought of as the probability  that ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " steps are taken to the right out of a total of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps.  Denoting this probability by ",
  Cell[BoxData[
      \(TraditionalForm\`W(n\_R, \ n)\)]],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(W(n\_R, n) = P(j, n)\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`j = 2  n\_R\  - n\)]],
  ".  Then "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W(n\_R, 
          n)\  = \(\(\(\(p\^n\_R\)(1 - p)\)\^\(n - 
                n\_R\)\)\(\ \)\(\(n!\)\/\(\(n\_R!\) \(\((n - 
                      n\_R)\)!\)\)\)\(\ \)\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(8.1.45)"],

Cell[TextData[{
  "This distribution is the probability that ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " ",
  StyleBox["events",
    FontSlant->"Italic"],
  "  (i.e. steps to the right) of probability ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " occur in a total of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " trials. It can be  simplified in the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  " is large. In this limit, we can show that ",
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " is peaked around the average value ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R = \ n\ p\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`n >> 1\)]],
  " is assumed we then have ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", \(<< \(n\_R\)\), " ", 
          RowBox[{"<<", 
            StyleBox["n",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  " (assuming ",
  Cell[BoxData[
      \(TraditionalForm\`0 < p < 1\)]],
  "). "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Take the logarithm of ",
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " and use ",
  StyleBox["Stirling's formula",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:32"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`ln\ \(N!\) \[TildeEqual] N\ ln\ N\  - \ N\)]],
  "   for ",
  Cell[BoxData[
      \(TraditionalForm\`N >> 1\)]]
}], "NumberedEquation",
  CellTags->"(8.1.46)"],

Cell[TextData[{
  "With the aid of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ",",
  " take the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`ln\ W\)]],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " to show that an extremum in ",
  Cell[BoxData[
      \(TraditionalForm\`ln\ W\)]],
  " exists at ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R = \ n\ p\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that this extremum is a maximum by evaluating the second derivative \
of ",
  Cell[BoxData[
      \(TraditionalForm\`ln\ W\)]],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  ". In particular, show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((ln\ W)\)\^\[DoublePrime]\)\( | \_\(n\_R = 
                n\ p\)\)\) = \(-1\)/\((n\ p\ q)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the results of (a) and (b) to show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W(n\_R, n) \[TildeEqual] 
        C\ \[ExponentialE]\^\(\(-\((n\_R - \ n\ p)\)\^2\)/\((2  n\ p\ \
q)\)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(8.1.47)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a constant. This is a ",
  StyleBox["Gaussian",
    FontSlant->"Italic"],
  " distribution.  (Hint: Perform a Taylor expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`ln\ W\)]],
  " about its maximum, keeping only up to quadratic terms.) "
}], "Text",
  CellTags->"i:33"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Stirling's formula as given by Eq. ",
  ButtonBox["(8.1.48)",
    ButtonData:>{"Chapter8.nb", "(8.1.48)"},
    ButtonStyle->"Hyperlink"],
  "  is too crude to determine the constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  ". However, ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " can be found using the following argument. Since ",
  Cell[BoxData[
      \(TraditionalForm\`2\ n\ p\ q\)]],
  " is a large number by assumption, ",
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " varies little as ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R \[Rule] \ n\_R + 1\)]],
  ", and can be thought of as a continuous function of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  ". Also, ",
  Cell[BoxData[
      \(TraditionalForm\`W(0, \ n)\  \[TildeEqual] W(n, n) \[TildeEqual] 
        0\)]],
  " . Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n\_R = 0\)\%n W(n\_R, 
              n) \[TildeEqual] \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( W(
                n\_R, n)\) \[DifferentialD]n\_R = 1\)]],
  ". Use this to show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(C\)\(\ \)\(=\)\(\((2\ \[Pi]\ n\ p\ \
q)\)\^\(\(-1\)/2\)\)\(\ \)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Plot Eq. ",
  ButtonBox["(8.1.47)",
    ButtonData:>{"Chapter8.nb", "(8.1.47)"},
    ButtonStyle->"Hyperlink"],
  " in comparison with Eq. ",
  ButtonBox["(8.1.45)",
    ButtonData:>{"Chapter8.nb", "(8.1.45)"},
    ButtonStyle->"Hyperlink"],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1/2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " The distribution ",
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " can also be simplified in the limit that the probability ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is small and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is large.  In this limit, ",
  Cell[BoxData[
      \(TraditionalForm\`W(n\_R, \ n)\)]],
  " is negligible unless ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", \(<< \(n\_R\)\), " ", 
          RowBox[{"<<", " ", 
            StyleBox["n",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ".  In these limits, show that"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - p)\)\^\(n - n\_R\)\  \[TildeEqual] \
\[ExponentialE]\^\(n\ p\)\)]],
  ". (Hint: Use ",
  Cell[BoxData[
      \(TraditionalForm\`ln\ \((1 - p)\)\  \[TildeEqual] \(-p\)\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Using Stirling's formula show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)/\(\((n - n\_R)\)!\)\  \[TildeEqual] 
        n\^n\_R\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use these results to show that ",
  Cell[BoxData[
      \(TraditionalForm\`W(n\_R, n)\)]],
  " becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`W(n\_R, 
          n) \[TildeEqual] \(\((n\ p)\)\^n\_R\/\(n\_R!\)\) \
\[ExponentialE]\^\(\(-n\)\ p\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(8.1.48)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(8.1.48)",
    ButtonData:>{"Chapter8.nb", "(8.1.48)"},
    ButtonStyle->"Hyperlink"],
  " is called the ",
  StyleBox["Poisson distribution",
    FontSlant->"Italic"],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 20\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ 0.1\)]],
  ". "
}], "Text",
  CellTags->"i:34"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that Eq. ",
  ButtonBox["(8.1.46)",
    ButtonData:>{"Chapter8.nb", "(8.1.46)"},
    ButtonStyle->"Hyperlink"],
  " is properly normalized, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n\_R = 0\)\%\[Infinity] W(n\_R, n) = 
        1\)]],
  ". (The sum can be continued to infinity because ",
  Cell[BoxData[
      \(TraditionalForm\`W\)]],
  " is negligible for ",
  Cell[BoxData[
      \(TraditionalForm\`n\_R \[Rule] \ n\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " A penny is tossed 600 times. What is the probability of scoring 372 \
tails? Evaluate this using (i) Eq. ",
  ButtonBox["(8.1.45)",
    ButtonData:>{"Chapter8.nb", "(8.1.45)"},
    ButtonStyle->"Hyperlink"],
  " (ii) Eq. ",
  ButtonBox["(8.1.47)",
    ButtonData:>"(8.1.47)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)(a)",
    FontWeight->"Bold"],
  " In radioactive decay, in a small time ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "  the probability ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " that one atom decays in a sample of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " atoms is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", "=", 
          RowBox[{"M", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", "\[Tau]"}]}]}], 
        TraditionalForm]]],
  ", where \[Tau] is the lifetime of any one atom. Assume that ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is chosen sufficiently small so that ",
  Cell[BoxData[
      \(TraditionalForm\`p << 1\)]],
  ". Then over a time ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", " ", ">>", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " (but ",
  Cell[BoxData[
      \(TraditionalForm\`t << \ \[Tau]\)]],
  "), show that the probability that ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " atoms have decayed, ",
  Cell[BoxData[
      \(TraditionalForm\`W(m, \ t)\)]],
  ",  is  given by a Poisson distribution."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the mean number of particles that have decayed in time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "m", "\[RightAngleBracket]"}], \((t)\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " A missile has a probability of 0.3 of hitting its intended target. How \
many missiles should be fired at the target in order to have a probability of \
at least 80% that at least one missile will hit the target?"
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  "  Show by substitution that  the binomial distribution satisfies the \
master equation ",
  ButtonBox["(8.1.34)",
    ButtonData:>{"Chapter8.nb", "(8.1.34)"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(12)(a)",
    FontWeight->"Bold"],
  " Conduction electrons in an electrical conductor have number density ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". When an electric field is applied ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ", there is a current density ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " (units of ",
  Cell[BoxData[
      \(TraditionalForm\`amperes\ per\ square\ meter\)]],
  ") given by ",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ \(\(j\)\(\ \ \)\(r\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is the resistivity (units of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalOmega]", " ", 
          StyleBox["m",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ").  Show that  the conduction electrons attain a drift velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(v = \(-\ E\)/e\ n\ r\)\)\)]],
  ". Show that this is equivalent to a collisional drag coefficient  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \(e\^2\) n\ \(\(r/m\)\(\ \)\)\)]],
  ". "
}], "Text",
  CellTags->"i:35"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In copper, the density of conduction electrons is roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^28\), " ", 
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], \(-3\)]}], TraditionalForm]]],
  " and the resistivity at room temperature is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", "=", 
          RowBox[{\(1.7\ \[Cross]10\^\(-8\)\), "\[CapitalOmega]", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " . Find the  drag coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Gamma]\)\(\ \)\)\)]],
  ",  and find the drift velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " in a 1-m-long wire across which 100 V is applied.  "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " If we treat electrons as classical particles, then their mean speed is \
given by the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", according to ",
  Cell[BoxData[
      \(TraditionalForm\`v\&_ = \@\(\(k\_B\) T/m\)\)]],
  ".  The time between collisions can be estimated as roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", 
          " ", \(\[Gamma]\^\(-1\)\)}], TraditionalForm]]],
  " and the electron mean free path is then roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(v\&_/\[Gamma]\)}], 
        TraditionalForm]]],
  ".  Using these estimates, show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(D~\ k\_B\), \(T/\((2\ m\ \[Gamma])\)\), Cell[""]}], 
        TraditionalForm]]],
  ". We will prove this ",
  StyleBox["Einstein relation ",
    FontSlant->"Italic"],
  " for classical particles  (except for the factor of ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ") in Sec. ",
  ButtonBox["8.2.3",
    ButtonData:>"c:21",
    ButtonStyle->"Hyperlink"],
  ". Use this result to estimate the thermal diffusivity of copper at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{"300", " ", 
            StyleBox["K",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". Compare with the actual thermal diffusivity, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", "=", " ", 
          RowBox[{\(1.1\ \[Cross]10\^\(-4\)\), "  ", 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " It's  surprising that this classical estimate works as well as it does, \
considering the fact that electrons in a conductor are ",
  StyleBox["degenerate",
    FontSlant->"Italic"],
  ", with much  larger kinetic energy than the classical formula would \
suggest, given by the ",
  StyleBox["Fermi energy",
    FontSlant->"Italic"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_F\  >> \ \(k\_B\) T\)]],
  ".  Thus, the mean free path is much larger than the classical result, and \
one would think the diffusion would be commensurately larger. However,  only \
a small fraction of these degenerate electrons actually participate in the \
conductivity, that fraction being  of order ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\ T/\[Epsilon]\_F\)]],
  ". (This is the fraction within energy ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_B\) T\)]],
  " of the ",
  StyleBox["Fermi surface",
    FontSlant->"Italic"],
  ".)  Then show that the classical formula of part c) still works \
approximately to describe the thermal diffusivity. For more on this topic, \
see ",
  ButtonBox["Reif (1965, Sec. 12.4)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".    "
}], "Text"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  StyleBox[" The Langevin equation. ",
    FontSlant->"Italic"],
  "Consider the following model of Brownian motion: a dust particle's ",
  StyleBox["velocity",
    FontSlant->"Italic"],
  " is randomly changed by a small random amount ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  " every timestep ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), " ", "=", " ", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", due to a randomly-fluctuating force. (This force arises from collisions \
between the dust particle and atoms in  the surrounding fluid). In addition, \
there is a drag force on the particle's velocity, so that on average ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "v", "\[RightAngleBracket]"}]}], 
            "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{\(-\[Gamma]\), " ", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "v", "\[RightAngleBracket]"}]}]}], 
        TraditionalForm]]],
  ", where \[Gamma] is a drag coefficient.  In differential form the equation \
for the velocity is then ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]v/\[DifferentialD]t\  = \ \
\(-\[Gamma]\)\ v\  + \ f(t)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is a random force with zero mean, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "f", "\[RightAngleBracket]"}], " ", "=", 
          " ", "0"}], TraditionalForm]]],
  ". The random velocity step is  therefore  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_n\), "=", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", \(t\_n\), 
              RowBox[{\(t\_n\), "+", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]], \(\(f(
                t\^\[Prime])\) \[DifferentialD]t\^\[Prime]\)}]}], 
        TraditionalForm]]],
  ". Position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " evolves according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t = v\)]],
  ". Finite-differencing the derivatives leads to the following random walk \
model for the particle velocity and position:"
}], "Text",
  CellTags->"i:36"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(v\_n = \[Alpha]\ v\_\(n - 1\) + 
          s\_\(n - 1\)\)\(,\)\)\)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_n\), "=", 
            RowBox[{\(x\_\(n - 1\)\), "+", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], " ", \(v\_\(n - 1\)\)}]}]}], 
          ","}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(8.1.49)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Alpha]", " ", "=", " ", 
          RowBox[{"1", " ", "-", " ", 
            RowBox[{"\[Gamma]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ". (These equations comprise the finite-differenced ",
  StyleBox["Langevin equations",
    FontSlant->"Italic"],
  " for position and velocity.)"
}], "Text",
  CellTags->"i:37"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Write a particle simulation for this problem, for 1000 particles,taking \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "1"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0.1\)]],
  ", and  ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n = \ \ \(\[PlusMinus]1\)\)]],
  " with equal probability for either sign. Start all particles at ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o = 10\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\  = \ 0\)]],
  ", and follow the dynamics for 50 timesteps. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " How do the average velocity and position evolve in the simulation?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find analytic expressions for",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "v", "\[RightAngleBracket]"}], \((t)\)}], 
        TraditionalForm]]],
  " and",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((t)\), 
          " "}], TraditionalForm]]],
  "and compare with  the simulation.(Hint:it may be simpler for you to solve \
differential equations rather than difference equations for",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((t)\)}], 
        TraditionalForm]]],
  " and",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "v", "\[RightAngleBracket]"}], \((t)\)}], 
        TraditionalForm]]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Plot the mean squared change in velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["v",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " ", "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(v\^2\), "\[RightAngleBracket]"}], "-", 
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "v", "\[RightAngleBracket]"}], "2"]}]}],
         TraditionalForm]]],
  " vs.time from the simulation. Does the particle velocity diffuse?"
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Plot the mean squared position change, and estimate the value of the \
particle diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " from your simulation data."
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " Solve the difference equation for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  " analytically, and use this solution to show that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["v",
                      FontSlant->"Italic"]}]], "n"], "2"], 
            "\[RightAngleBracket]"}], "=", " ", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], 
            "  ", \(\((1 - \[Alpha]\^\(2\ n\))\)\(/\)\((1 - \[Alpha]\^2)\)\(\ \
\)\)}]}], TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "        \tCompare  this result with the simulation result obtained in  \
part (d).  (Hint: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(s\_n\ s\_m\), "\[RightAngleBracket]"}], 
          " ", "=", "0"}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] m\)]],
  ". Also, note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can find many sums analytically using the function ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(g)",
    FontWeight->"Bold"],
  " Show in the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Rule] \ \[Infinity]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  " but ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), "=", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", "remains", " ", 
              "finite"}]}], ","}], TraditionalForm]]],
  " that this result becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["v",
                      FontSlant->"Italic"]}]], "2"], 
              "\[RightAngleBracket]"}], \((t\_n)\)}], "=", 
          RowBox[{
            FractionBox[
              RowBox[{" ", 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}]}], 
              
              RowBox[{"2", " ", "\[Gamma]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      
                      FontSlant->
                        "Italic"]}]]}]], \((1 - \[ExponentialE]\^\(\(-2\)\ \
\[Gamma]\ t\))\)}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.50)"],

Cell[TextData[{
  "        \tFor short times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rule]\)\(0\)\(\ \)\)\)]],
  ", show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["v",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " ", "=", " ", \(2\ \(D\_V\) t\_n\)}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(D\_V\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], "/",
               "2"}], 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " is the ",
  StyleBox["velocity diffusion coefficient",
    FontSlant->"Italic"],
  ".  Evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`D\_V\)]],
  " and compare this short-time theory with the simulation result for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["v",
                  FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " by graphing both together.  [Hint: Use the same method to simplify ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"1", "-", " ", 
              RowBox[{"\[Gamma]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]}], ")"}], \(\(\ \)\(2  n\)\)],
         TraditionalForm]]],
  " as was used in Exercise (7)(a).]"
}], "Text",
  CellTags->"i:40"],

Cell[TextData[{
  StyleBox["(h)",
    FontWeight->"Bold"],
  " In the long-time limit ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n \[Rule] \ \[Infinity]\)]],
  ", statistical physics predicts that the particle will come to thermal \
equilibrium with a mean squared velocity  equal to the  square of the ",
  StyleBox["thermal velocity, ",
    FontSlant->"Italic"],
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(v\^2\), "\[RightAngleBracket]"}], 
          "=", \(k\_B\ T/m\)}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the particle mass and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is the temperature.  In this limit,  prove the ",
  StyleBox["Einstein relation",
    FontSlant->"Italic"],
  " "
}], "Text",
  CellTags->"i:38"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`k\_B\ T\  = \ m\ D\_V/\[Gamma]\)]],
  "."
}], "NumberedEquation",
  CellTags->"(8.1.51)"],

Cell[TextData[{
  "(We will prove another Einstein relation in Sec. ",
  ButtonBox["8.2.3",
    ButtonData:>"c:23",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold"],
  " Analytically evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\_n\ v\_n\), "\[RightAngleBracket]"}]}], 
        TraditionalForm]]],
  ", plot the result vs. ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " for the parameters of the simulation, and compare with the simulation. \
Explain why this quantity is positive for short times, but  vanishes at large \
times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n >> \ \[Gamma]\^\(-1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(j)",
    FontWeight->"Bold"],
  " Evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\_n\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ",  and show that, at large times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n >> \[Gamma]\^\(-1\)\)]],
  " and for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "0"}], 
        TraditionalForm]]],
  ", one has ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\_n\^2\), "\[RightAngleBracket]"}], " ", 
          "=", " ", \(2\ D\ t\_n\)}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`D\  = \ D\_v/\[Gamma]\^2\)]],
  " is the spatial diffusion coefficient. Plot the result vs. ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " for the simulation parameters, and compare to the simulation. "
}], "Text"],

Cell[TextData[{
  "\t(Solution: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\_n\^2\), "\[RightAngleBracket]"}], " ", 
          "=", 
          RowBox[{
            RowBox[{"2", " ", \(D\_v\), "  ", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "3"], 
              " ", \(\(n\ \((1 - \[Alpha]\^2)\) - 
                    2\ \[Alpha] - \[Alpha]\^2 + \ \(\[Alpha]\^\(1 + n\)\)(
                      2 + 2\ \[Alpha] - \[Alpha]\^\(1 + \ n\))\)\/\(\((1 - \
\[Alpha])\)\^3\ \((1 + \[Alpha])\)\)\)}], " ", "+", " ", 
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(x\_n\), "\[RightAngleBracket]"}], 
              "2"]}]}], TraditionalForm]]],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(14)(a)",
    FontWeight->"Bold"],
  " A gas of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles is initially confined to the left half of a container of volume \
",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " by a partition. The partition is then removed, and the particles \
distribute themselves randomly throughout the container. What is the \
probability that, at any instant, all the particles are found back in the \
left half of the container? (This is a crude example of recurrence, and is \
much ",
  StyleBox["more",
    FontSlant->"Italic"],
  " likely than Poincar\[EAcute] recurrence, where each particle is found \
with nearly the same position and velocity as it had initially.)"
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "What is the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(N\_L)\)]],
  " that ",
  Cell[BoxData[
      \(TraditionalForm\`N\_L\)]],
  "  particles are in the left half of the container at any instant, (and ",
  Cell[BoxData[
      \(TraditionalForm\`N - N\_L\)]],
  " are in the right half)? Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " large this probability is given by a Gaussian distribution. "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use this probability to determine the mean squared fluctuation in the \
number of particles in the left half away from the mean value ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], 
          SuperscriptBox[
            SubscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["N",
                    FontSlant->"Italic"]}]], "L"], "2"], 
          "\[RightAngleBracket]"}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A polymer is a long chain of atoms connected by bonds.  Consider the \
following simplified model of a polymer. Assume that the polymer lies in the \
",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane, and the bonds are all of unit length. Furthermore, assume that the \
bonds can only be in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]x\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]y\)\)]],
  " directions. Then starting at one end of the chain, at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((x, y)\) = \((0, 0)\)\)\(,\)\)\)]],
  " the next atom can be at one of four locations, ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[PlusMinus]1\), 0)\)\)]],
  " or (0,\[PlusMinus]1), with equal probability. The next atom can be at any \
of its four possible locations, and so on. Thus we see that the atoms are at \
the locations corresponding to a two-dimensional random walk. "
}], "Text",
  CellTags->"i:83"],

Cell[TextData[{
  "\tOne important question, which can be addressed experimentally, is the \
mean size of a polymer chain consisting of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " bonds. The mean size is typically evaluated as ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(r\^2\), "\[RightAngleBracket]"}], 
            ")"}], \(1/2\)], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(r\^2\), 
              "\[RightAngleBracket]"}], \((n)\)}], " ", "=", " ", 
          RowBox[{\(\(1\/n\) \[Sum]\+\(i = 0\)\%n\), "|", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "i"], \( | \^\(\(\ \)\(2\)\)\)}]}], 
        TraditionalForm]]],
  ", the sum runs over the positions of all ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " atoms in the chain, and the average is over all possible configurations \
of the polymer,  all of which are assumed to be equally probable. This is \
equivalent to an average over all possible random walk processes."
}], "Text"],

Cell[TextData[{
  "\tDetermine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  " in this random walk model, and in particular show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), "\[RightAngleBracket]"}], 
          "\[Proportional]", "n"}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " Experiments on polymers show that  the size of a polymer with ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " bonds  is larger than suggested by the result given in the previous \
problem. The reason is that atoms in a polymer take up space, and so the \
random walk is excluded from regions already occupied by the polymer. This \
causes the polymer to spread out more than the simple random walk of the \
previous problem would predict."
}], "Text",
  CellTags->"i:41"],

Cell[TextData[{
  "\tOne way to estimate the effect of the excluded volume on the size of the \
polymer is to use a ",
  StyleBox["self-avoiding",
    FontSlant->"Italic"],
  " random walk.  This is a random walk where, as before, a step in any of \
the four directions is equally probable, ",
  StyleBox["except",
    FontSlant->"Italic"],
  " that the step cannot move to an already occupied position. The possible \
polymer configurations for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)]],
  " bonds are shown in Fig. ",
  ButtonBox["8.3",
    ButtonData:>"Fig. 8.3",
    ButtonStyle->"Hyperlink"],
  ", assuming that the first bond is always to the right (the direction of \
this bond can be chosen  arbitrarily because of the four-fold symmetry of the \
random walk on a square lattice).  "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.454545 0.5 0.454545 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.04545 .5 m
.5 .5 L
.95455 .5 L
s
.02 w
.04545 .5 Mdot
.5 .5 Mdot
.95455 .5 Mdot
gsave
.09091 .54545 -78 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(H) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(L) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.454545 0.5 0.454545 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.04545 .5 m
.5 .5 L
.5 .95455 L
s
.02 w
.04545 .5 Mdot
.5 .5 Mdot
.5 .95455 Mdot
gsave
.09091 .54545 -78 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(H) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(L) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.454545 0.5 0.454545 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.04545 .5 m
.5 .5 L
.5 .04545 L
s
.02 w
.04545 .5 Mdot
.5 .5 Mdot
.5 .04545 Mdot
gsave
.09091 .54545 -78 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(H) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(L) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{550, 171.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:_0000eR000`400?l00000o`00003ooooooooo
oooook7ooooo003ooooooooooooo/Oooool00?oooooooooooonaooooo`00oooooooooooook7ooooo
003ooooooooooooo/Oooool00?oooooooooooonaooooo`00oooooooooooook7ooooo003ooooooooo
oooo/Oooool00?oooooooooooonaooooo`00oooooooooooook7ooooo003ooooooooooooo/Oooool0
0?oooooooooooonaooooo`00oooooooooooook7ooooo003ooooooooooooo>?ooool2o`0007Oooooo
003ooooooooooooo=oooool4o`0007Kooooo003ooooooooooooo=oooool4o`0007Kooooo003ooooo
oooooooo>?ooool2o`0007Oooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00
ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oo
oooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00oooooooooooo
ocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Go
oooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o
0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooo
oooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000oooooooo
ool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Ooo
ool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool0
0?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003o
ooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?oooooooooo
ooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1e
ooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03
o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00oooo
ooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooo
oooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWo
oooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo
003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000
ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooo
oooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0
MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool0
0ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?oo
ooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003ooooo
ooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooli
ooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eoooo
o`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`00
0?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00oooooooo
ooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo
07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo
00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003o
oooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000oooo
ooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo
>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOoo
ool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0
003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?oooooo
ooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003ooooooooo
o`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?oooooooooooolioooo
o`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00
ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oo
oooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00oooooooooooo
ocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Go
oooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o
0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooo
oooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000oooooooo
ool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Ooo
ool00ol0003oooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool0
0?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003o
ooooooooo`1eooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?oooooooooo
ooliooooo`03o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1e
ooooo`00ooooooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03
o`000?oooooooooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00oooo
ooooooooocWooooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooo
oooo07Gooooo003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`00ooooooooooooocWo
oooo00?o0000ooooooooool0MOooool00?ooooooooooooliooooo`03o`000?oooooooooo07Gooooo
003ooooooooooooo>Oooool00ol0003oooooooooo`1eooooo`006_ooool2o`0005[ooooo0_l0001K
ooooo`;o00009Oooool2o`0005[ooooo0_l00022ooooo`;o0000F_ooool2o`0007Oooooo000Ioooo
o`Co0000F?ooool4o`0005Wooooo1?l0000Sooooo`Co0000F?ooool4o`00083ooooo1?l0001Hoooo
o`Co0000M_ooool001Wooooo_Ol0000Sooooof3o0000P?oooomPo`0007Kooooo000Jooooo`;o0000
F_ooool2o`0005_ooooo0_l0000Uooooo`;o0000F_ooool2o`0008;ooooo0_l0001Jooooo`;o0000
Moooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomFooooo`005_ooool00omgMgOoIVIVooooo`09ooooo`03o`000?nj^[[ooooo
00_ooooo00?oIVIVogMgMoooool0`oooool00omgMgOoIVIVooooo`09ooooo`03o`000?nj^[[ooooo
00_ooooo00?oIVIVogMgMoooool0A?ooool00ol0003oooooooooo`1looooo`03ogMgMomVIVKooooo
00Wooooo00?o0000okZj^_ooool02oooool00omVIVKoMgMgooooo`2looooo`005Oooool00ooMgMgo
410@onk^kP0:ooooo`;o<S8b3?ooool00oo^k^ko410@omgMg@32ooooo`03omgMgOl@413ok^k^00[o
oooo0_lb<S8<ooooo`03onk^k_l@413ogMgM04Cooooo00?o0000ooooooooool0Noooool00ooMgMgo
410@onk^kP0:ooooo`;o<S8b3?ooool00oo^k^ko410@omgMg@2looooo`005Oooool02OmEEEGoV9RH
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP04ooooo`03ohN7Qol0003o^[Zj00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP04ooooo`03ohN7QomVIVKooooo0<7ooooo00WoEEEEoiRHV?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00on7QhOoIVIVooooo`13ooooo`03o`000?oooooooooo07_ooooo00WoEEEE
oiRHV?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01?ooool00on7QhOo0000okZj^P03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00on7QhOoIVIVooooo`2kooooo`005Oooool02Ol0003o
ooooooooooooooooMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03olc<c?l0003o410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`04ooooo`03onk^k_l0003ooooo0<7ooooo00Wo0000oooooooooooo
ooooogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo<c<co0000oa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool00oo^k^ko0000ooooo`13ooooo`03o`000?oooooooooo07_ooooo00Wo
0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo<c<co0000oa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^ko0000ooooo`2kooooo`005Oooool01Olb
<S;ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02?ooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0`?ooool01Olb<S;ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool02?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`1kooooo`05oc8b<_ooooooooooooooool@41000oooool00ol@
413oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`2j
ooooo`005Oooool01Olb<S;ooooooooooooooooo000000?ooooo00?o0000ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0`?ooool01Olb<S;ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1kooooo`05oc8b<_oooooooooooooo
ool000000oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`2jooooo`005Oooool01Ol0003ok^k^oooooooooooo000000?ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Cooooo00?ok^k^o`000?ooool0`Ooo
ool01Ol0003ok^k^oooooooooooo000000?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?ok^k^o`000?ooool0@oooool00ol0003oooooooooo`1kooooo`05
o`000?o^k^koooooooooool000000oooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooo
ooooool000001?ooool00oo^k^ko0000ooooo`2kooooo`005Oooool01OmEEEGoMgMgoooooooooooo
410@00?ooooo00?o410@ooooooooool02?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
MgMgoeEEEOooool0`Oooool01OmEEEGoMgMgoooooooooooo410@00?ooooo00?o410@ooooooooool0
2?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgoeEEEOooool0@oooool00ol0003o
ooooooooo`1kooooo`05oeEEEOmgMgOoooooooooool@41000oooool00ol@413oooooooooo`08oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00omgMgOoEEEEooooo`2kooooo`005Oooool02OoM
gMgo410@onk^k_ooooooMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo^k^ko410@omgMg@32ooooo`09omgMgOl@413ok^k^oooooomgMgOoV9RHoooooonH
V9SoMgMg00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03onk^k_l@413ogMgM04Cooooo
00?o0000ooooooooool0Noooool02OoMgMgo410@onk^k_ooooooMgMgoiRHV?ooooooV9RHogMgM`0:
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo^k^ko410@omgMg@2looooo`005_ooool0
2?mgMgOoIVIVooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oIVIVogMgMoooool0`oooool02?mgMgOoIVIVooooooo^k^ko<S8bo`000?lb<S;ok^k^
2_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oIVIVogMgMoooool0A?ooool00ol0003o
ooooooooo`1looooo`08ogMgMomVIVKoooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool00omVIVKoMgMgooooo`2looooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeSooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeOooooo0_l0003ooooooeSooooo003ooooooeKooooo1?l0003ooooooeOo
oooo003ooooooeKooooo1?l0003ooooooeOooooo003ooooooeOooooo0_l0003ooooooeSooooo003o
oooooooooooo/Oooool00?oooooooooooonaooooo`00oooooooooooook7ooooo003ooooooooooooo
/Oooool00?oooooooooooonaooooo`00oooooooooooook7ooooo003ooooooooooooo/Oooool00?oo
oooooooooonaooooo`00oooooooooooook7ooooo003ooooooooooooo/Oooool00?oooooooooooona
ooooo`00oooooooooooook7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 686.5}, {213.812, 0}} -> {-0.0803103, -0.0234425, \
0.00575496, 0.00575496}, {{17.4375, 221.062}, {208.688, 5.0625}} -> \
{-0.288411, -1.15538, 0.0135054, 0.0135054}, {{241.375, 445.062}, {208.688, \
5.0625}} -> {-2.70823, -1.15538, 0.0135054, 0.0135054}, {{465.375, 669}, \
{208.688, 5.0625}} -> {-5.12806, -1.15538, 0.0135054, 0.0135054}}],

Cell["\<\
Fig. 8.3 The three possible paths for a self-avoiding random walk \
consisting of two steps\
\>", "Caption",
  CellTags->"Fig. 8.3"],

Cell["\<\
A considerable effort over the years has gone into determining the \
statistics of such self-avoiding walks. Little can be accomplished \
analytically without great effort, but numerical methods have proven to be \
very fruitful. \
\>", "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  " analytically for  a self-avoiding random walk for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\ and\ 3\)]],
  ". Average over all possible configurations of the chain, assuming that \
each configuration is equally likely. Compare to the results of the previous \
problem.  Which result is larger? ",
  StyleBox["(",
    FontSize->16],
  "Amazingly,  Dr. E. Teramoto of Kyoto University analytically evaluated ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " up to 20 bonds, ",
  StyleBox["using pencil and paper",
    FontSlant->"Italic"],
  " [according to Rosenbluth and Rosenbluth, (1955)].",
  StyleBox[")",
    FontSize->16]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Write a simulation for a self-avoiding random walk. Starting at the \
origin, the first step is always to the right, and the steps thereafter can \
be in any direction. In determining ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  ", throw away any configuration that crosses itself at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " or earlier. (Such configurations can still be counted in the average for \
timesteps before a crossing in the configuration has occurred). ",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "\tThere is one addendum to this method that must be made. In order to \
increase the efficiency of the simulation,  do not allow the walk to double \
back on itself. This implies that at any timestep there are only ",
  StyleBox["three",
    FontSlant->"Italic"],
  " possible directions for the next step, each with equal probability.  \
There are many different ways to code this, and the method is left up to you. \
Run your simulation of the polymer for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 5000\)]],
  " trials, up to a length of ",
  Cell[BoxData[
      \(TraditionalForm\`n = 50\)]],
  ". The reason that ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " must be chosen this large is that by the time ",
  Cell[BoxData[
      \(TraditionalForm\`n = 50\)]],
  " only about 100  configurations will be left in the average. On a log-log \
plot, plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(r\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ".  It should be nearly a straight line with slope ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". Thus, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), "\[RightAngleBracket]"}], 
          "\[Proportional]", \(n\^b\), " "}], TraditionalForm]]],
  ".The exponent ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " equals one in a simple random walk, but should be larger than one in a \
self-avoiding random walk. Thus, the polymer grows in size with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " more rapidly than expected from a simple random walk.  This is the \
excluded-volume effect.  To find the exponent ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 10\)]],
  ", fit ",
  Cell[BoxData[
      FormBox[
        RowBox[{"log", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(r\^2\), "\[RightAngleBracket]"}]}], 
        TraditionalForm]]],
  " to a form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"log", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(r\^2\), "\[RightAngleBracket]"}]}], " ",
           "=", " ", \(a\  + \ b\ log\ n\)}], TraditionalForm]]],
  ". For large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", it has been predicted that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\)\(\ \)\)\)]],
  " is roughly 1.5 for a random walk  in 2D, and 1.2 in 3D. How close did \
your simulation result come to the 2D estimate?"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["8.2 Thermal Equilibrium", "Subtitle",
  CellTags->"c:11"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["8.2.1 Random Walks with Arbitrary Steps", "Subsubtitle",
  CellTags->{"i:43", "c:12"}],

Cell[CellGroupData[{

Cell["Averages", "Section",
  CellTags->{"i:44", "c:13"}],

Cell[TextData[{
  "\tIn a random walk the steps need not be of fixed size. Let's consider a \
more general random walk where the step size ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "  is distributed according to a probability density ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  ".  In one step, the particle position changes from ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\) = x\_\(\(n\)\(\ \)\)\  + \ s\)]],
  ".  As is always the case with probability densities, "
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P\_\(a\ b\) = \[Integral]\_a\%b\( w(
              s)\) \[DifferentialD]s\)]],
  " "
}], "NE2",
  CellTags->"(8.2.1)"],

Cell[TextData[{
  "is the probability that the step falls in the range ",
  Cell[BoxData[
      \(TraditionalForm\`a < s < b\)]],
  " [see Eq. ",
  ButtonBox["(8.1.36)",
    ButtonData:>{"Chapter8.nb", "(8.1.36)"},
    ButtonStyle->"Hyperlink"],
  "]. "
}], "Text"],

Cell[TextData[{
  "\t The average step size is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "s", "\[RightAngleBracket]"}], 
          "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] 
              s\ \(w(s)\) \[DifferentialD]s\)}], TraditionalForm]]],
  " .  For instance, in our previous random walk, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w(s)\), " ", "=", " ", 
          RowBox[{
            RowBox[{"p", " ", 
              RowBox[{"\[Delta]", "(", 
                RowBox[{"s", "-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ")"}]}], " ", "+", " ", 
            RowBox[{"q", " ", 
              RowBox[{"\[Delta]", "(", 
                RowBox[{"s", "+", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ")"}]}]}]}], 
        TraditionalForm]]],
  ", and then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "s", "\[RightAngleBracket]"}], " ", "=", 
          " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "(", \(p - q\), ")"}]}], 
        TraditionalForm]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tConsider ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " steps in a random walk process. We will label each step ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... , N\)]],
  ". The probability ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]P\)]],
  " that each step falls in the range ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n \[Rule] \ s\_n + \[DifferentialD]s\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2,  ... , N\)]],
  ", is the product of the probabilities for the steps:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]P\  = \ \ \(\(w(
                  s\_1)\)\ \[DifferentialD]s\_1 ... \) . \(w(
              s\_N)\) \[DifferentialD]s\_N\)]],
  ". "
}], "NE2",
  CellTags->"(8.2.2)"],

Cell[TextData[{
  "This provides an example of a ",
  StyleBox["multivariate",
    FontSlant->"Italic"],
  " (i.e. multidimensional) probability distribution. The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{Cell[""], \(\[Rho](s\_1, s\_2,  ... , s\_N)\)}], 
              "\[Congruent]", \(\(w(s\_1)\) \(w(s\_2)\)\)}], "..."}], \(w(
            s\_N)\)}], TraditionalForm]]],
  " on the ",
  "right-hand",
  " side of the equation is the probability density for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " step process.  This multivariate distribution is normalized in the usual \
way: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Integral]\(\[Rho](s\_1,  ... , 
                  s\_N)\) \[DifferentialD]s\_1\ \[DifferentialD]s\_2 ... \) . \
\[DifferentialD]s\_N = 1\)\)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "and we can calculate average quantities over this distribution just as we \
did for averages over a single variable. For any function ",
  Cell[BoxData[
      \(TraditionalForm\`f(s\_1, s\_2,  ... , s\_N)\)]],
  ", the average is"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "f", "\[RightAngleBracket]"}], " ", "=", 
          " ", 
          
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]\
s\_1 \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]s\_2\) \
... \), 
            RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
              
              RowBox[{\(\[DifferentialD]s\_N\), \(\[Rho](s\_1,  ... , s\_N)\),
                 Cell[""], \(f(s\_1, s\_2,  ... , s\_N)\)}]}]}]}], 
        TraditionalForm]], "NumberedEquation"], "NumberedEquation"],
  StyleBox[". ", "NumberedEquation"]
}], "NE2",
  CellTags->"(8.2.3)"],

Cell[TextData[{
  "For example, if we wish to determine the average position after ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " steps, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((N)\)}], 
        TraditionalForm]]],
  ",",
  " we can write the position as a sum of the individual steps,  ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ \(s\_1\  + \ s\_2\  + \  ... \) + s\_N\)]],
  ".  Taking an average, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((N)\)}], 
          " ", "=", " ", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(\(s\_1 + \ s\_2 +  ... \) + s\_N\), 
              "\[RightAngleBracket]"}], " ", "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(s\_1\), "\[RightAngleBracket]"}], 
                  " ", "+", " ", 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(s\_2\), "\[RightAngleBracket]"}], 
                  " ", "+"}], " ", "..."}], "+", " ", 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\_N\), 
                "\[RightAngleBracket]"}]}]}]}], TraditionalForm]]],
  ",  "
}], "UNNEQ"],

Cell[TextData[{
  "where in the second step we used the linearity property of averages, Eq. \
",
  ButtonBox["(8.1.19)",
    ButtonData:>{"Chapter8.nb", "(8.1.19)"},
    ButtonStyle->"Hyperlink"],
  ".  Now, for a random walk, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \(\(w(s\_1)\) \(w(s\_2)\) ... \) \(w(
            s\_N)\)\)]],
  ", integrals over each term in the sum yield the same result. For instance, \
for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th term,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(s\_n\), "\[RightAngleBracket]"}], " ", 
          "=", 
          
          RowBox[{\(\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]s\_1 \( w(
                      s\_1)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]s\_2 \( w(
                          s\_2)\)\) ... \) \(\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\[DifferentialD]s\_\(\(N\)\(\ \)\) \(w(s\_N)\) s\_n\)\), "   ", 
            "=", "    ", 
            
            RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]s\_n \( w(s\_n)\) s\_n\), " ", "=", 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "s", "\[RightAngleBracket]"}]}]}]}], 
        TraditionalForm]]],
  ";"
}], "UNNEQ"],

Cell[TextData[{
  "that is, the average step size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "s", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " is independent of the time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ".  Therefore, we find that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((N)\)}], 
          " ", "=", " ", 
          RowBox[{"N", " ", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "s", "\[RightAngleBracket]"}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(8.2.4)"],

Cell[TextData[{
  "so there is a net drift of the particle distribution with velocity  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"v", "=", " ", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "s", "\[RightAngleBracket]"}], "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". We can perform a similar analysis for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^2\), 
            "\[RightAngleBracket]"}], \((N)\)}], TraditionalForm]]],
  ". According to Eq. ",
  ButtonBox["(8.2.3)",
    ButtonData:>{"Chapter8.nb", "(8.2.3)"},
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(x\^2\), 
              "\[RightAngleBracket]"}], \((N)\)}], "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              RowBox[{
                UnderoverscriptBox[
                  StyleBox[\(\(\[Sum]\)\(\ \)\),
                    FontSize->16], \(i = 1\), "N"], \(s\_i\), 
                UnderoverscriptBox[
                  StyleBox[\(\(\[Sum]\)\(\ \)\),
                    FontSize->16], \(j = 1\), "N"], \(s\_j\)}], 
              "\[RightAngleBracket]"}], " ", "=", " ", 
            RowBox[{
              RowBox[{
                UnderoverscriptBox[
                  StyleBox[\(\(\[Sum]\)\(\ \)\),
                    FontSize->16], \(i = 1\), "N"], 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(s\_i\^2\), 
                  "\[RightAngleBracket]"}]}], " ", "+", " ", 
              RowBox[{
                UnderoverscriptBox[
                  StyleBox[\(\(\[Sum]\)\(\ \)\),
                    FontSize->16], \(\(i, j = 1\)\+\(j \[NotEqual] \ i\)\), 
                  "N"], " ", 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(s\_i\ s\_j\), 
                  "\[RightAngleBracket]"}], " "}]}]}]}], TraditionalForm]]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "where in the second step we separated out terms  in the sums for which ",
  Cell[BoxData[
      \(TraditionalForm\`i = j\)]],
  ". Applying our distribution to these averages, we find that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(s\_i\^2\), "\[RightAngleBracket]"}], " ", 
          "=", " ", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}]}], 
        TraditionalForm]]],
  ", independent of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(s\_i\ s\_j\), "\[RightAngleBracket]"}], 
          " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\_i\), "\[RightAngleBracket]"}], 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\_j\), "\[RightAngleBracket]"}]}], 
            " ", "=", " ", 
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "s", "\[RightAngleBracket]"}], "2"]}]}],
         TraditionalForm]]],
  ". Thus, we find"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(x\^2\), 
              "\[RightAngleBracket]"}], \((N)\)}], " ", "=", " ", 
          RowBox[{
            RowBox[{"N", " ", 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}]}], 
            " ", "+", " ", 
            RowBox[{\(N(N - 1)\), "  ", 
              SuperscriptBox[
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], "s", "\[RightAngleBracket]"}], "2"], 
              " "}]}]}], TraditionalForm]]],
  ". "
}], "NE2",
  CellTags->"(8.2.5)"],

Cell[TextData[{
  "The factor ",
  Cell[BoxData[
      \(TraditionalForm\`N(N - 1)\)]],
  " is the number of terms in the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i \[NotEqual] \ j\)]],
  ". If we now consider the mean squared change in position away from the \
average, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " ", "=", " ", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(x\^2\), "\[RightAngleBracket]"}], " ", 
            "-", " ", 
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "x", "\[RightAngleBracket]"}], "2"]}]}],
         TraditionalForm]]],
  ", [see Eq. ",
  ButtonBox["(8.1.31)",
    ButtonData:>{"Chapter8.nb", "(8.1.31)"},
    ButtonStyle->"Hyperlink"],
  "] and use Eqs. ",
  ButtonBox["(8.2.4)",
    ButtonData:>{"Chapter8.nb", "(8.2.4)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.2.5)",
    ButtonData:>{"Chapter8.nb", "(8.2.5)"},
    ButtonStyle->"Hyperlink"],
  " to calculate this quantity, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " ", "=", " ", 
          RowBox[{"N", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], 
                " ", "-", " ", 
                SuperscriptBox[
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], "s", "\[RightAngleBracket]"}], 
                  "2"]}], ")"}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(8.2.6)"],

Cell[TextData[{
  "The mean ",
  "squared ",
  "change in position increases linearly with the number of steps in a random \
walk. In analogy to Eq. ",
  ButtonBox["(8.1.31)",
    ButtonData:>{"Chapter8.nb", "(8.1.31)"},
    ButtonStyle->"Hyperlink"],
  " we then define a diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " for this process, so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " ", "=", \(2\ D\ t\)}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"D", " ", "=", " ", 
        FractionBox[
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], " ", 
            "-", " ", 
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "s", "\[RightAngleBracket]"}], "2"]}], 
          RowBox[{"2", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]]}], TraditionalForm]]]], "NE2",
  CellTags->"(8.2.7)"],

Cell[TextData[{
  "This generalizes our previous expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", " ", "=", " ", 
          RowBox[{"2", " ", "p", " ", "q", " ", 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Conditional Probability and the Master Equation", "Section",
  CellTags->{"i:45", "c:14"}],

Cell[TextData[{
  "\tAn important property of  random walks is that the steps are ",
  StyleBox["uncorrelated",
    FontSlant->"Italic"],
  ". As an example, consider a random walk with fixed size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], "s"}], "=", \(\[PlusMinus]1\)}], 
        TraditionalForm]]],
  ", and define the probability of a step ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " to be ",
  Cell[BoxData[
      \(TraditionalForm\`P(s)\)]],
  ", where  ",
  Cell[BoxData[
      \(TraditionalForm\`P(1)\  = \ p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P(\(-1\))\  = \ q\)]],
  ". The probability of a step is not connected to the results of previous \
steps, and this means that the steps are ",
  "uncorrelated ",
  "with previous steps.   For such a process, we know that the probability of \
several consecutive steps is given by the",
  " product",
  " of the individual probabilities. For instance, the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_1, s\_2)\)]],
  " of  two consecutive steps with outcomes ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(s\_1, s\_2) = \(P(s\_1)\) \(P(s\_2)\)\)]],
  ".  "
}], "NE2",
  CellTags->"(8.2.8)"],

Cell[TextData[{
  "\tWe have already used this result several times; see, for instance, Eq. \
",
  ButtonBox["(8.2.2)",
    ButtonData:>{"Chapter8.nb", "(8.2.2)"},
    ButtonStyle->"Hyperlink"],
  ". However, this is only true for uncorrelated steps.  More generally, if \
the second step depends in some way on the first step, we define a ",
  StyleBox["conditional probability ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`P(s\_2 | s\_1)\)]],
  ". This is the probability that the outcome of the second step is ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  ",",
  " ",
  StyleBox["on condition that the outcome of the first step was ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  ". In other words, if we take these two steps ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " times",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_2 | s\_1)\)]],
  " is the fraction of the outcomes that yield ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  " taken out of those that  first yielded ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  ". In the form of an equation,  ",
  Cell[BoxData[
      \(TraditionalForm\`P(
          s\_2 | s\_1)\  = \(\(\(N(s\_2 | s\_1)\)/\(N(s\_1)\)\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`N(s\_1)\)]],
  " is the total number of outcomes that yielded ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`N(s\_2 | s\_1)\)]],
  " is the number of outcomes that yielded ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  " given that ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  " first occurred.  However, it is also the case that ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_1, s\_2) = \(N(s\_2 | s\_1)\)/M\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_1) = \(N(s\_1)\)/M\)]],
  ".  These results can be combined to yield the following equation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(s\_1, s\_2) = \(P(s\_1)\) \(P(s\_2 | s\_1)\)\)]],
  ". "
}], "NE2",
  CellTags->"(8.2.9)"],

Cell[TextData[{
  "It is instructive to examine this important result from several \
perspectives. For an uncorrelated random walk, ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_2 | s\_1) = P(s\_2)\)]],
  " independent of the first step, and Eq. ",
  ButtonBox["(8.2.9)",
    ButtonData:>{"Chapter8.nb", "(8.2.9)"},
    ButtonStyle->"Hyperlink"],
  " returns to Eq. ",
  ButtonBox["(8.2.8)",
    ButtonData:>{"Chapter8.nb", "(8.2.8)"},
    ButtonStyle->"Hyperlink"],
  ".  At the other extreme, the case of perfect correlation, the second step \
is always the same as the first. In this case ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_2 | s\_1)\  = \ 1\)]],
  " if  ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2 = s\_1\)]],
  " and is zero otherwise. Then Eq. ",
  ButtonBox["(8.2.9)",
    ButtonData:>{"Chapter8.nb", "(8.2.9)"},
    ButtonStyle->"Hyperlink"],
  " yields ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(P(s\_1, s\_2)\), " ", "=", 
          RowBox[{\(\(P(s\_1)\)\ if\ \ s\_2\), "=", 
            RowBox[{\(s\_1\), Cell[""]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P(s\_1, s\_2)\  = 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2 \[NotEqual] \ s\_1\)]],
  ", as we would have intuitively guessed when ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  "is perfectly correlated to ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAn example of  random variables in between these two extremes of no \
correlation and perfect correlation is the set of positions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " of a particle at timesteps ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". The position is correlated with its value at  the previous timestep.  \
Taking the case of a random walk on a grid (with fixed step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " ), the conditional probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(j | i)\)]],
  " for a particle to be at grid position ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " given that it was at position ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " on the previous step is ",
  Cell[BoxData[
      \(TraditionalForm\`P(j | i)\  = \ 
        p\ \[Delta]\_\(j - 1, \ i\) + \ q\ \[Delta]\_\(j + 1, \ i\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_\(i\ j\)\)]],
  " is the Kronecker delta function. Then the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(i, n; \ j, n + 1)\)]],
  " that a particle will be at position ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ",",
  StyleBox[" and ",
    FontSlant->"Italic"],
  "at step ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " is, according to Eq. ",
  ButtonBox["(8.2.9)",
    ButtonData:>{"Chapter8.nb", "(8.2.9)"},
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`P(i, n; \ j, 
          n + 1) = \(\(P(i, n)\) \((\ 
            p\ \[Delta]\_\(j - 1, \ i\) + \ 
              q\ \[Delta]\_\(j + 1, \ i\))\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(8.2.10)"],

Cell[TextData[{
  "If we now sum both sides over all locations ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", the left side becomes ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+i P(i, n; \ j, n + 1) = P(j, n + 1)\)]],
  ", the probability that a particles is at step ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " ",
  StyleBox["for any",
    FontSlant->"Italic"],
  " previous position. On the right side we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`p\ \(P(j - 1, n)\) + \ q\ \(P(j + 1, n)\)\)]],
  ". Therefore  we return to the master equation for this random walk, Eq. ",
  ButtonBox["(8.1.34)",
    ButtonData:>{"Chapter8.nb", "(8.1.34)"},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tFor a general uncorrelated random walk with a  probability distribution \
",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  " for each step, the conditional probability that particles are in a range \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[DifferentialD]x\)]],
  "  given that they were at position ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[Prime]\)]],
  " at the previous timestep, is ",
  Cell[BoxData[
      \(TraditionalForm\`P(x, \ 
          x + \[DifferentialD]x | x\^\[Prime])\  = \ \(w(
            x - x\^\[Prime])\) \(\(\[DifferentialD]x\)\(\ \)\)\)]],
  ". We can use this result to obtain a master equation for a general random \
walk. Let us assume that the position ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[Prime]\)]],
  " occured at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ".   Then the probability for consecutive steps at times ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\_n\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(n + 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho](x\^\[Prime], \ t\_n; x, 
          t\_\(n + 1\))\) \[DifferentialD]x\^\[Prime] \[DifferentialD]x\)]],
  ",  can be obtained from Eq. ",
  ButtonBox["(8.2.9)",
    ButtonData:>{"Chapter8.nb", "(8.2.9)"},
    ButtonStyle->"Hyperlink"],
  " : "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho](x\^\[Prime], t\_n; x, 
            t\_\(n + 1\))\) \[DifferentialD]x\^\[Prime] \[DifferentialD]x = \
\(\[Rho](x\^\[Prime], t\_n)\)\ \[DifferentialD]x\^\[Prime]\ \(w(
            x - x\^\[Prime])\)\ \[DifferentialD]x\)]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho](x\^\[Prime], 
          t\_n)\) \(\(\[DifferentialD]x\^\[Prime]\)\(\ \)\)\)]],
  "is the probability at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "; see Eq. ",
  ButtonBox["(8.1.35)",
    ButtonData:>{"Chapter8.nb", "(8.1.35)"},
    ButtonStyle->"Hyperlink"],
  ". Integrating both sides over ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[Prime]\)]],
  ", the ",
  "left-hand",
  " side becomes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho](x, t\_\(n + 1\))\)\ \[DifferentialD]x\)]],
  ", the probability  at the ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1  st\)]],
  " timestep that the particle is in the range ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ x + \[DifferentialD]x\)]],
  ", for any previous position.  Dividing both sides by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\)]],
  " we obtain the master equation for the evolution of the probability \
density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " in a general random walk,"
}], "Text",
  CellTags->"i:46"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, 
          t\_\(n + 1\)) = \ \[Integral]\[DifferentialD]x\^\[Prime] \( \[Rho](
              x\^\[Prime], t\_n)\)\ \(w(x - x\^\[Prime])\)\)]],
  "."
}], "NE2",
  CellTags->"(8.2.11)"],

Cell["\<\
This master equation can be solved directly for any given initial \
condition using Fourier transform techniques (see the exercises). \
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Correlation Functions", "Section",
  CellTags->{"i:47", "c:15"}],

Cell[TextData[{
  "\tHow can we tell if two outcomes of a random process, ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ",  are correlated or not? One way is to examine the ",
  StyleBox["correlation",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", defined by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(i\ j\), "\[RightAngleBracket]"}], 
                "-", 
                RowBox[{
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], "i", "\[RightAngleBracket]"}], 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], "j", "\[RightAngleBracket]"}]}]}], 
              ")"}], "/", 
            SqrtBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], \(i\^2\), 
                      "\[RightAngleBracket]"}], "-", 
                    SuperscriptBox[
                      RowBox[{
                        FormBox["\[LeftAngleBracket]",
                          "TraditionalForm"], "i", "\[RightAngleBracket]"}], 
                      "2"]}], ")"}], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], \(j\^2\), 
                      "\[RightAngleBracket]"}], "-", 
                    SuperscriptBox[
                      RowBox[{
                        FormBox["\[LeftAngleBracket]",
                          "TraditionalForm"], "j", "\[RightAngleBracket]"}], 
                      "2"]}], ")"}]}]]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(8.2.12)"],

Cell[TextData[{
  "The average ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(i\ j\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(i\ j\), "\[RightAngleBracket]"}], " ", 
          "=", "   ", \(\[Sum]\+\(i, j\)\ \(P(i, j)\)\ i\ j\)}], 
        TraditionalForm]]],
  ", where the sum is over all possible outcomes for ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P(i, j)\)\(\ \)\)\)]],
  "is the probability that both ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " occur. However, for uncorrelated outcomes, we can use Eq. ",
  ButtonBox["(8.2.8)",
    ButtonData:>{"Chapter8.nb", "(8.2.8)"},
    ButtonStyle->"Hyperlink"],
  " in which case we obtain ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(i\ j\), "\[RightAngleBracket]"}], "=", 
          RowBox[{\(\[Sum]\+i\ \(P(i)\) i\ \(\[Sum]\+j\ \(P(j)\) j\)\), "=", 
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "i", "\[RightAngleBracket]"}], 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "j", "\[RightAngleBracket]"}]}]}]}], 
        TraditionalForm]]],
  ". Therefore, for uncorrelated outcomes, Eq. ",
  ButtonBox["(8.2.12)",
    ButtonData:>{"Chapter8.nb", "(8.2.12)"},
    ButtonStyle->"Hyperlink"],
  " yields ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0\)]],
  ". For perfectly correlated outcomes where ",
  Cell[BoxData[
      \(TraditionalForm\`j = i\)]],
  ", Eq. ",
  ButtonBox["(8.2.12)",
    ButtonData:>{"Chapter8.nb", "(8.2.12)"},
    ButtonStyle->"Hyperlink"],
  " implies ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  ".  For perfect ",
  StyleBox["anticorrelation",
    FontSlant->"Italic"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(-i\)\)]],
  ", it is easy to see that ",
  Cell[BoxData[
      \(TraditionalForm\`c = \(-1\)\)]],
  ". Generally one can prove that ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " must be somewhere between ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ", with negative values implying some degree of anticorrelation, and \
positive values corresponding to positive correlation. "
}], "Text"],

Cell[TextData[{
  "\t Take, for example, the correlation between positions in a random walk \
that starts at the origin, with general steps ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  " . The correlation between positions at  timesteps ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n + m\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(c(n, n + m)\), "=", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(x\_n\ x\_\(n + m\)\), 
                  "\[RightAngleBracket]"}], "-", 
                RowBox[{
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(x\_n\), "\[RightAngleBracket]"}], 
                  
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(x\_\(n + m\)\), 
                    "\[RightAngleBracket]"}]}]}], ")"}], "/", 
            SqrtBox[
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], 
                  SuperscriptBox[
                    SubscriptBox[
                      StyleBox[
                        RowBox[{"\[Delta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "n"], "2"], 
                  "\[RightAngleBracket]"}], 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], 
                  SuperscriptBox[
                    SubscriptBox[
                      StyleBox[
                        RowBox[{"\[Delta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], \(n + m\)], "2"], 
                  "\[RightAngleBracket]"}]}]]}]}], TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "We already know that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\_n\), "\[RightAngleBracket]"}], " ", 
          "=", " ", 
          RowBox[{"n", " ", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "s", "\[RightAngleBracket]"}]}]}], 
        TraditionalForm]]],
  " for any ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". However, what is the value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\_n\ x\_\(n + m\)\), 
          "\[RightAngleBracket]"}], TraditionalForm]]],
  "? This is given by \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\_n\ x\_\(n + m\)\), 
            "\[RightAngleBracket]"}], " ", "=", "  ", 
          RowBox[{
            RowBox[{
              UnderoverscriptBox[
                StyleBox[\(\(\[Sum]\)\(\ \)\),
                  FontSize->16], \(i = 1\), "n"], " ", 
              UnderoverscriptBox[
                StyleBox[\(\(\[Sum]\)\(\ \)\),
                  FontSize->16], \(j = 1\), \(n + m\)], 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(\(s\_i\) s\_j\), 
                "\[RightAngleBracket]"}]}], " ", "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  UnderoverscriptBox[
                    StyleBox[\(\(\[Sum]\)\(\ \)\),
                      FontSize->16], \(i = 1\), "n"], 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(s\_i\^2\), 
                    "\[RightAngleBracket]"}]}], "+", " ", 
                RowBox[{
                  UnderoverscriptBox[
                    StyleBox[\(\(\[Sum]\)\(\ \)\),
                      FontSize->16], \(i = 1\), "n"], " ", 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(s\_i\), "\[RightAngleBracket]"}], 
                  " ", 
                  UnderoverscriptBox[
                    StyleBox[\(\(\[Sum]\)\(\ \)\),
                      
                      FontSize->
                        16], \(\(j = 1\)\+\(j \[NotEqual] \ i\)\), \(n + m\)],
                   
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(s\_j\), 
                    "\[RightAngleBracket]"}]}]}], " ", "=", 
              RowBox[{
                RowBox[{"n", 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(s\^2\), 
                    "\[RightAngleBracket]"}]}], " ", "+", " ", 
                RowBox[{\(n(n + m - 1)\), 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[LeftAngleBracket]",
                          "TraditionalForm"], "s", "\[RightAngleBracket]"}], 
                      ")"}], "2"], "  "}]}]}]}]}], TraditionalForm]]],
  ",\nwhere in the second step we separated out the terms with ",
  Cell[BoxData[
      \(TraditionalForm\`i = j\)]],
  ".  Then using Eqs. ",
  ButtonBox["(8.2.6)",
    ButtonData:>{"Chapter8.nb", "(8.2.6)"},
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(8.2.4)",
    ButtonData:>{"Chapter8.nb", "(8.2.4)"},
    ButtonStyle->"Hyperlink"],
  ", a little algebra leads to the result ",
  Cell[BoxData[
      \(TraditionalForm\`c(n, n + m) = \ \(\(n/\@\(n(n + m)\)\)\(\ \)\)\)]],
  ".  This shows that correlations between positions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + m\)\)]],
  " are always nonnegative, and slowly fall off as ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " increases. Over time, the particle loses memory of its previous position \
at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " as it steps randomly away from that position. If we consider the case ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  ", we see that ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`m > 0\)]],
  ": the loss of correlation is immediate because the first step is \
completely uncorrelated from the origin. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhomogeneous Random Walks", "Section",
  CellTags->{"i:48", "c:16"}],

Cell[TextData[{
  "In a real system, eventually the dust reaches the bottom of the fluid \
container; or the electrons reach the edge of the conductor. How can we allow \
for the effect of this barrier on the random walk? More generally, external \
forces applied to the dust grains or the electrons may vary with position. We \
would then expect that the distribution of the random steps should depend on \
the position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " of the particle: ",
  Cell[BoxData[
      \(TraditionalForm\`w = w(x, s)\)]],
  ". (Here we take ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to be the position ",
  StyleBox["before the step is taken.",
    FontSlant->"Italic"],
  ")   For example, for the case of a barrier at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "with particles confined to ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ", we would require that ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\  = \ 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`s < \(-x\)\)]],
  ", so that no steps below ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " are allowed. "
}], "Text"],

Cell[TextData[{
  "\tThe master equation for an inhomogeneous random walk follows from the \
same analysis as for Eq. ",
  ButtonBox["(8.2.11)",
    ButtonData:>{"Chapter8.nb", "(8.2.11)"},
    ButtonStyle->"Hyperlink"],
  ". Now the conditional probability that particles are in a range around ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " given that they were at previously at ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[Prime]\)]],
  "  is ",
  Cell[BoxData[
      \(TraditionalForm\`P(x, \ 
          x + \[DifferentialD]x | x\^\[Prime])\  = \ \(w(x\^\[Prime], 
            x - x\^\[Prime])\) \[DifferentialD]x\)]],
  ", and the resulting master equation is "
}], "Text",
  CellTags->"i:49"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Rho](x, 
        t\_\(n + 1\)) = \ \[Integral]\[DifferentialD]x\^\[Prime] \( \[Rho](
            x\^\[Prime], 
            t\_n)\)\ \(\(w(x\^\[Prime], x - x\^\[Prime])\)\(.\)\)\)]]], "NE2",\

  CellTags->"(8.2.13)"],

Cell[TextData[{
  "A drift velocity and a diffusion coefficient can still be defined for such \
an inhomogeneous random walk, provided that the steps are small compared to \
the inhomogeneity scale length. If this is so, then a Fokker-Planck equation \
can be obtained from Eq. ",
  ButtonBox["(8.2.13)",
    ButtonData:>{"Chapter8.nb", "(8.2.13)"},
    ButtonStyle->"Hyperlink"],
  ". Defining the step size  ",
  Cell[BoxData[
      \(TraditionalForm\`s\  = \(\(x\)\(-\)\(x\^\[Prime]\)\(\ \)\)\)]],
  " and changing the integration variable to ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ", Eq. ",
  ButtonBox["(8.2.13)",
    ButtonData:>{"Chapter8.nb", "(8.2.13)"},
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Rho](x, 
        t\_\(n + 1\)) = \ \[Integral]\[DifferentialD]s\ \(\[Rho](x - s, 
            t\_n)\)\ \(\(w(x - s, s)\)\(.\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "Assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t\_n)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\)]],
  " are slowly varying in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", we can Taylor-expand these functions to second order  in ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, 
          t\_\(n + 1\)) = \ \[Integral]\[DifferentialD]\(s(\ \(\[Rho](x, 
                    t\_n)\)\ \(w(x, \ s)\)\  - 
                s \(\[PartialD]\/\[PartialD]x\)[\(\[Rho](x, t\_n)\)\ \(w(x, \ 
                        s)\)\ ]\  + \(1\/2\) \(s\^2\) \(\[PartialD]\^2\/\
\[PartialD]x\^2\)[\(\[Rho](x, t\_n)\)\ \(w(x, \ s)\)\ ]\ \ )\)\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Dividing  by ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and performing the integration over ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " then yields the inhomogeneous Fokker-Planck equation:"
}], "Text",
  CellTags->"i:50"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Rho]\/\[PartialD]t + \(\[PartialD]\/\
\[PartialD]x\) \((\ \(\(v\&_\)(
                    x)\)\ \[Rho]\  - \ \ \(\[PartialD]\/\[PartialD]x\)\ [\(D(
                      x)\)\ \[Rho]])\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(8.2.14)"],

Cell["\<\
 The quantity in large parentheses is the particle flux due to \
diffusion and drift, where \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(D(x)\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], "/",
               "2"}], 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}], " ", "=", 
          RowBox[{"\[Integral]", 
            RowBox[{\(s\^2\), " ", \(w(x, s)\), \(\[DifferentialD]s/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(8.2.15)"],

Cell[" is the diffusion coefficient, and where ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(v\&_\)(x)\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "s", "\[RightAngleBracket]"}], 
            RowBox[{\((x)\), "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], "=", 
          RowBox[{"\[Integral]", 
            RowBox[{"s", " ", \(w(x, s)\), 
              RowBox[{\(\[DifferentialD]s\), "/", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]}]}]}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(8.2.16)"],

Cell[TextData[{
  "is related to the drift velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v(x)\)]],
  " of the particles. This relation follows from noting that diffusive flux \
has the form of Fick's law, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-D\)\ \[PartialD]\[Rho]/\[PartialD]x\)]],
  ", and flux due to drift has the form ",
  Cell[BoxData[
      \(TraditionalForm\`v\ \[Rho]\)]],
  ". Then we can write the  particle flux appearing in Eq. ",
  ButtonBox["(8.2.14)",
    ButtonData:>{"Chapter8.nb", "(8.2.14)"},
    ButtonStyle->"Hyperlink"],
  " as a sum of these two fluxes:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\(v\&_\)(
              x)\)\ \[Rho]\  - \ \ \[PartialD]\/\[PartialD]x\ \((\(D(
                  x)\)\ \[Rho])\) = \(v(
              x)\)\ \[Rho] - \(\(D\) \(\[PartialD]\[Rho]\/\[PartialD]x\)\(\ \
\)\)\)\)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "from which we obtain the drift velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`v(
          x)\  = \(\(\(v\&_\)(
            x)\)\(\ \)\(-\)\(\[PartialD]D\/\[PartialD]x\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(8.2.17)"],

Cell[TextData[{
  "\tThe inhomogeneous Fokker-Planck equation, written in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`v\&_\)]],
  ", is"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]\[Rho]\/\[PartialD]t + \(\[PartialD]\/\
\[PartialD]x\) \((\ \(v(x)\)\ \[Rho]\  - \ \ \ \(D(
                  x)\) \[PartialD]\[Rho]\/\[PartialD]x)\) = 0. \)]]], "NE2",
  CellTags->"(8.2.18)"],

Cell[TextData[{
  "Because this equation is inhomogeneous, it is difficult to solve \
analytically except in certain special cases. However, the numerical methods \
discussed in Chapter ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  " can be applied  - see the exercises. We can also use random walk \
simulations to obtain approximate numerical solutions to Eq. ",
  ButtonBox["(8.2.18)",
    ButtonData:>{"Chapter8.nb", "(8.2.18)"},
    ButtonStyle->"Hyperlink"],
  ". This method is considered in the next subsection.   "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["8.2.2 Simulations", "Subsubtitle",
  CellTags->"c:17"],

Cell[TextData[{
  "In order to create a random walk simulation  with steps distributed \
according to some general distribution ",
  Cell[BoxData[
      FormBox[
        RowBox[{"w", "(", "s", 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", we require a method of choosing points randomly from this probability \
distribution. Random number generators such as ",
  StyleBox["Random",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " distribute the particles uniformly over a given range. How do we generate \
a nonuniform distribution?  The two most commonly used approaches are the \
transformation method and the rejection method. "
}], "Text"],

Cell[CellGroupData[{

Cell["Transformation method", "Section",
  CellTags->{"i:52", "c:18"}],

Cell[TextData[{
  "The transformation method works as follows. We can use ",
  StyleBox["Random",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to generate a uniform distribution ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  " of particles over some range of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " . In order to generate a new distribution of particles, ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  ", we apply a transformation to the particle positions, ",
  Cell[BoxData[
      \(TraditionalForm\`y = y(x)\)]],
  ". A range of positions ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ x\  + \ \[DifferentialD]x\)]],
  " transforms to a new range  ",
  Cell[BoxData[
      \(TraditionalForm\`y(x) \[Rule] \ y(x + \[DifferentialD]x)\)]],
  ". Taylor expanding, this range may be written as ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\  \[Rule] \ y(x) + \[DifferentialD]y\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y = \[DifferentialD]x\
\ \ \ \[DifferentialD]y/\[DifferentialD]x\)]],
  ". The probability distribution  for ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w(y)\)]],
  ", is obtained from the fact that every particle in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\)]],
  " transforms to a particle in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\)]],
  ", so the number of particles in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\)]],
  " equals the number of particles in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`w(y)\  | \[DifferentialD]y | \  = \ \(p(
            x)\)\ \[DifferentialD]x\)]],
  "."
}], "NE2",
  CellTags->"(8.2.19)"],

Cell["In other words, ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`w(y)\  = \ 
        p(x)\  | \[DifferentialD]x/\[DifferentialD]y | \)]],
  "."
}], "NE2",
  CellTags->"(8.2.20)"],

Cell[TextData[{
  "Thus, to generate some distribution ",
  Cell[BoxData[
      \(TraditionalForm\`w(y)\)]],
  ", we can use Eq. ",
  ButtonBox["(8.2.20)",
    ButtonData:>{"Chapter8.nb", "(8.2.20)"},
    ButtonStyle->"Hyperlink"],
  " to determine the required transformation ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ", given that ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  " is constant. Then according to Eq. ",
  ButtonBox["(8.2.20)",
    ButtonData:>{"Chapter8.nb", "(8.2.20)"},
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(
          y)\  = \ \[Integral]\_\(-\[Infinity]\)\%y\( w(
              y)\) \[DifferentialD]y\)]],
  ", "
}], "NE2",
  CellTags->"(8.2.21)"],

Cell[TextData[{
  " where the function ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\)]],
  " is the inverse of the required transformation ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ", and we have dropped the constant ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " because this constant enters only as a normalization to ",
  Cell[BoxData[
      \(TraditionalForm\`w(y)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor example, lets assume that ",
  Cell[BoxData[
      \(TraditionalForm\`w(y)\  = \ y\^2/9\)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < 3\)]],
  ", and is zero otherwise. [This distribution has the proper normalization, \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( w(
              y)\) \[DifferentialD]y = 1\)]],
  ". ] Then according to Eq. ",
  ButtonBox["(8.2.21)",
    ButtonData:>{"Chapter8.nb", "(8.2.21)"},
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\  = \ 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`y < 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\  = \ y\^3/27\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0 < y < 3\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\  = \ 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`y > 3\)]],
  ". This function is plotted in Fig. ",
  ButtonBox["8.4",
    ButtonData:>"Fig. 8.4",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.20179 .13244 -18 -4.5 ]
[.20179 .13244 0 4.5 ]
[.20179 .25016 -18 -4.5 ]
[.20179 .25016 0 4.5 ]
[.20179 .36788 -18 -4.5 ]
[.20179 .36788 0 4.5 ]
[.20179 .4856 -18 -4.5 ]
[.20179 .4856 0 4.5 ]
[.20179 .60332 -6 -4.5 ]
[.20179 .60332 0 4.5 ]
[.21429 .64303 -14 0 ]
[.21429 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(1)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(2)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(3)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.21429 .13244 m
.22054 .13244 L
s
[(0.2)] .20179 .13244 1 0 Mshowa
.21429 .25016 m
.22054 .25016 L
s
[(0.4)] .20179 .25016 1 0 Mshowa
.21429 .36788 m
.22054 .36788 L
s
[(0.6)] .20179 .36788 1 0 Mshowa
.21429 .4856 m
.22054 .4856 L
s
[(0.8)] .20179 .4856 1 0 Mshowa
.21429 .60332 m
.22054 .60332 L
s
[(1)] .20179 .60332 1 0 Mshowa
.125 Mabswid
.21429 .04415 m
.21804 .04415 L
s
.21429 .07358 m
.21804 .07358 L
s
.21429 .10301 m
.21804 .10301 L
s
.21429 .16187 m
.21804 .16187 L
s
.21429 .1913 m
.21804 .1913 L
s
.21429 .22073 m
.21804 .22073 L
s
.21429 .27959 m
.21804 .27959 L
s
.21429 .30902 m
.21804 .30902 L
s
.21429 .33845 m
.21804 .33845 L
s
.21429 .39731 m
.21804 .39731 L
s
.21429 .42674 m
.21804 .42674 L
s
.21429 .45617 m
.21804 .45617 L
s
.21429 .51503 m
.21804 .51503 L
s
.21429 .54446 m
.21804 .54446 L
s
.21429 .57389 m
.21804 .57389 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
gsave
.21429 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.20178 .01472 L
.20742 .01472 L
.21019 .01472 L
.2114 .01472 L
.21274 .01472 L
.21394 .01472 L
.21506 .01472 L
.21625 .01472 L
.21753 .01472 L
.21819 .01472 L
.21892 .01472 L
.22024 .01472 L
.22152 .01472 L
.22272 .01472 L
.224 .01472 L
.22536 .01472 L
.22779 .01472 L
.22915 .01473 L
.23041 .01473 L
.23328 .01474 L
.2358 .01475 L
.23809 .01476 L
.24324 .01479 L
.24782 .01483 L
.25279 .0149 L
.2575 .01497 L
.26185 .01505 L
.27147 .01531 L
.28051 .01563 L
.29043 .01611 L
.30111 .01678 L
.32115 .01857 L
.33123 .01976 L
.34225 .02133 L
.36186 .02485 L
.38281 .02981 L
.40416 .03631 L
.42431 .04394 L
.46278 .06312 L
.5037 .09118 L
.5431 .12686 L
.58099 .17027 L
.62133 .22746 L
.66015 .29432 L
.70143 .37939 L
Mistroke
.74119 .47617 L
.76126 .53094 L
.77 .55607 L
.77943 .58412 L
.78201 .59194 L
.78342 .59624 L
.78473 .60027 L
.78585 .60332 L
.78705 .60332 L
.78959 .60332 L
.79914 .60332 L
.82013 .60332 L
.86154 .60332 L
.90144 .60332 L
.93982 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006P3oool400000003014A4@3oool0oooo06T0oooo100000000`0A4A40
oooo0?ooo`0b0?ooo`D00000=@3oool01@2IVIT04A4A0000000c<c<0c<c<03L0oooo0P0000000`0A
4A40oooo0?ooo`0Z0?ooo`00703oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo03@0
oooo00D0VIVI028R8P3^k^h0oooo04A4A00e0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<0>03oool0
0`000000oooo0?ooo`0[0?ooo`004@3oool6000000D0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0e0?ooo`0309VIV@0R8R80k^k^03X0oooo00<000000?ooo`3oool0<`3oool50000
02`0oooo000L0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0=P3oool00`2IVIT0
8R8R0>k^kP0h0?ooo`030:ZZZP0A4A40oooo03@0oooo00@0A4A40=gMg@3oool00000;@3oool001`0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0g0?ooo`0307MgM`1VIVH0oooo03H0
oooo00<04A4A0000002k^k/0=@3oool0103MgMd0EEEE0?ooo`00000]0?ooo`00703oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0=P3oool00`2k^k/0
8R8R0?ooo`0e0?ooo`0307MgM`3<c<`0000002d0oooo000L0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool0=03oool01@000000^k^k0?ooo`2IVIT04A4A03D0oooo00D04A4A09VIV@3o
ool0^k^k0000000f0?ooo`030>k^kP14A4@0000002d0oooo000J0?ooo`80EEEE00<000000?ooo`3o
ool0J`3oool205EEE@030000003oool0oooo03@0oooo00D0VIVI014A4@0000008R8R0<c<c00e0?oo
o`050:ZZZP0A4A400000014A4@2ZZZX0=`3oool00`1gMgL000000?ooo`0?0?ooo`<0000000<04A4A
0?ooo`3oool05`3oool00?l0ooooCP3oool00`0R8R80^k^k0?ooo`0H0?ooo`00DP3oool00`000000
oooo0?ooo`3h0?ooo`0309VIV@0c<c<0oooo01P0oooo001B0?ooo`030000003oool0oooo0?P0oooo
00<0gMgM0000002k^k/0603oool00580oooo00<000000?ooo`3oool0n03oool00`1EEED0MgMg03<c
<`0H0?ooo`00DP3oool00`000000oooo0?ooo`3g0?ooo`050=gMg@0A4A40oooo028R8P3<c<`05`3o
ool00140ooooo`00000b000000X0oooo00D0IVIV08R8R03oool0VIVI05EEE@0G0?ooo`00603oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`d000002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00h0oooo00<0k^k^0000003^k^h00P3oool00`000000gMgM0?ooo`0E0?ooo`00603oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0240oooo1`00000?0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
00h0oooo00@04A4A000000000000oooo0P0000000`0A4A40oooo0?ooo`0D0?ooo`00DP3oool00`00
0000oooo0?ooo`0X0?ooo`D00000iP3oool00580oooo00<000000?ooo`3oool0;@3oool300000><0
oooo001B0?ooo`030000003oool0oooo0300oooo0`00003P0?ooo`00DP3oool00`000000oooo0?oo
o`0c0?ooo`<00000g@3oool00580oooo00<000000?ooo`3oool0=P3oool400000=T0oooo001B0?oo
o`030000003oool0oooo03X0oooo0`00003F0?ooo`00DP3oool2000003h0oooo0P00003D0?ooo`00
DP3oool00`000000oooo0?ooo`0o0?ooo`800000dP3oool00580oooo00<000000?ooo`3oool0@@3o
ool200000=00oooo001B0?ooo`030000003oool0oooo04<0oooo0P00003>0?ooo`00DP3oool00`00
0000oooo0?ooo`150?ooo`800000c03oool00580oooo00<000000?ooo`3oool0A`3oool200000<X0
oooo001B0?ooo`030000003oool0oooo04T0oooo0P0000380?ooo`00DP3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0<D0oooo001B0?ooo`030000003oool0oooo04`0oooo0P000035
0?ooo`00DP3oool2000004l0oooo00<000000?ooo`3oool0`P3oool00580oooo00<000000?ooo`3o
ool0C`3oool200000<80oooo001B0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
_`3oool00580oooo00<000000?ooo`3oool0DP3oool200000;l0oooo001B0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0_03oool00580oooo00<000000?ooo`3oool0E@3oool20000
0;`0oooo001B0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0^@3oool00580oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`2h0?ooo`00DP3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo0;L0oooo001B0?ooo`800000F`3oool00`000000oooo0?ooo`2f
0?ooo`00DP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0;D0oooo001B0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0]03oool00580oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`2c0?ooo`00DP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0;80oooo001B0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0/@3oool0
0580oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2`0?ooo`00=`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001P3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo0:l0oooo000g0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R
8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0[`3oool003L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80
k^k^00L0oooo0`00001R0?ooo`030000003oool0oooo0:h0oooo000g0?ooo`050000003oool0oooo
0?ooo`0000003@3oool00`2IVIT08R8R0>k^kP060?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0[@3oool003L0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1VIVH0
oooo00D0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2/0?ooo`00=`3oool01@0A
4A40oooo0?ooo`3oool04A4A00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo0:/0oooo000g0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool0
1@000000^k^k0?ooo`2IVIT04A4A00H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`2Z0?ooo`00=`3oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D0VIVI014A4@0000008R8R
0<c<c0060?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0Z@3oool00580oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`2Y0?ooo`00DP3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo0:P0oooo001B0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0Y`3oool00580oooo0P00001[0?ooo`030000003oool0oooo0:H0oooo001B0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0Y@3oool00580oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`2T0?ooo`00DP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo0:<0oooo001B0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0X`3oool00580
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`2R0?ooo`00DP3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo0:40oooo001B0?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0X@3oool00580oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`2P
0?ooo`00DP3oool200000780oooo00<000000?ooo`3oool0W`3oool00580oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`2N0?ooo`00DP3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo09h0oooo001B0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0W@3o
ool00580oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`2L0?ooo`00DP3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo09`0oooo001B0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0V`3oool00580oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`2J0?ooo`00DP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo09T0oooo001B
0?ooo`800000N03oool00`000000oooo0?ooo`2I0?ooo`00DP3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo09P0oooo001B0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0U`3oool00580oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`2G0?ooo`00DP3o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo09H0oooo001B0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool0U@3oool003L0oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R1P3oool200000003014A4@3oool0oooo00@0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`2E0?ooo`00=`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R87
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`2D
0?ooo`00=`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo1@0000060?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0U03oool003L0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`0404A4A03MgMd0oooo000000L0oooo0`00001m0?ooo`030000003oool0oooo09<0oooo000g
0?ooo`050000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE0?ooo`0000070?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0TP3oool003L0oooo00D04A4A0?ooo`3oool0oooo
014A4@0<0?ooo`0307MgM`3<c<`0000000L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`2B0?ooo`00=`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A0000000
1`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0940oooo000g0?ooo`050>k^kP0c
<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`060?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool0T@3oool00580oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2@0?ooo`00DP3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo08l0oooo001B0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool0S`3oool00580oooo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`2>0?ooo`00DP3oool2000008<0oooo00<000000?ooo`3oool0
SP3oool00580oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`2=0?ooo`00DP3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo08`0oooo001B0?ooo`030000003oool0oooo
08@0oooo00<000000?ooo`3oool0S03oool00580oooo00<000000?ooo`3oool0Q@3oool00`000000
oooo0?ooo`2;0?ooo`00DP3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08/0oooo
001B0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0RP3oool00580oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`2:0?ooo`00DP3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo08T0oooo001B0?ooo`800000R03oool00`000000oooo0?ooo`290?ooo`00
DP3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo08P0oooo001B0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0R03oool00580oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`280?ooo`00DP3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
08L0oooo001B0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0Q`3oool00580oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`260?ooo`00DP3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo08H0oooo001B0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0Q@3oool00580oooo0P00002<0?ooo`030000003oool0oooo08D0oooo001B0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0Q03oool00580oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`240?ooo`00DP3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo08<0oooo001B0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0P`3oool0
0580oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`220?ooo`00=`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c<c<00000014A4@3<c<`01P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0880oooo000g0?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL01@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P060?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0PP3oool003L0oooo00D04A4A0?ooo`3oool0oooo014A
4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0840oooo000g0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000VIVI
0?ooo`2IVIT08R8R00H0oooo0`00002?0?ooo`030000003oool0oooo0840oooo000g0?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A4A40c<c<00H0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`200?ooo`00=`3oool01@0A4A40oooo0?ooo`3oool04A4A
00/0oooo00<0EEEE08R8R03oool0203oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
0800oooo000g0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool00`3MgMd04A4A09VIV@080?oo
o`030000003oool0oooo0940oooo00<000000?ooo`3oool0O`3oool003L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@H0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`1o0?ooo`00DP3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
07h0oooo001B0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0OP3oool00580oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1m0?ooo`00DP3oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo07d0oooo001B0?ooo`800000U03oool00`000000oooo0?ooo`1m
0?ooo`00DP3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo07`0oooo001B0?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0O03oool00580oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`1k0?ooo`00DP3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo07/0oooo001B0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0NP3oool0
0580oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1j0?ooo`00DP3oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo07X0oooo001B0?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0N@3oool00580oooo0P00002H0?ooo`030000003oool0oooo07T0oooo001B
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0N03oool00580oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`1h0?ooo`00DP3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo07L0oooo001B0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
M`3oool00580oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1g0?ooo`00DP3oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo07H0oooo001B0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0MP3oool00580oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`1e0?ooo`00DP3oool2000009`0oooo00<000000?ooo`3oool0M@3oool00580oooo00<0
00000?ooo`3oool0W03oool00`000000oooo0?ooo`1d0?ooo`00DP3oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo07@0oooo001B0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0M03oool00580oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`1c0?ooo`00
DP3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo07<0oooo000g0?ooo`050>k^kP0c
<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c0060?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0LP3oool003L0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00H0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`1b0?ooo`00=`3oool01@0A4A40oooo0?ooo`3oool04A4A
00/0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0L@3oool003L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0503<c<`2IVIT0
oooo09VIV@0c<c<01P3oool3000009l0oooo00<000000?ooo`3oool0L@3oool003L0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<c<`01P3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo0740oooo000g0?ooo`05014A4@3oool0oooo0?ooo`0A4A40
2`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A00H0oooo00<000000?ooo`3oool0X03oool00`000000
oooo0?ooo`1`0?ooo`00=`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3o
ool0^k^k000000060?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0L03oool003L0
oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01P3oool0
0`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0700oooo001B0?ooo`030000003oool0oooo
0:40oooo00<000000?ooo`3oool0K`3oool00580oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`1_0?ooo`00DP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo06h0oooo
001B0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0KP3oool00580oooo0P00002S
0?ooo`030000003oool0oooo06h0oooo001B0?ooo`030000003oool0oooo0:<0oooo00<000000?oo
o`3oool0K@3oool00580oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`1]0?ooo`00
DP3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo06d0oooo001B0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0K03oool00580oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`1/0?ooo`00DP3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
06`0oooo001B0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0J`3oool00580oooo
0P00002V0?ooo`030000003oool0oooo06/0oooo001B0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool0J`3oool00580oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`1[
0?ooo`00DP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo06X0oooo001B0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool0JP3oool00580oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`1Z0?ooo`00DP3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo06T0oooo001B0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0J@3oool0
0580oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`1Y0?ooo`00DP3oool200000:T0
oooo00<000000?ooo`3oool0J03oool00580oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`1X0?ooo`00DP3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo06P0oooo001B
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0I`3oool00580oooo00<000000?oo
o`3oool0Z@3oool00`000000oooo0?ooo`1W0?ooo`00DP3oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo06L0oooo001B0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
IP3oool004P0oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0:X0oooo00<0
00000?ooo`3oool0IP3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2[
0?ooo`030000003oool0oooo06D0oooo001:0?ooo`030000003oool0oooo00D0oooo0`00002[0?oo
oc/00000;@3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooa@0
oooo001:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00BP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo503oool004X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooa@0oooo00180?ooo`80EEEE00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?oooa@0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo001B0?ooo`<0000000<04A4A0?ooo`3oool0o`3ooolA0?ooo`00D03oool01P1g
MgL0IVIV0?ooo`3oool08R8R0;^k^`D0oooo00<0IVIV07MgM`3oool0o`3oool;0?ooo`00C`3oool0
0`3MgMd04A4A0>k^kP020?ooo`0309VIV@0c<c<0oooo00@0oooo00<0k^k^014A4@3MgMd0o`3oool;
0?ooo`00A03oool200000080oooo0P0000050?ooo`0305EEE@2IVIT0oooo0080oooo00<0gMgM0000
002k^k/01@3oool00`28R8P0IVIV0?ooo`3o0?ooo`X0oooo00140?ooo`060>k^kP0R8R80R8R80<c<
c0000000c<c<1@3oool00`000000oooo0?ooo`020?ooo`0305EEE@1gMgL0<c<c00D0oooo00<0k^k^
0000003oool0o`3oool:0?ooo`00A@3oool0103MgMd000000000003<c<`60?ooo`0903<c<`3oool0
oooo0?ooo`3MgMd04A4A0?ooo`0R8R80c<c<00D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
A@3oool0103^k^h08R8R0000003^k^h60?ooo`0903<c<`3oool0oooo0?ooo`1VIVH0R8R80?ooo`2I
VIT0EEEE00D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00A03oool01@3^k^h08R8R07MgM`1g
MgL0<c<c00H0oooo00H000000>k^kP3oool0k^k^0000003^k^h20?ooo`030000003MgMd0oooo0080
oooo00<0k^k^0000003oool0o`3oool:0?ooo`00A03oool200000080oooo0P0000050?ooo`0405EE
E@1gMgL0oooo014A4@80000000@0oooo0000000000004A4A0`3oool00`1gMgL0EEEE0?ooo`3o0?oo
o`X0oooo001?0?ooo`030=gMg@0A4A40k^k^00T0oooo00<0k^k^014A4@3MgMd0o`3oool;0?ooo`00
D03oool00`1gMgL0IVIV0?ooo`080?ooo`0306IVIP1gMgL0oooo0?l0oooo2`3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.42366, -0.0840035, \
0.0215521, 0.00697441}}],

Cell[TextData[{
  "Fig. 8.4 The function ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\)]],
  " for the choice ",
  Cell[BoxData[
      \(TraditionalForm\`w(y)\  = \ y\^2/9\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < 3\)]],
  "."
}], "Caption",
  CellTags->"Fig. 8.4"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " is then ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\  = \ 3\ \(\(x\)\(\ \)\)\^\(1/3\)\)]],
  " over the range of interest,  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " .  Below, we define a random number ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " that is distributed according to ",
  Cell[BoxData[
      \(TraditionalForm\`w(y)\)]],
  ", and generate the resulting distribution out of ",
  Cell[BoxData[
      \(TraditionalForm\`10, 000\)]],
  " random numbers. We compare the histogram in bins of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.1"}], 
        TraditionalForm]]],
  " with the function 10,000 ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w(y)\), " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", which is the expected number of particles in a bin."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(y[x_]\  = \ 3 \((x)\)\^\((1/3)\);\)\), "\n", 
    \(\(\(s[]\  := \ y[Random[]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(data = Table[s[], {10000}];\)\), "\n", 
    \(\(<< Graphics`;\)\), "\n", 
    \(\(h = 
        Histogram[data, HistogramRange \[Rule] {\(-1\), 4}, 
          HistogramCategories \[Rule] \ 50, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(t\  = \ 
        Plot[0.1\ \ 10000\ \ y^2/9, {y, 0, 3}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[h, t, DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.12"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.196078 0.196078 0.0147151 0.000588604 [
[.19608 .00222 -3 -9 ]
[.19608 .00222 3 0 ]
[.39216 .00222 -3 -9 ]
[.39216 .00222 3 0 ]
[.58824 .00222 -3 -9 ]
[.58824 .00222 3 0 ]
[.78431 .00222 -3 -9 ]
[.78431 .00222 3 0 ]
[.98039 .00222 -3 -9 ]
[.98039 .00222 3 0 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19608 .01472 m
.19608 .02097 L
s
[(0)] .19608 .00222 0 1 Mshowa
.39216 .01472 m
.39216 .02097 L
s
[(1)] .39216 .00222 0 1 Mshowa
.58824 .01472 m
.58824 .02097 L
s
[(2)] .58824 .00222 0 1 Mshowa
.78431 .01472 m
.78431 .02097 L
s
[(3)] .78431 .00222 0 1 Mshowa
.98039 .01472 m
.98039 .02097 L
s
[(4)] .98039 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .13244 m
.00625 .13244 L
s
[(200)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(400)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(600)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(800)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1000)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.01961 .01472 L
.01961 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.01961 .01472 L
.01961 .01472 L
0 .01472 L
s
1 0 0 r
.01961 .01472 m
.01961 .01472 L
.03922 .01472 L
.03922 .01472 L
F
0 g
.01961 .01472 m
.01961 .01472 L
.03922 .01472 L
.03922 .01472 L
.01961 .01472 L
s
1 0 0 r
.03922 .01472 m
.03922 .01472 L
.05882 .01472 L
.05882 .01472 L
F
0 g
.03922 .01472 m
.03922 .01472 L
.05882 .01472 L
.05882 .01472 L
.03922 .01472 L
s
1 0 0 r
.05882 .01472 m
.05882 .01472 L
.07843 .01472 L
.07843 .01472 L
F
0 g
.05882 .01472 m
.05882 .01472 L
.07843 .01472 L
.07843 .01472 L
.05882 .01472 L
s
1 0 0 r
.07843 .01472 m
.07843 .01472 L
.09804 .01472 L
.09804 .01472 L
F
0 g
.07843 .01472 m
.07843 .01472 L
.09804 .01472 L
.09804 .01472 L
.07843 .01472 L
s
1 0 0 r
.09804 .01472 m
.09804 .01472 L
.11765 .01472 L
.11765 .01472 L
F
0 g
.09804 .01472 m
.09804 .01472 L
.11765 .01472 L
.11765 .01472 L
.09804 .01472 L
s
1 0 0 r
.11765 .01472 m
.11765 .01472 L
.13725 .01472 L
.13725 .01472 L
F
0 g
.11765 .01472 m
.11765 .01472 L
.13725 .01472 L
.13725 .01472 L
.11765 .01472 L
s
1 0 0 r
.13725 .01472 m
.13725 .01472 L
.15686 .01472 L
.15686 .01472 L
F
0 g
.13725 .01472 m
.13725 .01472 L
.15686 .01472 L
.15686 .01472 L
.13725 .01472 L
s
1 0 0 r
.15686 .01472 m
.15686 .01472 L
.17647 .01472 L
.17647 .01472 L
F
0 g
.15686 .01472 m
.15686 .01472 L
.17647 .01472 L
.17647 .01472 L
.15686 .01472 L
s
1 0 0 r
.17647 .01472 m
.17647 .01472 L
.19608 .01472 L
.19608 .01472 L
F
0 g
.17647 .01472 m
.17647 .01472 L
.19608 .01472 L
.19608 .01472 L
.17647 .01472 L
s
1 0 0 r
.19608 .01472 m
.19608 .01472 L
.21569 .01472 L
.21569 .01472 L
F
0 g
.19608 .01472 m
.19608 .01472 L
.21569 .01472 L
.21569 .01472 L
.19608 .01472 L
s
1 0 0 r
.21569 .01472 m
.21569 .01648 L
.23529 .01648 L
.23529 .01472 L
F
0 g
.21569 .01472 m
.21569 .01648 L
.23529 .01648 L
.23529 .01472 L
.21569 .01472 L
s
1 0 0 r
.23529 .01472 m
.23529 .01707 L
.2549 .01707 L
.2549 .01472 L
F
0 g
.23529 .01472 m
.23529 .01707 L
.2549 .01707 L
.2549 .01472 L
.23529 .01472 L
s
1 0 0 r
.2549 .01472 m
.2549 .02237 L
.27451 .02237 L
.27451 .01472 L
F
0 g
.2549 .01472 m
.2549 .02237 L
.27451 .02237 L
.27451 .01472 L
.2549 .01472 L
s
1 0 0 r
.27451 .01472 m
.27451 .02708 L
.29412 .02708 L
.29412 .01472 L
F
0 g
.27451 .01472 m
.27451 .02708 L
.29412 .02708 L
.29412 .01472 L
.27451 .01472 L
s
1 0 0 r
.29412 .01472 m
.29412 .03237 L
.31373 .03237 L
.31373 .01472 L
F
0 g
.29412 .01472 m
.29412 .03237 L
.31373 .03237 L
.31373 .01472 L
.29412 .01472 L
s
1 0 0 r
.31373 .01472 m
.31373 .04415 L
.33333 .04415 L
.33333 .01472 L
F
0 g
.31373 .01472 m
.31373 .04415 L
.33333 .04415 L
.33333 .01472 L
.31373 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .04532 L
.35294 .04532 L
.35294 .01472 L
F
0 g
.33333 .01472 m
.33333 .04532 L
.35294 .04532 L
.35294 .01472 L
.33333 .01472 L
s
1 0 0 r
.35294 .01472 m
.35294 .07299 L
.37255 .07299 L
.37255 .01472 L
F
0 g
.35294 .01472 m
.35294 .07299 L
.37255 .07299 L
.37255 .01472 L
.35294 .01472 L
s
1 0 0 r
.37255 .01472 m
.37255 .07358 L
.39216 .07358 L
.39216 .01472 L
F
0 g
.37255 .01472 m
.37255 .07358 L
.39216 .07358 L
.39216 .01472 L
.37255 .01472 L
s
1 0 0 r
.39216 .01472 m
.39216 .08358 L
.41176 .08358 L
.41176 .01472 L
F
0 g
.39216 .01472 m
.39216 .08358 L
.41176 .08358 L
.41176 .01472 L
.39216 .01472 L
s
1 0 0 r
.41176 .01472 m
.41176 .10301 L
.43137 .10301 L
.43137 .01472 L
F
0 g
.41176 .01472 m
.41176 .10301 L
.43137 .10301 L
.43137 .01472 L
.41176 .01472 L
s
1 0 0 r
.43137 .01472 m
.43137 .11007 L
.45098 .11007 L
.45098 .01472 L
F
0 g
.43137 .01472 m
.43137 .11007 L
.45098 .11007 L
.45098 .01472 L
.43137 .01472 L
s
1 0 0 r
.45098 .01472 m
.45098 .14244 L
.47059 .14244 L
.47059 .01472 L
F
0 g
.45098 .01472 m
.45098 .14244 L
.47059 .14244 L
.47059 .01472 L
.45098 .01472 L
s
1 0 0 r
.47059 .01472 m
.47059 .16245 L
.4902 .16245 L
.4902 .01472 L
F
0 g
.47059 .01472 m
.47059 .16245 L
.4902 .16245 L
.4902 .01472 L
.47059 .01472 L
s
1 0 0 r
.4902 .01472 m
.4902 .16245 L
.5098 .16245 L
.5098 .01472 L
F
0 g
.4902 .01472 m
.4902 .16245 L
.5098 .16245 L
.5098 .01472 L
.4902 .01472 L
s
1 0 0 r
.5098 .01472 m
.5098 .1913 L
.52941 .1913 L
.52941 .01472 L
F
0 g
.5098 .01472 m
.5098 .1913 L
.52941 .1913 L
.52941 .01472 L
.5098 .01472 L
s
1 0 0 r
.52941 .01472 m
.52941 .20071 L
.54902 .20071 L
.54902 .01472 L
F
0 g
.52941 .01472 m
.52941 .20071 L
.54902 .20071 L
.54902 .01472 L
.52941 .01472 L
s
1 0 0 r
.54902 .01472 m
.54902 .24133 L
.56863 .24133 L
.56863 .01472 L
F
0 g
.54902 .01472 m
.54902 .24133 L
.56863 .24133 L
.56863 .01472 L
.54902 .01472 L
s
1 0 0 r
.56863 .01472 m
.56863 .27429 L
.58824 .27429 L
.58824 .01472 L
F
0 g
.56863 .01472 m
.56863 .27429 L
.58824 .27429 L
.58824 .01472 L
.56863 .01472 L
s
1 0 0 r
.58824 .01472 m
.58824 .2996 L
.60784 .2996 L
.60784 .01472 L
F
0 g
.58824 .01472 m
.58824 .2996 L
.60784 .2996 L
.60784 .01472 L
.58824 .01472 L
s
1 0 0 r
.60784 .01472 m
.60784 .31255 L
.62745 .31255 L
.62745 .01472 L
F
0 g
.60784 .01472 m
.60784 .31255 L
.62745 .31255 L
.62745 .01472 L
.60784 .01472 L
s
1 0 0 r
.62745 .01472 m
.62745 .33433 L
.64706 .33433 L
.64706 .01472 L
F
0 g
.62745 .01472 m
.62745 .33433 L
.64706 .33433 L
.64706 .01472 L
.62745 .01472 L
s
1 0 0 r
.64706 .01472 m
.64706 .35905 L
.66667 .35905 L
.66667 .01472 L
F
0 g
.64706 .01472 m
.64706 .35905 L
.66667 .35905 L
.66667 .01472 L
.64706 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .44557 L
.68627 .44557 L
.68627 .01472 L
F
0 g
.66667 .01472 m
.66667 .44557 L
.68627 .44557 L
.68627 .01472 L
.66667 .01472 L
s
1 0 0 r
.68627 .01472 m
.68627 .41614 L
.70588 .41614 L
.70588 .01472 L
F
0 g
.68627 .01472 m
.68627 .41614 L
.70588 .41614 L
.70588 .01472 L
.68627 .01472 L
s
1 0 0 r
.70588 .01472 m
.70588 .46735 L
.72549 .46735 L
.72549 .01472 L
F
0 g
.70588 .01472 m
.70588 .46735 L
.72549 .46735 L
.72549 .01472 L
.70588 .01472 L
s
1 0 0 r
.72549 .01472 m
.72549 .48207 L
.7451 .48207 L
.7451 .01472 L
F
0 g
.72549 .01472 m
.72549 .48207 L
.7451 .48207 L
.7451 .01472 L
.72549 .01472 L
s
1 0 0 r
.7451 .01472 m
.7451 .57036 L
.76471 .57036 L
.76471 .01472 L
F
0 g
.7451 .01472 m
.7451 .57036 L
.76471 .57036 L
.76471 .01472 L
.7451 .01472 L
s
1 0 0 r
.76471 .01472 m
.76471 .60273 L
.78431 .60273 L
.78431 .01472 L
F
0 g
.76471 .01472 m
.76471 .60273 L
.78431 .60273 L
.78431 .01472 L
.76471 .01472 L
s
1 0 0 r
.78431 .01472 m
.78431 .01472 L
.80392 .01472 L
.80392 .01472 L
F
0 g
.78431 .01472 m
.78431 .01472 L
.80392 .01472 L
.80392 .01472 L
.78431 .01472 L
s
1 0 0 r
.80392 .01472 m
.80392 .01472 L
.82353 .01472 L
.82353 .01472 L
F
0 g
.80392 .01472 m
.80392 .01472 L
.82353 .01472 L
.82353 .01472 L
.80392 .01472 L
s
1 0 0 r
.82353 .01472 m
.82353 .01472 L
.84314 .01472 L
.84314 .01472 L
F
0 g
.82353 .01472 m
.82353 .01472 L
.84314 .01472 L
.84314 .01472 L
.82353 .01472 L
s
1 0 0 r
.84314 .01472 m
.84314 .01472 L
.86275 .01472 L
.86275 .01472 L
F
0 g
.84314 .01472 m
.84314 .01472 L
.86275 .01472 L
.86275 .01472 L
.84314 .01472 L
s
1 0 0 r
.86275 .01472 m
.86275 .01472 L
.88235 .01472 L
.88235 .01472 L
F
0 g
.86275 .01472 m
.86275 .01472 L
.88235 .01472 L
.88235 .01472 L
.86275 .01472 L
s
1 0 0 r
.88235 .01472 m
.88235 .01472 L
.90196 .01472 L
.90196 .01472 L
F
0 g
.88235 .01472 m
.88235 .01472 L
.90196 .01472 L
.90196 .01472 L
.88235 .01472 L
s
1 0 0 r
.90196 .01472 m
.90196 .01472 L
.92157 .01472 L
.92157 .01472 L
F
0 g
.90196 .01472 m
.90196 .01472 L
.92157 .01472 L
.92157 .01472 L
.90196 .01472 L
s
1 0 0 r
.92157 .01472 m
.92157 .01472 L
.94118 .01472 L
.94118 .01472 L
F
0 g
.92157 .01472 m
.92157 .01472 L
.94118 .01472 L
.94118 .01472 L
.92157 .01472 L
s
1 0 0 r
.94118 .01472 m
.94118 .01472 L
.96078 .01472 L
.96078 .01472 L
F
0 g
.94118 .01472 m
.94118 .01472 L
.96078 .01472 L
.96078 .01472 L
.94118 .01472 L
s
1 0 0 r
.96078 .01472 m
.96078 .01472 L
.98039 .01472 L
.98039 .01472 L
F
0 g
.96078 .01472 m
.96078 .01472 L
.98039 .01472 L
.98039 .01472 L
.96078 .01472 L
s
1 0 0 r
.98039 .01472 m
.98039 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.98039 .01472 m
.98039 .01472 L
1 .01472 L
1 .01472 L
.98039 .01472 L
s
.19608 .01472 m
.1968 .01472 L
.19747 .01472 L
.19823 .01472 L
.19895 .01473 L
.20023 .01474 L
.20162 .01477 L
.20316 .0148 L
.20478 .01484 L
.2077 .01494 L
.2107 .01508 L
.21352 .01523 L
.21994 .01568 L
.22649 .01629 L
.23248 .01697 L
.24597 .01895 L
.25769 .02117 L
.27049 .02413 L
.2956 .03156 L
.31976 .04074 L
.34545 .05267 L
.37019 .06629 L
.39401 .08135 L
.41933 .0995 L
.44372 .11904 L
.46717 .13973 L
.49214 .16382 L
.51617 .18901 L
.54172 .21794 L
.56633 .24791 L
.59 .27868 L
.61519 .31352 L
.63945 .3491 L
.66276 .3852 L
.68759 .42567 L
.71149 .4666 L
.7369 .51225 L
.76137 .5583 L
.78431 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00G_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03cooooo1?l000000ol@
413oooooooooo`0hooooo`Go0000>_ooool01OnHV9So410@o`000?lb<S;oc<c<03gooooo0_l00000
0ol@413oooooooooo`04ooooo`00G_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03kooooo00?o0000
ooooooooool0>_ooool01OnHV9So8B4Qonk^k_ooooooA4A403[ooooo00Go410@okZj^_ooooooMgMg
oc8b<P0nooooo`03o`000?oooooooooo00Gooooo001Nooooo`05oa0@4?ooooooooooooooool@4100
?_ooool00ol0003oooooooooo`0kooooo`03oiRHV?lQ8B7ok^k^03oooooo00?o0000ooooooooool0
>Oooool5o`0000Kooooo001Nooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003ooooo
ooooo`0looooo`03oiRHV?lQ8B7ok^k^03gooooo00?oZJVYoa0@4?ooool0>_ooool01?m4A4CogMgM
ooooool00007ooooo`00G_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000oooooooo
ool0?Oooool00omgMgOoIVIVooooo`0kooooo`03oa0@4?l0003o^[Zj03_ooooo00CogMgMoeEEEOoo
oooo00001oooool005kooooo00Go410@oooooooooooooooooa0@400nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0>oooool00onj^[[o8B4Qooooo`0kooooo`03ogMgMoo<c<co0000
00Oooooo001Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?_ooool00ol0003oooooooooo`0joooo
o`05o`000?nj^[[ooooooiRHV?l@4100>_ooool01Ol@413oV9RHoooooonj^[[o000003cooooo00?o
k^k^odA4A?l000001oooool005kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0looooo`03oeEEEOmV
IVKo000003cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00jooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0?Oooool00omgMgOo0000ooooo`06ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4
ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oo
ooooA?ooool002;oooooool00017o`0000008_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00Cooooo3Ol00006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo000Rooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool04?ooool4o`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool0
02;ooooo00?o0000ooooooooool0Coooool8o`0000Goo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`1Fooooo`Oo00001_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`15ooooo`008_ooool00ol0003oooooooooo`1Looooo`?o00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`15ooooo`008_ooool00ol0003oooooooooo`1Looooo`So00001Ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000
ooooooooool0H_ooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo06?ooooo0ol00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15oooo
o`008_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo003oo`0000;o000000?oo`00o`000?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`;o0000
I?ooool=o`0000Koo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0Jooo
ool2o`0000;ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool0
0ol0003oooooooooo`1]ooooo`?o00001_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0
003oooooooooo`1_ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;o
oooo00?o0000ooooooooool0Koooool3o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo
00?o0000ooooooooool0Koooool00ol0003oo`00ool00002o`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
AOooool002;ooooo00?o0000ooooooooool0Koooool00ol0003oo`00ool00002ool00003o`000?oo
003o000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo04Gooooo000Rooooo`03o`000?oooooooooo06oooooo00?o0000ool00?oo00000ooo0002
o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo04Gooooo000Rooooo`03o`000?oooooooooo06oooooo00?o0000ool00?oo00001?oo0002o`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
04Gooooo000Rooooo`;o0000L?ooool>o`0000Goo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`15ooooo`008_ooool00ol0003oooooooooo`1jooooo`?o00001Ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo07cooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000R
ooooo`03o`000?oooooooooo07cooooo1ol00006ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Roooo
o`03o`000?oooooooooo07oooooo00Co0000oooooooooooo00001_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15
ooooo`008_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooo000000Koo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0AOooool002;ooooo00?o0000ooooooooool0POooool2o`0000Koo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0AOooool002;ooooo00?o0000ooooooooool0P_ooool2o`0000Goo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
AOooool002;ooooo00?o0000ooooooooool0P_ooool00ol0003oo`00o`000004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo04Gooooo000Rooooo`03o`000?oooooooooo08;ooooo00?o0000ool00?oo00000_l00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo04Gooooo000Rooooo`;o0000Poooool8o`0000Goo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03
o`000?oooooooooo08Sooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`29ooooo`Oo0000
1Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oo
oooooooo08_ooooo00Go0000ooooooooooooooooo`000005ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0S?ooool01?l0003ooooooooo
ool00005ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o
0000ooooooooool0SOooool00ol0003oooooo`000005ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0S_ooool2o`0000Goo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`2?ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`15ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2?ooooo`;o
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0008ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0008oooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Gooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2?
ooooo`04o`000?oo003oo`00o`0000;oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`15ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0Soooool01ol0003oo`00
ool00?oo003o0000ool00?l000001_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`002oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0Soooool00ol0003oo`00ool00002ool000;o00001_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`15ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`2?ooooo`So00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`001oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`2Eooooo`03o`000?oo003o000000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0AOooool002;ooooo00?o0000ooooooooool0UOooool01?l0003oo`00ool00?l00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo09Gooooo00Go0000ool00?oo
003oo`00o`000002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo09Go
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00o`000005ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oo003oo`0000?oo`000_l00005ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool2o`0009Kooooo3_l0
0006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000
ooooooooool0W?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`2Moooo
o`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo09kooooo00Go0000oooooooo
ooooooooo`000006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;o
oooo00?o0000ooooooooool0Woooool01?l0003oooooooooool00006ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0X?ooool00ol0003o
ooooo`000006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo
00?o0000ooooooooool0XOooool2o`0000Koo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`15ooooo`008_ooool00ol0003oooooooooo`2Rooooo`03o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`2R
ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Roooo
o`;o0000Xoooool8o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000oooooooo
ool0YOooool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;o
oooo00?o0000ooooooooool0Y_ooool01?l0003oooooooooool00005ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
04Gooooo000Rooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooool000001_l00005ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`00
8_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
AOooool002;ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo04Gooooo000Rooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`2[ooooo`05o`000?oooooooooo
ooooool000001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0AOooool002;ooooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15
ooooo`008_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo000000Goo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`;o
0000[_ooool00ol0003oooooo`000005ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`2^ooooo`;o0000
1Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
AOooool002;ooooo00?o0000ooooooooool0[oooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool0
0ol0003oooooooooo`2_ooooo`;o00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0[oooool00ol0
003oo`00o`000003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`2_ooooo`03o`000?oo003o000000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Go
oooo000Rooooo`03o`000?oooooooooo0:oooooo00Co0000ool00?oo003o00000_oo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool000Wooooo
0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2_ooooo`Oo00001_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Gooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`2dooooo`;o00001_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo
0007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0;Gooooo00?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo04Gooooo0007ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool3
o`000;Gooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo04Gooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2eooooo`;o0000
1Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0008ooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`2eooooo`03o`000?oo003o000000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`15ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0]Oooool00ol0003oo`00o`000004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0AOooool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0;Gooooo00Co0000
ool00?oo003o00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000R
ooooo`03o`000?oooooooooo0;Gooooo00Go0000ool00?oo003oo`00o`000002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0]Oooool0
0ol0003oo`00ool00002ool00003o`000?oo003o000000Goo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool0
02;ooooo00?o0000ooooooooool0]Oooool8o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;o
oooo00?o0000ooooooooool0^oooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo
0_l0002mooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o
0000ooooooooool0_?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000R
ooooo`03o`000?oooooooooo0;cooooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Roooo
o`03o`000?oooooooooo0;cooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15oooo
o`008_ooool00ol0003oooooooooo`2looooo`04o`000?oo003oo`00o`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0AOooool002;ooooo00?o0000ooooooooool0_?ooool01?l0003oo`00ool00?l00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0;cooooo00Oo0000ool00?oo
003oo`00o`000?oo003o000000Goo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0;cooooo1ol00005ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15oooo
o`008_ooool00ol0003oooooooooo`31ooooo`;o00001Ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0
`_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`15ooooo`008_ooool2o`000<?ooooo0_l00004ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool0
0ol0003oooooooooo`32ooooo`Oo00001_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo04Gooooo000Rooooo`03o`000?oooooooooo0<Cooooo00Go0000ooooooooooooooooo`000006
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000oooo
ooooool0aOooool01?l0003oooooooooool00006ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0AOooool002;ooooo00?o0000ooooooooool0a_ooool00ol0003oooooo`000006ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000oooooooo
ool0a_ooool00ol0003oooooo`000006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0AOooool002;ooooo00?o0000ooooooooool0aoooool2o`0000Koo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`38ooooo`03o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool0
0ol0003oooooooooo`38ooooo`So00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool2o`00
0<[ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
04Gooooo000Rooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0<[ooooo
00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo
000Rooooo`03o`000?oooooooooo0<_ooooo00Go0000ooooooooooooooooo`000005ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0<cooooo00Co0000oooooooooooo0000
1Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3<ooooo`04o`000?oo
ooooooooo`0000Goo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0cOoo
ool00ol0003oooooo`000005ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0007ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo0<kooooo2?l00006ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`001oooool01OmEEEGoMgMg
oooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0AOooool000Oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
coooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0007ooooo`05o`000?nH
V9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000d?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
04Gooooo0007ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0=7ooooo00Go
0000ooooooooooooooooo`000006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`15ooooo`001oooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool0dOooool01Ol0003ooooooooooooooooo000000Koo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0007ooooo`03omgMgOl@413oV9RH00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3Booooo`04o`000?ooooooooooo`0000Koo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0008ooooo`04olc<c?m4A4Co
0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3Cooooo`03o`000?oooooo000000Koo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`00
0?oooooooooo0=Cooooo0_l00006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3Dooooo`;o00001_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOoo
ool002;ooooo00?o0000ooooooooool0eOooool00ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0
003oooooooooo`3Eooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`;o0000e_ooool2o`0000Go
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Go
oooo000Rooooo`03o`000?oooooooooo0=Gooooo00?o0000ool00?l000001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o
0000ooooooooool0eOooool00ol0003oo`00o`000004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3E
ooooo`04o`000?oo003oo`00o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0=Gooooo00Co0000
ool00?oo003o00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0eOooool01Ol0003oo`00ool00?oo
003o000000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo04Gooooo000Rooooo`03o`000?oooooooooo0=Gooooo00Go0000ool00?oo003oo`00o`00
0002ool000Oo00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3E
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?l000001Oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0=Gooooo00?o0000ool0
0?oo00000ooo0002o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15oooo
o`008_ooool00ol0003oooooooooo`3Eooooo`03o`000?oo003oo`0000?oo`000_l00005ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo0_l0003Fooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0=Gooooo00?o0000ool00?oo00001?oo
00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOoo
ool002;ooooo00?o0000ooooooooool0eOooool00ol0003oo`00ool00004ool000;o00001?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo
0=Gooooo00?o0000ool00?oo00001?oo00000ol0003oooooo`000003ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0eOooool00ol0003o
o`00ool00004ool00003o`000?oooooo000000?ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3Eooooo`03o`000?oo003oo`0000Coo`00
00Co0000oooooooooooo00000_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Go
oooo000Rooooo`03o`000?oooooooooo0=Gooooo2?l00002ooooo`04o`000?ooooooooooo`0000Go
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0h?ooool00ol0003ooooo
o`000005ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0>7ooooo0_l0
0005ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Gooooo000Rooooo`;o0000h_ooool2o`0000Goo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0AOooool002;ooooo00?o0000ooooooooool0h_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0>;ooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3Rooooo`;o0000
1?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3Rooooo`Oo00001_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOoo
ool002;ooooo00?o0000ooooooooool0i?ooool01Ol0003ooooooooooooooooo000000Koo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000R
ooooo`03o`000?oooooooooo0>Gooooo00Co0000oooooooooooo00001_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000
ooooooooool0iOooool01?l0003oooooooooool00006ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`001oooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3Vooooo`03o`000?oooooo000000Koo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0007ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooool000001ol00005
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool000Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Kooooo0ol0003Wooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo0007ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool01Oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool000Oo
oooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0j?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`15ooooo`001oooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3Yooooo`03
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo04Gooooo0007ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo0>Wooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0AOooool000Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0j_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003ooooooooo
o`3Zooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0>_ooooo00Go0000
ooooooooooooooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOoo
ool002;ooooo00?o0000ooooooooool0joooool01Ol0003ooooooooooooooooo000000Goo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3/
ooooo`04o`000?ooooooooooo`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`15ooooo`008_ooool2o`000>gooooo00Co0000oooooooooooo00001Ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0>gooooo00?o0000
ooooool000001Ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Gooooo000Roooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooool000001Ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0>kooooo0_l00005ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0
k_ooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_oo
ool00ol0003oooooooooo`3_ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3_ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0
003oooooooooo`3_ooooo`;o00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
04Gooooo000Rooooo`03o`000?oooooooooo0>oooooo00?o0000ool00?l000000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo04Gooooo000Rooooo`;o0000l?ooool00ol0003oo`00
o`000003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o
0000ooooooooool0koooool01?l0003oo`00ool00?l00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0koooool01?l0003oo`00ool0
0?l00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool002;ooooo00?o
0000ooooooooool0koooool01ol0003oo`00ool00?oo003o0000ool00?l000001Ooo00000ol0003o
ooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3_ooooo`07o`000?oo003oo`00ool00?l0
003oo`00o`000005ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo0>oo
oooo00?o0000ool00?oo00000_oo0002o`0000Goo`0000?o0000ooooooooool0AOooool002;ooooo
00?o0000ooooooooool0koooool00ol0003oo`00ool00002ool000;o00001Ooo00000ol0003ooooo
ooooo`15ooooo`008_ooool00ol0003oooooooooo`3_ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3_
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15
ooooo`008_ooool00ol0003oooooooooo`3_ooooo`So00001?oo00000ol0003oooooooooo`15oooo
o`008_ooool2o`000?Kooooo0_l00004ool00003o`000?oooooooooo04Gooooo000Rooooo`03o`00
0?oooooooooo0?Gooooo00?o0000ool00?l000000ooo00000ol0003oooooooooo`15ooooo`008_oo
ool00ol0003oooooooooo`3eooooo`03o`000?oo003o000000?oo`0000?o0000ooooooooool0AOoo
ool002;ooooo00?o0000ooooooooool0mOooool01?l0003oo`00ool00?l00002ool00003o`000?oo
oooooooo04Gooooo000Rooooo`03o`000?oooooooooo0?Gooooo00Co0000ool00?oo003o00000_oo
00000ol0003oooooooooo`15ooooo`008_ooool00ol0003oooooooooo`3eooooo`07o`000?oo003o
o`00ool00?l0003oo`00o`000017ooooo`008_ooool00ol0003oooooooooo`3eooooo`07o`000?oo
003oo`00ool00?l0003oo`00o`000017ooooo`001?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?Gooooo00?o0000ool00?oo00000_oo0002o`0004Oooooo
0002ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0mOooool00ol0003oo`00ool00002ool000;o0000Aoooool000;ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?Gooooo1ol00017ooooo`000_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oo
ooooA?ooool000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`3oooooodCooooo0002ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooom4ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooA?ooool00003
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0oooo
oom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.53464, -104.052, \
0.0196194, 6.53567}}]
}, Open  ]],

Cell[TextData[{
  "The correct quadratic distribution is properly reproduced over the \
required range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < 3\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rejection Method", "Section",
  CellTags->{"i:53", "c:19"}],

Cell[TextData[{
  "The transformation method is only useful if it is easy to find the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  ". This is not always the case. Another method can often be applied in such \
situations: the ",
  StyleBox["rejection",
    FontSlant->"Italic"],
  " method. In this method, we distribute particles in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " according to some distribution ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  " by using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\ \)\(two\)\),
          FontSlant->"Italic"], TraditionalForm]]],
  " uniformly distributed random numbers. "
}], "Text"],

Cell[TextData[{
  "\tThe method is depicted in Fig. ",
  ButtonBox["8.5",
    ButtonData:>"Fig. 8.5",
    ButtonStyle->"Hyperlink"],
  ". Around the function ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  " we draw a curve ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ". This curve is arbitrary, but must contain ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  " is nonzero only on the range ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " must also be nonzero over this range, and must be greater than or equal \
to ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  ".   Typically ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is just chosen to be a constant that is greater than or equal to the \
maximum of ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  ", and that is what we will do here: ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ 
        f\_o \[GreaterEqual] \ max\ \(\[Omega](x)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe will now use our uniform random number generator to distribute \
particles ",
  StyleBox["uniformly",
    FontSlant->"Italic"],
  " below the line ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = f\_o\)]],
  ". That is, we choose one  random number ",
  Cell[BoxData[
      \(TraditionalForm\`s\_x\)]],
  "  in the range ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  ", and a second random number ",
  Cell[BoxData[
      \(TraditionalForm\`s\_y\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < f\_o\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(sx[]\  := \ Random[Real, {a, b}];\)\), "\n", 
    \(\(sy[]\  := \ Random[Real, {0, f0}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.13"],

Cell[TextData[{
  "Now, notice that the nunber of points ",
  Cell[BoxData[
      \(TraditionalForm\`\((s\_x, \ s\_y)\)\)]],
  " that fall below the curve ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`x\ to\ x + \[DifferentialD]x\)]],
  ", is simply proportional to the area  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\ \ \(w(x)\)\)]],
  ". Therefore, if we keep only those points that fall below the curve ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  " and reject the rest, the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-position of the points will be distributed according to  ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  ": the number of values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " falling in the range ",
  Cell[BoxData[
      \(TraditionalForm\`x\ to\ x + \[DifferentialD]x\)]],
  " is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\(w(x)\)\ \[DifferentialD]x\)]],
  ".   The program for the rejection method is given below:"
}], "Text"],

Cell[BoxData[
    \(s[]\  := \((xx = sx[]; \ \ While[sy[]\  > \ w[xx], \ \ xx = sx[]]; 
        xx)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.14"],

Cell[TextData[{
  "The ",
  StyleBox["While",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement repeatedly executes the test ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(sy[]\), " ", ">", " ", 
          RowBox[{
            StyleBox["w",
              FontSlant->"Plain"], "[", "xx", "]"}]}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and the command ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(xx = sx[]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  "  until the test is not true.  This allows us to reject points above the \
curve ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  " until a point falls below the curve, when it is accepted. The ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " position of this point is the desired random number. "
}], "Text",
  CellTags->"i:63"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59978 
%%ImageSize: 917 550 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00103858 0.0142805 0.00103858 [
[ 0 0 0 0 ]
[ 1 .59978 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .59978 L
0 .59978 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01428 translate
.95238 .57122 scale
2751 string
917 550 8 [917 0 0 550 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9000000000000C9C9C9C9C9C9
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9
C9C9C9C9C9C9C9C9C9C9C9C9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{267.938, 160.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005>0000b2000`400?l00000o`00003ooooooom?
ooooo`00oooooom?ooooo`00oooooom?ooooo`00oooooom?ooooo`00oooooom?ooooo`002?oooooo
0?oooch0oooo2Oooool000Soooooo`3oooln0?ooo`Wooooo0008ooooool0oooo?P3oool9ooooo`00
2?oooooo0?oooch0oooo2Oooool000Soooooo`3oooln0?ooo`Wooooo0008ooooool0oooo3`3oool0
1@2ZZZX0>CTi0:ZZZP2ZZZX0SXj>02X0oooo2Oooool000Soooooo`3oool?0?ooo`80EEEE0P3oool0
0`2ZZZX0:b/[0>?Sh`0X0?ooo`Wooooo0008ooooool0oooo3`3oool00`2ZZZX000000?ooo`020?oo
o`030820P00L71`0oooo02L0oooo2Oooool000Sooooo7@3oool01`3Shn<0EEEE08j>SP3oool0hn?S
05EEE@36a/H0j`3oool00`000000ZZZZ0?ooo`020?ooo`0303Ti>@1aLG40oooo02H0oooo2Oooool0
00Sooooo7@3oool0200L71`0SXj>0?ooo`2ZZZX0SXj>0000003Shn<0a/K6jP3oool203Ti>@<0oooo
00<0SXj>01`L703oool09P3oool9ooooo`002?oooolM0?ooo`080000002ZZZX0oooo0?ooo`2>SXh0
00000:ZZZP3Shn>40?ooo`0701`L701EEED0oooo0?ooo`36a/H000000<K6aP0;0?ooo`030<K6aP00
0000ZZZZ0080oooo00<0LG5a03Ti>@3Shn<01P3oool00`1EEED0oooo0?ooo`040?ooo`0605EEE@0[
:b/0LG5a0>?Sh`1aLG40>CTi0P36a/H01`000000ZZZZ0?ooo`3oool0LG5a03Ti>@3Shn<0<03oool0
0`2>SXh000000<K6aP020?ooo`030:ZZZP000000oooo02H0oooo2Oooool000Sooooo7@3oool01`0L
71`0LG5a0?ooo`3oool0hn?S0000002>SXh0Q@3oool02036a/H0oooo08j>SP3oool0SXj>03Ti>@36
a/H0hn?S2`3oool30<K6aP040?ooo`0i>CT0SXj>0:ZZZPH0oooo00<0EEEE0?ooo`3oool00`3oool0
202ZZZX000000=GEe@3oool0a/K603Ti>@1EEED0hn?S1036a/H0103oool0>CTi08j>SP2ZZZX`0?oo
o`070<K6aP000000ZZZZ0<K6aP3oool0EEEE03Ti>@0W0?ooo`Wooooo0008oooooad0oooo0P1EEED3
0?ooo`80EEEEQ`3oool0102ZZZX0`<3005EEE@1EEED?0?ooo`040820P03oool000000:ZZZPL0oooo
00<0EEEE0?ooo`3oool00`3oool00`2ZZZX000000?ooo`020?ooo`0305EEE@000000oooo00<0oooo
00@0P8200?ooo`000000ZZZZ<P3oool00`000000ZZZZ0:ZZZP02000000030=GEe@3oool0oooo02D0
oooo2Oooool000Sooooo7@3oool00`3Shn<000000>?Sh`020?ooo`0308j>SP000000oooo08L0oooo
00<0P82003Ti>@2>SXh03`3oool0103Shn<0P8200000003Shn<70?ooo`0305EEE@3oool0oooo00<0
oooo00<0a/K60000002ZZZX00P3oool00`36a/H000000<K6aP030?ooo`040>?Sh`20P80000000>?S
hc80oooo00<0>CTi075aL@3oool0:P3oool9ooooo`002?oooolN0?ooo`0708j>SP1EEED0oooo0?oo
o`2ZZZX000000<K6aP280?ooo`030000002ZZZX0oooo00l0oooo00<0P8200000003oool00`3oool4
05EEE@0501`L701EEED0EEEE05EEE@36a/H00P3oool00`0i>CT0:b/[0?ooo`020?ooo`0301`L702>
SXh0oooo00<0oooo00<0P8200000003oool0<P3oool00`2>SXh071`L0?ooo`0Z0?ooo`Wooooo0008
oooooal0oooo00H0LG5a0820P03Shn<0SXj>01`L702>SXj70?ooo`030:ZZZP000000SXj>0100oooo
00<0:b/[0000003Shn<01`3oool00`1EEED0oooo0?ooo`040?ooo`030<K6aP000000a/K60080oooo
0P1EEED40?ooo`0302/[:`000000hn?S0380oooo00<0ZZZZ0000003Shn<0:P3oool9ooooo`002?oo
oolQ0?ooo`040:ZZZP36a/H0a/K60<K6aXL0oooo00D0P8200000002>SXh0hn?S0:ZZZP0>0?ooo`05
0000001EEED0LG5a0>?Sh`36a/H01@3oool00`1EEED0oooo0?ooo`050?ooo`060=GEe@0i>CT0hn?S
0?ooo`1EEED00000103oool01@000000EEEE075aL@3Shn<0a/K602l0oooo00@0hn?S0:ZZZP1aLG40
a/K6:P3oool9ooooo`002?oooonZ0?ooo`070>?Sh`2ZZZX00000075aL@3oool0EEEE01`L700<0?oo
o`070<K6aP1aLG4000000<K6aP3Shn<071`L075aL@050?ooo`0305EEE@3oool0oooo00H0oooo00h0
hn?S05EEE@2ZZZX0SXj>00000036a/H0oooo0<K6aP1aLG4000000<K6aP3Shn<071`L075aLDd0oooo
00D071`L0000001EEED0LG5a0<K6aP0;0?ooo`Wooooo0008ooooolT0oooo00<0a/K60?ooo`3oool0
2P3oool00`0i>CT0LG5a0?ooo`1C0?ooo`030<K6aP000000000000<0000000<0>CTi08j>SP3oool0
203oool9ooooo`002?oooooF0?ooo`03075aL@0i>CT0oooo05<0oooo00<0ZZZZ0000000000001P00
00000`1aLG40a/K60?ooo`050?ooo`Wooooo0008ooooomH0oooo00<0ZZZZ0000003oool0D`3oool0
0`1EEED00000000000080000000305EEE@30`<00oooo00<0oooo2Oooool000Soooooe@3oool0103S
hn<0SXj>0000002ZZZYC0?ooo`0305EEE@000000000000X0000000@0>CTi075aL@36a/H0oooo2Ooo
ool000Sooooo103oool00`20P80000000000003o000003H0000000<0EEEEooooooooool01oooool0
00Sooooo103oool00`3EeMD00000075aL@0G0:ZZZP030000001IFET0QXJ600D0QXJ61@0000000`0F
5QH0FEUI08J6QP2008J6QP030000001IFET0QXJ600l0QXJ600<0000005UIF@26QXH0<P26QXH0101I
FET0;Bd]0000000];BdG08J6QP03071`L01EEED0ZZZZ01T0ZZZZ00<0>CTi0000000000002P000000
100L71`0LG5a0<K6aP3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<00000
08J6QP39bLT02039bLT01P2XZ:P0L71`01HF5P000000;Bd]09bLW7l0bLW900<0000008J6QP39bLT0
3`39bLT00`000000QXJ60<W9b@0`0<W9b@0609bLW000000000000000000R8R80@d=35`39bLT00`26
QXH000000?ooo`0I0?ooo`0305EEE@000000000000L0000000<0>CTi08j>SP3EeMD0103oool9oooo
o`002?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT02`39bLT01@2LW9`0
FEUI0000000];Bd0W9bL07d0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0^0<W9
b@05071`L00F5QH0000005UIF@26QXH06P39bLT00`26QXH000000?ooo`0I0?ooo`030:ZZZP000000
000000@0000000<071`L075aL@36a/H01`3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo
01H0oooo00<0000008J6QP39bLT03@39bLT01@2c/k<0FEUI00000013@d<0/k>c07/0bLW900<00000
08J6QP39bLT03`39bLT00`000000QXJ60<W9b@0/0<W9b@05071`L0000000000005UIF@2c/k<07039
bLT00`26QXH000000?ooo`0I0?ooo`070>?Sh`00000000000000000L71`0LG5a0<K6aP0:0?ooo`Wo
oooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0?0<W9b@0509bL
W00F5QH0000006EUI@2c/k<0N@39bLT00`000000QXJ60<W9b@0?0<W9b@0300000026QXH0bLW902X0
bLW900D0QXJ601HF5P000000FEUI0;>c/`0N0<W9b@0308J6QP000000oooo01X0oooo0P2>SXh00`3E
eMD0oooo0?ooo`0;0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000
QXJ60<W9b@0A0<W9b@0405UIF@000000000005UIFGP0bLW900<0000008J6QP39bLT03`39bLT00`00
0000QXJ60<W9b@0X0<W9b@050;>c/`0];Bd0000002d];@2c/k<08039bLT00`26QXH000000?ooo`0Z
0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0B0<W9
b@0409NGU`000000000006EUIGL0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0W
0<W9b@040:RXZ00000008R8R09NGUb80bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool5
0?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT04`39bLT0102c/k<05QHF00000013
@d=f0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT09P39bLT0101`L700000004=3
@`2c/k<S0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?oo
o`0F0?ooo`0300000026QXH0bLW901@0bLW900@0/k>c04=3@`000000@d=3M@39bLT00`000000QXJ6
0<W9b@0?0<W9b@0300000026QXH0bLW902@0bLW900@0/k>c02d];@000000L71`9@39bLT00`26QXH0
00000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ6
0<W9b@0F0<W9b@0304=3@`000000@d=307@0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ6
0<W9b@0S0<W9b@040;>c/`0F5QH05QHF0;>c/bH0bLW900<0QXJ60000003oool0:P3oool9ooooo`00
2?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT05`39bLT00`1IFET00000
04=3@`1c0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT08P39bLT01026QXH05QHF
01HF5P2c/k<W0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ
0?ooo`0F0?ooo`0300000026QXH0bLW901P0bLW900<0QXJ600000013@d<0LP39bLT00`000000QXJ6
0<W9b@0?0<W9b@0300000026QXH0bLW90240bLW900@0IFEU00000013@d<0/k>c:039bLT00`26QXH0
00000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ6
0<W9b@0I0<W9b@0408J6QP0000008R8R0;>c/g00bLW900<0000008J6QP39bLT03`39bLT00`000000
QXJ60<W9b@0P0<W9b@0304=3@`000000@d=302X0bLW900<0QXJ60000003oool0:P3oool9ooooo`00
2?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT06P39bLT01026QXH00000
01HF5P2c/k=_0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT07P39bLT0102c/k<0
;Bd]0000001UIFD[0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000
ZZZZ0?ooo`0F0?ooo`0300000026QXH0bLW901/0bLW900<0UiNG0000000R8R80K`39bLT00`000000
QXJ60<W9b@0?0<W9b@0300000026QXH0bLW901h0bLW900<08R8R00000026QXH0;039bLT00`26QXH0
00000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ6
0<W9b@0L0<W9b@0308J6QP000000@d=306h0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ6
0<W9b@0M0<W9b@0304=3@`000000QXJ602d0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?oo
ool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT07@39bLT00`1`L700000008J6
QP1]0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT07039bLT00`13@d<0000008J6
QP0^0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0F
0?ooo`0300000026QXH0bLW901h0bLW900<0@d=300000026QXH0K039bLT00`000000QXJ60<W9b@0?
0<W9b@0300000026QXH0bLW901/0bLW900<0@d=300000026QXH0;`39bLT00`26QXH000000?ooo`0Z
0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0O0<W9
b@0302d];@0F5QH0/k>c06/0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0J0<W9
b@03071`L0000000QXJ60300bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`03
0000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT07`39bLT00`2c/k<05QHF01HF5P1[0<W9b@03
00000026QXH0bLW900l0bLW900<0000008J6QP39bLT06@39bLT00`26QXH0000005UIF@0a0<W9b@03
08J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0F0?ooo`030000
0026QXH0bLW90200bLW900<0W9bL00000013@d<0JP39bLT00`000000QXJ60<W9b@0?0<W9b@030000
0026QXH0bLW901P0bLW900<0IFEU00000013@d<0<P39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo
0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0Q0<W9b@03071`L000
0000QXJ606T0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0G0<W9b@0304=3@`00
0000@d=303<0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0
oooo01H0oooo00<0000008J6QP39bLT08P39bLT00`0R8R8000000<W9b@1X0<W9b@0300000026QXH0
bLW900l0bLW900<0000008J6QP39bLT05P39bLT00`1UIFD0000003<c<`0d0<W9b@0308J6QP000000
oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0F0?ooo`0300000026QXH0bLW9
0280bLW900@0W9bL0000000R8R80/k>cI`39bLT00`000000QXJ60<W9b@0?0<W9b@0300000026QXH0
bLW901D0bLW900<0/k>c00000013@d<0=@39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008oooo
o`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0S0<W9b@0308J6QP000000@d=3
06L0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0E0<W9b@805QHF=P39bLT00`26
QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000
QXJ60<W9b@0T0<W9b@0306EUI@000000L71`06H0bLW900<0000008J6QP39bLT03`39bLT00`000000
QXJ60<W9b@0D0<W9b@0304=3@`0F5QH0/k>c03H0bLW900<0QXJ60000003oool0:P3oool9ooooo`00
2?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT09@39bLT00`1IFET00000
09bLW01U0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT04`39bLT00`1`L7000000
09bLW00g0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?oo
o`0F0?ooo`0300000026QXH0bLW902H0bLW900<0;Bd]01HF5P2c/k<0I039bLT00`000000QXJ60<W9
b@0?0<W9b@0300000026QXH0bLW90180bLW900<0W9bL00000026QXH0>039bLT00`26QXH000000?oo
o`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0V
0<W9b@030;>c/`0F5QH0@d=306@0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0A
0<W9b@030;>c/`0F5QH0@d=303T0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?oo
o`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT09`39bLT00`26QXH0000008J6QP1S0<W9
b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT04@39bLT00`0];Bd0@d=30<W9b@0i0<W9
b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0F0?ooo`03
00000026QXH0bLW902P0bLW900<08R8R00000039bLT0HP39bLT00`000000QXJ60<W9b@0?0<W9b@03
00000026QXH0bLW90100bLW900<0IFEU0000002XZ:P0>P39bLT00`26QXH000000?ooo`0Z0?ooo`Wo
oooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0X0<W9b@0309bL
W0000000FEUI0680bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@0?0<W9b@030;>c
/`0F5QH0L71`03/0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002Z
ZZX0oooo01H0oooo00<0000008J6QP39bLT0:@39bLT00`1IFET0000009bLW01Q0<W9b@0300000026
QXH0bLW900l0bLW900<0000008J6QP39bLT03`39bLT202d];C`0bLW900<0QXJ60000003oool0:P3o
ool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0:P39bLT0
0`0];Bd05QHF0<W9b@1P0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT03P39bLT0
0`0R8R805QHF0;>c/`0l0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`00
0000ZZZZ0?ooo`0F0?ooo`0300000026QXH0bLW902X0bLW900<0/k>c0000001IFET0H039bLT00`00
0000QXJ60<W9b@0?0<W9b@0300000026QXH0bLW900d0bLW900<0FEUI00000026QXH0?@39bLT00`26
QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000
QXJ60<W9b@0[0<W9b@03071`L0000000QXJ605l0bLW900<0000008J6QP39bLT03`39bLT00`000000
QXJ60<W9b@0<0<W9b@0308J6QP000000IFEU03h0bLW900<0QXJ60000003oool0:P3oool9ooooo`00
2?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0;039bLT00`0];Bd05QHF
0:RXZ01N0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT02`39bLT00`2c/k<05QHF
04=3@`0o0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?oo
o`0F0?ooo`0300000026QXH0bLW902`0bLW900@0/k>c0000000R8R80/k>cG@39bLT00`000000QXJ6
0<W9b@0?0<W9b@0300000026QXH0bLW900/0bLW900<0;Bd]01HF5P2c/k<0?`39bLT00`26QXH00000
0?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9
b@0]0<W9b@03071`L0000000@d=305d0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9
b@0:0<W9b@0302d];@000000W9bL0400bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool5
0?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0;P39bLT2000000030:RXZ039bLT0
bLW905X0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@090<W9b@0308J6QP000000
@d=30440bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo
01H0oooo00<0000008J6QP39bLT0;P39bLT00`2XZ:P0000004=3@`1L0<W9b@0300000026QXH0bLW9
00l0bLW900<0000008J6QP39bLT02@39bLT201HF5P030;>c/`39bLT0bLW903l0bLW900<0QXJ60000
003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39
bLT0;`39bLT00`1`L700000008J6QP1K0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39
bLT02039bLT00`1IFET0000008J6QP120<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo
1@3oool00`000000ZZZZ0?ooo`0F0?ooo`0300000026QXH0bLW90300bLW90P0F5QH00`2c/k<0bLW9
0<W9b@1H0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT01`39bLT00`2LW9`00000
05UIF@130<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?oo
o`0F0?ooo`0300000026QXH0bLW90300bLW900<0W9bL0000001IFET0FP39bLT00`000000QXJ60<W9
b@0?0<W9b@0300000026QXH0bLW900L0bLW900<05QHF02d];@39bLT0@`39bLT00`26QXH000000?oo
o`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0a
0<W9b@0304=3@`000000W9bL05T0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@06
0<W9b@0305UIF@0F5QH0/k>c04@0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?oo
o`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0<@39bLT00`2c/k<0000001HF5P1I0<W9
b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT01@39bLT00`26QXH0000008J6QP150<W9
b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0F0?ooo`03
00000026QXH0bLW90380bLW900<0L71`0000001`L700F039bLT00`000000QXJ60<W9b@0?0<W9b@03
00000026QXH0bLW900@0bLW900<0QXJ60000001IFET0AP39bLT00`26QXH000000?ooo`0Z0?ooo`Wo
oooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0c0<W9b@03028R
8P000000bLW905L0bLW900<0000008J6QP39bLT03`39bLT00`000000QXJ60<W9b@040<W9b@800000
A`39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3o
ool00`000000QXJ60<W9b@0c0<W9b@03071`L0000000FEUI05L0bLW900<0000008J6QP39bLT03`39
bLT00`000000QXJ60<W9b@030<W9b@0304=3@`0F5QH0Z:RX04L0bLW900<0QXJ60000003oool0:P3o
ool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0=039bLT0
0`0];Bd000000;>c/`1F0<W9b@0300000026QXH0bLW900l0bLW900<0000008J6QP39bLT00P39bLT0
0`26QXH0000008J6QP180<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`00
0000ZZZZ0?ooo`0F0?ooo`0300000026QXH0bLW903@0bLW900<0W9bL00000013@d<0EP39bLT00`00
0000QXJ60<W9b@0?0<W9b@0700000026QXH0bLW90<W9b@2c/k<0000004=3@`190<W9b@0308J6QP00
0000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0F0?ooo`0300000026QXH0
bLW903D0bLW900<0FEUI00000026QXH0E@39bLT00`000000QXJ60<W9b@0?0<W9b@0600000026QXH0
bLW90<W9b@0];Bd05QHFBP39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<0
00000:ZZZP3oool05P3oool00`000000QXJ60<W9b@0f0<W9b@0301HF5P000000/k>c05@0bLW900<0
000008J6QP39bLT03`39bLT01P000000QXJ60<W9b@1`L700000009bLW4X0bLW900<0QXJ60000003o
ool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0
=P39bLT00`26QXH0000004=3@`1D0<W9b@0300000026QXH0bLW900l0bLW900D0000008J6QP39bLT0
5QHF05UIF@1;0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ
0?ooo`0F0?ooo`0300000026QXH0bLW903L0bLW900<0@d=30000002LW9`0D`39bLT00`000000QXJ6
0<W9b@0?0<W9b@0400000026QXH0FEUI01HF5T`0bLW900<0QXJ60000003oool0:P3oool9ooooo`00
2?ooool50?ooo`030000002ZZZX0oooo01H0oooo00<0000008J6QP39bLT0>039bLT00`0R8R80@d=3
0<W9b@1B0<W9b@0300000026QXH0bLW900l0bLW900@0000008J6QP000000IFEUC039bLT00`26QXH0
00000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool05P3oool00`0L71`0L71`
0<W9b@0h0<W9b@03071`L0000000W9bL0580bLW900<0000008J6QP39bLT03`39bLT00`0000005QHF
01HF5P1=0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?oo
o`0F0?ooo`0305EEE@000000IFEU03T0bLW90P0];BeB0<W9b@0300000026QXH0bLW900l0bLW90P00
00000`1`L700bLW90<W9b@1;0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool0
0`000000ZZZZ0?ooo`0G0?ooo`0305EEE@000000L71`03P0bLW900<0/k>c0000002LW9`0D@39bLT0
0`000000QXJ60<W9b@0?0<W9b@0302d];@0F5QH0bLW904d0bLW900<0QXJ60000003oool0:P3oool9
ooooo`002?ooool50?ooo`030000002ZZZX0oooo01P0oooo00<0:b/[00000026QXH0>039bLT00`1I
FET05QHF0<W9b@1@0<W9b@0300000026QXH0bLW900h0bLW900<0@d=30000002LW9`0CP39bLT00`26
QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool06@3oool00`1EEED0
000008J6QP0h0<W9b@0301HF5P1`L700bLW904l0bLW900<0000008J6QP39bLT03@39bLT00`2LW9`0
000004=3@`1?0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ
0?ooo`0J0?ooo`0305EEE@000000QXJ603L0bLW900<0L71`0000002c/k<0C`39bLT00`000000QXJ6
0<W9b@0=0<W9b@0302d];@000000/k>c04l0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?oo
ool50?ooo`030000002ZZZX0oooo01/0oooo00<0EEEE0000002c/k<0=`39bLT202d];Dl0bLW900<0
000008J6QP39bLT03039bLT00`26QXH000000:RXZ01@0<W9b@0308J6QP000000oooo02X0oooo2Ooo
ool000Sooooo1@3oool00`000000ZZZZ0?ooo`0L0?ooo`0301`L700F5QH0/k>c03H0bLW900<0W9bL
00000026QXH0CP39bLT00`000000QXJ60<W9b@0;0<W9b@030;>c/`0F5QH0L71`0540bLW900<0QXJ6
0000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo01`0oooo00<0eMGE0000
000R8R80=`39bLT2028R8Th0bLW900<0000008J6QP39bLT02`39bLT00`1UIFD000000<W9b@1A0<W9
b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0M0?ooo`03
0:ZZZP000000@d=303H0bLW900<0QXJ600000026QXH0C@39bLT00`000000QXJ60<W9b@0:0<W9b@03
0;>c/`0F5QH0FEUI0580bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000
002ZZZX0oooo01h0oooo00<0ZZZZ0000001`L700=P39bLT00`0];Bd05QHF0<W9b@1<0<W9b@030000
0026QXH0bLW900X0bLW900<0@d=301HF5P39bLT0DP39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo
0008ooooo`D0oooo00<000000:ZZZP3oool07`3oool00`1aLG40000006EUI@0e0<W9b@0309bLW000
00008R8R04`0bLW900<0000008J6QP39bLT02@39bLT00`26QXH00000071`L01C0<W9b@0308J6QP00
0000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0P0?ooo`0305EEE@000000
@d=303D0bLW900<0FEUI0000001IFET0B`39bLT00`000000QXJ60<W9b@090<W9b@0301HF5P0];Bd0
bLW905<0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo
0240oooo00<0P8200000001`L700=039bLT0102c/k<000000000002c/k=:0<W9b@0300000026QXH0
bLW900P0bLW900<0L71`0000002LW9`0E039bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008oooo
o`D0oooo00<000000:ZZZP3oool08P3oool00`1aLG40000008J6QP0d0<W9b@0308J6QP000000;Bd]
04X0bLW900<0000008J6QP39bLT01`39bLT00`2c/k<0000004=3@`1E0<W9b@0308J6QP000000oooo
02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0S0?ooo`0305EEE@000000QXJ603@0
bLW900<0FEUI0000002LW9`0B@39bLT00`000000QXJ60<W9b@070<W9b@0305UIF@000000/k>c05D0
bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo02@0oooo
00<0:b/[028R8P39bLT0<`39bLT00`2XZ:P0000004=3@`190<W9b@0300000026QXH0bLW900H0bLW9
00<0Z:RX00000013@d<0EP39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<0
00000:ZZZP3oool0903oool00`36a/H0000004=3@`0d0<W9b@0305UIF@000000/k>c04P0bLW900<0
000008J6QP39bLT01P39bLT00`1IFET000000;>c/`1F0<W9b@0308J6QP000000oooo02X0oooo2Ooo
ool000Sooooo1@3oool00`000000ZZZZ0?ooo`0U0?ooo`030:ZZZP000000FEUI03<0bLW900<0/k>c
01HF5P0];Bd05039bLT00`2c/k<0bLW90<W9b@090<W9b@030;>c/`39bLT0bLW902D0bLW900<00000
08J6QP39bLT01@39bLT00`2c/k<0000005UIF@1G0<W9b@0308J6QP000000oooo02X0oooo2Oooool0
00Sooooo1@3oool00`000000ZZZZ0?ooo`0V0?ooo`0308j>SP000000QXJ603<0bLW900<0L71`0000
002LW9`04`39bLT00`1IFET0bLW90<W9b@090<W9b@80QXJ69P39bLT00`000000QXJ60<W9b@050<W9
b@0302d];@0F5QH0/k>c05L0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`03
0000002ZZZX0oooo02L0oooo00<0EEEE0000002LW9`0<`39bLT202d];A80bLW900<0W9bL05UIF@39
bLT02`39bLT00`13@d<0QXJ60<W9b@0T0<W9b@0300000026QXH0bLW900@0bLW900<0IFEU0000001`
L700F039bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0
:03oool00`0i>CT05QHF0;>c/`0b0<W9b@0309bLW0000000L71`00L0bLW900D0/k>c0<W9b@39bLT0
bLW909bLW0050<W9b@0305UIF@26QXH0bLW90080bLW900H0W9bL0;>c/`39bLT0bLW90;>c/`2LW9`4
0<W9b@0302d];@26QXH0bLW902<0bLW900<0000008J6QP39bLT00`39bLT00`2LW9`0000002d];@1I
0<W9b@0308J6QP000000oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0X0?oo
o`030>?Sh`0L71`0;Bd]03<0bLW900<0FEUI01HF5P39bLT01P39bLT01P0];Bd0bLW90<W9b@39bLT0
00000:RXZ0@0bLW900<0;Bd]08J6QP39bLT00P39bLT01`0F5QH0FEUI0;>c/`39bLT0@d=302d];@2L
W9`00`39bLT00`1`L7005QHF0<W9b@0S0<W9b@0300000026QXH0bLW900<0bLW900<0;Bd]0000002L
W9`0F@39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0
:@3oool01036a/H00000028R8P2c/k<a0<W9b@030;>c/`0F5QH0L71`00H0bLW900L0000008J6QP39
bLT0bLW90000000R8R80QXJ600<0bLW900<0000008J6QP39bLT01039bLT01@1`L700bLW901HF5P26
QXH0W9bL00<0bLW900<0/k>c0000001`L7008`39bLT00`000000QXJ60<W9b@020<W9b@03071`L000
0000IFEU05X0bLW900<0QXJ60000003oool0:P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0
oooo02X0oooo00<0P8200000001UIFD0<P39bLT00`1UIFD08R8R0<W9b@050<W9b@0500000013@d<0
bLW90:RXZ00000000P1UIFD30<W9b@0300000026QXH0bLW900@0bLW900@0Z:RX08J6QP000000QXJ6
1@39bLT00`0R8R80@d=30<W9b@0R0<W9b@0300000026QXH0bLW90080bLW900<00000028R8P39bLT0
FP39bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0:`3o
ool00`0[:b/0000008J6QP0a0<W9b@030;>c/`0F5QH0L71`00@0bLW900T0W9bL00000026QXH0W9bL
08J6QP000000Z:RX0;>c/`1IFET00P39bLT00`000000L71`0<W9b@050<W9b@03071`L0000000bLW9
00D0bLW900<0@d=301HF5P39bLT08P39bLT01`000000QXJ60<W9b@39bLT0L71`00000026QXH0F`39
bLT00`26QXH000000?ooo`0Z0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0;03oool0
0`1EEED000000;>c/`0a0<W9b@03071`L00F5QH0/k>c00<0bLW900<0QXJ600000039bLT00P26QXH0
20000000bLW90<W9b@1`L700W9bL0<W9b@0F5QH0@d=31P39bLT00`26QXH000000<W9b@050<W9b@03
071`L0000000bLW90280bLW900H0000008J6QP39bLT0/k>c00000013@d=L0<W9b@0308J6QP000000
oooo02X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0]0?ooo`0301`L700F5QH0/k>c
0340bLW900<0;Bd]05UIF@39bLT00P39bLT01P26QXH000000<W9b@39bLT0@d=3000000<0bLW900@0
;Bd]0<W9b@13@d<05QHF1P39bLT00`13@d<05QHF08J6QP050<W9b@0308J6QP000000bLW90280bLW9
00H0000008J6QP39bLT0;Bd]0000002c/k=L0<W9b@0301HF5P1aLG40oooo02X0oooo2Oooool000So
oooo1@3oool00`000000ZZZZ0?ooo`0]0?ooo`030>?Sh`0L71`0@d=30340bLW900<0W9bL0000002X
Z:P00P39bLT01P1IFET0;Bd]0<W9b@39bLT0W9bL04=3@`80bLW900H0QXJ600000039bLT0W9bL0000
002LW9`50<W9b@0302d];@1IFET0L71`0080L71`0`39bLT00`26QXH000000<W9b@0R0<W9b@050000
0026QXH0L71`0000001`L700G039bLT00`1IFET071`L0>?Sh`0[0?ooo`Wooooo0008ooooo`D0oooo
00<000000:ZZZP3oool0;P3oool00`36a/H0000004=3@`0a0<W9b@0604=3@`000000/k>c09bLW01I
FET0L71`0`39bLT01@26QXH0bLW90<W9b@26QXH0FEUI0080bLW900<0@d=305UIF@39bLT00P39bLT0
1`2c/k<0QXJ604=3@`2c/k<0bLW905UIF@26QXH00`39bLT00`26QXH0@d=30<W9b@0R0<W9b@040000
001`L7005QHF01HF5U`0bLW900<0W9bL0000002ZZZX0;03oool9ooooo`002?ooool50?ooo`030000
002ZZZX0oooo02l0oooo00<0ZZZZ00000026QXH0<039bLT00`2c/k<0000004=3@`0=0<W9b@030;>c
/`0];Bd0/k>c00`0bLW900<0QXJ6071`L039bLT08P39bLT0100000005QHF0000002LW9aL0<W9b@03
01HF5P0i>CT0oooo02`0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0`0?ooo`03075a
L@000000W9bL0300bLW900<0Z:RX0000002LW9`03@39bLT00`2c/k<0FEUI0<W9b@0;0<W9b@0304=3
@`2c/k<0bLW90280bLW90P0000000`1IFET0bLW90<W9b@1J0<W9b@0304=3@`000000hn?S02d0oooo
2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`0a0?ooo`0305EEE@0F5QH0/k>c0300bLW900<0
FEUI02d];@39bLT03@39bLT00`2c/k<0QXJ60<W9b@0:0<W9b@03071`L039bLT0bLW90280bLW900<0
000001HF5P2c/k<0F`39bLT00`26QXH0000008j>SP0^0?ooo`Wooooo0008ooooo`D0oooo00<00000
0:ZZZP3oool0<P3oool00`0[:b/0@d=30<W9b@0_0<W9b@030:RXZ0000000QXJ603h0bLW900<0IFEU
0000001UIFD0G039bLT00`0R8R8000000?ooo`0^0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZ
ZP3oool0<P3oool00`2ZZZX0000006EUI@0`0<W9b@0305UIF@0];Bd0bLW903`0bLW900<0Z:RX01HF
5P0F5QH0G039bLT00`1`L700000008j>SP0_0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3o
ool0<`3oool00`2ZZZX0000005UIF@0_0<W9b@030;>c/`0F5QH0L71`03`0bLW900<08R8R00000026
QXH0F`39bLT00`2c/k<0000001`L700`0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0
=03oool00`20P800000008J6QP0_0<W9b@03071`L0000000/k>c03X0bLW900<0L71`00000013@d<0
G039bLT00`0F5QH000000<K6aP0`0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0=@3o
ool00`2ZZZX0000009bLW00_0<W9b@0302d];@13@d<0bLW903P0bLW900@0/k>c0000000R8R80/k>c
FP39bLT0102c/k<08R8R0000002ZZZXa0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0
=P3oool00`1EEED05QHF0;>c/`0^0<W9b@0309bLW0000000QXJ603P0bLW900<0@d=301HF5P2XZ:P0
F`39bLT00`0];Bd0000005EEE@0b0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0=`3o
ool00`1EEED05QHF0<W9b@0^0<W9b@0305UIF@0F5QH0bLW903H0bLW900<0W9bL0000002LW9`0F`39
bLT00`13@d<000000820P00c0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0=`3oool0
0`3Shn<071`L04=3@`0^0<W9b@030;>c/`000000FEUI03H0bLW900<05QHF05UIF@39bLT0FP39bLT0
0`1`L700000005EEE@0d0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0>03oool00`3E
eMD0000006EUI@0^0<W9b@0306EUI@000000Z:RX03@0bLW900<0IFEU00000039bLT0FP39bLT00`2X
Z:P0000002/[:`0e0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0>@3oool00`1EEED0
00000;>c/`0]0<W9b@030;>c/`000000FEUI03<0bLW900<0/k>c01HF5P1`L700F`39bLT00`0];Bd0
00000>?Sh`0e0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0>P3oool00`0i>CT05QHF
0;>c/`0]0<W9b@03071`L0000000QXJ60380bLW900<0@d=302d];@39bLT0FP39bLT00`13@d<00000
0:ZZZP0f0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0>P3oool00`3Shn<071`L02d]
;@0^0<W9b@0301HF5P000000L71`0300bLW900<0L71`01HF5P2c/k<0FP39bLT00`1`L70000000:ZZ
ZP0g0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0>`3oool0103Shn<00000028R8P2c
/k</0<W9b@0409bLW000000000000;>c/bh0bLW900<0/k>c00000026QXH0FP39bLT00`26QXH00000
05EEE@0h0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0?03oool0102ZZZX0000001HF
5P2c/k</0<W9b@0308J6QP000000;Bd]02h0bLW900<05QHF04=3@`39bLT0F@39bLT00`26QXH00000
05EEE@0i0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0?@3oool00`3EeMD071`L01HF
5P0]0<W9b@0305UIF@000000L71`02`0bLW900<0@d=301HF5P2c/k<0F@39bLT00`1UIFD0000005EE
E@0j0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0?P3oool00`3Shn<071`L04=3@`0]
0<W9b@0301HF5P000000/k>c02X0bLW900<0IFEU0000002LW9`0F@39bLT00`13@d<0000005EEE@0k
0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0?`3oool00`3EeMD0000006EUI@0/0<W9
b@0308J6QP000000@d=302T0bLW900<0IFEU0000001UIFD0F@39bLT00`1UIFD000000410@00l0?oo
o`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0@03oool00`2ZZZX0000008J6QP0/0<W9b@03
04=3@`000000/k>c02L0bLW900@0/k>c01HF5P0R8R80/k>cF039bLT00`26QXH0000005EEE@0m0?oo
o`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0@@3oool00`1EEED0000008J6QP0[0<W9b@03
0;>c/`0F5QH0;Bd]02L0bLW90P0F5QH00`2XZ:P0bLW90<W9b@1F0<W9b@0308J6QP000000EEEE03h0
oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`120?ooo`0305EEE@000000/k>c02/0bLW9
00<0W9bL0000001IFET09@39bLT00`13@d<000000;>c/`1H0<W9b@0308J6QP000000EEEE03l0oooo
2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`130?ooo`0305EEE@0F5QH0/k>c02/0bLW900<0
L71`00000026QXH08`39bLT00`13@d<0000008J6QP1H0<W9b@0308J6QP000000EEEE0400oooo2Ooo
ool000Sooooo1@3oool00`000000ZZZZ0?ooo`140?ooo`0305EEE@0F5QH0QXJ602/0bLW900<0@d=3
0000002c/k<08@39bLT00`26QXH0000008J6QP1H0<W9b@03071`L0000000EEEE0440oooo2Oooool0
00Sooooo1@3oool00`000000ZZZZ0?ooo`150?ooo`0305EEE@000000IFEU02/0bLW90P0F5QH00`2X
Z:P0bLW90<W9b@0M0<W9b@0308J6QP000000@d=305P0bLW900<0@d=30000001aLG40@P3oool9oooo
o`002?ooool50?ooo`030000002ZZZX0oooo04H0oooo00<0EEEE00000013@d<0:P39bLT0102c/k<0
5QHF0000002LW9`M0<W9b@0309bLW0000000@d=305L0bLW900@0QXJ6028R8P000000ZZZZ@`3oool9
ooooo`002?ooool50?ooo`030000002ZZZX0oooo04L0oooo00<0P82000000013@d<0:P39bLT0102c
/k<0000001HF5P2c/k<K0<W9b@030;>c/`0F5QH0;Bd]05L0bLW900@0L71`0000000[:b/0a/K6A03o
ool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo04P0oooo00<0P8200000000R8R80:P39bLT0
0`2GUiL00000028R8P0K0<W9b@03028R8P000000Z:RX05H0bLW900<0IFEU0000000[:b/0AP3oool9
ooooo`002?ooool50?ooo`030000002ZZZX0oooo04T0oooo00<0EEEE00000013@d<0:P39bLT00`26
QXH0000005UIF@0I0<W9b@0304=3@`000000QXJ605H0bLW900<0L71`0000001EEED0A`3oool9oooo
o`002?ooool50?ooo`030000002ZZZX0oooo04X0oooo00<0EEEE00000013@d<0:P39bLT00`1`L700
0000071`L00F0<W9b@0408J6QP0000005QHF09bLW5H0bLW900<0@d=30000001aLG40B03oool9oooo
o`002?ooool50?ooo`030000002ZZZX0oooo04/0oooo00<0EEEE00000013@d<0:P39bLT01013@d<0
000002d];@2c/k<C0<W9b@0405UIF@0000008R8R0;>c/eD0bLW900@0/k>c01HF5P000000ZZZZB@3o
ool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo04`0oooo00<0EEEE00000013@d<0:P39bLT0
102LW9`05QHF01HF5P2LW9`@0<W9b@0409bLW00F5QH0000008J6QUH0bLW900@0QXJ601HF5P0L71`0
hn?SBP3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo04d0oooo00@0EEEE0000000];Bd0
Z:RX:P39bLT0100];Bd0000004=3@`2c/k<<0<W9b@050;>c/`13@d<0000001HF5P26QXH0E@39bLT0
1@2XZ:P0@d=30000000i>CT0hn?S04/0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`1>
0?ooo`0408j>SP000000000008J6QRX0bLW900@0L71`0000000F5QH0@d=30P26QXH00`2c/k<0bLW9
0<W9b@020<W9b@80QXJ600H0@d=302d];@000000000004=3@`2c/k=E0<W9b@04071`L00000000000
08j>STd0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`1?0?ooo`040:ZZZP0[:b/00000
05UIFBX0bLW900<0/k>c071`L013@d<02@000000100];Bd0@d=308J6QP2LW9aE0<W9b@050;>c/`0]
;Bd0000005EEE@3Shn<0CP3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo0540oooo00<0
:b/[0000001UIFD0;039bLT00`26QXH0IFEU06EUI@0606EUI@030:RXZ039bLT0bLW905D0bLW900@0
Z:RX000000000000ZZZZD03oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo0540oooo00@0
hn?S05EEE@000000L71`R`39bLT00`26QXH05QHF01`L70020<K6aU00oooo2Oooool000Sooooo1@3o
ool00`000000ZZZZ0?ooo`1C0?ooo`0308j>SP000000@d=308P0bLW900@0/k>c04=3@`000000LG5a
0P3oool00`2>SXh0:b/[0?ooo`040?ooo`80a/K62P3oool00`36a/H0eMGE0?ooo`0k0?ooo`Wooooo
0008ooooo`D0oooo00<000000:ZZZP3oool0E03oool0102ZZZX071`L04=3@`2c/k>50<W9b@04071`
L00F5QH071`L0<K6aP@0oooo00<0000008j>SP3oool00`3oool00`0i>CT0oooo0?ooo`0:0?ooo`03
0820P02>SXh0oooo03X0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`1E0?ooo`040>?S
h`0L71`05QHF071`L880bLW900@0L71`028R8P0L71`0SXj>1P3oool00`1EEED071`L0?ooo`020?oo
o`030>?Sh`1EEED0oooo00`0oooo00<0EEEE0:ZZZP3oool0>@3oool9ooooo`002?ooool50?ooo`03
0000002ZZZX0oooo05L0oooo00@0EEEE0000000R8R80QXJ6OP39bLT01@1`L7005QHF01`L7020P800
hn?S00L0oooo00<0ZZZZ00000036a/H00P3oool01`2ZZZX0EEEE0?ooo`3oool0a/K60000001EEED0
0P3oool00`1aLG40>CTi0>?Sh`030?ooo`030<K6aP000000hn?S03T0oooo2Oooool000Sooooo1@3o
ool00`000000ZZZZ0?ooo`1H0?ooo`050:ZZZP0[:b/0000004=3@`2c/k<0NP39bLT0102LW9`0;Bd]
01`L702>SXh;0?ooo`0401`L702>SXh0oooo0?ooo`80EEEE0`3oool01`2ZZZX0oooo08j>SP3oool0
>CTi08j>SP2ZZZX0103oool00`0L71`0LG5a0?ooo`0h0?ooo`Wooooo0008ooooo`D0oooo00<00000
0:ZZZP3oool0FP3oool0102>SXh0000001HF5P26QXIg0<W9b@0509bLW00];Bd00000075aL@3Shn<0
303oool205EEE@80oooo0P1EEED50?ooo`80a/K600<000000:ZZZP3oool0103oool00`1aLG400000
0?ooo`0h0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0F`3oool0103EeMD000000000
001UIFEe0<W9b@0408J6QP000000:b/[0=GEe@h0oooo00@0ZZZZ0000003oool0oooo0P1EEED60?oo
o`030820P0000000oooo00D0oooo00<0ZZZZ0000003EeMD0>03oool9ooooo`002?ooool50?ooo`03
0000002ZZZX0oooo05`0oooo00D0hn?S03Ti>@000000;Bd]09bLW01`0<W9b@0509bLW013@d<08R8R
0000001aLG40403oool01P36a/H000000<K6aP3oool0EEEE000000H0oooo00<0ZZZZ0000003oool0
1@3oool00`36a/H000000:ZZZP0h0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0GP3o
ool01@2>SXh071`L0000001IFET0/k>c06`0bLW900H0QXJ602d];@00000071`L0820P03Shn<B0?oo
o`0601`L702>SXh0oooo0:ZZZP000000hn?S1@3oool00`1aLG4000000>?Sh`060?ooo`030000002Z
ZZX0oooo03L0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`1P0?ooo`05075aL@000000
5QHF06EUI@2c/k<0J039bLT01@1`L7005QHF0000000i>CT0ZZZZ01D0oooo0P1EEED0103oool0hn?S
0000002>SXh50?ooo`80EEEE00<0LG5a0>?Sh`36a/H0103oool00`000000ZZZZ0?ooo`0g0?ooo`Wo
oooo0008ooooo`D0oooo00<000000:ZZZP3oool0H@3oool01P3Shn<0>CTi000000000000FEUI0;>c
/f@0bLW900D0L71`01HF5P000000LG5a0<K6aP0F0?ooo`030<K6aP1aLG4000000080ZZZZ00<0LG5a
03Ti>@3oool00P3oool01`3Shn<0ZZZZ00000036a/H0hn?S01`L701aLG40103oool00`000000hn?S
0?ooo`0g0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0H`3oool01P3EeMD0LG5a0000
00000000FEUI0;>c/el0bLW900H0W9bL04=3@`0F5QH071`L075aL@3Shn<J0?ooo`0600000036a/H0
oooo0?ooo`0L71`0hn?S3@3oool00`0L71`0oooo0?ooo`0g0?ooo`Wooooo0008ooooo`D0oooo00<0
00000:ZZZP3oool0IP3oool01@2>SXh071`L0000001IFET0W9bL05/0bLW900D0QXJ602d];@000000
:b/[08j>SP0M0?ooo`0603Ti>@2ZZZX0oooo0?ooo`3Shn<0EEEE303oool00`36a/H0LG5a0?ooo`0h
0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0J03oool01@2>SXh071`L0000000];Bd0
QXJ605H0bLW900H0QXJ604=3@`000000>CTi075aL@3Shn<O0?ooo`070<K6aP0i>CT0a/K601`L703o
ool0hn?S0:ZZZP0;0?ooo`0308j>SP3Shn<0oooo03P0oooo2Oooool000Sooooo1@3oool00`000000
ZZZZ0?ooo`1Z0?ooo`0505EEE@000000000000000026QXH0DP39bLT01@1UIFD000000000000[:b/0
ZZZZ02<0oooo00<0ZZZZ05EEE@20P8000P3oool00`3EeMD0oooo0?ooo`090?ooo`030=GEe@3oool0
oooo03P0oooo2Oooool000Sooooo1@3oool00`000000ZZZZ0?ooo`1[0?ooo`070>?Sh`20P80071`L
0000000];Bd0L71`0;>c/`1;0<W9b@030;>c/`1`L700;Bd]0080000000<0EEEE0<K6aP3oool0L03o
ool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo06h0oooo00L0SXj>03Ti>@000000000001HF
5P1IFET0W9bL04D0bLW900<0/k>c071`L00];Bd00P0000000`1EEED0ZZZZ0?ooo`1c0?ooo`Wooooo
0008ooooo`D0oooo00<000000:ZZZP3oool0L@3oool00`2ZZZX0EEEE000000020000000304=3@`26
QXH0bLW903d0bLW90P26QXH01P13@d<05QHF000000000000>CTi0:ZZZWL0oooo2Oooool000Sooooo
1@3oool00`000000ZZZZ0?ooo`1d0?ooo`030:ZZZP20P800>CTi0080000000<0;Bd]071`L02c/k<0
=@39bLT0102LW9`0QXJ604=3@`0];Bd30000000403Ti>@1aLG40ZZZZ0>?ShgT0oooo2Oooool000So
oooo1@3oool00`000000ZZZZ0?ooo`1g0?ooo`030>?Sh`2>SXh0EEEE00<0000000D0;Bd]04=3@`1U
IFD0QXJ609bLW00Y0<W9b@050;>c/`26QXH0QXJ605UIF@13@d<00`000000100i>CT0EEEE0:ZZZP3S
hn=n0?ooo`Wooooo0008ooooo`D0oooo00<000000:ZZZP3oool0N`3oool0102ZZZX0SXj>05EEE@0i
>CT40000000501HF5P13@d<0FEUI08J6QP2LW9`07039bLT208J6QP03071`L013@d<0@d=300D00000
00@071`L05EEE@2>SXh0a/K6P`3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo0800oooo
00@0hn?S0:ZZZP1aLG40EEEE2000000404=3@`03071`L026QXH0QXJ600P0QXJ61P13@d<00`0F5QH0
0000000000040000000503Ti>@1EEED0SXj>0:ZZZP3Shn<0R03oool9ooooo`002?ooool50?ooo`03
0000002ZZZX0oooo08H0oooo00<0ZZZZ08j>SP1EEED01@1EEED00`0L71`000000000000@00000003
01`L701EEED0LG5a0080ZZZZS`3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo0?l0oooo
=P3oool9ooooo`002?ooool50?ooo`030000002ZZZX0oooo0?l0oooo=P3oool9ooooo`002?ooool5
0?ooo`030000002ZZZX0oooo0?l0oooo=P3oool9ooooo`002?ooool30?ooo`040<K6aP2ZZZX00000
075aL@80ZZZZo`3ooole0?ooo`Wooooo0008ooooo`03075aL@000000000000H0000000<071`L075a
L@3Shn<0o`3ooolb0?ooo`Wooooo0008ooooo`0305EEE@000000000000P0000000<0hn?S0?ooo`3o
ool0o`3oool`0?ooo`Wooooo0008ooooo`030:ZZZP000000000000L0000000<0EEEE0?ooo`3oool0
o`3ooola0?ooo`Wooooo0008ooooo`030?ooo`000000000000L0000000<0ZZZZ0?ooo`3oool0o`3o
oola0?ooo`Wooooo0008ooooo`030?ooo`1EEED0000000L00000o`3ooold0?ooo`Wooooo0008oooo
o`030?ooo`2>SXh0000000H0000000<0>CTi0?ooo`3oool0o`3ooolb0?ooo`Wooooo0008ooooo`03
0?ooo`3Shn<0000000H0000000<0ZZZZ0?ooo`3oool0o`3ooolb0?ooo`Wooooo0008ooooo`80oooo
00<0>CTi0000000000000`0000000`0L71`0oooo0?ooo`3o0?oooc<0oooo2Oooool000Sooooo0P3o
ool00`2>SXh000000000000300000003075aL@3oool0oooo0?l0oooo<`3oool9ooooo`002?ooool3
0?ooo`D0000000<0hn?S0?ooo`3oool0o`3ooolc0?ooo`Wooooo0008ooooo`<0oooo00D0EEEE0000
00000000000003Ti>@3o0?ooocH0oooo2Oooool000Sooooo0`3oool01@2ZZZX00000000000000000
SXj>0?l0oooo=P3oool9ooooo`002?ooool40?ooo`<00000o`3ooolg0?ooo`Wooooo0008ooooo`@0
oooo00<0EEEE0000000i>CT0o`3ooolg0?ooo`Wooooo0008ooooo`@0oooo00<0eMGE0000002>SXh0
o`3ooolg0?ooo`Wooooo0008ooooo`D0oooo00<0>CTi0<K6aP3oool0o`3ooolf0?ooo`Wooooo0008
ooooo`D0oooo00<0ZZZZ0?ooo`3oool0o`3ooolf0?ooo`Wooooo003oooooodoooooo003oooooodoo
oooo003oooooodoooooo003oooooodoooooo0000\
\>"],
  ImageRangeCache->{{{0, 333.875}, {199.812, 0}} -> {-23.9877, -13.7529, \
3.6128, 3.6128}}],

Cell[TextData[{
  "Fig. 8.5 Rejection method. Random points are distributed uniformly in the \
grey region. Points are rejected if they fall above the curve ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  "."
}], "Caption",
  CellTags->"Fig. 8.5"],

Cell[TextData[{
  "\tBelow, we show how the method can be applied to determine a random \
number distributed according to a Gaussian density",
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\  = \ \[ExponentialE]\^\(-x\^2\)/\@\[Pi]\)]],
  ".  In principle, this distribution extends to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PlusMinus]\[Infinity]\)\(,\)\)\)]],
  " but large values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " are highly unlikely, so we take ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(-10\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b = 10\)]],
  ". We should not take ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\)\(,\)\)\)]],
  "  or ",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  " to be overly large, or we waste too much time rejecting almost all of the \
points. We choose ",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  " as the maximum of  ",
  Cell[BoxData[
      \(TraditionalForm\`w(x)\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(w[x_]\  = \ Exp[\(-x^2\)]/Sqrt[Pi];\)\), "\n", 
    \(a = \(-10\); b = 10;\), "\n", 
    \(\(f0\  = \ 1/Sqrt[Pi];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.15"],

Cell[TextData[{
  "We now plot distribution arising from ",
  Cell[BoxData[
      \(TraditionalForm\`5000\)]],
  " points as a histogram  in Cell ",
  ButtonBox["8.16",
    ButtonData:>"Cell 8.16",
    ButtonStyle->"Hyperlink"],
  ". It is clearly an excellent match to a Gaussian. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Table[s[], {5000}];\)\), "\[IndentingNewLine]", 
    \(\ \(Histogram[%];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.16"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.178571 0.0147151 0.00196201 [
[.14286 .00222 -6 -9 ]
[.14286 .00222 6 0 ]
[.32143 .00222 -6 -9 ]
[.32143 .00222 6 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.67857 .00222 -3 -9 ]
[.67857 .00222 3 0 ]
[.85714 .00222 -3 -9 ]
[.85714 .00222 3 0 ]
[-0.0125 .11282 -12 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -18 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -18 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -18 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 .01472 m
.14286 .02097 L
s
[(-2)] .14286 .00222 0 1 Mshowa
.32143 .01472 m
.32143 .02097 L
s
[(-1)] .32143 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0)] .5 .00222 0 1 Mshowa
.67857 .01472 m
.67857 .02097 L
s
[(1)] .67857 .00222 0 1 Mshowa
.85714 .01472 m
.85714 .02097 L
s
[(2)] .85714 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .11282 m
.00625 .11282 L
s
[(50)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(100)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(150)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(200)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(250)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(300)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01668 L
.01786 .01668 L
.01786 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01668 L
.01786 .01668 L
.01786 .01472 L
0 .01472 L
s
1 0 0 r
.01786 .01472 m
.01786 .01472 L
.03571 .01472 L
.03571 .01472 L
F
0 g
.01786 .01472 m
.01786 .01472 L
.03571 .01472 L
.03571 .01472 L
.01786 .01472 L
s
1 0 0 r
.03571 .01472 m
.03571 .01472 L
.05357 .01472 L
.05357 .01472 L
F
0 g
.03571 .01472 m
.03571 .01472 L
.05357 .01472 L
.05357 .01472 L
.03571 .01472 L
s
1 0 0 r
.05357 .01472 m
.05357 .01668 L
.07143 .01668 L
.07143 .01472 L
F
0 g
.05357 .01472 m
.05357 .01668 L
.07143 .01668 L
.07143 .01472 L
.05357 .01472 L
s
1 0 0 r
.07143 .01472 m
.07143 .01472 L
.08929 .01472 L
.08929 .01472 L
F
0 g
.07143 .01472 m
.07143 .01472 L
.08929 .01472 L
.08929 .01472 L
.07143 .01472 L
s
1 0 0 r
.08929 .01472 m
.08929 .01864 L
.10714 .01864 L
.10714 .01472 L
F
0 g
.08929 .01472 m
.08929 .01864 L
.10714 .01864 L
.10714 .01472 L
.08929 .01472 L
s
1 0 0 r
.10714 .01472 m
.10714 .02453 L
.125 .02453 L
.125 .01472 L
F
0 g
.10714 .01472 m
.10714 .02453 L
.125 .02453 L
.125 .01472 L
.10714 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .02649 L
.14286 .02649 L
.14286 .01472 L
F
0 g
.125 .01472 m
.125 .02649 L
.14286 .02649 L
.14286 .01472 L
.125 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .02649 L
.16071 .02649 L
.16071 .01472 L
F
0 g
.14286 .01472 m
.14286 .02649 L
.16071 .02649 L
.16071 .01472 L
.14286 .01472 L
s
1 0 0 r
.16071 .01472 m
.16071 .03237 L
.17857 .03237 L
.17857 .01472 L
F
0 g
.16071 .01472 m
.16071 .03237 L
.17857 .03237 L
.17857 .01472 L
.16071 .01472 L
s
1 0 0 r
.17857 .01472 m
.17857 .03041 L
.19643 .03041 L
.19643 .01472 L
F
0 g
.17857 .01472 m
.17857 .03041 L
.19643 .03041 L
.19643 .01472 L
.17857 .01472 L
s
1 0 0 r
.19643 .01472 m
.19643 .05592 L
.21429 .05592 L
.21429 .01472 L
F
0 g
.19643 .01472 m
.19643 .05592 L
.21429 .05592 L
.21429 .01472 L
.19643 .01472 L
s
1 0 0 r
.21429 .01472 m
.21429 .05984 L
.23214 .05984 L
.23214 .01472 L
F
0 g
.21429 .01472 m
.21429 .05984 L
.23214 .05984 L
.23214 .01472 L
.21429 .01472 L
s
1 0 0 r
.23214 .01472 m
.23214 .07554 L
.25 .07554 L
.25 .01472 L
F
0 g
.23214 .01472 m
.23214 .07554 L
.25 .07554 L
.25 .01472 L
.23214 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .08731 L
.26786 .08731 L
.26786 .01472 L
F
0 g
.25 .01472 m
.25 .08731 L
.26786 .08731 L
.26786 .01472 L
.25 .01472 L
s
1 0 0 r
.26786 .01472 m
.26786 .13636 L
.28571 .13636 L
.28571 .01472 L
F
0 g
.26786 .01472 m
.26786 .13636 L
.28571 .13636 L
.28571 .01472 L
.26786 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .1756 L
.30357 .1756 L
.30357 .01472 L
F
0 g
.28571 .01472 m
.28571 .1756 L
.30357 .1756 L
.30357 .01472 L
.28571 .01472 L
s
1 0 0 r
.30357 .01472 m
.30357 .16579 L
.32143 .16579 L
.32143 .01472 L
F
0 g
.30357 .01472 m
.30357 .16579 L
.32143 .16579 L
.32143 .01472 L
.30357 .01472 L
s
1 0 0 r
.32143 .01472 m
.32143 .25212 L
.33929 .25212 L
.33929 .01472 L
F
0 g
.32143 .01472 m
.32143 .25212 L
.33929 .25212 L
.33929 .01472 L
.32143 .01472 L
s
1 0 0 r
.33929 .01472 m
.33929 .30705 L
.35714 .30705 L
.35714 .01472 L
F
0 g
.33929 .01472 m
.33929 .30705 L
.35714 .30705 L
.35714 .01472 L
.33929 .01472 L
s
1 0 0 r
.35714 .01472 m
.35714 .32079 L
.375 .32079 L
.375 .01472 L
F
0 g
.35714 .01472 m
.35714 .32079 L
.375 .32079 L
.375 .01472 L
.35714 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .36592 L
.39286 .36592 L
.39286 .01472 L
F
0 g
.375 .01472 m
.375 .36592 L
.39286 .36592 L
.39286 .01472 L
.375 .01472 L
s
1 0 0 r
.39286 .01472 m
.39286 .42478 L
.41071 .42478 L
.41071 .01472 L
F
0 g
.39286 .01472 m
.39286 .42478 L
.41071 .42478 L
.41071 .01472 L
.39286 .01472 L
s
1 0 0 r
.41071 .01472 m
.41071 .47971 L
.42857 .47971 L
.42857 .01472 L
F
0 g
.41071 .01472 m
.41071 .47971 L
.42857 .47971 L
.42857 .01472 L
.41071 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .48756 L
.44643 .48756 L
.44643 .01472 L
F
0 g
.42857 .01472 m
.42857 .48756 L
.44643 .48756 L
.44643 .01472 L
.42857 .01472 L
s
1 0 0 r
.44643 .01472 m
.44643 .48756 L
.46429 .48756 L
.46429 .01472 L
F
0 g
.44643 .01472 m
.44643 .48756 L
.46429 .48756 L
.46429 .01472 L
.44643 .01472 L
s
1 0 0 r
.46429 .01472 m
.46429 .60332 L
.48214 .60332 L
.48214 .01472 L
F
0 g
.46429 .01472 m
.46429 .60332 L
.48214 .60332 L
.48214 .01472 L
.46429 .01472 L
s
1 0 0 r
.48214 .01472 m
.48214 .57193 L
.5 .57193 L
.5 .01472 L
F
0 g
.48214 .01472 m
.48214 .57193 L
.5 .57193 L
.5 .01472 L
.48214 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .56212 L
.51786 .56212 L
.51786 .01472 L
F
0 g
.5 .01472 m
.5 .56212 L
.51786 .56212 L
.51786 .01472 L
.5 .01472 L
s
1 0 0 r
.51786 .01472 m
.51786 .60332 L
.53571 .60332 L
.53571 .01472 L
F
0 g
.51786 .01472 m
.51786 .60332 L
.53571 .60332 L
.53571 .01472 L
.51786 .01472 L
s
1 0 0 r
.53571 .01472 m
.53571 .53269 L
.55357 .53269 L
.55357 .01472 L
F
0 g
.53571 .01472 m
.53571 .53269 L
.55357 .53269 L
.55357 .01472 L
.53571 .01472 L
s
1 0 0 r
.55357 .01472 m
.55357 .53269 L
.57143 .53269 L
.57143 .01472 L
F
0 g
.55357 .01472 m
.55357 .53269 L
.57143 .53269 L
.57143 .01472 L
.55357 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .45421 L
.58929 .45421 L
.58929 .01472 L
F
0 g
.57143 .01472 m
.57143 .45421 L
.58929 .45421 L
.58929 .01472 L
.57143 .01472 L
s
1 0 0 r
.58929 .01472 m
.58929 .42478 L
.60714 .42478 L
.60714 .01472 L
F
0 g
.58929 .01472 m
.58929 .42478 L
.60714 .42478 L
.60714 .01472 L
.58929 .01472 L
s
1 0 0 r
.60714 .01472 m
.60714 .37376 L
.625 .37376 L
.625 .01472 L
F
0 g
.60714 .01472 m
.60714 .37376 L
.625 .37376 L
.625 .01472 L
.60714 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .31098 L
.64286 .31098 L
.64286 .01472 L
F
0 g
.625 .01472 m
.625 .31098 L
.64286 .31098 L
.64286 .01472 L
.625 .01472 L
s
1 0 0 r
.64286 .01472 m
.64286 .26193 L
.66071 .26193 L
.66071 .01472 L
F
0 g
.64286 .01472 m
.64286 .26193 L
.66071 .26193 L
.66071 .01472 L
.64286 .01472 L
s
1 0 0 r
.66071 .01472 m
.66071 .22661 L
.67857 .22661 L
.67857 .01472 L
F
0 g
.66071 .01472 m
.66071 .22661 L
.67857 .22661 L
.67857 .01472 L
.66071 .01472 L
s
1 0 0 r
.67857 .01472 m
.67857 .19522 L
.69643 .19522 L
.69643 .01472 L
F
0 g
.67857 .01472 m
.67857 .19522 L
.69643 .19522 L
.69643 .01472 L
.67857 .01472 L
s
1 0 0 r
.69643 .01472 m
.69643 .1756 L
.71429 .1756 L
.71429 .01472 L
F
0 g
.69643 .01472 m
.69643 .1756 L
.71429 .1756 L
.71429 .01472 L
.69643 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .13832 L
.73214 .13832 L
.73214 .01472 L
F
0 g
.71429 .01472 m
.71429 .13832 L
.73214 .13832 L
.73214 .01472 L
.71429 .01472 L
s
1 0 0 r
.73214 .01472 m
.73214 .10889 L
.75 .10889 L
.75 .01472 L
F
0 g
.73214 .01472 m
.73214 .10889 L
.75 .10889 L
.75 .01472 L
.73214 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .08535 L
.76786 .08535 L
.76786 .01472 L
F
0 g
.75 .01472 m
.75 .08535 L
.76786 .08535 L
.76786 .01472 L
.75 .01472 L
s
1 0 0 r
.76786 .01472 m
.76786 .06769 L
.78571 .06769 L
.78571 .01472 L
F
0 g
.76786 .01472 m
.76786 .06769 L
.78571 .06769 L
.78571 .01472 L
.76786 .01472 L
s
1 0 0 r
.78571 .01472 m
.78571 .04415 L
.80357 .04415 L
.80357 .01472 L
F
0 g
.78571 .01472 m
.78571 .04415 L
.80357 .04415 L
.80357 .01472 L
.78571 .01472 L
s
1 0 0 r
.80357 .01472 m
.80357 .04807 L
.82143 .04807 L
.82143 .01472 L
F
0 g
.80357 .01472 m
.80357 .04807 L
.82143 .04807 L
.82143 .01472 L
.80357 .01472 L
s
1 0 0 r
.82143 .01472 m
.82143 .02845 L
.83929 .02845 L
.83929 .01472 L
F
0 g
.82143 .01472 m
.82143 .02845 L
.83929 .02845 L
.83929 .01472 L
.82143 .01472 L
s
1 0 0 r
.83929 .01472 m
.83929 .02256 L
.85714 .02256 L
.85714 .01472 L
F
0 g
.83929 .01472 m
.83929 .02256 L
.85714 .02256 L
.85714 .01472 L
.83929 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .02256 L
.875 .02256 L
.875 .01472 L
F
0 g
.85714 .01472 m
.85714 .02256 L
.875 .02256 L
.875 .01472 L
.85714 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .02453 L
.89286 .02453 L
.89286 .01472 L
F
0 g
.875 .01472 m
.875 .02453 L
.89286 .02453 L
.89286 .01472 L
.875 .01472 L
s
1 0 0 r
.89286 .01472 m
.89286 .01472 L
.91071 .01472 L
.91071 .01472 L
F
0 g
.89286 .01472 m
.89286 .01472 L
.91071 .01472 L
.91071 .01472 L
.89286 .01472 L
s
1 0 0 r
.91071 .01472 m
.91071 .01668 L
.92857 .01668 L
.92857 .01472 L
F
0 g
.91071 .01472 m
.91071 .01668 L
.92857 .01668 L
.92857 .01472 L
.91071 .01472 L
s
1 0 0 r
.92857 .01472 m
.92857 .01668 L
.94643 .01668 L
.94643 .01472 L
F
0 g
.92857 .01472 m
.92857 .01668 L
.94643 .01668 L
.94643 .01472 L
.92857 .01472 L
s
1 0 0 r
.94643 .01472 m
.94643 .01472 L
.96429 .01472 L
.96429 .01472 L
F
0 g
.94643 .01472 m
.94643 .01472 L
.96429 .01472 L
.96429 .01472 L
.94643 .01472 L
s
1 0 0 r
.96429 .01472 m
.96429 .01668 L
.98214 .01668 L
.98214 .01472 L
F
0 g
.96429 .01472 m
.96429 .01668 L
.98214 .01668 L
.98214 .01472 L
.96429 .01472 L
s
1 0 0 r
.98214 .01472 m
.98214 .01668 L
1 .01668 L
1 .01472 L
F
0 g
.98214 .01472 m
.98214 .01668 L
1 .01668 L
1 .01472 L
.98214 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Boooool5
o`0003Oooooo1?l000000ol@413oooooooooo`0_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0>?oo
ool4o`000003oa0@4?oooooooooo03?ooooo1Ol0000_ooooo`00Boooool01OnHV9So8B4Qonk^k_oo
ooooA4A403Wooooo00?o0000ooooooooool0<Oooool01OmgMgOoV9RHoooooonHV9SoMgMg03[ooooo
00?o0000ooooooooool0=Oooool01OnHV9So8B4Qonk^k_ooooooA4A402oooooo0013ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP0_ooooo`Ko00001Oooool00ol0003oooooooooo`0aooooo`05oa0@
4?ooooooooooooooool@4100>_ooool00ol0003oooooooooo`0fooooo`03oiRHV?lQ8B7ok^k^033o
oooo001=ooooo`03oiRHV?lQ8B7ok^k^03Wooooo00?o0000ooooooooool0<Oooool01Ol0003ooooo
oooooooooooo000003[ooooo00?o0000ooooooooool0=oooool00onHV9So8B4Qonk^kP0_ooooo`00
C_ooool00omgMgOoIVIVooooo`0hooooo`03o`000?oooooooooo037ooooo00Go0000oooooooooooo
ooooo`00000jooooo`03o`000?oooooooooo03Sooooo00?oMgMgofIVI_ooool0;_ooool004oooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0aooooo`05oa0@4?ooooooooooooooool@
4100>_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo001;ooooo`05o`00
0?nj^[[ooooooiRHV?l@4100>Oooool00ol0003oooooooooo`0aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0>_ooool00ol0003oooooooooo`0eooooo`05o`000?nj^[[ooooooiRHV?l@4100;oooool0
04_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00gooooo`03oeEEEOmVIVKo000003?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000003Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00_ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[oooooool0
001?o`0000006_ooool7o`0000_ooooo1ol00005ooooo`Oo00001Ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo3Ol00005ooooo`go0000000Jooooo`03o`000?oooooooooo
027ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000go00001Ooo00000ol0
003oooooooooo`0Rooooo`006_ooool00ol0003oooooooooo`0Qooooo`Oo00001Ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`09ooooo`Oo00009?ooool001[ooooo00?o0000ooooooooool09oooool=o`0000Goo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
1ol0000fooooo`006_ooool00ol0003oooooooooo`0cooooo`03o`000?oo003oo`0000?oo`001_l0
0005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0>_ooool001[ooooo0_l0000d
ooooo`Oo00001?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0>_ooool001[ooooo00?o0000ooooooooool0?_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0>_ooool001[ooooo00?o0000oooooooo
ool0?_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0>_ooool001[ooooo00?o0000ooooooooool0?_ooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0>_ooool001[ooooo00?o0000ooooooooool0?_oo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0007o`0000Goo`0000?o0000ooooooooool0>_ooool001[ooooo00?o0000ooooooooool0?_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`03ooooo`Oo0000??ooool001[ooooo00?o0000ooooooooool0?_ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`16ooooo`006_ooool2o`0003oooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0A_ooool001[ooooo
00?o0000ooooooooool0?_ooool7o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`16ooooo`006_ooool00ol0003oooooooooo`14ooooo`Oo00001Ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`16ooooo`006_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0A_ooool001[ooooo00?o0000ooooooooool0B_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0004Sooooo000Jooooo`03
o`000?oooooooooo04[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0C?ooool001[ooooo0_l0001;ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo04cooooo000Jooooo`03o`000?oooooooooo04[ooooo1ol00005ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0C?ooool001[ooooo00?o0000ooooooooool0D?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0C?ooool0
01[ooooo00?o0000ooooooooool0D?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0C?ooool001[ooooo00?o0000ooooooooool0D?ooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool000Oo0000C_ooool001[ooooo00?o0000ooooooooool0D?ooool7o`0000Goo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05;ooooo
000Jooooo`03o`000?oooooooooo05Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0D_ooool001[ooooo0_l0001G
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo05;ooooo000Jooooo`03o`000?oooooooooo05Kooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0D_ooool001[ooooo00?o0000ooooooooool0E_ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Booooo`00
6_ooool00ol0003oooooooooo`1Fooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05;ooooo0008ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0E_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Booooo`002oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo05Kooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool000Oo0000E?ooool000cooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`04ooooo`?o0000E_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0F?ooool000_ooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0F?ooool000Sooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`1Hooooo`002?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`1Hooooo`002?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`1Fooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`1Hooooo`002?ooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo05Kooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo05Sooooo000Jooooo`03o`000?oooooo
oooo05Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo05Sooooo000Jooooo`;o0000Eoooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0F?ooool001[ooooo00?o0000ooooooooool0E_ooool7o`0000Go
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0F?ooool001[ooooo00?o0000ooooooooool0G?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0006o`0005[ooooo
000Jooooo`03o`000?oooooooooo05cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool001[ooooo00?o0000
ooooooooool0G?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1Mooooo`006_ooool00ol0003oooooooooo`1Loooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo05gooooo000Jooooo`03o`000?oooooooooo05cooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0GOooool001[ooooo0_l0001Mooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05gooooo000Jooooo`03o`000?oo
oooooooo05cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0GOooool001[ooooo00?o0000ooooooooool0G?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1Mooooo`006_ooool00ol0003oooooooooo`1Looooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
05gooooo000Jooooo`03o`000?oooooooooo05cooooo00?o0000ool00?oo00000ooo0007o`0000Go
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0GOooool001[ooooo00?o0000ooooooooool0G?ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Mooooo`006_ooool2o`0005gooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool001[ooooo00?o0000
ooooooooool0G?ooool7o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`001ol0001Oooooo`006_ooool00ol0003oooooooooo`1Xoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo06?ooooo000Jooooo`03o`000?oooooooooo06Sooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Hoooool001[ooooo00?o0000ooooooooool0J?ooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Sooooo`006_oo
ool00ol0003oooooooooo`1Xooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo06?ooooo000Jooooo`03o`000?oooooo
oooo06Sooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Hoooool001[ooooo0_l0001Yooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
06?ooooo000Jooooo`03o`000?oooooooooo06Sooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool000Oo0000IOooool001[ooooo00?o0000ooooooooool0J?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool001[ooooo00?o
0000ooooooooool0J?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0JOooool000Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo06Sooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06Wooooo0002ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1Yooooo`000_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0
001Xooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1Yooooo`000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0J?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool000;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo06Sooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo06Wooooo0002ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Yooooo`000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0J?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool0
0003oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0
001[ooooo`006_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Koooool001[ooooo0_l0001Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Koooool001[ooooo00?o0000ooooooooool0J?ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo06oooooo000Jooooo`03o`000?oooooooooo06Sooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1_ooooo`006_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Koooool001[ooooo00?o0000ooooooooool0J?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo06oooooo000Jooooo`03o`000?oooooooooo
06Sooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1_ooooo`006_ooool2o`0006Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1_ooooo`006_ooool00ol0003ooooo
ooooo`1Xooooo`Oo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Koooool001[ooooo00?o0000ooooooooool0K_ooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1_ooooo`006_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06oooooo000Joooo
o`03o`000?oooooooooo06kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
00Oo0000LOooool001[ooooo00?o0000ooooooooool0K_ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0MOooool001[ooooo00?o0000ooooooooool0
K_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
MOooool001[ooooo0_l0001_ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1eooooo`006_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1eooooo`006_ooool00ol0
003oooooooooo`1^ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1eooooo`006_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1eooooo`006_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1eooooo`006_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`1eooooo`006_ooool2o`0006oooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo000Joooo
o`03o`000?oooooooooo06kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo07Gooooo000Jooooo`03o`000?oooooooooo06kooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo000Jooooo`03o`00
0?oooooooooo06kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo07Gooooo0004o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgM
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo06kooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo0002oooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`1^ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1eooooo`000_ooool00ol0003oooooooooo`07ooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`1^ooooo`Oo0000
1Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1eooooo`000_ooool00ol0003oooooooooo`06ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`04ooooo`?o0000M?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0007Oooooo
0002ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`1dooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07_o
oooo0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0M?ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1kooooo`00
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo07Cooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Noooool00003oeEE
EOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`1dooooo`Oo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07_o
oooo000Jooooo`03o`000?oooooooooo07[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo07_ooooo000Jooooo`;o0000Noooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Noooool001[ooooo00?o0000
ooooooooool0N_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Noooool001[ooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Noooool001[ooooo00?o0000oooooooo
ool0N_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Noooool001[ooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Noooool001[ooooo00?o0000ooooooooool0N_oo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Nooo
ool001[ooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Noooool001[ooooo0_l0001kooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1kooooo`006_ooool00ol0003o
ooooooooo`1jooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1kooooo`006_ooool00ol0003oooooooooo`1jooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1kooooo`006_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1kooooo`006_ooool00ol0003oooooooooo`1jooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1kooooo`006_ooool00ol0003oooooooooo`1joooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1koooo
o`006_ooool2o`0007_ooooo1ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07_ooooo000Jooooo`03o`00
0?oooooooooo083ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1kooooo`006_oo
ool00ol0003oooooooooo`20ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool000Oo0000OOooool001[ooooo00?o0000ooooooooool0P?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`21ooooo`006_ooool00ol0003oooooooooo`20ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
087ooooo000Jooooo`03o`000?oooooooooo083ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool001[ooooo
00?o0000ooooooooool0P?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`21ooooo`006_ooool2o`00087ooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0POooool001[ooooo00?o0000ooooooooool0P?ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`21
ooooo`006_ooool00ol0003oooooooooo`20ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo000Jooooo`03
o`000?oooooooooo083ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool000Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
083ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0POooool00004ob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`20ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo087ooooo00000onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00020ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo087ooooo00001?ooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0P?ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`21ooooo`000_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0P?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`21ooooo`000oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0P?oo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`21ooooo`0000Co^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo083o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0POooool00004oa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`20
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo087ooooo000Jooooo`03o`000?oooooooooo083ooooo1ol00005ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
00Oo0000Poooool001[ooooo0_l00027ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Qoooool001[ooooo00?o0000ooooooooool0Q_ooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo08Oooooo000Jooooo`03o`000?oooooooooo08Kooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`27ooooo`006_ooool00ol0003oooooooooo`26ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Qoooool001[ooooo00?o0000ooooooooool0Q_ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo08Oooooo000Jooooo`03o`000?oooooooooo08Ko
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`27ooooo`006_ooool2o`0008Oooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`27ooooo`006_ooool00ol0003ooooooooo
o`26ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Qoooool001[ooooo00?o0000
ooooooooool0Q_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo08Oooooo000Joooo
o`03o`000?oooooooooo08Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`001ol00029ooooo`006_ooool00ol0003oooooooooo`26ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo08gooooo000Jooooo`03o`000?oooooooooo08Kooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
SOooool001[ooooo00?o0000ooooooooool0Q_ooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2=ooooo`006_ooool2
o`0008Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0SOooool001[ooooo00?o0000ooooooooool0Q_ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2=ooooo`006_ooool00ol0003oooooooooo`26ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo08go
oooo000Jooooo`03o`000?oooooooooo08Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0SOooool001[ooooo00?o
0000ooooooooool0Q_ooool7o`0000Goo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2=ooooo`006_ooool00ol0003oooooooooo`2<ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2=ooooo`006_ooool2o`0008gooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo08gooooo000Jooooo`03
o`000?oooooooooo08cooooo3?l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2=ooooo`006_ooool00ol0003oooooooooo`2Gooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo08gooooo000Jooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0SOoo
ool000Co00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0SOooool00004ob4Q8Oo^
k^koooooodA4A0Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`2Gooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo08gooooo00000onHV9So8B4Qonk^kP09oooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`2G
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo08gooooo00001?ooooooV9RHob4Q8Oo^k^h7ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`04ooooo`?o0000Uoooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2=ooooo`000_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0Uoooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2=ooooo`000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
SOooool00004okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0Uoooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2=ooooo`00
00Co410@o`000?lQ8B7oc<c<1?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo09Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0SOooool001[ooooo00?o0000oooooooo
ool0Uoooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2=ooooo`006_ooool2o`0009Sooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
SOooool001[ooooo00?o0000ooooooooool0Uoooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2=ooooo`006_ooool0
0ol0003oooooooooo`2Gooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo08gooooo000Jooooo`03o`000?oooooooooo
09Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo000=o`0008oooooo000Jooooo`03o`000?oooooooooo09Oo
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Iooooo`006_ooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0VOooool001[ooooo00?o
0000ooooooooool0Uoooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo09Wooooo000J
ooooo`;o0000V?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo09Wooooo000Joooo
o`03o`000?oooooooooo09Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Ioooo
o`006_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0VOooool001[ooooo00?o0000ooooooooool0Uoooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo09Wooooo000Jooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Iooooo`006_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0VOooool001[ooooo0_l0002Hooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo0007o`0000Goo`0000?o0000ooooooooool0VOooool001[o
oooo00?o0000ooooooooool0Uoooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09Wo
oooo000Jooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`2Iooooo`006_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo003oo`0000?oo`001ol0
0005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0VOooool001[ooooo00?o0000
ooooooooool0Uoooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00Wooooo00?o0000
ool00?oo00000ooo00000ol0003oooooooooo`2Iooooo`006_ooool00ol0003oooooooooo`2Goooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo09Wooooo000Jooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0VOooool001[ooooo0_l0002Hooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
2Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09Wooooo000Jooooo`03o`000?oo
oooooooo09Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`09ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0VOooool001[ooooo00?o0000ooooooooool0Uoooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`2Iooooo`006_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
09Wooooo00001?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0Uoooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Iooooo`0000Co^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo09Oooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0VOooool000?ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo09Oooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0VOooool000;ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Uoooool7o`0000_ooooo1ol0002K
ooooo`0000Cooooooa0@4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000;ooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo^[Zjo`0000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3oooooodcooooo00001?l@413o0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
oooooom<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.24916, -27.2478, \
0.0210627, 1.917}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Two Simulations of a Random Walk with Bias", "Section",
  CellTags->"c:20"],

Cell[CellGroupData[{

Cell["Uniform System", "Subsubsection"],

Cell[TextData[{
  "We can now simulate a random walk with a given probability distribution  \
",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  " for the steps. We first take the case of a homogeneous system for which"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(w(s)\  = \ \(-\(1\/\(2 \( a(1 - a)\)\)\)\) \((1 - s - a)\)\), 
        ",", "  ", 
        RowBox[{\(-a\), "<", "s", "<", 
          RowBox[{"a", Cell[","]}]}]}], TraditionalForm]]]], "NE2",
  CellTags->"(8.2.22)"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\  = \ 0\)]],
  " otherwise. Thus,  the maximum step size is ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". This distribution is plotted in Cell ",
  ButtonBox["8.17",
    ButtonData:>"Cell 8.17",
    ButtonStyle->"Hyperlink"],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1/4\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(a = 1/4;\)\), "\n", 
    \(\(w[
          s_]\  := \ \(1\/\(2  a \((1 - a)\)\)\) \((1 - s - 
                a)\)\  /; \ \(-a\) \[LessEqual] \ s \[LessEqual] 
            a;\)\), "\n", 
    \(\(w[s_]\  := \ 0\  /; Abs[s] > \ a;\)\), "\n", 
    \(\(Plot[w[s], {s, \(-1\), 1}, 
        AxesLabel \[Rule] {"\<s\>", "\<w(s)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.17"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.22098 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.4875 .12521 -18 -4.5 ]
[.4875 .12521 0 4.5 ]
[.4875 .2357 -6 -4.5 ]
[.4875 .2357 0 4.5 ]
[.4875 .34619 -18 -4.5 ]
[.4875 .34619 0 4.5 ]
[.4875 .45668 -6 -4.5 ]
[.4875 .45668 0 4.5 ]
[.4875 .56717 -18 -4.5 ]
[.4875 .56717 0 4.5 ]
[.5 .64303 -14.0625 0 ]
[.5 .64303 14.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12521 m
.50625 .12521 L
s
[(0.5)] .4875 .12521 1 0 Mshowa
.5 .2357 m
.50625 .2357 L
s
[(1)] .4875 .2357 1 0 Mshowa
.5 .34619 m
.50625 .34619 L
s
[(1.5)] .4875 .34619 1 0 Mshowa
.5 .45668 m
.50625 .45668 L
s
[(2)] .4875 .45668 1 0 Mshowa
.5 .56717 m
.50625 .56717 L
s
[(2.5)] .4875 .56717 1 0 Mshowa
.125 Mabswid
.5 .03681 m
.50375 .03681 L
s
.5 .05891 m
.50375 .05891 L
s
.5 .08101 m
.50375 .08101 L
s
.5 .10311 m
.50375 .10311 L
s
.5 .1473 m
.50375 .1473 L
s
.5 .1694 m
.50375 .1694 L
s
.5 .1915 m
.50375 .1915 L
s
.5 .2136 m
.50375 .2136 L
s
.5 .25779 m
.50375 .25779 L
s
.5 .27989 m
.50375 .27989 L
s
.5 .30199 m
.50375 .30199 L
s
.5 .32409 m
.50375 .32409 L
s
.5 .36828 m
.50375 .36828 L
s
.5 .39038 m
.50375 .39038 L
s
.5 .41248 m
.50375 .41248 L
s
.5 .43458 m
.50375 .43458 L
s
.5 .47877 m
.50375 .47877 L
s
.5 .50087 m
.50375 .50087 L
s
.5 .52297 m
.50375 .52297 L
s
.5 .54507 m
.50375 .54507 L
s
.5 .58926 m
.50375 .58926 L
s
.5 .61136 m
.50375 .61136 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -75.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.125 13.000 moveto
(H) show
75.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.125 13.000 moveto
(L) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.32392 .01472 L
.34309 .01472 L
.36173 .01472 L
.37114 .01472 L
.37372 .01472 L
.37649 .01472 L
.37783 .01472 L
.3791 .01472 L
.38025 .01472 L
.3815 .60332 L
.38215 .60252 L
.38283 .60167 L
.38405 .60016 L
.38681 .59674 L
.39182 .59055 L
.40117 .57897 L
.42214 .55302 L
.46012 .50603 L
.50054 .45601 L
.53945 .40786 L
.55926 .38334 L
.58081 .35667 L
.59085 .34426 L
.60151 .33106 L
.61061 .3198 L
.6131 .31671 L
.61579 .31339 L
.61703 .31186 L
.61833 .31025 L
.61944 .01472 L
.62066 .01472 L
.66122 .01472 L
.70026 .01472 L
.74176 .01472 L
.78174 .01472 L
.82021 .01472 L
.86113 .01472 L
.90053 .01472 L
.93842 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006P3oool400000003014A4@3oool0oooo03T0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM07L0oooo00D0k^k^
03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM03/0oooo
100000000`0A4A40oooo0?ooo`0Y0?ooo`00703oool00`000000oooo0?ooo`0k0?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0MP3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo03`0oooo00<000000?ooo`3o
ool0:`3oool00140oooo1P0000050?ooo`030000003oool0oooo03<0oooo1P0000020?ooo`05014A
4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`1e0?ooo`05014A4@3oool0oooo0?oo
o`0A4A40403oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02/0oooo000L0?ooo`03
0000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo
07H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo03`0oooo00<00000
0?ooo`3oool0:`3oool001`0oooo00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00D00000028R8P000000<c<c0<c<c01g0?ooo`050000003oool0oooo0?ooo`000000
303oool01@0000008R8R0000000c<c<0c<c<03d0oooo00<000000?ooo`3oool0:`3oool001`0oooo
00<000000?ooo`3oool0>`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3o
ool0N@3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0[0?ooo`00703oool00`000000oooo0?ooo`0k0?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL0303oool00`000000oooo0?ooo`1i0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02/0oooo000J0?ooo`80EEEE00<000000?oo
o`3oool0>`3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo1000001h0?ooo`050>k^kP0c<c<0
000003<c<`3^k^h0303oool4000003`0oooo0P1EEED00`000000oooo0?ooo`0[0?ooo`00o`3ooomY
0?ooo`00Z@3oool00`000000oooo0?ooo`2l0?ooo`00Z@3oool00`000000oooo0?ooo`2P0?ooo`06
014A4@0c<c<000000000000A4A40ZZZZ5P3oool00:T0oooo00<000000?ooo`3oool0X03oool01P00
0000ZZZZ0?ooo`3oool0^k^k000001H0oooo002Y0?ooo`030000003oool0oooo0:40oooo00D0^k^k
08R8R01VIVH0IVIV014A4@0F0?ooo`004@3ooooo0000038000002P3oool01P0c<c<08R8R07MgM`1g
MgL0R8R80>k^kQH0oooo000H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3o
ool01P000000^k^k0?ooo`3^k^h0MgMg000001H0oooo000H0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
00H0ZZZZ028R8P000000000003<c<`0A4A4F0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool0
08D0oooo00<000000?ooo`3oool08@3oool200000280oooo00<000000?ooo`3oool0V03oool008D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0
oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0
8@3oool200000280oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0
oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`8000008P3oool00`000000oooo0?oo
o`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`00
0000oooo0?ooo`0Q0?ooo`8000008P3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo
00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`2H0?ooo`00Q@3oool00`000000oooo0?ooo`060?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3o
ool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool01P3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`060?ooo`05014A4@3o
ool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool300000240oooo00<000000?ooo`3oool0
V03oool008D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000`0oooo
00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0V03oool008D0oooo00<000000?ooo`3oool01P3oool01@0A4A40oooo0?ooo`3oool04A4A00`0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0
oooo00250?ooo`030000003oool0oooo00H0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00
Q@3oool00`000000oooo0?ooo`060?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000H0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo0025
0?ooo`030000003oool0oooo0240oooo0P00000R0?ooo`030000003oool0oooo09P0oooo00250?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?oo
o`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool20000
0280oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?oo
o`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0V03oool008D0oooo00<000000?ooo`3oool08@3oool200000280oooo00<000000?ooo`3oool0
V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<00000
0?ooo`3oool08@3oool200000280oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00
Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
V03oool008D0oooo00<000000?ooo`3oool05`3oool400000003014A4@3oool0oooo00<0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H
0?ooo`00Q@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0`00000Q0?oo
o`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo09P0oooo00250?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo09P0oooo00250?ooo`030000003oool0oooo01L0oooo0P1EEED00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000
003oool0oooo0240oooo0P00000R0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool0
08D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
09P0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo0P00000R
0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo09P0oooo00250?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2H0?ooo`00Q@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V03oool0
08D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
09P0oooo00250?ooo`030000003oool0oooo0240oooo0P00000R0?ooo`030000003oool0oooo09P0
oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`2H0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P
0?ooo`800000VP3oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo09T0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`2J0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`800000
803oool00`000000oooo0?ooo`2J0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0V`3oool008D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo09`0oooo00250?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2M0?ooo`00Q@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0W@3oool008D0oooo
00<000000?ooo`3oool01`3oool400000003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo09h0
oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool2028R8PP0oooo
00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo09l0oooo
00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`030?ooo`<000006@3oool00`000000oooo0?ooo`2P0?ooo`00Q@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0:40oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02`3oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`2R0?ooo`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0:<0oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0X`3oool008D0oooo
00<000000?ooo`3oool01`3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0Y03oool008D0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0:D0oooo00250?ooo`030000003oool0
oooo0240oooo0P00000D0?ooo`030000003oool0oooo0:H0oooo00250?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2W0?ooo`00Q@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0Z03oool008D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0:T0oooo
00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`2Z0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0ZP3oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0:/0oooo00250?ooo`030000003oool0oooo0240oooo0P00000>0?ooo`03
0000003oool0oooo0:`0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`2]0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0[@3oool008D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:h0oooo00250?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2_0?ooo`00Q@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0/03oool008D0oooo
00<000000?ooo`3oool08@3oool2000000X0oooo00<000000?ooo`3oool0/03oool008D0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;40oooo0025
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b
0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0/`3oool008D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0;@0oooo00250?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`2d0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0]@3oool008D0oooo00<000000?ooo`3oool08@3oool2
000000@0oooo00<000000?ooo`3oool0]P3oool008D0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0;L0oooo00250?ooo`030000003oool0oooo0240
oooo00D000000?ooo`3oool0oooo0000002j0?ooo`00Q@3oool00`000000oooo0?ooo`0Q0?ooo`05
0000003oool0oooo0?ooo`000000^P3oool008D0oooo00<000000?ooo`3oool05P3oool5000000H0
oooo00@000000?ooo`3oool00000^`3oool008D0oooo00<000000?ooo`3oool05P3oool01@2IVIT0
8R8R0>k^kP3oool0A4A400H0oooo00<000000?ooo`000000_03oool008D0oooo00<000000?ooo`3o
ool05`3oool00`2IVIT08R8R0>k^kP070?ooo`800000_@3oool008D0oooo00<000000?ooo`3oool0
603oool00`2IVIT08R8R0>k^kP060?ooo`<00000_03oool008D0oooo00<000000?ooo`3oool06@3o
ool00`1gMgL0IVIV0?ooo`050?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool00`3oool200000;h0oooo00250?ooo`030000003oool0oooo
01H0oooo00D000000;^k^`3oool0VIVI014A4@040?ooo`030000003oool000000;h0oooo00250?oo
o`030000003oool0oooo01H0oooo00D0VIVI014A4@0000008R8R0<c<c0030?ooo`040000003oool0
oooo00000;h0oooo00250?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0000
002n0?ooo`00Q@3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo0?ooo`800000_@3o
ool008D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0;`0oooo00250?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`2l0?ooo`00Q@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0_03oool008D0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`00Q@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0_03oool008D0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`070?ooo`800000_@3oool008D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2l0?ooo`00Q@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0_03o
ool008D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0;`0oooo00250?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2l0?ooo`00Q@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0_03oool008D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0=0?ooo`800000_@3oool008D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`2l0?ooo`00Q@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0_03oool008D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2l0?ooo`00Q@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0_03o
ool008D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`800000_@3oool0
08D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0;`0oooo00250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`2l0?ooo`00Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0_03oool008D0oooo00<000000?ooo`3oool01P3oool5000000D0oooo0P0R
8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`2l0?ooo`00Q@3o
ool00`000000oooo0?ooo`060?ooo`0509VIV@000000k^k^0?ooo`14A4@01@3oool2028R8PP0oooo
00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`2l0?ooo`00Q@3oool00`000000oooo0?oo
o`060?ooo`040000002IVIT08R8R0>k^kQ40oooo00<000000?ooo`3oool00`3oool300000;`0oooo
00250?ooo`030000003oool0oooo00H0oooo00D000000?ooo`2IVIT08R8R0>k^kP0?0?ooo`0307Mg
M`0c<c<0oooo00@0oooo00<000000?ooo`3oool0_03oool008D0oooo00<000000?ooo`3oool01@3o
ool01P000000oooo0?ooo`3oool0MgMg06IVIP`0oooo00D00000028R8P000000<c<c0<c<c0050?oo
o`030000003oool0oooo0;`0oooo00250?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0_03oool008D0oooo00<000000?ooo`3oool00`3oool020000000oooo0?ooo`000000^k^k0?oo
o`2IVIT04A4A303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;`0oooo00250?oo
o`030000003oool0oooo00<0oooo00P000000?ooo`3oool0VIVI014A4@0000008R8R0<c<c0`0oooo
100000060?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`2l0?ooo`00Q@3oool01@000000oooo0?ooo`3o
ool0000001l0oooo0P00002m0?ooo`00Q@3oool010000000oooo0?ooo`00000P0?ooo`030000003o
ool0oooo0;`0oooo00250?ooo`030000003oool000000240oooo00<000000?ooo`3oool0_03oool0
08D0oooo0P00000R0?ooo`030000003oool0oooo0;`0oooo00250?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0_03oool00:T0oooo00<000000?ooo`3oool0_03oool00:T0oooo00<0
00000?ooo`3oool0_03oool00:T0oooo0P00002m0?ooo`00Z@3oool00`000000oooo0?ooo`2l0?oo
o`00Z@3oool00`000000oooo0?ooo`2l0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00Y`3oool00`1gMgL0IVIV0?ooo`080?ooo`0306IVIP1gMgL0oooo0;<0
oooo002V0?ooo`030=gMg@0A4A40k^k^00T0oooo00<0k^k^014A4@3MgMd0/`3oool009`0oooo00D0
00000<c<c03MgMd000000>k^kP050?ooo`0605EEE@2IVIT0oooo0?ooo`0A4A40<c<c0P0000000`0A
4A40ZZZZ0?ooo`020?ooo`0308R8R01VIVH0oooo0;80oooo002K0?ooo`060:ZZZP000000R8R809VI
V@000000VIVI1@3oool01P000000oooo0?ooo`3oool000000:ZZZP80oooo00<0^k^k0000003oool0
0P3oool00`3^k^h000000?ooo`2b0?ooo`00V`3oool01P1EEED0MgMg04A4A014A4@0MgMg05EEE@D0
oooo00<0<c<c0?ooo`3oool00P3oool01@2k^k/0R8R806IVIP1VIVH04A4A00@0oooo00<000000?oo
o`3oool0/@3oool009/0oooo00H000000=gMg@14A4@08R8R0>k^kP0000050?ooo`0603<c<`3oool0
oooo0?ooo`0c<c<08R8R0P1gMgL00`28R8P0k^k^0?ooo`030?ooo`030000003oool0oooo0;40oooo
002J0?ooo`080:ZZZP0R8R80oooo08R8R01EEED0oooo03<c<`2ZZZX40?ooo`0:0000003^k^h0oooo
0?ooo`000000^k^k0?ooo`3^k^h0MgMg000000<0oooo00<0k^k^0000003oool0/P3oool009X0oooo
0`0000020?ooo`<00000103oool01P1EEED0MgMg0?ooo`3oool0ZZZZ028R8P80000000<0<c<c014A
4@3oool00P3oool00`1gMgL0EEEE0?ooo`2b0?ooo`00YP3oool00`3MgMd04A4A0>k^kP090?ooo`03
0>k^kP0A4A40gMgM0;<0oooo002W0?ooo`0307MgM`1VIVH0oooo00P0oooo00<0IVIV07MgM`3oool0
/`3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.16946, -0.223752, \
0.00862084, 0.0185771}}]
}, Open  ]],

Cell[TextData[{
  "According to Eq. ",
  ButtonBox["(8.2.4)",
    ButtonData:>{"Chapter8.nb", "(8.2.4)"},
    ButtonStyle->"Hyperlink"],
  " we expect a uniform drift speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"v", "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "s", "\[RightAngleBracket]"}], "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". For this distribution, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "s", "\[RightAngleBracket]"}], " ", 
          "=", \(\(-1\)\(/\)\(36\)\(\ \)\)}], TraditionalForm]]],
  ". Also, the particle distribution should spread with diffusion coefficient \
",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " given by Eq. ",
  ButtonBox["(8.2.7)",
    ButtonData:>{"Chapter8.nb", "(8.2.7)"},
    ButtonStyle->"Hyperlink"],
  ". For this distribution,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], " ", 
          "=", " ", \(1/48 = 0.021 ... \)}], TraditionalForm]]],
  ", so ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", " ", "=", 
          RowBox[{
            RowBox[{\((1/48\  - \ 1/36\^2)\), "/", 
              RowBox[{"(", 
                RowBox[{"2", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], ")"}]}], "=", 
            RowBox[{
              RowBox[{"13", "/", 
                RowBox[{"(", 
                  RowBox[{"1296", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], ")"}]}], "=", 
              RowBox[{\(0.0100 ... \), "/", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], " "}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t We will use the rejection method to create a random variable ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["s",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " with distribution ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  ", and test these predictions for the resulting random walk, starting all \
particles at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ". The resulting simulation for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 200\)]],
  " particles is displayed in Cell ",
  ButtonBox["8.18",
    ButtonData:>"Cell 8.18",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ random\ step\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(f0\  = \ 3. ;\), " ", 
        "\n", \(sx[]\  := \ Random[Real, {\(-a\), a}];\), 
        "\n", \(sy[]\  := \ Random[Real, {0, f0}];\), 
        "\n", \(s[]\  := \((ss = sx[]; \ \ While[sy[]\  > \ w[ss], \ 
                ss = sx[]]; ss)\);\), "\[IndentingNewLine]", 
        StyleBox[\( (*\ the\ random\ walk\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", 
        " ", \(x[k_, n_]\  := \ \(x[k, n]\  = \ x[k, n - 1]\  + \ s[]\);\), 
        "\n", 
        StyleBox[\( (*\ initial\ condition\ \ and\ parameters*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(x[k_, 0]\  = \ 0;\), "\n", \(M = 200;\), 
        "\n", \(Nstep\  = \ 50;\), "\[IndentingNewLine]", 
        StyleBox[\( (*\ analysis*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(positions\  = \ 
            Table[x[k, n], {k, 1, 200}, {n, 0, Nstep}];\), 
        "\n", \(pos[n_]\  := \ Table[positions[\([j, n + 1]\)], {j, 1, M}];\),
         "\n", \(Table[
            ListPlot[pos[n], PlotRange \[Rule] {\(-6\), 2}, 
              AxesLabel \[Rule] {"\<k\>", "\<x\>"}], {n, 0, 
              50}];\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.18"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .46353 Mdot
.03333 .46353 Mdot
.0381 .46353 Mdot
.04286 .46353 Mdot
.04762 .46353 Mdot
.05238 .46353 Mdot
.05714 .46353 Mdot
.0619 .46353 Mdot
.06667 .46353 Mdot
.07143 .46353 Mdot
.07619 .46353 Mdot
.08095 .46353 Mdot
.08571 .46353 Mdot
.09048 .46353 Mdot
.09524 .46353 Mdot
.1 .46353 Mdot
.10476 .46353 Mdot
.10952 .46353 Mdot
.11429 .46353 Mdot
.11905 .46353 Mdot
.12381 .46353 Mdot
.12857 .46353 Mdot
.13333 .46353 Mdot
.1381 .46353 Mdot
.14286 .46353 Mdot
.14762 .46353 Mdot
.15238 .46353 Mdot
.15714 .46353 Mdot
.1619 .46353 Mdot
.16667 .46353 Mdot
.17143 .46353 Mdot
.17619 .46353 Mdot
.18095 .46353 Mdot
.18571 .46353 Mdot
.19048 .46353 Mdot
.19524 .46353 Mdot
.2 .46353 Mdot
.20476 .46353 Mdot
.20952 .46353 Mdot
.21429 .46353 Mdot
.21905 .46353 Mdot
.22381 .46353 Mdot
.22857 .46353 Mdot
.23333 .46353 Mdot
.2381 .46353 Mdot
.24286 .46353 Mdot
.24762 .46353 Mdot
.25238 .46353 Mdot
.25714 .46353 Mdot
.2619 .46353 Mdot
.26667 .46353 Mdot
.27143 .46353 Mdot
.27619 .46353 Mdot
.28095 .46353 Mdot
.28571 .46353 Mdot
.29048 .46353 Mdot
.29524 .46353 Mdot
.3 .46353 Mdot
.30476 .46353 Mdot
.30952 .46353 Mdot
.31429 .46353 Mdot
.31905 .46353 Mdot
.32381 .46353 Mdot
.32857 .46353 Mdot
.33333 .46353 Mdot
.3381 .46353 Mdot
.34286 .46353 Mdot
.34762 .46353 Mdot
.35238 .46353 Mdot
.35714 .46353 Mdot
.3619 .46353 Mdot
.36667 .46353 Mdot
.37143 .46353 Mdot
.37619 .46353 Mdot
.38095 .46353 Mdot
.38571 .46353 Mdot
.39048 .46353 Mdot
.39524 .46353 Mdot
.4 .46353 Mdot
.40476 .46353 Mdot
.40952 .46353 Mdot
.41429 .46353 Mdot
.41905 .46353 Mdot
.42381 .46353 Mdot
.42857 .46353 Mdot
.43333 .46353 Mdot
.4381 .46353 Mdot
.44286 .46353 Mdot
.44762 .46353 Mdot
.45238 .46353 Mdot
.45714 .46353 Mdot
.4619 .46353 Mdot
.46667 .46353 Mdot
.47143 .46353 Mdot
.47619 .46353 Mdot
.48095 .46353 Mdot
.48571 .46353 Mdot
.49048 .46353 Mdot
.49524 .46353 Mdot
.5 .46353 Mdot
.50476 .46353 Mdot
.50952 .46353 Mdot
.51429 .46353 Mdot
.51905 .46353 Mdot
.52381 .46353 Mdot
.52857 .46353 Mdot
.53333 .46353 Mdot
.5381 .46353 Mdot
.54286 .46353 Mdot
.54762 .46353 Mdot
.55238 .46353 Mdot
.55714 .46353 Mdot
.5619 .46353 Mdot
.56667 .46353 Mdot
.57143 .46353 Mdot
.57619 .46353 Mdot
.58095 .46353 Mdot
.58571 .46353 Mdot
.59048 .46353 Mdot
.59524 .46353 Mdot
.6 .46353 Mdot
.60476 .46353 Mdot
.60952 .46353 Mdot
.61429 .46353 Mdot
.61905 .46353 Mdot
.62381 .46353 Mdot
.62857 .46353 Mdot
.63333 .46353 Mdot
.6381 .46353 Mdot
.64286 .46353 Mdot
.64762 .46353 Mdot
.65238 .46353 Mdot
.65714 .46353 Mdot
.6619 .46353 Mdot
.66667 .46353 Mdot
.67143 .46353 Mdot
.67619 .46353 Mdot
.68095 .46353 Mdot
.68571 .46353 Mdot
.69048 .46353 Mdot
.69524 .46353 Mdot
.7 .46353 Mdot
.70476 .46353 Mdot
.70952 .46353 Mdot
.71429 .46353 Mdot
.71905 .46353 Mdot
.72381 .46353 Mdot
.72857 .46353 Mdot
.73333 .46353 Mdot
.7381 .46353 Mdot
.74286 .46353 Mdot
.74762 .46353 Mdot
.75238 .46353 Mdot
.75714 .46353 Mdot
.7619 .46353 Mdot
.76667 .46353 Mdot
.77143 .46353 Mdot
.77619 .46353 Mdot
.78095 .46353 Mdot
.78571 .46353 Mdot
.79048 .46353 Mdot
.79524 .46353 Mdot
.8 .46353 Mdot
.80476 .46353 Mdot
.80952 .46353 Mdot
.81429 .46353 Mdot
.81905 .46353 Mdot
.82381 .46353 Mdot
.82857 .46353 Mdot
.83333 .46353 Mdot
.8381 .46353 Mdot
.84286 .46353 Mdot
.84762 .46353 Mdot
.85238 .46353 Mdot
.85714 .46353 Mdot
.8619 .46353 Mdot
.86667 .46353 Mdot
.87143 .46353 Mdot
.87619 .46353 Mdot
.88095 .46353 Mdot
.88571 .46353 Mdot
.89048 .46353 Mdot
.89524 .46353 Mdot
.9 .46353 Mdot
.90476 .46353 Mdot
.90952 .46353 Mdot
.91429 .46353 Mdot
.91905 .46353 Mdot
.92381 .46353 Mdot
.92857 .46353 Mdot
.93333 .46353 Mdot
.9381 .46353 Mdot
.94286 .46353 Mdot
.94762 .46353 Mdot
.95238 .46353 Mdot
.95714 .46353 Mdot
.9619 .46353 Mdot
.96667 .46353 Mdot
.97143 .46353 Mdot
.97619 .46353 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`003`3oool01@3^k^h0<c<c0000000A4A40c<c<0?l0
ooooE@3oool000l0oooo00D0EEEE07MgM`3oool0VIVI028R8P3o0?oooeD0oooo00070?ooo`H00000
0P3oool01@000000oooo0?ooo`3oool000000?l0ooooE@3oool000l0oooo00D0000009VIV@3oool0
VIVI028R8P060?ooo`<00000o`3ooom<0?ooo`003`3oool01@000000EEEE0000000A4A40c<c<00H0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`003`3oool00`1EEED0R8R80?ooo`080?ooo`030000
003oool0oooo0?l0ooooC03oool000l0oooo00<0gMgM014A4@2IVIT0203oool00`000000oooo0?oo
o`3o0?oood`0oooo000@0?ooo`040<c<c014A4@00000014A4@H0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`006P3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0oooo
C03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J
0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0oooo
C03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
0100oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo0?l0ooooC03oool0
01<0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3o0?oood`0oooo00070?ooo`H0
00001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooC03oool001<0oooo
00<0MgMg03<c<`3oool0103oool300000?l0ooooC03oool00100oooo00D00000028R8P000000<c<c
0<c<c0050?ooo`030000003oool0oooo0?l0ooooC03oool00100oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`00403oool4000000H0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`006P3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool200000?l0ooooC@3oool001X0oooo
00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J
0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`03
0000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool00140oooo
0P0000000`0A4A40oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood`0oooo00070?ooo`H000000P3oool5
000000H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`003`3oool01014A4@0gMgM0?ooo`000007
0?ooo`<00000o`3ooom<0?ooo`003`3oool0103MgMd0EEEE0?ooo`0000070?ooo`030000003oool0
oooo0?l0ooooC03oool00100oooo00<0MgMg0<c<c00000001`3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000@0?ooo`030>k^kP14A4@0000000L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
4@3oool00`1gMgL000000?ooo`060?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00
003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0
oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000
o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0
oooo0?l0ooooC03oool000l0oooo00D0VIVI014A4@000000<c<c0<c<c0060?ooo`030000003oool0
oooo0?l0ooooC03oool000l0oooo00D04A4A0;^k^`3oool0MgMg03<c<`060?ooo`030000003oool0
oooo0?l0ooooC03oool000L0oooo1P0000060?ooo`030000003oool0oooo00@0oooo0`00003o0?oo
od`0oooo000B0?ooo`030:ZZZP0A4A40oooo00D0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
4@3oool00`0A4A4000000;^k^`060?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo00<0
^k^k028R8P3oool01@3oool00`000000oooo0?ooo`3o0?oood`0oooo000?0?ooo`05014A4@2IVIT0
oooo0;^k^`0000001P3oool00`000000oooo0?ooo`3o0?oood`0oooo000?0?ooo`050:ZZZP0A4A40
0000014A4@2ZZZX01P3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool200000?l0ooooC@3o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`003`3oool5000000H0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`003`3oool01@2IVIT08R8R0>k^kP3oool0A4A400H0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`001`3oool6000000<0oooo00<0VIVI028R8P3^k^h01`3oool300000?l0
ooooC03oool00140oooo00<0VIVI028R8P3^k^h01P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000B0?ooo`0307MgM`1VIVH0oooo00D0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`004`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooC03oool000l0oooo00D000000;^k
^`3oool0VIVI014A4@060?ooo`030000003oool0oooo0?l0ooooC03oool000l0oooo00D0VIVI014A
4@0000008R8R0<c<c0060?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000o`3ooom=
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000o`3ooom=
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000@0?ooo`@0000000<04A4A0?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?oood`0oooo000B0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3ooom<0?ooo`001`3oool6000000D0oooo00<000000?ooo`3oool01@3o
ool300000?l0ooooC03oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?oood`0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood`0oooo000@0?ooo`80EEEE00<0
00000?ooo`3oool01@3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool200000?l0ooooC@3o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`110?oo
o`0504A4A0000000000003<c<`3MgMd00P3oool01@3^k^h0<c<c0000000c<c<0k^k^03/0oooo1000
0000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^0`3oool01@3^k^h0<c<c0000000c<c<0
k^k^03H0oooo100000001@0A4A40oooo0?ooo`3oool0A4A40080000000T0<c<c0=gMg@3oool0oooo
0>k^kP0c<c<0000003<c<`3^k^h0=@3oool5000000<0oooo00D0k^k^03<c<`000000<c<c0>k^kP03
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h06`3oool001X0oooo00<000000?ooo`3oool0A03oool0
2@1gMgL0<c<c0?ooo`3oool0MgMg09VIV@3oool0VIVI07MgM`0m0?ooo`030000003oool0oooo0080
oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0>03oool0
0`000000oooo0?ooo`060?ooo`0907MgM`0c<c<0oooo0?ooo`1gMgL0VIVI0?ooo`2IVIT0MgMg03D0
oooo00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg01/0oooo000J0?ooo`030000003oool0oooo04D0oooo00@00000
0?ooo`3oool04A4A0`3oool00`0A4A40oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00D0
4A4A0?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A40>03oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo014A4@<0oooo00<04A4A0?ooo`3oool0=03oool00`2I
VIT08R8R0>k^kP040?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3o
ool04A4A01/0oooo000J0?ooo`800000A@3oool01@1gMgL0<c<c0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000003P0oooo00<000000?ooo`3oool01P3oool01@1gMgL0
<c<c0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0=@3oool00`2IVIT08R8R0>k^kP030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000001/0oooo000J
0?ooo`030000003oool0oooo0440oooo00D00000028R8P000000<c<c0<c<c0020?ooo`050000003o
ool0oooo0?ooo`000000?@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000003P0oooo00<000000?ooo`3oool00`3oool01@00
00008R8R0000000c<c<0c<c<0080oooo00D000000?ooo`3oool0oooo0000000h0?ooo`0307MgM`1V
IVH0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00006`3oool001X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`05014A
4@3oool0oooo0?ooo`0A4A40?@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A03P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`05014A4@3oool0oooo0?ooo`0A4A40>@3oool01@000000oooo0?oo
o`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`03014A4@3oool0oooo01T0
oooo000J0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg03d0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0h0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg03D0oooo00D000000;^k^`3oool0VIVI
014A4@030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
01/0oooo000J0?ooo`030000003oool0oooo0440oooo100000030?ooo`050>k^kP0c<c<0000003<c
<`3^k^h0>`3oool205EEE@030000003oool0oooo0080oooo00D0k^k^03<c<`000000<c<c0>k^kP03
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0=P3oool205EEE@030000003oool0oooo00<0oooo1000
00030?ooo`050>k^kP0c<c<0000003<c<`3^k^h0=@3oool01@2IVIT04A4A0000000R8R80c<c<00<0
oooo00D0k^k^03<c<`000000<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h06`3oool0
01X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo
00<000000?ooo`3oool0o`3ooolj0?ooo`8000000P3oool00`0A4A4000000000000;0?ooo`006P3o
ool00`000000oooo0?ooo`3o0?oooc/0oooo00D000000?ooo`3^k^h0<c<c0<c<c00<0?ooo`004P3o
oooo000003/000002`3oool010000000VIVI03<c<`3<c<`=0?ooo`006P3ooooo000002`000004P3o
ool00`0000004A4A09VIV@0>0?ooo`006P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool04@3oool010000000k^k^04A4A01gMgL=0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oooc/0oooo00D000000?ooo`14A4@00000014A4@0<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool03P3oool001X0oooo0P00003o0?oo
oc`0oooo00<000000?ooo`3oool03P3oool001X0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`80
0000403oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?oo
odd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0
oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?oo
odd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool00100oooo100000000`0A4A40oooo
0?ooo`030?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000B0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooom<0?oo
o`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood`0oooo000B0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00403oool205EEE@030000003oool0
oooo00D0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool000l0oooo1@0000060?ooo`030000003oool0oooo0?l0
ooooC03oool000l0oooo00D0VIVI028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0oooo0?l0
ooooC03oool00100oooo00<0VIVI028R8P3^k^h01`3oool00`000000oooo0?ooo`3o0?oood`0oooo
000A0?ooo`0309VIV@0R8R80k^k^00H0oooo0`00003o0?oood`0oooo000B0?ooo`0307MgM`1VIVH0
oooo0?l0ooooE03oool001<0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`003`3oool01@000000
^k^k0?ooo`2IVIT04A4A0?l0ooooE@3oool000l0oooo00D0VIVI014A4@0000008R8R0<c<c03o0?oo
oeD0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo000G0?ooo`8000000P3oool200000?l0ooooC03o
ool001L0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<co0?oood`0oooo000H0?ooo`040=gMg@00
000000000<c<c?l0ooooC@3oool001P0oooo00@0k^k^028R8P000000k^k^o`3ooom=0?ooo`005`3o
ool01@3^k^h08R8R07MgM`1gMgL0<c<c0?l0ooooC@3oool001L0oooo0P0000020?ooo`800000o`3o
oom<0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.7718, -6.23327, \
0.840833, 0.0518284}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45789 Mdot
.03333 .4696 Mdot
.0381 .45664 Mdot
.04286 .44807 Mdot
.04762 .45699 Mdot
.05238 .44481 Mdot
.05714 .48249 Mdot
.0619 .44544 Mdot
.06667 .47184 Mdot
.07143 .44893 Mdot
.07619 .45681 Mdot
.08095 .44805 Mdot
.08571 .46926 Mdot
.09048 .46174 Mdot
.09524 .46655 Mdot
.1 .45016 Mdot
.10476 .45807 Mdot
.10952 .45076 Mdot
.11429 .47478 Mdot
.11905 .46666 Mdot
.12381 .46835 Mdot
.12857 .48009 Mdot
.13333 .46454 Mdot
.1381 .47588 Mdot
.14286 .47032 Mdot
.14762 .47147 Mdot
.15238 .45426 Mdot
.15714 .44756 Mdot
.1619 .48105 Mdot
.16667 .44499 Mdot
.17143 .45241 Mdot
.17619 .47766 Mdot
.18095 .46898 Mdot
.18571 .44554 Mdot
.19048 .45456 Mdot
.19524 .45474 Mdot
.2 .4443 Mdot
.20476 .48007 Mdot
.20952 .46984 Mdot
.21429 .4575 Mdot
.21905 .45164 Mdot
.22381 .47542 Mdot
.22857 .46153 Mdot
.23333 .4651 Mdot
.2381 .45599 Mdot
.24286 .46417 Mdot
.24762 .46564 Mdot
.25238 .47771 Mdot
.25714 .45184 Mdot
.2619 .46017 Mdot
.26667 .46229 Mdot
.27143 .44458 Mdot
.27619 .48006 Mdot
.28095 .45102 Mdot
.28571 .4558 Mdot
.29048 .45961 Mdot
.29524 .46656 Mdot
.3 .45072 Mdot
.30476 .45211 Mdot
.30952 .46304 Mdot
.31429 .46489 Mdot
.31905 .44768 Mdot
.32381 .47091 Mdot
.32857 .45588 Mdot
.33333 .46349 Mdot
.3381 .45107 Mdot
.34286 .47477 Mdot
.34762 .45872 Mdot
.35238 .44496 Mdot
.35714 .45795 Mdot
.3619 .46813 Mdot
.36667 .46807 Mdot
.37143 .45068 Mdot
.37619 .45131 Mdot
.38095 .44709 Mdot
.38571 .45533 Mdot
.39048 .48169 Mdot
.39524 .46617 Mdot
.4 .47256 Mdot
.40476 .45405 Mdot
.40952 .46459 Mdot
.41429 .4652 Mdot
.41905 .46235 Mdot
.42381 .47915 Mdot
.42857 .47179 Mdot
.43333 .46285 Mdot
.4381 .44647 Mdot
.44286 .45117 Mdot
.44762 .46264 Mdot
.45238 .45476 Mdot
.45714 .45419 Mdot
.4619 .46998 Mdot
.46667 .45943 Mdot
.47143 .45481 Mdot
.47619 .45006 Mdot
.48095 .45314 Mdot
.48571 .48007 Mdot
.49048 .45117 Mdot
.49524 .45347 Mdot
.5 .46439 Mdot
.50476 .45035 Mdot
.50952 .44608 Mdot
.51429 .45194 Mdot
.51905 .45552 Mdot
.52381 .46128 Mdot
.52857 .45873 Mdot
.53333 .44562 Mdot
.5381 .48089 Mdot
.54286 .44635 Mdot
.54762 .48269 Mdot
.55238 .47507 Mdot
.55714 .47878 Mdot
.5619 .47126 Mdot
.56667 .45333 Mdot
.57143 .45002 Mdot
.57619 .47668 Mdot
.58095 .45547 Mdot
.58571 .45714 Mdot
.59048 .44975 Mdot
.59524 .44745 Mdot
.6 .46136 Mdot
.60476 .47298 Mdot
.60952 .4607 Mdot
.61429 .44427 Mdot
.61905 .4677 Mdot
.62381 .4644 Mdot
.62857 .47378 Mdot
.63333 .46679 Mdot
.6381 .4645 Mdot
.64286 .44759 Mdot
.64762 .45095 Mdot
.65238 .44718 Mdot
.65714 .45226 Mdot
.6619 .4598 Mdot
.66667 .45767 Mdot
.67143 .47382 Mdot
.67619 .47594 Mdot
.68095 .45695 Mdot
.68571 .47685 Mdot
.69048 .44573 Mdot
.69524 .46528 Mdot
.7 .46324 Mdot
.70476 .45515 Mdot
.70952 .46027 Mdot
.71429 .47779 Mdot
.71905 .47251 Mdot
.72381 .46879 Mdot
.72857 .44791 Mdot
.73333 .46908 Mdot
.7381 .4553 Mdot
.74286 .45026 Mdot
.74762 .47122 Mdot
.75238 .46362 Mdot
.75714 .4452 Mdot
.7619 .46605 Mdot
.76667 .45453 Mdot
.77143 .44909 Mdot
.77619 .46374 Mdot
.78095 .47672 Mdot
.78571 .45627 Mdot
.79048 .46598 Mdot
.79524 .46412 Mdot
.8 .44986 Mdot
.80476 .48016 Mdot
.80952 .44437 Mdot
.81429 .47724 Mdot
.81905 .46677 Mdot
.82381 .45651 Mdot
.82857 .47737 Mdot
.83333 .45468 Mdot
.8381 .44629 Mdot
.84286 .45918 Mdot
.84762 .46918 Mdot
.85238 .47514 Mdot
.85714 .46758 Mdot
.8619 .48063 Mdot
.86667 .44873 Mdot
.87143 .46603 Mdot
.87619 .46458 Mdot
.88095 .47852 Mdot
.88571 .44549 Mdot
.89048 .4803 Mdot
.89524 .48242 Mdot
.9 .44473 Mdot
.90476 .45878 Mdot
.90952 .45839 Mdot
.91429 .47357 Mdot
.91905 .45641 Mdot
.92381 .44828 Mdot
.92857 .47599 Mdot
.93333 .47056 Mdot
.9381 .47245 Mdot
.94286 .47386 Mdot
.94762 .44635 Mdot
.95238 .47676 Mdot
.95714 .4622 Mdot
.9619 .48045 Mdot
.96667 .45403 Mdot
.97143 .46441 Mdot
.97619 .4462 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .46242 Mdot
.03333 .46893 Mdot
.0381 .46133 Mdot
.04286 .43196 Mdot
.04762 .44805 Mdot
.05238 .43337 Mdot
.05714 .50075 Mdot
.0619 .45282 Mdot
.06667 .48233 Mdot
.07143 .44429 Mdot
.07619 .44107 Mdot
.08095 .44311 Mdot
.08571 .45009 Mdot
.09048 .476 Mdot
.09524 .45817 Mdot
.1 .46144 Mdot
.10476 .44227 Mdot
.10952 .46141 Mdot
.11429 .46532 Mdot
.11905 .45192 Mdot
.12381 .46296 Mdot
.12857 .46139 Mdot
.13333 .47603 Mdot
.1381 .48883 Mdot
.14286 .45564 Mdot
.14762 .47261 Mdot
.15238 .43788 Mdot
.15714 .44133 Mdot
.1619 .47434 Mdot
.16667 .4544 Mdot
.17143 .45898 Mdot
.17619 .46168 Mdot
.18095 .48462 Mdot
.18571 .46341 Mdot
.19048 .43584 Mdot
.19524 .45525 Mdot
.2 .4297 Mdot
.20476 .49599 Mdot
.20952 .45919 Mdot
.21429 .47252 Mdot
.21905 .4544 Mdot
.22381 .46183 Mdot
.22857 .45457 Mdot
.23333 .48302 Mdot
.2381 .43972 Mdot
.24286 .44969 Mdot
.24762 .47601 Mdot
.25238 .46936 Mdot
.25714 .45997 Mdot
.2619 .44539 Mdot
.26667 .47643 Mdot
.27143 .44068 Mdot
.27619 .49114 Mdot
.28095 .43263 Mdot
.28571 .45588 Mdot
.29048 .45779 Mdot
.29524 .48199 Mdot
.3 .43601 Mdot
.30476 .44444 Mdot
.30952 .48175 Mdot
.31429 .46938 Mdot
.31905 .43207 Mdot
.32381 .46782 Mdot
.32857 .4578 Mdot
.33333 .44811 Mdot
.3381 .44087 Mdot
.34286 .46365 Mdot
.34762 .46844 Mdot
.35238 .44896 Mdot
.35714 .47449 Mdot
.3619 .47171 Mdot
.36667 .45211 Mdot
.37143 .43395 Mdot
.37619 .45896 Mdot
.38095 .43257 Mdot
.38571 .44894 Mdot
.39048 .46291 Mdot
.39524 .48381 Mdot
.4 .459 Mdot
.40476 .44252 Mdot
.40952 .4802 Mdot
.41429 .45982 Mdot
.41905 .46104 Mdot
.42381 .4792 Mdot
.42857 .46671 Mdot
.43333 .4641 Mdot
.4381 .43017 Mdot
.44286 .46079 Mdot
.44762 .46879 Mdot
.45238 .46505 Mdot
.45714 .46064 Mdot
.4619 .48374 Mdot
.46667 .46049 Mdot
.47143 .46709 Mdot
.47619 .45497 Mdot
.48095 .44779 Mdot
.48571 .48338 Mdot
.49048 .45931 Mdot
.49524 .45969 Mdot
.5 .44649 Mdot
.50476 .46055 Mdot
.50952 .43181 Mdot
.51429 .45569 Mdot
.51905 .44032 Mdot
.52381 .44591 Mdot
.52857 .47495 Mdot
.53333 .44035 Mdot
.5381 .49053 Mdot
.54286 .43277 Mdot
.54762 .48721 Mdot
.55238 .49065 Mdot
.55714 .49071 Mdot
.5619 .48589 Mdot
.56667 .43591 Mdot
.57143 .46309 Mdot
.57619 .47396 Mdot
.58095 .47111 Mdot
.58571 .4572 Mdot
.59048 .43878 Mdot
.59524 .45266 Mdot
.6 .47261 Mdot
.60476 .46141 Mdot
.60952 .46594 Mdot
.61429 .42798 Mdot
.61905 .45262 Mdot
.62381 .45926 Mdot
.62857 .48657 Mdot
.63333 .45203 Mdot
.6381 .45077 Mdot
.64286 .45297 Mdot
.64762 .43277 Mdot
.65238 .46014 Mdot
.65714 .43486 Mdot
.6619 .45424 Mdot
.66667 .46959 Mdot
.67143 .47415 Mdot
.67619 .45998 Mdot
.68095 .44065 Mdot
.68571 .47139 Mdot
.69048 .45532 Mdot
.69524 .45228 Mdot
.7 .44675 Mdot
.70476 .43589 Mdot
.70952 .44442 Mdot
.71429 .47193 Mdot
.71905 .47718 Mdot
.72381 .46006 Mdot
.72857 .44362 Mdot
.73333 .4855 Mdot
.7381 .46636 Mdot
.74286 .44175 Mdot
.74762 .47163 Mdot
.75238 .45976 Mdot
.75714 .45675 Mdot
.7619 .45241 Mdot
.76667 .44225 Mdot
.77143 .46604 Mdot
.77619 .47976 Mdot
.78095 .47701 Mdot
.78571 .47523 Mdot
.79048 .46854 Mdot
.79524 .47562 Mdot
.8 .44284 Mdot
.80476 .49429 Mdot
.80952 .45285 Mdot
.81429 .46403 Mdot
.81905 .44813 Mdot
.82381 .45749 Mdot
.82857 .46331 Mdot
.83333 .46994 Mdot
.8381 .45194 Mdot
.84286 .4476 Mdot
.84762 .48457 Mdot
.85238 .46504 Mdot
.85714 .45747 Mdot
.8619 .47868 Mdot
.86667 .45427 Mdot
.87143 .4549 Mdot
.87619 .45911 Mdot
.88095 .46185 Mdot
.88571 .44075 Mdot
.89048 .46313 Mdot
.89524 .46831 Mdot
.9 .44139 Mdot
.90476 .46024 Mdot
.90952 .44894 Mdot
.91429 .46221 Mdot
.91905 .44976 Mdot
.92381 .45136 Mdot
.92857 .4785 Mdot
.93333 .46055 Mdot
.9381 .45652 Mdot
.94286 .46136 Mdot
.94762 .43425 Mdot
.95238 .46557 Mdot
.95714 .45408 Mdot
.9619 .49706 Mdot
.96667 .43883 Mdot
.97143 .46217 Mdot
.97619 .4327 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45524 Mdot
.03333 .45885 Mdot
.0381 .46718 Mdot
.04286 .43963 Mdot
.04762 .46361 Mdot
.05238 .41461 Mdot
.05714 .4819 Mdot
.0619 .44291 Mdot
.06667 .46465 Mdot
.07143 .42774 Mdot
.07619 .43637 Mdot
.08095 .43193 Mdot
.08571 .45122 Mdot
.09048 .48961 Mdot
.09524 .47115 Mdot
.1 .44878 Mdot
.10476 .45469 Mdot
.10952 .46012 Mdot
.11429 .45262 Mdot
.11905 .45136 Mdot
.12381 .44983 Mdot
.12857 .46502 Mdot
.13333 .49515 Mdot
.1381 .50673 Mdot
.14286 .44598 Mdot
.14762 .47077 Mdot
.15238 .45546 Mdot
.15714 .42644 Mdot
.1619 .46266 Mdot
.16667 .47081 Mdot
.17143 .4522 Mdot
.17619 .46233 Mdot
.18095 .46828 Mdot
.18571 .47577 Mdot
.19048 .41745 Mdot
.19524 .43658 Mdot
.2 .44495 Mdot
.20476 .48199 Mdot
.20952 .44423 Mdot
.21429 .48523 Mdot
.21905 .47011 Mdot
.22381 .446 Mdot
.22857 .43851 Mdot
.23333 .46545 Mdot
.2381 .45548 Mdot
.24286 .43421 Mdot
.24762 .48747 Mdot
.25238 .48004 Mdot
.25714 .45454 Mdot
.2619 .4516 Mdot
.26667 .47732 Mdot
.27143 .43206 Mdot
.27619 .47253 Mdot
.28095 .42726 Mdot
.28571 .45547 Mdot
.29048 .47696 Mdot
.29524 .46652 Mdot
.3 .42333 Mdot
.30476 .44837 Mdot
.30952 .50035 Mdot
.31429 .47656 Mdot
.31905 .42786 Mdot
.32381 .45638 Mdot
.32857 .46786 Mdot
.33333 .45159 Mdot
.3381 .42955 Mdot
.34286 .45822 Mdot
.34762 .47803 Mdot
.35238 .43425 Mdot
.35714 .46055 Mdot
.3619 .46679 Mdot
.36667 .46162 Mdot
.37143 .43743 Mdot
.37619 .45939 Mdot
.38095 .41948 Mdot
.38571 .44043 Mdot
.39048 .46402 Mdot
.39524 .46767 Mdot
.4 .46634 Mdot
.40476 .43816 Mdot
.40952 .46819 Mdot
.41429 .4613 Mdot
.41905 .4614 Mdot
.42381 .49204 Mdot
.42857 .4836 Mdot
.43333 .45871 Mdot
.4381 .41943 Mdot
.44286 .47332 Mdot
.44762 .47579 Mdot
.45238 .46063 Mdot
.45714 .45799 Mdot
.4619 .46878 Mdot
.46667 .47391 Mdot
.47143 .47452 Mdot
.47619 .43941 Mdot
.48095 .44889 Mdot
.48571 .48307 Mdot
.49048 .4482 Mdot
.49524 .44544 Mdot
.5 .44754 Mdot
.50476 .47063 Mdot
.50952 .4195 Mdot
.51429 .45731 Mdot
.51905 .43654 Mdot
.52381 .46098 Mdot
.52857 .47852 Mdot
.53333 .44268 Mdot
.5381 .49872 Mdot
.54286 .42213 Mdot
.54762 .4759 Mdot
.55238 .50802 Mdot
.55714 .47264 Mdot
.5619 .47155 Mdot
.56667 .42711 Mdot
.57143 .46487 Mdot
.57619 .45752 Mdot
.58095 .48728 Mdot
.58571 .45175 Mdot
.59048 .44054 Mdot
.59524 .4334 Mdot
.6 .47115 Mdot
.60476 .45269 Mdot
.60952 .45786 Mdot
.61429 .44544 Mdot
.61905 .43363 Mdot
.62381 .47601 Mdot
.62857 .473 Mdot
.63333 .46605 Mdot
.6381 .44338 Mdot
.64286 .43786 Mdot
.64762 .41891 Mdot
.65238 .46857 Mdot
.65714 .44379 Mdot
.6619 .43951 Mdot
.66667 .46495 Mdot
.67143 .47399 Mdot
.67619 .46479 Mdot
.68095 .42172 Mdot
.68571 .48582 Mdot
.69048 .45231 Mdot
.69524 .45275 Mdot
.7 .45983 Mdot
.70476 .4195 Mdot
.70952 .45704 Mdot
.71429 .46364 Mdot
.71905 .47967 Mdot
.72381 .46103 Mdot
.72857 .4302 Mdot
.73333 .46776 Mdot
.7381 .47337 Mdot
.74286 .43236 Mdot
.74762 .46985 Mdot
.75238 .47156 Mdot
.75714 .44784 Mdot
.7619 .43803 Mdot
.76667 .43346 Mdot
.77143 .46835 Mdot
.77619 .47644 Mdot
.78095 .4764 Mdot
.78571 .47206 Mdot
.79048 .4601 Mdot
.79524 .47517 Mdot
.8 .43195 Mdot
.80476 .49088 Mdot
.80952 .46833 Mdot
.81429 .46964 Mdot
.81905 .42884 Mdot
.82381 .47581 Mdot
.82857 .45998 Mdot
.83333 .48715 Mdot
.8381 .45621 Mdot
.84286 .46588 Mdot
.84762 .49536 Mdot
.85238 .44952 Mdot
.85714 .44789 Mdot
.8619 .46421 Mdot
.86667 .44392 Mdot
.87143 .45429 Mdot
.87619 .44239 Mdot
.88095 .45168 Mdot
.88571 .44389 Mdot
.89048 .44819 Mdot
.89524 .45213 Mdot
.9 .42846 Mdot
.90476 .47133 Mdot
.90952 .4377 Mdot
.91429 .44566 Mdot
.91905 .4315 Mdot
.92381 .43487 Mdot
.92857 .46915 Mdot
.93333 .47591 Mdot
.9381 .45997 Mdot
.94286 .46671 Mdot
.94762 .44025 Mdot
.95238 .45775 Mdot
.95714 .4635 Mdot
.9619 .50402 Mdot
.96667 .45283 Mdot
.97143 .45419 Mdot
.97619 .43172 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44154 Mdot
.03333 .45049 Mdot
.0381 .46119 Mdot
.04286 .45651 Mdot
.04762 .45498 Mdot
.05238 .39664 Mdot
.05714 .47471 Mdot
.0619 .44782 Mdot
.06667 .44944 Mdot
.07143 .42549 Mdot
.07619 .41923 Mdot
.08095 .42292 Mdot
.08571 .44148 Mdot
.09048 .47161 Mdot
.09524 .4883 Mdot
.1 .43653 Mdot
.10476 .46932 Mdot
.10952 .45799 Mdot
.11429 .46727 Mdot
.11905 .44131 Mdot
.12381 .45608 Mdot
.12857 .45615 Mdot
.13333 .50981 Mdot
.1381 .51203 Mdot
.14286 .43258 Mdot
.14762 .48728 Mdot
.15238 .46304 Mdot
.15714 .41932 Mdot
.1619 .46841 Mdot
.16667 .47781 Mdot
.17143 .4468 Mdot
.17619 .45723 Mdot
.18095 .47144 Mdot
.18571 .49246 Mdot
.19048 .40127 Mdot
.19524 .44676 Mdot
.2 .43115 Mdot
.20476 .49664 Mdot
.20952 .4278 Mdot
.21429 .46706 Mdot
.21905 .48393 Mdot
.22381 .42997 Mdot
.22857 .44192 Mdot
.23333 .46311 Mdot
.2381 .4379 Mdot
.24286 .44663 Mdot
.24762 .47145 Mdot
.25238 .47014 Mdot
.25714 .45754 Mdot
.2619 .44228 Mdot
.26667 .49188 Mdot
.27143 .43636 Mdot
.27619 .4582 Mdot
.28095 .43871 Mdot
.28571 .4507 Mdot
.29048 .47412 Mdot
.29524 .46788 Mdot
.3 .40638 Mdot
.30476 .45334 Mdot
.30952 .48975 Mdot
.31429 .48952 Mdot
.31905 .42148 Mdot
.32381 .43855 Mdot
.32857 .45002 Mdot
.33333 .45323 Mdot
.3381 .41593 Mdot
.34286 .44859 Mdot
.34762 .46198 Mdot
.35238 .44031 Mdot
.35714 .45044 Mdot
.3619 .45392 Mdot
.36667 .46616 Mdot
.37143 .4283 Mdot
.37619 .4411 Mdot
.38095 .40902 Mdot
.38571 .42865 Mdot
.39048 .44561 Mdot
.39524 .45453 Mdot
.4 .47138 Mdot
.40476 .42367 Mdot
.40952 .48299 Mdot
.41429 .47206 Mdot
.41905 .48065 Mdot
.42381 .48326 Mdot
.42857 .49271 Mdot
.43333 .4545 Mdot
.4381 .42459 Mdot
.44286 .45445 Mdot
.44762 .46194 Mdot
.45238 .46978 Mdot
.45714 .43908 Mdot
.4619 .45553 Mdot
.46667 .46262 Mdot
.47143 .46354 Mdot
.47619 .42226 Mdot
.48095 .44435 Mdot
.48571 .49829 Mdot
.49048 .44582 Mdot
.49524 .44673 Mdot
.5 .43534 Mdot
.50476 .4529 Mdot
.50952 .41019 Mdot
.51429 .45256 Mdot
.51905 .43324 Mdot
.52381 .44278 Mdot
.52857 .48481 Mdot
.53333 .43499 Mdot
.5381 .48275 Mdot
.54286 .42484 Mdot
.54762 .47478 Mdot
.55238 .52562 Mdot
.55714 .45362 Mdot
.5619 .46058 Mdot
.56667 .42635 Mdot
.57143 .45345 Mdot
.57619 .46112 Mdot
.58095 .49464 Mdot
.58571 .43524 Mdot
.59048 .42856 Mdot
.59524 .43021 Mdot
.6 .46272 Mdot
.60476 .46 Mdot
.60952 .44388 Mdot
.61429 .44763 Mdot
.61905 .42516 Mdot
.62381 .48139 Mdot
.62857 .46826 Mdot
.63333 .47215 Mdot
.6381 .43944 Mdot
.64286 .44068 Mdot
.64762 .41866 Mdot
.65238 .46992 Mdot
.65714 .42677 Mdot
.6619 .42804 Mdot
.66667 .47457 Mdot
.67143 .47481 Mdot
.67619 .44722 Mdot
.68095 .40408 Mdot
.68571 .48823 Mdot
.69048 .46067 Mdot
.69524 .47173 Mdot
.7 .45107 Mdot
.70476 .43592 Mdot
.70952 .45442 Mdot
.71429 .46885 Mdot
.71905 .46291 Mdot
.72381 .4702 Mdot
.72857 .43723 Mdot
.73333 .4533 Mdot
.7381 .46254 Mdot
.74286 .42655 Mdot
.74762 .4587 Mdot
.75238 .47557 Mdot
.75714 .44558 Mdot
.7619 .44509 Mdot
.76667 .42192 Mdot
.77143 .45843 Mdot
.77619 .47975 Mdot
.78095 .49394 Mdot
.78571 .48334 Mdot
.79048 .46689 Mdot
.79524 .47002 Mdot
.8 .43447 Mdot
.80476 .49695 Mdot
.80952 .46303 Mdot
.81429 .4691 Mdot
.81905 .42451 Mdot
.82381 .46421 Mdot
.82857 .45693 Mdot
.83333 .50008 Mdot
.8381 .45034 Mdot
.84286 .45455 Mdot
.84762 .47655 Mdot
.85238 .43212 Mdot
.85714 .45439 Mdot
.8619 .45202 Mdot
.86667 .44726 Mdot
.87143 .4516 Mdot
.87619 .44132 Mdot
.88095 .46578 Mdot
.88571 .46142 Mdot
.89048 .45813 Mdot
.89524 .43965 Mdot
.9 .41876 Mdot
.90476 .45759 Mdot
.90952 .42025 Mdot
.91429 .43946 Mdot
.91905 .4127 Mdot
.92381 .44893 Mdot
.92857 .46757 Mdot
.93333 .46584 Mdot
.9381 .47185 Mdot
.94286 .45401 Mdot
.94762 .43348 Mdot
.95238 .46101 Mdot
.95714 .44916 Mdot
.9619 .49577 Mdot
.96667 .4633 Mdot
.97143 .47072 Mdot
.97619 .42041 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .42798 Mdot
.03333 .4368 Mdot
.0381 .47105 Mdot
.04286 .43863 Mdot
.04762 .45807 Mdot
.05238 .41502 Mdot
.05714 .48004 Mdot
.0619 .43727 Mdot
.06667 .45027 Mdot
.07143 .44179 Mdot
.07619 .41747 Mdot
.08095 .42185 Mdot
.08571 .43372 Mdot
.09048 .45308 Mdot
.09524 .48502 Mdot
.1 .45024 Mdot
.10476 .45294 Mdot
.10952 .45057 Mdot
.11429 .46411 Mdot
.11905 .44744 Mdot
.12381 .47367 Mdot
.12857 .46498 Mdot
.13333 .50514 Mdot
.1381 .51427 Mdot
.14286 .42251 Mdot
.14762 .48094 Mdot
.15238 .45662 Mdot
.15714 .42473 Mdot
.1619 .44947 Mdot
.16667 .48222 Mdot
.17143 .46484 Mdot
.17619 .44356 Mdot
.18095 .4793 Mdot
.18571 .49053 Mdot
.19048 .39888 Mdot
.19524 .45631 Mdot
.2 .41616 Mdot
.20476 .49596 Mdot
.20952 .42496 Mdot
.21429 .47036 Mdot
.21905 .4963 Mdot
.22381 .44532 Mdot
.22857 .44469 Mdot
.23333 .45805 Mdot
.2381 .43595 Mdot
.24286 .45952 Mdot
.24762 .45668 Mdot
.25238 .46954 Mdot
.25714 .44794 Mdot
.2619 .45275 Mdot
.26667 .49517 Mdot
.27143 .45379 Mdot
.27619 .4521 Mdot
.28095 .43784 Mdot
.28571 .46199 Mdot
.29048 .47556 Mdot
.29524 .46229 Mdot
.3 .414 Mdot
.30476 .44667 Mdot
.30952 .48232 Mdot
.31429 .50212 Mdot
.31905 .40872 Mdot
.32381 .43695 Mdot
.32857 .44517 Mdot
.33333 .43503 Mdot
.3381 .41011 Mdot
.34286 .45957 Mdot
.34762 .46023 Mdot
.35238 .42916 Mdot
.35714 .4667 Mdot
.3619 .4415 Mdot
.36667 .45547 Mdot
.37143 .41466 Mdot
.37619 .44249 Mdot
.38095 .40364 Mdot
.38571 .44557 Mdot
.39048 .44748 Mdot
.39524 .44297 Mdot
.4 .46124 Mdot
.40476 .41559 Mdot
.40952 .49969 Mdot
.41429 .47499 Mdot
.41905 .46343 Mdot
.42381 .48611 Mdot
.42857 .49453 Mdot
.43333 .44952 Mdot
.4381 .44285 Mdot
.44286 .46506 Mdot
.44762 .46681 Mdot
.45238 .46105 Mdot
.45714 .43676 Mdot
.4619 .44985 Mdot
.46667 .46973 Mdot
.47143 .45664 Mdot
.47619 .40386 Mdot
.48095 .45492 Mdot
.48571 .48431 Mdot
.49048 .44244 Mdot
.49524 .43892 Mdot
.5 .43133 Mdot
.50476 .43718 Mdot
.50952 .41692 Mdot
.51429 .46352 Mdot
.51905 .4296 Mdot
.52381 .42395 Mdot
.52857 .48833 Mdot
.53333 .44219 Mdot
.5381 .47381 Mdot
.54286 .42464 Mdot
.54762 .46997 Mdot
.55238 .52709 Mdot
.55714 .44279 Mdot
.5619 .44161 Mdot
.56667 .42693 Mdot
.57143 .46247 Mdot
.57619 .46526 Mdot
.58095 .49764 Mdot
.58571 .42178 Mdot
.59048 .44041 Mdot
.59524 .44694 Mdot
.6 .45191 Mdot
.60476 .46207 Mdot
.60952 .44232 Mdot
.61429 .4481 Mdot
.61905 .44414 Mdot
.62381 .48275 Mdot
.62857 .45329 Mdot
.63333 .4712 Mdot
.6381 .44864 Mdot
.64286 .43685 Mdot
.64762 .41919 Mdot
.65238 .47044 Mdot
.65714 .42392 Mdot
.6619 .41334 Mdot
.66667 .48967 Mdot
.67143 .47509 Mdot
.67619 .44187 Mdot
.68095 .38679 Mdot
.68571 .49113 Mdot
.69048 .44415 Mdot
.69524 .45891 Mdot
.7 .44597 Mdot
.70476 .4179 Mdot
.70952 .43517 Mdot
.71429 .46491 Mdot
.71905 .45418 Mdot
.72381 .46067 Mdot
.72857 .456 Mdot
.73333 .43845 Mdot
.7381 .45375 Mdot
.74286 .44223 Mdot
.74762 .43966 Mdot
.75238 .46453 Mdot
.75714 .43973 Mdot
.7619 .44934 Mdot
.76667 .42874 Mdot
.77143 .44875 Mdot
.77619 .47124 Mdot
.78095 .50323 Mdot
.78571 .47817 Mdot
.79048 .45724 Mdot
.79524 .45337 Mdot
.8 .42206 Mdot
.80476 .49807 Mdot
.80952 .46584 Mdot
.81429 .48442 Mdot
.81905 .41263 Mdot
.82381 .47187 Mdot
.82857 .44314 Mdot
.83333 .4873 Mdot
.8381 .45945 Mdot
.84286 .47385 Mdot
.84762 .48283 Mdot
.85238 .41904 Mdot
.85714 .44569 Mdot
.8619 .45251 Mdot
.86667 .44404 Mdot
.87143 .43669 Mdot
.87619 .42688 Mdot
.88095 .4502 Mdot
.88571 .44717 Mdot
.89048 .45369 Mdot
.89524 .45378 Mdot
.9 .42428 Mdot
.90476 .47592 Mdot
.90952 .42095 Mdot
.91429 .44036 Mdot
.91905 .40883 Mdot
.92381 .44133 Mdot
.92857 .47975 Mdot
.93333 .45777 Mdot
.9381 .47655 Mdot
.94286 .46377 Mdot
.94762 .44052 Mdot
.95238 .45165 Mdot
.95714 .45236 Mdot
.9619 .48756 Mdot
.96667 .44913 Mdot
.97143 .48373 Mdot
.97619 .41682 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .42361 Mdot
.03333 .44237 Mdot
.0381 .46907 Mdot
.04286 .42671 Mdot
.04762 .46982 Mdot
.05238 .40277 Mdot
.05714 .48381 Mdot
.0619 .4412 Mdot
.06667 .44515 Mdot
.07143 .44775 Mdot
.07619 .42604 Mdot
.08095 .43475 Mdot
.08571 .43108 Mdot
.09048 .46092 Mdot
.09524 .48095 Mdot
.1 .45977 Mdot
.10476 .44855 Mdot
.10952 .4372 Mdot
.11429 .44592 Mdot
.11905 .44271 Mdot
.12381 .45915 Mdot
.12857 .47221 Mdot
.13333 .522 Mdot
.1381 .5116 Mdot
.14286 .4303 Mdot
.14762 .48015 Mdot
.15238 .43868 Mdot
.15714 .42539 Mdot
.1619 .44585 Mdot
.16667 .46484 Mdot
.17143 .46248 Mdot
.17619 .43747 Mdot
.18095 .46213 Mdot
.18571 .49323 Mdot
.19048 .40044 Mdot
.19524 .45263 Mdot
.2 .40976 Mdot
.20476 .51504 Mdot
.20952 .42426 Mdot
.21429 .46589 Mdot
.21905 .48526 Mdot
.22381 .462 Mdot
.22857 .45129 Mdot
.23333 .46227 Mdot
.2381 .43562 Mdot
.24286 .46744 Mdot
.24762 .46446 Mdot
.25238 .47077 Mdot
.25714 .45458 Mdot
.2619 .44873 Mdot
.26667 .47595 Mdot
.27143 .46645 Mdot
.27619 .4564 Mdot
.28095 .4282 Mdot
.28571 .45101 Mdot
.29048 .4723 Mdot
.29524 .46171 Mdot
.3 .39635 Mdot
.30476 .43365 Mdot
.30952 .46788 Mdot
.31429 .48314 Mdot
.31905 .40301 Mdot
.32381 .43901 Mdot
.32857 .45439 Mdot
.33333 .42057 Mdot
.3381 .42912 Mdot
.34286 .471 Mdot
.34762 .46829 Mdot
.35238 .42982 Mdot
.35714 .47777 Mdot
.3619 .42613 Mdot
.36667 .46334 Mdot
.37143 .41671 Mdot
.37619 .45745 Mdot
.38095 .39038 Mdot
.38571 .43453 Mdot
.39048 .43359 Mdot
.39524 .42886 Mdot
.4 .47213 Mdot
.40476 .40402 Mdot
.40952 .4882 Mdot
.41429 .47933 Mdot
.41905 .45103 Mdot
.42381 .48528 Mdot
.42857 .50053 Mdot
.43333 .43704 Mdot
.4381 .45428 Mdot
.44286 .455 Mdot
.44762 .46648 Mdot
.45238 .46123 Mdot
.45714 .44139 Mdot
.4619 .44376 Mdot
.46667 .45272 Mdot
.47143 .44884 Mdot
.47619 .38882 Mdot
.48095 .45999 Mdot
.48571 .48432 Mdot
.49048 .42719 Mdot
.49524 .44998 Mdot
.5 .41809 Mdot
.50476 .42645 Mdot
.50952 .41801 Mdot
.51429 .44429 Mdot
.51905 .43566 Mdot
.52381 .41661 Mdot
.52857 .48021 Mdot
.53333 .43133 Mdot
.5381 .47922 Mdot
.54286 .42089 Mdot
.54762 .45895 Mdot
.55238 .51317 Mdot
.55714 .45323 Mdot
.5619 .46025 Mdot
.56667 .44049 Mdot
.57143 .44673 Mdot
.57619 .47305 Mdot
.58095 .49541 Mdot
.58571 .41893 Mdot
.59048 .45486 Mdot
.59524 .46338 Mdot
.6 .47065 Mdot
.60476 .45588 Mdot
.60952 .45617 Mdot
.61429 .43376 Mdot
.61905 .43157 Mdot
.62381 .46393 Mdot
.62857 .44808 Mdot
.63333 .46171 Mdot
.6381 .45287 Mdot
.64286 .42266 Mdot
.64762 .4203 Mdot
.65238 .45879 Mdot
.65714 .40907 Mdot
.6619 .40249 Mdot
.66667 .4843 Mdot
.67143 .46456 Mdot
.67619 .42741 Mdot
.68095 .38656 Mdot
.68571 .47784 Mdot
.69048 .45079 Mdot
.69524 .47492 Mdot
.7 .46274 Mdot
.70476 .40982 Mdot
.70952 .44682 Mdot
.71429 .45391 Mdot
.71905 .4402 Mdot
.72381 .45289 Mdot
.72857 .46723 Mdot
.73333 .44509 Mdot
.7381 .45393 Mdot
.74286 .4253 Mdot
.74762 .43944 Mdot
.75238 .45664 Mdot
.75714 .43648 Mdot
.7619 .43921 Mdot
.76667 .41135 Mdot
.77143 .43543 Mdot
.77619 .45309 Mdot
.78095 .51306 Mdot
.78571 .47991 Mdot
.79048 .43845 Mdot
.79524 .47141 Mdot
.8 .4251 Mdot
.80476 .50466 Mdot
.80952 .4765 Mdot
.81429 .48208 Mdot
.81905 .42435 Mdot
.82381 .45711 Mdot
.82857 .45454 Mdot
.83333 .49672 Mdot
.8381 .45241 Mdot
.84286 .45641 Mdot
.84762 .4746 Mdot
.85238 .40172 Mdot
.85714 .42744 Mdot
.8619 .46137 Mdot
.86667 .45206 Mdot
.87143 .4352 Mdot
.87619 .42626 Mdot
.88095 .45209 Mdot
.88571 .43665 Mdot
.89048 .45986 Mdot
.89524 .43594 Mdot
.9 .43312 Mdot
.90476 .48205 Mdot
.90952 .42047 Mdot
.91429 .434 Mdot
.91905 .39886 Mdot
.92381 .42397 Mdot
.92857 .49636 Mdot
.93333 .44662 Mdot
.9381 .47888 Mdot
.94286 .46946 Mdot
.94762 .45568 Mdot
.95238 .43934 Mdot
.95714 .47001 Mdot
.9619 .49181 Mdot
.96667 .43262 Mdot
.97143 .48396 Mdot
.97619 .40323 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .42193 Mdot
.03333 .44241 Mdot
.0381 .45194 Mdot
.04286 .44246 Mdot
.04762 .45735 Mdot
.05238 .39018 Mdot
.05714 .49203 Mdot
.0619 .44309 Mdot
.06667 .43437 Mdot
.07143 .46008 Mdot
.07619 .43054 Mdot
.08095 .4495 Mdot
.08571 .43335 Mdot
.09048 .47589 Mdot
.09524 .48611 Mdot
.1 .46193 Mdot
.10476 .46766 Mdot
.10952 .4477 Mdot
.11429 .44542 Mdot
.11905 .46184 Mdot
.12381 .45749 Mdot
.12857 .46085 Mdot
.13333 .5088 Mdot
.1381 .52986 Mdot
.14286 .41341 Mdot
.14762 .48531 Mdot
.15238 .42466 Mdot
.15714 .42891 Mdot
.1619 .43852 Mdot
.16667 .46284 Mdot
.17143 .44413 Mdot
.17619 .43038 Mdot
.18095 .45629 Mdot
.18571 .47883 Mdot
.19048 .3924 Mdot
.19524 .43639 Mdot
.2 .39958 Mdot
.20476 .50494 Mdot
.20952 .43924 Mdot
.21429 .46249 Mdot
.21905 .4934 Mdot
.22381 .45651 Mdot
.22857 .44801 Mdot
.23333 .47045 Mdot
.2381 .41883 Mdot
.24286 .44817 Mdot
.24762 .455 Mdot
.25238 .48944 Mdot
.25714 .46521 Mdot
.2619 .44018 Mdot
.26667 .45998 Mdot
.27143 .46329 Mdot
.27619 .44974 Mdot
.28095 .43088 Mdot
.28571 .46166 Mdot
.29048 .47863 Mdot
.29524 .4555 Mdot
.3 .37975 Mdot
.30476 .42954 Mdot
.30952 .4784 Mdot
.31429 .47971 Mdot
.31905 .39086 Mdot
.32381 .43892 Mdot
.32857 .44957 Mdot
.33333 .40497 Mdot
.3381 .43368 Mdot
.34286 .45807 Mdot
.34762 .47802 Mdot
.35238 .43943 Mdot
.35714 .47693 Mdot
.3619 .41767 Mdot
.36667 .47579 Mdot
.37143 .40763 Mdot
.37619 .45202 Mdot
.38095 .39495 Mdot
.38571 .44611 Mdot
.39048 .43702 Mdot
.39524 .42903 Mdot
.4 .45622 Mdot
.40476 .38655 Mdot
.40952 .48667 Mdot
.41429 .48441 Mdot
.41905 .44226 Mdot
.42381 .48117 Mdot
.42857 .51132 Mdot
.43333 .44538 Mdot
.4381 .45111 Mdot
.44286 .45164 Mdot
.44762 .448 Mdot
.45238 .45236 Mdot
.45714 .44297 Mdot
.4619 .43201 Mdot
.46667 .44628 Mdot
.47143 .46663 Mdot
.47619 .39366 Mdot
.48095 .45635 Mdot
.48571 .47303 Mdot
.49048 .42451 Mdot
.49524 .46512 Mdot
.5 .39953 Mdot
.50476 .43515 Mdot
.50952 .40747 Mdot
.51429 .42973 Mdot
.51905 .42524 Mdot
.52381 .41992 Mdot
.52857 .47531 Mdot
.53333 .43337 Mdot
.5381 .4803 Mdot
.54286 .42852 Mdot
.54762 .46756 Mdot
.55238 .49642 Mdot
.55714 .44526 Mdot
.5619 .45524 Mdot
.56667 .43915 Mdot
.57143 .45969 Mdot
.57619 .45702 Mdot
.58095 .47669 Mdot
.58571 .41858 Mdot
.59048 .44781 Mdot
.59524 .44776 Mdot
.6 .48132 Mdot
.60476 .45955 Mdot
.60952 .44902 Mdot
.61429 .43038 Mdot
.61905 .41648 Mdot
.62381 .45439 Mdot
.62857 .43386 Mdot
.63333 .45983 Mdot
.6381 .43979 Mdot
.64286 .42984 Mdot
.64762 .40787 Mdot
.65238 .45003 Mdot
.65714 .39227 Mdot
.6619 .40515 Mdot
.66667 .48225 Mdot
.67143 .45065 Mdot
.67619 .41103 Mdot
.68095 .38632 Mdot
.68571 .46264 Mdot
.69048 .44337 Mdot
.69524 .47658 Mdot
.7 .47907 Mdot
.70476 .42473 Mdot
.70952 .45377 Mdot
.71429 .44079 Mdot
.71905 .42627 Mdot
.72381 .46324 Mdot
.72857 .46493 Mdot
.73333 .4549 Mdot
.7381 .46221 Mdot
.74286 .41892 Mdot
.74762 .43767 Mdot
.75238 .45169 Mdot
.75714 .4384 Mdot
.7619 .44356 Mdot
.76667 .42809 Mdot
.77143 .43269 Mdot
.77619 .45224 Mdot
.78095 .50556 Mdot
.78571 .47358 Mdot
.79048 .44721 Mdot
.79524 .4755 Mdot
.8 .4117 Mdot
.80476 .48562 Mdot
.80952 .49099 Mdot
.81429 .48142 Mdot
.81905 .42289 Mdot
.82381 .4607 Mdot
.82857 .44286 Mdot
.83333 .47758 Mdot
.8381 .45042 Mdot
.84286 .46387 Mdot
.84762 .48864 Mdot
.85238 .40953 Mdot
.85714 .42446 Mdot
.8619 .44935 Mdot
.86667 .45186 Mdot
.87143 .41779 Mdot
.87619 .43421 Mdot
.88095 .44801 Mdot
.88571 .44613 Mdot
.89048 .47677 Mdot
.89524 .43993 Mdot
.9 .42683 Mdot
.90476 .48001 Mdot
.90952 .42244 Mdot
.91429 .41921 Mdot
.91905 .41353 Mdot
.92381 .41613 Mdot
.92857 .50617 Mdot
.93333 .44774 Mdot
.9381 .46336 Mdot
.94286 .47887 Mdot
.94762 .44839 Mdot
.95238 .45788 Mdot
.95714 .46813 Mdot
.9619 .48808 Mdot
.96667 .43561 Mdot
.97143 .47284 Mdot
.97619 .39387 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .43677 Mdot
.03333 .44079 Mdot
.0381 .4519 Mdot
.04286 .45797 Mdot
.04762 .44095 Mdot
.05238 .39732 Mdot
.05714 .4813 Mdot
.0619 .44761 Mdot
.06667 .42664 Mdot
.07143 .45954 Mdot
.07619 .42319 Mdot
.08095 .45517 Mdot
.08571 .42596 Mdot
.09048 .49263 Mdot
.09524 .48061 Mdot
.1 .44709 Mdot
.10476 .45157 Mdot
.10952 .45511 Mdot
.11429 .44643 Mdot
.11905 .46102 Mdot
.12381 .44302 Mdot
.12857 .45225 Mdot
.13333 .52063 Mdot
.1381 .54171 Mdot
.14286 .39479 Mdot
.14762 .47002 Mdot
.15238 .43467 Mdot
.15714 .42407 Mdot
.1619 .44522 Mdot
.16667 .47271 Mdot
.17143 .44284 Mdot
.17619 .41272 Mdot
.18095 .45986 Mdot
.18571 .48609 Mdot
.19048 .406 Mdot
.19524 .44401 Mdot
.2 .40136 Mdot
.20476 .49093 Mdot
.20952 .43039 Mdot
.21429 .44428 Mdot
.21905 .49871 Mdot
.22381 .44598 Mdot
.22857 .43728 Mdot
.23333 .48003 Mdot
.2381 .43534 Mdot
.24286 .43503 Mdot
.24762 .46274 Mdot
.25238 .47881 Mdot
.25714 .47982 Mdot
.2619 .44123 Mdot
.26667 .44852 Mdot
.27143 .46195 Mdot
.27619 .43595 Mdot
.28095 .43091 Mdot
.28571 .45355 Mdot
.29048 .49518 Mdot
.29524 .45014 Mdot
.3 .39422 Mdot
.30476 .41678 Mdot
.30952 .48376 Mdot
.31429 .49706 Mdot
.31905 .375 Mdot
.32381 .43717 Mdot
.32857 .43309 Mdot
.33333 .39258 Mdot
.3381 .44237 Mdot
.34286 .45635 Mdot
.34762 .48872 Mdot
.35238 .43059 Mdot
.35714 .48283 Mdot
.3619 .40756 Mdot
.36667 .47793 Mdot
.37143 .39259 Mdot
.37619 .43643 Mdot
.38095 .38538 Mdot
.38571 .4376 Mdot
.39048 .4413 Mdot
.39524 .44636 Mdot
.4 .45262 Mdot
.40476 .3697 Mdot
.40952 .47558 Mdot
.41429 .50236 Mdot
.41905 .42991 Mdot
.42381 .49124 Mdot
.42857 .52072 Mdot
.43333 .46091 Mdot
.4381 .45252 Mdot
.44286 .43451 Mdot
.44762 .4342 Mdot
.45238 .43625 Mdot
.45714 .42632 Mdot
.4619 .44054 Mdot
.46667 .42879 Mdot
.47143 .47002 Mdot
.47619 .4041 Mdot
.48095 .46618 Mdot
.48571 .4654 Mdot
.49048 .44093 Mdot
.49524 .45876 Mdot
.5 .39716 Mdot
.50476 .4182 Mdot
.50952 .39015 Mdot
.51429 .41322 Mdot
.51905 .41247 Mdot
.52381 .41006 Mdot
.52857 .46951 Mdot
.53333 .43401 Mdot
.5381 .48387 Mdot
.54286 .43254 Mdot
.54762 .45353 Mdot
.55238 .47816 Mdot
.55714 .44862 Mdot
.5619 .4743 Mdot
.56667 .42767 Mdot
.57143 .4453 Mdot
.57619 .46244 Mdot
.58095 .46822 Mdot
.58571 .41496 Mdot
.59048 .46488 Mdot
.59524 .46664 Mdot
.6 .46949 Mdot
.60476 .467 Mdot
.60952 .44166 Mdot
.61429 .43816 Mdot
.61905 .4172 Mdot
.62381 .44741 Mdot
.62857 .42548 Mdot
.63333 .45775 Mdot
.6381 .43417 Mdot
.64286 .41226 Mdot
.64762 .39432 Mdot
.65238 .44384 Mdot
.65714 .37346 Mdot
.6619 .41166 Mdot
.66667 .48427 Mdot
.67143 .43734 Mdot
.67619 .40154 Mdot
.68095 .36796 Mdot
.68571 .44436 Mdot
.69048 .43797 Mdot
.69524 .48734 Mdot
.7 .49743 Mdot
.70476 .44266 Mdot
.70952 .44466 Mdot
.71429 .43271 Mdot
.71905 .43072 Mdot
.72381 .45011 Mdot
.72857 .47365 Mdot
.73333 .45693 Mdot
.7381 .45658 Mdot
.74286 .43233 Mdot
.74762 .43585 Mdot
.75238 .4356 Mdot
.75714 .43649 Mdot
.7619 .43023 Mdot
.76667 .42208 Mdot
.77143 .43371 Mdot
.77619 .44159 Mdot
.78095 .49619 Mdot
.78571 .46822 Mdot
.79048 .46101 Mdot
.79524 .47001 Mdot
.8 .4189 Mdot
.80476 .4747 Mdot
.80952 .48289 Mdot
.81429 .46775 Mdot
.81905 .40422 Mdot
.82381 .47123 Mdot
.82857 .4576 Mdot
.83333 .46232 Mdot
.8381 .44636 Mdot
.84286 .44974 Mdot
.84762 .50196 Mdot
.85238 .42082 Mdot
.85714 .41465 Mdot
.8619 .45609 Mdot
.86667 .44966 Mdot
.87143 .41056 Mdot
.87619 .41637 Mdot
.88095 .44027 Mdot
.88571 .4495 Mdot
.89048 .47337 Mdot
.89524 .45313 Mdot
.9 .42519 Mdot
.90476 .4953 Mdot
.90952 .40751 Mdot
.91429 .41157 Mdot
.91905 .41968 Mdot
.92381 .42022 Mdot
.92857 .52129 Mdot
.93333 .43141 Mdot
.9381 .44437 Mdot
.94286 .4657 Mdot
.94762 .43006 Mdot
.95238 .45165 Mdot
.95714 .45058 Mdot
.9619 .50294 Mdot
.96667 .43784 Mdot
.97143 .45376 Mdot
.97619 .3983 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44498 Mdot
.03333 .43571 Mdot
.0381 .44366 Mdot
.04286 .47702 Mdot
.04762 .43726 Mdot
.05238 .39619 Mdot
.05714 .49884 Mdot
.0619 .46143 Mdot
.06667 .4098 Mdot
.07143 .45576 Mdot
.07619 .419 Mdot
.08095 .46523 Mdot
.08571 .42712 Mdot
.09048 .48926 Mdot
.09524 .4616 Mdot
.1 .4382 Mdot
.10476 .45852 Mdot
.10952 .44759 Mdot
.11429 .44037 Mdot
.11905 .44836 Mdot
.12381 .44042 Mdot
.12857 .46761 Mdot
.13333 .5219 Mdot
.1381 .55102 Mdot
.14286 .40368 Mdot
.14762 .47239 Mdot
.15238 .44093 Mdot
.15714 .43814 Mdot
.1619 .43968 Mdot
.16667 .46097 Mdot
.17143 .42885 Mdot
.17619 .42441 Mdot
.18095 .46892 Mdot
.18571 .49597 Mdot
.19048 .41479 Mdot
.19524 .4465 Mdot
.2 .39479 Mdot
.20476 .48033 Mdot
.20952 .42191 Mdot
.21429 .42531 Mdot
.21905 .48096 Mdot
.22381 .45859 Mdot
.22857 .42402 Mdot
.23333 .4709 Mdot
.2381 .44553 Mdot
.24286 .42039 Mdot
.24762 .48125 Mdot
.25238 .46584 Mdot
.25714 .47529 Mdot
.2619 .44577 Mdot
.26667 .45645 Mdot
.27143 .44702 Mdot
.27619 .43339 Mdot
.28095 .42277 Mdot
.28571 .44167 Mdot
.29048 .48636 Mdot
.29524 .43404 Mdot
.3 .38304 Mdot
.30476 .41835 Mdot
.30952 .47734 Mdot
.31429 .49386 Mdot
.31905 .36621 Mdot
.32381 .43294 Mdot
.32857 .41722 Mdot
.33333 .39954 Mdot
.3381 .43488 Mdot
.34286 .43921 Mdot
.34762 .47314 Mdot
.35238 .44122 Mdot
.35714 .475 Mdot
.3619 .41318 Mdot
.36667 .47664 Mdot
.37143 .40994 Mdot
.37619 .42294 Mdot
.38095 .37061 Mdot
.38571 .45657 Mdot
.39048 .42304 Mdot
.39524 .4632 Mdot
.4 .44344 Mdot
.40476 .35464 Mdot
.40952 .46819 Mdot
.41429 .50676 Mdot
.41905 .42558 Mdot
.42381 .47483 Mdot
.42857 .50873 Mdot
.43333 .44869 Mdot
.4381 .45736 Mdot
.44286 .44587 Mdot
.44762 .4415 Mdot
.45238 .44154 Mdot
.45714 .41177 Mdot
.4619 .43063 Mdot
.46667 .42957 Mdot
.47143 .46107 Mdot
.47619 .40869 Mdot
.48095 .45563 Mdot
.48571 .48183 Mdot
.49048 .44948 Mdot
.49524 .44644 Mdot
.5 .39469 Mdot
.50476 .39974 Mdot
.50952 .37775 Mdot
.51429 .41038 Mdot
.51905 .40474 Mdot
.52381 .41368 Mdot
.52857 .46965 Mdot
.53333 .43741 Mdot
.5381 .46557 Mdot
.54286 .42588 Mdot
.54762 .46653 Mdot
.55238 .4614 Mdot
.55714 .45312 Mdot
.5619 .47058 Mdot
.56667 .43239 Mdot
.57143 .43562 Mdot
.57619 .44554 Mdot
.58095 .48249 Mdot
.58571 .39673 Mdot
.59048 .48297 Mdot
.59524 .46887 Mdot
.6 .4623 Mdot
.60476 .46252 Mdot
.60952 .43005 Mdot
.61429 .44292 Mdot
.61905 .40428 Mdot
.62381 .45704 Mdot
.62857 .41011 Mdot
.63333 .44216 Mdot
.6381 .42023 Mdot
.64286 .40862 Mdot
.64762 .40416 Mdot
.65238 .43402 Mdot
.65714 .37459 Mdot
.6619 .41357 Mdot
.66667 .46754 Mdot
.67143 .44301 Mdot
.67619 .38373 Mdot
.68095 .35856 Mdot
.68571 .45377 Mdot
.69048 .45614 Mdot
.69524 .49562 Mdot
.7 .4924 Mdot
.70476 .42465 Mdot
.70952 .43581 Mdot
.71429 .43039 Mdot
.71905 .42115 Mdot
.72381 .43973 Mdot
.72857 .46043 Mdot
.73333 .47058 Mdot
.7381 .44186 Mdot
.74286 .4199 Mdot
.74762 .42559 Mdot
.75238 .43816 Mdot
.75714 .43103 Mdot
.7619 .42049 Mdot
.76667 .4285 Mdot
.77143 .42617 Mdot
.77619 .45678 Mdot
.78095 .49204 Mdot
.78571 .47491 Mdot
.79048 .45047 Mdot
.79524 .47842 Mdot
.8 .4216 Mdot
.80476 .48069 Mdot
.80952 .4845 Mdot
.81429 .47037 Mdot
.81905 .38704 Mdot
.82381 .46253 Mdot
.82857 .44204 Mdot
.83333 .44946 Mdot
.8381 .44076 Mdot
.84286 .44389 Mdot
.84762 .486 Mdot
.85238 .43632 Mdot
.85714 .42674 Mdot
.8619 .44628 Mdot
.86667 .43984 Mdot
.87143 .40335 Mdot
.87619 .42724 Mdot
.88095 .4584 Mdot
.88571 .43779 Mdot
.89048 .47725 Mdot
.89524 .44664 Mdot
.9 .44026 Mdot
.90476 .4776 Mdot
.90952 .41218 Mdot
.91429 .39598 Mdot
.91905 .43002 Mdot
.92381 .40193 Mdot
.92857 .52346 Mdot
.93333 .43181 Mdot
.9381 .42811 Mdot
.94286 .47447 Mdot
.94762 .42 Mdot
.95238 .44334 Mdot
.95714 .45485 Mdot
.9619 .5095 Mdot
.96667 .43323 Mdot
.97143 .45624 Mdot
.97619 .38552 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .45045 Mdot
.03333 .4254 Mdot
.0381 .44203 Mdot
.04286 .49071 Mdot
.04762 .42696 Mdot
.05238 .40052 Mdot
.05714 .48074 Mdot
.0619 .44296 Mdot
.06667 .39554 Mdot
.07143 .45294 Mdot
.07619 .41123 Mdot
.08095 .449 Mdot
.08571 .42813 Mdot
.09048 .47496 Mdot
.09524 .46813 Mdot
.1 .44362 Mdot
.10476 .44315 Mdot
.10952 .42886 Mdot
.11429 .44943 Mdot
.11905 .43558 Mdot
.12381 .45064 Mdot
.12857 .4747 Mdot
.13333 .53622 Mdot
.1381 .54831 Mdot
.14286 .38884 Mdot
.14762 .47684 Mdot
.15238 .42362 Mdot
.15714 .43303 Mdot
.1619 .43379 Mdot
.16667 .45214 Mdot
.17143 .40962 Mdot
.17619 .41369 Mdot
.18095 .45028 Mdot
.18571 .48848 Mdot
.19048 .42781 Mdot
.19524 .4619 Mdot
.2 .39649 Mdot
.20476 .46441 Mdot
.20952 .41153 Mdot
.21429 .41411 Mdot
.21905 .47885 Mdot
.22381 .44458 Mdot
.22857 .41876 Mdot
.23333 .46002 Mdot
.2381 .44394 Mdot
.24286 .42592 Mdot
.24762 .49742 Mdot
.25238 .46383 Mdot
.25714 .47178 Mdot
.2619 .43683 Mdot
.26667 .45016 Mdot
.27143 .45532 Mdot
.27619 .43012 Mdot
.28095 .40677 Mdot
.28571 .45683 Mdot
.29048 .48458 Mdot
.29524 .44496 Mdot
.3 .36655 Mdot
.30476 .40802 Mdot
.30952 .49122 Mdot
.31429 .49508 Mdot
.31905 .37102 Mdot
.32381 .41753 Mdot
.32857 .42143 Mdot
.33333 .40095 Mdot
.3381 .42054 Mdot
.34286 .44234 Mdot
.34762 .45769 Mdot
.35238 .44895 Mdot
.35714 .47479 Mdot
.3619 .40503 Mdot
.36667 .48091 Mdot
.37143 .39232 Mdot
.37619 .40841 Mdot
.38095 .37223 Mdot
.38571 .45565 Mdot
.39048 .40845 Mdot
.39524 .47893 Mdot
.4 .4413 Mdot
.40476 .35163 Mdot
.40952 .45349 Mdot
.41429 .51665 Mdot
.41905 .42023 Mdot
.42381 .47768 Mdot
.42857 .50389 Mdot
.43333 .44898 Mdot
.4381 .46826 Mdot
.44286 .46041 Mdot
.44762 .4479 Mdot
.45238 .42585 Mdot
.45714 .39802 Mdot
.4619 .41762 Mdot
.46667 .42343 Mdot
.47143 .45613 Mdot
.47619 .42161 Mdot
.48095 .45091 Mdot
.48571 .4655 Mdot
.49048 .4411 Mdot
.49524 .43531 Mdot
.5 .37563 Mdot
.50476 .39052 Mdot
.50952 .36762 Mdot
.51429 .41157 Mdot
.51905 .41923 Mdot
.52381 .41569 Mdot
.52857 .45242 Mdot
.53333 .42401 Mdot
.5381 .44997 Mdot
.54286 .41969 Mdot
.54762 .45664 Mdot
.55238 .44374 Mdot
.55714 .46167 Mdot
.5619 .48466 Mdot
.56667 .4258 Mdot
.57143 .44108 Mdot
.57619 .44434 Mdot
.58095 .46325 Mdot
.58571 .38018 Mdot
.59048 .4726 Mdot
.59524 .45484 Mdot
.6 .46977 Mdot
.60476 .44746 Mdot
.60952 .44057 Mdot
.61429 .44647 Mdot
.61905 .4081 Mdot
.62381 .47081 Mdot
.62857 .39137 Mdot
.63333 .43704 Mdot
.6381 .43228 Mdot
.64286 .39353 Mdot
.64762 .38629 Mdot
.65238 .43054 Mdot
.65714 .35812 Mdot
.6619 .42725 Mdot
.66667 .47263 Mdot
.67143 .44289 Mdot
.67619 .3709 Mdot
.68095 .36219 Mdot
.68571 .44148 Mdot
.69048 .45159 Mdot
.69524 .48531 Mdot
.7 .48456 Mdot
.70476 .42744 Mdot
.70952 .43359 Mdot
.71429 .4352 Mdot
.71905 .44025 Mdot
.72381 .44692 Mdot
.72857 .46545 Mdot
.73333 .4635 Mdot
.7381 .45468 Mdot
.74286 .40118 Mdot
.74762 .42787 Mdot
.75238 .4331 Mdot
.75714 .41433 Mdot
.7619 .43172 Mdot
.76667 .41467 Mdot
.77143 .42232 Mdot
.77619 .45952 Mdot
.78095 .4888 Mdot
.78571 .4832 Mdot
.79048 .45576 Mdot
.79524 .48384 Mdot
.8 .41867 Mdot
.80476 .49992 Mdot
.80952 .49763 Mdot
.81429 .47268 Mdot
.81905 .37491 Mdot
.82381 .45276 Mdot
.82857 .45833 Mdot
.83333 .4627 Mdot
.8381 .4239 Mdot
.84286 .43716 Mdot
.84762 .50325 Mdot
.85238 .42821 Mdot
.85714 .42494 Mdot
.8619 .43565 Mdot
.86667 .43351 Mdot
.87143 .40409 Mdot
.87619 .4272 Mdot
.88095 .47279 Mdot
.88571 .45526 Mdot
.89048 .46162 Mdot
.89524 .44188 Mdot
.9 .42262 Mdot
.90476 .46249 Mdot
.90952 .40245 Mdot
.91429 .37763 Mdot
.91905 .42292 Mdot
.92381 .38651 Mdot
.92857 .52938 Mdot
.93333 .41626 Mdot
.9381 .41706 Mdot
.94286 .48862 Mdot
.94762 .42222 Mdot
.95238 .43738 Mdot
.95714 .44113 Mdot
.9619 .49065 Mdot
.96667 .42422 Mdot
.97143 .45221 Mdot
.97619 .37824 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .43482 Mdot
.03333 .40614 Mdot
.0381 .45386 Mdot
.04286 .47773 Mdot
.04762 .42666 Mdot
.05238 .38984 Mdot
.05714 .4637 Mdot
.0619 .44998 Mdot
.06667 .38753 Mdot
.07143 .44168 Mdot
.07619 .42748 Mdot
.08095 .45703 Mdot
.08571 .41387 Mdot
.09048 .49269 Mdot
.09524 .45447 Mdot
.1 .42878 Mdot
.10476 .42538 Mdot
.10952 .44278 Mdot
.11429 .466 Mdot
.11905 .43531 Mdot
.12381 .43747 Mdot
.12857 .4627 Mdot
.13333 .52071 Mdot
.1381 .52919 Mdot
.14286 .36965 Mdot
.14762 .49383 Mdot
.15238 .41189 Mdot
.15714 .41484 Mdot
.1619 .42061 Mdot
.16667 .45208 Mdot
.17143 .40108 Mdot
.17619 .41579 Mdot
.18095 .46301 Mdot
.18571 .47719 Mdot
.19048 .43567 Mdot
.19524 .46104 Mdot
.2 .3852 Mdot
.20476 .46112 Mdot
.20952 .42321 Mdot
.21429 .39498 Mdot
.21905 .47765 Mdot
.22381 .45786 Mdot
.22857 .41485 Mdot
.23333 .47672 Mdot
.2381 .44591 Mdot
.24286 .4152 Mdot
.24762 .4787 Mdot
.25238 .46833 Mdot
.25714 .45541 Mdot
.2619 .44354 Mdot
.26667 .43788 Mdot
.27143 .4548 Mdot
.27619 .41364 Mdot
.28095 .42243 Mdot
.28571 .44847 Mdot
.29048 .48519 Mdot
.29524 .45977 Mdot
.3 .37982 Mdot
.30476 .40111 Mdot
.30952 .49679 Mdot
.31429 .50309 Mdot
.31905 .36289 Mdot
.32381 .40963 Mdot
.32857 .43489 Mdot
.33333 .41624 Mdot
.3381 .41613 Mdot
.34286 .45379 Mdot
.34762 .45977 Mdot
.35238 .43626 Mdot
.35714 .47421 Mdot
.3619 .41977 Mdot
.36667 .49268 Mdot
.37143 .40315 Mdot
.37619 .42761 Mdot
.38095 .36906 Mdot
.38571 .44361 Mdot
.39048 .40841 Mdot
.39524 .48692 Mdot
.4 .4441 Mdot
.40476 .36038 Mdot
.40952 .44563 Mdot
.41429 .50416 Mdot
.41905 .40601 Mdot
.42381 .45929 Mdot
.42857 .49433 Mdot
.43333 .46147 Mdot
.4381 .45618 Mdot
.44286 .45539 Mdot
.44762 .45905 Mdot
.45238 .4221 Mdot
.45714 .38859 Mdot
.4619 .40435 Mdot
.46667 .43182 Mdot
.47143 .46592 Mdot
.47619 .42132 Mdot
.48095 .43654 Mdot
.48571 .45743 Mdot
.49048 .42524 Mdot
.49524 .43508 Mdot
.5 .39161 Mdot
.50476 .38109 Mdot
.50952 .3628 Mdot
.51429 .39819 Mdot
.51905 .42228 Mdot
.52381 .43126 Mdot
.52857 .44546 Mdot
.53333 .431 Mdot
.5381 .4428 Mdot
.54286 .4093 Mdot
.54762 .4458 Mdot
.55238 .4505 Mdot
.55714 .45374 Mdot
.5619 .49059 Mdot
.56667 .42648 Mdot
.57143 .42559 Mdot
.57619 .4296 Mdot
.58095 .44519 Mdot
.58571 .38119 Mdot
.59048 .45668 Mdot
.59524 .44596 Mdot
.6 .46103 Mdot
.60476 .44873 Mdot
.60952 .45275 Mdot
.61429 .44272 Mdot
.61905 .40768 Mdot
.62381 .45151 Mdot
.62857 .37915 Mdot
.63333 .42736 Mdot
.6381 .42302 Mdot
.64286 .38738 Mdot
.64762 .38569 Mdot
.65238 .42432 Mdot
.65714 .35696 Mdot
.6619 .44013 Mdot
.66667 .48878 Mdot
.67143 .42843 Mdot
.67619 .3676 Mdot
.68095 .36281 Mdot
.68571 .43919 Mdot
.69048 .46723 Mdot
.69524 .48726 Mdot
.7 .46616 Mdot
.70476 .41928 Mdot
.70952 .43348 Mdot
.71429 .429 Mdot
.71905 .43089 Mdot
.72381 .43772 Mdot
.72857 .44634 Mdot
.73333 .48003 Mdot
.7381 .46906 Mdot
.74286 .38791 Mdot
.74762 .41374 Mdot
.75238 .4519 Mdot
.75714 .4192 Mdot
.7619 .42181 Mdot
.76667 .40957 Mdot
.77143 .40775 Mdot
.77619 .45518 Mdot
.78095 .50367 Mdot
.78571 .50068 Mdot
.79048 .45266 Mdot
.79524 .48589 Mdot
.8 .4073 Mdot
.80476 .51381 Mdot
.80952 .51249 Mdot
.81429 .45598 Mdot
.81905 .37886 Mdot
.82381 .44394 Mdot
.82857 .45592 Mdot
.83333 .4802 Mdot
.8381 .40486 Mdot
.84286 .45497 Mdot
.84762 .49581 Mdot
.85238 .41139 Mdot
.85714 .41341 Mdot
.8619 .43778 Mdot
.86667 .41916 Mdot
.87143 .3887 Mdot
.87619 .4332 Mdot
.88095 .48718 Mdot
.88571 .43848 Mdot
.89048 .48024 Mdot
.89524 .43581 Mdot
.9 .43552 Mdot
.90476 .45748 Mdot
.90952 .39294 Mdot
.91429 .37425 Mdot
.91905 .42008 Mdot
.92381 .40401 Mdot
.92857 .52535 Mdot
.93333 .41275 Mdot
.9381 .41119 Mdot
.94286 .50396 Mdot
.94762 .41184 Mdot
.95238 .42094 Mdot
.95714 .45484 Mdot
.9619 .48111 Mdot
.96667 .4098 Mdot
.97143 .4551 Mdot
.97619 .37004 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .42816 Mdot
.03333 .40685 Mdot
.0381 .44691 Mdot
.04286 .46444 Mdot
.04762 .41177 Mdot
.05238 .3713 Mdot
.05714 .46241 Mdot
.0619 .43195 Mdot
.06667 .37787 Mdot
.07143 .44785 Mdot
.07619 .42166 Mdot
.08095 .45038 Mdot
.08571 .39585 Mdot
.09048 .48344 Mdot
.09524 .44298 Mdot
.1 .44223 Mdot
.10476 .41227 Mdot
.10952 .45079 Mdot
.11429 .46177 Mdot
.11905 .43468 Mdot
.12381 .44151 Mdot
.12857 .44734 Mdot
.13333 .51303 Mdot
.1381 .51643 Mdot
.14286 .36733 Mdot
.14762 .50994 Mdot
.15238 .39723 Mdot
.15714 .42309 Mdot
.1619 .42827 Mdot
.16667 .43471 Mdot
.17143 .40366 Mdot
.17619 .40787 Mdot
.18095 .47422 Mdot
.18571 .47814 Mdot
.19048 .45014 Mdot
.19524 .46932 Mdot
.2 .37365 Mdot
.20476 .47783 Mdot
.20952 .43019 Mdot
.21429 .40225 Mdot
.21905 .46898 Mdot
.22381 .45336 Mdot
.22857 .41054 Mdot
.23333 .47916 Mdot
.2381 .4299 Mdot
.24286 .40945 Mdot
.24762 .49159 Mdot
.25238 .48663 Mdot
.25714 .44427 Mdot
.2619 .43461 Mdot
.26667 .44162 Mdot
.27143 .44517 Mdot
.27619 .39952 Mdot
.28095 .40822 Mdot
.28571 .44472 Mdot
.29048 .46802 Mdot
.29524 .47084 Mdot
.3 .36922 Mdot
.30476 .40089 Mdot
.30952 .49749 Mdot
.31429 .4873 Mdot
.31905 .34619 Mdot
.32381 .40107 Mdot
.32857 .41632 Mdot
.33333 .40256 Mdot
.3381 .41101 Mdot
.34286 .43487 Mdot
.34762 .46482 Mdot
.35238 .43938 Mdot
.35714 .45843 Mdot
.3619 .40519 Mdot
.36667 .50675 Mdot
.37143 .39202 Mdot
.37619 .41819 Mdot
.38095 .35703 Mdot
.38571 .43963 Mdot
.39048 .40981 Mdot
.39524 .48969 Mdot
.4 .45622 Mdot
.40476 .36326 Mdot
.40952 .43545 Mdot
.41429 .49306 Mdot
.41905 .40409 Mdot
.42381 .45736 Mdot
.42857 .49006 Mdot
.43333 .44664 Mdot
.4381 .43963 Mdot
.44286 .441 Mdot
.44762 .43999 Mdot
.45238 .41989 Mdot
.45714 .3968 Mdot
.4619 .39446 Mdot
.46667 .44962 Mdot
.47143 .47478 Mdot
.47619 .4123 Mdot
.48095 .41785 Mdot
.48571 .4682 Mdot
.49048 .41021 Mdot
.49524 .43269 Mdot
.5 .38723 Mdot
.50476 .39219 Mdot
.50952 .37428 Mdot
.51429 .40368 Mdot
.51905 .42546 Mdot
.52381 .41818 Mdot
.52857 .43574 Mdot
.53333 .43458 Mdot
.5381 .42385 Mdot
.54286 .41972 Mdot
.54762 .42791 Mdot
.55238 .44002 Mdot
.55714 .45997 Mdot
.5619 .47806 Mdot
.56667 .41076 Mdot
.57143 .41621 Mdot
.57619 .43993 Mdot
.58095 .45332 Mdot
.58571 .38941 Mdot
.59048 .45831 Mdot
.59524 .43187 Mdot
.6 .4487 Mdot
.60476 .4331 Mdot
.60952 .43872 Mdot
.61429 .4493 Mdot
.61905 .39642 Mdot
.62381 .44584 Mdot
.62857 .36848 Mdot
.63333 .42716 Mdot
.6381 .43091 Mdot
.64286 .37329 Mdot
.64762 .38159 Mdot
.65238 .43115 Mdot
.65714 .34207 Mdot
.6619 .43159 Mdot
.66667 .50782 Mdot
.67143 .44406 Mdot
.67619 .35302 Mdot
.68095 .37891 Mdot
.68571 .45168 Mdot
.69048 .45988 Mdot
.69524 .49362 Mdot
.7 .45793 Mdot
.70476 .4009 Mdot
.70952 .4428 Mdot
.71429 .41363 Mdot
.71905 .43559 Mdot
.72381 .42235 Mdot
.72857 .44602 Mdot
.73333 .47139 Mdot
.7381 .4571 Mdot
.74286 .39518 Mdot
.74762 .39848 Mdot
.75238 .46214 Mdot
.75714 .40758 Mdot
.7619 .4112 Mdot
.76667 .40955 Mdot
.77143 .39114 Mdot
.77619 .46122 Mdot
.78095 .52035 Mdot
.78571 .51701 Mdot
.79048 .43618 Mdot
.79524 .48159 Mdot
.8 .396 Mdot
.80476 .50714 Mdot
.80952 .5035 Mdot
.81429 .47204 Mdot
.81905 .38278 Mdot
.82381 .43516 Mdot
.82857 .45042 Mdot
.83333 .49749 Mdot
.8381 .3982 Mdot
.84286 .44051 Mdot
.84762 .49532 Mdot
.85238 .39407 Mdot
.85714 .42911 Mdot
.8619 .43932 Mdot
.86667 .41859 Mdot
.87143 .37073 Mdot
.87619 .4173 Mdot
.88095 .48038 Mdot
.88571 .44715 Mdot
.89048 .46715 Mdot
.89524 .42585 Mdot
.9 .43946 Mdot
.90476 .44608 Mdot
.90952 .38504 Mdot
.91429 .36714 Mdot
.91905 .43616 Mdot
.92381 .39386 Mdot
.92857 .52658 Mdot
.93333 .41728 Mdot
.9381 .39676 Mdot
.94286 .4931 Mdot
.94762 .41474 Mdot
.95238 .42529 Mdot
.95714 .4558 Mdot
.9619 .49654 Mdot
.96667 .39667 Mdot
.97143 .46076 Mdot
.97619 .37471 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .4092 Mdot
.03333 .40056 Mdot
.0381 .43209 Mdot
.04286 .45389 Mdot
.04762 .42085 Mdot
.05238 .37447 Mdot
.05714 .44722 Mdot
.0619 .42205 Mdot
.06667 .39029 Mdot
.07143 .42862 Mdot
.07619 .42036 Mdot
.08095 .43505 Mdot
.08571 .38879 Mdot
.09048 .46825 Mdot
.09524 .4398 Mdot
.1 .45937 Mdot
.10476 .4296 Mdot
.10952 .4684 Mdot
.11429 .46221 Mdot
.11905 .41566 Mdot
.12381 .43473 Mdot
.12857 .42998 Mdot
.13333 .5312 Mdot
.1381 .52209 Mdot
.14286 .35536 Mdot
.14762 .49648 Mdot
.15238 .38952 Mdot
.15714 .40466 Mdot
.1619 .41472 Mdot
.16667 .4499 Mdot
.17143 .39639 Mdot
.17619 .39158 Mdot
.18095 .46489 Mdot
.18571 .49587 Mdot
.19048 .43792 Mdot
.19524 .45522 Mdot
.2 .36061 Mdot
.20476 .4668 Mdot
.20952 .43898 Mdot
.21429 .40845 Mdot
.21905 .47495 Mdot
.22381 .46928 Mdot
.22857 .42213 Mdot
.23333 .46146 Mdot
.2381 .43013 Mdot
.24286 .3949 Mdot
.24762 .50695 Mdot
.25238 .48172 Mdot
.25714 .43908 Mdot
.2619 .41682 Mdot
.26667 .44526 Mdot
.27143 .45029 Mdot
.27619 .40858 Mdot
.28095 .40544 Mdot
.28571 .46045 Mdot
.29048 .45113 Mdot
.29524 .46807 Mdot
.3 .37585 Mdot
.30476 .38851 Mdot
.30952 .50827 Mdot
.31429 .47997 Mdot
.31905 .33151 Mdot
.32381 .41358 Mdot
.32857 .39978 Mdot
.33333 .39394 Mdot
.3381 .40619 Mdot
.34286 .42441 Mdot
.34762 .4551 Mdot
.35238 .44707 Mdot
.35714 .44567 Mdot
.3619 .38686 Mdot
.36667 .49467 Mdot
.37143 .37601 Mdot
.37619 .42349 Mdot
.38095 .33896 Mdot
.38571 .43961 Mdot
.39048 .40886 Mdot
.39524 .472 Mdot
.4 .43803 Mdot
.40476 .36078 Mdot
.40952 .45261 Mdot
.41429 .50665 Mdot
.41905 .38777 Mdot
.42381 .46983 Mdot
.42857 .4743 Mdot
.43333 .46154 Mdot
.4381 .43452 Mdot
.44286 .43339 Mdot
.44762 .42482 Mdot
.45238 .43207 Mdot
.45714 .40166 Mdot
.4619 .377 Mdot
.46667 .4309 Mdot
.47143 .46971 Mdot
.47619 .40826 Mdot
.48095 .4217 Mdot
.48571 .47942 Mdot
.49048 .41718 Mdot
.49524 .42321 Mdot
.5 .40032 Mdot
.50476 .37294 Mdot
.50952 .36191 Mdot
.51429 .41781 Mdot
.51905 .4244 Mdot
.52381 .41113 Mdot
.52857 .43613 Mdot
.53333 .44206 Mdot
.5381 .43446 Mdot
.54286 .42885 Mdot
.54762 .43751 Mdot
.55238 .4466 Mdot
.55714 .45487 Mdot
.5619 .48984 Mdot
.56667 .40955 Mdot
.57143 .40951 Mdot
.57619 .43867 Mdot
.58095 .43893 Mdot
.58571 .40314 Mdot
.59048 .45104 Mdot
.59524 .44029 Mdot
.6 .44394 Mdot
.60476 .43637 Mdot
.60952 .43736 Mdot
.61429 .46439 Mdot
.61905 .37804 Mdot
.62381 .44449 Mdot
.62857 .3803 Mdot
.63333 .43035 Mdot
.6381 .43275 Mdot
.64286 .37241 Mdot
.64762 .39629 Mdot
.65238 .43418 Mdot
.65714 .32444 Mdot
.6619 .42093 Mdot
.66667 .49678 Mdot
.67143 .42984 Mdot
.67619 .33575 Mdot
.68095 .37785 Mdot
.68571 .44782 Mdot
.69048 .44881 Mdot
.69524 .50793 Mdot
.7 .44207 Mdot
.70476 .41692 Mdot
.70952 .45039 Mdot
.71429 .42152 Mdot
.71905 .42681 Mdot
.72381 .42063 Mdot
.72857 .45236 Mdot
.73333 .46612 Mdot
.7381 .463 Mdot
.74286 .40324 Mdot
.74762 .38795 Mdot
.75238 .47267 Mdot
.75714 .39639 Mdot
.7619 .40632 Mdot
.76667 .4061 Mdot
.77143 .38891 Mdot
.77619 .47951 Mdot
.78095 .51172 Mdot
.78571 .51228 Mdot
.79048 .4496 Mdot
.79524 .48098 Mdot
.8 .40727 Mdot
.80476 .51085 Mdot
.80952 .48838 Mdot
.81429 .45933 Mdot
.81905 .40123 Mdot
.82381 .41863 Mdot
.82857 .4373 Mdot
.83333 .47846 Mdot
.8381 .38379 Mdot
.84286 .42767 Mdot
.84762 .48739 Mdot
.85238 .37484 Mdot
.85714 .42942 Mdot
.8619 .43705 Mdot
.86667 .4271 Mdot
.87143 .38699 Mdot
.87619 .4071 Mdot
.88095 .4758 Mdot
.88571 .4447 Mdot
.89048 .48362 Mdot
.89524 .41664 Mdot
.9 .42751 Mdot
.90476 .43549 Mdot
.90952 .4043 Mdot
.91429 .38218 Mdot
.91905 .42398 Mdot
.92381 .39964 Mdot
.92857 .53051 Mdot
.93333 .40648 Mdot
.9381 .38977 Mdot
.94286 .47972 Mdot
.94762 .40638 Mdot
.95238 .436 Mdot
.95714 .44876 Mdot
.9619 .50175 Mdot
.96667 .38757 Mdot
.97143 .45265 Mdot
.97619 .36292 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39692 Mdot
.03333 .39032 Mdot
.0381 .43337 Mdot
.04286 .43917 Mdot
.04762 .41626 Mdot
.05238 .37857 Mdot
.05714 .44314 Mdot
.0619 .41881 Mdot
.06667 .39912 Mdot
.07143 .41043 Mdot
.07619 .40616 Mdot
.08095 .4181 Mdot
.08571 .39983 Mdot
.09048 .48043 Mdot
.09524 .43695 Mdot
.1 .44759 Mdot
.10476 .4234 Mdot
.10952 .48008 Mdot
.11429 .4765 Mdot
.11905 .40466 Mdot
.12381 .45184 Mdot
.12857 .4438 Mdot
.13333 .53062 Mdot
.1381 .50619 Mdot
.14286 .36424 Mdot
.14762 .49687 Mdot
.15238 .39354 Mdot
.15714 .40528 Mdot
.1619 .40191 Mdot
.16667 .44197 Mdot
.17143 .41537 Mdot
.17619 .37866 Mdot
.18095 .47407 Mdot
.18571 .501 Mdot
.19048 .44388 Mdot
.19524 .44786 Mdot
.2 .37772 Mdot
.20476 .45798 Mdot
.20952 .42949 Mdot
.21429 .42002 Mdot
.21905 .46988 Mdot
.22381 .474 Mdot
.22857 .43807 Mdot
.23333 .46617 Mdot
.2381 .41139 Mdot
.24286 .39604 Mdot
.24762 .49273 Mdot
.25238 .4813 Mdot
.25714 .45269 Mdot
.2619 .41527 Mdot
.26667 .43058 Mdot
.27143 .46313 Mdot
.27619 .39039 Mdot
.28095 .42018 Mdot
.28571 .47338 Mdot
.29048 .43411 Mdot
.29524 .46041 Mdot
.3 .38781 Mdot
.30476 .39165 Mdot
.30952 .52293 Mdot
.31429 .47054 Mdot
.31905 .31723 Mdot
.32381 .40405 Mdot
.32857 .39445 Mdot
.33333 .38162 Mdot
.3381 .412 Mdot
.34286 .43226 Mdot
.34762 .4391 Mdot
.35238 .44876 Mdot
.35714 .42792 Mdot
.3619 .39028 Mdot
.36667 .50699 Mdot
.37143 .37809 Mdot
.37619 .41034 Mdot
.38095 .34944 Mdot
.38571 .44895 Mdot
.39048 .40249 Mdot
.39524 .45457 Mdot
.4 .44666 Mdot
.40476 .35249 Mdot
.40952 .44504 Mdot
.41429 .50131 Mdot
.41905 .37613 Mdot
.42381 .48037 Mdot
.42857 .48334 Mdot
.43333 .47101 Mdot
.4381 .44535 Mdot
.44286 .43845 Mdot
.44762 .43893 Mdot
.45238 .42118 Mdot
.45714 .39536 Mdot
.4619 .36131 Mdot
.46667 .42228 Mdot
.47143 .47542 Mdot
.47619 .39707 Mdot
.48095 .41986 Mdot
.48571 .47897 Mdot
.49048 .4303 Mdot
.49524 .43392 Mdot
.5 .38999 Mdot
.50476 .35439 Mdot
.50952 .35386 Mdot
.51429 .4086 Mdot
.51905 .41205 Mdot
.52381 .42722 Mdot
.52857 .44221 Mdot
.53333 .43895 Mdot
.5381 .42339 Mdot
.54286 .41156 Mdot
.54762 .42547 Mdot
.55238 .4325 Mdot
.55714 .47175 Mdot
.5619 .4727 Mdot
.56667 .42195 Mdot
.57143 .41043 Mdot
.57619 .43304 Mdot
.58095 .45531 Mdot
.58571 .40855 Mdot
.59048 .46014 Mdot
.59524 .44528 Mdot
.6 .43976 Mdot
.60476 .43274 Mdot
.60952 .43066 Mdot
.61429 .45962 Mdot
.61905 .39167 Mdot
.62381 .44264 Mdot
.62857 .36529 Mdot
.63333 .4288 Mdot
.6381 .44948 Mdot
.64286 .3637 Mdot
.64762 .39056 Mdot
.65238 .44483 Mdot
.65714 .34372 Mdot
.6619 .41695 Mdot
.66667 .49085 Mdot
.67143 .4225 Mdot
.67619 .35226 Mdot
.68095 .38738 Mdot
.68571 .46518 Mdot
.69048 .4535 Mdot
.69524 .51759 Mdot
.7 .43322 Mdot
.70476 .40038 Mdot
.70952 .44753 Mdot
.71429 .4294 Mdot
.71905 .42093 Mdot
.72381 .42981 Mdot
.72857 .44443 Mdot
.73333 .45638 Mdot
.7381 .4605 Mdot
.74286 .38937 Mdot
.74762 .37486 Mdot
.75238 .47148 Mdot
.75714 .38732 Mdot
.7619 .39005 Mdot
.76667 .40523 Mdot
.77143 .37011 Mdot
.77619 .48117 Mdot
.78095 .49264 Mdot
.78571 .51789 Mdot
.79048 .4624 Mdot
.79524 .48612 Mdot
.8 .38871 Mdot
.80476 .4954 Mdot
.80952 .48506 Mdot
.81429 .45979 Mdot
.81905 .39017 Mdot
.82381 .41152 Mdot
.82857 .44452 Mdot
.83333 .46352 Mdot
.8381 .37456 Mdot
.84286 .41425 Mdot
.84762 .49993 Mdot
.85238 .38662 Mdot
.85714 .41683 Mdot
.8619 .44192 Mdot
.86667 .44251 Mdot
.87143 .37578 Mdot
.87619 .39001 Mdot
.88095 .46133 Mdot
.88571 .45372 Mdot
.89048 .49572 Mdot
.89524 .39986 Mdot
.9 .44193 Mdot
.90476 .42781 Mdot
.90952 .38833 Mdot
.91429 .40074 Mdot
.91905 .40805 Mdot
.92381 .40507 Mdot
.92857 .5353 Mdot
.93333 .40286 Mdot
.9381 .37574 Mdot
.94286 .48839 Mdot
.94762 .39994 Mdot
.95238 .45455 Mdot
.95714 .43371 Mdot
.9619 .49586 Mdot
.96667 .38328 Mdot
.97143 .44656 Mdot
.97619 .36403 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39056 Mdot
.03333 .37841 Mdot
.0381 .42549 Mdot
.04286 .42972 Mdot
.04762 .43468 Mdot
.05238 .37562 Mdot
.05714 .43165 Mdot
.0619 .41473 Mdot
.06667 .38783 Mdot
.07143 .39819 Mdot
.07619 .41667 Mdot
.08095 .42771 Mdot
.08571 .38122 Mdot
.09048 .4915 Mdot
.09524 .44888 Mdot
.1 .42929 Mdot
.10476 .40678 Mdot
.10952 .48354 Mdot
.11429 .46079 Mdot
.11905 .41314 Mdot
.12381 .44678 Mdot
.12857 .43853 Mdot
.13333 .54267 Mdot
.1381 .4908 Mdot
.14286 .35499 Mdot
.14762 .48393 Mdot
.15238 .40635 Mdot
.15714 .4055 Mdot
.1619 .38999 Mdot
.16667 .44881 Mdot
.17143 .41632 Mdot
.17619 .38593 Mdot
.18095 .48672 Mdot
.18571 .51819 Mdot
.19048 .42896 Mdot
.19524 .45219 Mdot
.2 .39555 Mdot
.20476 .44386 Mdot
.20952 .41966 Mdot
.21429 .43283 Mdot
.21905 .48135 Mdot
.22381 .468 Mdot
.22857 .42758 Mdot
.23333 .47238 Mdot
.2381 .41996 Mdot
.24286 .38792 Mdot
.24762 .48399 Mdot
.25238 .47779 Mdot
.25714 .46381 Mdot
.2619 .39948 Mdot
.26667 .42394 Mdot
.27143 .45029 Mdot
.27619 .38271 Mdot
.28095 .43404 Mdot
.28571 .45563 Mdot
.29048 .43937 Mdot
.29524 .44405 Mdot
.3 .37284 Mdot
.30476 .40558 Mdot
.30952 .52081 Mdot
.31429 .46992 Mdot
.31905 .31156 Mdot
.32381 .38706 Mdot
.32857 .37568 Mdot
.33333 .37384 Mdot
.3381 .40381 Mdot
.34286 .41541 Mdot
.34762 .44945 Mdot
.35238 .43836 Mdot
.35714 .41407 Mdot
.3619 .40138 Mdot
.36667 .52352 Mdot
.37143 .36038 Mdot
.37619 .40237 Mdot
.38095 .35539 Mdot
.38571 .43813 Mdot
.39048 .39225 Mdot
.39524 .43886 Mdot
.4 .42958 Mdot
.40476 .34578 Mdot
.40952 .46267 Mdot
.41429 .48483 Mdot
.41905 .37352 Mdot
.42381 .47764 Mdot
.42857 .49339 Mdot
.43333 .45395 Mdot
.4381 .46459 Mdot
.44286 .43955 Mdot
.44762 .4417 Mdot
.45238 .40848 Mdot
.45714 .40164 Mdot
.4619 .3473 Mdot
.46667 .40313 Mdot
.47143 .45883 Mdot
.47619 .39212 Mdot
.48095 .40893 Mdot
.48571 .4846 Mdot
.49048 .4481 Mdot
.49524 .41938 Mdot
.5 .38926 Mdot
.50476 .36753 Mdot
.50952 .3649 Mdot
.51429 .41214 Mdot
.51905 .40905 Mdot
.52381 .44011 Mdot
.52857 .43388 Mdot
.53333 .45311 Mdot
.5381 .41112 Mdot
.54286 .41733 Mdot
.54762 .42341 Mdot
.55238 .42463 Mdot
.55714 .46483 Mdot
.5619 .47096 Mdot
.56667 .40325 Mdot
.57143 .4177 Mdot
.57619 .42257 Mdot
.58095 .44406 Mdot
.58571 .41642 Mdot
.59048 .45773 Mdot
.59524 .45313 Mdot
.6 .4281 Mdot
.60476 .41463 Mdot
.60952 .42627 Mdot
.61429 .4453 Mdot
.61905 .40518 Mdot
.62381 .4467 Mdot
.62857 .36301 Mdot
.63333 .42911 Mdot
.6381 .44227 Mdot
.64286 .35596 Mdot
.64762 .38899 Mdot
.65238 .44836 Mdot
.65714 .3275 Mdot
.6619 .42295 Mdot
.66667 .48338 Mdot
.67143 .40976 Mdot
.67619 .34722 Mdot
.68095 .37664 Mdot
.68571 .47824 Mdot
.69048 .45601 Mdot
.69524 .51248 Mdot
.7 .42532 Mdot
.70476 .38522 Mdot
.70952 .4463 Mdot
.71429 .42897 Mdot
.71905 .40682 Mdot
.72381 .41915 Mdot
.72857 .46136 Mdot
.73333 .46344 Mdot
.7381 .45716 Mdot
.74286 .3922 Mdot
.74762 .36733 Mdot
.75238 .47297 Mdot
.75714 .3757 Mdot
.7619 .38603 Mdot
.76667 .38998 Mdot
.77143 .3696 Mdot
.77619 .47567 Mdot
.78095 .48579 Mdot
.78571 .53237 Mdot
.79048 .45529 Mdot
.79524 .49831 Mdot
.8 .37205 Mdot
.80476 .4949 Mdot
.80952 .47476 Mdot
.81429 .4419 Mdot
.81905 .3867 Mdot
.82381 .41604 Mdot
.82857 .44579 Mdot
.83333 .45846 Mdot
.8381 .37357 Mdot
.84286 .40016 Mdot
.84762 .48092 Mdot
.85238 .3965 Mdot
.85714 .4175 Mdot
.8619 .42415 Mdot
.86667 .43492 Mdot
.87143 .38154 Mdot
.87619 .39595 Mdot
.88095 .45138 Mdot
.88571 .46721 Mdot
.89048 .47661 Mdot
.89524 .40772 Mdot
.9 .42565 Mdot
.90476 .41821 Mdot
.90952 .37214 Mdot
.91429 .4162 Mdot
.91905 .40528 Mdot
.92381 .40544 Mdot
.92857 .54861 Mdot
.93333 .41394 Mdot
.9381 .38574 Mdot
.94286 .46953 Mdot
.94762 .38149 Mdot
.95238 .46179 Mdot
.95714 .44172 Mdot
.9619 .47666 Mdot
.96667 .36904 Mdot
.97143 .43655 Mdot
.97619 .36641 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .37335 Mdot
.03333 .37601 Mdot
.0381 .43189 Mdot
.04286 .41141 Mdot
.04762 .4507 Mdot
.05238 .36321 Mdot
.05714 .41898 Mdot
.0619 .43404 Mdot
.06667 .38789 Mdot
.07143 .39985 Mdot
.07619 .41132 Mdot
.08095 .43083 Mdot
.08571 .37558 Mdot
.09048 .50179 Mdot
.09524 .43496 Mdot
.1 .41044 Mdot
.10476 .39764 Mdot
.10952 .46766 Mdot
.11429 .45363 Mdot
.11905 .39804 Mdot
.12381 .43012 Mdot
.12857 .4444 Mdot
.13333 .54958 Mdot
.1381 .48482 Mdot
.14286 .35463 Mdot
.14762 .49848 Mdot
.15238 .409 Mdot
.15714 .39444 Mdot
.1619 .40011 Mdot
.16667 .44191 Mdot
.17143 .41 Mdot
.17619 .39942 Mdot
.18095 .47099 Mdot
.18571 .51914 Mdot
.19048 .41422 Mdot
.19524 .4472 Mdot
.2 .39228 Mdot
.20476 .45935 Mdot
.20952 .40223 Mdot
.21429 .42302 Mdot
.21905 .47785 Mdot
.22381 .46575 Mdot
.22857 .43969 Mdot
.23333 .48649 Mdot
.2381 .43731 Mdot
.24286 .40444 Mdot
.24762 .49905 Mdot
.25238 .47207 Mdot
.25714 .44898 Mdot
.2619 .38264 Mdot
.26667 .4289 Mdot
.27143 .43112 Mdot
.27619 .37684 Mdot
.28095 .44642 Mdot
.28571 .44992 Mdot
.29048 .44022 Mdot
.29524 .43771 Mdot
.3 .37544 Mdot
.30476 .39352 Mdot
.30952 .51019 Mdot
.31429 .45341 Mdot
.31905 .29528 Mdot
.32381 .37867 Mdot
.32857 .36276 Mdot
.33333 .38621 Mdot
.3381 .41853 Mdot
.34286 .39748 Mdot
.34762 .46834 Mdot
.35238 .44211 Mdot
.35714 .41584 Mdot
.3619 .38756 Mdot
.36667 .51173 Mdot
.37143 .3486 Mdot
.37619 .41013 Mdot
.38095 .36188 Mdot
.38571 .44755 Mdot
.39048 .40693 Mdot
.39524 .4239 Mdot
.4 .43085 Mdot
.40476 .33502 Mdot
.40952 .46684 Mdot
.41429 .49588 Mdot
.41905 .3703 Mdot
.42381 .46035 Mdot
.42857 .48515 Mdot
.43333 .46461 Mdot
.4381 .47659 Mdot
.44286 .43536 Mdot
.44762 .43251 Mdot
.45238 .39662 Mdot
.45714 .39541 Mdot
.4619 .33085 Mdot
.46667 .40942 Mdot
.47143 .4652 Mdot
.47619 .37665 Mdot
.48095 .41583 Mdot
.48571 .48057 Mdot
.49048 .43369 Mdot
.49524 .43612 Mdot
.5 .40036 Mdot
.50476 .36971 Mdot
.50952 .36628 Mdot
.51429 .40496 Mdot
.51905 .39393 Mdot
.52381 .42223 Mdot
.52857 .43325 Mdot
.53333 .44498 Mdot
.5381 .40268 Mdot
.54286 .42213 Mdot
.54762 .43204 Mdot
.55238 .4151 Mdot
.55714 .47831 Mdot
.5619 .45699 Mdot
.56667 .3971 Mdot
.57143 .4025 Mdot
.57619 .42466 Mdot
.58095 .43377 Mdot
.58571 .40782 Mdot
.59048 .45456 Mdot
.59524 .46288 Mdot
.6 .44241 Mdot
.60476 .39788 Mdot
.60952 .42504 Mdot
.61429 .45206 Mdot
.61905 .41459 Mdot
.62381 .45853 Mdot
.62857 .37759 Mdot
.63333 .41133 Mdot
.6381 .42694 Mdot
.64286 .34896 Mdot
.64762 .38167 Mdot
.65238 .44951 Mdot
.65714 .31077 Mdot
.6619 .41711 Mdot
.66667 .4808 Mdot
.67143 .39604 Mdot
.67619 .33235 Mdot
.68095 .38545 Mdot
.68571 .46928 Mdot
.69048 .43937 Mdot
.69524 .51407 Mdot
.7 .43173 Mdot
.70476 .38659 Mdot
.70952 .4649 Mdot
.71429 .43819 Mdot
.71905 .42401 Mdot
.72381 .41631 Mdot
.72857 .44733 Mdot
.73333 .46639 Mdot
.7381 .4657 Mdot
.74286 .40248 Mdot
.74762 .35443 Mdot
.75238 .47976 Mdot
.75714 .36761 Mdot
.7619 .39128 Mdot
.76667 .402 Mdot
.77143 .36672 Mdot
.77619 .4593 Mdot
.78095 .47673 Mdot
.78571 .52175 Mdot
.79048 .46757 Mdot
.79524 .48963 Mdot
.8 .3886 Mdot
.80476 .49374 Mdot
.80952 .48584 Mdot
.81429 .43506 Mdot
.81905 .37987 Mdot
.82381 .3985 Mdot
.82857 .46149 Mdot
.83333 .45323 Mdot
.8381 .35887 Mdot
.84286 .41738 Mdot
.84762 .47442 Mdot
.85238 .40628 Mdot
.85714 .4272 Mdot
.8619 .41221 Mdot
.86667 .44683 Mdot
.87143 .36843 Mdot
.87619 .40299 Mdot
.88095 .46131 Mdot
.88571 .46976 Mdot
.89048 .47064 Mdot
.89524 .39612 Mdot
.9 .42995 Mdot
.90476 .42996 Mdot
.90952 .36635 Mdot
.91429 .4005 Mdot
.91905 .39254 Mdot
.92381 .40892 Mdot
.92857 .5576 Mdot
.93333 .42816 Mdot
.9381 .39908 Mdot
.94286 .46801 Mdot
.94762 .38863 Mdot
.95238 .47116 Mdot
.95714 .43272 Mdot
.9619 .49381 Mdot
.96667 .35673 Mdot
.97143 .43855 Mdot
.97619 .36226 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36061 Mdot
.03333 .38456 Mdot
.0381 .42593 Mdot
.04286 .40578 Mdot
.04762 .46387 Mdot
.05238 .37242 Mdot
.05714 .40926 Mdot
.0619 .42954 Mdot
.06667 .37413 Mdot
.07143 .41069 Mdot
.07619 .40908 Mdot
.08095 .44969 Mdot
.08571 .36209 Mdot
.09048 .48551 Mdot
.09524 .4254 Mdot
.1 .39775 Mdot
.10476 .38871 Mdot
.10952 .48243 Mdot
.11429 .45816 Mdot
.11905 .38312 Mdot
.12381 .41771 Mdot
.12857 .44245 Mdot
.13333 .53266 Mdot
.1381 .47049 Mdot
.14286 .35185 Mdot
.14762 .509 Mdot
.15238 .41651 Mdot
.15714 .37709 Mdot
.1619 .39138 Mdot
.16667 .42613 Mdot
.17143 .41369 Mdot
.17619 .39082 Mdot
.18095 .45661 Mdot
.18571 .50713 Mdot
.19048 .41814 Mdot
.19524 .42974 Mdot
.2 .38751 Mdot
.20476 .46683 Mdot
.20952 .40975 Mdot
.21429 .41861 Mdot
.21905 .49625 Mdot
.22381 .46645 Mdot
.22857 .42112 Mdot
.23333 .49847 Mdot
.2381 .42515 Mdot
.24286 .41478 Mdot
.24762 .48046 Mdot
.25238 .46222 Mdot
.25714 .46626 Mdot
.2619 .37886 Mdot
.26667 .41523 Mdot
.27143 .43812 Mdot
.27619 .36586 Mdot
.28095 .43413 Mdot
.28571 .44045 Mdot
.29048 .45406 Mdot
.29524 .42078 Mdot
.3 .35776 Mdot
.30476 .4009 Mdot
.30952 .52217 Mdot
.31429 .45942 Mdot
.31905 .28535 Mdot
.32381 .37478 Mdot
.32857 .35717 Mdot
.33333 .38187 Mdot
.3381 .41266 Mdot
.34286 .40319 Mdot
.34762 .47377 Mdot
.35238 .45949 Mdot
.35714 .40388 Mdot
.3619 .39286 Mdot
.36667 .50618 Mdot
.37143 .33937 Mdot
.37619 .40564 Mdot
.38095 .38092 Mdot
.38571 .42897 Mdot
.39048 .39198 Mdot
.39524 .4086 Mdot
.4 .44323 Mdot
.40476 .32406 Mdot
.40952 .46993 Mdot
.41429 .49437 Mdot
.41905 .35381 Mdot
.42381 .4523 Mdot
.42857 .47754 Mdot
.43333 .44762 Mdot
.4381 .46345 Mdot
.44286 .44349 Mdot
.44762 .42249 Mdot
.45238 .37858 Mdot
.45714 .38441 Mdot
.4619 .34673 Mdot
.46667 .41604 Mdot
.47143 .47988 Mdot
.47619 .38618 Mdot
.48095 .41915 Mdot
.48571 .46673 Mdot
.49048 .41816 Mdot
.49524 .42153 Mdot
.5 .40297 Mdot
.50476 .36607 Mdot
.50952 .36549 Mdot
.51429 .39309 Mdot
.51905 .38203 Mdot
.52381 .4122 Mdot
.52857 .44856 Mdot
.53333 .43328 Mdot
.5381 .39135 Mdot
.54286 .43916 Mdot
.54762 .42169 Mdot
.55238 .40463 Mdot
.55714 .48214 Mdot
.5619 .45581 Mdot
.56667 .39714 Mdot
.57143 .4163 Mdot
.57619 .41179 Mdot
.58095 .43824 Mdot
.58571 .40316 Mdot
.59048 .45564 Mdot
.59524 .47117 Mdot
.6 .43415 Mdot
.60476 .39676 Mdot
.60952 .40848 Mdot
.61429 .46048 Mdot
.61905 .40807 Mdot
.62381 .44142 Mdot
.62857 .38273 Mdot
.63333 .39746 Mdot
.6381 .44485 Mdot
.64286 .33773 Mdot
.64762 .36486 Mdot
.65238 .431 Mdot
.65714 .29558 Mdot
.6619 .4359 Mdot
.66667 .49212 Mdot
.67143 .3773 Mdot
.67619 .3282 Mdot
.68095 .40095 Mdot
.68571 .48113 Mdot
.69048 .45765 Mdot
.69524 .51751 Mdot
.7 .44817 Mdot
.70476 .37681 Mdot
.70952 .44682 Mdot
.71429 .42865 Mdot
.71905 .41333 Mdot
.72381 .40623 Mdot
.72857 .43992 Mdot
.73333 .44798 Mdot
.7381 .44867 Mdot
.74286 .39707 Mdot
.74762 .34665 Mdot
.75238 .4757 Mdot
.75714 .37035 Mdot
.7619 .37286 Mdot
.76667 .40855 Mdot
.77143 .35075 Mdot
.77619 .47397 Mdot
.78095 .46166 Mdot
.78571 .52227 Mdot
.79048 .471 Mdot
.79524 .49834 Mdot
.8 .39419 Mdot
.80476 .50075 Mdot
.80952 .50295 Mdot
.81429 .42827 Mdot
.81905 .37576 Mdot
.82381 .39668 Mdot
.82857 .46579 Mdot
.83333 .44154 Mdot
.8381 .35978 Mdot
.84286 .40331 Mdot
.84762 .47391 Mdot
.85238 .38894 Mdot
.85714 .41837 Mdot
.8619 .41321 Mdot
.86667 .43342 Mdot
.87143 .36976 Mdot
.87619 .39077 Mdot
.88095 .45236 Mdot
.88571 .47594 Mdot
.89048 .4857 Mdot
.89524 .38304 Mdot
.9 .41609 Mdot
.90476 .41932 Mdot
.90952 .37521 Mdot
.91429 .41143 Mdot
.91905 .3765 Mdot
.92381 .39782 Mdot
.92857 .55251 Mdot
.93333 .42263 Mdot
.9381 .38579 Mdot
.94286 .45334 Mdot
.94762 .4036 Mdot
.95238 .45831 Mdot
.95714 .4317 Mdot
.9619 .47906 Mdot
.96667 .3658 Mdot
.97143 .44907 Mdot
.97619 .36623 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36172 Mdot
.03333 .39307 Mdot
.0381 .43168 Mdot
.04286 .38923 Mdot
.04762 .45019 Mdot
.05238 .38046 Mdot
.05714 .39537 Mdot
.0619 .43332 Mdot
.06667 .3877 Mdot
.07143 .39587 Mdot
.07619 .4132 Mdot
.08095 .44973 Mdot
.08571 .351 Mdot
.09048 .4718 Mdot
.09524 .41794 Mdot
.1 .38868 Mdot
.10476 .39215 Mdot
.10952 .46989 Mdot
.11429 .464 Mdot
.11905 .38114 Mdot
.12381 .40859 Mdot
.12857 .44445 Mdot
.13333 .54095 Mdot
.1381 .47198 Mdot
.14286 .35342 Mdot
.14762 .50216 Mdot
.15238 .39845 Mdot
.15714 .39044 Mdot
.1619 .38009 Mdot
.16667 .41491 Mdot
.17143 .39549 Mdot
.17619 .37341 Mdot
.18095 .44746 Mdot
.18571 .51811 Mdot
.19048 .42837 Mdot
.19524 .41866 Mdot
.2 .40186 Mdot
.20476 .45828 Mdot
.20952 .4281 Mdot
.21429 .43151 Mdot
.21905 .48448 Mdot
.22381 .4589 Mdot
.22857 .42712 Mdot
.23333 .49082 Mdot
.2381 .44245 Mdot
.24286 .42259 Mdot
.24762 .46663 Mdot
.25238 .46718 Mdot
.25714 .4539 Mdot
.2619 .36603 Mdot
.26667 .4024 Mdot
.27143 .42187 Mdot
.27619 .37908 Mdot
.28095 .43441 Mdot
.28571 .45865 Mdot
.29048 .44603 Mdot
.29524 .40201 Mdot
.3 .3652 Mdot
.30476 .39688 Mdot
.30952 .53186 Mdot
.31429 .4449 Mdot
.31905 .28357 Mdot
.32381 .35761 Mdot
.32857 .35024 Mdot
.33333 .39711 Mdot
.3381 .40252 Mdot
.34286 .40629 Mdot
.34762 .45887 Mdot
.35238 .44335 Mdot
.35714 .39061 Mdot
.3619 .38362 Mdot
.36667 .5164 Mdot
.37143 .35803 Mdot
.37619 .40149 Mdot
.38095 .39083 Mdot
.38571 .43112 Mdot
.39048 .39494 Mdot
.39524 .39444 Mdot
.4 .45292 Mdot
.40476 .31662 Mdot
.40952 .478 Mdot
.41429 .48103 Mdot
.41905 .36119 Mdot
.42381 .44793 Mdot
.42857 .47983 Mdot
.43333 .43036 Mdot
.4381 .46129 Mdot
.44286 .44943 Mdot
.44762 .42653 Mdot
.45238 .39763 Mdot
.45714 .39245 Mdot
.4619 .33453 Mdot
.46667 .41402 Mdot
.47143 .46354 Mdot
.47619 .40458 Mdot
.48095 .41037 Mdot
.48571 .47078 Mdot
.49048 .40101 Mdot
.49524 .41219 Mdot
.5 .39064 Mdot
.50476 .36175 Mdot
.50952 .38456 Mdot
.51429 .40974 Mdot
.51905 .399 Mdot
.52381 .39766 Mdot
.52857 .46711 Mdot
.53333 .43748 Mdot
.5381 .38886 Mdot
.54286 .43973 Mdot
.54762 .42105 Mdot
.55238 .39173 Mdot
.55714 .49798 Mdot
.5619 .4518 Mdot
.56667 .39674 Mdot
.57143 .40986 Mdot
.57619 .41993 Mdot
.58095 .43858 Mdot
.58571 .40119 Mdot
.59048 .44778 Mdot
.59524 .45939 Mdot
.6 .42641 Mdot
.60476 .38081 Mdot
.60952 .39529 Mdot
.61429 .44318 Mdot
.61905 .41108 Mdot
.62381 .43632 Mdot
.62857 .39198 Mdot
.63333 .4032 Mdot
.6381 .42562 Mdot
.64286 .34442 Mdot
.64762 .35723 Mdot
.65238 .41632 Mdot
.65714 .2864 Mdot
.6619 .43604 Mdot
.66667 .50375 Mdot
.67143 .36385 Mdot
.67619 .34547 Mdot
.68095 .39986 Mdot
.68571 .47114 Mdot
.69048 .47243 Mdot
.69524 .53014 Mdot
.7 .43551 Mdot
.70476 .36186 Mdot
.70952 .45817 Mdot
.71429 .42394 Mdot
.71905 .40676 Mdot
.72381 .40114 Mdot
.72857 .43484 Mdot
.73333 .46607 Mdot
.7381 .45262 Mdot
.74286 .39078 Mdot
.74762 .32941 Mdot
.75238 .48241 Mdot
.75714 .3581 Mdot
.7619 .35367 Mdot
.76667 .41143 Mdot
.77143 .33373 Mdot
.77619 .48757 Mdot
.78095 .47005 Mdot
.78571 .50848 Mdot
.79048 .4888 Mdot
.79524 .50055 Mdot
.8 .3809 Mdot
.80476 .51291 Mdot
.80952 .49914 Mdot
.81429 .41886 Mdot
.81905 .3668 Mdot
.82381 .37888 Mdot
.82857 .45015 Mdot
.83333 .43594 Mdot
.8381 .34802 Mdot
.84286 .41865 Mdot
.84762 .48608 Mdot
.85238 .40719 Mdot
.85714 .43065 Mdot
.8619 .40395 Mdot
.86667 .44565 Mdot
.87143 .35734 Mdot
.87619 .37738 Mdot
.88095 .45071 Mdot
.88571 .48397 Mdot
.89048 .47289 Mdot
.89524 .37608 Mdot
.9 .40712 Mdot
.90476 .4183 Mdot
.90952 .37226 Mdot
.91429 .40858 Mdot
.91905 .36894 Mdot
.92381 .38395 Mdot
.92857 .54002 Mdot
.93333 .4154 Mdot
.9381 .38265 Mdot
.94286 .43712 Mdot
.94762 .42131 Mdot
.95238 .45379 Mdot
.95714 .42059 Mdot
.9619 .47035 Mdot
.96667 .38182 Mdot
.97143 .43578 Mdot
.97619 .37387 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .34515 Mdot
.03333 .38034 Mdot
.0381 .44252 Mdot
.04286 .37407 Mdot
.04762 .45436 Mdot
.05238 .36604 Mdot
.05714 .38708 Mdot
.0619 .45096 Mdot
.06667 .3855 Mdot
.07143 .39589 Mdot
.07619 .39601 Mdot
.08095 .44306 Mdot
.08571 .35063 Mdot
.09048 .45308 Mdot
.09524 .40055 Mdot
.1 .39314 Mdot
.10476 .37552 Mdot
.10952 .48794 Mdot
.11429 .45344 Mdot
.11905 .36994 Mdot
.12381 .41145 Mdot
.12857 .43914 Mdot
.13333 .53093 Mdot
.1381 .46764 Mdot
.14286 .36107 Mdot
.14762 .48891 Mdot
.15238 .4084 Mdot
.15714 .38168 Mdot
.1619 .36703 Mdot
.16667 .39732 Mdot
.17143 .41217 Mdot
.17619 .36364 Mdot
.18095 .45736 Mdot
.18571 .51802 Mdot
.19048 .41155 Mdot
.19524 .40166 Mdot
.2 .39153 Mdot
.20476 .45433 Mdot
.20952 .44484 Mdot
.21429 .42599 Mdot
.21905 .48671 Mdot
.22381 .46959 Mdot
.22857 .44444 Mdot
.23333 .5012 Mdot
.2381 .45119 Mdot
.24286 .4081 Mdot
.24762 .45962 Mdot
.25238 .45774 Mdot
.25714 .43858 Mdot
.2619 .37014 Mdot
.26667 .40431 Mdot
.27143 .4111 Mdot
.27619 .37774 Mdot
.28095 .44141 Mdot
.28571 .44154 Mdot
.29048 .44938 Mdot
.29524 .39344 Mdot
.3 .37589 Mdot
.30476 .38337 Mdot
.30952 .5186 Mdot
.31429 .43052 Mdot
.31905 .27062 Mdot
.32381 .35039 Mdot
.32857 .34188 Mdot
.33333 .38096 Mdot
.3381 .42037 Mdot
.34286 .40982 Mdot
.34762 .45546 Mdot
.35238 .44645 Mdot
.35714 .3738 Mdot
.3619 .38418 Mdot
.36667 .51609 Mdot
.37143 .35123 Mdot
.37619 .41386 Mdot
.38095 .37175 Mdot
.38571 .43583 Mdot
.39048 .41061 Mdot
.39524 .38272 Mdot
.4 .46189 Mdot
.40476 .30751 Mdot
.40952 .47462 Mdot
.41429 .48259 Mdot
.41905 .36835 Mdot
.42381 .44451 Mdot
.42857 .47281 Mdot
.43333 .41675 Mdot
.4381 .46514 Mdot
.44286 .43724 Mdot
.44762 .42852 Mdot
.45238 .41156 Mdot
.45714 .41159 Mdot
.4619 .3383 Mdot
.46667 .41856 Mdot
.47143 .46785 Mdot
.47619 .39908 Mdot
.48095 .39283 Mdot
.48571 .45598 Mdot
.49048 .38644 Mdot
.49524 .39302 Mdot
.5 .37255 Mdot
.50476 .36565 Mdot
.50952 .38466 Mdot
.51429 .40353 Mdot
.51905 .41415 Mdot
.52381 .38311 Mdot
.52857 .48033 Mdot
.53333 .42699 Mdot
.5381 .37652 Mdot
.54286 .42832 Mdot
.54762 .41702 Mdot
.55238 .39381 Mdot
.55714 .50244 Mdot
.5619 .45815 Mdot
.56667 .37881 Mdot
.57143 .40108 Mdot
.57619 .43654 Mdot
.58095 .4501 Mdot
.58571 .39815 Mdot
.59048 .44037 Mdot
.59524 .47135 Mdot
.6 .42354 Mdot
.60476 .39924 Mdot
.60952 .37983 Mdot
.61429 .42874 Mdot
.61905 .39254 Mdot
.62381 .42474 Mdot
.62857 .38686 Mdot
.63333 .39614 Mdot
.6381 .41314 Mdot
.64286 .335 Mdot
.64762 .33898 Mdot
.65238 .40351 Mdot
.65714 .27439 Mdot
.6619 .44181 Mdot
.66667 .51824 Mdot
.67143 .36984 Mdot
.67619 .35801 Mdot
.68095 .40159 Mdot
.68571 .47586 Mdot
.69048 .45576 Mdot
.69524 .52458 Mdot
.7 .43956 Mdot
.70476 .3656 Mdot
.70952 .47506 Mdot
.71429 .43604 Mdot
.71905 .42496 Mdot
.72381 .4032 Mdot
.72857 .4329 Mdot
.73333 .45334 Mdot
.7381 .4488 Mdot
.74286 .38231 Mdot
.74762 .33167 Mdot
.75238 .49511 Mdot
.75714 .34699 Mdot
.7619 .34257 Mdot
.76667 .42303 Mdot
.77143 .32394 Mdot
.77619 .50636 Mdot
.78095 .46179 Mdot
.78571 .52151 Mdot
.79048 .48346 Mdot
.79524 .48453 Mdot
.8 .39822 Mdot
.80476 .5049 Mdot
.80952 .48072 Mdot
.81429 .39975 Mdot
.81905 .3555 Mdot
.82381 .39458 Mdot
.82857 .43511 Mdot
.83333 .44028 Mdot
.8381 .34505 Mdot
.84286 .40296 Mdot
.84762 .48764 Mdot
.85238 .39117 Mdot
.85714 .42536 Mdot
.8619 .42272 Mdot
.86667 .463 Mdot
.87143 .34358 Mdot
.87619 .36457 Mdot
.88095 .45189 Mdot
.88571 .49872 Mdot
.89048 .48869 Mdot
.89524 .35857 Mdot
.9 .39678 Mdot
.90476 .40606 Mdot
.90952 .37137 Mdot
.91429 .4161 Mdot
.91905 .3838 Mdot
.92381 .38807 Mdot
.92857 .54833 Mdot
.93333 .4311 Mdot
.9381 .36448 Mdot
.94286 .42761 Mdot
.94762 .41475 Mdot
.95238 .44257 Mdot
.95714 .41576 Mdot
.9619 .45513 Mdot
.96667 .39166 Mdot
.97143 .42876 Mdot
.97619 .37381 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33361 Mdot
.03333 .36882 Mdot
.0381 .42549 Mdot
.04286 .36314 Mdot
.04762 .46028 Mdot
.05238 .36543 Mdot
.05714 .37093 Mdot
.0619 .45253 Mdot
.06667 .39018 Mdot
.07143 .37925 Mdot
.07619 .37949 Mdot
.08095 .45764 Mdot
.08571 .35784 Mdot
.09048 .45335 Mdot
.09524 .41558 Mdot
.1 .3796 Mdot
.10476 .37389 Mdot
.10952 .47499 Mdot
.11429 .46175 Mdot
.11905 .36767 Mdot
.12381 .41651 Mdot
.12857 .44236 Mdot
.13333 .51458 Mdot
.1381 .45657 Mdot
.14286 .35816 Mdot
.14762 .48439 Mdot
.15238 .41674 Mdot
.15714 .36635 Mdot
.1619 .37126 Mdot
.16667 .40504 Mdot
.17143 .42766 Mdot
.17619 .35736 Mdot
.18095 .45777 Mdot
.18571 .53497 Mdot
.19048 .41952 Mdot
.19524 .38923 Mdot
.2 .39437 Mdot
.20476 .46021 Mdot
.20952 .42708 Mdot
.21429 .43855 Mdot
.21905 .4761 Mdot
.22381 .47357 Mdot
.22857 .43504 Mdot
.23333 .49882 Mdot
.2381 .43882 Mdot
.24286 .40249 Mdot
.24762 .44659 Mdot
.25238 .45546 Mdot
.25714 .43189 Mdot
.2619 .36991 Mdot
.26667 .42243 Mdot
.27143 .41451 Mdot
.27619 .36981 Mdot
.28095 .43328 Mdot
.28571 .4247 Mdot
.29048 .43062 Mdot
.29524 .38291 Mdot
.3 .38125 Mdot
.30476 .37037 Mdot
.30952 .53333 Mdot
.31429 .42722 Mdot
.31905 .25302 Mdot
.32381 .34439 Mdot
.32857 .32296 Mdot
.33333 .37288 Mdot
.3381 .42676 Mdot
.34286 .39834 Mdot
.34762 .45403 Mdot
.35238 .46118 Mdot
.35714 .38918 Mdot
.3619 .38642 Mdot
.36667 .51909 Mdot
.37143 .3681 Mdot
.37619 .43228 Mdot
.38095 .36736 Mdot
.38571 .422 Mdot
.39048 .41403 Mdot
.39524 .38234 Mdot
.4 .45587 Mdot
.40476 .28948 Mdot
.40952 .46396 Mdot
.41429 .47733 Mdot
.41905 .36742 Mdot
.42381 .4285 Mdot
.42857 .46063 Mdot
.43333 .40391 Mdot
.4381 .47748 Mdot
.44286 .44796 Mdot
.44762 .44548 Mdot
.45238 .39911 Mdot
.45714 .41984 Mdot
.4619 .34168 Mdot
.46667 .41765 Mdot
.47143 .47578 Mdot
.47619 .38821 Mdot
.48095 .39176 Mdot
.48571 .47239 Mdot
.49048 .38595 Mdot
.49524 .37839 Mdot
.5 .36644 Mdot
.50476 .3539 Mdot
.50952 .39047 Mdot
.51429 .41292 Mdot
.51905 .40694 Mdot
.52381 .36835 Mdot
.52857 .46149 Mdot
.53333 .42833 Mdot
.5381 .37032 Mdot
.54286 .4404 Mdot
.54762 .40696 Mdot
.55238 .4107 Mdot
.55714 .48665 Mdot
.5619 .47177 Mdot
.56667 .37057 Mdot
.57143 .38412 Mdot
.57619 .42663 Mdot
.58095 .45344 Mdot
.58571 .38613 Mdot
.59048 .4468 Mdot
.59524 .45428 Mdot
.6 .41105 Mdot
.60476 .3983 Mdot
.60952 .36333 Mdot
.61429 .43606 Mdot
.61905 .37458 Mdot
.62381 .41993 Mdot
.62857 .38433 Mdot
.63333 .39975 Mdot
.6381 .40207 Mdot
.64286 .34577 Mdot
.64762 .34413 Mdot
.65238 .39364 Mdot
.65714 .25795 Mdot
.6619 .44582 Mdot
.66667 .533 Mdot
.67143 .35989 Mdot
.67619 .36327 Mdot
.68095 .41699 Mdot
.68571 .46568 Mdot
.69048 .45857 Mdot
.69524 .51594 Mdot
.7 .42916 Mdot
.70476 .36242 Mdot
.70952 .46504 Mdot
.71429 .44582 Mdot
.71905 .41658 Mdot
.72381 .38799 Mdot
.72857 .41493 Mdot
.73333 .44338 Mdot
.7381 .45923 Mdot
.74286 .38806 Mdot
.74762 .33146 Mdot
.75238 .50832 Mdot
.75714 .33213 Mdot
.7619 .35849 Mdot
.76667 .43125 Mdot
.77143 .3408 Mdot
.77619 .51018 Mdot
.78095 .45618 Mdot
.78571 .53752 Mdot
.79048 .47382 Mdot
.79524 .48984 Mdot
.8 .397 Mdot
.80476 .50232 Mdot
.80952 .49061 Mdot
.81429 .38374 Mdot
.81905 .35522 Mdot
.82381 .39533 Mdot
.82857 .44119 Mdot
.83333 .43669 Mdot
.8381 .32839 Mdot
.84286 .40054 Mdot
.84762 .47038 Mdot
.85238 .39622 Mdot
.85714 .42987 Mdot
.8619 .40357 Mdot
.86667 .44925 Mdot
.87143 .35369 Mdot
.87619 .35342 Mdot
.88095 .45798 Mdot
.88571 .49498 Mdot
.89048 .49372 Mdot
.89524 .37568 Mdot
.9 .40573 Mdot
.90476 .40083 Mdot
.90952 .38175 Mdot
.91429 .42282 Mdot
.91905 .37872 Mdot
.92381 .39117 Mdot
.92857 .53617 Mdot
.93333 .42228 Mdot
.9381 .38075 Mdot
.94286 .41536 Mdot
.94762 .41257 Mdot
.95238 .44665 Mdot
.95714 .40667 Mdot
.9619 .43665 Mdot
.96667 .38563 Mdot
.97143 .43073 Mdot
.97619 .38839 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31668 Mdot
.03333 .3817 Mdot
.0381 .43185 Mdot
.04286 .34618 Mdot
.04762 .46759 Mdot
.05238 .3666 Mdot
.05714 .36452 Mdot
.0619 .43887 Mdot
.06667 .37732 Mdot
.07143 .37784 Mdot
.07619 .36503 Mdot
.08095 .45628 Mdot
.08571 .36376 Mdot
.09048 .4632 Mdot
.09524 .40562 Mdot
.1 .37363 Mdot
.10476 .38968 Mdot
.10952 .46742 Mdot
.11429 .44334 Mdot
.11905 .37437 Mdot
.12381 .41924 Mdot
.12857 .42983 Mdot
.13333 .49584 Mdot
.1381 .47017 Mdot
.14286 .37689 Mdot
.14762 .47435 Mdot
.15238 .42313 Mdot
.15714 .35019 Mdot
.1619 .36089 Mdot
.16667 .42242 Mdot
.17143 .43325 Mdot
.17619 .339 Mdot
.18095 .47576 Mdot
.18571 .55324 Mdot
.19048 .41605 Mdot
.19524 .39739 Mdot
.2 .3987 Mdot
.20476 .44577 Mdot
.20952 .43558 Mdot
.21429 .43696 Mdot
.21905 .46112 Mdot
.22381 .45505 Mdot
.22857 .43736 Mdot
.23333 .49737 Mdot
.2381 .42628 Mdot
.24286 .41327 Mdot
.24762 .44684 Mdot
.25238 .45216 Mdot
.25714 .44108 Mdot
.2619 .38134 Mdot
.26667 .42141 Mdot
.27143 .43368 Mdot
.27619 .37634 Mdot
.28095 .44061 Mdot
.28571 .42901 Mdot
.29048 .43056 Mdot
.29524 .39642 Mdot
.3 .38323 Mdot
.30476 .38724 Mdot
.30952 .5255 Mdot
.31429 .43949 Mdot
.31905 .24859 Mdot
.32381 .3452 Mdot
.32857 .32632 Mdot
.33333 .38467 Mdot
.3381 .43041 Mdot
.34286 .40898 Mdot
.34762 .44103 Mdot
.35238 .47783 Mdot
.35714 .3886 Mdot
.3619 .38808 Mdot
.36667 .50343 Mdot
.37143 .37028 Mdot
.37619 .42097 Mdot
.38095 .36174 Mdot
.38571 .42587 Mdot
.39048 .41676 Mdot
.39524 .37457 Mdot
.4 .45471 Mdot
.40476 .30215 Mdot
.40952 .46273 Mdot
.41429 .4784 Mdot
.41905 .3744 Mdot
.42381 .44632 Mdot
.42857 .44385 Mdot
.43333 .40014 Mdot
.4381 .49668 Mdot
.44286 .45376 Mdot
.44762 .42877 Mdot
.45238 .39236 Mdot
.45714 .42845 Mdot
.4619 .33564 Mdot
.46667 .42437 Mdot
.47143 .48961 Mdot
.47619 .39755 Mdot
.48095 .38575 Mdot
.48571 .46373 Mdot
.49048 .37341 Mdot
.49524 .37333 Mdot
.5 .37192 Mdot
.50476 .35185 Mdot
.50952 .39241 Mdot
.51429 .42528 Mdot
.51905 .40623 Mdot
.52381 .35754 Mdot
.52857 .44849 Mdot
.53333 .44141 Mdot
.5381 .36374 Mdot
.54286 .45434 Mdot
.54762 .39547 Mdot
.55238 .39212 Mdot
.55714 .46927 Mdot
.5619 .48742 Mdot
.56667 .36723 Mdot
.57143 .38644 Mdot
.57619 .41693 Mdot
.58095 .44872 Mdot
.58571 .36835 Mdot
.59048 .46344 Mdot
.59524 .4558 Mdot
.6 .4097 Mdot
.60476 .38883 Mdot
.60952 .34854 Mdot
.61429 .43307 Mdot
.61905 .39054 Mdot
.62381 .40148 Mdot
.62857 .37056 Mdot
.63333 .3856 Mdot
.6381 .40246 Mdot
.64286 .34877 Mdot
.64762 .35677 Mdot
.65238 .38934 Mdot
.65714 .24109 Mdot
.6619 .44081 Mdot
.66667 .54382 Mdot
.67143 .36469 Mdot
.67619 .38251 Mdot
.68095 .42314 Mdot
.68571 .45494 Mdot
.69048 .47153 Mdot
.69524 .50581 Mdot
.7 .42975 Mdot
.70476 .34985 Mdot
.70952 .46362 Mdot
.71429 .45438 Mdot
.71905 .40027 Mdot
.72381 .3932 Mdot
.72857 .39662 Mdot
.73333 .43857 Mdot
.7381 .45301 Mdot
.74286 .39085 Mdot
.74762 .31976 Mdot
.75238 .50984 Mdot
.75714 .33171 Mdot
.7619 .35287 Mdot
.76667 .44766 Mdot
.77143 .3283 Mdot
.77619 .51501 Mdot
.78095 .45832 Mdot
.78571 .54153 Mdot
.79048 .45816 Mdot
.79524 .50657 Mdot
.8 .40334 Mdot
.80476 .50543 Mdot
.80952 .50002 Mdot
.81429 .38348 Mdot
.81905 .3593 Mdot
.82381 .38388 Mdot
.82857 .42247 Mdot
.83333 .44075 Mdot
.8381 .31314 Mdot
.84286 .38636 Mdot
.84762 .45929 Mdot
.85238 .3815 Mdot
.85714 .42819 Mdot
.8619 .39105 Mdot
.86667 .43188 Mdot
.87143 .34298 Mdot
.87619 .33719 Mdot
.88095 .44771 Mdot
.88571 .49678 Mdot
.89048 .48833 Mdot
.89524 .38355 Mdot
.9 .38812 Mdot
.90476 .38768 Mdot
.90952 .3866 Mdot
.91429 .42938 Mdot
.91905 .38737 Mdot
.92381 .38068 Mdot
.92857 .5292 Mdot
.93333 .42165 Mdot
.9381 .36365 Mdot
.94286 .3974 Mdot
.94762 .40954 Mdot
.95238 .43434 Mdot
.95714 .3946 Mdot
.9619 .42801 Mdot
.96667 .38043 Mdot
.97143 .41251 Mdot
.97619 .37503 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31969 Mdot
.03333 .37026 Mdot
.0381 .43284 Mdot
.04286 .35455 Mdot
.04762 .4769 Mdot
.05238 .36523 Mdot
.05714 .37872 Mdot
.0619 .42035 Mdot
.06667 .38966 Mdot
.07143 .38296 Mdot
.07619 .35852 Mdot
.08095 .46688 Mdot
.08571 .37796 Mdot
.09048 .45934 Mdot
.09524 .39037 Mdot
.1 .374 Mdot
.10476 .39004 Mdot
.10952 .44892 Mdot
.11429 .44806 Mdot
.11905 .36569 Mdot
.12381 .43129 Mdot
.12857 .4228 Mdot
.13333 .47852 Mdot
.1381 .48035 Mdot
.14286 .38893 Mdot
.14762 .48378 Mdot
.15238 .40619 Mdot
.15714 .36945 Mdot
.1619 .37378 Mdot
.16667 .41772 Mdot
.17143 .44908 Mdot
.17619 .34993 Mdot
.18095 .46619 Mdot
.18571 .57177 Mdot
.19048 .43385 Mdot
.19524 .38192 Mdot
.2 .3796 Mdot
.20476 .45809 Mdot
.20952 .44219 Mdot
.21429 .42382 Mdot
.21905 .47102 Mdot
.22381 .47362 Mdot
.22857 .44739 Mdot
.23333 .49029 Mdot
.2381 .41061 Mdot
.24286 .41285 Mdot
.24762 .44649 Mdot
.25238 .45437 Mdot
.25714 .44009 Mdot
.2619 .37073 Mdot
.26667 .41475 Mdot
.27143 .43063 Mdot
.27619 .37567 Mdot
.28095 .43141 Mdot
.28571 .41242 Mdot
.29048 .41194 Mdot
.29524 .40648 Mdot
.3 .38821 Mdot
.30476 .38503 Mdot
.30952 .51534 Mdot
.31429 .42631 Mdot
.31905 .26287 Mdot
.32381 .34196 Mdot
.32857 .33205 Mdot
.33333 .38948 Mdot
.3381 .4286 Mdot
.34286 .39125 Mdot
.34762 .44588 Mdot
.35238 .47362 Mdot
.35714 .3829 Mdot
.3619 .3816 Mdot
.36667 .48534 Mdot
.37143 .37957 Mdot
.37619 .41084 Mdot
.38095 .37507 Mdot
.38571 .42333 Mdot
.39048 .40436 Mdot
.39524 .38549 Mdot
.4 .43871 Mdot
.40476 .29569 Mdot
.40952 .47934 Mdot
.41429 .477 Mdot
.41905 .38559 Mdot
.42381 .43717 Mdot
.42857 .44562 Mdot
.43333 .39856 Mdot
.4381 .47778 Mdot
.44286 .44108 Mdot
.44762 .41259 Mdot
.45238 .41012 Mdot
.45714 .41254 Mdot
.4619 .32775 Mdot
.46667 .42699 Mdot
.47143 .47088 Mdot
.47619 .38201 Mdot
.48095 .39162 Mdot
.48571 .46133 Mdot
.49048 .36239 Mdot
.49524 .39113 Mdot
.5 .36826 Mdot
.50476 .36288 Mdot
.50952 .39524 Mdot
.51429 .42254 Mdot
.51905 .38741 Mdot
.52381 .3731 Mdot
.52857 .45977 Mdot
.53333 .44838 Mdot
.5381 .36717 Mdot
.54286 .45262 Mdot
.54762 .39268 Mdot
.55238 .40274 Mdot
.55714 .45591 Mdot
.5619 .49155 Mdot
.56667 .38252 Mdot
.57143 .37045 Mdot
.57619 .43218 Mdot
.58095 .4622 Mdot
.58571 .36201 Mdot
.59048 .46572 Mdot
.59524 .47213 Mdot
.6 .42071 Mdot
.60476 .39523 Mdot
.60952 .35805 Mdot
.61429 .41934 Mdot
.61905 .37356 Mdot
.62381 .38851 Mdot
.62857 .37553 Mdot
.63333 .38785 Mdot
.6381 .38612 Mdot
.64286 .34622 Mdot
.64762 .34478 Mdot
.65238 .38629 Mdot
.65714 .2247 Mdot
.6619 .4335 Mdot
.66667 .53832 Mdot
.67143 .36926 Mdot
.67619 .37057 Mdot
.68095 .40657 Mdot
.68571 .44671 Mdot
.69048 .4661 Mdot
.69524 .48787 Mdot
.7 .41873 Mdot
.70476 .33397 Mdot
.70952 .47579 Mdot
.71429 .45105 Mdot
.71905 .41205 Mdot
.72381 .37406 Mdot
.72857 .39142 Mdot
.73333 .42795 Mdot
.7381 .44317 Mdot
.74286 .37691 Mdot
.74762 .30927 Mdot
.75238 .49322 Mdot
.75714 .33036 Mdot
.7619 .34713 Mdot
.76667 .4602 Mdot
.77143 .31142 Mdot
.77619 .52669 Mdot
.78095 .44801 Mdot
.78571 .53739 Mdot
.79048 .44706 Mdot
.79524 .5083 Mdot
.8 .41015 Mdot
.80476 .51678 Mdot
.80952 .4939 Mdot
.81429 .37785 Mdot
.81905 .36838 Mdot
.82381 .38721 Mdot
.82857 .41529 Mdot
.83333 .43279 Mdot
.8381 .31266 Mdot
.84286 .37908 Mdot
.84762 .4488 Mdot
.85238 .37432 Mdot
.85714 .41307 Mdot
.8619 .39365 Mdot
.86667 .44503 Mdot
.87143 .34582 Mdot
.87619 .33287 Mdot
.88095 .44197 Mdot
.88571 .50334 Mdot
.89048 .47347 Mdot
.89524 .38877 Mdot
.9 .39403 Mdot
.90476 .40153 Mdot
.90952 .39386 Mdot
.91429 .42374 Mdot
.91905 .37902 Mdot
.92381 .37123 Mdot
.92857 .53843 Mdot
.93333 .40795 Mdot
.9381 .369 Mdot
.94286 .37922 Mdot
.94762 .39226 Mdot
.95238 .43918 Mdot
.95714 .41381 Mdot
.9619 .42326 Mdot
.96667 .36933 Mdot
.97143 .42034 Mdot
.97619 .36499 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30972 Mdot
.03333 .36938 Mdot
.0381 .41535 Mdot
.04286 .35308 Mdot
.04762 .45782 Mdot
.05238 .3508 Mdot
.05714 .36829 Mdot
.0619 .41738 Mdot
.06667 .37642 Mdot
.07143 .39266 Mdot
.07619 .36873 Mdot
.08095 .46316 Mdot
.08571 .35958 Mdot
.09048 .47632 Mdot
.09524 .38674 Mdot
.1 .36355 Mdot
.10476 .3877 Mdot
.10952 .43438 Mdot
.11429 .42937 Mdot
.11905 .38242 Mdot
.12381 .43743 Mdot
.12857 .41003 Mdot
.13333 .4662 Mdot
.1381 .48341 Mdot
.14286 .37277 Mdot
.14762 .49305 Mdot
.15238 .41465 Mdot
.15714 .35659 Mdot
.1619 .35999 Mdot
.16667 .41653 Mdot
.17143 .43635 Mdot
.17619 .35784 Mdot
.18095 .48085 Mdot
.18571 .56559 Mdot
.19048 .426 Mdot
.19524 .36459 Mdot
.2 .36788 Mdot
.20476 .47424 Mdot
.20952 .44262 Mdot
.21429 .42998 Mdot
.21905 .48404 Mdot
.22381 .46635 Mdot
.22857 .42922 Mdot
.23333 .47785 Mdot
.2381 .41659 Mdot
.24286 .39357 Mdot
.24762 .44303 Mdot
.25238 .44263 Mdot
.25714 .45748 Mdot
.2619 .37709 Mdot
.26667 .40213 Mdot
.27143 .42204 Mdot
.27619 .36147 Mdot
.28095 .42968 Mdot
.28571 .39568 Mdot
.29048 .4037 Mdot
.29524 .38843 Mdot
.3 .39939 Mdot
.30476 .37001 Mdot
.30952 .52483 Mdot
.31429 .41708 Mdot
.31905 .26075 Mdot
.32381 .34044 Mdot
.32857 .34997 Mdot
.33333 .40476 Mdot
.3381 .41776 Mdot
.34286 .39303 Mdot
.34762 .44741 Mdot
.35238 .48135 Mdot
.35714 .3911 Mdot
.3619 .37413 Mdot
.36667 .49326 Mdot
.37143 .36233 Mdot
.37619 .428 Mdot
.38095 .37796 Mdot
.38571 .43716 Mdot
.39048 .4169 Mdot
.39524 .37148 Mdot
.4 .45294 Mdot
.40476 .28879 Mdot
.40952 .48702 Mdot
.41429 .48379 Mdot
.41905 .37095 Mdot
.42381 .4231 Mdot
.42857 .45243 Mdot
.43333 .39253 Mdot
.4381 .47706 Mdot
.44286 .43517 Mdot
.44762 .41572 Mdot
.45238 .39675 Mdot
.45714 .42224 Mdot
.4619 .32901 Mdot
.46667 .43355 Mdot
.47143 .45654 Mdot
.47619 .37625 Mdot
.48095 .40107 Mdot
.48571 .4549 Mdot
.49048 .34758 Mdot
.49524 .37609 Mdot
.5 .36476 Mdot
.50476 .37529 Mdot
.50952 .38221 Mdot
.51429 .42475 Mdot
.51905 .3888 Mdot
.52381 .35533 Mdot
.52857 .45573 Mdot
.53333 .46617 Mdot
.5381 .37399 Mdot
.54286 .44425 Mdot
.54762 .39427 Mdot
.55238 .39689 Mdot
.55714 .45605 Mdot
.5619 .49395 Mdot
.56667 .3966 Mdot
.57143 .37828 Mdot
.57619 .42437 Mdot
.58095 .44795 Mdot
.58571 .3689 Mdot
.59048 .46621 Mdot
.59524 .49057 Mdot
.6 .41223 Mdot
.60476 .39007 Mdot
.60952 .36697 Mdot
.61429 .4289 Mdot
.61905 .36047 Mdot
.62381 .38012 Mdot
.62857 .35745 Mdot
.63333 .38727 Mdot
.6381 .38252 Mdot
.64286 .33863 Mdot
.64762 .34097 Mdot
.65238 .40014 Mdot
.65714 .20867 Mdot
.6619 .43228 Mdot
.66667 .53339 Mdot
.67143 .36208 Mdot
.67619 .35488 Mdot
.68095 .40501 Mdot
.68571 .4523 Mdot
.69048 .46011 Mdot
.69524 .47957 Mdot
.7 .40032 Mdot
.70476 .33919 Mdot
.70952 .49368 Mdot
.71429 .45567 Mdot
.71905 .40487 Mdot
.72381 .36288 Mdot
.72857 .38861 Mdot
.73333 .42958 Mdot
.7381 .45513 Mdot
.74286 .37886 Mdot
.74762 .30628 Mdot
.75238 .47661 Mdot
.75714 .32182 Mdot
.7619 .34626 Mdot
.76667 .47254 Mdot
.77143 .32046 Mdot
.77619 .51654 Mdot
.78095 .45437 Mdot
.78571 .51825 Mdot
.79048 .43138 Mdot
.79524 .49375 Mdot
.8 .3923 Mdot
.80476 .51249 Mdot
.80952 .4943 Mdot
.81429 .37648 Mdot
.81905 .34922 Mdot
.82381 .39204 Mdot
.82857 .42614 Mdot
.83333 .4492 Mdot
.8381 .30244 Mdot
.84286 .39705 Mdot
.84762 .43741 Mdot
.85238 .38872 Mdot
.85714 .4036 Mdot
.8619 .38888 Mdot
.86667 .45456 Mdot
.87143 .34163 Mdot
.87619 .34193 Mdot
.88095 .45719 Mdot
.88571 .51096 Mdot
.89048 .47234 Mdot
.89524 .39799 Mdot
.9 .39143 Mdot
.90476 .39057 Mdot
.90952 .39563 Mdot
.91429 .41885 Mdot
.91905 .37962 Mdot
.92381 .3553 Mdot
.92857 .52112 Mdot
.93333 .3966 Mdot
.9381 .3781 Mdot
.94286 .37191 Mdot
.94762 .38838 Mdot
.95238 .43894 Mdot
.95714 .42995 Mdot
.9619 .40672 Mdot
.96667 .35192 Mdot
.97143 .42325 Mdot
.97619 .36246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31063 Mdot
.03333 .3827 Mdot
.0381 .41443 Mdot
.04286 .33432 Mdot
.04762 .45188 Mdot
.05238 .36696 Mdot
.05714 .38754 Mdot
.0619 .41679 Mdot
.06667 .36337 Mdot
.07143 .39063 Mdot
.07619 .38377 Mdot
.08095 .44939 Mdot
.08571 .36207 Mdot
.09048 .48071 Mdot
.09524 .39364 Mdot
.1 .35528 Mdot
.10476 .38021 Mdot
.10952 .43174 Mdot
.11429 .41531 Mdot
.11905 .36582 Mdot
.12381 .44682 Mdot
.12857 .41643 Mdot
.13333 .45263 Mdot
.1381 .49808 Mdot
.14286 .37628 Mdot
.14762 .5006 Mdot
.15238 .41436 Mdot
.15714 .36759 Mdot
.1619 .35159 Mdot
.16667 .4083 Mdot
.17143 .43192 Mdot
.17619 .36031 Mdot
.18095 .46343 Mdot
.18571 .552 Mdot
.19048 .42627 Mdot
.19524 .3707 Mdot
.2 .36113 Mdot
.20476 .46358 Mdot
.20952 .44562 Mdot
.21429 .42334 Mdot
.21905 .46865 Mdot
.22381 .45173 Mdot
.22857 .41226 Mdot
.23333 .47809 Mdot
.2381 .42452 Mdot
.24286 .38111 Mdot
.24762 .44664 Mdot
.25238 .42903 Mdot
.25714 .47191 Mdot
.2619 .36792 Mdot
.26667 .41287 Mdot
.27143 .427 Mdot
.27619 .35201 Mdot
.28095 .41891 Mdot
.28571 .37753 Mdot
.29048 .38636 Mdot
.29524 .3725 Mdot
.3 .40273 Mdot
.30476 .35383 Mdot
.30952 .53795 Mdot
.31429 .42115 Mdot
.31905 .27971 Mdot
.32381 .32627 Mdot
.32857 .34516 Mdot
.33333 .4185 Mdot
.3381 .42049 Mdot
.34286 .38676 Mdot
.34762 .43072 Mdot
.35238 .4686 Mdot
.35714 .37804 Mdot
.3619 .3581 Mdot
.36667 .47918 Mdot
.37143 .36232 Mdot
.37619 .44205 Mdot
.38095 .36602 Mdot
.38571 .422 Mdot
.39048 .41046 Mdot
.39524 .35231 Mdot
.4 .44762 Mdot
.40476 .27398 Mdot
.40952 .50207 Mdot
.41429 .46842 Mdot
.41905 .35284 Mdot
.42381 .4364 Mdot
.42857 .45064 Mdot
.43333 .3996 Mdot
.4381 .49061 Mdot
.44286 .44748 Mdot
.44762 .4148 Mdot
.45238 .39954 Mdot
.45714 .41561 Mdot
.4619 .32741 Mdot
.46667 .42117 Mdot
.47143 .4558 Mdot
.47619 .36188 Mdot
.48095 .38947 Mdot
.48571 .45557 Mdot
.49048 .33271 Mdot
.49524 .37566 Mdot
.5 .36429 Mdot
.50476 .38812 Mdot
.50952 .3744 Mdot
.51429 .44395 Mdot
.51905 .386 Mdot
.52381 .33612 Mdot
.52857 .4374 Mdot
.53333 .452 Mdot
.5381 .36918 Mdot
.54286 .46172 Mdot
.54762 .38421 Mdot
.55238 .39086 Mdot
.55714 .44578 Mdot
.5619 .49365 Mdot
.56667 .39317 Mdot
.57143 .39051 Mdot
.57619 .41013 Mdot
.58095 .4417 Mdot
.58571 .36115 Mdot
.59048 .44934 Mdot
.59524 .47917 Mdot
.6 .40877 Mdot
.60476 .40453 Mdot
.60952 .37313 Mdot
.61429 .42119 Mdot
.61905 .35339 Mdot
.62381 .3824 Mdot
.62857 .34017 Mdot
.63333 .40308 Mdot
.6381 .37883 Mdot
.64286 .3286 Mdot
.64762 .34413 Mdot
.65238 .39629 Mdot
.65714 .2048 Mdot
.6619 .44826 Mdot
.66667 .53777 Mdot
.67143 .37035 Mdot
.67619 .36285 Mdot
.68095 .42103 Mdot
.68571 .44857 Mdot
.69048 .46664 Mdot
.69524 .47295 Mdot
.7 .39554 Mdot
.70476 .32094 Mdot
.70952 .48572 Mdot
.71429 .44488 Mdot
.71905 .38963 Mdot
.72381 .34664 Mdot
.72857 .39226 Mdot
.73333 .41237 Mdot
.7381 .43612 Mdot
.74286 .37919 Mdot
.74762 .31622 Mdot
.75238 .47782 Mdot
.75714 .33401 Mdot
.7619 .33231 Mdot
.76667 .45374 Mdot
.77143 .3249 Mdot
.77619 .53121 Mdot
.78095 .43981 Mdot
.78571 .50337 Mdot
.79048 .43616 Mdot
.79524 .51178 Mdot
.8 .40926 Mdot
.80476 .50568 Mdot
.80952 .49642 Mdot
.81429 .38612 Mdot
.81905 .35917 Mdot
.82381 .40264 Mdot
.82857 .41339 Mdot
.83333 .43309 Mdot
.8381 .29189 Mdot
.84286 .38388 Mdot
.84762 .42842 Mdot
.85238 .39107 Mdot
.85714 .4181 Mdot
.8619 .38195 Mdot
.86667 .4447 Mdot
.87143 .35288 Mdot
.87619 .33528 Mdot
.88095 .45192 Mdot
.88571 .49671 Mdot
.89048 .4608 Mdot
.89524 .39551 Mdot
.9 .4056 Mdot
.90476 .39177 Mdot
.90952 .37636 Mdot
.91429 .41035 Mdot
.91905 .38692 Mdot
.92381 .36104 Mdot
.92857 .53705 Mdot
.93333 .39383 Mdot
.9381 .35976 Mdot
.94286 .35394 Mdot
.94762 .38327 Mdot
.95238 .45451 Mdot
.95714 .43093 Mdot
.9619 .41679 Mdot
.96667 .34143 Mdot
.97143 .41784 Mdot
.97619 .36777 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30533 Mdot
.03333 .37524 Mdot
.0381 .39708 Mdot
.04286 .31943 Mdot
.04762 .4436 Mdot
.05238 .38425 Mdot
.05714 .40051 Mdot
.0619 .42134 Mdot
.06667 .36354 Mdot
.07143 .37935 Mdot
.07619 .37868 Mdot
.08095 .43688 Mdot
.08571 .37253 Mdot
.09048 .4675 Mdot
.09524 .38124 Mdot
.1 .35398 Mdot
.10476 .36233 Mdot
.10952 .42173 Mdot
.11429 .42057 Mdot
.11905 .36616 Mdot
.12381 .4515 Mdot
.12857 .42492 Mdot
.13333 .46122 Mdot
.1381 .48118 Mdot
.14286 .35736 Mdot
.14762 .48479 Mdot
.15238 .42144 Mdot
.15714 .38456 Mdot
.1619 .3664 Mdot
.16667 .41631 Mdot
.17143 .42291 Mdot
.17619 .34164 Mdot
.18095 .4496 Mdot
.18571 .55678 Mdot
.19048 .41384 Mdot
.19524 .37449 Mdot
.2 .3454 Mdot
.20476 .45438 Mdot
.20952 .44922 Mdot
.21429 .40719 Mdot
.21905 .46742 Mdot
.22381 .45573 Mdot
.22857 .39732 Mdot
.23333 .47917 Mdot
.2381 .44159 Mdot
.24286 .38763 Mdot
.24762 .43808 Mdot
.25238 .44604 Mdot
.25714 .45443 Mdot
.2619 .36356 Mdot
.26667 .40241 Mdot
.27143 .42376 Mdot
.27619 .34881 Mdot
.28095 .42046 Mdot
.28571 .38581 Mdot
.29048 .37756 Mdot
.29524 .3542 Mdot
.3 .38716 Mdot
.30476 .3442 Mdot
.30952 .54239 Mdot
.31429 .42044 Mdot
.31905 .29233 Mdot
.32381 .33718 Mdot
.32857 .36253 Mdot
.33333 .40431 Mdot
.3381 .41707 Mdot
.34286 .38608 Mdot
.34762 .43677 Mdot
.35238 .45025 Mdot
.35714 .36148 Mdot
.3619 .34491 Mdot
.36667 .47973 Mdot
.37143 .36671 Mdot
.37619 .42922 Mdot
.38095 .34825 Mdot
.38571 .41521 Mdot
.39048 .42657 Mdot
.39524 .35163 Mdot
.4 .45961 Mdot
.40476 .28977 Mdot
.40952 .50846 Mdot
.41429 .46132 Mdot
.41905 .35198 Mdot
.42381 .44945 Mdot
.42857 .45664 Mdot
.43333 .40619 Mdot
.4381 .50542 Mdot
.44286 .43393 Mdot
.44762 .39663 Mdot
.45238 .39098 Mdot
.45714 .41471 Mdot
.4619 .31119 Mdot
.46667 .40211 Mdot
.47143 .46122 Mdot
.47619 .35704 Mdot
.48095 .39054 Mdot
.48571 .45076 Mdot
.49048 .31574 Mdot
.49524 .36047 Mdot
.5 .34524 Mdot
.50476 .38915 Mdot
.50952 .35815 Mdot
.51429 .43793 Mdot
.51905 .38207 Mdot
.52381 .34883 Mdot
.52857 .43412 Mdot
.53333 .43509 Mdot
.5381 .36896 Mdot
.54286 .45564 Mdot
.54762 .36855 Mdot
.55238 .37505 Mdot
.55714 .45329 Mdot
.5619 .47541 Mdot
.56667 .401 Mdot
.57143 .37895 Mdot
.57619 .41057 Mdot
.58095 .43724 Mdot
.58571 .36537 Mdot
.59048 .46806 Mdot
.59524 .4733 Mdot
.6 .40107 Mdot
.60476 .42355 Mdot
.60952 .35843 Mdot
.61429 .4063 Mdot
.61905 .36262 Mdot
.62381 .3815 Mdot
.62857 .32762 Mdot
.63333 .4067 Mdot
.6381 .38408 Mdot
.64286 .33923 Mdot
.64762 .32933 Mdot
.65238 .39606 Mdot
.65714 .22135 Mdot
.6619 .46036 Mdot
.66667 .52379 Mdot
.67143 .3566 Mdot
.67619 .37286 Mdot
.68095 .43928 Mdot
.68571 .44254 Mdot
.69048 .47631 Mdot
.69524 .46892 Mdot
.7 .40674 Mdot
.70476 .32774 Mdot
.70952 .48296 Mdot
.71429 .43992 Mdot
.71905 .39832 Mdot
.72381 .3565 Mdot
.72857 .37753 Mdot
.73333 .39425 Mdot
.7381 .42022 Mdot
.74286 .38855 Mdot
.74762 .31974 Mdot
.75238 .48804 Mdot
.75714 .31523 Mdot
.7619 .34952 Mdot
.76667 .4461 Mdot
.77143 .31291 Mdot
.77619 .51897 Mdot
.78095 .44194 Mdot
.78571 .49478 Mdot
.79048 .42199 Mdot
.79524 .51496 Mdot
.8 .42738 Mdot
.80476 .50603 Mdot
.80952 .49901 Mdot
.81429 .38927 Mdot
.81905 .37038 Mdot
.82381 .38998 Mdot
.82857 .42255 Mdot
.83333 .42779 Mdot
.8381 .30197 Mdot
.84286 .39663 Mdot
.84762 .44525 Mdot
.85238 .37593 Mdot
.85714 .40191 Mdot
.8619 .36497 Mdot
.86667 .46163 Mdot
.87143 .33718 Mdot
.87619 .31798 Mdot
.88095 .44829 Mdot
.88571 .50689 Mdot
.89048 .45317 Mdot
.89524 .40542 Mdot
.9 .41377 Mdot
.90476 .3843 Mdot
.90952 .35976 Mdot
.91429 .40118 Mdot
.91905 .3896 Mdot
.92381 .35294 Mdot
.92857 .53426 Mdot
.93333 .41242 Mdot
.9381 .34327 Mdot
.94286 .33552 Mdot
.94762 .37447 Mdot
.95238 .44139 Mdot
.95714 .44778 Mdot
.9619 .4223 Mdot
.96667 .3341 Mdot
.97143 .41145 Mdot
.97619 .37691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .29967 Mdot
.03333 .38076 Mdot
.0381 .41588 Mdot
.04286 .33552 Mdot
.04762 .45395 Mdot
.05238 .37189 Mdot
.05714 .41193 Mdot
.0619 .42242 Mdot
.06667 .37834 Mdot
.07143 .38578 Mdot
.07619 .36715 Mdot
.08095 .43282 Mdot
.08571 .37476 Mdot
.09048 .4856 Mdot
.09524 .39014 Mdot
.1 .35221 Mdot
.10476 .34905 Mdot
.10952 .42206 Mdot
.11429 .40877 Mdot
.11905 .36138 Mdot
.12381 .43668 Mdot
.12857 .41686 Mdot
.13333 .45413 Mdot
.1381 .49165 Mdot
.14286 .33903 Mdot
.14762 .47987 Mdot
.15238 .43919 Mdot
.15714 .39781 Mdot
.1619 .35767 Mdot
.16667 .424 Mdot
.17143 .41279 Mdot
.17619 .34993 Mdot
.18095 .43885 Mdot
.18571 .54542 Mdot
.19048 .4295 Mdot
.19524 .35915 Mdot
.2 .33986 Mdot
.20476 .44479 Mdot
.20952 .46428 Mdot
.21429 .40734 Mdot
.21905 .45988 Mdot
.22381 .45827 Mdot
.22857 .38236 Mdot
.23333 .47141 Mdot
.2381 .44237 Mdot
.24286 .38434 Mdot
.24762 .43112 Mdot
.25238 .43733 Mdot
.25714 .44561 Mdot
.2619 .37317 Mdot
.26667 .41489 Mdot
.27143 .43547 Mdot
.27619 .34796 Mdot
.28095 .42935 Mdot
.28571 .39644 Mdot
.29048 .39373 Mdot
.29524 .35442 Mdot
.3 .40492 Mdot
.30476 .34068 Mdot
.30952 .54449 Mdot
.31429 .43567 Mdot
.31905 .30422 Mdot
.32381 .33954 Mdot
.32857 .36801 Mdot
.33333 .42213 Mdot
.3381 .41089 Mdot
.34286 .37843 Mdot
.34762 .43434 Mdot
.35238 .43943 Mdot
.35714 .35784 Mdot
.3619 .34016 Mdot
.36667 .47473 Mdot
.37143 .35917 Mdot
.37619 .41112 Mdot
.38095 .33076 Mdot
.38571 .42386 Mdot
.39048 .40868 Mdot
.39524 .35897 Mdot
.4 .47234 Mdot
.40476 .30171 Mdot
.40952 .51794 Mdot
.41429 .44825 Mdot
.41905 .3412 Mdot
.42381 .44593 Mdot
.42857 .45243 Mdot
.43333 .41093 Mdot
.4381 .49622 Mdot
.44286 .4188 Mdot
.44762 .39807 Mdot
.45238 .39041 Mdot
.45714 .40301 Mdot
.4619 .3109 Mdot
.46667 .40243 Mdot
.47143 .47129 Mdot
.47619 .34061 Mdot
.48095 .38081 Mdot
.48571 .44431 Mdot
.49048 .30006 Mdot
.49524 .34991 Mdot
.5 .3579 Mdot
.50476 .40061 Mdot
.50952 .35057 Mdot
.51429 .45235 Mdot
.51905 .38162 Mdot
.52381 .36347 Mdot
.52857 .42188 Mdot
.53333 .44798 Mdot
.5381 .35327 Mdot
.54286 .44165 Mdot
.54762 .36357 Mdot
.55238 .35856 Mdot
.55714 .4465 Mdot
.5619 .45964 Mdot
.56667 .3899 Mdot
.57143 .36543 Mdot
.57619 .40801 Mdot
.58095 .41914 Mdot
.58571 .35866 Mdot
.59048 .46945 Mdot
.59524 .47888 Mdot
.6 .38602 Mdot
.60476 .41233 Mdot
.60952 .36953 Mdot
.61429 .41372 Mdot
.61905 .34706 Mdot
.62381 .37273 Mdot
.62857 .32362 Mdot
.63333 .41657 Mdot
.6381 .37426 Mdot
.64286 .34478 Mdot
.64762 .32893 Mdot
.65238 .3826 Mdot
.65714 .21336 Mdot
.6619 .46287 Mdot
.66667 .51296 Mdot
.67143 .35927 Mdot
.67619 .36479 Mdot
.68095 .43105 Mdot
.68571 .42737 Mdot
.69048 .47261 Mdot
.69524 .45571 Mdot
.7 .39803 Mdot
.70476 .34375 Mdot
.70952 .47893 Mdot
.71429 .42518 Mdot
.71905 .41308 Mdot
.72381 .35038 Mdot
.72857 .36696 Mdot
.73333 .39985 Mdot
.7381 .42206 Mdot
.74286 .39308 Mdot
.74762 .30168 Mdot
.75238 .49333 Mdot
.75714 .32385 Mdot
.7619 .33606 Mdot
.76667 .44779 Mdot
.77143 .29928 Mdot
.77619 .51246 Mdot
.78095 .43888 Mdot
.78571 .47806 Mdot
.79048 .4128 Mdot
.79524 .50082 Mdot
.8 .40847 Mdot
.80476 .50274 Mdot
.80952 .48098 Mdot
.81429 .39748 Mdot
.81905 .38862 Mdot
.82381 .37406 Mdot
.82857 .40552 Mdot
.83333 .42847 Mdot
.8381 .30738 Mdot
.84286 .38556 Mdot
.84762 .44327 Mdot
.85238 .3763 Mdot
.85714 .39643 Mdot
.8619 .37906 Mdot
.86667 .45681 Mdot
.87143 .31824 Mdot
.87619 .31872 Mdot
.88095 .45624 Mdot
.88571 .51772 Mdot
.89048 .44514 Mdot
.89524 .40071 Mdot
.9 .39923 Mdot
.90476 .3794 Mdot
.90952 .36337 Mdot
.91429 .41253 Mdot
.91905 .39877 Mdot
.92381 .33628 Mdot
.92857 .51757 Mdot
.93333 .39757 Mdot
.9381 .35416 Mdot
.94286 .33837 Mdot
.94762 .38252 Mdot
.95238 .45376 Mdot
.95714 .45644 Mdot
.9619 .42252 Mdot
.96667 .31914 Mdot
.97143 .39305 Mdot
.97619 .36297 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .28794 Mdot
.03333 .38757 Mdot
.0381 .40961 Mdot
.04286 .34143 Mdot
.04762 .45906 Mdot
.05238 .36183 Mdot
.05714 .41826 Mdot
.0619 .40529 Mdot
.06667 .38668 Mdot
.07143 .37002 Mdot
.07619 .35994 Mdot
.08095 .42921 Mdot
.08571 .39111 Mdot
.09048 .48569 Mdot
.09524 .40661 Mdot
.1 .3363 Mdot
.10476 .34705 Mdot
.10952 .40527 Mdot
.11429 .41724 Mdot
.11905 .3444 Mdot
.12381 .42418 Mdot
.12857 .42072 Mdot
.13333 .44647 Mdot
.1381 .48287 Mdot
.14286 .32863 Mdot
.14762 .46418 Mdot
.15238 .43688 Mdot
.15714 .38323 Mdot
.1619 .34327 Mdot
.16667 .41192 Mdot
.17143 .39874 Mdot
.17619 .35918 Mdot
.18095 .42452 Mdot
.18571 .55797 Mdot
.19048 .44061 Mdot
.19524 .343 Mdot
.2 .32973 Mdot
.20476 .46206 Mdot
.20952 .47869 Mdot
.21429 .39761 Mdot
.21905 .44283 Mdot
.22381 .47088 Mdot
.22857 .38439 Mdot
.23333 .45463 Mdot
.2381 .46144 Mdot
.24286 .40317 Mdot
.24762 .42344 Mdot
.25238 .41841 Mdot
.25714 .43016 Mdot
.2619 .38402 Mdot
.26667 .40043 Mdot
.27143 .43188 Mdot
.27619 .3362 Mdot
.28095 .44652 Mdot
.28571 .38695 Mdot
.29048 .4043 Mdot
.29524 .36401 Mdot
.3 .4014 Mdot
.30476 .33429 Mdot
.30952 .56313 Mdot
.31429 .43488 Mdot
.31905 .28841 Mdot
.32381 .3483 Mdot
.32857 .36037 Mdot
.33333 .40476 Mdot
.3381 .39828 Mdot
.34286 .36851 Mdot
.34762 .43407 Mdot
.35238 .45653 Mdot
.35714 .35001 Mdot
.3619 .32534 Mdot
.36667 .45627 Mdot
.37143 .35346 Mdot
.37619 .42507 Mdot
.38095 .34105 Mdot
.38571 .41288 Mdot
.39048 .4147 Mdot
.39524 .37202 Mdot
.4 .49126 Mdot
.40476 .29017 Mdot
.40952 .53443 Mdot
.41429 .45293 Mdot
.41905 .32196 Mdot
.42381 .44405 Mdot
.42857 .43882 Mdot
.43333 .42045 Mdot
.4381 .48787 Mdot
.44286 .40607 Mdot
.44762 .38906 Mdot
.45238 .38856 Mdot
.45714 .41339 Mdot
.4619 .29734 Mdot
.46667 .38546 Mdot
.47143 .48418 Mdot
.47619 .32196 Mdot
.48095 .36576 Mdot
.48571 .43335 Mdot
.49048 .28996 Mdot
.49524 .34382 Mdot
.5 .33899 Mdot
.50476 .38597 Mdot
.50952 .35354 Mdot
.51429 .45367 Mdot
.51905 .38184 Mdot
.52381 .35009 Mdot
.52857 .41593 Mdot
.53333 .44022 Mdot
.5381 .35939 Mdot
.54286 .46002 Mdot
.54762 .36892 Mdot
.55238 .37496 Mdot
.55714 .45094 Mdot
.5619 .44849 Mdot
.56667 .40438 Mdot
.57143 .35153 Mdot
.57619 .41021 Mdot
.58095 .40307 Mdot
.58571 .3466 Mdot
.59048 .47818 Mdot
.59524 .49549 Mdot
.6 .38499 Mdot
.60476 .39716 Mdot
.60952 .37983 Mdot
.61429 .4168 Mdot
.61905 .35551 Mdot
.62381 .36963 Mdot
.62857 .30694 Mdot
.63333 .40069 Mdot
.6381 .38722 Mdot
.64286 .32941 Mdot
.64762 .32115 Mdot
.65238 .36865 Mdot
.65714 .21977 Mdot
.6619 .47549 Mdot
.66667 .49609 Mdot
.67143 .34495 Mdot
.67619 .38158 Mdot
.68095 .43699 Mdot
.68571 .43975 Mdot
.69048 .48331 Mdot
.69524 .44555 Mdot
.7 .37987 Mdot
.70476 .32749 Mdot
.70952 .47733 Mdot
.71429 .40989 Mdot
.71905 .40904 Mdot
.72381 .36643 Mdot
.72857 .35878 Mdot
.73333 .41378 Mdot
.7381 .43041 Mdot
.74286 .37581 Mdot
.74762 .29044 Mdot
.75238 .49491 Mdot
.75714 .30629 Mdot
.7619 .32612 Mdot
.76667 .43056 Mdot
.77143 .285 Mdot
.77619 .49366 Mdot
.78095 .45194 Mdot
.78571 .49065 Mdot
.79048 .40584 Mdot
.79524 .50071 Mdot
.8 .40169 Mdot
.80476 .51015 Mdot
.80952 .46807 Mdot
.81429 .39318 Mdot
.81905 .39437 Mdot
.82381 .36325 Mdot
.82857 .38928 Mdot
.83333 .40946 Mdot
.8381 .31285 Mdot
.84286 .39306 Mdot
.84762 .45904 Mdot
.85238 .37088 Mdot
.85714 .38985 Mdot
.8619 .36907 Mdot
.86667 .44813 Mdot
.87143 .33426 Mdot
.87619 .33296 Mdot
.88095 .45128 Mdot
.88571 .51273 Mdot
.89048 .44754 Mdot
.89524 .38184 Mdot
.9 .41787 Mdot
.90476 .36042 Mdot
.90952 .35334 Mdot
.91429 .41596 Mdot
.91905 .41203 Mdot
.92381 .32918 Mdot
.92857 .52527 Mdot
.93333 .41088 Mdot
.9381 .37202 Mdot
.94286 .33657 Mdot
.94762 .39217 Mdot
.95238 .47302 Mdot
.95714 .46915 Mdot
.9619 .41326 Mdot
.96667 .3081 Mdot
.97143 .40397 Mdot
.97619 .35627 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .27347 Mdot
.03333 .37987 Mdot
.0381 .426 Mdot
.04286 .34914 Mdot
.04762 .44279 Mdot
.05238 .34457 Mdot
.05714 .41916 Mdot
.0619 .4241 Mdot
.06667 .37378 Mdot
.07143 .35159 Mdot
.07619 .34919 Mdot
.08095 .41355 Mdot
.08571 .40544 Mdot
.09048 .50188 Mdot
.09524 .40366 Mdot
.1 .32429 Mdot
.10476 .35316 Mdot
.10952 .40687 Mdot
.11429 .42003 Mdot
.11905 .3315 Mdot
.12381 .42826 Mdot
.12857 .43252 Mdot
.13333 .46039 Mdot
.1381 .48157 Mdot
.14286 .34318 Mdot
.14762 .462 Mdot
.15238 .42892 Mdot
.15714 .37291 Mdot
.1619 .32482 Mdot
.16667 .41983 Mdot
.17143 .39244 Mdot
.17619 .35938 Mdot
.18095 .43877 Mdot
.18571 .55195 Mdot
.19048 .42674 Mdot
.19524 .33825 Mdot
.2 .31702 Mdot
.20476 .4477 Mdot
.20952 .481 Mdot
.21429 .40157 Mdot
.21905 .45687 Mdot
.22381 .47395 Mdot
.22857 .39571 Mdot
.23333 .444 Mdot
.2381 .4728 Mdot
.24286 .40312 Mdot
.24762 .41364 Mdot
.25238 .39983 Mdot
.25714 .43253 Mdot
.2619 .36584 Mdot
.26667 .38848 Mdot
.27143 .43286 Mdot
.27619 .33023 Mdot
.28095 .44423 Mdot
.28571 .37526 Mdot
.29048 .41748 Mdot
.29524 .35544 Mdot
.3 .38242 Mdot
.30476 .33321 Mdot
.30952 .55375 Mdot
.31429 .43627 Mdot
.31905 .29101 Mdot
.32381 .34497 Mdot
.32857 .35763 Mdot
.33333 .39492 Mdot
.3381 .39357 Mdot
.34286 .37709 Mdot
.34762 .44611 Mdot
.35238 .44467 Mdot
.35714 .36353 Mdot
.3619 .30628 Mdot
.36667 .46759 Mdot
.37143 .34659 Mdot
.37619 .40785 Mdot
.38095 .33997 Mdot
.38571 .40517 Mdot
.39048 .41118 Mdot
.39524 .35557 Mdot
.4 .475 Mdot
.40476 .27735 Mdot
.40952 .55363 Mdot
.41429 .44819 Mdot
.41905 .33967 Mdot
.42381 .42612 Mdot
.42857 .45162 Mdot
.43333 .4279 Mdot
.4381 .49654 Mdot
.44286 .40431 Mdot
.44762 .3905 Mdot
.45238 .38448 Mdot
.45714 .40326 Mdot
.4619 .29155 Mdot
.46667 .3761 Mdot
.47143 .47062 Mdot
.47619 .33572 Mdot
.48095 .37108 Mdot
.48571 .44804 Mdot
.49048 .28039 Mdot
.49524 .33114 Mdot
.5 .32965 Mdot
.50476 .39268 Mdot
.50952 .35946 Mdot
.51429 .44753 Mdot
.51905 .37892 Mdot
.52381 .36605 Mdot
.52857 .42214 Mdot
.53333 .4215 Mdot
.5381 .34421 Mdot
.54286 .47253 Mdot
.54762 .35899 Mdot
.55238 .3757 Mdot
.55714 .43923 Mdot
.5619 .43187 Mdot
.56667 .42247 Mdot
.57143 .355 Mdot
.57619 .4008 Mdot
.58095 .38983 Mdot
.58571 .3437 Mdot
.59048 .47501 Mdot
.59524 .492 Mdot
.6 .38515 Mdot
.60476 .38901 Mdot
.60952 .36935 Mdot
.61429 .4034 Mdot
.61905 .34578 Mdot
.62381 .35879 Mdot
.62857 .30091 Mdot
.63333 .39831 Mdot
.6381 .38149 Mdot
.64286 .32507 Mdot
.64762 .33491 Mdot
.65238 .36377 Mdot
.65714 .21888 Mdot
.6619 .45854 Mdot
.66667 .48772 Mdot
.67143 .34175 Mdot
.67619 .37639 Mdot
.68095 .4479 Mdot
.68571 .44376 Mdot
.69048 .50064 Mdot
.69524 .45678 Mdot
.7 .36368 Mdot
.70476 .33584 Mdot
.70952 .49027 Mdot
.71429 .40236 Mdot
.71905 .42491 Mdot
.72381 .35839 Mdot
.72857 .36945 Mdot
.73333 .41836 Mdot
.7381 .41179 Mdot
.74286 .3755 Mdot
.74762 .29462 Mdot
.75238 .50259 Mdot
.75714 .30785 Mdot
.7619 .34062 Mdot
.76667 .43166 Mdot
.77143 .27316 Mdot
.77619 .47629 Mdot
.78095 .43285 Mdot
.78571 .49738 Mdot
.79048 .40811 Mdot
.79524 .50058 Mdot
.8 .41539 Mdot
.80476 .52875 Mdot
.80952 .45532 Mdot
.81429 .38691 Mdot
.81905 .38977 Mdot
.82381 .36645 Mdot
.82857 .3818 Mdot
.83333 .402 Mdot
.8381 .29803 Mdot
.84286 .38596 Mdot
.84762 .45306 Mdot
.85238 .36908 Mdot
.85714 .37389 Mdot
.8619 .35881 Mdot
.86667 .46516 Mdot
.87143 .33723 Mdot
.87619 .32778 Mdot
.88095 .45346 Mdot
.88571 .5205 Mdot
.89048 .45636 Mdot
.89524 .38678 Mdot
.9 .40348 Mdot
.90476 .3531 Mdot
.90952 .3366 Mdot
.91429 .40144 Mdot
.91905 .4164 Mdot
.92381 .34834 Mdot
.92857 .52599 Mdot
.93333 .39965 Mdot
.9381 .38595 Mdot
.94286 .33589 Mdot
.94762 .37497 Mdot
.95238 .46606 Mdot
.95714 .46353 Mdot
.9619 .42399 Mdot
.96667 .30655 Mdot
.97143 .39437 Mdot
.97619 .34705 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .27824 Mdot
.03333 .3848 Mdot
.0381 .41745 Mdot
.04286 .35722 Mdot
.04762 .44294 Mdot
.05238 .35443 Mdot
.05714 .4169 Mdot
.0619 .43728 Mdot
.06667 .37681 Mdot
.07143 .35388 Mdot
.07619 .33128 Mdot
.08095 .39729 Mdot
.08571 .40791 Mdot
.09048 .4889 Mdot
.09524 .4182 Mdot
.1 .30649 Mdot
.10476 .34159 Mdot
.10952 .40293 Mdot
.11429 .42145 Mdot
.11905 .3361 Mdot
.12381 .43229 Mdot
.12857 .42564 Mdot
.13333 .4505 Mdot
.1381 .4785 Mdot
.14286 .35077 Mdot
.14762 .44558 Mdot
.15238 .4186 Mdot
.15714 .35435 Mdot
.1619 .32104 Mdot
.16667 .40069 Mdot
.17143 .39211 Mdot
.17619 .35622 Mdot
.18095 .42381 Mdot
.18571 .54021 Mdot
.19048 .4113 Mdot
.19524 .33324 Mdot
.2 .30667 Mdot
.20476 .43355 Mdot
.20952 .46949 Mdot
.21429 .40315 Mdot
.21905 .43998 Mdot
.22381 .48916 Mdot
.22857 .41059 Mdot
.23333 .4317 Mdot
.2381 .47737 Mdot
.24286 .41999 Mdot
.24762 .43229 Mdot
.25238 .4025 Mdot
.25714 .4514 Mdot
.2619 .35536 Mdot
.26667 .37635 Mdot
.27143 .4405 Mdot
.27619 .32748 Mdot
.28095 .43476 Mdot
.28571 .38495 Mdot
.29048 .41123 Mdot
.29524 .37083 Mdot
.3 .38828 Mdot
.30476 .31504 Mdot
.30952 .55419 Mdot
.31429 .42936 Mdot
.31905 .27642 Mdot
.32381 .34857 Mdot
.32857 .37623 Mdot
.33333 .40873 Mdot
.3381 .37639 Mdot
.34286 .38415 Mdot
.34762 .46058 Mdot
.35238 .45731 Mdot
.35714 .35808 Mdot
.3619 .29571 Mdot
.36667 .47526 Mdot
.37143 .36583 Mdot
.37619 .42009 Mdot
.38095 .32396 Mdot
.38571 .39373 Mdot
.39048 .42084 Mdot
.39524 .35709 Mdot
.4 .46563 Mdot
.40476 .27769 Mdot
.40952 .56841 Mdot
.41429 .45952 Mdot
.41905 .32689 Mdot
.42381 .41077 Mdot
.42857 .46434 Mdot
.43333 .42742 Mdot
.4381 .49516 Mdot
.44286 .41114 Mdot
.44762 .39844 Mdot
.45238 .37545 Mdot
.45714 .40418 Mdot
.4619 .30667 Mdot
.46667 .36263 Mdot
.47143 .45627 Mdot
.47619 .32228 Mdot
.48095 .38585 Mdot
.48571 .43516 Mdot
.49048 .26351 Mdot
.49524 .32531 Mdot
.5 .32336 Mdot
.50476 .38199 Mdot
.50952 .34117 Mdot
.51429 .44519 Mdot
.51905 .36704 Mdot
.52381 .3479 Mdot
.52857 .4168 Mdot
.53333 .41513 Mdot
.5381 .33722 Mdot
.54286 .4595 Mdot
.54762 .36471 Mdot
.55238 .39452 Mdot
.55714 .44377 Mdot
.5619 .44292 Mdot
.56667 .40718 Mdot
.57143 .33777 Mdot
.57619 .40966 Mdot
.58095 .3978 Mdot
.58571 .33571 Mdot
.59048 .48711 Mdot
.59524 .47734 Mdot
.6 .36886 Mdot
.60476 .37622 Mdot
.60952 .35606 Mdot
.61429 .39371 Mdot
.61905 .35808 Mdot
.62381 .35994 Mdot
.62857 .28551 Mdot
.63333 .39813 Mdot
.6381 .38603 Mdot
.64286 .32927 Mdot
.64762 .33381 Mdot
.65238 .36435 Mdot
.65714 .21511 Mdot
.6619 .45427 Mdot
.66667 .4745 Mdot
.67143 .35188 Mdot
.67619 .3686 Mdot
.68095 .46009 Mdot
.68571 .45927 Mdot
.69048 .50408 Mdot
.69524 .46644 Mdot
.7 .38294 Mdot
.70476 .33793 Mdot
.70952 .48531 Mdot
.71429 .3966 Mdot
.71905 .40791 Mdot
.72381 .36761 Mdot
.72857 .35993 Mdot
.73333 .42292 Mdot
.7381 .41871 Mdot
.74286 .39255 Mdot
.74762 .30696 Mdot
.75238 .48788 Mdot
.75714 .32072 Mdot
.7619 .34446 Mdot
.76667 .41734 Mdot
.77143 .28183 Mdot
.77619 .47299 Mdot
.78095 .42194 Mdot
.78571 .48411 Mdot
.79048 .39751 Mdot
.79524 .49721 Mdot
.8 .43028 Mdot
.80476 .51725 Mdot
.80952 .45258 Mdot
.81429 .38044 Mdot
.81905 .40055 Mdot
.82381 .37162 Mdot
.82857 .39006 Mdot
.83333 .40328 Mdot
.8381 .29916 Mdot
.84286 .37637 Mdot
.84762 .46678 Mdot
.85238 .36037 Mdot
.85714 .36496 Mdot
.8619 .35306 Mdot
.86667 .46173 Mdot
.87143 .34939 Mdot
.87619 .31445 Mdot
.88095 .47151 Mdot
.88571 .52192 Mdot
.89048 .44909 Mdot
.89524 .37946 Mdot
.9 .41177 Mdot
.90476 .36175 Mdot
.90952 .33551 Mdot
.91429 .39478 Mdot
.91905 .4098 Mdot
.92381 .33242 Mdot
.92857 .5447 Mdot
.93333 .40247 Mdot
.9381 .4016 Mdot
.94286 .32429 Mdot
.94762 .35654 Mdot
.95238 .47432 Mdot
.95714 .45801 Mdot
.9619 .40929 Mdot
.96667 .30367 Mdot
.97143 .39927 Mdot
.97619 .3299 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .26138 Mdot
.03333 .36603 Mdot
.0381 .40635 Mdot
.04286 .36257 Mdot
.04762 .43562 Mdot
.05238 .35733 Mdot
.05714 .40163 Mdot
.0619 .43637 Mdot
.06667 .3634 Mdot
.07143 .34388 Mdot
.07619 .31963 Mdot
.08095 .38962 Mdot
.08571 .40873 Mdot
.09048 .49258 Mdot
.09524 .41953 Mdot
.1 .2921 Mdot
.10476 .34897 Mdot
.10952 .39816 Mdot
.11429 .42362 Mdot
.11905 .3234 Mdot
.12381 .44624 Mdot
.12857 .43295 Mdot
.13333 .45869 Mdot
.1381 .46715 Mdot
.14286 .3425 Mdot
.14762 .4534 Mdot
.15238 .40588 Mdot
.15714 .35996 Mdot
.1619 .33341 Mdot
.16667 .40496 Mdot
.17143 .38929 Mdot
.17619 .35211 Mdot
.18095 .41822 Mdot
.18571 .52542 Mdot
.19048 .40167 Mdot
.19524 .32895 Mdot
.2 .31243 Mdot
.20476 .4162 Mdot
.20952 .48588 Mdot
.21429 .40094 Mdot
.21905 .43248 Mdot
.22381 .50756 Mdot
.22857 .40138 Mdot
.23333 .41813 Mdot
.2381 .48587 Mdot
.24286 .41655 Mdot
.24762 .41621 Mdot
.25238 .41395 Mdot
.25714 .44115 Mdot
.2619 .34624 Mdot
.26667 .36559 Mdot
.27143 .4309 Mdot
.27619 .34654 Mdot
.28095 .42638 Mdot
.28571 .37102 Mdot
.29048 .42372 Mdot
.29524 .36514 Mdot
.3 .37046 Mdot
.30476 .32778 Mdot
.30952 .5359 Mdot
.31429 .41786 Mdot
.31905 .26217 Mdot
.32381 .33205 Mdot
.32857 .36253 Mdot
.33333 .4134 Mdot
.3381 .37886 Mdot
.34286 .3833 Mdot
.34762 .45178 Mdot
.35238 .47148 Mdot
.35714 .3474 Mdot
.3619 .31192 Mdot
.36667 .46134 Mdot
.37143 .34668 Mdot
.37619 .41128 Mdot
.38095 .3102 Mdot
.38571 .37567 Mdot
.39048 .43321 Mdot
.39524 .34895 Mdot
.4 .4747 Mdot
.40476 .26518 Mdot
.40952 .57408 Mdot
.41429 .46731 Mdot
.41905 .31354 Mdot
.42381 .40184 Mdot
.42857 .47002 Mdot
.43333 .42841 Mdot
.4381 .49573 Mdot
.44286 .40957 Mdot
.44762 .40338 Mdot
.45238 .36606 Mdot
.45714 .38681 Mdot
.4619 .30064 Mdot
.46667 .38065 Mdot
.47143 .44323 Mdot
.47619 .3379 Mdot
.48095 .38774 Mdot
.48571 .4189 Mdot
.49048 .27246 Mdot
.49524 .32444 Mdot
.5 .32379 Mdot
.50476 .37819 Mdot
.50952 .33323 Mdot
.51429 .44298 Mdot
.51905 .38414 Mdot
.52381 .36098 Mdot
.52857 .43056 Mdot
.53333 .41513 Mdot
.5381 .3272 Mdot
.54286 .46881 Mdot
.54762 .34798 Mdot
.55238 .39453 Mdot
.55714 .43013 Mdot
.5619 .43225 Mdot
.56667 .3932 Mdot
.57143 .35488 Mdot
.57619 .40631 Mdot
.58095 .39844 Mdot
.58571 .32552 Mdot
.59048 .48407 Mdot
.59524 .47459 Mdot
.6 .37825 Mdot
.60476 .37696 Mdot
.60952 .37063 Mdot
.61429 .40733 Mdot
.61905 .35169 Mdot
.62381 .34138 Mdot
.62857 .27867 Mdot
.63333 .39279 Mdot
.6381 .40329 Mdot
.64286 .31671 Mdot
.64762 .31848 Mdot
.65238 .3573 Mdot
.65714 .21685 Mdot
.6619 .43655 Mdot
.66667 .48647 Mdot
.67143 .3526 Mdot
.67619 .35344 Mdot
.68095 .45453 Mdot
.68571 .45012 Mdot
.69048 .50865 Mdot
.69524 .4695 Mdot
.7 .36584 Mdot
.70476 .33974 Mdot
.70952 .48157 Mdot
.71429 .38607 Mdot
.71905 .39544 Mdot
.72381 .36533 Mdot
.72857 .3506 Mdot
.73333 .43218 Mdot
.7381 .40937 Mdot
.74286 .37761 Mdot
.74762 .30353 Mdot
.75238 .49287 Mdot
.75714 .30792 Mdot
.7619 .33852 Mdot
.76667 .40998 Mdot
.77143 .26756 Mdot
.77619 .475 Mdot
.78095 .41132 Mdot
.78571 .47067 Mdot
.79048 .4097 Mdot
.79524 .47863 Mdot
.8 .44597 Mdot
.80476 .51343 Mdot
.80952 .43894 Mdot
.81429 .36292 Mdot
.81905 .38793 Mdot
.82381 .3893 Mdot
.82857 .39916 Mdot
.83333 .39872 Mdot
.8381 .31541 Mdot
.84286 .36316 Mdot
.84762 .45257 Mdot
.85238 .34705 Mdot
.85714 .34674 Mdot
.8619 .34262 Mdot
.86667 .48072 Mdot
.87143 .35127 Mdot
.87619 .31909 Mdot
.88095 .46949 Mdot
.88571 .51826 Mdot
.89048 .43358 Mdot
.89524 .36732 Mdot
.9 .42534 Mdot
.90476 .38068 Mdot
.90952 .33324 Mdot
.91429 .41238 Mdot
.91905 .39536 Mdot
.92381 .31312 Mdot
.92857 .53826 Mdot
.93333 .3901 Mdot
.9381 .38598 Mdot
.94286 .31655 Mdot
.94762 .34879 Mdot
.95238 .47849 Mdot
.95714 .43933 Mdot
.9619 .39776 Mdot
.96667 .28799 Mdot
.97143 .38203 Mdot
.97619 .33294 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .26541 Mdot
.03333 .36231 Mdot
.0381 .42492 Mdot
.04286 .37018 Mdot
.04762 .43713 Mdot
.05238 .36935 Mdot
.05714 .38465 Mdot
.0619 .4439 Mdot
.06667 .36847 Mdot
.07143 .34815 Mdot
.07619 .32753 Mdot
.08095 .3781 Mdot
.08571 .40295 Mdot
.09048 .48194 Mdot
.09524 .42472 Mdot
.1 .29325 Mdot
.10476 .36444 Mdot
.10952 .40925 Mdot
.11429 .43016 Mdot
.11905 .31881 Mdot
.12381 .4293 Mdot
.12857 .44563 Mdot
.13333 .45169 Mdot
.1381 .45705 Mdot
.14286 .35103 Mdot
.14762 .46559 Mdot
.15238 .41515 Mdot
.15714 .35735 Mdot
.1619 .31872 Mdot
.16667 .40984 Mdot
.17143 .38238 Mdot
.17619 .34766 Mdot
.18095 .40288 Mdot
.18571 .52821 Mdot
.19048 .38374 Mdot
.19524 .33946 Mdot
.2 .29864 Mdot
.20476 .43497 Mdot
.20952 .47813 Mdot
.21429 .41567 Mdot
.21905 .42064 Mdot
.22381 .51466 Mdot
.22857 .38582 Mdot
.23333 .39895 Mdot
.2381 .47665 Mdot
.24286 .40277 Mdot
.24762 .4153 Mdot
.25238 .39646 Mdot
.25714 .43151 Mdot
.2619 .34864 Mdot
.26667 .37379 Mdot
.27143 .42625 Mdot
.27619 .33031 Mdot
.28095 .40735 Mdot
.28571 .35452 Mdot
.29048 .42521 Mdot
.29524 .35115 Mdot
.3 .38445 Mdot
.30476 .34394 Mdot
.30952 .5238 Mdot
.31429 .41435 Mdot
.31905 .25463 Mdot
.32381 .32542 Mdot
.32857 .38075 Mdot
.33333 .40735 Mdot
.3381 .36714 Mdot
.34286 .36926 Mdot
.34762 .4334 Mdot
.35238 .45708 Mdot
.35714 .34588 Mdot
.3619 .31984 Mdot
.36667 .46259 Mdot
.37143 .34443 Mdot
.37619 .41479 Mdot
.38095 .31913 Mdot
.38571 .39034 Mdot
.39048 .42083 Mdot
.39524 .34566 Mdot
.4 .4858 Mdot
.40476 .28303 Mdot
.40952 .58402 Mdot
.41429 .45184 Mdot
.41905 .3117 Mdot
.42381 .41001 Mdot
.42857 .4802 Mdot
.43333 .41238 Mdot
.4381 .49641 Mdot
.44286 .42352 Mdot
.44762 .38888 Mdot
.45238 .35108 Mdot
.45714 .38434 Mdot
.4619 .29487 Mdot
.46667 .38387 Mdot
.47143 .44195 Mdot
.47619 .34495 Mdot
.48095 .3948 Mdot
.48571 .42466 Mdot
.49048 .27907 Mdot
.49524 .33145 Mdot
.5 .30537 Mdot
.50476 .37853 Mdot
.50952 .34176 Mdot
.51429 .45958 Mdot
.51905 .37841 Mdot
.52381 .37253 Mdot
.52857 .42989 Mdot
.53333 .42947 Mdot
.5381 .33838 Mdot
.54286 .46115 Mdot
.54762 .35334 Mdot
.55238 .38342 Mdot
.55714 .43566 Mdot
.5619 .43231 Mdot
.56667 .37623 Mdot
.57143 .34429 Mdot
.57619 .40367 Mdot
.58095 .40491 Mdot
.58571 .31599 Mdot
.59048 .49806 Mdot
.59524 .47859 Mdot
.6 .38263 Mdot
.60476 .36355 Mdot
.60952 .35177 Mdot
.61429 .41297 Mdot
.61905 .36358 Mdot
.62381 .33304 Mdot
.62857 .26558 Mdot
.63333 .37757 Mdot
.6381 .39292 Mdot
.64286 .32378 Mdot
.64762 .31006 Mdot
.65238 .36797 Mdot
.65714 .21016 Mdot
.6619 .42085 Mdot
.66667 .49749 Mdot
.67143 .33376 Mdot
.67619 .34471 Mdot
.68095 .47182 Mdot
.68571 .43106 Mdot
.69048 .49637 Mdot
.69524 .4785 Mdot
.7 .376 Mdot
.70476 .32569 Mdot
.70952 .47823 Mdot
.71429 .36863 Mdot
.71905 .40131 Mdot
.72381 .35002 Mdot
.72857 .33994 Mdot
.73333 .42804 Mdot
.7381 .39973 Mdot
.74286 .39554 Mdot
.74762 .28804 Mdot
.75238 .47735 Mdot
.75714 .31398 Mdot
.7619 .32013 Mdot
.76667 .40738 Mdot
.77143 .2865 Mdot
.77619 .48166 Mdot
.78095 .42309 Mdot
.78571 .45725 Mdot
.79048 .4091 Mdot
.79524 .49071 Mdot
.8 .44277 Mdot
.80476 .50602 Mdot
.80952 .43473 Mdot
.81429 .37602 Mdot
.81905 .37453 Mdot
.82381 .40318 Mdot
.82857 .41837 Mdot
.83333 .40492 Mdot
.8381 .30019 Mdot
.84286 .34833 Mdot
.84762 .45747 Mdot
.85238 .33524 Mdot
.85714 .34951 Mdot
.8619 .33436 Mdot
.86667 .47172 Mdot
.87143 .34211 Mdot
.87619 .30874 Mdot
.88095 .48128 Mdot
.88571 .50555 Mdot
.89048 .42609 Mdot
.89524 .37409 Mdot
.9 .41877 Mdot
.90476 .37637 Mdot
.90952 .34421 Mdot
.91429 .41176 Mdot
.91905 .39293 Mdot
.92381 .29736 Mdot
.92857 .5452 Mdot
.93333 .37424 Mdot
.9381 .38057 Mdot
.94286 .33023 Mdot
.94762 .34983 Mdot
.95238 .4626 Mdot
.95714 .43385 Mdot
.9619 .4061 Mdot
.96667 .27691 Mdot
.97143 .37463 Mdot
.97619 .33002 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .24711 Mdot
.03333 .36035 Mdot
.0381 .42477 Mdot
.04286 .37135 Mdot
.04762 .42143 Mdot
.05238 .35906 Mdot
.05714 .39913 Mdot
.0619 .4422 Mdot
.06667 .35406 Mdot
.07143 .32992 Mdot
.07619 .325 Mdot
.08095 .3753 Mdot
.08571 .40284 Mdot
.09048 .50056 Mdot
.09524 .41423 Mdot
.1 .30748 Mdot
.10476 .35484 Mdot
.10952 .40546 Mdot
.11429 .42558 Mdot
.11905 .31577 Mdot
.12381 .43947 Mdot
.12857 .4464 Mdot
.13333 .46063 Mdot
.1381 .46454 Mdot
.14286 .33646 Mdot
.14762 .47382 Mdot
.15238 .40148 Mdot
.15714 .35479 Mdot
.1619 .33559 Mdot
.16667 .39598 Mdot
.17143 .36468 Mdot
.17619 .354 Mdot
.18095 .39389 Mdot
.18571 .53841 Mdot
.19048 .38858 Mdot
.19524 .32863 Mdot
.2 .30082 Mdot
.20476 .41722 Mdot
.20952 .48787 Mdot
.21429 .40079 Mdot
.21905 .4151 Mdot
.22381 .50636 Mdot
.22857 .38752 Mdot
.23333 .40446 Mdot
.2381 .47761 Mdot
.24286 .38986 Mdot
.24762 .42841 Mdot
.25238 .40033 Mdot
.25714 .44157 Mdot
.2619 .34097 Mdot
.26667 .38848 Mdot
.27143 .42794 Mdot
.27619 .33952 Mdot
.28095 .41082 Mdot
.28571 .34552 Mdot
.29048 .41855 Mdot
.29524 .33251 Mdot
.3 .39277 Mdot
.30476 .35354 Mdot
.30952 .51656 Mdot
.31429 .42578 Mdot
.31905 .2555 Mdot
.32381 .30959 Mdot
.32857 .383 Mdot
.33333 .41958 Mdot
.3381 .372 Mdot
.34286 .35537 Mdot
.34762 .44196 Mdot
.35238 .44721 Mdot
.35714 .3551 Mdot
.3619 .316 Mdot
.36667 .45497 Mdot
.37143 .33531 Mdot
.37619 .42357 Mdot
.38095 .31137 Mdot
.38571 .39799 Mdot
.39048 .41341 Mdot
.39524 .33222 Mdot
.4 .49544 Mdot
.40476 .26602 Mdot
.40952 .59939 Mdot
.41429 .44077 Mdot
.41905 .32038 Mdot
.42381 .40887 Mdot
.42857 .46479 Mdot
.43333 .39564 Mdot
.4381 .50152 Mdot
.44286 .4096 Mdot
.44762 .37323 Mdot
.45238 .35822 Mdot
.45714 .36731 Mdot
.4619 .29076 Mdot
.46667 .37577 Mdot
.47143 .42422 Mdot
.47619 .33191 Mdot
.48095 .38173 Mdot
.48571 .41079 Mdot
.49048 .2975 Mdot
.49524 .3342 Mdot
.5 .2867 Mdot
.50476 .38072 Mdot
.50952 .34401 Mdot
.51429 .44643 Mdot
.51905 .38386 Mdot
.52381 .38396 Mdot
.52857 .44667 Mdot
.53333 .43978 Mdot
.5381 .33454 Mdot
.54286 .45288 Mdot
.54762 .36896 Mdot
.55238 .36997 Mdot
.55714 .45452 Mdot
.5619 .44389 Mdot
.56667 .38498 Mdot
.57143 .32993 Mdot
.57619 .39596 Mdot
.58095 .41762 Mdot
.58571 .32324 Mdot
.59048 .49303 Mdot
.59524 .46915 Mdot
.6 .40033 Mdot
.60476 .36135 Mdot
.60952 .34908 Mdot
.61429 .42194 Mdot
.61905 .35486 Mdot
.62381 .32699 Mdot
.62857 .25541 Mdot
.63333 .38668 Mdot
.6381 .37754 Mdot
.64286 .30603 Mdot
.64762 .31785 Mdot
.65238 .35195 Mdot
.65714 .20862 Mdot
.6619 .43309 Mdot
.66667 .48577 Mdot
.67143 .32965 Mdot
.67619 .34903 Mdot
.68095 .46954 Mdot
.68571 .44496 Mdot
.69048 .51058 Mdot
.69524 .46627 Mdot
.7 .36189 Mdot
.70476 .32076 Mdot
.70952 .46956 Mdot
.71429 .34958 Mdot
.71905 .40158 Mdot
.72381 .34757 Mdot
.72857 .35379 Mdot
.73333 .41295 Mdot
.7381 .40649 Mdot
.74286 .39056 Mdot
.74762 .30388 Mdot
.75238 .48333 Mdot
.75714 .32898 Mdot
.7619 .33437 Mdot
.76667 .40146 Mdot
.77143 .2776 Mdot
.77619 .46931 Mdot
.78095 .40993 Mdot
.78571 .46188 Mdot
.79048 .42328 Mdot
.79524 .50599 Mdot
.8 .45208 Mdot
.80476 .50658 Mdot
.80952 .4476 Mdot
.81429 .38345 Mdot
.81905 .36176 Mdot
.82381 .4142 Mdot
.82857 .42295 Mdot
.83333 .41735 Mdot
.8381 .31379 Mdot
.84286 .36008 Mdot
.84762 .45196 Mdot
.85238 .34842 Mdot
.85714 .3512 Mdot
.8619 .33186 Mdot
.86667 .45991 Mdot
.87143 .36046 Mdot
.87619 .30864 Mdot
.88095 .46569 Mdot
.88571 .52174 Mdot
.89048 .40787 Mdot
.89524 .37205 Mdot
.9 .41562 Mdot
.90476 .37848 Mdot
.90952 .33131 Mdot
.91429 .39695 Mdot
.91905 .38798 Mdot
.92381 .30054 Mdot
.92857 .55013 Mdot
.93333 .35625 Mdot
.9381 .37236 Mdot
.94286 .31999 Mdot
.94762 .33848 Mdot
.95238 .44817 Mdot
.95714 .41834 Mdot
.9619 .39371 Mdot
.96667 .28597 Mdot
.97143 .37474 Mdot
.97619 .31783 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23724 Mdot
.03333 .37682 Mdot
.0381 .42266 Mdot
.04286 .36811 Mdot
.04762 .40628 Mdot
.05238 .36619 Mdot
.05714 .39746 Mdot
.0619 .43139 Mdot
.06667 .35134 Mdot
.07143 .31691 Mdot
.07619 .33717 Mdot
.08095 .37271 Mdot
.08571 .38608 Mdot
.09048 .48381 Mdot
.09524 .42004 Mdot
.1 .31181 Mdot
.10476 .35706 Mdot
.10952 .42157 Mdot
.11429 .43506 Mdot
.11905 .31041 Mdot
.12381 .43716 Mdot
.12857 .43336 Mdot
.13333 .44141 Mdot
.1381 .46792 Mdot
.14286 .32819 Mdot
.14762 .4592 Mdot
.15238 .38436 Mdot
.15714 .35079 Mdot
.1619 .35487 Mdot
.16667 .38978 Mdot
.17143 .35214 Mdot
.17619 .36095 Mdot
.18095 .37955 Mdot
.18571 .52473 Mdot
.19048 .39182 Mdot
.19524 .31371 Mdot
.2 .30231 Mdot
.20476 .4033 Mdot
.20952 .48292 Mdot
.21429 .38274 Mdot
.21905 .43361 Mdot
.22381 .49662 Mdot
.22857 .38088 Mdot
.23333 .39007 Mdot
.2381 .48083 Mdot
.24286 .39789 Mdot
.24762 .42424 Mdot
.25238 .41021 Mdot
.25714 .44025 Mdot
.2619 .3466 Mdot
.26667 .38404 Mdot
.27143 .42123 Mdot
.27619 .34579 Mdot
.28095 .40576 Mdot
.28571 .34005 Mdot
.29048 .42588 Mdot
.29524 .31811 Mdot
.3 .38023 Mdot
.30476 .36002 Mdot
.30952 .5246 Mdot
.31429 .41944 Mdot
.31905 .25287 Mdot
.32381 .29615 Mdot
.32857 .38858 Mdot
.33333 .41171 Mdot
.3381 .36098 Mdot
.34286 .36133 Mdot
.34762 .45785 Mdot
.35238 .43638 Mdot
.35714 .33997 Mdot
.3619 .3178 Mdot
.36667 .4676 Mdot
.37143 .33098 Mdot
.37619 .40981 Mdot
.38095 .29622 Mdot
.38571 .38469 Mdot
.39048 .41101 Mdot
.39524 .34134 Mdot
.4 .47696 Mdot
.40476 .25639 Mdot
.40952 .58362 Mdot
.41429 .44433 Mdot
.41905 .31734 Mdot
.42381 .42306 Mdot
.42857 .44885 Mdot
.43333 .40495 Mdot
.4381 .48361 Mdot
.44286 .41429 Mdot
.44762 .37765 Mdot
.45238 .34474 Mdot
.45714 .37621 Mdot
.4619 .30459 Mdot
.46667 .36179 Mdot
.47143 .41574 Mdot
.47619 .33519 Mdot
.48095 .36548 Mdot
.48571 .40205 Mdot
.49048 .30047 Mdot
.49524 .31595 Mdot
.5 .28611 Mdot
.50476 .36667 Mdot
.50952 .33425 Mdot
.51429 .46418 Mdot
.51905 .37765 Mdot
.52381 .36501 Mdot
.52857 .45539 Mdot
.53333 .43369 Mdot
.5381 .31958 Mdot
.54286 .43607 Mdot
.54762 .36508 Mdot
.55238 .37275 Mdot
.55714 .4505 Mdot
.5619 .42494 Mdot
.56667 .37951 Mdot
.57143 .32643 Mdot
.57619 .40604 Mdot
.58095 .41101 Mdot
.58571 .33936 Mdot
.59048 .48859 Mdot
.59524 .48333 Mdot
.6 .39387 Mdot
.60476 .36743 Mdot
.60952 .33924 Mdot
.61429 .40418 Mdot
.61905 .34399 Mdot
.62381 .30773 Mdot
.62857 .24939 Mdot
.63333 .38853 Mdot
.6381 .36891 Mdot
.64286 .31369 Mdot
.64762 .31986 Mdot
.65238 .34638 Mdot
.65714 .20211 Mdot
.6619 .44514 Mdot
.66667 .48098 Mdot
.67143 .33275 Mdot
.67619 .35211 Mdot
.68095 .48789 Mdot
.68571 .43238 Mdot
.69048 .52132 Mdot
.69524 .46475 Mdot
.7 .35698 Mdot
.70476 .31127 Mdot
.70952 .4883 Mdot
.71429 .35052 Mdot
.71905 .40338 Mdot
.72381 .33359 Mdot
.72857 .35113 Mdot
.73333 .4265 Mdot
.7381 .39883 Mdot
.74286 .38922 Mdot
.74762 .30419 Mdot
.75238 .4769 Mdot
.75714 .32015 Mdot
.7619 .34925 Mdot
.76667 .40927 Mdot
.77143 .26488 Mdot
.77619 .47597 Mdot
.78095 .4165 Mdot
.78571 .47159 Mdot
.79048 .41473 Mdot
.79524 .50939 Mdot
.8 .44371 Mdot
.80476 .49253 Mdot
.80952 .43019 Mdot
.81429 .3786 Mdot
.81905 .35772 Mdot
.82381 .39968 Mdot
.82857 .41001 Mdot
.83333 .40036 Mdot
.8381 .29452 Mdot
.84286 .34308 Mdot
.84762 .44901 Mdot
.85238 .34152 Mdot
.85714 .34413 Mdot
.8619 .33798 Mdot
.86667 .44764 Mdot
.87143 .35379 Mdot
.87619 .30654 Mdot
.88095 .46753 Mdot
.88571 .51751 Mdot
.89048 .42678 Mdot
.89524 .37941 Mdot
.9 .4142 Mdot
.90476 .37566 Mdot
.90952 .31444 Mdot
.91429 .4019 Mdot
.91905 .37369 Mdot
.92381 .31911 Mdot
.92857 .53134 Mdot
.93333 .36303 Mdot
.9381 .36598 Mdot
.94286 .32158 Mdot
.94762 .33658 Mdot
.95238 .42983 Mdot
.95714 .4312 Mdot
.9619 .38258 Mdot
.96667 .30034 Mdot
.97143 .36625 Mdot
.97619 .31418 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .25198 Mdot
.03333 .36315 Mdot
.0381 .42335 Mdot
.04286 .37561 Mdot
.04762 .41871 Mdot
.05238 .37534 Mdot
.05714 .394 Mdot
.0619 .44049 Mdot
.06667 .34145 Mdot
.07143 .30324 Mdot
.07619 .34205 Mdot
.08095 .36436 Mdot
.08571 .3864 Mdot
.09048 .4697 Mdot
.09524 .43474 Mdot
.1 .30612 Mdot
.10476 .35086 Mdot
.10952 .4081 Mdot
.11429 .41585 Mdot
.11905 .30464 Mdot
.12381 .43302 Mdot
.12857 .44496 Mdot
.13333 .44505 Mdot
.1381 .44915 Mdot
.14286 .31952 Mdot
.14762 .4638 Mdot
.15238 .371 Mdot
.15714 .3423 Mdot
.1619 .36923 Mdot
.16667 .37719 Mdot
.17143 .36808 Mdot
.17619 .3455 Mdot
.18095 .38741 Mdot
.18571 .54064 Mdot
.19048 .3852 Mdot
.19524 .30913 Mdot
.2 .30576 Mdot
.20476 .40306 Mdot
.20952 .49213 Mdot
.21429 .3766 Mdot
.21905 .44862 Mdot
.22381 .51034 Mdot
.22857 .38022 Mdot
.23333 .40571 Mdot
.2381 .46417 Mdot
.24286 .40759 Mdot
.24762 .41074 Mdot
.25238 .42939 Mdot
.25714 .45336 Mdot
.2619 .36193 Mdot
.26667 .39203 Mdot
.27143 .40639 Mdot
.27619 .35653 Mdot
.28095 .40977 Mdot
.28571 .33973 Mdot
.29048 .43257 Mdot
.29524 .3082 Mdot
.3 .37429 Mdot
.30476 .37373 Mdot
.30952 .54316 Mdot
.31429 .4154 Mdot
.31905 .26695 Mdot
.32381 .28735 Mdot
.32857 .38108 Mdot
.33333 .41527 Mdot
.3381 .34324 Mdot
.34286 .3744 Mdot
.34762 .44307 Mdot
.35238 .44556 Mdot
.35714 .32167 Mdot
.3619 .29939 Mdot
.36667 .46499 Mdot
.37143 .33518 Mdot
.37619 .4169 Mdot
.38095 .2814 Mdot
.38571 .37657 Mdot
.39048 .39979 Mdot
.39524 .32775 Mdot
.4 .4726 Mdot
.40476 .24228 Mdot
.40952 .56738 Mdot
.41429 .43796 Mdot
.41905 .32215 Mdot
.42381 .42817 Mdot
.42857 .44846 Mdot
.43333 .40045 Mdot
.4381 .50289 Mdot
.44286 .41794 Mdot
.44762 .36672 Mdot
.45238 .34113 Mdot
.45714 .36743 Mdot
.4619 .31267 Mdot
.46667 .37649 Mdot
.47143 .4015 Mdot
.47619 .33597 Mdot
.48095 .38146 Mdot
.48571 .4056 Mdot
.49048 .29033 Mdot
.49524 .31457 Mdot
.5 .27911 Mdot
.50476 .34852 Mdot
.50952 .32143 Mdot
.51429 .44784 Mdot
.51905 .36238 Mdot
.52381 .34585 Mdot
.52857 .44869 Mdot
.53333 .45043 Mdot
.5381 .30123 Mdot
.54286 .41685 Mdot
.54762 .37705 Mdot
.55238 .36919 Mdot
.55714 .43396 Mdot
.5619 .41265 Mdot
.56667 .36581 Mdot
.57143 .31714 Mdot
.57619 .40074 Mdot
.58095 .41099 Mdot
.58571 .3204 Mdot
.59048 .47943 Mdot
.59524 .48761 Mdot
.6 .3889 Mdot
.60476 .36552 Mdot
.60952 .32056 Mdot
.61429 .39706 Mdot
.61905 .35249 Mdot
.62381 .30868 Mdot
.62857 .25853 Mdot
.63333 .37891 Mdot
.6381 .35988 Mdot
.64286 .32528 Mdot
.64762 .30519 Mdot
.65238 .3476 Mdot
.65714 .18512 Mdot
.6619 .43556 Mdot
.66667 .48902 Mdot
.67143 .33029 Mdot
.67619 .34603 Mdot
.68095 .47454 Mdot
.68571 .433 Mdot
.69048 .50552 Mdot
.69524 .44641 Mdot
.7 .35963 Mdot
.70476 .30291 Mdot
.70952 .50297 Mdot
.71429 .35279 Mdot
.71905 .399 Mdot
.72381 .31486 Mdot
.72857 .36685 Mdot
.73333 .40929 Mdot
.7381 .40866 Mdot
.74286 .40236 Mdot
.74762 .29285 Mdot
.75238 .45828 Mdot
.75714 .30957 Mdot
.7619 .33517 Mdot
.76667 .41501 Mdot
.77143 .24695 Mdot
.77619 .48212 Mdot
.78095 .40312 Mdot
.78571 .48017 Mdot
.79048 .40733 Mdot
.79524 .49087 Mdot
.8 .4377 Mdot
.80476 .48979 Mdot
.80952 .44007 Mdot
.81429 .39571 Mdot
.81905 .35305 Mdot
.82381 .38736 Mdot
.82857 .40803 Mdot
.83333 .38703 Mdot
.8381 .28928 Mdot
.84286 .34869 Mdot
.84762 .45634 Mdot
.85238 .33304 Mdot
.85714 .35064 Mdot
.8619 .33478 Mdot
.86667 .43821 Mdot
.87143 .33796 Mdot
.87619 .30324 Mdot
.88095 .47897 Mdot
.88571 .50425 Mdot
.89048 .4449 Mdot
.89524 .39739 Mdot
.9 .42219 Mdot
.90476 .37744 Mdot
.90952 .29752 Mdot
.91429 .40316 Mdot
.91905 .36945 Mdot
.92381 .30437 Mdot
.92857 .51975 Mdot
.93333 .36478 Mdot
.9381 .37881 Mdot
.94286 .31045 Mdot
.94762 .34433 Mdot
.95238 .42233 Mdot
.95714 .41815 Mdot
.9619 .38002 Mdot
.96667 .30441 Mdot
.97143 .37416 Mdot
.97619 .316 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23844 Mdot
.03333 .35485 Mdot
.0381 .43263 Mdot
.04286 .38162 Mdot
.04762 .43304 Mdot
.05238 .36125 Mdot
.05714 .39512 Mdot
.0619 .43721 Mdot
.06667 .35077 Mdot
.07143 .29227 Mdot
.07619 .33914 Mdot
.08095 .35496 Mdot
.08571 .39009 Mdot
.09048 .4885 Mdot
.09524 .43364 Mdot
.1 .29702 Mdot
.10476 .33576 Mdot
.10952 .40366 Mdot
.11429 .41827 Mdot
.11905 .31398 Mdot
.12381 .43189 Mdot
.12857 .45929 Mdot
.13333 .45281 Mdot
.1381 .45928 Mdot
.14286 .3345 Mdot
.14762 .47068 Mdot
.15238 .39025 Mdot
.15714 .33986 Mdot
.1619 .38108 Mdot
.16667 .39599 Mdot
.17143 .35291 Mdot
.17619 .36187 Mdot
.18095 .37813 Mdot
.18571 .55229 Mdot
.19048 .37171 Mdot
.19524 .2935 Mdot
.2 .30254 Mdot
.20476 .39788 Mdot
.20952 .47842 Mdot
.21429 .37126 Mdot
.21905 .45536 Mdot
.22381 .52816 Mdot
.22857 .3692 Mdot
.23333 .40955 Mdot
.2381 .46763 Mdot
.24286 .39453 Mdot
.24762 .39422 Mdot
.25238 .44157 Mdot
.25714 .44156 Mdot
.2619 .34778 Mdot
.26667 .39616 Mdot
.27143 .39916 Mdot
.27619 .34881 Mdot
.28095 .40718 Mdot
.28571 .32643 Mdot
.29048 .43793 Mdot
.29524 .30222 Mdot
.3 .37487 Mdot
.30476 .35861 Mdot
.30952 .56207 Mdot
.31429 .41545 Mdot
.31905 .28264 Mdot
.32381 .28963 Mdot
.32857 .36192 Mdot
.33333 .40227 Mdot
.3381 .3445 Mdot
.34286 .35961 Mdot
.34762 .44787 Mdot
.35238 .43002 Mdot
.35714 .33891 Mdot
.3619 .28106 Mdot
.36667 .47239 Mdot
.37143 .35017 Mdot
.37619 .40193 Mdot
.38095 .26477 Mdot
.38571 .36155 Mdot
.39048 .39597 Mdot
.39524 .32614 Mdot
.4 .46145 Mdot
.40476 .22488 Mdot
.40952 .57794 Mdot
.41429 .41984 Mdot
.41905 .31843 Mdot
.42381 .41585 Mdot
.42857 .45089 Mdot
.43333 .38386 Mdot
.4381 .51206 Mdot
.44286 .43657 Mdot
.44762 .36566 Mdot
.45238 .32255 Mdot
.45714 .35104 Mdot
.4619 .32642 Mdot
.46667 .36645 Mdot
.47143 .41714 Mdot
.47619 .33182 Mdot
.48095 .38961 Mdot
.48571 .40901 Mdot
.49048 .28409 Mdot
.49524 .3043 Mdot
.5 .27893 Mdot
.50476 .35774 Mdot
.50952 .33907 Mdot
.51429 .42988 Mdot
.51905 .37201 Mdot
.52381 .33459 Mdot
.52857 .43189 Mdot
.53333 .46124 Mdot
.5381 .30582 Mdot
.54286 .40189 Mdot
.54762 .37468 Mdot
.55238 .35869 Mdot
.55714 .42867 Mdot
.5619 .41961 Mdot
.56667 .38286 Mdot
.57143 .32823 Mdot
.57619 .3893 Mdot
.58095 .41832 Mdot
.58571 .33427 Mdot
.59048 .46852 Mdot
.59524 .47844 Mdot
.6 .40522 Mdot
.60476 .3635 Mdot
.60952 .31707 Mdot
.61429 .41352 Mdot
.61905 .35247 Mdot
.62381 .30911 Mdot
.62857 .24843 Mdot
.63333 .3937 Mdot
.6381 .36018 Mdot
.64286 .34162 Mdot
.64762 .291 Mdot
.65238 .35121 Mdot
.65714 .18137 Mdot
.6619 .45431 Mdot
.66667 .48634 Mdot
.67143 .31525 Mdot
.67619 .3287 Mdot
.68095 .46764 Mdot
.68571 .45094 Mdot
.69048 .4961 Mdot
.69524 .43574 Mdot
.7 .35916 Mdot
.70476 .30751 Mdot
.70952 .49719 Mdot
.71429 .34971 Mdot
.71905 .393 Mdot
.72381 .31899 Mdot
.72857 .37383 Mdot
.73333 .39915 Mdot
.7381 .40759 Mdot
.74286 .39988 Mdot
.74762 .2919 Mdot
.75238 .47619 Mdot
.75714 .30493 Mdot
.7619 .33482 Mdot
.76667 .42426 Mdot
.77143 .26553 Mdot
.77619 .49366 Mdot
.78095 .41097 Mdot
.78571 .47956 Mdot
.79048 .39006 Mdot
.79524 .49178 Mdot
.8 .44674 Mdot
.80476 .47102 Mdot
.80952 .43858 Mdot
.81429 .40891 Mdot
.81905 .35009 Mdot
.82381 .39521 Mdot
.82857 .40526 Mdot
.83333 .38871 Mdot
.8381 .27529 Mdot
.84286 .33825 Mdot
.84762 .47469 Mdot
.85238 .31672 Mdot
.85714 .34043 Mdot
.8619 .32846 Mdot
.86667 .4224 Mdot
.87143 .34727 Mdot
.87619 .2858 Mdot
.88095 .45988 Mdot
.88571 .50889 Mdot
.89048 .45923 Mdot
.89524 .3785 Mdot
.9 .41599 Mdot
.90476 .38505 Mdot
.90952 .29693 Mdot
.91429 .41606 Mdot
.91905 .36121 Mdot
.92381 .31072 Mdot
.92857 .53697 Mdot
.93333 .35055 Mdot
.9381 .36127 Mdot
.94286 .3285 Mdot
.94762 .3512 Mdot
.95238 .41547 Mdot
.95714 .43124 Mdot
.9619 .3621 Mdot
.96667 .3042 Mdot
.97143 .37184 Mdot
.97619 .32251 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .24559 Mdot
.03333 .34768 Mdot
.0381 .42028 Mdot
.04286 .36241 Mdot
.04762 .42968 Mdot
.05238 .36116 Mdot
.05714 .38762 Mdot
.0619 .42592 Mdot
.06667 .35185 Mdot
.07143 .29634 Mdot
.07619 .32498 Mdot
.08095 .36998 Mdot
.08571 .39539 Mdot
.09048 .4756 Mdot
.09524 .42014 Mdot
.1 .30703 Mdot
.10476 .34277 Mdot
.10952 .38703 Mdot
.11429 .40991 Mdot
.11905 .3016 Mdot
.12381 .446 Mdot
.12857 .45045 Mdot
.13333 .46064 Mdot
.1381 .44914 Mdot
.14286 .35108 Mdot
.14762 .46177 Mdot
.15238 .37757 Mdot
.15714 .34324 Mdot
.1619 .39948 Mdot
.16667 .38409 Mdot
.17143 .35965 Mdot
.17619 .37038 Mdot
.18095 .36449 Mdot
.18571 .54842 Mdot
.19048 .359 Mdot
.19524 .28178 Mdot
.2 .29272 Mdot
.20476 .38457 Mdot
.20952 .46961 Mdot
.21429 .36513 Mdot
.21905 .4681 Mdot
.22381 .51227 Mdot
.22857 .3642 Mdot
.23333 .41087 Mdot
.2381 .45893 Mdot
.24286 .38149 Mdot
.24762 .4047 Mdot
.25238 .43138 Mdot
.25714 .4262 Mdot
.2619 .35327 Mdot
.26667 .3953 Mdot
.27143 .38338 Mdot
.27619 .35725 Mdot
.28095 .39365 Mdot
.28571 .32951 Mdot
.29048 .44645 Mdot
.29524 .32115 Mdot
.3 .38077 Mdot
.30476 .35309 Mdot
.30952 .55993 Mdot
.31429 .39697 Mdot
.31905 .29201 Mdot
.32381 .29071 Mdot
.32857 .35926 Mdot
.33333 .40732 Mdot
.3381 .3563 Mdot
.34286 .36256 Mdot
.34762 .45415 Mdot
.35238 .41395 Mdot
.35714 .34048 Mdot
.3619 .29679 Mdot
.36667 .48855 Mdot
.37143 .3693 Mdot
.37619 .41438 Mdot
.38095 .27707 Mdot
.38571 .37684 Mdot
.39048 .3853 Mdot
.39524 .31693 Mdot
.4 .45069 Mdot
.40476 .22412 Mdot
.40952 .57483 Mdot
.41429 .42144 Mdot
.41905 .33249 Mdot
.42381 .42802 Mdot
.42857 .43484 Mdot
.43333 .37117 Mdot
.4381 .49324 Mdot
.44286 .43747 Mdot
.44762 .37298 Mdot
.45238 .319 Mdot
.45714 .34386 Mdot
.4619 .33228 Mdot
.46667 .34929 Mdot
.47143 .42401 Mdot
.47619 .32478 Mdot
.48095 .38309 Mdot
.48571 .39585 Mdot
.49048 .30283 Mdot
.49524 .29416 Mdot
.5 .27516 Mdot
.50476 .34751 Mdot
.50952 .3426 Mdot
.51429 .41484 Mdot
.51905 .36625 Mdot
.52381 .31587 Mdot
.52857 .42867 Mdot
.53333 .46642 Mdot
.5381 .32246 Mdot
.54286 .40806 Mdot
.54762 .37665 Mdot
.55238 .34346 Mdot
.55714 .42798 Mdot
.5619 .40827 Mdot
.56667 .37202 Mdot
.57143 .33478 Mdot
.57619 .38456 Mdot
.58095 .41102 Mdot
.58571 .3246 Mdot
.59048 .4538 Mdot
.59524 .48543 Mdot
.6 .41727 Mdot
.60476 .36322 Mdot
.60952 .31833 Mdot
.61429 .42249 Mdot
.61905 .36663 Mdot
.62381 .29386 Mdot
.62857 .26152 Mdot
.63333 .39634 Mdot
.6381 .3469 Mdot
.64286 .32835 Mdot
.64762 .29497 Mdot
.65238 .34706 Mdot
.65714 .19169 Mdot
.6619 .44236 Mdot
.66667 .4859 Mdot
.67143 .3078 Mdot
.67619 .33208 Mdot
.68095 .4702 Mdot
.68571 .44741 Mdot
.69048 .49156 Mdot
.69524 .42693 Mdot
.7 .35646 Mdot
.70476 .29808 Mdot
.70952 .49779 Mdot
.71429 .34019 Mdot
.71905 .37987 Mdot
.72381 .30353 Mdot
.72857 .35544 Mdot
.73333 .38613 Mdot
.7381 .39049 Mdot
.74286 .38695 Mdot
.74762 .30608 Mdot
.75238 .45899 Mdot
.75714 .29427 Mdot
.7619 .32556 Mdot
.76667 .40683 Mdot
.77143 .27909 Mdot
.77619 .48379 Mdot
.78095 .41041 Mdot
.78571 .47788 Mdot
.79048 .38979 Mdot
.79524 .50825 Mdot
.8 .44031 Mdot
.80476 .45296 Mdot
.80952 .43052 Mdot
.81429 .417 Mdot
.81905 .36937 Mdot
.82381 .39328 Mdot
.82857 .40099 Mdot
.83333 .38183 Mdot
.8381 .25614 Mdot
.84286 .33562 Mdot
.84762 .48771 Mdot
.85238 .31329 Mdot
.85714 .33311 Mdot
.8619 .31169 Mdot
.86667 .4371 Mdot
.87143 .34356 Mdot
.87619 .30036 Mdot
.88095 .45873 Mdot
.88571 .5241 Mdot
.89048 .47468 Mdot
.89524 .39707 Mdot
.9 .43078 Mdot
.90476 .3809 Mdot
.90952 .28704 Mdot
.91429 .43321 Mdot
.91905 .34837 Mdot
.92381 .29613 Mdot
.92857 .53716 Mdot
.93333 .35903 Mdot
.9381 .36049 Mdot
.94286 .33428 Mdot
.94762 .34994 Mdot
.95238 .40804 Mdot
.95714 .42885 Mdot
.9619 .3709 Mdot
.96667 .32087 Mdot
.97143 .36861 Mdot
.97619 .30887 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23882 Mdot
.03333 .33931 Mdot
.0381 .43248 Mdot
.04286 .34611 Mdot
.04762 .41255 Mdot
.05238 .34501 Mdot
.05714 .38642 Mdot
.0619 .42045 Mdot
.06667 .34869 Mdot
.07143 .29012 Mdot
.07619 .31351 Mdot
.08095 .3693 Mdot
.08571 .3773 Mdot
.09048 .45832 Mdot
.09524 .42187 Mdot
.1 .31829 Mdot
.10476 .35166 Mdot
.10952 .38088 Mdot
.11429 .42885 Mdot
.11905 .29322 Mdot
.12381 .44106 Mdot
.12857 .46307 Mdot
.13333 .45875 Mdot
.1381 .45456 Mdot
.14286 .33252 Mdot
.14762 .46175 Mdot
.15238 .38317 Mdot
.15714 .3318 Mdot
.1619 .41047 Mdot
.16667 .38126 Mdot
.17143 .35887 Mdot
.17619 .36724 Mdot
.18095 .34518 Mdot
.18571 .54002 Mdot
.19048 .34086 Mdot
.19524 .29023 Mdot
.2 .27801 Mdot
.20476 .38758 Mdot
.20952 .45856 Mdot
.21429 .37514 Mdot
.21905 .46215 Mdot
.22381 .49344 Mdot
.22857 .35872 Mdot
.23333 .39785 Mdot
.2381 .46957 Mdot
.24286 .36764 Mdot
.24762 .4053 Mdot
.25238 .42905 Mdot
.25714 .41376 Mdot
.2619 .3397 Mdot
.26667 .40627 Mdot
.27143 .39448 Mdot
.27619 .34028 Mdot
.28095 .39892 Mdot
.28571 .31083 Mdot
.29048 .4383 Mdot
.29524 .30984 Mdot
.3 .36874 Mdot
.30476 .33464 Mdot
.30952 .57026 Mdot
.31429 .41493 Mdot
.31905 .31054 Mdot
.32381 .29019 Mdot
.32857 .3408 Mdot
.33333 .39238 Mdot
.3381 .35541 Mdot
.34286 .3585 Mdot
.34762 .46378 Mdot
.35238 .40775 Mdot
.35714 .32273 Mdot
.3619 .2782 Mdot
.36667 .48163 Mdot
.37143 .37483 Mdot
.37619 .39732 Mdot
.38095 .26001 Mdot
.38571 .39078 Mdot
.39048 .39747 Mdot
.39524 .32157 Mdot
.4 .46861 Mdot
.40476 .23885 Mdot
.40952 .57417 Mdot
.41429 .41485 Mdot
.41905 .35114 Mdot
.42381 .42516 Mdot
.42857 .44109 Mdot
.43333 .35241 Mdot
.4381 .47972 Mdot
.44286 .42022 Mdot
.44762 .38317 Mdot
.45238 .31344 Mdot
.45714 .3501 Mdot
.4619 .31918 Mdot
.46667 .34055 Mdot
.47143 .42582 Mdot
.47619 .32328 Mdot
.48095 .37061 Mdot
.48571 .40811 Mdot
.49048 .29822 Mdot
.49524 .2774 Mdot
.5 .26197 Mdot
.50476 .34812 Mdot
.50952 .335 Mdot
.51429 .43042 Mdot
.51905 .35423 Mdot
.52381 .31085 Mdot
.52857 .42634 Mdot
.53333 .47664 Mdot
.5381 .31594 Mdot
.54286 .41572 Mdot
.54762 .38234 Mdot
.55238 .32946 Mdot
.55714 .43747 Mdot
.5619 .39424 Mdot
.56667 .37125 Mdot
.57143 .34568 Mdot
.57619 .38387 Mdot
.58095 .4297 Mdot
.58571 .32011 Mdot
.59048 .46144 Mdot
.59524 .49906 Mdot
.6 .42103 Mdot
.60476 .37583 Mdot
.60952 .31118 Mdot
.61429 .43138 Mdot
.61905 .34916 Mdot
.62381 .29795 Mdot
.62857 .24751 Mdot
.63333 .39419 Mdot
.6381 .33566 Mdot
.64286 .33873 Mdot
.64762 .30336 Mdot
.65238 .34155 Mdot
.65714 .20084 Mdot
.6619 .45154 Mdot
.66667 .46983 Mdot
.67143 .31527 Mdot
.67619 .33132 Mdot
.68095 .45095 Mdot
.68571 .46583 Mdot
.69048 .48413 Mdot
.69524 .42633 Mdot
.7 .36679 Mdot
.70476 .3152 Mdot
.70952 .48633 Mdot
.71429 .32356 Mdot
.71905 .38017 Mdot
.72381 .30556 Mdot
.72857 .37107 Mdot
.73333 .38995 Mdot
.7381 .38342 Mdot
.74286 .36773 Mdot
.74762 .29365 Mdot
.75238 .45601 Mdot
.75714 .27569 Mdot
.7619 .33564 Mdot
.76667 .41753 Mdot
.77143 .28517 Mdot
.77619 .4789 Mdot
.78095 .39538 Mdot
.78571 .48404 Mdot
.79048 .39326 Mdot
.79524 .50044 Mdot
.8 .43683 Mdot
.80476 .46407 Mdot
.80952 .41742 Mdot
.81429 .43106 Mdot
.81905 .36526 Mdot
.82381 .40747 Mdot
.82857 .39514 Mdot
.83333 .36874 Mdot
.8381 .25606 Mdot
.84286 .33699 Mdot
.84762 .47097 Mdot
.85238 .31808 Mdot
.85714 .3488 Mdot
.8619 .29649 Mdot
.86667 .4334 Mdot
.87143 .36002 Mdot
.87619 .28199 Mdot
.88095 .45678 Mdot
.88571 .51308 Mdot
.89048 .47085 Mdot
.89524 .41637 Mdot
.9 .42526 Mdot
.90476 .36175 Mdot
.90952 .30211 Mdot
.91429 .43771 Mdot
.91905 .33065 Mdot
.92381 .29909 Mdot
.92857 .52736 Mdot
.93333 .36841 Mdot
.9381 .36509 Mdot
.94286 .33481 Mdot
.94762 .33443 Mdot
.95238 .39645 Mdot
.95714 .41804 Mdot
.9619 .38041 Mdot
.96667 .31311 Mdot
.97143 .37199 Mdot
.97619 .3006 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .24113 Mdot
.03333 .33378 Mdot
.0381 .44799 Mdot
.04286 .33814 Mdot
.04762 .43043 Mdot
.05238 .34727 Mdot
.05714 .38375 Mdot
.0619 .40966 Mdot
.06667 .35377 Mdot
.07143 .28788 Mdot
.07619 .29516 Mdot
.08095 .37189 Mdot
.08571 .37419 Mdot
.09048 .44416 Mdot
.09524 .42838 Mdot
.1 .32464 Mdot
.10476 .3424 Mdot
.10952 .38962 Mdot
.11429 .43838 Mdot
.11905 .28995 Mdot
.12381 .43911 Mdot
.12857 .46712 Mdot
.13333 .46224 Mdot
.1381 .43934 Mdot
.14286 .31524 Mdot
.14762 .45883 Mdot
.15238 .38308 Mdot
.15714 .33406 Mdot
.1619 .40781 Mdot
.16667 .36917 Mdot
.17143 .36618 Mdot
.17619 .3596 Mdot
.18095 .34052 Mdot
.18571 .522 Mdot
.19048 .3317 Mdot
.19524 .30283 Mdot
.2 .27864 Mdot
.20476 .37481 Mdot
.20952 .44194 Mdot
.21429 .36805 Mdot
.21905 .46835 Mdot
.22381 .48945 Mdot
.22857 .371 Mdot
.23333 .39048 Mdot
.2381 .4524 Mdot
.24286 .35068 Mdot
.24762 .40266 Mdot
.25238 .41173 Mdot
.25714 .39885 Mdot
.2619 .35078 Mdot
.26667 .40055 Mdot
.27143 .39586 Mdot
.27619 .34129 Mdot
.28095 .38511 Mdot
.28571 .29212 Mdot
.29048 .42113 Mdot
.29524 .30935 Mdot
.3 .37108 Mdot
.30476 .32411 Mdot
.30952 .5672 Mdot
.31429 .40687 Mdot
.31905 .30352 Mdot
.32381 .27858 Mdot
.32857 .33254 Mdot
.33333 .37703 Mdot
.3381 .34544 Mdot
.34286 .34376 Mdot
.34762 .45955 Mdot
.35238 .42035 Mdot
.35714 .31077 Mdot
.3619 .27235 Mdot
.36667 .4827 Mdot
.37143 .36559 Mdot
.37619 .38451 Mdot
.38095 .26031 Mdot
.38571 .39446 Mdot
.39048 .4166 Mdot
.39524 .3054 Mdot
.4 .47803 Mdot
.40476 .23392 Mdot
.40952 .57118 Mdot
.41429 .42838 Mdot
.41905 .35457 Mdot
.42381 .43337 Mdot
.42857 .43476 Mdot
.43333 .34551 Mdot
.4381 .47965 Mdot
.44286 .40913 Mdot
.44762 .40187 Mdot
.45238 .29996 Mdot
.45714 .3647 Mdot
.4619 .32923 Mdot
.46667 .35897 Mdot
.47143 .44342 Mdot
.47619 .33062 Mdot
.48095 .35275 Mdot
.48571 .39529 Mdot
.49048 .2954 Mdot
.49524 .25869 Mdot
.5 .27708 Mdot
.50476 .33321 Mdot
.50952 .3375 Mdot
.51429 .41972 Mdot
.51905 .36756 Mdot
.52381 .29572 Mdot
.52857 .43472 Mdot
.53333 .46403 Mdot
.5381 .30716 Mdot
.54286 .40549 Mdot
.54762 .39791 Mdot
.55238 .31836 Mdot
.55714 .43111 Mdot
.5619 .38158 Mdot
.56667 .36163 Mdot
.57143 .35878 Mdot
.57619 .38036 Mdot
.58095 .44107 Mdot
.58571 .30318 Mdot
.59048 .46229 Mdot
.59524 .50141 Mdot
.6 .41361 Mdot
.60476 .37706 Mdot
.60952 .30376 Mdot
.61429 .41541 Mdot
.61905 .33912 Mdot
.62381 .28158 Mdot
.62857 .25175 Mdot
.63333 .40347 Mdot
.6381 .32388 Mdot
.64286 .32987 Mdot
.64762 .29397 Mdot
.65238 .35811 Mdot
.65714 .18351 Mdot
.6619 .43249 Mdot
.66667 .4611 Mdot
.67143 .31704 Mdot
.67619 .31371 Mdot
.68095 .46191 Mdot
.68571 .46923 Mdot
.69048 .48447 Mdot
.69524 .41621 Mdot
.7 .36455 Mdot
.70476 .30907 Mdot
.70952 .47257 Mdot
.71429 .33012 Mdot
.71905 .38637 Mdot
.72381 .29056 Mdot
.72857 .37287 Mdot
.73333 .39168 Mdot
.7381 .3853 Mdot
.74286 .35043 Mdot
.74762 .29195 Mdot
.75238 .452 Mdot
.75714 .27648 Mdot
.7619 .34186 Mdot
.76667 .42534 Mdot
.77143 .27602 Mdot
.77619 .47717 Mdot
.78095 .41211 Mdot
.78571 .50123 Mdot
.79048 .37435 Mdot
.79524 .49858 Mdot
.8 .43602 Mdot
.80476 .46914 Mdot
.80952 .40369 Mdot
.81429 .41271 Mdot
.81905 .35497 Mdot
.82381 .38984 Mdot
.82857 .38681 Mdot
.83333 .37498 Mdot
.8381 .25076 Mdot
.84286 .32215 Mdot
.84762 .47066 Mdot
.85238 .30406 Mdot
.85714 .33813 Mdot
.8619 .31158 Mdot
.86667 .41939 Mdot
.87143 .36633 Mdot
.87619 .28303 Mdot
.88095 .45689 Mdot
.88571 .51477 Mdot
.89048 .46594 Mdot
.89524 .41069 Mdot
.9 .43076 Mdot
.90476 .37846 Mdot
.90952 .30013 Mdot
.91429 .4547 Mdot
.91905 .33583 Mdot
.92381 .29451 Mdot
.92857 .54614 Mdot
.93333 .3513 Mdot
.9381 .35267 Mdot
.94286 .32762 Mdot
.94762 .33789 Mdot
.95238 .40302 Mdot
.95714 .43609 Mdot
.9619 .38214 Mdot
.96667 .32615 Mdot
.97143 .35698 Mdot
.97619 .30324 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .2489 Mdot
.03333 .34987 Mdot
.0381 .45015 Mdot
.04286 .33579 Mdot
.04762 .42059 Mdot
.05238 .36595 Mdot
.05714 .38016 Mdot
.0619 .40879 Mdot
.06667 .3442 Mdot
.07143 .30508 Mdot
.07619 .28683 Mdot
.08095 .36815 Mdot
.08571 .37458 Mdot
.09048 .45065 Mdot
.09524 .4165 Mdot
.1 .31266 Mdot
.10476 .33698 Mdot
.10952 .37048 Mdot
.11429 .42207 Mdot
.11905 .283 Mdot
.12381 .42023 Mdot
.12857 .47883 Mdot
.13333 .47685 Mdot
.1381 .42206 Mdot
.14286 .3084 Mdot
.14762 .4674 Mdot
.15238 .39872 Mdot
.15714 .31999 Mdot
.1619 .40094 Mdot
.16667 .38139 Mdot
.17143 .3619 Mdot
.17619 .34997 Mdot
.18095 .34951 Mdot
.18571 .51701 Mdot
.19048 .34249 Mdot
.19524 .30495 Mdot
.2 .27373 Mdot
.20476 .38597 Mdot
.20952 .43382 Mdot
.21429 .35652 Mdot
.21905 .46708 Mdot
.22381 .47782 Mdot
.22857 .36881 Mdot
.23333 .39812 Mdot
.2381 .4604 Mdot
.24286 .34061 Mdot
.24762 .3954 Mdot
.25238 .3983 Mdot
.25714 .4129 Mdot
.2619 .33356 Mdot
.26667 .38747 Mdot
.27143 .37709 Mdot
.27619 .32577 Mdot
.28095 .40392 Mdot
.28571 .29542 Mdot
.29048 .43081 Mdot
.29524 .29397 Mdot
.3 .36612 Mdot
.30476 .32527 Mdot
.30952 .55543 Mdot
.31429 .41928 Mdot
.31905 .29605 Mdot
.32381 .25944 Mdot
.32857 .31518 Mdot
.33333 .36726 Mdot
.3381 .33696 Mdot
.34286 .35828 Mdot
.34762 .45445 Mdot
.35238 .42081 Mdot
.35714 .32562 Mdot
.3619 .27449 Mdot
.36667 .49542 Mdot
.37143 .35644 Mdot
.37619 .37453 Mdot
.38095 .26061 Mdot
.38571 .40053 Mdot
.39048 .4357 Mdot
.39524 .30827 Mdot
.4 .46553 Mdot
.40476 .22219 Mdot
.40952 .57505 Mdot
.41429 .41794 Mdot
.41905 .36669 Mdot
.42381 .43639 Mdot
.42857 .4354 Mdot
.43333 .32807 Mdot
.4381 .49681 Mdot
.44286 .40143 Mdot
.44762 .38781 Mdot
.45238 .29006 Mdot
.45714 .36866 Mdot
.4619 .32459 Mdot
.46667 .36618 Mdot
.47143 .44599 Mdot
.47619 .33282 Mdot
.48095 .34481 Mdot
.48571 .39632 Mdot
.49048 .28753 Mdot
.49524 .24189 Mdot
.5 .26668 Mdot
.50476 .32476 Mdot
.50952 .31854 Mdot
.51429 .40928 Mdot
.51905 .37779 Mdot
.52381 .29846 Mdot
.52857 .44904 Mdot
.53333 .4613 Mdot
.5381 .2965 Mdot
.54286 .4121 Mdot
.54762 .39626 Mdot
.55238 .3189 Mdot
.55714 .4227 Mdot
.5619 .36855 Mdot
.56667 .348 Mdot
.57143 .35314 Mdot
.57619 .39379 Mdot
.58095 .42266 Mdot
.58571 .3209 Mdot
.59048 .44886 Mdot
.59524 .50146 Mdot
.6 .40318 Mdot
.60476 .3924 Mdot
.60952 .28686 Mdot
.61429 .42281 Mdot
.61905 .34628 Mdot
.62381 .28424 Mdot
.62857 .26469 Mdot
.63333 .42184 Mdot
.6381 .3384 Mdot
.64286 .33325 Mdot
.64762 .28415 Mdot
.65238 .3493 Mdot
.65714 .17424 Mdot
.6619 .42397 Mdot
.66667 .44295 Mdot
.67143 .33369 Mdot
.67619 .3019 Mdot
.68095 .44539 Mdot
.68571 .46434 Mdot
.69048 .49292 Mdot
.69524 .40591 Mdot
.7 .38134 Mdot
.70476 .32314 Mdot
.70952 .48417 Mdot
.71429 .31592 Mdot
.71905 .37852 Mdot
.72381 .2895 Mdot
.72857 .38014 Mdot
.73333 .39507 Mdot
.7381 .37552 Mdot
.74286 .3326 Mdot
.74762 .28687 Mdot
.75238 .44339 Mdot
.75714 .27115 Mdot
.7619 .33745 Mdot
.76667 .431 Mdot
.77143 .27706 Mdot
.77619 .4728 Mdot
.78095 .42701 Mdot
.78571 .48604 Mdot
.79048 .35904 Mdot
.79524 .49637 Mdot
.8 .43883 Mdot
.80476 .45392 Mdot
.80952 .40694 Mdot
.81429 .4309 Mdot
.81905 .33798 Mdot
.82381 .37533 Mdot
.82857 .38176 Mdot
.83333 .36878 Mdot
.8381 .24617 Mdot
.84286 .31379 Mdot
.84762 .45951 Mdot
.85238 .31569 Mdot
.85714 .33869 Mdot
.8619 .30942 Mdot
.86667 .40034 Mdot
.87143 .36496 Mdot
.87619 .26774 Mdot
.88095 .43764 Mdot
.88571 .50629 Mdot
.89048 .47101 Mdot
.89524 .39191 Mdot
.9 .44466 Mdot
.90476 .36483 Mdot
.90952 .29172 Mdot
.91429 .45636 Mdot
.91905 .33519 Mdot
.92381 .29747 Mdot
.92857 .53694 Mdot
.93333 .35935 Mdot
.9381 .35358 Mdot
.94286 .31408 Mdot
.94762 .34066 Mdot
.95238 .39778 Mdot
.95714 .43642 Mdot
.9619 .39534 Mdot
.96667 .31017 Mdot
.97143 .36286 Mdot
.97619 .28947 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .24876 Mdot
.03333 .35904 Mdot
.0381 .43659 Mdot
.04286 .32812 Mdot
.04762 .41767 Mdot
.05238 .37561 Mdot
.05714 .37598 Mdot
.0619 .38952 Mdot
.06667 .32692 Mdot
.07143 .30951 Mdot
.07619 .27702 Mdot
.08095 .35662 Mdot
.08571 .35795 Mdot
.09048 .46879 Mdot
.09524 .39768 Mdot
.1 .30576 Mdot
.10476 .33846 Mdot
.10952 .36471 Mdot
.11429 .42713 Mdot
.11905 .28242 Mdot
.12381 .42474 Mdot
.12857 .49488 Mdot
.13333 .46629 Mdot
.1381 .4063 Mdot
.14286 .31871 Mdot
.14762 .47006 Mdot
.15238 .41217 Mdot
.15714 .3278 Mdot
.1619 .401 Mdot
.16667 .37063 Mdot
.17143 .34654 Mdot
.17619 .36575 Mdot
.18095 .34277 Mdot
.18571 .50931 Mdot
.19048 .33225 Mdot
.19524 .30718 Mdot
.2 .25696 Mdot
.20476 .37164 Mdot
.20952 .4299 Mdot
.21429 .37303 Mdot
.21905 .46187 Mdot
.22381 .49172 Mdot
.22857 .35046 Mdot
.23333 .3836 Mdot
.2381 .45703 Mdot
.24286 .32702 Mdot
.24762 .39897 Mdot
.25238 .38222 Mdot
.25714 .40065 Mdot
.2619 .31966 Mdot
.26667 .39172 Mdot
.27143 .36827 Mdot
.27619 .32703 Mdot
.28095 .38899 Mdot
.28571 .29634 Mdot
.29048 .44203 Mdot
.29524 .30219 Mdot
.3 .36202 Mdot
.30476 .3136 Mdot
.30952 .54031 Mdot
.31429 .4191 Mdot
.31905 .30102 Mdot
.32381 .24529 Mdot
.32857 .32397 Mdot
.33333 .37727 Mdot
.3381 .3272 Mdot
.34286 .35051 Mdot
.34762 .4664 Mdot
.35238 .43855 Mdot
.35714 .32267 Mdot
.3619 .2599 Mdot
.36667 .4987 Mdot
.37143 .36408 Mdot
.37619 .36947 Mdot
.38095 .25823 Mdot
.38571 .41125 Mdot
.39048 .4479 Mdot
.39524 .31367 Mdot
.4 .45729 Mdot
.40476 .21866 Mdot
.40952 .57181 Mdot
.41429 .41698 Mdot
.41905 .36415 Mdot
.42381 .43422 Mdot
.42857 .43085 Mdot
.43333 .33951 Mdot
.4381 .48109 Mdot
.44286 .38495 Mdot
.44762 .40169 Mdot
.45238 .28875 Mdot
.45714 .3568 Mdot
.4619 .30614 Mdot
.46667 .35354 Mdot
.47143 .44289 Mdot
.47619 .3138 Mdot
.48095 .34438 Mdot
.48571 .41156 Mdot
.49048 .29507 Mdot
.49524 .24376 Mdot
.5 .28026 Mdot
.50476 .3058 Mdot
.50952 .31138 Mdot
.51429 .40041 Mdot
.51905 .38367 Mdot
.52381 .28958 Mdot
.52857 .4324 Mdot
.53333 .4584 Mdot
.5381 .31444 Mdot
.54286 .39937 Mdot
.54762 .41332 Mdot
.55238 .30829 Mdot
.55714 .43012 Mdot
.5619 .38351 Mdot
.56667 .33203 Mdot
.57143 .35753 Mdot
.57619 .37782 Mdot
.58095 .40826 Mdot
.58571 .3295 Mdot
.59048 .43095 Mdot
.59524 .48494 Mdot
.6 .41995 Mdot
.60476 .38956 Mdot
.60952 .27304 Mdot
.61429 .41717 Mdot
.61905 .32914 Mdot
.62381 .28736 Mdot
.62857 .25355 Mdot
.63333 .40587 Mdot
.6381 .34264 Mdot
.64286 .31953 Mdot
.64762 .27078 Mdot
.65238 .35497 Mdot
.65714 .18805 Mdot
.6619 .41601 Mdot
.66667 .42663 Mdot
.67143 .31544 Mdot
.67619 .29927 Mdot
.68095 .45814 Mdot
.68571 .46324 Mdot
.69048 .49468 Mdot
.69524 .40717 Mdot
.7 .36624 Mdot
.70476 .32797 Mdot
.70952 .4945 Mdot
.71429 .32388 Mdot
.71905 .37821 Mdot
.72381 .29626 Mdot
.72857 .37074 Mdot
.73333 .40264 Mdot
.7381 .37523 Mdot
.74286 .32162 Mdot
.74762 .26793 Mdot
.75238 .42773 Mdot
.75714 .27626 Mdot
.7619 .33029 Mdot
.76667 .44642 Mdot
.77143 .26828 Mdot
.77619 .46239 Mdot
.78095 .41083 Mdot
.78571 .47554 Mdot
.79048 .35563 Mdot
.79524 .48854 Mdot
.8 .42365 Mdot
.80476 .47207 Mdot
.80952 .41673 Mdot
.81429 .4367 Mdot
.81905 .33228 Mdot
.82381 .39153 Mdot
.82857 .37601 Mdot
.83333 .35271 Mdot
.8381 .25906 Mdot
.84286 .31622 Mdot
.84762 .46279 Mdot
.85238 .33429 Mdot
.85714 .35626 Mdot
.8619 .29621 Mdot
.86667 .40142 Mdot
.87143 .36907 Mdot
.87619 .26792 Mdot
.88095 .44871 Mdot
.88571 .51982 Mdot
.89048 .48442 Mdot
.89524 .4025 Mdot
.9 .45082 Mdot
.90476 .34572 Mdot
.90952 .29798 Mdot
.91429 .44388 Mdot
.91905 .32019 Mdot
.92381 .28933 Mdot
.92857 .54069 Mdot
.93333 .34131 Mdot
.9381 .36627 Mdot
.94286 .30617 Mdot
.94762 .32564 Mdot
.95238 .40422 Mdot
.95714 .45003 Mdot
.9619 .40881 Mdot
.96667 .32147 Mdot
.97143 .35791 Mdot
.97619 .28458 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23319 Mdot
.03333 .37663 Mdot
.0381 .43052 Mdot
.04286 .33748 Mdot
.04762 .40059 Mdot
.05238 .39322 Mdot
.05714 .36211 Mdot
.0619 .39666 Mdot
.06667 .31145 Mdot
.07143 .2935 Mdot
.07619 .27582 Mdot
.08095 .36721 Mdot
.08571 .34173 Mdot
.09048 .45228 Mdot
.09524 .38436 Mdot
.1 .29241 Mdot
.10476 .34871 Mdot
.10952 .34795 Mdot
.11429 .44507 Mdot
.11905 .26556 Mdot
.12381 .43993 Mdot
.12857 .49084 Mdot
.13333 .46611 Mdot
.1381 .41549 Mdot
.14286 .31161 Mdot
.14762 .4511 Mdot
.15238 .40048 Mdot
.15714 .31054 Mdot
.1619 .40351 Mdot
.16667 .3755 Mdot
.17143 .34336 Mdot
.17619 .35362 Mdot
.18095 .34691 Mdot
.18571 .4907 Mdot
.19048 .33809 Mdot
.19524 .30082 Mdot
.2 .26988 Mdot
.20476 .37741 Mdot
.20952 .43609 Mdot
.21429 .36024 Mdot
.21905 .44682 Mdot
.22381 .50711 Mdot
.22857 .35272 Mdot
.23333 .3993 Mdot
.2381 .44811 Mdot
.24286 .30839 Mdot
.24762 .39227 Mdot
.25238 .36892 Mdot
.25714 .40311 Mdot
.2619 .30978 Mdot
.26667 .37471 Mdot
.27143 .35192 Mdot
.27619 .30844 Mdot
.28095 .40693 Mdot
.28571 .29561 Mdot
.29048 .4242 Mdot
.29524 .28647 Mdot
.3 .36947 Mdot
.30476 .30508 Mdot
.30952 .5398 Mdot
.31429 .41854 Mdot
.31905 .31199 Mdot
.32381 .24231 Mdot
.32857 .3098 Mdot
.33333 .36999 Mdot
.3381 .33316 Mdot
.34286 .34114 Mdot
.34762 .47097 Mdot
.35238 .43411 Mdot
.35714 .31216 Mdot
.3619 .24841 Mdot
.36667 .49087 Mdot
.37143 .37649 Mdot
.37619 .36196 Mdot
.38095 .24294 Mdot
.38571 .42534 Mdot
.39048 .44223 Mdot
.39524 .31334 Mdot
.4 .44412 Mdot
.40476 .20463 Mdot
.40952 .55321 Mdot
.41429 .40817 Mdot
.41905 .3588 Mdot
.42381 .44839 Mdot
.42857 .41258 Mdot
.43333 .3574 Mdot
.4381 .46932 Mdot
.44286 .36572 Mdot
.44762 .41854 Mdot
.45238 .28593 Mdot
.45714 .37117 Mdot
.4619 .30698 Mdot
.46667 .34727 Mdot
.47143 .44458 Mdot
.47619 .31081 Mdot
.48095 .3487 Mdot
.48571 .40869 Mdot
.49048 .28839 Mdot
.49524 .24456 Mdot
.5 .27769 Mdot
.50476 .29619 Mdot
.50952 .3032 Mdot
.51429 .39055 Mdot
.51905 .39612 Mdot
.52381 .28592 Mdot
.52857 .43277 Mdot
.53333 .47171 Mdot
.5381 .30262 Mdot
.54286 .40589 Mdot
.54762 .39452 Mdot
.55238 .2895 Mdot
.55714 .43799 Mdot
.5619 .40209 Mdot
.56667 .31463 Mdot
.57143 .34693 Mdot
.57619 .37458 Mdot
.58095 .39645 Mdot
.58571 .33009 Mdot
.59048 .44151 Mdot
.59524 .48016 Mdot
.6 .42445 Mdot
.60476 .39007 Mdot
.60952 .2555 Mdot
.61429 .42302 Mdot
.61905 .31716 Mdot
.62381 .28509 Mdot
.62857 .25629 Mdot
.63333 .41454 Mdot
.6381 .32566 Mdot
.64286 .33754 Mdot
.64762 .26892 Mdot
.65238 .34689 Mdot
.65714 .20341 Mdot
.6619 .42557 Mdot
.66667 .41443 Mdot
.67143 .3164 Mdot
.67619 .30369 Mdot
.68095 .45385 Mdot
.68571 .46004 Mdot
.69048 .51118 Mdot
.69524 .41312 Mdot
.7 .35618 Mdot
.70476 .31168 Mdot
.70952 .48409 Mdot
.71429 .33927 Mdot
.71905 .36528 Mdot
.72381 .28923 Mdot
.72857 .35163 Mdot
.73333 .4118 Mdot
.7381 .38291 Mdot
.74286 .3096 Mdot
.74762 .26349 Mdot
.75238 .41722 Mdot
.75714 .27088 Mdot
.7619 .32495 Mdot
.76667 .46359 Mdot
.77143 .24909 Mdot
.77619 .45105 Mdot
.78095 .4215 Mdot
.78571 .45714 Mdot
.79048 .34547 Mdot
.79524 .4861 Mdot
.8 .41712 Mdot
.80476 .47364 Mdot
.80952 .42462 Mdot
.81429 .41847 Mdot
.81905 .34738 Mdot
.82381 .38508 Mdot
.82857 .39155 Mdot
.83333 .3674 Mdot
.8381 .25753 Mdot
.84286 .30175 Mdot
.84762 .45219 Mdot
.85238 .32602 Mdot
.85714 .34864 Mdot
.8619 .2952 Mdot
.86667 .40361 Mdot
.87143 .35543 Mdot
.87619 .25075 Mdot
.88095 .46443 Mdot
.88571 .50475 Mdot
.89048 .49335 Mdot
.89524 .38433 Mdot
.9 .43184 Mdot
.90476 .33443 Mdot
.90952 .28299 Mdot
.91429 .4393 Mdot
.91905 .32431 Mdot
.92381 .30349 Mdot
.92857 .53473 Mdot
.93333 .32449 Mdot
.9381 .36885 Mdot
.94286 .30086 Mdot
.94762 .32226 Mdot
.95238 .38709 Mdot
.95714 .44297 Mdot
.9619 .41821 Mdot
.96667 .30608 Mdot
.97143 .35006 Mdot
.97619 .28119 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .2166 Mdot
.03333 .38015 Mdot
.0381 .41771 Mdot
.04286 .32049 Mdot
.04762 .38294 Mdot
.05238 .39071 Mdot
.05714 .34343 Mdot
.0619 .39839 Mdot
.06667 .30352 Mdot
.07143 .28026 Mdot
.07619 .28045 Mdot
.08095 .38637 Mdot
.08571 .3441 Mdot
.09048 .43646 Mdot
.09524 .37015 Mdot
.1 .30406 Mdot
.10476 .33104 Mdot
.10952 .34221 Mdot
.11429 .46248 Mdot
.11905 .26095 Mdot
.12381 .42169 Mdot
.12857 .50291 Mdot
.13333 .46832 Mdot
.1381 .42875 Mdot
.14286 .29387 Mdot
.14762 .44906 Mdot
.15238 .40887 Mdot
.15714 .30351 Mdot
.1619 .41936 Mdot
.16667 .3801 Mdot
.17143 .36029 Mdot
.17619 .33989 Mdot
.18095 .34608 Mdot
.18571 .4755 Mdot
.19048 .32932 Mdot
.19524 .29866 Mdot
.2 .26004 Mdot
.20476 .38749 Mdot
.20952 .44123 Mdot
.21429 .35791 Mdot
.21905 .43608 Mdot
.22381 .5106 Mdot
.22857 .36288 Mdot
.23333 .38005 Mdot
.2381 .45528 Mdot
.24286 .31128 Mdot
.24762 .37927 Mdot
.25238 .36635 Mdot
.25714 .39522 Mdot
.2619 .29072 Mdot
.26667 .37521 Mdot
.27143 .36971 Mdot
.27619 .28975 Mdot
.28095 .4139 Mdot
.28571 .3086 Mdot
.29048 .40942 Mdot
.29524 .2707 Mdot
.3 .3841 Mdot
.30476 .30939 Mdot
.30952 .53402 Mdot
.31429 .40309 Mdot
.31905 .30742 Mdot
.32381 .22705 Mdot
.32857 .30937 Mdot
.33333 .35586 Mdot
.3381 .35018 Mdot
.34286 .34673 Mdot
.34762 .46784 Mdot
.35238 .43131 Mdot
.35714 .30064 Mdot
.3619 .23141 Mdot
.36667 .48246 Mdot
.37143 .37394 Mdot
.37619 .34485 Mdot
.38095 .2254 Mdot
.38571 .40864 Mdot
.39048 .44073 Mdot
.39524 .29531 Mdot
.4 .42687 Mdot
.40476 .19905 Mdot
.40952 .55392 Mdot
.41429 .39896 Mdot
.41905 .3669 Mdot
.42381 .44225 Mdot
.42857 .42492 Mdot
.43333 .36627 Mdot
.4381 .45803 Mdot
.44286 .36111 Mdot
.44762 .43351 Mdot
.45238 .26818 Mdot
.45714 .38741 Mdot
.4619 .29299 Mdot
.46667 .333 Mdot
.47143 .44079 Mdot
.47619 .29878 Mdot
.48095 .34745 Mdot
.48571 .39429 Mdot
.49048 .27001 Mdot
.49524 .23679 Mdot
.5 .26898 Mdot
.50476 .29008 Mdot
.50952 .29571 Mdot
.51429 .37869 Mdot
.51905 .38842 Mdot
.52381 .29959 Mdot
.52857 .43778 Mdot
.53333 .47378 Mdot
.5381 .3051 Mdot
.54286 .3888 Mdot
.54762 .38697 Mdot
.55238 .28722 Mdot
.55714 .42858 Mdot
.5619 .4113 Mdot
.56667 .30434 Mdot
.57143 .33915 Mdot
.57619 .39126 Mdot
.58095 .40796 Mdot
.58571 .31177 Mdot
.59048 .42492 Mdot
.59524 .49362 Mdot
.6 .44283 Mdot
.60476 .37188 Mdot
.60952 .241 Mdot
.61429 .43214 Mdot
.61905 .30333 Mdot
.62381 .27829 Mdot
.62857 .2692 Mdot
.63333 .39783 Mdot
.6381 .3203 Mdot
.64286 .3564 Mdot
.64762 .2604 Mdot
.65238 .3298 Mdot
.65714 .20459 Mdot
.6619 .43322 Mdot
.66667 .40557 Mdot
.67143 .31844 Mdot
.67619 .28784 Mdot
.68095 .44032 Mdot
.68571 .4587 Mdot
.69048 .51835 Mdot
.69524 .42469 Mdot
.7 .34774 Mdot
.70476 .29908 Mdot
.70952 .50166 Mdot
.71429 .35783 Mdot
.71905 .36207 Mdot
.72381 .28697 Mdot
.72857 .36786 Mdot
.73333 .42753 Mdot
.7381 .37313 Mdot
.74286 .31301 Mdot
.74762 .27529 Mdot
.75238 .42004 Mdot
.75714 .28242 Mdot
.7619 .32287 Mdot
.76667 .48009 Mdot
.77143 .26715 Mdot
.77619 .4533 Mdot
.78095 .41807 Mdot
.78571 .47398 Mdot
.79048 .33129 Mdot
.79524 .47748 Mdot
.8 .41194 Mdot
.80476 .47467 Mdot
.80952 .42184 Mdot
.81429 .42998 Mdot
.81905 .34787 Mdot
.82381 .3943 Mdot
.82857 .39204 Mdot
.83333 .36467 Mdot
.8381 .26633 Mdot
.84286 .2997 Mdot
.84762 .45405 Mdot
.85238 .30951 Mdot
.85714 .35241 Mdot
.8619 .28176 Mdot
.86667 .40119 Mdot
.87143 .35277 Mdot
.87619 .23768 Mdot
.88095 .48091 Mdot
.88571 .50021 Mdot
.89048 .48494 Mdot
.89524 .39625 Mdot
.9 .43531 Mdot
.90476 .34062 Mdot
.90952 .26968 Mdot
.91429 .45083 Mdot
.91905 .33286 Mdot
.92381 .29444 Mdot
.92857 .54081 Mdot
.93333 .31064 Mdot
.9381 .37839 Mdot
.94286 .30089 Mdot
.94762 .31303 Mdot
.95238 .39343 Mdot
.95714 .44214 Mdot
.9619 .40674 Mdot
.96667 .28901 Mdot
.97143 .36753 Mdot
.97619 .28909 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .22687 Mdot
.03333 .38672 Mdot
.0381 .43111 Mdot
.04286 .31488 Mdot
.04762 .36368 Mdot
.05238 .37985 Mdot
.05714 .34043 Mdot
.0619 .39886 Mdot
.06667 .28617 Mdot
.07143 .26997 Mdot
.07619 .26199 Mdot
.08095 .38599 Mdot
.08571 .3256 Mdot
.09048 .44387 Mdot
.09524 .38876 Mdot
.1 .32227 Mdot
.10476 .31976 Mdot
.10952 .33663 Mdot
.11429 .45117 Mdot
.11905 .24797 Mdot
.12381 .43163 Mdot
.12857 .50659 Mdot
.13333 .4838 Mdot
.1381 .43289 Mdot
.14286 .27835 Mdot
.14762 .44481 Mdot
.15238 .39723 Mdot
.15714 .29746 Mdot
.1619 .43489 Mdot
.16667 .38897 Mdot
.17143 .37397 Mdot
.17619 .34077 Mdot
.18095 .35728 Mdot
.18571 .49029 Mdot
.19048 .33219 Mdot
.19524 .30543 Mdot
.2 .27525 Mdot
.20476 .37568 Mdot
.20952 .44182 Mdot
.21429 .35344 Mdot
.21905 .43088 Mdot
.22381 .5258 Mdot
.22857 .34871 Mdot
.23333 .37607 Mdot
.2381 .46513 Mdot
.24286 .32028 Mdot
.24762 .36046 Mdot
.25238 .35581 Mdot
.25714 .37967 Mdot
.2619 .29466 Mdot
.26667 .36952 Mdot
.27143 .36767 Mdot
.27619 .28751 Mdot
.28095 .40753 Mdot
.28571 .31149 Mdot
.29048 .40553 Mdot
.29524 .27087 Mdot
.3 .36681 Mdot
.30476 .29382 Mdot
.30952 .54411 Mdot
.31429 .40815 Mdot
.31905 .31688 Mdot
.32381 .21011 Mdot
.32857 .30835 Mdot
.33333 .36434 Mdot
.3381 .34627 Mdot
.34286 .3436 Mdot
.34762 .4775 Mdot
.35238 .43112 Mdot
.35714 .29559 Mdot
.3619 .24218 Mdot
.36667 .46451 Mdot
.37143 .37136 Mdot
.37619 .36081 Mdot
.38095 .21116 Mdot
.38571 .40214 Mdot
.39048 .42316 Mdot
.39524 .28849 Mdot
.4 .43969 Mdot
.40476 .18825 Mdot
.40952 .55703 Mdot
.41429 .387 Mdot
.41905 .35087 Mdot
.42381 .42914 Mdot
.42857 .409 Mdot
.43333 .35554 Mdot
.4381 .46117 Mdot
.44286 .37546 Mdot
.44762 .41534 Mdot
.45238 .25711 Mdot
.45714 .39197 Mdot
.4619 .27894 Mdot
.46667 .33021 Mdot
.47143 .44066 Mdot
.47619 .28581 Mdot
.48095 .33155 Mdot
.48571 .40795 Mdot
.49048 .26422 Mdot
.49524 .22855 Mdot
.5 .28671 Mdot
.50476 .30672 Mdot
.50952 .27866 Mdot
.51429 .36749 Mdot
.51905 .40623 Mdot
.52381 .30266 Mdot
.52857 .44445 Mdot
.53333 .47113 Mdot
.5381 .30662 Mdot
.54286 .36983 Mdot
.54762 .38605 Mdot
.55238 .28544 Mdot
.55714 .42509 Mdot
.5619 .41661 Mdot
.56667 .30754 Mdot
.57143 .33047 Mdot
.57619 .39146 Mdot
.58095 .42073 Mdot
.58571 .321 Mdot
.59048 .41473 Mdot
.59524 .47897 Mdot
.6 .44687 Mdot
.60476 .37917 Mdot
.60952 .22885 Mdot
.61429 .42579 Mdot
.61905 .29003 Mdot
.62381 .2615 Mdot
.62857 .2676 Mdot
.63333 .40035 Mdot
.6381 .32585 Mdot
.64286 .34269 Mdot
.64762 .26923 Mdot
.65238 .33743 Mdot
.65714 .19298 Mdot
.6619 .44822 Mdot
.66667 .4244 Mdot
.67143 .30362 Mdot
.67619 .27 Mdot
.68095 .43008 Mdot
.68571 .4609 Mdot
.69048 .50132 Mdot
.69524 .42356 Mdot
.7 .3597 Mdot
.70476 .30704 Mdot
.70952 .49658 Mdot
.71429 .37535 Mdot
.71905 .37446 Mdot
.72381 .27551 Mdot
.72857 .35433 Mdot
.73333 .42577 Mdot
.7381 .38973 Mdot
.74286 .30316 Mdot
.74762 .25838 Mdot
.75238 .42217 Mdot
.75714 .26831 Mdot
.7619 .32196 Mdot
.76667 .47946 Mdot
.77143 .2509 Mdot
.77619 .46871 Mdot
.78095 .42281 Mdot
.78571 .48004 Mdot
.79048 .31508 Mdot
.79524 .48726 Mdot
.8 .39447 Mdot
.80476 .45935 Mdot
.80952 .41063 Mdot
.81429 .42315 Mdot
.81905 .34787 Mdot
.82381 .39931 Mdot
.82857 .39628 Mdot
.83333 .37892 Mdot
.8381 .25643 Mdot
.84286 .28427 Mdot
.84762 .43691 Mdot
.85238 .29362 Mdot
.85714 .33658 Mdot
.8619 .26464 Mdot
.86667 .39029 Mdot
.87143 .34914 Mdot
.87619 .23564 Mdot
.88095 .47905 Mdot
.88571 .50157 Mdot
.89048 .47839 Mdot
.89524 .40776 Mdot
.9 .45011 Mdot
.90476 .34305 Mdot
.90952 .25556 Mdot
.91429 .4643 Mdot
.91905 .3259 Mdot
.92381 .30413 Mdot
.92857 .52713 Mdot
.93333 .30215 Mdot
.9381 .36244 Mdot
.94286 .29213 Mdot
.94762 .30596 Mdot
.95238 .3949 Mdot
.95714 .43257 Mdot
.9619 .41475 Mdot
.96667 .27856 Mdot
.97143 .3756 Mdot
.97619 .26994 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .2237 Mdot
.03333 .37809 Mdot
.0381 .43743 Mdot
.04286 .3097 Mdot
.04762 .35089 Mdot
.05238 .37211 Mdot
.05714 .35842 Mdot
.0619 .4077 Mdot
.06667 .30308 Mdot
.07143 .27826 Mdot
.07619 .277 Mdot
.08095 .36968 Mdot
.08571 .32952 Mdot
.09048 .44925 Mdot
.09524 .37481 Mdot
.1 .3237 Mdot
.10476 .30427 Mdot
.10952 .34773 Mdot
.11429 .45752 Mdot
.11905 .23243 Mdot
.12381 .4242 Mdot
.12857 .52364 Mdot
.13333 .49757 Mdot
.1381 .43003 Mdot
.14286 .28957 Mdot
.14762 .43016 Mdot
.15238 .40373 Mdot
.15714 .28541 Mdot
.1619 .41707 Mdot
.16667 .3776 Mdot
.17143 .38476 Mdot
.17619 .3446 Mdot
.18095 .34642 Mdot
.18571 .48169 Mdot
.19048 .31761 Mdot
.19524 .3046 Mdot
.2 .2638 Mdot
.20476 .38837 Mdot
.20952 .4557 Mdot
.21429 .33794 Mdot
.21905 .41473 Mdot
.22381 .51144 Mdot
.22857 .34351 Mdot
.23333 .37205 Mdot
.2381 .44954 Mdot
.24286 .30577 Mdot
.24762 .37444 Mdot
.25238 .35888 Mdot
.25714 .37799 Mdot
.2619 .31355 Mdot
.26667 .35491 Mdot
.27143 .37339 Mdot
.27619 .29615 Mdot
.28095 .40872 Mdot
.28571 .30835 Mdot
.29048 .41245 Mdot
.29524 .28086 Mdot
.3 .35623 Mdot
.30476 .29394 Mdot
.30952 .5576 Mdot
.31429 .41196 Mdot
.31905 .3131 Mdot
.32381 .2256 Mdot
.32857 .29666 Mdot
.33333 .38252 Mdot
.3381 .36043 Mdot
.34286 .33594 Mdot
.34762 .45856 Mdot
.35238 .42024 Mdot
.35714 .2858 Mdot
.3619 .24172 Mdot
.36667 .44908 Mdot
.37143 .37312 Mdot
.37619 .37607 Mdot
.38095 .21306 Mdot
.38571 .41976 Mdot
.39048 .42747 Mdot
.39524 .28512 Mdot
.4 .44708 Mdot
.40476 .19753 Mdot
.40952 .56341 Mdot
.41429 .38575 Mdot
.41905 .35787 Mdot
.42381 .42316 Mdot
.42857 .39633 Mdot
.43333 .34209 Mdot
.4381 .44938 Mdot
.44286 .37285 Mdot
.44762 .40081 Mdot
.45238 .25386 Mdot
.45714 .40529 Mdot
.4619 .29659 Mdot
.46667 .31378 Mdot
.47143 .42233 Mdot
.47619 .28533 Mdot
.48095 .31419 Mdot
.48571 .39716 Mdot
.49048 .26217 Mdot
.49524 .2116 Mdot
.5 .2853 Mdot
.50476 .29154 Mdot
.50952 .29374 Mdot
.51429 .34823 Mdot
.51905 .38988 Mdot
.52381 .30514 Mdot
.52857 .43761 Mdot
.53333 .47758 Mdot
.5381 .30516 Mdot
.54286 .3653 Mdot
.54762 .38191 Mdot
.55238 .26904 Mdot
.55714 .41291 Mdot
.5619 .39944 Mdot
.56667 .29952 Mdot
.57143 .3302 Mdot
.57619 .41024 Mdot
.58095 .41247 Mdot
.58571 .31389 Mdot
.59048 .39994 Mdot
.59524 .49756 Mdot
.6 .44818 Mdot
.60476 .3797 Mdot
.60952 .21657 Mdot
.61429 .42965 Mdot
.61905 .28263 Mdot
.62381 .25176 Mdot
.62857 .27954 Mdot
.63333 .38571 Mdot
.6381 .33586 Mdot
.64286 .33186 Mdot
.64762 .2601 Mdot
.65238 .3438 Mdot
.65714 .18824 Mdot
.6619 .43782 Mdot
.66667 .40563 Mdot
.67143 .31269 Mdot
.67619 .26431 Mdot
.68095 .44277 Mdot
.68571 .45283 Mdot
.69048 .50464 Mdot
.69524 .41734 Mdot
.7 .34333 Mdot
.70476 .32324 Mdot
.70952 .47797 Mdot
.71429 .36253 Mdot
.71905 .38039 Mdot
.72381 .29263 Mdot
.72857 .36492 Mdot
.73333 .4105 Mdot
.7381 .38398 Mdot
.74286 .30018 Mdot
.74762 .24061 Mdot
.75238 .42987 Mdot
.75714 .27765 Mdot
.7619 .33134 Mdot
.76667 .49014 Mdot
.77143 .23512 Mdot
.77619 .47097 Mdot
.78095 .42025 Mdot
.78571 .46982 Mdot
.79048 .31258 Mdot
.79524 .49276 Mdot
.8 .40233 Mdot
.80476 .45912 Mdot
.80952 .41727 Mdot
.81429 .41336 Mdot
.81905 .34267 Mdot
.82381 .41791 Mdot
.82857 .39356 Mdot
.83333 .38198 Mdot
.8381 .27426 Mdot
.84286 .26653 Mdot
.84762 .4445 Mdot
.85238 .30048 Mdot
.85714 .33124 Mdot
.8619 .27683 Mdot
.86667 .40143 Mdot
.87143 .33087 Mdot
.87619 .22972 Mdot
.88095 .4761 Mdot
.88571 .50704 Mdot
.89048 .49607 Mdot
.89524 .40327 Mdot
.9 .45115 Mdot
.90476 .359 Mdot
.90952 .24649 Mdot
.91429 .48224 Mdot
.91905 .31088 Mdot
.92381 .31122 Mdot
.92857 .5353 Mdot
.93333 .32021 Mdot
.9381 .3612 Mdot
.94286 .28571 Mdot
.94762 .30916 Mdot
.95238 .38236 Mdot
.95714 .42323 Mdot
.9619 .4138 Mdot
.96667 .27673 Mdot
.97143 .3867 Mdot
.97619 .26463 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .208 Mdot
.03333 .38526 Mdot
.0381 .43363 Mdot
.04286 .31739 Mdot
.04762 .33306 Mdot
.05238 .39062 Mdot
.05714 .35639 Mdot
.0619 .40852 Mdot
.06667 .30396 Mdot
.07143 .29559 Mdot
.07619 .29601 Mdot
.08095 .35496 Mdot
.08571 .32659 Mdot
.09048 .43482 Mdot
.09524 .36534 Mdot
.1 .32342 Mdot
.10476 .28579 Mdot
.10952 .35591 Mdot
.11429 .44671 Mdot
.11905 .22332 Mdot
.12381 .41738 Mdot
.12857 .50958 Mdot
.13333 .48591 Mdot
.1381 .42308 Mdot
.14286 .27679 Mdot
.14762 .44154 Mdot
.15238 .40274 Mdot
.15714 .27068 Mdot
.1619 .40144 Mdot
.16667 .37182 Mdot
.17143 .40351 Mdot
.17619 .32678 Mdot
.18095 .32988 Mdot
.18571 .47876 Mdot
.19048 .31387 Mdot
.19524 .28971 Mdot
.2 .2805 Mdot
.20476 .39966 Mdot
.20952 .44578 Mdot
.21429 .31949 Mdot
.21905 .42497 Mdot
.22381 .51847 Mdot
.22857 .34585 Mdot
.23333 .36175 Mdot
.2381 .44263 Mdot
.24286 .31381 Mdot
.24762 .35863 Mdot
.25238 .37618 Mdot
.25714 .39356 Mdot
.2619 .33048 Mdot
.26667 .35581 Mdot
.27143 .36781 Mdot
.27619 .30624 Mdot
.28095 .4044 Mdot
.28571 .30098 Mdot
.29048 .42406 Mdot
.29524 .27303 Mdot
.3 .33854 Mdot
.30476 .3032 Mdot
.30952 .56845 Mdot
.31429 .39767 Mdot
.31905 .29895 Mdot
.32381 .23864 Mdot
.32857 .29464 Mdot
.33333 .39632 Mdot
.3381 .36349 Mdot
.34286 .32625 Mdot
.34762 .4758 Mdot
.35238 .4238 Mdot
.35714 .27444 Mdot
.3619 .25606 Mdot
.36667 .4578 Mdot
.37143 .38586 Mdot
.37619 .35956 Mdot
.38095 .22948 Mdot
.38571 .40278 Mdot
.39048 .44203 Mdot
.39524 .27106 Mdot
.4 .43101 Mdot
.40476 .18153 Mdot
.40952 .55031 Mdot
.41429 .39303 Mdot
.41905 .34069 Mdot
.42381 .40671 Mdot
.42857 .37715 Mdot
.43333 .34538 Mdot
.4381 .45697 Mdot
.44286 .362 Mdot
.44762 .38326 Mdot
.45238 .25739 Mdot
.45714 .39112 Mdot
.4619 .296 Mdot
.46667 .30043 Mdot
.47143 .40529 Mdot
.47619 .29683 Mdot
.48095 .32354 Mdot
.48571 .37925 Mdot
.49048 .24721 Mdot
.49524 .22522 Mdot
.5 .28736 Mdot
.50476 .28385 Mdot
.50952 .28599 Mdot
.51429 .33814 Mdot
.51905 .38599 Mdot
.52381 .29647 Mdot
.52857 .44933 Mdot
.53333 .47126 Mdot
.5381 .30935 Mdot
.54286 .3648 Mdot
.54762 .39944 Mdot
.55238 .28305 Mdot
.55714 .40318 Mdot
.5619 .40317 Mdot
.56667 .29423 Mdot
.57143 .33613 Mdot
.57619 .39463 Mdot
.58095 .41322 Mdot
.58571 .31347 Mdot
.59048 .39683 Mdot
.59524 .49794 Mdot
.6 .45008 Mdot
.60476 .39096 Mdot
.60952 .21328 Mdot
.61429 .44235 Mdot
.61905 .28388 Mdot
.62381 .24013 Mdot
.62857 .27008 Mdot
.63333 .38111 Mdot
.6381 .33387 Mdot
.64286 .31484 Mdot
.64762 .26456 Mdot
.65238 .34292 Mdot
.65714 .19249 Mdot
.6619 .42514 Mdot
.66667 .41797 Mdot
.67143 .32463 Mdot
.67619 .25736 Mdot
.68095 .44224 Mdot
.68571 .44612 Mdot
.69048 .49861 Mdot
.69524 .41523 Mdot
.7 .34852 Mdot
.70476 .32025 Mdot
.70952 .48392 Mdot
.71429 .36246 Mdot
.71905 .39 Mdot
.72381 .29413 Mdot
.72857 .3689 Mdot
.73333 .39129 Mdot
.7381 .37579 Mdot
.74286 .29519 Mdot
.74762 .24426 Mdot
.75238 .42126 Mdot
.75714 .27625 Mdot
.7619 .32699 Mdot
.76667 .49958 Mdot
.77143 .21893 Mdot
.77619 .47694 Mdot
.78095 .40345 Mdot
.78571 .46173 Mdot
.79048 .32124 Mdot
.79524 .47562 Mdot
.8 .40306 Mdot
.80476 .452 Mdot
.80952 .42687 Mdot
.81429 .40419 Mdot
.81905 .33132 Mdot
.82381 .40553 Mdot
.82857 .38681 Mdot
.83333 .3632 Mdot
.8381 .25904 Mdot
.84286 .27855 Mdot
.84762 .43538 Mdot
.85238 .2955 Mdot
.85714 .34205 Mdot
.8619 .29579 Mdot
.86667 .38523 Mdot
.87143 .33009 Mdot
.87619 .22879 Mdot
.88095 .48483 Mdot
.88571 .51584 Mdot
.89048 .48877 Mdot
.89524 .38816 Mdot
.9 .43185 Mdot
.90476 .34401 Mdot
.90952 .24117 Mdot
.91429 .47275 Mdot
.91905 .31113 Mdot
.92381 .32165 Mdot
.92857 .54075 Mdot
.93333 .31399 Mdot
.9381 .36061 Mdot
.94286 .2844 Mdot
.94762 .32267 Mdot
.95238 .39515 Mdot
.95714 .41908 Mdot
.9619 .4035 Mdot
.96667 .25978 Mdot
.97143 .3935 Mdot
.97619 .27844 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .20383 Mdot
.03333 .38873 Mdot
.0381 .43986 Mdot
.04286 .3208 Mdot
.04762 .3293 Mdot
.05238 .39676 Mdot
.05714 .33772 Mdot
.0619 .41773 Mdot
.06667 .31908 Mdot
.07143 .31196 Mdot
.07619 .31005 Mdot
.08095 .34512 Mdot
.08571 .32783 Mdot
.09048 .43504 Mdot
.09524 .36419 Mdot
.1 .30724 Mdot
.10476 .28072 Mdot
.10952 .35367 Mdot
.11429 .45013 Mdot
.11905 .22097 Mdot
.12381 .43514 Mdot
.12857 .5267 Mdot
.13333 .48429 Mdot
.1381 .41258 Mdot
.14286 .28725 Mdot
.14762 .44775 Mdot
.15238 .38799 Mdot
.15714 .25338 Mdot
.1619 .4065 Mdot
.16667 .36755 Mdot
.17143 .38835 Mdot
.17619 .31444 Mdot
.18095 .31407 Mdot
.18571 .46886 Mdot
.19048 .31373 Mdot
.19524 .27416 Mdot
.2 .27116 Mdot
.20476 .38047 Mdot
.20952 .4514 Mdot
.21429 .32943 Mdot
.21905 .41717 Mdot
.22381 .4998 Mdot
.22857 .34769 Mdot
.23333 .36382 Mdot
.2381 .43357 Mdot
.24286 .29803 Mdot
.24762 .36775 Mdot
.25238 .36737 Mdot
.25714 .40194 Mdot
.2619 .3359 Mdot
.26667 .34907 Mdot
.27143 .36105 Mdot
.27619 .31253 Mdot
.28095 .41589 Mdot
.28571 .29721 Mdot
.29048 .40669 Mdot
.29524 .2642 Mdot
.3 .33086 Mdot
.30476 .31493 Mdot
.30952 .58234 Mdot
.31429 .38475 Mdot
.31905 .28286 Mdot
.32381 .23128 Mdot
.32857 .28242 Mdot
.33333 .38198 Mdot
.3381 .3484 Mdot
.34286 .34196 Mdot
.34762 .49157 Mdot
.35238 .40968 Mdot
.35714 .25574 Mdot
.3619 .25488 Mdot
.36667 .46952 Mdot
.37143 .40372 Mdot
.37619 .36892 Mdot
.38095 .21047 Mdot
.38571 .39438 Mdot
.39048 .45371 Mdot
.39524 .26456 Mdot
.4 .42734 Mdot
.40476 .18983 Mdot
.40952 .53805 Mdot
.41429 .38167 Mdot
.41905 .32417 Mdot
.42381 .39469 Mdot
.42857 .37416 Mdot
.43333 .34811 Mdot
.4381 .47337 Mdot
.44286 .34831 Mdot
.44762 .37115 Mdot
.45238 .23837 Mdot
.45714 .37207 Mdot
.4619 .30316 Mdot
.46667 .30438 Mdot
.47143 .38709 Mdot
.47619 .30805 Mdot
.48095 .30785 Mdot
.48571 .3813 Mdot
.49048 .23283 Mdot
.49524 .24375 Mdot
.5 .27984 Mdot
.50476 .30017 Mdot
.50952 .27476 Mdot
.51429 .3481 Mdot
.51905 .3673 Mdot
.52381 .28433 Mdot
.52857 .45342 Mdot
.53333 .46112 Mdot
.5381 .2951 Mdot
.54286 .37761 Mdot
.54762 .41258 Mdot
.55238 .2947 Mdot
.55714 .38681 Mdot
.5619 .40816 Mdot
.56667 .27924 Mdot
.57143 .31838 Mdot
.57619 .38849 Mdot
.58095 .4056 Mdot
.58571 .33017 Mdot
.59048 .40744 Mdot
.59524 .51063 Mdot
.6 .44008 Mdot
.60476 .39634 Mdot
.60952 .22746 Mdot
.61429 .42369 Mdot
.61905 .26471 Mdot
.62381 .23834 Mdot
.62857 .25997 Mdot
.63333 .38938 Mdot
.6381 .32513 Mdot
.64286 .31938 Mdot
.64762 .25316 Mdot
.65238 .36186 Mdot
.65714 .17547 Mdot
.6619 .41448 Mdot
.66667 .40633 Mdot
.67143 .30692 Mdot
.67619 .23939 Mdot
.68095 .44165 Mdot
.68571 .45124 Mdot
.69048 .48227 Mdot
.69524 .40037 Mdot
.7 .33491 Mdot
.70476 .30737 Mdot
.70952 .48402 Mdot
.71429 .37375 Mdot
.71905 .37511 Mdot
.72381 .293 Mdot
.72857 .36352 Mdot
.73333 .40164 Mdot
.7381 .36049 Mdot
.74286 .28377 Mdot
.74762 .2296 Mdot
.75238 .40595 Mdot
.75714 .29546 Mdot
.7619 .3174 Mdot
.76667 .50215 Mdot
.77143 .23162 Mdot
.77619 .46478 Mdot
.78095 .40596 Mdot
.78571 .44362 Mdot
.79048 .3346 Mdot
.79524 .46961 Mdot
.8 .42217 Mdot
.80476 .46192 Mdot
.80952 .41073 Mdot
.81429 .40854 Mdot
.81905 .33161 Mdot
.82381 .4034 Mdot
.82857 .36983 Mdot
.83333 .34527 Mdot
.8381 .26269 Mdot
.84286 .28107 Mdot
.84762 .4446 Mdot
.85238 .29707 Mdot
.85714 .34034 Mdot
.8619 .30386 Mdot
.86667 .3961 Mdot
.87143 .31741 Mdot
.87619 .22383 Mdot
.88095 .48655 Mdot
.88571 .5003 Mdot
.89048 .50143 Mdot
.89524 .37721 Mdot
.9 .41909 Mdot
.90476 .35341 Mdot
.90952 .2534 Mdot
.91429 .46559 Mdot
.91905 .30215 Mdot
.92381 .32416 Mdot
.92857 .5293 Mdot
.93333 .31252 Mdot
.9381 .36341 Mdot
.94286 .29637 Mdot
.94762 .3134 Mdot
.95238 .38206 Mdot
.95714 .42589 Mdot
.9619 .39932 Mdot
.96667 .24548 Mdot
.97143 .3779 Mdot
.97619 .26208 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .19005 Mdot
.03333 .38125 Mdot
.0381 .45321 Mdot
.04286 .32839 Mdot
.04762 .32768 Mdot
.05238 .39782 Mdot
.05714 .34008 Mdot
.0619 .41003 Mdot
.06667 .3101 Mdot
.07143 .32502 Mdot
.07619 .29512 Mdot
.08095 .34568 Mdot
.08571 .3244 Mdot
.09048 .44628 Mdot
.09524 .34729 Mdot
.1 .29962 Mdot
.10476 .28229 Mdot
.10952 .35888 Mdot
.11429 .43639 Mdot
.11905 .2209 Mdot
.12381 .44215 Mdot
.12857 .5159 Mdot
.13333 .50116 Mdot
.1381 .40007 Mdot
.14286 .27243 Mdot
.14762 .43605 Mdot
.15238 .37343 Mdot
.15714 .23885 Mdot
.1619 .42538 Mdot
.16667 .37584 Mdot
.17143 .38048 Mdot
.17619 .32357 Mdot
.18095 .30785 Mdot
.18571 .45161 Mdot
.19048 .30483 Mdot
.19524 .28509 Mdot
.2 .26382 Mdot
.20476 .37562 Mdot
.20952 .43879 Mdot
.21429 .34706 Mdot
.21905 .40832 Mdot
.22381 .48654 Mdot
.22857 .3329 Mdot
.23333 .36095 Mdot
.2381 .41876 Mdot
.24286 .29354 Mdot
.24762 .3601 Mdot
.25238 .35222 Mdot
.25714 .40345 Mdot
.2619 .33908 Mdot
.26667 .34374 Mdot
.27143 .37835 Mdot
.27619 .3023 Mdot
.28095 .39722 Mdot
.28571 .27892 Mdot
.29048 .388 Mdot
.29524 .25243 Mdot
.3 .33659 Mdot
.30476 .32332 Mdot
.30952 .57906 Mdot
.31429 .39929 Mdot
.31905 .29549 Mdot
.32381 .23916 Mdot
.32857 .28897 Mdot
.33333 .40089 Mdot
.3381 .33257 Mdot
.34286 .3277 Mdot
.34762 .49058 Mdot
.35238 .40012 Mdot
.35714 .26351 Mdot
.3619 .25104 Mdot
.36667 .46733 Mdot
.37143 .40312 Mdot
.37619 .38454 Mdot
.38095 .19443 Mdot
.38571 .40993 Mdot
.39048 .43693 Mdot
.39524 .25091 Mdot
.4 .41344 Mdot
.40476 .18546 Mdot
.40952 .54123 Mdot
.41429 .38308 Mdot
.41905 .31368 Mdot
.42381 .38339 Mdot
.42857 .35563 Mdot
.43333 .33842 Mdot
.4381 .48171 Mdot
.44286 .34891 Mdot
.44762 .35197 Mdot
.45238 .22815 Mdot
.45714 .37951 Mdot
.4619 .2949 Mdot
.46667 .29192 Mdot
.47143 .38756 Mdot
.47619 .32261 Mdot
.48095 .29982 Mdot
.48571 .39552 Mdot
.49048 .24569 Mdot
.49524 .24937 Mdot
.5 .26656 Mdot
.50476 .28686 Mdot
.50952 .27166 Mdot
.51429 .33556 Mdot
.51905 .3652 Mdot
.52381 .30074 Mdot
.52857 .45786 Mdot
.53333 .4732 Mdot
.5381 .31082 Mdot
.54286 .3645 Mdot
.54762 .40916 Mdot
.55238 .30001 Mdot
.55714 .37602 Mdot
.5619 .39078 Mdot
.56667 .29462 Mdot
.57143 .31712 Mdot
.57619 .37542 Mdot
.58095 .39707 Mdot
.58571 .32737 Mdot
.59048 .40928 Mdot
.59524 .52477 Mdot
.6 .43079 Mdot
.60476 .39034 Mdot
.60952 .21228 Mdot
.61429 .4081 Mdot
.61905 .2468 Mdot
.62381 .22042 Mdot
.62857 .25562 Mdot
.63333 .39556 Mdot
.6381 .31246 Mdot
.64286 .30294 Mdot
.64762 .26292 Mdot
.65238 .37237 Mdot
.65714 .18705 Mdot
.6619 .39826 Mdot
.66667 .40809 Mdot
.67143 .29777 Mdot
.67619 .245 Mdot
.68095 .43388 Mdot
.68571 .43365 Mdot
.69048 .4871 Mdot
.69524 .38919 Mdot
.7 .32822 Mdot
.70476 .30185 Mdot
.70952 .48982 Mdot
.71429 .35964 Mdot
.71905 .37475 Mdot
.72381 .29477 Mdot
.72857 .37955 Mdot
.73333 .40175 Mdot
.7381 .3648 Mdot
.74286 .28427 Mdot
.74762 .21902 Mdot
.75238 .408 Mdot
.75714 .27935 Mdot
.7619 .303 Mdot
.76667 .48835 Mdot
.77143 .23371 Mdot
.77619 .45317 Mdot
.78095 .42465 Mdot
.78571 .44453 Mdot
.79048 .31781 Mdot
.79524 .45129 Mdot
.8 .41513 Mdot
.80476 .47627 Mdot
.80952 .40349 Mdot
.81429 .41192 Mdot
.81905 .33358 Mdot
.82381 .39615 Mdot
.82857 .38051 Mdot
.83333 .32713 Mdot
.8381 .25214 Mdot
.84286 .29599 Mdot
.84762 .43257 Mdot
.85238 .29978 Mdot
.85714 .34424 Mdot
.8619 .28843 Mdot
.86667 .39108 Mdot
.87143 .32107 Mdot
.87619 .21354 Mdot
.88095 .50353 Mdot
.88571 .49055 Mdot
.89048 .48668 Mdot
.89524 .36157 Mdot
.9 .40925 Mdot
.90476 .3421 Mdot
.90952 .24852 Mdot
.91429 .47052 Mdot
.91905 .28914 Mdot
.92381 .30893 Mdot
.92857 .51004 Mdot
.93333 .3038 Mdot
.9381 .35987 Mdot
.94286 .29661 Mdot
.94762 .29983 Mdot
.95238 .36939 Mdot
.95714 .4346 Mdot
.9619 .39913 Mdot
.96667 .25363 Mdot
.97143 .36119 Mdot
.97619 .26043 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .18214 Mdot
.03333 .36943 Mdot
.0381 .43636 Mdot
.04286 .31183 Mdot
.04762 .32759 Mdot
.05238 .41448 Mdot
.05714 .33698 Mdot
.0619 .42629 Mdot
.06667 .32317 Mdot
.07143 .31254 Mdot
.07619 .30959 Mdot
.08095 .3579 Mdot
.08571 .31787 Mdot
.09048 .43132 Mdot
.09524 .34483 Mdot
.1 .29247 Mdot
.10476 .26716 Mdot
.10952 .35409 Mdot
.11429 .44119 Mdot
.11905 .23554 Mdot
.12381 .42444 Mdot
.12857 .50163 Mdot
.13333 .49079 Mdot
.1381 .39362 Mdot
.14286 .27042 Mdot
.14762 .42741 Mdot
.15238 .36454 Mdot
.15714 .23984 Mdot
.1619 .42932 Mdot
.16667 .37846 Mdot
.17143 .38123 Mdot
.17619 .30672 Mdot
.18095 .3168 Mdot
.18571 .44206 Mdot
.19048 .29937 Mdot
.19524 .27092 Mdot
.2 .25393 Mdot
.20476 .38281 Mdot
.20952 .43504 Mdot
.21429 .36433 Mdot
.21905 .39625 Mdot
.22381 .48456 Mdot
.22857 .33516 Mdot
.23333 .37975 Mdot
.2381 .41766 Mdot
.24286 .29197 Mdot
.24762 .36642 Mdot
.25238 .35131 Mdot
.25714 .41066 Mdot
.2619 .34017 Mdot
.26667 .35206 Mdot
.27143 .37189 Mdot
.27619 .30407 Mdot
.28095 .38284 Mdot
.28571 .27733 Mdot
.29048 .37871 Mdot
.29524 .24979 Mdot
.3 .34078 Mdot
.30476 .31124 Mdot
.30952 .56205 Mdot
.31429 .39553 Mdot
.31905 .29374 Mdot
.32381 .23546 Mdot
.32857 .2716 Mdot
.33333 .38259 Mdot
.3381 .33082 Mdot
.34286 .33524 Mdot
.34762 .48078 Mdot
.35238 .39272 Mdot
.35714 .25491 Mdot
.3619 .23747 Mdot
.36667 .46089 Mdot
.37143 .40075 Mdot
.37619 .36553 Mdot
.38095 .21294 Mdot
.38571 .41012 Mdot
.39048 .44098 Mdot
.39524 .25245 Mdot
.4 .40002 Mdot
.40476 .17797 Mdot
.40952 .5591 Mdot
.41429 .37157 Mdot
.41905 .30435 Mdot
.42381 .3724 Mdot
.42857 .3657 Mdot
.43333 .3344 Mdot
.4381 .46433 Mdot
.44286 .34072 Mdot
.44762 .34895 Mdot
.45238 .22393 Mdot
.45714 .38954 Mdot
.4619 .28191 Mdot
.46667 .29322 Mdot
.47143 .37108 Mdot
.47619 .3102 Mdot
.48095 .28816 Mdot
.48571 .37722 Mdot
.49048 .24379 Mdot
.49524 .23929 Mdot
.5 .27304 Mdot
.50476 .27319 Mdot
.50952 .25675 Mdot
.51429 .35219 Mdot
.51905 .35993 Mdot
.52381 .3015 Mdot
.52857 .46695 Mdot
.53333 .4639 Mdot
.5381 .31971 Mdot
.54286 .36419 Mdot
.54762 .39359 Mdot
.55238 .31112 Mdot
.55714 .36217 Mdot
.5619 .3965 Mdot
.56667 .31258 Mdot
.57143 .33225 Mdot
.57619 .36175 Mdot
.58095 .40086 Mdot
.58571 .34566 Mdot
.59048 .39025 Mdot
.59524 .51955 Mdot
.6 .42672 Mdot
.60476 .37925 Mdot
.60952 .19468 Mdot
.61429 .39986 Mdot
.61905 .23854 Mdot
.62381 .20226 Mdot
.62857 .23723 Mdot
.63333 .37678 Mdot
.6381 .29671 Mdot
.64286 .28479 Mdot
.64762 .27933 Mdot
.65238 .37751 Mdot
.65714 .17222 Mdot
.6619 .38026 Mdot
.66667 .39529 Mdot
.67143 .28757 Mdot
.67619 .24727 Mdot
.68095 .43025 Mdot
.68571 .45204 Mdot
.69048 .48831 Mdot
.69524 .40246 Mdot
.7 .34181 Mdot
.70476 .30158 Mdot
.70952 .49336 Mdot
.71429 .37696 Mdot
.71905 .39205 Mdot
.72381 .29283 Mdot
.72857 .37737 Mdot
.73333 .38824 Mdot
.7381 .37846 Mdot
.74286 .28327 Mdot
.74762 .20398 Mdot
.75238 .40641 Mdot
.75714 .27414 Mdot
.7619 .28775 Mdot
.76667 .47268 Mdot
.77143 .23573 Mdot
.77619 .4453 Mdot
.78095 .41176 Mdot
.78571 .43125 Mdot
.79048 .3265 Mdot
.79524 .46645 Mdot
.8 .43012 Mdot
.80476 .48736 Mdot
.80952 .39719 Mdot
.81429 .42299 Mdot
.81905 .31494 Mdot
.82381 .39238 Mdot
.82857 .3647 Mdot
.83333 .32849 Mdot
.8381 .26243 Mdot
.84286 .29364 Mdot
.84762 .42311 Mdot
.85238 .30205 Mdot
.85714 .3425 Mdot
.8619 .27934 Mdot
.86667 .38769 Mdot
.87143 .32339 Mdot
.87619 .20644 Mdot
.88095 .51672 Mdot
.88571 .48428 Mdot
.89048 .47495 Mdot
.89524 .36143 Mdot
.9 .4103 Mdot
.90476 .34946 Mdot
.90952 .24983 Mdot
.91429 .45388 Mdot
.91905 .29091 Mdot
.92381 .30672 Mdot
.92857 .51416 Mdot
.93333 .3157 Mdot
.9381 .35061 Mdot
.94286 .3149 Mdot
.94762 .29985 Mdot
.95238 .37868 Mdot
.95714 .44363 Mdot
.9619 .39058 Mdot
.96667 .24561 Mdot
.97143 .35188 Mdot
.97619 .24675 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .16796 Mdot
.03333 .36082 Mdot
.0381 .42825 Mdot
.04286 .29644 Mdot
.04762 .3111 Mdot
.05238 .42268 Mdot
.05714 .34118 Mdot
.0619 .41702 Mdot
.06667 .31996 Mdot
.07143 .32794 Mdot
.07619 .31309 Mdot
.08095 .36718 Mdot
.08571 .3037 Mdot
.09048 .42826 Mdot
.09524 .33706 Mdot
.1 .31106 Mdot
.10476 .27677 Mdot
.10952 .36794 Mdot
.11429 .42935 Mdot
.11905 .23701 Mdot
.12381 .40661 Mdot
.12857 .48961 Mdot
.13333 .48603 Mdot
.1381 .40914 Mdot
.14286 .26461 Mdot
.14762 .42644 Mdot
.15238 .37331 Mdot
.15714 .232 Mdot
.1619 .42882 Mdot
.16667 .39474 Mdot
.17143 .37048 Mdot
.17619 .32132 Mdot
.18095 .30726 Mdot
.18571 .43927 Mdot
.19048 .30738 Mdot
.19524 .25242 Mdot
.2 .23659 Mdot
.20476 .3864 Mdot
.20952 .44734 Mdot
.21429 .34926 Mdot
.21905 .38363 Mdot
.22381 .47522 Mdot
.22857 .3452 Mdot
.23333 .37209 Mdot
.2381 .42553 Mdot
.24286 .28692 Mdot
.24762 .36829 Mdot
.25238 .33657 Mdot
.25714 .41437 Mdot
.2619 .34836 Mdot
.26667 .34904 Mdot
.27143 .36247 Mdot
.27619 .29208 Mdot
.28095 .3673 Mdot
.28571 .27316 Mdot
.29048 .39717 Mdot
.29524 .23117 Mdot
.3 .34246 Mdot
.30476 .30655 Mdot
.30952 .58113 Mdot
.31429 .39883 Mdot
.31905 .2761 Mdot
.32381 .24186 Mdot
.32857 .26837 Mdot
.33333 .3736 Mdot
.3381 .31729 Mdot
.34286 .34038 Mdot
.34762 .46259 Mdot
.35238 .40201 Mdot
.35714 .2673 Mdot
.3619 .22581 Mdot
.36667 .4645 Mdot
.37143 .40528 Mdot
.37619 .3513 Mdot
.38095 .19896 Mdot
.38571 .39226 Mdot
.39048 .43727 Mdot
.39524 .25524 Mdot
.4 .38405 Mdot
.40476 .19537 Mdot
.40952 .5462 Mdot
.41429 .37774 Mdot
.41905 .31968 Mdot
.42381 .36113 Mdot
.42857 .37282 Mdot
.43333 .3326 Mdot
.4381 .47482 Mdot
.44286 .33487 Mdot
.44762 .3541 Mdot
.45238 .2174 Mdot
.45714 .4017 Mdot
.4619 .26832 Mdot
.46667 .28784 Mdot
.47143 .36716 Mdot
.47619 .30616 Mdot
.48095 .27974 Mdot
.48571 .39552 Mdot
.49048 .22926 Mdot
.49524 .24252 Mdot
.5 .28124 Mdot
.50476 .26895 Mdot
.50952 .24447 Mdot
.51429 .34424 Mdot
.51905 .3647 Mdot
.52381 .2906 Mdot
.52857 .47337 Mdot
.53333 .44643 Mdot
.5381 .33335 Mdot
.54286 .36353 Mdot
.54762 .40489 Mdot
.55238 .31593 Mdot
.55714 .36283 Mdot
.5619 .41094 Mdot
.56667 .29797 Mdot
.57143 .33675 Mdot
.57619 .3532 Mdot
.58095 .38482 Mdot
.58571 .35179 Mdot
.59048 .40713 Mdot
.59524 .51137 Mdot
.6 .42091 Mdot
.60476 .37072 Mdot
.60952 .21392 Mdot
.61429 .38093 Mdot
.61905 .23163 Mdot
.62381 .21222 Mdot
.62857 .24913 Mdot
.63333 .36565 Mdot
.6381 .28613 Mdot
.64286 .27048 Mdot
.64762 .28676 Mdot
.65238 .39077 Mdot
.65714 .16134 Mdot
.6619 .39188 Mdot
.66667 .39405 Mdot
.67143 .27222 Mdot
.67619 .22915 Mdot
.68095 .42904 Mdot
.68571 .4468 Mdot
.69048 .49235 Mdot
.69524 .41119 Mdot
.7 .33764 Mdot
.70476 .28697 Mdot
.70952 .48323 Mdot
.71429 .36361 Mdot
.71905 .39039 Mdot
.72381 .2829 Mdot
.72857 .38563 Mdot
.73333 .39193 Mdot
.7381 .39219 Mdot
.74286 .29826 Mdot
.74762 .19878 Mdot
.75238 .41022 Mdot
.75714 .26889 Mdot
.7619 .27428 Mdot
.76667 .46104 Mdot
.77143 .22578 Mdot
.77619 .42785 Mdot
.78095 .39445 Mdot
.78571 .42044 Mdot
.79048 .33795 Mdot
.79524 .46965 Mdot
.8 .44892 Mdot
.80476 .47179 Mdot
.80952 .39948 Mdot
.81429 .4194 Mdot
.81905 .30686 Mdot
.82381 .39231 Mdot
.82857 .37941 Mdot
.83333 .33447 Mdot
.8381 .24439 Mdot
.84286 .30394 Mdot
.84762 .4173 Mdot
.85238 .2989 Mdot
.85714 .33472 Mdot
.8619 .26966 Mdot
.86667 .38402 Mdot
.87143 .3256 Mdot
.87619 .19619 Mdot
.88095 .52447 Mdot
.88571 .47719 Mdot
.89048 .46612 Mdot
.89524 .35451 Mdot
.9 .40588 Mdot
.90476 .33133 Mdot
.90952 .24784 Mdot
.91429 .44308 Mdot
.91905 .30417 Mdot
.92381 .31721 Mdot
.92857 .49593 Mdot
.93333 .33228 Mdot
.9381 .35786 Mdot
.94286 .32861 Mdot
.94762 .28994 Mdot
.95238 .39185 Mdot
.95714 .45803 Mdot
.9619 .37204 Mdot
.96667 .25043 Mdot
.97143 .33476 Mdot
.97619 .23922 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.463525 0.0772542 [
[.2619 .45103 -6 -9 ]
[.2619 .45103 6 0 ]
[.5 .45103 -9 -9 ]
[.5 .45103 9 0 ]
[.7381 .45103 -9 -9 ]
[.7381 .45103 9 0 ]
[.97619 .45103 -9 -9 ]
[.97619 .45103 9 0 ]
[1.025 .46353 0 -6 ]
[1.025 .46353 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -12 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -12 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -12 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .54078 -6 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .46353 m
.2619 .46978 L
s
[(50)] .2619 .45103 0 1 Mshowa
.5 .46353 m
.5 .46978 L
s
[(100)] .5 .45103 0 1 Mshowa
.7381 .46353 m
.7381 .46978 L
s
[(150)] .7381 .45103 0 1 Mshowa
.97619 .46353 m
.97619 .46978 L
s
[(200)] .97619 .45103 0 1 Mshowa
.125 Mabswid
.07143 .46353 m
.07143 .46728 L
s
.11905 .46353 m
.11905 .46728 L
s
.16667 .46353 m
.16667 .46728 L
s
.21429 .46353 m
.21429 .46728 L
s
.30952 .46353 m
.30952 .46728 L
s
.35714 .46353 m
.35714 .46728 L
s
.40476 .46353 m
.40476 .46728 L
s
.45238 .46353 m
.45238 .46728 L
s
.54762 .46353 m
.54762 .46728 L
s
.59524 .46353 m
.59524 .46728 L
s
.64286 .46353 m
.64286 .46728 L
s
.69048 .46353 m
.69048 .46728 L
s
.78571 .46353 m
.78571 .46728 L
s
.83333 .46353 m
.83333 .46728 L
s
.88095 .46353 m
.88095 .46728 L
s
.92857 .46353 m
.92857 .46728 L
s
.25 Mabswid
0 .46353 m
1 .46353 L
s
gsave
1.025 .46353 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-6)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-4)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-3)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(-1)] .01131 .38627 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .16282 Mdot
.03333 .34972 Mdot
.0381 .43777 Mdot
.04286 .28982 Mdot
.04762 .30133 Mdot
.05238 .41073 Mdot
.05714 .33903 Mdot
.0619 .40683 Mdot
.06667 .30293 Mdot
.07143 .31771 Mdot
.07619 .30099 Mdot
.08095 .351 Mdot
.08571 .30272 Mdot
.09048 .41961 Mdot
.09524 .3288 Mdot
.1 .29416 Mdot
.10476 .26565 Mdot
.10952 .35418 Mdot
.11429 .41953 Mdot
.11905 .23317 Mdot
.12381 .41716 Mdot
.12857 .49589 Mdot
.13333 .49516 Mdot
.1381 .41791 Mdot
.14286 .27797 Mdot
.14762 .42512 Mdot
.15238 .35427 Mdot
.15714 .2207 Mdot
.1619 .43972 Mdot
.16667 .38711 Mdot
.17143 .37637 Mdot
.17619 .32826 Mdot
.18095 .30657 Mdot
.18571 .42562 Mdot
.19048 .2932 Mdot
.19524 .2584 Mdot
.2 .24839 Mdot
.20476 .39004 Mdot
.20952 .44818 Mdot
.21429 .35221 Mdot
.21905 .38648 Mdot
.22381 .48907 Mdot
.22857 .32964 Mdot
.23333 .35588 Mdot
.2381 .41404 Mdot
.24286 .2867 Mdot
.24762 .36965 Mdot
.25238 .32385 Mdot
.25714 .42684 Mdot
.2619 .34403 Mdot
.26667 .3415 Mdot
.27143 .37139 Mdot
.27619 .30723 Mdot
.28095 .36637 Mdot
.28571 .27899 Mdot
.29048 .38335 Mdot
.29524 .23607 Mdot
.3 .34988 Mdot
.30476 .30604 Mdot
.30952 .5952 Mdot
.31429 .40197 Mdot
.31905 .28413 Mdot
.32381 .23658 Mdot
.32857 .27747 Mdot
.33333 .3912 Mdot
.3381 .29854 Mdot
.34286 .33638 Mdot
.34762 .46244 Mdot
.35238 .39618 Mdot
.35714 .28514 Mdot
.3619 .20992 Mdot
.36667 .47076 Mdot
.37143 .39959 Mdot
.37619 .35912 Mdot
.38095 .21576 Mdot
.38571 .40706 Mdot
.39048 .44042 Mdot
.39524 .2707 Mdot
.4 .40096 Mdot
.40476 .19013 Mdot
.40952 .53495 Mdot
.41429 .37423 Mdot
.41905 .33898 Mdot
.42381 .37559 Mdot
.42857 .36189 Mdot
.43333 .32999 Mdot
.4381 .48492 Mdot
.44286 .32841 Mdot
.44762 .35355 Mdot
.45238 .20931 Mdot
.45714 .3934 Mdot
.4619 .24948 Mdot
.46667 .30493 Mdot
.47143 .36815 Mdot
.47619 .31965 Mdot
.48095 .26612 Mdot
.48571 .38807 Mdot
.49048 .23647 Mdot
.49524 .23989 Mdot
.5 .27352 Mdot
.50476 .26804 Mdot
.50952 .25269 Mdot
.51429 .35277 Mdot
.51905 .34783 Mdot
.52381 .3076 Mdot
.52857 .46097 Mdot
.53333 .45094 Mdot
.5381 .3391 Mdot
.54286 .35581 Mdot
.54762 .38708 Mdot
.55238 .33238 Mdot
.55714 .34767 Mdot
.5619 .39567 Mdot
.56667 .28144 Mdot
.57143 .3222 Mdot
.57619 .36622 Mdot
.58095 .39641 Mdot
.58571 .34216 Mdot
.59048 .4086 Mdot
.59524 .50335 Mdot
.6 .40588 Mdot
.60476 .35587 Mdot
.60952 .22227 Mdot
.61429 .38695 Mdot
.61905 .21788 Mdot
.62381 .21262 Mdot
.62857 .24332 Mdot
.63333 .3713 Mdot
.6381 .29506 Mdot
.64286 .2566 Mdot
.64762 .2822 Mdot
.65238 .40128 Mdot
.65714 .15022 Mdot
.6619 .37627 Mdot
.66667 .41276 Mdot
.67143 .27416 Mdot
.67619 .22796 Mdot
.68095 .4148 Mdot
.68571 .44697 Mdot
.69048 .4758 Mdot
.69524 .41526 Mdot
.7 .32315 Mdot
.70476 .268 Mdot
.70952 .48188 Mdot
.71429 .36648 Mdot
.71905 .39159 Mdot
.72381 .26512 Mdot
.72857 .37092 Mdot
.73333 .3995 Mdot
.7381 .3932 Mdot
.74286 .28276 Mdot
.74762 .19136 Mdot
.75238 .40875 Mdot
.75714 .24974 Mdot
.7619 .28369 Mdot
.76667 .44818 Mdot
.77143 .22905 Mdot
.77619 .41107 Mdot
.78095 .37667 Mdot
.78571 .43232 Mdot
.79048 .3377 Mdot
.79524 .47333 Mdot
.8 .46588 Mdot
.80476 .46199 Mdot
.80952 .4028 Mdot
.81429 .41091 Mdot
.81905 .28882 Mdot
.82381 .40951 Mdot
.82857 .37263 Mdot
.83333 .32386 Mdot
.8381 .23119 Mdot
.84286 .29366 Mdot
.84762 .40567 Mdot
.85238 .30575 Mdot
.85714 .33628 Mdot
.8619 .25446 Mdot
.86667 .39314 Mdot
.87143 .30656 Mdot
.87619 .2042 Mdot
.88095 .5169 Mdot
.88571 .48176 Mdot
.89048 .46477 Mdot
.89524 .36279 Mdot
.9 .42009 Mdot
.90476 .34794 Mdot
.90952 .25111 Mdot
.91429 .44626 Mdot
.91905 .31154 Mdot
.92381 .30123 Mdot
.92857 .51275 Mdot
.93333 .31592 Mdot
.9381 .34445 Mdot
.94286 .33634 Mdot
.94762 .27679 Mdot
.95238 .38035 Mdot
.95714 .44576 Mdot
.9619 .37156 Mdot
.96667 .25043 Mdot
.97143 .35168 Mdot
.97619 .24981 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, -6, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Particles settle toward lower ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", and spread as expected. The mean position of the distribution and the \
mean squared change in position are  shown in  Fig. ",
  ButtonBox["8.6",
    ButtonData:>"Fig. 8.6",
    ButtonStyle->"Hyperlink"],
  ", together with the theory predictions of Eqs. ",
  ButtonBox["(8.2.4)",
    ButtonData:>{"Chapter8.nb", "(8.2.4)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.2.7)",
    ButtonData:>{"Chapter8.nb", "(8.2.7)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.603319 0.395861 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 10 6 ]
[.01131 .04911 -24 -4.5 ]
[.01131 .04911 0 4.5 ]
[.01131 .12829 -24 -4.5 ]
[.01131 .12829 0 4.5 ]
[.01131 .20746 -12 -4.5 ]
[.01131 .20746 0 4.5 ]
[.01131 .28663 -24 -4.5 ]
[.01131 .28663 0 4.5 ]
[.01131 .3658 -24 -4.5 ]
[.01131 .3658 0 4.5 ]
[.01131 .44497 -24 -4.5 ]
[.01131 .44497 0 4.5 ]
[.01131 .52415 -24 -4.5 ]
[.01131 .52415 0 4.5 ]
[.02381 .64303 -11 0 ]
[.02381 .64303 11 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(10)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(20)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(30)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(40)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(50)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.0619 .60332 m
.0619 .60707 L
s
.1 .60332 m
.1 .60707 L
s
.1381 .60332 m
.1381 .60707 L
s
.17619 .60332 m
.17619 .60707 L
s
.25238 .60332 m
.25238 .60707 L
s
.29048 .60332 m
.29048 .60707 L
s
.32857 .60332 m
.32857 .60707 L
s
.36667 .60332 m
.36667 .60707 L
s
.44286 .60332 m
.44286 .60707 L
s
.48095 .60332 m
.48095 .60707 L
s
.51905 .60332 m
.51905 .60707 L
s
.55714 .60332 m
.55714 .60707 L
s
.63333 .60332 m
.63333 .60707 L
s
.67143 .60332 m
.67143 .60707 L
s
.70952 .60332 m
.70952 .60707 L
s
.74762 .60332 m
.74762 .60707 L
s
.82381 .60332 m
.82381 .60707 L
s
.8619 .60332 m
.8619 .60707 L
s
.9 .60332 m
.9 .60707 L
s
.9381 .60332 m
.9381 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .04911 m
.03006 .04911 L
s
[(-1.4)] .01131 .04911 1 0 Mshowa
.02381 .12829 m
.03006 .12829 L
s
[(-1.2)] .01131 .12829 1 0 Mshowa
.02381 .20746 m
.03006 .20746 L
s
[(-1)] .01131 .20746 1 0 Mshowa
.02381 .28663 m
.03006 .28663 L
s
[(-0.8)] .01131 .28663 1 0 Mshowa
.02381 .3658 m
.03006 .3658 L
s
[(-0.6)] .01131 .3658 1 0 Mshowa
.02381 .44497 m
.03006 .44497 L
s
[(-0.4)] .01131 .44497 1 0 Mshowa
.02381 .52415 m
.03006 .52415 L
s
[(-0.2)] .01131 .52415 1 0 Mshowa
.125 Mabswid
.02381 .06891 m
.02756 .06891 L
s
.02381 .0887 m
.02756 .0887 L
s
.02381 .10849 m
.02756 .10849 L
s
.02381 .14808 m
.02756 .14808 L
s
.02381 .16787 m
.02756 .16787 L
s
.02381 .18767 m
.02756 .18767 L
s
.02381 .22725 m
.02756 .22725 L
s
.02381 .24704 m
.02756 .24704 L
s
.02381 .26684 m
.02756 .26684 L
s
.02381 .30642 m
.02756 .30642 L
s
.02381 .32622 m
.02756 .32622 L
s
.02381 .34601 m
.02756 .34601 L
s
.02381 .3856 m
.02756 .3856 L
s
.02381 .40539 m
.02756 .40539 L
s
.02381 .42518 m
.02756 .42518 L
s
.02381 .46477 m
.02756 .46477 L
s
.02381 .48456 m
.02756 .48456 L
s
.02381 .50435 m
.02756 .50435 L
s
.02381 .54394 m
.02756 .54394 L
s
.02381 .56373 m
.02756 .56373 L
s
.02381 .58353 m
.02756 .58353 L
s
.02381 .02932 m
.02756 .02932 L
s
.02381 .00953 m
.02756 .00953 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.04286 .59278 Mdot
.0619 .58248 Mdot
.08095 .57139 Mdot
.1 .55521 Mdot
.11905 .54679 Mdot
.1381 .53591 Mdot
.15714 .52604 Mdot
.17619 .51311 Mdot
.19524 .49897 Mdot
.21429 .48175 Mdot
.23333 .47004 Mdot
.25238 .45232 Mdot
.27143 .43973 Mdot
.29048 .4321 Mdot
.30952 .41644 Mdot
.32857 .40852 Mdot
.34762 .39205 Mdot
.36667 .38129 Mdot
.38571 .36808 Mdot
.40476 .35762 Mdot
.42381 .34883 Mdot
.44286 .34006 Mdot
.4619 .32846 Mdot
.48095 .31475 Mdot
.5 .30295 Mdot
.51905 .29179 Mdot
.5381 .28023 Mdot
.55714 .26929 Mdot
.57619 .26173 Mdot
.59524 .24382 Mdot
.61429 .23511 Mdot
.63333 .22801 Mdot
.65238 .212 Mdot
.67143 .19975 Mdot
.69048 .19525 Mdot
.70952 .18571 Mdot
.72857 .17455 Mdot
.74762 .16099 Mdot
.76667 .14865 Mdot
.78571 .13786 Mdot
.80476 .1207 Mdot
.82381 .10974 Mdot
.84286 .09764 Mdot
.8619 .09141 Mdot
.88095 .08042 Mdot
.9 .06555 Mdot
.91905 .04811 Mdot
.9381 .0341 Mdot
.95714 .02387 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .60332 m
.06244 .58101 L
.10458 .55669 L
.14415 .53385 L
.18221 .51188 L
.22272 .48849 L
.26171 .46598 L
.30316 .44205 L
.34309 .419 L
.3815 .39683 L
.42237 .37323 L
.46172 .35052 L
.49955 .32867 L
.53984 .30542 L
.57861 .28303 L
.61984 .25923 L
.65954 .23631 L
.69774 .21426 L
.73838 .1908 L
.77751 .16821 L
.81909 .1442 L
.85916 .12107 L
.89771 .09882 L
.93871 .07515 L
.97619 .05351 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 0.54998 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .12471 -18 -4.5 ]
[.01131 .12471 0 4.5 ]
[.01131 .23471 -18 -4.5 ]
[.01131 .23471 0 4.5 ]
[.01131 .3447 -18 -4.5 ]
[.01131 .3447 0 4.5 ]
[.01131 .4547 -18 -4.5 ]
[.01131 .4547 0 4.5 ]
[.01131 .56469 -6 -4.5 ]
[.01131 .56469 0 4.5 ]
[.02381 .64303 -16.625 0 ]
[.02381 .64303 16.625 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(10)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(20)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(30)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(40)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(50)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12471 m
.03006 .12471 L
s
[(0.2)] .01131 .12471 1 0 Mshowa
.02381 .23471 m
.03006 .23471 L
s
[(0.4)] .01131 .23471 1 0 Mshowa
.02381 .3447 m
.03006 .3447 L
s
[(0.6)] .01131 .3447 1 0 Mshowa
.02381 .4547 m
.03006 .4547 L
s
[(0.8)] .01131 .4547 1 0 Mshowa
.02381 .56469 m
.03006 .56469 L
s
[(1)] .01131 .56469 1 0 Mshowa
.125 Mabswid
.02381 .04221 m
.02756 .04221 L
s
.02381 .06971 m
.02756 .06971 L
s
.02381 .09721 m
.02756 .09721 L
s
.02381 .15221 m
.02756 .15221 L
s
.02381 .17971 m
.02756 .17971 L
s
.02381 .20721 m
.02756 .20721 L
s
.02381 .26221 m
.02756 .26221 L
s
.02381 .2897 m
.02756 .2897 L
s
.02381 .3172 m
.02756 .3172 L
s
.02381 .3722 m
.02756 .3722 L
s
.02381 .3997 m
.02756 .3997 L
s
.02381 .4272 m
.02756 .4272 L
s
.02381 .4822 m
.02756 .4822 L
s
.02381 .5097 m
.02756 .5097 L
s
.02381 .5372 m
.02756 .5372 L
s
.02381 .59219 m
.02756 .59219 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -77.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
86.250 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
92.250 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.04286 .02587 Mdot
.0619 .03792 Mdot
.08095 .04922 Mdot
.1 .06259 Mdot
.11905 .06847 Mdot
.1381 .07733 Mdot
.15714 .0832 Mdot
.17619 .0984 Mdot
.19524 .1063 Mdot
.21429 .12354 Mdot
.23333 .13229 Mdot
.25238 .14693 Mdot
.27143 .15656 Mdot
.29048 .16703 Mdot
.30952 .17717 Mdot
.32857 .19245 Mdot
.34762 .20698 Mdot
.36667 .21566 Mdot
.38571 .23559 Mdot
.40476 .24799 Mdot
.42381 .26143 Mdot
.44286 .26174 Mdot
.4619 .27535 Mdot
.48095 .28083 Mdot
.5 .28513 Mdot
.51905 .28487 Mdot
.5381 .31564 Mdot
.55714 .33477 Mdot
.57619 .34549 Mdot
.59524 .3578 Mdot
.61429 .36423 Mdot
.63333 .37842 Mdot
.65238 .37837 Mdot
.67143 .39575 Mdot
.69048 .42315 Mdot
.70952 .41097 Mdot
.72857 .42167 Mdot
.74762 .43914 Mdot
.76667 .44985 Mdot
.78571 .46114 Mdot
.80476 .47837 Mdot
.82381 .5133 Mdot
.84286 .54979 Mdot
.8619 .55837 Mdot
.88095 .55382 Mdot
.9 .56731 Mdot
.91905 .57404 Mdot
.9381 .57899 Mdot
.95714 .58858 Mdot
.97619 .60332 Mdot
.5 Mabswid
.02381 .01472 m
.06244 .03709 L
.10458 .0615 L
.14415 .08442 L
.18221 .10647 L
.22272 .12993 L
.26171 .15252 L
.30316 .17653 L
.34309 .19966 L
.3815 .22191 L
.42237 .24558 L
.46172 .26838 L
.49955 .29029 L
.53984 .31363 L
.57861 .33609 L
.61984 .35997 L
.65954 .38297 L
.69774 .40509 L
.73838 .42864 L
.77751 .45131 L
.81909 .47539 L
.85916 .4986 L
.89771 .52093 L
.93871 .54468 L
.97619 .56639 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{529.75, 155.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:F0000`R000`400?l00000o`00003oo`3ooooo
0?oooiP0oooo003o0?ooool0ooooV03oool00?l0ooooo`3ooonH0?ooo`00o`3ooooo0?oooiP0oooo
003o0?ooool0ooooV03oool00?l0ooooo`3ooonH0?ooo`00o`3ooooo0?oooiP0oooo003o0?oooj@0
oooo10000000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^8@3oool5000000<0oooo00D0
k^k^03<c<`000000<c<c0>k^kP0R0?ooo`0509VIV@0A4A40000003<c<`3<c<`00`3oool01@3^k^h0
<c<c0000000c<c<0k^k^02@0oooo0P0000002@0A4A40oooo0?ooo`3oool0k^k^03<c<`000000<c<c
0>k^kP0S0?ooo`0504A4A0000000000003<c<`3MgMd00P3oool01@3^k^h0<c<c0000000c<c<0k^k^
02`0oooo000b0?ooo`030000003oool0oooo0?l0ooooL@3oool00`000000oooo0?ooo`020?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL08@3oool01@2IVIT08R8R0>k^kP3oool0A4A400<0oooo00D0MgMg
09VIV@3oool0VIVI07MgM`0R0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<00`3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg02D0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
02H0oooo00T0MgMg03<c<`3oool0oooo07MgM`2IVIT0oooo09VIV@1gMgL0;03oool00380oooo00<0
00000?ooo`3oool0o`3oooma0?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo
014A4@0R0?ooo`0309VIV@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`05
0000003oool0oooo0?ooo`0A4A400`3oool00`0A4A40oooo0?ooo`0P0?ooo`D000000`3oool01@0A
4A40oooo0?ooo`3oool04A4A02L0oooo00@000000?ooo`3oool04A4A0`3oool00`0A4A40oooo0?oo
o`0Z0?ooo`00<P3oool200000?l0ooooLP3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000008`3oool00`2IVIT08R8R0>k^kP030?ooo`050000003oool0oooo0?ooo`000000
9@3oool00`2ZZZX04A4A0?ooo`020?ooo`050000003oool0oooo0?ooo`0000008P3oool01014A4@0
gMgM0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000009P3oool01@1gMgL0<c<c0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0:P3oool00380oooo00<000000?ooo`3oool0k@3oool2
00000840oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000002@0oooo00<0
MgMg06IVIP3oool00P3oool01@000000oooo0?ooo`3oool0000002@0oooo00<04A4A0000002k^k/0
0`3oool01@000000oooo0?ooo`3oool000000280oooo00@0gMgM05EEE@3oool00000103oool01@00
0000oooo0?ooo`3oool0000002<0oooo00D00000028R8P000000<c<c0<c<c0020?ooo`050000003o
ool0oooo0?ooo`000000;03oool00380oooo00<000000?ooo`3oool0k@3oool200000840oooo00<0
00000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A02D0oooo00D000000?ooo`3oool0
oooo014A4@030?ooo`03014A4@3oool0oooo02<0oooo00<0^k^k028R8P3oool00P3oool01@0A4A40
oooo0?ooo`3oool04A4A02<0oooo00<0MgMg0<c<c0000000103oool01@0A4A40oooo0?ooo`3oool0
4A4A02<0oooo00<000000?ooo`3oool0103oool01@0A4A40oooo0?ooo`3oool04A4A02`0oooo000b
0?ooo`030000003oool0oooo0?l0ooooL@3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0
oooo09VIV@1gMgL08@3oool01@000000^k^k0?ooo`2IVIT04A4A00<0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0R0?ooo`05014A4@2IVIT0oooo0;^k^`0000000`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg02<0oooo00<0k^k^04A4A0000000103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02<0oooo00<0
00000?ooo`3oool0103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02`0oooo000b0?ooo`030000003o
ool0oooo0>P0oooo0P0000240?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0<c<c0000
000c<c<0k^k^0240oooo00D0VIVI014A4@0000008R8R0<c<c0030?ooo`050>k^kP0c<c<0000003<c
<`3^k^h08P3oool01@2ZZZX04A4A0000000A4A40ZZZZ00<0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0T0?ooo`0307MgM`000000oooo00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0S0?ooo`@00000
0`3oool01@3^k^h0<c<c0000000c<c<0k^k^02`0oooo000b0?ooo`800000j@3oool2000005/0oooo
00<000000?ooo`3oool0o`3ooolJ0?ooo`00<P3oool00`000000oooo0?ooo`3S0?ooo`800000H03o
ool00`000000oooo0?ooo`3f0?ooo`04014A4@00000000000?ooo`80000000<04A4A0?ooo`3oool0
6P3oool00380oooo00<000000?ooo`3oool0h`3oool200000600oooo00<000000?ooo`3oool0m`3o
ool01@000000oooo0?ooo`3oool0000001d0oooo000I0?ooo`@0000000<04A4A0?ooo`3oool00P3o
ool2028R8PH0oooo0P0000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooAP3o
ool00`000000oooo0?ooo`3g0?ooo`050000003oool0oooo0?ooo`0000007@3oool001/0oooo00<0
00000?ooo`3oool0103oool2028R8PL0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?oood00oooom`0000090?ooo`050000003oool0oooo0?ooo`0000007@3oool00100oooo1P00
00050?ooo`030000003oool0oooo00X0oooo1@0000050?ooo`800000g`3oool2000006D0oooo00@0
00000?ooo`00000000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`0500000028R8P0oooo0:ZZZP00
00007@3oool001/0oooo00<000000?ooo`3oool02P3oool01014A4@0gMgM0?ooo`0000060?ooo`03
0000003oool0oooo0=h0oooo0P00001U0?ooo`040000003oool0oooo0?ooo`800000l`3oool00`0A
4A40000007MgM`020000000309VIV@3oool0oooo01/0oooo000K0?ooo`030000003oool0oooo00X0
oooo00@0gMgM05EEE@3oool000001P3oool00`000000oooo0?ooo`3/0?ooo`800000E`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000o`3ooolF0?ooo`006`3oool00`000000oooo0?ooo`0;
0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0jP3oool2000005T0oooo00<00000
0?ooo`3oool0103oool200000?l0oooo503oool001/0oooo00<000000?ooo`3oool02`3oool00`3^
k^h0A4A4000000060?ooo`030000003oool0oooo0=X0oooo0P00000<0?ooo`800000F`3oool00`00
0000oooo0?ooo`060?ooo`800000o`3ooolB0?ooo`006@3oool205EEE@030000003oool0oooo00`0
oooo00<0MgMg0000003oool01@3oool200000=/0oooo0P00000;0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool01P3oool010000000oooo00000000003o0?oooa00oooo000b0?ooo`03
0000003oool0oooo0>D0oooo0P00001N0?ooo`8000002`3oool200000?l0oooo3P3oool00380oooo
00<000000?ooo`3oool0h`3oool200000600oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3o0?ooo`/0oooo000b0?ooo`030000003oool0oooo0=D0oooo0P00000:0?ooo`800000HP3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00800000o`3oool;0?ooo`00<P3oool0
0`000000oooo0?ooo`3E0?ooo`800000203oool2000006@0oooo00<000000?ooo`3oool03`3oool2
00000?l0oooo2@3oool00380oooo0P00003O0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool04@3oool200000?l0oooo1`3oool00380oooo00<000000?ooo`3oool0d03oool2000000X0
oooo0P00001W0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000003o0?oo
o`H0oooo000b0?ooo`030000003oool0oooo0</0oooo0P0000030?ooo`800000203oool2000006T0
oooo0P00000E0?ooo`800000o`3oool40?ooo`00<P3oool00`000000oooo0?ooo`3;0?ooo`800000
2`3oool2000006/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooo`40oooo
000b0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?oo
o`0G0?ooo`800000o`3oool10?ooo`00<P3oool200000<L0oooo0P00000=0?ooo`800000KP3oool0
0`000000oooo0?ooo`0H0?ooo`800000o`3oool00380oooo00<000000?ooo`3oool0aP3oool20000
00`0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0J0?ooo`80000000<0oooo0000
003oool0nP3oool00380oooo00<000000?ooo`3oool0dP3oool200000740oooo00<000000?ooo`3o
ool0703oool200000?/0oooo000I0?ooo`@0000000<04A4A0?ooo`3oool00P3oool2028R8P@0oooo
1@0000050?ooo`030000003oool0oooo0<80oooo0P00000=0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool07P3oool200000?T0oooo000K0?ooo`030000003oool0oooo00@0oooo0P0R
8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`320?ooo`800000
2`3oool2000007@0oooo0P00000Q0?ooo`800000m`3oool00100oooo1P0000050?ooo`030000003o
ool0oooo00/0oooo00<0VIVI028R8P3^k^h01P3oool200000<h0oooo0P00001f0?ooo`030000003o
ool0oooo0280oooo0P00003e0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`0309VIV@0R8R80
k^k^00D0oooo00<000000?ooo`3oool0b`3oool2000007P0oooo00<000000?ooo`3oool0903oool2
00000?<0oooo000K0?ooo`030000003oool0oooo00d0oooo00<0MgMg06IVIP3oool0103oool00`00
0000oooo0?ooo`2m0?ooo`8000002P3oool2000007X0oooo00<000000?ooo`3oool09P3oool20000
0?40oooo000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`2m0?ooo`800000203oool200000680oooo00D0k^k^03<c<`000000<c<c0>k^kP050?oo
o`808R8R103oool5000000D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3^0?oo
o`006`3oool00`000000oooo0?ooo`0:0?ooo`050000002k^k/0oooo09VIV@0A4A401@3oool00`00
0000oooo0?ooo`350?ooo`800000I03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R84
0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0Y0?ooo`800000kP3o
ool001T0oooo0P1EEED00`000000oooo0?ooo`0:0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3o
ool200000;T0oooo0P0000090?ooo`800000IP3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo
00<0VIVI028R8P3^k^h01P3oool00`000000oooo0?ooo`0[0?ooo`800000k03oool00380oooo00<0
00000?ooo`3oool0^03oool2000000L0oooo0P00001X0?ooo`050000003oool0oooo0?ooo`000000
3@3oool00`2IVIT08R8R0>k^kP050?ooo`800000;03oool00`000000oooo0000003[0?ooo`00<P3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo06P0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`0307MgM`1VIVH0oooo00@0oooo00<000000?ooo`3oool0;P3oool200000>T0oooo
000b0?ooo`030000003oool0oooo0;<0oooo0P0000090?ooo`800000J`3oool01@0A4A40oooo0?oo
o`3oool04A4A00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0>H0oooo000b0?ooo`030000003oool0oooo0;<0oooo0P0000070?ooo`800000K@3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@050?ooo`03
0000003oool0oooo0340oooo0P00003V0?ooo`00<P3oool200000;/0oooo0P00001_0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<00D0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`3S0?ooo`00<P3oool00`000000oooo0?ooo`2h0?ooo`80
0000R`3oool00`000000oooo0?ooo`0d0?ooo`800000h`3oool00380oooo00<000000?ooo`3oool0
[P3oool2000000L0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool000000>80oooo000b0?ooo`030000003oool0oooo0:h0oooo0P0000050?ooo`800000SP3o
ool2000003P0oooo0P00003P0?ooo`00<P3oool00`000000oooo0?ooo`2Y0?ooo`800000203oool2
00000900oooo00<000000?ooo`3oool0>@3oool200000=h0oooo000b0?ooo`800000ZP3oool20000
00L0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0=/0oooo000b0?ooo`030000003oool0oooo0;00oooo0P00002C0?ooo`030000003oool0oooo03`0
oooo0P00003K0?ooo`00<P3oool00`000000oooo0?ooo`2U0?ooo`8000001`3oool2000009D0oooo
00<000000?ooo`3oool0?P3oool200000=T0oooo000Y0?ooo`@0000000<04A4A0?ooo`3oool00P3o
ool00`000000oooo0?ooo`2P0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0=H0oooo000[0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0X03oool2000000T0oooo0P00002H0?ooo`800000@P3oool3
00000=D0oooo000P0?ooo`H000001@3oool00`000000oooo0?ooo`040?ooo`800000ZP3oool20000
09X0oooo00<000000?ooo`3oool0@`3oool200000=@0oooo000[0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0V`3oool2000000/0oooo00<000000?ooo`3oool0VP3oool00`000000
oooo0?ooo`150?ooo`800000dP3oool002/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2K0?ooo`8000002@3oool2000009d0oooo00<000000?ooo`3oool0A`3oool200000=00oooo
000[0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Y03oool2000009l0oooo00<0
00000?ooo`3oool0A`3oool010000000oooo00000000003>0?ooo`00:`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`1;0?ooo`800000c03oool002T0oooo0P1EEED00`000000oooo0?ooo`040?ooo`800000U`3oool2
000000T0oooo0P00002R0?ooo`030000003oool0oooo04d0oooo0P00003:0?ooo`00<P3oool00`00
0000oooo0?ooo`2F0?ooo`8000001`3oool200000:@0oooo0P00001=0?ooo`040000003oool0oooo
00000<T0oooo000b0?ooo`030000003oool0oooo0940oooo0P00000;0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0D03oool200000<L0oooo000b0?ooo`030000003oool0oooo0940
oooo0P0000090?ooo`800000Y`3oool00`000000oooo0?ooo`1B0?ooo`800000a@3oool00380oooo
00<000000?ooo`3oool0S@3oool2000000/0oooo0P00002Y0?ooo`030000003oool0oooo0540oooo
00@000000?ooo`3oool00000a03oool00380oooo0P00002>0?ooo`8000002@3oool200000940oooo
00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1P3oool200000003014A4@3oool0oooo00<0
oooo00<000000?ooo`3oool0E@3oool200000<80oooo000b0?ooo`030000003oool0oooo09H0oooo
0P00002C0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1G0?ooo`800000`03oool00380oooo00<000000?ooo`3oool0
U03oool2000009D0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001@3oool00`000000
oooo0?ooo`1I0?ooo`800000_P3oool00380oooo00<000000?ooo`3oool0TP3oool2000009L0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`0404A4A03MgMd0oooo000000H0oooo0P00001F0?oo
o`030000003oool0oooo00<0oooo0P00002l0?ooo`00<P3oool00`000000oooo0?ooo`280?ooo`80
00001P3oool2000009T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo
000000H0oooo00<000000?ooo`3oool0G@3oool200000;X0oooo000b0?ooo`800000Q03oool20000
00<0oooo0P0000050?ooo`030000003oool0oooo09T0oooo00D04A4A0?ooo`3oool0oooo014A4@0<
0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0G`3oool200000;P0oooo000b0?oo
o`030000003oool0oooo08<0oooo0P0000080?ooo`800000W03oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00`0oooo00<0k^k^04A4A00000001P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo0;D0oooo000b0?ooo`030000003oool0oooo08/0oooo0P00002N0?ooo`050>k^kP0c<c<00000
03<c<`3^k^h03@3oool00`1gMgL000000?ooo`050?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool01@3oool200000;D0oooo000H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2
028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c0050?ooo`030000003oool0oooo07h0oooo0P00
000:0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`2b0?ooo`00603oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2I
VIT0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`1n0?ooo`800000203oool200000;/0oooo
00<000000?ooo`3oool0I@3oool200000;80oooo000@0?ooo`H000000P3oool01@0A4A40oooo0?oo
o`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000Q`3oool200000;d0
oooo0P00001P0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`2_0?oo
o`00603oool01@000000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`05
0?ooo`030000003oool0oooo07T0oooo0P00000:0?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool0J03oool200000:l0oooo000H0?ooo`050000003oool0oooo0?ooo`0000002`3oool0
1@3<c<`00000000000000000c<c<00D0oooo00<000000?ooo`3oool0N@3oool2000000P0oooo0P00
00300?ooo`030000003oool0oooo06X0oooo0P00002]0?ooo`00603oool01@0A4A40oooo0?ooo`3o
ool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@050?ooo`030000003oool0oooo0840oooo
0P0000320?ooo`030000003oool0oooo06P0oooo00@000000?ooo`3oool0oooo0P00002[0?ooo`00
603oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0^k^k000000050?oo
o`030000003oool0oooo07D0oooo0P0000090?ooo`030000003oool0oooo0<80oooo00<000000?oo
o`3oool0KP3oool200000:T0oooo000H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2Z
ZZX04A4A0000000A4A40ZZZZ00D0oooo0P00001f0?ooo`8000001`3oool200000<D0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`0200000:L0oooo000b0?ooo`030000003oool0oooo
07`0oooo0P0000370?ooo`800000LP3oool300000080oooo00<000000?ooo`3oool0X03oool00380
oooo00<000000?ooo`3oool0L03oool2000000T0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`1d0?ooo`800000X`3oool00380oooo00<000000?ooo`3oool0L03oool2000000L0oooo
0P00003:0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0X03oool00380oooo00<0
00000?ooo`3oool0M`3oool200000<`0oooo00<000000?ooo`3oool0M`3oool200000:00oooo000b
0?ooo`800000K03oool2000000T0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`1i
0?ooo`800000WP3oool00380oooo00<000000?ooo`3oool0J`3oool2000000L0oooo0P00003?0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0V`3oool00380oooo00<000000?ooo`3o
ool0LP3oool200000=40oooo00<000000?ooo`3oool0O03oool2000009/0oooo000b0?ooo`030000
003oool0oooo06H0oooo0P0000090?ooo`030000003oool0oooo0=40oooo0P00001l0?ooo`040000
003oool0oooo000009X0oooo000b0?ooo`030000003oool0oooo06H0oooo0P0000070?ooo`800000
e03oool00`000000oooo0?ooo`1o0?ooo`800000V03oool00380oooo0P00001^0?ooo`800000eP3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo09D0oooo000b0?ooo`030000003oool0
oooo0640oooo0P0000090?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0PP3oool2
000009D0oooo000b0?ooo`030000003oool0oooo0640oooo0P0000070?ooo`800000_`3oool01@3^
k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c<c<00000014A4@3<c<`01@3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0980oooo000H0?ooo`050>k^kP0c<c<0
000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^03<c<`0000004A4A0<c<c0050?ooo`030000
003oool0oooo05d0oooo0P0000090?ooo`800000`@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0
oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo00<0oooo0P00002B0?ooo`00603oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`1M
0?ooo`8000001`3oool200000<<0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`270?ooo`800000T03oool00100oooo1P00
00020?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000D0
oooo0P00001I0?ooo`8000002P3oool200000<D0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000002IVIT0oooo09VIV@0R8R801@3oool2000008D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2=0?ooo`00603oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
09VIV@3oool0VIVI028R8P050?ooo`030000003oool0oooo05P0oooo0P0000080?ooo`800000a`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D0000005EEE@0000004A4A0<c<c0050?ooo`03
0000003oool0oooo08X0oooo0P00002=0?ooo`00603oool01@000000oooo0?ooo`3oool0000000/0
oooo00D0000005EEE@0000004A4A0<c<c0050?ooo`030000003oool0oooo0600oooo0P0000390?oo
o`05014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`070?ooo`030000003oool0
oooo08`0oooo0P00002;0?ooo`00603oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE
08R8R03oool01`3oool00`000000oooo0?ooo`1N0?ooo`800000b`3oool01@1gMgL0VIVI0?ooo`2I
VIT0MgMg00/0oooo00<0gMgM014A4@2IVIT01`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo08P0oooo000H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool00`3MgMd04A4A09VI
V@070?ooo`030000003oool0oooo05<0oooo0P0000080?ooo`030000003oool0oooo0</0oooo00D0
k^k^03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@D0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`030?ooo`800000R03oool001P0oooo00D0k^k^03<c<`000000
<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@D0oooo0P00001D0?ooo`8000001P3oool20000
0>P0oooo00<000000?ooo`3oool0S@3oool010000000oooo0?ooo`3oool2000008H0oooo000b0?oo
o`030000003oool0oooo04h0oooo0P0000090?ooo`800000jP3oool00`000000oooo0?ooo`2C0?oo
o`800000Q03oool00380oooo00<000000?ooo`3oool0CP3oool2000000P0oooo00<000000?ooo`3o
ool0jP3oool2000009H0oooo0P0000220?ooo`00<P3oool00`000000oooo0?ooo`1F0?ooo`800000
k@3oool00`000000oooo0?ooo`2G0?ooo`800000P03oool00380oooo00<000000?ooo`3oool0E03o
ool200000>l0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`020?ooo`040000003o
ool00000000007h0oooo000b0?ooo`800000E03oool00`000000oooo0?ooo`3_0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0N`3oool00380oooo00<000000?ooo`3oool0B@3oool2
000000H0oooo0P00003b0?ooo`030000003oool0oooo09`0oooo0P00001k0?ooo`00<P3oool00`00
0000oooo0?ooo`190?ooo`800000103oool200000?@0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`1h0?ooo`00<P3oool00`000000oooo0?ooo`140?ooo`800000203oool00`000000
oooo0?ooo`3d0?ooo`800000W03oool010000000oooo0?ooo`3oool2000007P0oooo000b0?ooo`03
0000003oool0oooo04@0oooo0P0000060?ooo`800000m`3oool00`000000oooo0?ooo`2Q0?ooo`03
0000003oool0oooo07D0oooo000b0?ooo`800000B`3oool200000?T0oooo00<000000?ooo`3oool0
XP3oool2000007D0oooo000b0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0n@3o
ool00`000000oooo0?ooo`2T0?ooo`800000L`3oool00380oooo00<000000?ooo`3oool0@03oool2
000000D0oooo0P00003l0?ooo`030000003oool0oooo0:D0oooo0`00001a0?ooo`00603oool01@3^
k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3oool00`3oool0
0`000000oooo0?ooo`100?ooo`8000000`3oool200000?h0oooo00<000000?ooo`3oool0Z03oool2
000006l0oooo000H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`8000001`3oool00`000000oooo0?ooo`3n
0?ooo`030000003oool0oooo0:T0oooo0`00001]0?ooo`00403oool600000080oooo00D04A4A0?oo
o`3oool0oooo014A4@0;0?ooo`D000001@3oool2000003`0oooo0P0000050?ooo`800000o`3oool2
0?ooo`800000X@3oool00`000000oooo0?ooo`090?ooo`800000J`3oool001P0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`0404A4A03MgMd0oooo000000H0oooo00<000000?ooo`3oool0@03o
ool200000?l0oooo103oool00`000000oooo0?ooo`2^0?ooo`800000J@3oool001P0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000000H0oooo00<000000?ooo`3oool0
=P3oool2000000L0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0IP3oool001P0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0307Mg
M`3<c<`0000000H0oooo00<000000?ooo`3oool0=P3oool2000000D0oooo0P00003o0?ooo`L0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`02000006H0oooo000H0?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000060?ooo`030000003oool0oooo03/0oooo
0P00003^0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0c<c<028R8P00
00008R8R0<c<c0050?ooo`030000003oool0oooo0;<0oooo0P00001T0?ooo`00603oool01@3^k^h0
<c<c0000000c<c<0k^k^00d0oooo00<0MgMg0000003oool01@3oool2000003/0oooo00<000000?oo
o`3oool0kP3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0
oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0640oooo000b
0?ooo`030000003oool0oooo0340oooo0P0000050?ooo`800000l@3oool01@0A4A40oooo0?ooo`3o
ool04A4A00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool00P00001Q0?ooo`00<P3oool00`000000oooo0?ooo`0a0?ooo`8000000`3o
ool200000?<0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c
<c<01@3oool200000;T0oooo0P00001O0?ooo`00<P3oool00`000000oooo0?ooo`0d0?ooo`800000
m@3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c0050?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0G03oool00380oooo00<000000?ooo`3o
ool0;03oool2000000@0oooo0P00003g0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@0A
4A40^k^k0?ooo`2k^k/04A4A00D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`02
000005`0oooo000b0?ooo`800000;@3oool200000080oooo0P00003i0?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0000000D0oooo00<000000?ooo`3oool0_@3o
ool2000005X0oooo000b0?ooo`030000003oool0oooo02h0oooo0P00003k0?ooo`050>k^kP0c<c<0
000003<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00D0oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`1G0?ooo`00<P3oool00`000000oooo0?ooo`0/0?ooo`800000o`3o
oolH0?ooo`030000003oool0oooo0<00oooo0P00001G0?ooo`00<P3oool00`000000oooo0?ooo`0X
0?ooo`80000000<0oooo0000003oool0o`3ooolI0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool00`3oool2000005D0oooo000b0?ooo`030000003oool0oooo02P0oooo0`00003o0?oo
oa/0oooo0P0000350?ooo`030000003oool0oooo0580oooo000b0?ooo`800000:03oool200000?l0
oooo7@3oool00`000000oooo0?ooo`350?ooo`800000DP3oool00380oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0a`3oool200000500oooo
000b0?ooo`030000003oool0oooo02<0oooo0`00003o0?ooob00oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`1=0?ooo`00603oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R
8R840?ooo`D000001@3oool00`000000oooo0?ooo`0R0?ooo`<00000o`3ooolQ0?ooo`030000003o
ool0oooo0<X0oooo0P00001=0?ooo`00603oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R
8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`3<0?ooo`800000B`3oool00100oooo1P00
00020?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`2IVIT08R8R0>k^kP060?ooo`800000
7`3oool300000?l0oooo9@3oool200000<l0oooo0P0000190?ooo`00603oool01@000000oooo0?oo
o`3oool0000000d0oooo00<0VIVI028R8P3^k^h01@3oool00`000000oooo0?ooo`0M0?ooo`<00000
o`3ooolV0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0AP3oool001P0oooo00D0
00000?ooo`3oool0oooo0000000>0?ooo`0307MgM`1VIVH0oooo00@0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`0=0?ooo`800000AP3oool001P0oooo00D04A4A0?ooo`3oool0oooo014A4@0?0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool300000?l0oooo:P3oool00`000000oooo
0?ooo`3C0?ooo`800000A03oool001P0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000
002k^k/0oooo09VIV@0A4A401@3oool00`000000oooo0?ooo`0H0?ooo`<00000o`3oool[0?ooo`03
0000003oool0oooo0=D0oooo0P0000120?ooo`00603oool01@3^k^h0<c<c0000000c<c<0k^k^00/0
oooo00D0VIVI014A4@0000008R8R0<c<c0050?ooo`800000603oool00`000000oooo0?ooo`3o0?oo
ob`0oooo00<000000?ooo`3oool0e`3oool200000400oooo000b0?ooo`030000003oool0oooo01@0
oooo0`00003o0?ooobl0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0m0?ooo`00
<P3oool00`000000oooo0?ooo`0C0?ooo`<00000o`3oool`0?ooo`800000f`3oool2000003d0oooo
000b0?ooo`030000003oool0oooo0100oooo0`00000D0?ooo`@0000000P04A4A0?ooo`3oool0k^k^
03<c<`000000<c<c0>k^kR<0oooo1@0000030?ooo`050>k^kP0c<c<0000003<c<`3^k^h08`3oool0
1@2IVIT04A4A0000000c<c<0c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0U0?ooo`800000
00T04A4A0?ooo`3oool0oooo0>k^kP0c<c<0000003<c<`3^k^h0903oool01@14A4@000000000000c
<c<0gMgM0080oooo00D0k^k^03<c<`000000<c<c0>k^kP1B0?ooo`030000003oool0oooo0=`0oooo
0P00000k0?ooo`00<P3oool00`000000oooo0?ooo`0@0?ooo`8000005`3oool00`000000oooo0?oo
o`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL08`3oool01@2IVIT08R8R0>k^kP3oool0A4A400<0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`0S0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<00`3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg02L0oooo00T0MgMg03<c<`3oool0oooo07MgM`2IVIT0oooo09VIV@1gMgL0DP3oool0
0`000000oooo0?ooo`3N0?ooo`800000>@3oool00380oooo0P00000?0?ooo`8000006@3oool00`00
0000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40903oool00`2IVIT08R8R0>k^kP04
0?ooo`05014A4@3oool0oooo0?ooo`0A4A409`3oool01@000000oooo0?ooo`3oool04A4A00<0oooo
00<04A4A0?ooo`3oool08@3oool5000000<0oooo00D04A4A0?ooo`3oool0oooo014A4@0X0?ooo`04
0000003oool0oooo014A4@<0oooo00<04A4A0?ooo`3oool0D03oool00`000000oooo0?ooo`3P0?oo
o`800000=`3oool00380oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000U0?ooo`0309VIV@0R8R80k^k^
00<0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030:ZZZP0A4A40oooo0080oooo00D00000
0?ooo`3oool0oooo0000000S0?ooo`0404A4A03MgMd0oooo000000@0oooo00D000000?ooo`3oool0
oooo0000000W0?ooo`0507MgM`0c<c<0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`170?oo
o`@0000000<04A4A0?ooo`3oool00P3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo
01T0oooo0P00000e0?ooo`00<P3oool00`000000oooo0?ooo`0;0?ooo`800000703oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000009P3oool00`1gMgL0IVIV0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000009@3oool00`0A4A4000000;^k^`030?ooo`050000003oool0
oooo0?ooo`0000008`3oool0103MgMd0EEEE0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
0000903oool01@0000008R8R0000000c<c<0c<c<0080oooo00D000000?ooo`3oool0oooo0000001;
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo00T0oooo1000000L0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0W0?ooo`050000003oool0
oooo0?ooo`0A4A400`3oool00`0A4A40oooo0?ooo`0T0?ooo`030;^k^`0R8R80oooo0080oooo00D0
4A4A0?ooo`3oool0oooo014A4@0T0?ooo`0307MgM`3<c<`0000000@0oooo00D04A4A0?ooo`3oool0
oooo014A4@0T0?ooo`030000003oool0oooo00@0oooo00D04A4A0?ooo`3oool0oooo014A4@1;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0H0?oo
o`800000<P3oool00380oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`0S0?ooo`050000002k^k/0oooo
09VIV@0A4A400`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02<0oooo00D04A4A09VIV@3oool0^k^k
000000030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0903oool00`3^k^h0A4A4000000040?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL0903oool00`000000oooo0?ooo`040?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL0B`3oool00`000000oooo0?ooo`040?ooo`800000j03oool00`000000oooo0?ooo`0_
0?ooo`00<P3oool2000000L0oooo0P00000O0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^
k^h0<c<c0000000c<c<0k^k^02<0oooo00D0VIVI014A4@0000008R8R0<c<c0030?ooo`050>k^kP0c
<c<0000003<c<`3^k^h08`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00<0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0U0?ooo`0307MgM`000000oooo00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0T
0?ooo`@000000`3oool01@3^k^h0<c<c0000000c<c<0k^k^04/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo0480oooo000b0?ooo`030000003oool0
oooo00@0oooo1000003o0?ooocL0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oooaX0oooo000b0?ooo`040000003oool0oooo0?ooo`<00000o`3ooolk0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0n0?ooo`00<P3oool00`00
0000oooo0?ooo`0300000?X0oooo00@04A4A000000000000oooo0P0000000`0A4A40oooo0?ooo`0f
0?ooo`80EEEE00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3M0?ooo`030000003oool0
oooo03T0oooo000b0?ooo`<00000oP3oool01@000000oooo0?ooo`3oool000000480oooo00<00000
0?ooo`3oool0o`3ooolJ0?ooo`00;03oooom000000X0oooo00D000000?ooo`3oool0oooo00000012
0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0=03oool00340oooo0P0000080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000120?ooo`800000o`3ooolK
0?ooo`00<P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool03P3oool01@000000R8R80?ooo`2ZZZX000000480oooo00<000000?ooo`3oool0o`3ooolJ
0?ooo`00<P3oool00`000000oooo0?ooo`3m0?ooo`03014A4@000000MgMg0080000000<0VIVI0?oo
o`3oool0@03oool00`000000oooo0?ooo`3o0?oooaX0oooo000b0?ooo`030000003oool0oooo0?l0
ooooAP3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo0300oooo003o0?ooog/0oooo
00<000000?ooo`3oool0o`3ooolJ0?ooo`00o`3ooomk0?ooo`030000003oool0oooo0?l0oooo6P3o
ool00?l0ooooN`3oool00`000000oooo0?ooo`3o0?oooaX0oooo003o0?ooool0ooooV03oool00?l0
ooooo`3ooonH0?ooo`00o`3ooooo0?oooiP0oooo003o0?ooool0ooooV03oool00?l0ooooo`3ooonH
0?ooo`00o`3ooooo0?oooiP0oooo003o0?ooool0ooooV03oool002`0oooo00<0VIVI028R8P3oool0
0P0000020?ooo`8000000P3oool00`0R8R80VIVI0?ooo`3o0?ooool0ooooGP3oool002T0oooo00`0
gMgM06IVIP000000EEEE0:ZZZP3oool0k^k^028R8P28R8P0c<c<0000003<c<`20?ooo`050:ZZZP1E
EED0000006IVIP3MgMd0o`3ooooo0?oooe`0oooo000X0?ooo`0409VIV@0000004A4A0=gMg@@0oooo
00@0gMgM000000000000c<c<1@3oool0103MgMd04A4A0000002IVIWo0?ooool0ooooF`3oool002T0
oooo00D0gMgM06IVIP000000EEEE0:ZZZP020?ooo`040>k^kP0R8R8000000>k^kP<0oooo00D0ZZZZ
05EEE@000000IVIV0=gMg@3o0?oooc40oooo00T0VIVI028R8P3oool0oooo0:ZZZP0A4A400000014A
4@28R8P00`3oool200000080oooo0P0000080?ooo`03028R8P2IVIT0oooo0?l0oooo3P3oool002`0
oooo00D0VIVI028R8P3oool0k^k^028R8P0207MgM`0603<c<`3oool0oooo0?ooo`0R8R80VIVIo`3o
oola0?ooo`050=gMg@1VIVH0000005EEE@2ZZZX00P3oool01P000000VIVI0?ooo`3<c<`08R8R08R8
R080oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`80?ooo`050:ZZZP1EEED0000006IVIP3MgMd0
o`3oool<0?ooo`00;`3oool200000080oooo0P00003o0?oooc@0oooo00@0VIVI0000000A4A40gMgM
103oool01P000000oooo0?ooo`3oool0gMgM014A4@<0oooo00@0gMgM000000000000c<c<2`3oool0
103MgMd04A4A0000002IVIWo0?ooo`/0oooo003o0?ooofX0oooo00D0gMgM06IVIP000000EEEE0:ZZ
ZP020?ooo`0305EEE@2k^k/0oooo0080oooo00P000000?ooo`3oool0oooo0>k^kP0R8R8000000>k^
kPT0oooo00D0ZZZZ05EEE@000000IVIV0=gMg@3o0?ooo``0oooo003o0?ooofd0oooo00X0VIVI028R
8P3oool0oooo0>k^kP14A4@0^k^k0?ooo`28R8P0<c<c0P3oool01@3^k^h08R8R07MgM`1gMgL0<c<c
00T0oooo00<08R8R09VIV@3oool0o`3oool>0?ooo`00o`3ooomc0?ooo`0409VIV@0A4A40EEEE0>k^
kP80oooo0P0000020?ooo`H00000o`3ooolE0?ooo`00o`3ooomc0?ooo`030000002k^k/0oooo00X0
oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00o`3ooomc0?ooo`0409VIV@0000000000014A4@X0
oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00o`3ooon20?ooo`030000003oool0oooo0?l0oooo
4`3oool00?l0ooooO`3oool010000000oooo0?ooo`00003o0?oooaD0oooo003o0?oooh00oooo0P00
003o0?oooaH0oooo003o0?ooool0ooooV03oool00?l0ooooo`3ooonH0?ooo`00o`3ooooo0?oooiP0
oooo003o0?ooool0ooooV03oool00?l0ooooo`3ooonH0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 661.188}, {193.688, 0}} -> {-0.0548894, -0.0147182, \
0.00398862, 0.00398862}, {{17.1875, 315.625}, {189.062, 4.5625}} -> \
{-10.4686, -1.60611, 0.259923, 0.0125067}, {{345.5, 643.938}, {189.062, \
4.5625}} -> {-80.8108, -0.140189, 0.26706, 0.00924916}}],

Cell["\<\
Fig. 8.6. Mean position and mean squared change in position for a \
random walk with a bias. \
\>", "Caption",
  CellTags->"Fig. 8.6"],

Cell["Both quantities closely adhere to their predicted values.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Nonuniform System", "Subsubsection",
  CellTags->"i:54"],

Cell[TextData[{
  "\tHere we simulate  a nonuniform system where the particles drift toward \
smaller ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " but are confined to the range ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  " (as occurs, for instance, when dust settles through a fluid to the bottom \
of a container  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "). We therefore require that no particles step below ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`w\  = \ 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`s < \(-x\)\)]],
  ".  The previous random walk can be easily modified to include this \
constraint by shifting the step distribution to the right, so that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(w(x, 
            s)\  = \ \(-\(1\/\(2 \( a(1 - a)\)\)\)[1 - s - a + b(x)]\)\), ",",
         "  ", 
        RowBox[{\(\(-a\) + \ b(x)\), "<", "s", "<", 
          RowBox[{"a", "+", " ", 
            RowBox[{\(b(x)\), Cell[","]}]}]}]}], TraditionalForm]]]], "NE2",
  CellTags->"(8.2.23)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`b(x)\  = \ 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`x > a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b(x)\  = \(\(a\)\(-\)\(\ \)\(x\)\(\ \)\)\)]],
  "if ",
  Cell[BoxData[
      \(TraditionalForm\`x < a\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\)]],
  " is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x > a\)]],
  ", but for  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < a\)]],
  "  it shifts so that no particle ever steps below ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ".  Since the distribution of steps shifts without changing shape, the \
diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is unaffected, and for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1/4\)]],
  " remains ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", " ", "=", " ", 
          RowBox[{\(13/1296\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ". The resulting random walk is shown in Cell ",
  ButtonBox["8.19",
    ButtonData:>"Cell 8.19",
    ButtonStyle->"Hyperlink"],
  ". The only change to the previous rejection method is  that now the random \
number ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " is a function of position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", and we choose the random number ",
  Cell[BoxData[
      \(TraditionalForm\`s\_x\)]],
  " from a range that depends on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". We now begin particles at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 2\)]],
  " so that we can see them settle toward the container bottom at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(a = \ 
        1/4;\), "\n", \(b[x_]\  := \ 0\  /; \ x > a;\), "\n", \(b[x_]\  := \ 
        a - x\  /; \ x \[LessEqual] \ \ a;\), "\n", \(w[x_, 
          s_]\  := \ \(1\/\(2  a \((1 - a)\)\)\) \((1 - s - a + 
              b[x])\);\), "\[IndentingNewLine]", 
    StyleBox[\( (*\ rejection\ \(\(method\)\(:\)\)\ *) \),
      FontColor->RGBColor[1, 0, 0]], "\n", 
    RowBox[{\(f0\  = \ 3. ;\), 
      " "}], "\[IndentingNewLine]", \(sx[x_]\  := \ 
        Random[Real, {\(-a\) + b[x], a + b[x]}];\), "\n", \(sy[]\  := \ 
        Random[Real, {0, f0}];\), "\n", 
    RowBox[{\(s[
            x_]\  := \((ss = sx[x]; \ \ While[
              sy[]\  > \ w[x, ss], \ \ ss = sx[x]]; ss)\);\), 
      "\[IndentingNewLine]"}], "\n", 
    StyleBox[\( (*\ the\ random\ \(\(walk\)\(:\)\)\ *) \),
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    RowBox[{
      " ", \(x[k_, n_]\  := \ \(x[k, n]\  = \ 
            x[k, n - 1]\  + \ s[x[k, n - 1]]\);\)}], "\[IndentingNewLine]", 
    StyleBox[\( (*\ initial\ condition\ \ and\ parameters*) \),
      FontColor->RGBColor[1, 0, 
      0]], "\n", \(x[k_, 0]\  = \ 2;\), "\n", \(M = 
        200;\), "\n", \(Nstep\  = \ 150;\), "\[IndentingNewLine]", 
    StyleBox[\( (*\ analysis*) \),
      FontColor->RGBColor[1, 0, 
      0]], "\[IndentingNewLine]", \(positions\  = \ 
        Table[x[k, n], {k, 1, 200}, {n, 0, Nstep}];\), "\n", \(pos[n_]\  := \ 
        Table[positions[\([j, n + 1]\)], {j, 1, M}];\), "\n", \(Table[
        ListPlot[pos[n], PlotRange \[Rule] {0, 3}, 
          AxesLabel \[Rule] {"\<k\>", "\<x\>"}], {n, 0, 100, 2}];\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 8.19"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .41202 Mdot
.03333 .41202 Mdot
.0381 .41202 Mdot
.04286 .41202 Mdot
.04762 .41202 Mdot
.05238 .41202 Mdot
.05714 .41202 Mdot
.0619 .41202 Mdot
.06667 .41202 Mdot
.07143 .41202 Mdot
.07619 .41202 Mdot
.08095 .41202 Mdot
.08571 .41202 Mdot
.09048 .41202 Mdot
.09524 .41202 Mdot
.1 .41202 Mdot
.10476 .41202 Mdot
.10952 .41202 Mdot
.11429 .41202 Mdot
.11905 .41202 Mdot
.12381 .41202 Mdot
.12857 .41202 Mdot
.13333 .41202 Mdot
.1381 .41202 Mdot
.14286 .41202 Mdot
.14762 .41202 Mdot
.15238 .41202 Mdot
.15714 .41202 Mdot
.1619 .41202 Mdot
.16667 .41202 Mdot
.17143 .41202 Mdot
.17619 .41202 Mdot
.18095 .41202 Mdot
.18571 .41202 Mdot
.19048 .41202 Mdot
.19524 .41202 Mdot
.2 .41202 Mdot
.20476 .41202 Mdot
.20952 .41202 Mdot
.21429 .41202 Mdot
.21905 .41202 Mdot
.22381 .41202 Mdot
.22857 .41202 Mdot
.23333 .41202 Mdot
.2381 .41202 Mdot
.24286 .41202 Mdot
.24762 .41202 Mdot
.25238 .41202 Mdot
.25714 .41202 Mdot
.2619 .41202 Mdot
.26667 .41202 Mdot
.27143 .41202 Mdot
.27619 .41202 Mdot
.28095 .41202 Mdot
.28571 .41202 Mdot
.29048 .41202 Mdot
.29524 .41202 Mdot
.3 .41202 Mdot
.30476 .41202 Mdot
.30952 .41202 Mdot
.31429 .41202 Mdot
.31905 .41202 Mdot
.32381 .41202 Mdot
.32857 .41202 Mdot
.33333 .41202 Mdot
.3381 .41202 Mdot
.34286 .41202 Mdot
.34762 .41202 Mdot
.35238 .41202 Mdot
.35714 .41202 Mdot
.3619 .41202 Mdot
.36667 .41202 Mdot
.37143 .41202 Mdot
.37619 .41202 Mdot
.38095 .41202 Mdot
.38571 .41202 Mdot
.39048 .41202 Mdot
.39524 .41202 Mdot
.4 .41202 Mdot
.40476 .41202 Mdot
.40952 .41202 Mdot
.41429 .41202 Mdot
.41905 .41202 Mdot
.42381 .41202 Mdot
.42857 .41202 Mdot
.43333 .41202 Mdot
.4381 .41202 Mdot
.44286 .41202 Mdot
.44762 .41202 Mdot
.45238 .41202 Mdot
.45714 .41202 Mdot
.4619 .41202 Mdot
.46667 .41202 Mdot
.47143 .41202 Mdot
.47619 .41202 Mdot
.48095 .41202 Mdot
.48571 .41202 Mdot
.49048 .41202 Mdot
.49524 .41202 Mdot
.5 .41202 Mdot
.50476 .41202 Mdot
.50952 .41202 Mdot
.51429 .41202 Mdot
.51905 .41202 Mdot
.52381 .41202 Mdot
.52857 .41202 Mdot
.53333 .41202 Mdot
.5381 .41202 Mdot
.54286 .41202 Mdot
.54762 .41202 Mdot
.55238 .41202 Mdot
.55714 .41202 Mdot
.5619 .41202 Mdot
.56667 .41202 Mdot
.57143 .41202 Mdot
.57619 .41202 Mdot
.58095 .41202 Mdot
.58571 .41202 Mdot
.59048 .41202 Mdot
.59524 .41202 Mdot
.6 .41202 Mdot
.60476 .41202 Mdot
.60952 .41202 Mdot
.61429 .41202 Mdot
.61905 .41202 Mdot
.62381 .41202 Mdot
.62857 .41202 Mdot
.63333 .41202 Mdot
.6381 .41202 Mdot
.64286 .41202 Mdot
.64762 .41202 Mdot
.65238 .41202 Mdot
.65714 .41202 Mdot
.6619 .41202 Mdot
.66667 .41202 Mdot
.67143 .41202 Mdot
.67619 .41202 Mdot
.68095 .41202 Mdot
.68571 .41202 Mdot
.69048 .41202 Mdot
.69524 .41202 Mdot
.7 .41202 Mdot
.70476 .41202 Mdot
.70952 .41202 Mdot
.71429 .41202 Mdot
.71905 .41202 Mdot
.72381 .41202 Mdot
.72857 .41202 Mdot
.73333 .41202 Mdot
.7381 .41202 Mdot
.74286 .41202 Mdot
.74762 .41202 Mdot
.75238 .41202 Mdot
.75714 .41202 Mdot
.7619 .41202 Mdot
.76667 .41202 Mdot
.77143 .41202 Mdot
.77619 .41202 Mdot
.78095 .41202 Mdot
.78571 .41202 Mdot
.79048 .41202 Mdot
.79524 .41202 Mdot
.8 .41202 Mdot
.80476 .41202 Mdot
.80952 .41202 Mdot
.81429 .41202 Mdot
.81905 .41202 Mdot
.82381 .41202 Mdot
.82857 .41202 Mdot
.83333 .41202 Mdot
.8381 .41202 Mdot
.84286 .41202 Mdot
.84762 .41202 Mdot
.85238 .41202 Mdot
.85714 .41202 Mdot
.8619 .41202 Mdot
.86667 .41202 Mdot
.87143 .41202 Mdot
.87619 .41202 Mdot
.88095 .41202 Mdot
.88571 .41202 Mdot
.89048 .41202 Mdot
.89524 .41202 Mdot
.9 .41202 Mdot
.90476 .41202 Mdot
.90952 .41202 Mdot
.91429 .41202 Mdot
.91905 .41202 Mdot
.92381 .41202 Mdot
.92857 .41202 Mdot
.93333 .41202 Mdot
.9381 .41202 Mdot
.94286 .41202 Mdot
.94762 .41202 Mdot
.95238 .41202 Mdot
.95714 .41202 Mdot
.9619 .41202 Mdot
.96667 .41202 Mdot
.97143 .41202 Mdot
.97619 .41202 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0gooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0booooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03;ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo001Yoooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03Wooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0doooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
<_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool006[ooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0gooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100=?ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0<Oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01kooooo001Yoooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
=?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0booooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000007_ooool006Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003Cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000e
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000007_ooool006Kooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`00I_oo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0<_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool006Kooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0=oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03;ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Noooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomCooooo`;o00000_ooool00ol@413o0000o`00
000?ooooo`00oooooomDooooo`05o`000?ooooook^k^oc8b<_o<c<`04?ooool00?ooooooE?ooool0
1?l0003oV9RHoc8b<_o<c<`Aooooo`007_ooooooo`0002_o00002oooool00ol0003o410@oiRHV00B
ooooo`009Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04?ooool01?l0003ok^k^oeEEEOn7QhLAooooo`009Oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo00Go0000oooooom4A4Co0000oa0@400@ooooo`009Oooool00ol0
003oooooooooo`3oooooobcooooo00?o0000ooooooooool04_ooool002Gooooo00?o0000oooooooo
ool0ooooool/ooooo`03o`000?oooooooooo01;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
:oooool2o`0001Cooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000:
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3ooooood7ooooo000:ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool000[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood7ooooo000:
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooom1ooooo`002_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood7ooooo000:ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@Oooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000;ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool000gooooo
00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo@Oooool000gooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@Oooool000gooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom1ooooo`003Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom1oooo
o`003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom1ooooo`002oooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool00onHV9So8B4Qonk^kP07oooooooo00007_l0000Vooooo`007?ooool00onHV9So8B4Q
onk^kP06oooooooo00007_l0000Vooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
oooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3o
oooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000:ooooo`Go00001Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo
@Oooool000[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool000_ooooo00?oV9RHob4Q8Oo^k^h04Ooo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom1ooooo`003?ooool00onHV9So8B4Qonk^kP0?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`003Oooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3o
oooood7ooooo000>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3ooooood7ooooo000:ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@Oooool000[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_oo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_oo
ool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo0ol0003o
oooood7ooooo000Mooooo`03ojVYZOl@413ooooo0?ooooooBOooool001cooooo00?o410@o`000?nj
^[X0oooooom:ooooo`007Oooool00onj^[[o8B4Qooooo`3oooooodWooooo000Jooooo`05oa0@4?nH
V9SooooookZj^_l00000oooooom:ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo
B_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool002;ooooo0_l00002ooooo`;o0000oooooom1ooooo`008_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMgOoooooo@Oooool002?ooooo00CogMgMo`000?l@413oc<c<oooo
oom2ooooo`008oooool01?o^k^ko8B4Qoa0@4?o^k^kooooood;ooooo000Sooooo`04ob4Q8OmgMgOo
MgMgoc8b<_oooooo@_ooool002;ooooo0_l00002ooooo`;o0000oooooom1ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26.3541, -0.244154, \
0.881889, 0.0203847}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .34178 Mdot
.03333 .39531 Mdot
.0381 .4086 Mdot
.04286 .37418 Mdot
.04762 .37976 Mdot
.05238 .32106 Mdot
.05714 .36758 Mdot
.0619 .38752 Mdot
.06667 .34899 Mdot
.07143 .38811 Mdot
.07619 .34264 Mdot
.08095 .36286 Mdot
.08571 .37584 Mdot
.09048 .47225 Mdot
.09524 .42759 Mdot
.1 .40179 Mdot
.10476 .3457 Mdot
.10952 .4272 Mdot
.11429 .37734 Mdot
.11905 .38203 Mdot
.12381 .34258 Mdot
.12857 .35123 Mdot
.13333 .37896 Mdot
.1381 .35269 Mdot
.14286 .35837 Mdot
.14762 .35017 Mdot
.15238 .37474 Mdot
.15714 .39767 Mdot
.1619 .36228 Mdot
.16667 .38165 Mdot
.17143 .43534 Mdot
.17619 .47446 Mdot
.18095 .42782 Mdot
.18571 .4777 Mdot
.19048 .42218 Mdot
.19524 .40353 Mdot
.2 .38488 Mdot
.20476 .39997 Mdot
.20952 .40645 Mdot
.21429 .39771 Mdot
.21905 .4084 Mdot
.22381 .45594 Mdot
.22857 .35004 Mdot
.23333 .44544 Mdot
.2381 .45492 Mdot
.24286 .3999 Mdot
.24762 .3885 Mdot
.25238 .32437 Mdot
.25714 .35488 Mdot
.2619 .34267 Mdot
.26667 .43843 Mdot
.27143 .40935 Mdot
.27619 .40037 Mdot
.28095 .38354 Mdot
.28571 .42442 Mdot
.29048 .39424 Mdot
.29524 .45766 Mdot
.3 .37764 Mdot
.30476 .36778 Mdot
.30952 .40625 Mdot
.31429 .32828 Mdot
.31905 .40534 Mdot
.32381 .34663 Mdot
.32857 .43009 Mdot
.33333 .42054 Mdot
.3381 .44812 Mdot
.34286 .40422 Mdot
.34762 .47795 Mdot
.35238 .41271 Mdot
.35714 .35565 Mdot
.3619 .43818 Mdot
.36667 .41932 Mdot
.37143 .48633 Mdot
.37619 .38691 Mdot
.38095 .50464 Mdot
.38571 .41791 Mdot
.39048 .37707 Mdot
.39524 .36255 Mdot
.4 .4463 Mdot
.40476 .41242 Mdot
.40952 .36376 Mdot
.41429 .44483 Mdot
.41905 .45907 Mdot
.42381 .40416 Mdot
.42857 .41942 Mdot
.43333 .40939 Mdot
.4381 .35222 Mdot
.44286 .42482 Mdot
.44762 .44539 Mdot
.45238 .34605 Mdot
.45714 .32161 Mdot
.4619 .39881 Mdot
.46667 .39181 Mdot
.47143 .34479 Mdot
.47619 .35005 Mdot
.48095 .35225 Mdot
.48571 .37876 Mdot
.49048 .48218 Mdot
.49524 .39006 Mdot
.5 .38243 Mdot
.50476 .43232 Mdot
.50952 .43597 Mdot
.51429 .45585 Mdot
.51905 .36171 Mdot
.52381 .43547 Mdot
.52857 .40809 Mdot
.53333 .4081 Mdot
.5381 .45661 Mdot
.54286 .42225 Mdot
.54762 .36466 Mdot
.55238 .36593 Mdot
.55714 .44687 Mdot
.5619 .46578 Mdot
.56667 .42133 Mdot
.57143 .38242 Mdot
.57619 .36204 Mdot
.58095 .4212 Mdot
.58571 .36781 Mdot
.59048 .36155 Mdot
.59524 .43897 Mdot
.6 .41198 Mdot
.60476 .43629 Mdot
.60952 .41987 Mdot
.61429 .40938 Mdot
.61905 .41266 Mdot
.62381 .34387 Mdot
.62857 .47068 Mdot
.63333 .43542 Mdot
.6381 .3752 Mdot
.64286 .37414 Mdot
.64762 .3308 Mdot
.65238 .44391 Mdot
.65714 .39546 Mdot
.6619 .46229 Mdot
.66667 .47335 Mdot
.67143 .44846 Mdot
.67619 .36825 Mdot
.68095 .43667 Mdot
.68571 .41577 Mdot
.69048 .44192 Mdot
.69524 .36951 Mdot
.7 .3916 Mdot
.70476 .37514 Mdot
.70952 .40116 Mdot
.71429 .40307 Mdot
.71905 .40842 Mdot
.72381 .3439 Mdot
.72857 .38136 Mdot
.73333 .48884 Mdot
.7381 .40956 Mdot
.74286 .34781 Mdot
.74762 .42704 Mdot
.75238 .40332 Mdot
.75714 .38371 Mdot
.7619 .4433 Mdot
.76667 .49637 Mdot
.77143 .40687 Mdot
.77619 .40604 Mdot
.78095 .43542 Mdot
.78571 .37047 Mdot
.79048 .36634 Mdot
.79524 .40082 Mdot
.8 .38696 Mdot
.80476 .4791 Mdot
.80952 .48142 Mdot
.81429 .38491 Mdot
.81905 .41966 Mdot
.82381 .4336 Mdot
.82857 .43159 Mdot
.83333 .37668 Mdot
.8381 .36375 Mdot
.84286 .44619 Mdot
.84762 .39302 Mdot
.85238 .45908 Mdot
.85714 .45866 Mdot
.8619 .33185 Mdot
.86667 .39768 Mdot
.87143 .39751 Mdot
.87619 .45835 Mdot
.88095 .47702 Mdot
.88571 .38045 Mdot
.89048 .4378 Mdot
.89524 .35644 Mdot
.9 .41301 Mdot
.90476 .43654 Mdot
.90952 .44019 Mdot
.91429 .37984 Mdot
.91905 .37176 Mdot
.92381 .44976 Mdot
.92857 .32435 Mdot
.93333 .41575 Mdot
.9381 .41472 Mdot
.94286 .40502 Mdot
.94762 .40886 Mdot
.95238 .4905 Mdot
.95714 .39425 Mdot
.9619 .42465 Mdot
.96667 .4565 Mdot
.97143 .50797 Mdot
.97619 .40099 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .38026 Mdot
.03333 .45076 Mdot
.0381 .36208 Mdot
.04286 .36638 Mdot
.04762 .38153 Mdot
.05238 .35963 Mdot
.05714 .36093 Mdot
.0619 .37691 Mdot
.06667 .29313 Mdot
.07143 .32025 Mdot
.07619 .31521 Mdot
.08095 .37229 Mdot
.08571 .31294 Mdot
.09048 .43725 Mdot
.09524 .47408 Mdot
.1 .44512 Mdot
.10476 .36581 Mdot
.10952 .49106 Mdot
.11429 .34675 Mdot
.11905 .37818 Mdot
.12381 .32783 Mdot
.12857 .35424 Mdot
.13333 .40134 Mdot
.1381 .33521 Mdot
.14286 .43582 Mdot
.14762 .31262 Mdot
.15238 .30384 Mdot
.15714 .3493 Mdot
.1619 .33531 Mdot
.16667 .34996 Mdot
.17143 .45419 Mdot
.17619 .46197 Mdot
.18095 .41256 Mdot
.18571 .54127 Mdot
.19048 .41445 Mdot
.19524 .40926 Mdot
.2 .43171 Mdot
.20476 .34442 Mdot
.20952 .44173 Mdot
.21429 .34652 Mdot
.21905 .39242 Mdot
.22381 .42998 Mdot
.22857 .39959 Mdot
.23333 .46851 Mdot
.2381 .49291 Mdot
.24286 .35801 Mdot
.24762 .32845 Mdot
.25238 .2702 Mdot
.25714 .43244 Mdot
.2619 .39195 Mdot
.26667 .35696 Mdot
.27143 .45281 Mdot
.27619 .3412 Mdot
.28095 .38364 Mdot
.28571 .36073 Mdot
.29048 .40614 Mdot
.29524 .42698 Mdot
.3 .43895 Mdot
.30476 .28559 Mdot
.30952 .36163 Mdot
.31429 .30374 Mdot
.31905 .40345 Mdot
.32381 .3507 Mdot
.32857 .3695 Mdot
.33333 .42345 Mdot
.3381 .44206 Mdot
.34286 .42987 Mdot
.34762 .43807 Mdot
.35238 .42619 Mdot
.35714 .32407 Mdot
.3619 .42448 Mdot
.36667 .39578 Mdot
.37143 .51467 Mdot
.37619 .34799 Mdot
.38095 .46853 Mdot
.38571 .45674 Mdot
.39048 .36995 Mdot
.39524 .39578 Mdot
.4 .4482 Mdot
.40476 .36075 Mdot
.40952 .42777 Mdot
.41429 .3914 Mdot
.41905 .49942 Mdot
.42381 .3476 Mdot
.42857 .38905 Mdot
.43333 .41796 Mdot
.4381 .39155 Mdot
.44286 .45894 Mdot
.44762 .36919 Mdot
.45238 .33342 Mdot
.45714 .24581 Mdot
.4619 .39548 Mdot
.46667 .48273 Mdot
.47143 .28146 Mdot
.47619 .34122 Mdot
.48095 .4164 Mdot
.48571 .38325 Mdot
.49048 .44174 Mdot
.49524 .36017 Mdot
.5 .35702 Mdot
.50476 .39646 Mdot
.50952 .4321 Mdot
.51429 .49245 Mdot
.51905 .37746 Mdot
.52381 .39723 Mdot
.52857 .4735 Mdot
.53333 .45719 Mdot
.5381 .38944 Mdot
.54286 .41502 Mdot
.54762 .37435 Mdot
.55238 .38052 Mdot
.55714 .43769 Mdot
.5619 .50266 Mdot
.56667 .46731 Mdot
.57143 .30933 Mdot
.57619 .3187 Mdot
.58095 .35082 Mdot
.58571 .36885 Mdot
.59048 .33956 Mdot
.59524 .44554 Mdot
.6 .3833 Mdot
.60476 .4075 Mdot
.60952 .37619 Mdot
.61429 .46134 Mdot
.61905 .39425 Mdot
.62381 .38005 Mdot
.62857 .46677 Mdot
.63333 .39083 Mdot
.6381 .32013 Mdot
.64286 .40218 Mdot
.64762 .30302 Mdot
.65238 .37409 Mdot
.65714 .34077 Mdot
.6619 .4586 Mdot
.66667 .43815 Mdot
.67143 .37622 Mdot
.67619 .34112 Mdot
.68095 .39384 Mdot
.68571 .33446 Mdot
.69048 .46049 Mdot
.69524 .44565 Mdot
.7 .36576 Mdot
.70476 .42574 Mdot
.70952 .3849 Mdot
.71429 .40232 Mdot
.71905 .41673 Mdot
.72381 .26689 Mdot
.72857 .33415 Mdot
.73333 .53076 Mdot
.7381 .38978 Mdot
.74286 .38086 Mdot
.74762 .41882 Mdot
.75238 .37672 Mdot
.75714 .35263 Mdot
.7619 .49429 Mdot
.76667 .43242 Mdot
.77143 .35824 Mdot
.77619 .31315 Mdot
.78095 .37029 Mdot
.78571 .41397 Mdot
.79048 .34772 Mdot
.79524 .4065 Mdot
.8 .43379 Mdot
.80476 .4214 Mdot
.80952 .4245 Mdot
.81429 .3157 Mdot
.81905 .41389 Mdot
.82381 .46606 Mdot
.82857 .40814 Mdot
.83333 .37763 Mdot
.8381 .29527 Mdot
.84286 .46936 Mdot
.84762 .43898 Mdot
.85238 .49771 Mdot
.85714 .54151 Mdot
.8619 .31441 Mdot
.86667 .40152 Mdot
.87143 .40385 Mdot
.87619 .40155 Mdot
.88095 .43233 Mdot
.88571 .38896 Mdot
.89048 .43862 Mdot
.89524 .349 Mdot
.9 .49496 Mdot
.90476 .43957 Mdot
.90952 .41187 Mdot
.91429 .40521 Mdot
.91905 .34579 Mdot
.92381 .4776 Mdot
.92857 .31061 Mdot
.93333 .38245 Mdot
.9381 .40408 Mdot
.94286 .42341 Mdot
.94762 .40474 Mdot
.95238 .49458 Mdot
.95714 .38786 Mdot
.9619 .38739 Mdot
.96667 .46609 Mdot
.97143 .4629 Mdot
.97619 .39304 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36982 Mdot
.03333 .43862 Mdot
.0381 .33584 Mdot
.04286 .33912 Mdot
.04762 .38316 Mdot
.05238 .36552 Mdot
.05714 .3643 Mdot
.0619 .38109 Mdot
.06667 .22587 Mdot
.07143 .30238 Mdot
.07619 .30043 Mdot
.08095 .38707 Mdot
.08571 .29008 Mdot
.09048 .5076 Mdot
.09524 .52901 Mdot
.1 .37417 Mdot
.10476 .34803 Mdot
.10952 .5676 Mdot
.11429 .37575 Mdot
.11905 .37954 Mdot
.12381 .29621 Mdot
.12857 .2987 Mdot
.13333 .38254 Mdot
.1381 .30011 Mdot
.14286 .44357 Mdot
.14762 .2643 Mdot
.15238 .29014 Mdot
.15714 .3523 Mdot
.1619 .35624 Mdot
.16667 .2602 Mdot
.17143 .38083 Mdot
.17619 .52459 Mdot
.18095 .34446 Mdot
.18571 .59403 Mdot
.19048 .40684 Mdot
.19524 .44682 Mdot
.2 .43701 Mdot
.20476 .32817 Mdot
.20952 .44604 Mdot
.21429 .30567 Mdot
.21905 .36718 Mdot
.22381 .43208 Mdot
.22857 .37884 Mdot
.23333 .40577 Mdot
.2381 .49137 Mdot
.24286 .35981 Mdot
.24762 .29281 Mdot
.25238 .22485 Mdot
.25714 .49379 Mdot
.2619 .40338 Mdot
.26667 .31384 Mdot
.27143 .45539 Mdot
.27619 .30611 Mdot
.28095 .40914 Mdot
.28571 .3689 Mdot
.29048 .42878 Mdot
.29524 .33733 Mdot
.3 .48031 Mdot
.30476 .29131 Mdot
.30952 .36026 Mdot
.31429 .31463 Mdot
.31905 .32581 Mdot
.32381 .28553 Mdot
.32857 .3685 Mdot
.33333 .39837 Mdot
.3381 .46282 Mdot
.34286 .36592 Mdot
.34762 .39378 Mdot
.35238 .37743 Mdot
.35714 .35405 Mdot
.3619 .44267 Mdot
.36667 .38323 Mdot
.37143 .4417 Mdot
.37619 .30017 Mdot
.38095 .4645 Mdot
.38571 .43244 Mdot
.39048 .34003 Mdot
.39524 .35165 Mdot
.4 .39182 Mdot
.40476 .37326 Mdot
.40952 .37448 Mdot
.41429 .38889 Mdot
.41905 .52838 Mdot
.42381 .35101 Mdot
.42857 .42097 Mdot
.43333 .34032 Mdot
.4381 .36043 Mdot
.44286 .4704 Mdot
.44762 .37863 Mdot
.45238 .27524 Mdot
.45714 .24248 Mdot
.4619 .42837 Mdot
.46667 .39959 Mdot
.47143 .20979 Mdot
.47619 .32534 Mdot
.48095 .42743 Mdot
.48571 .40281 Mdot
.49048 .40886 Mdot
.49524 .41092 Mdot
.5 .41906 Mdot
.50476 .40039 Mdot
.50952 .39539 Mdot
.51429 .4168 Mdot
.51905 .33042 Mdot
.52381 .34986 Mdot
.52857 .49212 Mdot
.53333 .42573 Mdot
.5381 .37225 Mdot
.54286 .51146 Mdot
.54762 .38957 Mdot
.55238 .41875 Mdot
.55714 .4758 Mdot
.5619 .46945 Mdot
.56667 .4543 Mdot
.57143 .31628 Mdot
.57619 .26204 Mdot
.58095 .36551 Mdot
.58571 .30482 Mdot
.59048 .41446 Mdot
.59524 .47011 Mdot
.6 .38064 Mdot
.60476 .41555 Mdot
.60952 .35316 Mdot
.61429 .40875 Mdot
.61905 .35071 Mdot
.62381 .43963 Mdot
.62857 .3837 Mdot
.63333 .39791 Mdot
.6381 .30854 Mdot
.64286 .38415 Mdot
.64762 .20971 Mdot
.65238 .42712 Mdot
.65714 .32254 Mdot
.6619 .47436 Mdot
.66667 .43883 Mdot
.67143 .36803 Mdot
.67619 .39624 Mdot
.68095 .419 Mdot
.68571 .37223 Mdot
.69048 .40202 Mdot
.69524 .43694 Mdot
.7 .3497 Mdot
.70476 .41331 Mdot
.70952 .35735 Mdot
.71429 .36655 Mdot
.71905 .45895 Mdot
.72381 .30933 Mdot
.72857 .33996 Mdot
.73333 .51654 Mdot
.7381 .41078 Mdot
.74286 .32664 Mdot
.74762 .43755 Mdot
.75238 .40647 Mdot
.75714 .33698 Mdot
.7619 .46394 Mdot
.76667 .35675 Mdot
.77143 .35508 Mdot
.77619 .33279 Mdot
.78095 .45283 Mdot
.78571 .44348 Mdot
.79048 .33096 Mdot
.79524 .37124 Mdot
.8 .41858 Mdot
.80476 .36144 Mdot
.80952 .45212 Mdot
.81429 .32012 Mdot
.81905 .41401 Mdot
.82381 .45215 Mdot
.82857 .35966 Mdot
.83333 .33469 Mdot
.8381 .31099 Mdot
.84286 .41955 Mdot
.84762 .38047 Mdot
.85238 .5585 Mdot
.85714 .58114 Mdot
.8619 .40443 Mdot
.86667 .32315 Mdot
.87143 .40367 Mdot
.87619 .43801 Mdot
.88095 .41172 Mdot
.88571 .44632 Mdot
.89048 .39494 Mdot
.89524 .33091 Mdot
.9 .48453 Mdot
.90476 .40094 Mdot
.90952 .42953 Mdot
.91429 .42335 Mdot
.91905 .29672 Mdot
.92381 .43882 Mdot
.92857 .30881 Mdot
.93333 .37628 Mdot
.9381 .35902 Mdot
.94286 .3803 Mdot
.94762 .33775 Mdot
.95238 .4689 Mdot
.95714 .35927 Mdot
.9619 .38269 Mdot
.96667 .4531 Mdot
.97143 .4371 Mdot
.97619 .31038 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39211 Mdot
.03333 .42426 Mdot
.0381 .38783 Mdot
.04286 .26929 Mdot
.04762 .35781 Mdot
.05238 .28087 Mdot
.05714 .35465 Mdot
.0619 .35926 Mdot
.06667 .22137 Mdot
.07143 .30522 Mdot
.07619 .33098 Mdot
.08095 .37465 Mdot
.08571 .31806 Mdot
.09048 .51289 Mdot
.09524 .48123 Mdot
.1 .33951 Mdot
.10476 .38921 Mdot
.10952 .54539 Mdot
.11429 .41742 Mdot
.11905 .40368 Mdot
.12381 .26916 Mdot
.12857 .20964 Mdot
.13333 .34702 Mdot
.1381 .27236 Mdot
.14286 .46777 Mdot
.14762 .30015 Mdot
.15238 .20739 Mdot
.15714 .35376 Mdot
.1619 .36331 Mdot
.16667 .26135 Mdot
.17143 .33276 Mdot
.17619 .58765 Mdot
.18095 .32785 Mdot
.19048 .40548 Mdot
.19524 .42815 Mdot
.2 .45015 Mdot
.20476 .28986 Mdot
.20952 .47404 Mdot
.21429 .3287 Mdot
.21905 .32694 Mdot
.22381 .44284 Mdot
.22857 .42772 Mdot
.23333 .37389 Mdot
.2381 .46959 Mdot
.24286 .28413 Mdot
.24762 .28403 Mdot
.25238 .17493 Mdot
.25714 .48844 Mdot
.2619 .33352 Mdot
.26667 .30723 Mdot
.27143 .49916 Mdot
.27619 .22432 Mdot
.28095 .39125 Mdot
.28571 .42766 Mdot
.29048 .38515 Mdot
.29524 .32946 Mdot
.3 .45257 Mdot
.30476 .24563 Mdot
.30952 .29079 Mdot
.31429 .22087 Mdot
.31905 .29371 Mdot
.32381 .31422 Mdot
.32857 .36074 Mdot
.33333 .34503 Mdot
.3381 .44662 Mdot
.34286 .29269 Mdot
.34762 .30224 Mdot
.35238 .34911 Mdot
.35714 .36119 Mdot
.3619 .45107 Mdot
.36667 .46459 Mdot
.37143 .43511 Mdot
.37619 .31187 Mdot
.38095 .46775 Mdot
.38571 .34779 Mdot
.39048 .31384 Mdot
.39524 .36296 Mdot
.4 .39602 Mdot
.40476 .30904 Mdot
.40952 .35502 Mdot
.41429 .35707 Mdot
.41905 .49859 Mdot
.42381 .27782 Mdot
.42857 .37455 Mdot
.43333 .41351 Mdot
.4381 .33509 Mdot
.44286 .4041 Mdot
.44762 .29666 Mdot
.45238 .21385 Mdot
.45714 .18644 Mdot
.4619 .37402 Mdot
.46667 .35547 Mdot
.47143 .12623 Mdot
.47619 .30129 Mdot
.48095 .3893 Mdot
.48571 .44594 Mdot
.49048 .34323 Mdot
.49524 .38964 Mdot
.5 .39106 Mdot
.50476 .3868 Mdot
.50952 .43476 Mdot
.51429 .36052 Mdot
.51905 .25261 Mdot
.52381 .32372 Mdot
.52857 .45968 Mdot
.53333 .38973 Mdot
.5381 .37136 Mdot
.54286 .52054 Mdot
.54762 .39544 Mdot
.55238 .41274 Mdot
.55714 .47721 Mdot
.5619 .42214 Mdot
.56667 .42302 Mdot
.57143 .29409 Mdot
.57619 .24537 Mdot
.58095 .41309 Mdot
.58571 .24409 Mdot
.59048 .38731 Mdot
.59524 .4764 Mdot
.6 .34068 Mdot
.60476 .41273 Mdot
.60952 .40794 Mdot
.61429 .43308 Mdot
.61905 .26685 Mdot
.62381 .46213 Mdot
.62857 .39082 Mdot
.63333 .38186 Mdot
.6381 .29526 Mdot
.64286 .36136 Mdot
.64762 .18002 Mdot
.65238 .39906 Mdot
.65714 .29041 Mdot
.6619 .40298 Mdot
.66667 .42806 Mdot
.67143 .33808 Mdot
.67619 .44743 Mdot
.68095 .34664 Mdot
.68571 .41504 Mdot
.69048 .4051 Mdot
.69524 .42623 Mdot
.7 .35213 Mdot
.70476 .34466 Mdot
.70952 .40531 Mdot
.71429 .3306 Mdot
.71905 .40431 Mdot
.72381 .25484 Mdot
.72857 .34074 Mdot
.73333 .44698 Mdot
.7381 .37676 Mdot
.74286 .34088 Mdot
.74762 .44173 Mdot
.75238 .39687 Mdot
.75714 .26879 Mdot
.7619 .52568 Mdot
.76667 .44855 Mdot
.77143 .3161 Mdot
.77619 .29156 Mdot
.78095 .43535 Mdot
.78571 .4568 Mdot
.79048 .31219 Mdot
.79524 .32887 Mdot
.8 .46032 Mdot
.80476 .38488 Mdot
.80952 .43632 Mdot
.81429 .32759 Mdot
.81905 .34744 Mdot
.82381 .44468 Mdot
.82857 .36038 Mdot
.83333 .24656 Mdot
.8381 .30378 Mdot
.84286 .38431 Mdot
.84762 .39252 Mdot
.85238 .561 Mdot
.85714 .5979 Mdot
.8619 .42358 Mdot
.86667 .25946 Mdot
.87143 .39924 Mdot
.87619 .43681 Mdot
.88095 .41091 Mdot
.88571 .51893 Mdot
.89048 .37776 Mdot
.89524 .39399 Mdot
.9 .48186 Mdot
.90476 .41485 Mdot
.90952 .44543 Mdot
.91429 .37714 Mdot
.91905 .32553 Mdot
.92381 .42972 Mdot
.92857 .303 Mdot
.93333 .37285 Mdot
.9381 .29436 Mdot
.94286 .39269 Mdot
.94762 .27206 Mdot
.95238 .49959 Mdot
.95714 .36268 Mdot
.9619 .32362 Mdot
.96667 .44053 Mdot
.97143 .36889 Mdot
.97619 .26652 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33904 Mdot
.03333 .38581 Mdot
.0381 .33927 Mdot
.04286 .2635 Mdot
.04762 .32639 Mdot
.05238 .2229 Mdot
.05714 .32979 Mdot
.0619 .3436 Mdot
.06667 .26909 Mdot
.07143 .36864 Mdot
.07619 .35062 Mdot
.08095 .45334 Mdot
.08571 .37109 Mdot
.09048 .53005 Mdot
.09524 .48483 Mdot
.1 .32282 Mdot
.10476 .29869 Mdot
.11429 .44786 Mdot
.11905 .42383 Mdot
.12381 .25832 Mdot
.12857 .19122 Mdot
.13333 .36491 Mdot
.1381 .27004 Mdot
.14286 .45264 Mdot
.14762 .34303 Mdot
.15238 .13952 Mdot
.15714 .37043 Mdot
.1619 .38623 Mdot
.16667 .26176 Mdot
.17143 .27456 Mdot
.17619 .52062 Mdot
.18095 .33232 Mdot
.18571 .55814 Mdot
.19048 .40764 Mdot
.19524 .41798 Mdot
.2 .35605 Mdot
.20476 .29902 Mdot
.20952 .44997 Mdot
.21429 .32741 Mdot
.21905 .39077 Mdot
.22381 .42019 Mdot
.22857 .41475 Mdot
.23333 .36716 Mdot
.2381 .47129 Mdot
.24286 .26496 Mdot
.24762 .26357 Mdot
.25238 .14633 Mdot
.25714 .53794 Mdot
.2619 .28977 Mdot
.26667 .28053 Mdot
.27143 .50657 Mdot
.27619 .20922 Mdot
.28095 .43349 Mdot
.28571 .38693 Mdot
.29048 .42969 Mdot
.29524 .33458 Mdot
.3 .43786 Mdot
.30476 .25127 Mdot
.30952 .29894 Mdot
.31429 .16602 Mdot
.31905 .28209 Mdot
.32381 .30505 Mdot
.32857 .36981 Mdot
.33333 .38492 Mdot
.3381 .46716 Mdot
.34286 .28352 Mdot
.34762 .23137 Mdot
.35238 .2863 Mdot
.35714 .37806 Mdot
.3619 .46214 Mdot
.36667 .44333 Mdot
.37143 .40284 Mdot
.37619 .28438 Mdot
.38095 .50415 Mdot
.38571 .37937 Mdot
.39048 .36789 Mdot
.39524 .33733 Mdot
.4 .30342 Mdot
.40476 .25839 Mdot
.40952 .34093 Mdot
.41429 .26373 Mdot
.41905 .51318 Mdot
.42381 .17878 Mdot
.42857 .30528 Mdot
.43333 .39505 Mdot
.4381 .38161 Mdot
.44286 .41671 Mdot
.44762 .25046 Mdot
.45238 .1628 Mdot
.45714 .21944 Mdot
.4619 .3097 Mdot
.46667 .39669 Mdot
.47143 .16758 Mdot
.47619 .36856 Mdot
.48095 .33944 Mdot
.48571 .43201 Mdot
.49048 .38268 Mdot
.49524 .46164 Mdot
.5 .36661 Mdot
.50476 .40279 Mdot
.50952 .45494 Mdot
.51429 .33179 Mdot
.51905 .26485 Mdot
.52381 .34232 Mdot
.52857 .51534 Mdot
.53333 .38133 Mdot
.5381 .42321 Mdot
.54286 .45572 Mdot
.54762 .39826 Mdot
.55238 .33424 Mdot
.55714 .40704 Mdot
.5619 .36342 Mdot
.56667 .40377 Mdot
.57143 .27022 Mdot
.57619 .26626 Mdot
.58095 .3457 Mdot
.58571 .21124 Mdot
.59048 .42889 Mdot
.59524 .46312 Mdot
.6 .32785 Mdot
.60476 .39515 Mdot
.60952 .3417 Mdot
.61429 .37756 Mdot
.61905 .24499 Mdot
.62381 .46309 Mdot
.62857 .37421 Mdot
.63333 .33481 Mdot
.6381 .34894 Mdot
.64286 .29098 Mdot
.64762 .15333 Mdot
.65238 .35155 Mdot
.65714 .358 Mdot
.6619 .38179 Mdot
.66667 .42932 Mdot
.67143 .35222 Mdot
.67619 .43574 Mdot
.68095 .34997 Mdot
.68571 .37403 Mdot
.69048 .37827 Mdot
.69524 .38963 Mdot
.7 .36335 Mdot
.70476 .38312 Mdot
.70952 .3503 Mdot
.71429 .3119 Mdot
.71905 .38723 Mdot
.72381 .20785 Mdot
.72857 .28884 Mdot
.73333 .44611 Mdot
.7381 .36655 Mdot
.74286 .38266 Mdot
.74762 .48927 Mdot
.75238 .34945 Mdot
.75714 .22157 Mdot
.7619 .47826 Mdot
.76667 .52511 Mdot
.77143 .29532 Mdot
.77619 .2461 Mdot
.78095 .36697 Mdot
.78571 .40696 Mdot
.79048 .22485 Mdot
.79524 .3577 Mdot
.8 .42663 Mdot
.80476 .36753 Mdot
.80952 .37943 Mdot
.81429 .31067 Mdot
.81905 .28548 Mdot
.82381 .50967 Mdot
.82857 .41779 Mdot
.83333 .28774 Mdot
.8381 .25064 Mdot
.84286 .40168 Mdot
.84762 .3809 Mdot
.85238 .56827 Mdot
.8619 .42998 Mdot
.86667 .23864 Mdot
.87143 .35447 Mdot
.87619 .44065 Mdot
.88095 .45581 Mdot
.88571 .52681 Mdot
.89048 .33678 Mdot
.89524 .38493 Mdot
.9 .41259 Mdot
.90476 .50063 Mdot
.90952 .47603 Mdot
.91429 .37971 Mdot
.91905 .34391 Mdot
.92381 .40468 Mdot
.92857 .36561 Mdot
.93333 .36315 Mdot
.9381 .26871 Mdot
.94286 .42192 Mdot
.94762 .24424 Mdot
.95238 .49484 Mdot
.95714 .40652 Mdot
.9619 .28259 Mdot
.96667 .44557 Mdot
.97143 .32979 Mdot
.97619 .25166 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .25913 Mdot
.03333 .38185 Mdot
.0381 .33561 Mdot
.04286 .28428 Mdot
.04762 .29919 Mdot
.05238 .15546 Mdot
.05714 .32745 Mdot
.0619 .44156 Mdot
.06667 .2694 Mdot
.07143 .37214 Mdot
.07619 .37774 Mdot
.08095 .48016 Mdot
.08571 .3573 Mdot
.09048 .57213 Mdot
.09524 .4607 Mdot
.1 .26335 Mdot
.10476 .2745 Mdot
.10952 .56585 Mdot
.11429 .40736 Mdot
.11905 .439 Mdot
.12381 .23156 Mdot
.12857 .25961 Mdot
.13333 .35114 Mdot
.1381 .21023 Mdot
.14286 .39175 Mdot
.14762 .31095 Mdot
.15238 .17603 Mdot
.15714 .35345 Mdot
.1619 .35589 Mdot
.16667 .27881 Mdot
.17143 .31147 Mdot
.17619 .50035 Mdot
.18095 .32747 Mdot
.18571 .53254 Mdot
.19048 .40657 Mdot
.19524 .37974 Mdot
.2 .27446 Mdot
.20476 .26367 Mdot
.20952 .419 Mdot
.21429 .32956 Mdot
.21905 .34805 Mdot
.22381 .41548 Mdot
.22857 .36077 Mdot
.23333 .37894 Mdot
.2381 .46832 Mdot
.24286 .29915 Mdot
.24762 .20467 Mdot
.25238 .14177 Mdot
.25714 .47755 Mdot
.2619 .29609 Mdot
.26667 .24357 Mdot
.27143 .57353 Mdot
.27619 .16814 Mdot
.28095 .40169 Mdot
.28571 .37691 Mdot
.29048 .36664 Mdot
.29524 .27892 Mdot
.3 .39971 Mdot
.30476 .30115 Mdot
.30952 .34448 Mdot
.31429 .18192 Mdot
.31905 .22155 Mdot
.32381 .29482 Mdot
.32857 .3763 Mdot
.33333 .3213 Mdot
.3381 .42152 Mdot
.34286 .2251 Mdot
.34762 .18834 Mdot
.35238 .31387 Mdot
.35714 .34882 Mdot
.3619 .41419 Mdot
.36667 .41358 Mdot
.37143 .3646 Mdot
.37619 .22358 Mdot
.38095 .53532 Mdot
.38571 .44208 Mdot
.39048 .40437 Mdot
.39524 .33402 Mdot
.4 .26427 Mdot
.40476 .20481 Mdot
.40952 .25698 Mdot
.41429 .27608 Mdot
.41905 .49728 Mdot
.42381 .13307 Mdot
.42857 .31719 Mdot
.43333 .39968 Mdot
.4381 .39393 Mdot
.44286 .4401 Mdot
.44762 .18314 Mdot
.45238 .25064 Mdot
.45714 .21213 Mdot
.4619 .3134 Mdot
.46667 .38883 Mdot
.47143 .16286 Mdot
.47619 .3131 Mdot
.48095 .29474 Mdot
.48571 .45155 Mdot
.49048 .43739 Mdot
.49524 .42469 Mdot
.5 .356 Mdot
.50476 .4747 Mdot
.50952 .40945 Mdot
.51429 .4144 Mdot
.51905 .30239 Mdot
.52381 .35591 Mdot
.52857 .47803 Mdot
.53333 .37685 Mdot
.5381 .33207 Mdot
.54286 .49369 Mdot
.54762 .30849 Mdot
.55238 .24643 Mdot
.55714 .42714 Mdot
.5619 .35174 Mdot
.56667 .37137 Mdot
.57143 .24769 Mdot
.57619 .26229 Mdot
.58095 .33496 Mdot
.58571 .25348 Mdot
.59048 .34221 Mdot
.59524 .40222 Mdot
.6 .2499 Mdot
.60476 .38963 Mdot
.60952 .27874 Mdot
.61429 .34224 Mdot
.61905 .20683 Mdot
.62381 .42788 Mdot
.62857 .35754 Mdot
.63333 .29888 Mdot
.6381 .30537 Mdot
.64286 .25848 Mdot
.64762 .05876 Mdot
.65238 .32022 Mdot
.65714 .26428 Mdot
.6619 .32132 Mdot
.66667 .38629 Mdot
.67143 .33836 Mdot
.67619 .40533 Mdot
.68095 .38643 Mdot
.68571 .36884 Mdot
.69048 .38993 Mdot
.69524 .39566 Mdot
.7 .40668 Mdot
.70476 .41075 Mdot
.70952 .40457 Mdot
.71429 .26423 Mdot
.71905 .38117 Mdot
.72381 .15987 Mdot
.72857 .28415 Mdot
.73333 .42089 Mdot
.7381 .37819 Mdot
.74286 .33271 Mdot
.74762 .5136 Mdot
.75238 .3282 Mdot
.75714 .16424 Mdot
.7619 .43389 Mdot
.76667 .48961 Mdot
.77143 .26809 Mdot
.77619 .23297 Mdot
.78095 .34508 Mdot
.78571 .42246 Mdot
.79048 .17603 Mdot
.79524 .39684 Mdot
.8 .48105 Mdot
.80476 .3696 Mdot
.80952 .42334 Mdot
.81429 .29213 Mdot
.81905 .24184 Mdot
.82381 .49936 Mdot
.82857 .34458 Mdot
.83333 .26169 Mdot
.8381 .24576 Mdot
.84286 .30249 Mdot
.84762 .43106 Mdot
.85238 .58608 Mdot
.8619 .45568 Mdot
.86667 .17064 Mdot
.87143 .34489 Mdot
.87619 .46521 Mdot
.88095 .4122 Mdot
.88571 .5729 Mdot
.89048 .32573 Mdot
.89524 .37046 Mdot
.9 .41476 Mdot
.90476 .45778 Mdot
.90952 .40089 Mdot
.91429 .35573 Mdot
.91905 .32551 Mdot
.92381 .33845 Mdot
.92857 .30124 Mdot
.93333 .33347 Mdot
.9381 .21787 Mdot
.94286 .41645 Mdot
.94762 .19849 Mdot
.95238 .51509 Mdot
.95714 .38658 Mdot
.9619 .3004 Mdot
.96667 .50915 Mdot
.97143 .37779 Mdot
.97619 .2907 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .26689 Mdot
.03333 .36557 Mdot
.0381 .29029 Mdot
.04286 .30327 Mdot
.04762 .37323 Mdot
.05238 .1435 Mdot
.05714 .33177 Mdot
.0619 .35229 Mdot
.06667 .23862 Mdot
.07143 .31887 Mdot
.07619 .36697 Mdot
.08095 .39453 Mdot
.08571 .31319 Mdot
.09048 .57252 Mdot
.09524 .4667 Mdot
.1 .27184 Mdot
.10476 .27868 Mdot
.10952 .60583 Mdot
.11429 .44802 Mdot
.11905 .47379 Mdot
.12381 .19164 Mdot
.12857 .28278 Mdot
.13333 .34781 Mdot
.1381 .16447 Mdot
.14286 .34244 Mdot
.14762 .22417 Mdot
.15238 .15031 Mdot
.15714 .3359 Mdot
.1619 .31136 Mdot
.16667 .21403 Mdot
.17143 .29666 Mdot
.17619 .40794 Mdot
.18095 .30342 Mdot
.18571 .53445 Mdot
.19048 .4687 Mdot
.19524 .36413 Mdot
.2 .30768 Mdot
.20476 .25726 Mdot
.20952 .42601 Mdot
.21429 .32307 Mdot
.21905 .29529 Mdot
.22381 .48339 Mdot
.22857 .36024 Mdot
.23333 .40367 Mdot
.2381 .49431 Mdot
.24286 .27652 Mdot
.24762 .14389 Mdot
.25238 .15 Mdot
.25714 .42078 Mdot
.2619 .24479 Mdot
.26667 .14633 Mdot
.27143 .56781 Mdot
.27619 .18118 Mdot
.28095 .45606 Mdot
.28571 .43058 Mdot
.29048 .39961 Mdot
.29524 .29145 Mdot
.3 .41882 Mdot
.30476 .2832 Mdot
.30952 .31105 Mdot
.31429 .16008 Mdot
.31905 .22777 Mdot
.32381 .34999 Mdot
.32857 .34947 Mdot
.33333 .34438 Mdot
.3381 .35497 Mdot
.34286 .15627 Mdot
.34762 .14357 Mdot
.35238 .41243 Mdot
.35714 .30525 Mdot
.3619 .3764 Mdot
.36667 .34359 Mdot
.37143 .31486 Mdot
.37619 .20819 Mdot
.38095 .53586 Mdot
.38571 .44423 Mdot
.39048 .38503 Mdot
.39524 .26084 Mdot
.4 .22699 Mdot
.40476 .19381 Mdot
.40952 .2139 Mdot
.41429 .26655 Mdot
.41905 .40055 Mdot
.42381 .09722 Mdot
.42857 .27801 Mdot
.43333 .34835 Mdot
.4381 .38199 Mdot
.44286 .46099 Mdot
.44762 .20938 Mdot
.45238 .26028 Mdot
.45714 .24883 Mdot
.4619 .32042 Mdot
.46667 .37792 Mdot
.47143 .17519 Mdot
.47619 .26662 Mdot
.48095 .33946 Mdot
.48571 .44269 Mdot
.49048 .43342 Mdot
.49524 .50147 Mdot
.5 .26905 Mdot
.50476 .51718 Mdot
.50952 .43684 Mdot
.51429 .34014 Mdot
.51905 .26686 Mdot
.52381 .32656 Mdot
.52857 .46516 Mdot
.53333 .41763 Mdot
.5381 .34576 Mdot
.54286 .51376 Mdot
.54762 .25762 Mdot
.55238 .1568 Mdot
.55714 .40099 Mdot
.5619 .33458 Mdot
.56667 .31745 Mdot
.57143 .1917 Mdot
.57619 .24467 Mdot
.58095 .2526 Mdot
.58571 .25235 Mdot
.59048 .38052 Mdot
.59524 .42866 Mdot
.6 .29529 Mdot
.60476 .40032 Mdot
.60952 .34763 Mdot
.61429 .31272 Mdot
.61905 .2601 Mdot
.62381 .33881 Mdot
.62857 .29842 Mdot
.63333 .30753 Mdot
.6381 .22509 Mdot
.64286 .30094 Mdot
.64762 .09689 Mdot
.65238 .28258 Mdot
.65714 .20195 Mdot
.6619 .3361 Mdot
.66667 .33502 Mdot
.67143 .30355 Mdot
.67619 .40546 Mdot
.68095 .46631 Mdot
.68571 .44497 Mdot
.69048 .44365 Mdot
.69524 .47485 Mdot
.7 .38447 Mdot
.70476 .40468 Mdot
.70952 .36569 Mdot
.71429 .20643 Mdot
.71905 .41976 Mdot
.72381 .076 Mdot
.72857 .21392 Mdot
.73333 .37515 Mdot
.7381 .36494 Mdot
.74286 .34085 Mdot
.74762 .45581 Mdot
.75238 .31766 Mdot
.75714 .1915 Mdot
.7619 .38458 Mdot
.76667 .51821 Mdot
.77143 .34114 Mdot
.77619 .23497 Mdot
.78095 .28933 Mdot
.78571 .33739 Mdot
.79048 .18134 Mdot
.79524 .31206 Mdot
.8 .51472 Mdot
.80476 .37559 Mdot
.80952 .43275 Mdot
.81429 .28486 Mdot
.81905 .21533 Mdot
.82381 .5809 Mdot
.82857 .334 Mdot
.83333 .27488 Mdot
.8381 .21133 Mdot
.84286 .30297 Mdot
.84762 .51239 Mdot
.85238 .54954 Mdot
.8619 .36564 Mdot
.86667 .18938 Mdot
.87143 .38438 Mdot
.87619 .48903 Mdot
.88095 .42735 Mdot
.88571 .54506 Mdot
.89048 .35753 Mdot
.89524 .31254 Mdot
.9 .39058 Mdot
.90476 .50096 Mdot
.90952 .36363 Mdot
.91429 .34044 Mdot
.91905 .33157 Mdot
.92381 .36264 Mdot
.92857 .32022 Mdot
.93333 .3238 Mdot
.9381 .19037 Mdot
.94286 .32198 Mdot
.94762 .21691 Mdot
.95238 .51212 Mdot
.95714 .45105 Mdot
.9619 .29989 Mdot
.96667 .57898 Mdot
.97143 .31953 Mdot
.97619 .2861 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .28235 Mdot
.03333 .36829 Mdot
.0381 .27122 Mdot
.04286 .25164 Mdot
.04762 .34262 Mdot
.05238 .09756 Mdot
.05714 .34343 Mdot
.0619 .33745 Mdot
.06667 .21851 Mdot
.07143 .31918 Mdot
.07619 .42743 Mdot
.08095 .43837 Mdot
.08571 .35854 Mdot
.09048 .48605 Mdot
.09524 .41219 Mdot
.1 .24275 Mdot
.10476 .2647 Mdot
.10952 .59058 Mdot
.11429 .46488 Mdot
.11905 .42277 Mdot
.12381 .11066 Mdot
.12857 .36149 Mdot
.13333 .30672 Mdot
.1381 .1975 Mdot
.14286 .36663 Mdot
.14762 .24172 Mdot
.15238 .16194 Mdot
.15714 .24167 Mdot
.1619 .24017 Mdot
.16667 .20802 Mdot
.17143 .24854 Mdot
.17619 .38189 Mdot
.18095 .24776 Mdot
.18571 .4629 Mdot
.19048 .52954 Mdot
.19524 .34717 Mdot
.2 .22418 Mdot
.20476 .18957 Mdot
.20952 .36188 Mdot
.21429 .37486 Mdot
.21905 .25363 Mdot
.22381 .42064 Mdot
.22857 .31977 Mdot
.23333 .36583 Mdot
.2381 .43975 Mdot
.24286 .23473 Mdot
.24762 .18649 Mdot
.25238 .12299 Mdot
.25714 .38202 Mdot
.2619 .25456 Mdot
.26667 .13449 Mdot
.27143 .58514 Mdot
.27619 .16087 Mdot
.28095 .53568 Mdot
.28571 .37307 Mdot
.29048 .39638 Mdot
.29524 .29063 Mdot
.3 .38576 Mdot
.30476 .3215 Mdot
.30952 .30329 Mdot
.31429 .07737 Mdot
.31905 .23 Mdot
.32381 .40109 Mdot
.32857 .27846 Mdot
.33333 .38106 Mdot
.3381 .28989 Mdot
.34286 .08955 Mdot
.34762 .13118 Mdot
.35238 .42656 Mdot
.35714 .30003 Mdot
.3619 .33021 Mdot
.36667 .30702 Mdot
.37143 .25272 Mdot
.37619 .21325 Mdot
.38095 .52956 Mdot
.38571 .37589 Mdot
.39048 .32814 Mdot
.39524 .30881 Mdot
.4 .18853 Mdot
.40476 .13005 Mdot
.40952 .20598 Mdot
.41429 .23905 Mdot
.41905 .41263 Mdot
.42381 .12155 Mdot
.42857 .30507 Mdot
.43333 .33547 Mdot
.4381 .38961 Mdot
.44286 .47235 Mdot
.44762 .21104 Mdot
.45238 .25723 Mdot
.45714 .22034 Mdot
.4619 .3684 Mdot
.46667 .38634 Mdot
.47143 .16712 Mdot
.47619 .33902 Mdot
.48095 .30704 Mdot
.48571 .37739 Mdot
.49048 .35139 Mdot
.49524 .41867 Mdot
.5 .17502 Mdot
.50476 .51771 Mdot
.50952 .40021 Mdot
.51429 .34828 Mdot
.51905 .26279 Mdot
.52381 .29473 Mdot
.52857 .46627 Mdot
.53333 .47805 Mdot
.5381 .36759 Mdot
.54286 .50766 Mdot
.54762 .27117 Mdot
.55238 .07945 Mdot
.55714 .38556 Mdot
.5619 .30693 Mdot
.56667 .264 Mdot
.57143 .25537 Mdot
.57619 .21486 Mdot
.58095 .18294 Mdot
.58571 .27884 Mdot
.59048 .33414 Mdot
.59524 .38616 Mdot
.6 .22257 Mdot
.60476 .41352 Mdot
.60952 .26972 Mdot
.61429 .30851 Mdot
.61905 .21297 Mdot
.62381 .28471 Mdot
.62857 .30089 Mdot
.63333 .26014 Mdot
.6381 .22268 Mdot
.64286 .28892 Mdot
.64762 .02027 Mdot
.65238 .27447 Mdot
.65714 .17166 Mdot
.6619 .35934 Mdot
.66667 .36716 Mdot
.67143 .28717 Mdot
.67619 .31937 Mdot
.68095 .48165 Mdot
.68571 .38032 Mdot
.69048 .4272 Mdot
.69524 .40468 Mdot
.7 .36438 Mdot
.70476 .44365 Mdot
.70952 .39578 Mdot
.71429 .18206 Mdot
.71905 .41613 Mdot
.72381 .07812 Mdot
.72857 .19573 Mdot
.73333 .43876 Mdot
.7381 .36683 Mdot
.74286 .35222 Mdot
.74762 .46378 Mdot
.75238 .31673 Mdot
.75714 .20393 Mdot
.7619 .36795 Mdot
.76667 .47137 Mdot
.77143 .32207 Mdot
.77619 .23915 Mdot
.78095 .24488 Mdot
.78571 .361 Mdot
.79048 .1632 Mdot
.79524 .30456 Mdot
.8 .59649 Mdot
.80476 .29393 Mdot
.80952 .43429 Mdot
.81429 .25254 Mdot
.81905 .24888 Mdot
.82381 .52414 Mdot
.82857 .2479 Mdot
.83333 .21682 Mdot
.8381 .13339 Mdot
.84286 .26736 Mdot
.84762 .52318 Mdot
.85238 .56921 Mdot
.8619 .37144 Mdot
.86667 .13588 Mdot
.87143 .36253 Mdot
.87619 .54274 Mdot
.88095 .38231 Mdot
.88571 .49992 Mdot
.89048 .40744 Mdot
.89524 .27497 Mdot
.9 .29368 Mdot
.90476 .48597 Mdot
.90952 .33918 Mdot
.91429 .28984 Mdot
.91905 .42869 Mdot
.92381 .36915 Mdot
.92857 .31236 Mdot
.93333 .2994 Mdot
.9381 .18853 Mdot
.94286 .37191 Mdot
.94762 .15114 Mdot
.95238 .47899 Mdot
.95714 .4299 Mdot
.9619 .29571 Mdot
.97143 .32947 Mdot
.97619 .2536 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32871 Mdot
.03333 .34556 Mdot
.0381 .24872 Mdot
.04286 .208 Mdot
.04762 .25427 Mdot
.05238 .046 Mdot
.05714 .35095 Mdot
.0619 .40837 Mdot
.06667 .16465 Mdot
.07143 .3717 Mdot
.07619 .44806 Mdot
.08095 .48878 Mdot
.08571 .40926 Mdot
.09048 .45356 Mdot
.09524 .36919 Mdot
.1 .2617 Mdot
.10476 .19887 Mdot
.10952 .51372 Mdot
.11429 .39512 Mdot
.11905 .48324 Mdot
.12381 .09657 Mdot
.12857 .37413 Mdot
.13333 .28912 Mdot
.1381 .13311 Mdot
.14286 .3928 Mdot
.14762 .23689 Mdot
.15238 .13155 Mdot
.15714 .23376 Mdot
.1619 .27366 Mdot
.16667 .21319 Mdot
.17143 .17016 Mdot
.17619 .33815 Mdot
.18095 .25561 Mdot
.18571 .53438 Mdot
.19048 .55983 Mdot
.19524 .27589 Mdot
.2 .1566 Mdot
.20476 .21264 Mdot
.20952 .37241 Mdot
.21429 .36311 Mdot
.21905 .25098 Mdot
.22381 .36269 Mdot
.22857 .30035 Mdot
.23333 .32907 Mdot
.2381 .44687 Mdot
.24286 .1656 Mdot
.24762 .14656 Mdot
.25238 .10906 Mdot
.25714 .36521 Mdot
.2619 .25234 Mdot
.26667 .16096 Mdot
.27143 .58124 Mdot
.27619 .2049 Mdot
.28095 .50888 Mdot
.28571 .30986 Mdot
.29048 .39389 Mdot
.29524 .2184 Mdot
.3 .43642 Mdot
.30476 .32596 Mdot
.30952 .25697 Mdot
.31429 .12421 Mdot
.31905 .13165 Mdot
.32381 .41435 Mdot
.32857 .28435 Mdot
.33333 .32851 Mdot
.3381 .23612 Mdot
.34286 .11534 Mdot
.34762 .15476 Mdot
.35238 .41889 Mdot
.35714 .29583 Mdot
.3619 .32834 Mdot
.36667 .31425 Mdot
.37143 .21521 Mdot
.37619 .22552 Mdot
.38095 .48178 Mdot
.38571 .37496 Mdot
.39048 .29086 Mdot
.39524 .30138 Mdot
.4 .24268 Mdot
.40476 .11694 Mdot
.40952 .20587 Mdot
.41429 .23578 Mdot
.41905 .37457 Mdot
.42381 .09537 Mdot
.42857 .2651 Mdot
.43333 .28728 Mdot
.4381 .34863 Mdot
.44286 .47017 Mdot
.44762 .14815 Mdot
.45238 .22854 Mdot
.45714 .19244 Mdot
.4619 .29331 Mdot
.46667 .33308 Mdot
.47143 .17443 Mdot
.47619 .37506 Mdot
.48095 .31275 Mdot
.48571 .33635 Mdot
.49048 .35568 Mdot
.49524 .41096 Mdot
.5 .15281 Mdot
.50476 .53777 Mdot
.50952 .44842 Mdot
.51429 .28656 Mdot
.51905 .29509 Mdot
.52381 .26242 Mdot
.52857 .50982 Mdot
.53333 .42259 Mdot
.5381 .32057 Mdot
.54286 .49247 Mdot
.54762 .31863 Mdot
.55238 .09417 Mdot
.55714 .38248 Mdot
.5619 .31282 Mdot
.56667 .28255 Mdot
.57143 .22656 Mdot
.57619 .19791 Mdot
.58095 .18072 Mdot
.58571 .23567 Mdot
.59048 .39546 Mdot
.59524 .39235 Mdot
.6 .16101 Mdot
.60476 .38504 Mdot
.60952 .24003 Mdot
.61429 .32158 Mdot
.61905 .1437 Mdot
.62381 .29926 Mdot
.62857 .32463 Mdot
.63333 .27851 Mdot
.6381 .1583 Mdot
.64286 .32844 Mdot
.64762 .01287 Mdot
.65238 .28642 Mdot
.65714 .15696 Mdot
.6619 .31334 Mdot
.66667 .29317 Mdot
.67143 .3654 Mdot
.67619 .30741 Mdot
.68095 .44327 Mdot
.68571 .37059 Mdot
.69048 .42196 Mdot
.69524 .45152 Mdot
.7 .34413 Mdot
.70476 .39358 Mdot
.70952 .4114 Mdot
.71429 .25502 Mdot
.71905 .36254 Mdot
.72381 .08849 Mdot
.72857 .10974 Mdot
.73333 .41999 Mdot
.7381 .3477 Mdot
.74286 .35636 Mdot
.74762 .43211 Mdot
.75238 .35152 Mdot
.75714 .23096 Mdot
.7619 .43157 Mdot
.76667 .4516 Mdot
.77143 .34515 Mdot
.77619 .28163 Mdot
.78095 .30056 Mdot
.78571 .37438 Mdot
.79048 .14062 Mdot
.79524 .25533 Mdot
.8 .59046 Mdot
.80476 .25923 Mdot
.80952 .43199 Mdot
.81429 .20899 Mdot
.81905 .23005 Mdot
.82381 .56052 Mdot
.82857 .19248 Mdot
.83333 .26627 Mdot
.8381 .16567 Mdot
.84286 .26392 Mdot
.84762 .44354 Mdot
.85238 .51095 Mdot
.8619 .35579 Mdot
.86667 .13259 Mdot
.87143 .30327 Mdot
.87619 .4926 Mdot
.88095 .33956 Mdot
.88571 .49478 Mdot
.89048 .41906 Mdot
.89524 .26329 Mdot
.9 .34437 Mdot
.90476 .48959 Mdot
.90952 .38107 Mdot
.91429 .31607 Mdot
.91905 .39141 Mdot
.92381 .44021 Mdot
.92857 .31249 Mdot
.93333 .3091 Mdot
.9381 .1324 Mdot
.94286 .32304 Mdot
.94762 .11743 Mdot
.95238 .52131 Mdot
.95714 .3868 Mdot
.9619 .25045 Mdot
.96667 .58664 Mdot
.97143 .26791 Mdot
.97619 .16744 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39098 Mdot
.03333 .26877 Mdot
.0381 .30887 Mdot
.04286 .19437 Mdot
.04762 .18843 Mdot
.05238 .11997 Mdot
.05714 .27104 Mdot
.0619 .40015 Mdot
.06667 .11789 Mdot
.07143 .36707 Mdot
.07619 .35216 Mdot
.08095 .49269 Mdot
.08571 .39646 Mdot
.09048 .48365 Mdot
.09524 .39735 Mdot
.1 .26927 Mdot
.10476 .12918 Mdot
.10952 .50294 Mdot
.11429 .36183 Mdot
.11905 .54314 Mdot
.12381 .10221 Mdot
.12857 .34093 Mdot
.13333 .22124 Mdot
.1381 .18732 Mdot
.14286 .36286 Mdot
.14762 .2467 Mdot
.15238 .08994 Mdot
.15714 .26954 Mdot
.1619 .32339 Mdot
.16667 .17071 Mdot
.17143 .21289 Mdot
.17619 .38278 Mdot
.18095 .24161 Mdot
.18571 .50893 Mdot
.19048 .61225 Mdot
.19524 .19213 Mdot
.2 .1741 Mdot
.20476 .17219 Mdot
.20952 .3214 Mdot
.21429 .32356 Mdot
.21905 .21791 Mdot
.22381 .28367 Mdot
.22857 .34695 Mdot
.23333 .32771 Mdot
.2381 .40155 Mdot
.24286 .20617 Mdot
.24762 .06142 Mdot
.25238 .15178 Mdot
.25714 .34447 Mdot
.2619 .26222 Mdot
.26667 .11114 Mdot
.27143 .52888 Mdot
.27619 .3049 Mdot
.28095 .48186 Mdot
.28571 .32726 Mdot
.29048 .40374 Mdot
.29524 .17122 Mdot
.3 .51369 Mdot
.30476 .27913 Mdot
.30952 .24641 Mdot
.31429 .05748 Mdot
.31905 .08187 Mdot
.32381 .47487 Mdot
.32857 .26707 Mdot
.33333 .2416 Mdot
.3381 .27674 Mdot
.34286 .08349 Mdot
.34762 .14819 Mdot
.35238 .37385 Mdot
.35714 .24318 Mdot
.3619 .30017 Mdot
.36667 .29086 Mdot
.37143 .17157 Mdot
.37619 .22539 Mdot
.38095 .50582 Mdot
.38571 .34458 Mdot
.39048 .25742 Mdot
.39524 .36907 Mdot
.4 .23298 Mdot
.40476 .10281 Mdot
.40952 .23593 Mdot
.41429 .19246 Mdot
.41905 .31358 Mdot
.42381 .08232 Mdot
.42857 .27291 Mdot
.43333 .29277 Mdot
.4381 .38846 Mdot
.44286 .46838 Mdot
.44762 .10107 Mdot
.45238 .1931 Mdot
.45714 .18602 Mdot
.4619 .29813 Mdot
.46667 .33963 Mdot
.47143 .16253 Mdot
.47619 .36183 Mdot
.48095 .33659 Mdot
.48571 .27577 Mdot
.49048 .37159 Mdot
.49524 .33341 Mdot
.5 .18831 Mdot
.50476 .4892 Mdot
.50952 .37343 Mdot
.51429 .24508 Mdot
.51905 .31027 Mdot
.52381 .23325 Mdot
.52857 .49597 Mdot
.53333 .37553 Mdot
.5381 .27384 Mdot
.54286 .43911 Mdot
.54762 .37932 Mdot
.55238 .08145 Mdot
.55714 .29193 Mdot
.5619 .2392 Mdot
.56667 .30077 Mdot
.57143 .22355 Mdot
.57619 .18493 Mdot
.58095 .13076 Mdot
.58571 .30448 Mdot
.59048 .35658 Mdot
.59524 .33186 Mdot
.6 .1774 Mdot
.60476 .41114 Mdot
.60952 .22603 Mdot
.61429 .31672 Mdot
.61905 .11196 Mdot
.62381 .32533 Mdot
.62857 .37995 Mdot
.63333 .26412 Mdot
.6381 .19711 Mdot
.64286 .308 Mdot
.64762 .12382 Mdot
.65238 .24863 Mdot
.65714 .08946 Mdot
.6619 .32986 Mdot
.66667 .36399 Mdot
.67143 .31056 Mdot
.67619 .31306 Mdot
.68095 .47144 Mdot
.68571 .32948 Mdot
.69048 .42183 Mdot
.69524 .43376 Mdot
.7 .32619 Mdot
.70476 .34716 Mdot
.70952 .4513 Mdot
.71429 .26713 Mdot
.71905 .38067 Mdot
.72381 .15046 Mdot
.72857 .11678 Mdot
.73333 .42731 Mdot
.7381 .38289 Mdot
.74286 .33874 Mdot
.74762 .41073 Mdot
.75238 .33176 Mdot
.75714 .20463 Mdot
.7619 .37257 Mdot
.76667 .45606 Mdot
.77143 .35449 Mdot
.77619 .26563 Mdot
.78095 .35792 Mdot
.78571 .32209 Mdot
.79048 .20627 Mdot
.79524 .30822 Mdot
.8 .53333 Mdot
.80476 .25086 Mdot
.80952 .4508 Mdot
.81429 .22173 Mdot
.81905 .1927 Mdot
.82381 .5622 Mdot
.82857 .20106 Mdot
.83333 .18938 Mdot
.8381 .1083 Mdot
.84286 .19861 Mdot
.84762 .37553 Mdot
.85238 .45473 Mdot
.8619 .35065 Mdot
.86667 .07557 Mdot
.87143 .32194 Mdot
.87619 .4765 Mdot
.88095 .31912 Mdot
.88571 .50186 Mdot
.89048 .3638 Mdot
.89524 .25036 Mdot
.9 .3322 Mdot
.90476 .45292 Mdot
.90952 .36416 Mdot
.91429 .24428 Mdot
.91905 .32816 Mdot
.92381 .38306 Mdot
.92857 .3149 Mdot
.93333 .30677 Mdot
.9381 .09589 Mdot
.94286 .33922 Mdot
.94762 .06521 Mdot
.95238 .5298 Mdot
.95714 .35013 Mdot
.9619 .20572 Mdot
.96667 .57996 Mdot
.97143 .29193 Mdot
.97619 .08998 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .35053 Mdot
.03333 .23639 Mdot
.0381 .29201 Mdot
.04286 .20125 Mdot
.04762 .14966 Mdot
.05238 .19449 Mdot
.05714 .34055 Mdot
.0619 .31534 Mdot
.06667 .04451 Mdot
.07143 .33226 Mdot
.07619 .33215 Mdot
.08095 .45395 Mdot
.08571 .39745 Mdot
.09048 .4854 Mdot
.09524 .40449 Mdot
.1 .28218 Mdot
.10476 .04805 Mdot
.10952 .51436 Mdot
.11429 .34101 Mdot
.11905 .49901 Mdot
.12381 .1452 Mdot
.12857 .40453 Mdot
.13333 .22187 Mdot
.1381 .11116 Mdot
.14286 .28621 Mdot
.14762 .25784 Mdot
.15238 .0978 Mdot
.15714 .2924 Mdot
.1619 .25061 Mdot
.16667 .13686 Mdot
.17143 .22535 Mdot
.17619 .33538 Mdot
.18095 .24833 Mdot
.18571 .50909 Mdot
.19524 .14501 Mdot
.2 .11227 Mdot
.20476 .10334 Mdot
.20952 .32926 Mdot
.21429 .34278 Mdot
.21905 .26171 Mdot
.22381 .32582 Mdot
.22857 .34873 Mdot
.23333 .24164 Mdot
.2381 .34602 Mdot
.24286 .15758 Mdot
.24762 .06261 Mdot
.25238 .13025 Mdot
.25714 .30658 Mdot
.2619 .21824 Mdot
.26667 .09461 Mdot
.27143 .47503 Mdot
.27619 .34297 Mdot
.28095 .40462 Mdot
.28571 .33065 Mdot
.29048 .31704 Mdot
.29524 .18832 Mdot
.3 .45663 Mdot
.30476 .25072 Mdot
.30952 .20063 Mdot
.31429 .08016 Mdot
.31905 .02803 Mdot
.32381 .42505 Mdot
.32857 .2119 Mdot
.33333 .23461 Mdot
.3381 .27468 Mdot
.34286 .16398 Mdot
.34762 .11686 Mdot
.35238 .32861 Mdot
.35714 .19514 Mdot
.3619 .34626 Mdot
.36667 .20389 Mdot
.37143 .16948 Mdot
.37619 .25938 Mdot
.38095 .5415 Mdot
.38571 .34144 Mdot
.39048 .24332 Mdot
.39524 .3798 Mdot
.4 .25227 Mdot
.40476 .07695 Mdot
.40952 .19189 Mdot
.41429 .18565 Mdot
.41905 .30235 Mdot
.42381 .07453 Mdot
.42857 .21242 Mdot
.43333 .37935 Mdot
.4381 .39335 Mdot
.44286 .42028 Mdot
.44762 .10389 Mdot
.45238 .19657 Mdot
.45714 .17973 Mdot
.4619 .35443 Mdot
.46667 .30415 Mdot
.47143 .21227 Mdot
.47619 .44308 Mdot
.48095 .35256 Mdot
.48571 .23568 Mdot
.49048 .43304 Mdot
.49524 .34483 Mdot
.5 .25532 Mdot
.50476 .47323 Mdot
.50952 .37453 Mdot
.51429 .26836 Mdot
.51905 .2879 Mdot
.52381 .27851 Mdot
.52857 .46154 Mdot
.53333 .33295 Mdot
.5381 .18422 Mdot
.54286 .38164 Mdot
.54762 .35117 Mdot
.55238 .07254 Mdot
.55714 .35568 Mdot
.5619 .23885 Mdot
.56667 .21281 Mdot
.57143 .17578 Mdot
.57619 .18958 Mdot
.58095 .05631 Mdot
.58571 .25919 Mdot
.59048 .35943 Mdot
.59524 .33227 Mdot
.6 .14004 Mdot
.60476 .39321 Mdot
.60952 .15442 Mdot
.61429 .31172 Mdot
.61905 .1184 Mdot
.62381 .29586 Mdot
.62857 .41736 Mdot
.63333 .21004 Mdot
.6381 .13506 Mdot
.64286 .29366 Mdot
.64762 .12587 Mdot
.65238 .27807 Mdot
.65714 .06589 Mdot
.6619 .3094 Mdot
.66667 .34807 Mdot
.67143 .26155 Mdot
.67619 .33195 Mdot
.68095 .50872 Mdot
.68571 .33987 Mdot
.69048 .37307 Mdot
.69524 .39612 Mdot
.7 .35494 Mdot
.70476 .34965 Mdot
.70952 .44271 Mdot
.71429 .22127 Mdot
.71905 .30186 Mdot
.72381 .1515 Mdot
.72857 .03141 Mdot
.73333 .38743 Mdot
.7381 .38572 Mdot
.74286 .31474 Mdot
.74762 .43026 Mdot
.75238 .28308 Mdot
.75714 .18658 Mdot
.7619 .36288 Mdot
.76667 .47785 Mdot
.77143 .30614 Mdot
.77619 .26082 Mdot
.78095 .36642 Mdot
.78571 .2963 Mdot
.79048 .23056 Mdot
.79524 .32524 Mdot
.8 .46484 Mdot
.80476 .24893 Mdot
.80952 .41203 Mdot
.81429 .20054 Mdot
.81905 .26717 Mdot
.82381 .57176 Mdot
.82857 .28648 Mdot
.83333 .14529 Mdot
.8381 .12972 Mdot
.84286 .21505 Mdot
.84762 .36036 Mdot
.85238 .41955 Mdot
.8619 .33692 Mdot
.86667 .10645 Mdot
.87143 .2786 Mdot
.87619 .49676 Mdot
.88095 .34845 Mdot
.88571 .46696 Mdot
.89048 .32739 Mdot
.89524 .33359 Mdot
.9 .40159 Mdot
.90476 .48726 Mdot
.90952 .34754 Mdot
.91429 .29879 Mdot
.91905 .34001 Mdot
.92381 .38624 Mdot
.92857 .27807 Mdot
.93333 .35079 Mdot
.9381 .03302 Mdot
.94286 .41871 Mdot
.94762 .04098 Mdot
.95238 .51803 Mdot
.95714 .34162 Mdot
.9619 .16537 Mdot
.96667 .61505 Mdot
.97143 .22847 Mdot
.97619 .08888 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32849 Mdot
.03333 .26142 Mdot
.0381 .30131 Mdot
.04286 .19223 Mdot
.04762 .17236 Mdot
.05238 .23675 Mdot
.05714 .34465 Mdot
.0619 .28088 Mdot
.06667 .09816 Mdot
.07143 .36216 Mdot
.07619 .25955 Mdot
.08095 .43257 Mdot
.08571 .34953 Mdot
.09048 .48675 Mdot
.09524 .38206 Mdot
.1 .28291 Mdot
.10476 .04229 Mdot
.10952 .54102 Mdot
.11429 .37607 Mdot
.11905 .46827 Mdot
.12381 .1251 Mdot
.12857 .39427 Mdot
.13333 .25025 Mdot
.1381 .02624 Mdot
.14286 .33225 Mdot
.14762 .26074 Mdot
.15238 .10711 Mdot
.15714 .30649 Mdot
.1619 .28226 Mdot
.16667 .12466 Mdot
.17143 .19195 Mdot
.17619 .32253 Mdot
.18095 .19189 Mdot
.18571 .48141 Mdot
.19524 .1605 Mdot
.2 .12826 Mdot
.20476 .03801 Mdot
.20952 .24253 Mdot
.21429 .33009 Mdot
.21905 .27697 Mdot
.22381 .35707 Mdot
.22857 .37102 Mdot
.23333 .22182 Mdot
.2381 .27708 Mdot
.24286 .16336 Mdot
.24762 .00309 Mdot
.25238 .1005 Mdot
.25714 .26121 Mdot
.2619 .20299 Mdot
.26667 .09465 Mdot
.27143 .44006 Mdot
.27619 .33327 Mdot
.28095 .35288 Mdot
.28571 .30113 Mdot
.29048 .26263 Mdot
.29524 .14924 Mdot
.3 .38845 Mdot
.30476 .27718 Mdot
.30952 .28303 Mdot
.31429 .0733 Mdot
.31905 .01905 Mdot
.32381 .37385 Mdot
.32857 .26321 Mdot
.33333 .17277 Mdot
.3381 .20582 Mdot
.34286 .12122 Mdot
.34762 .13349 Mdot
.35238 .26217 Mdot
.35714 .21063 Mdot
.3619 .27032 Mdot
.36667 .20054 Mdot
.37143 .15338 Mdot
.37619 .19835 Mdot
.38095 .58532 Mdot
.38571 .30894 Mdot
.39048 .21864 Mdot
.39524 .3715 Mdot
.4 .28079 Mdot
.40476 .04855 Mdot
.40952 .19232 Mdot
.41429 .15948 Mdot
.41905 .20451 Mdot
.42381 .02039 Mdot
.42857 .17758 Mdot
.43333 .42712 Mdot
.4381 .29827 Mdot
.44286 .3509 Mdot
.44762 .09534 Mdot
.45238 .1622 Mdot
.45714 .12333 Mdot
.4619 .32031 Mdot
.46667 .35603 Mdot
.47143 .18708 Mdot
.47619 .50797 Mdot
.48095 .36897 Mdot
.48571 .2741 Mdot
.49048 .35365 Mdot
.49524 .34493 Mdot
.5 .28464 Mdot
.50476 .52241 Mdot
.50952 .32501 Mdot
.51429 .30223 Mdot
.51905 .286 Mdot
.52381 .32909 Mdot
.52857 .45828 Mdot
.53333 .36605 Mdot
.5381 .108 Mdot
.54286 .40427 Mdot
.54762 .3577 Mdot
.55238 .06488 Mdot
.55714 .29632 Mdot
.5619 .26021 Mdot
.56667 .15172 Mdot
.57143 .20083 Mdot
.57619 .22407 Mdot
.58095 .01062 Mdot
.58571 .24441 Mdot
.59048 .37834 Mdot
.59524 .3157 Mdot
.6 .10342 Mdot
.60476 .31873 Mdot
.60952 .09263 Mdot
.61429 .28661 Mdot
.61905 .07802 Mdot
.62381 .34081 Mdot
.62857 .36981 Mdot
.63333 .2284 Mdot
.6381 .13295 Mdot
.64286 .30559 Mdot
.64762 .06571 Mdot
.65238 .28151 Mdot
.65714 .02382 Mdot
.6619 .30815 Mdot
.66667 .33484 Mdot
.67143 .2126 Mdot
.67619 .26271 Mdot
.68095 .50814 Mdot
.68571 .33645 Mdot
.69048 .38777 Mdot
.69524 .34164 Mdot
.7 .37828 Mdot
.70476 .28069 Mdot
.70952 .45347 Mdot
.71429 .12238 Mdot
.71905 .31498 Mdot
.72381 .15468 Mdot
.72857 .03049 Mdot
.73333 .43244 Mdot
.7381 .44665 Mdot
.74286 .2826 Mdot
.74762 .38455 Mdot
.75238 .24493 Mdot
.75714 .08451 Mdot
.7619 .30293 Mdot
.76667 .44348 Mdot
.77143 .25918 Mdot
.77619 .25593 Mdot
.78095 .36942 Mdot
.78571 .25613 Mdot
.79048 .283 Mdot
.79524 .34105 Mdot
.8 .46804 Mdot
.80476 .26161 Mdot
.80952 .40781 Mdot
.81429 .17562 Mdot
.81905 .26383 Mdot
.82381 .57086 Mdot
.82857 .31767 Mdot
.83333 .05463 Mdot
.8381 .18556 Mdot
.84286 .13587 Mdot
.84762 .39894 Mdot
.85238 .37006 Mdot
.8619 .30267 Mdot
.86667 .0703 Mdot
.87143 .19083 Mdot
.87619 .42833 Mdot
.88095 .31977 Mdot
.88571 .43854 Mdot
.89048 .29435 Mdot
.89524 .35664 Mdot
.9 .41397 Mdot
.90476 .55707 Mdot
.90952 .32642 Mdot
.91429 .30382 Mdot
.91905 .37613 Mdot
.92381 .39064 Mdot
.92857 .22046 Mdot
.93333 .36071 Mdot
.9381 .06808 Mdot
.94286 .41404 Mdot
.94762 .07243 Mdot
.95238 .49795 Mdot
.95714 .31799 Mdot
.9619 .20451 Mdot
.97143 .23455 Mdot
.97619 .12028 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23512 Mdot
.03333 .25266 Mdot
.0381 .38167 Mdot
.04286 .26938 Mdot
.04762 .18989 Mdot
.05238 .20624 Mdot
.05714 .30212 Mdot
.0619 .2674 Mdot
.06667 .12378 Mdot
.07143 .35773 Mdot
.07619 .2902 Mdot
.08095 .40217 Mdot
.08571 .38772 Mdot
.09048 .47158 Mdot
.09524 .39363 Mdot
.1 .21907 Mdot
.10476 .04521 Mdot
.10952 .47155 Mdot
.11429 .36354 Mdot
.11905 .4532 Mdot
.12381 .13099 Mdot
.12857 .42226 Mdot
.13333 .25519 Mdot
.1381 .08725 Mdot
.14286 .35352 Mdot
.14762 .195 Mdot
.15238 .09437 Mdot
.15714 .32848 Mdot
.1619 .25176 Mdot
.16667 .18196 Mdot
.17143 .17126 Mdot
.17619 .34834 Mdot
.18095 .11907 Mdot
.18571 .49071 Mdot
.19524 .13597 Mdot
.2 .14741 Mdot
.20476 .0469 Mdot
.20952 .23477 Mdot
.21429 .34761 Mdot
.21905 .27727 Mdot
.22381 .28325 Mdot
.22857 .42101 Mdot
.23333 .2921 Mdot
.2381 .33683 Mdot
.24286 .21558 Mdot
.24762 .07334 Mdot
.25238 .11757 Mdot
.25714 .26192 Mdot
.2619 .15298 Mdot
.26667 .0664 Mdot
.27143 .40981 Mdot
.27619 .34387 Mdot
.28095 .36887 Mdot
.28571 .25187 Mdot
.29048 .26789 Mdot
.29524 .11563 Mdot
.3 .38442 Mdot
.30476 .28756 Mdot
.30952 .28007 Mdot
.31429 .04613 Mdot
.31905 .02491 Mdot
.32381 .31635 Mdot
.32857 .28279 Mdot
.33333 .16663 Mdot
.3381 .17156 Mdot
.34286 .14302 Mdot
.34762 .19173 Mdot
.35238 .28976 Mdot
.35714 .18387 Mdot
.3619 .24555 Mdot
.36667 .247 Mdot
.37143 .11933 Mdot
.37619 .25145 Mdot
.38095 .53753 Mdot
.38571 .24178 Mdot
.39048 .21297 Mdot
.39524 .38262 Mdot
.4 .361 Mdot
.40476 .06373 Mdot
.40952 .1477 Mdot
.41429 .20956 Mdot
.41905 .1571 Mdot
.42381 .03383 Mdot
.42857 .24162 Mdot
.43333 .4352 Mdot
.4381 .23497 Mdot
.44286 .31232 Mdot
.44762 .14044 Mdot
.45238 .0698 Mdot
.45714 .10855 Mdot
.4619 .27506 Mdot
.46667 .30911 Mdot
.47143 .21105 Mdot
.47619 .47132 Mdot
.48095 .3148 Mdot
.48571 .30906 Mdot
.49048 .42096 Mdot
.49524 .38373 Mdot
.5 .19155 Mdot
.50476 .46608 Mdot
.50952 .29295 Mdot
.51429 .29138 Mdot
.51905 .34909 Mdot
.52381 .36674 Mdot
.52857 .4255 Mdot
.53333 .33412 Mdot
.5381 .02795 Mdot
.54286 .46749 Mdot
.54762 .37317 Mdot
.55238 .00206 Mdot
.55714 .27855 Mdot
.5619 .30608 Mdot
.56667 .10599 Mdot
.57143 .15816 Mdot
.57619 .22018 Mdot
.58095 .04508 Mdot
.58571 .21184 Mdot
.59048 .36724 Mdot
.59524 .29294 Mdot
.6 .10715 Mdot
.60476 .33297 Mdot
.60952 .05577 Mdot
.61429 .37616 Mdot
.61905 .0855 Mdot
.62381 .33585 Mdot
.62857 .4228 Mdot
.63333 .20012 Mdot
.6381 .16971 Mdot
.64286 .31062 Mdot
.64762 .02595 Mdot
.65238 .25455 Mdot
.65714 .05418 Mdot
.6619 .23899 Mdot
.66667 .35779 Mdot
.67143 .15314 Mdot
.67619 .23432 Mdot
.68095 .50433 Mdot
.68571 .29368 Mdot
.69048 .38779 Mdot
.69524 .29955 Mdot
.7 .34546 Mdot
.70476 .26314 Mdot
.70952 .39783 Mdot
.71429 .12987 Mdot
.71905 .35238 Mdot
.72381 .23177 Mdot
.72857 .03695 Mdot
.73333 .49056 Mdot
.7381 .37833 Mdot
.74286 .22719 Mdot
.74762 .38661 Mdot
.75238 .20771 Mdot
.75714 .06466 Mdot
.7619 .23418 Mdot
.76667 .40016 Mdot
.77143 .23908 Mdot
.77619 .29798 Mdot
.78095 .34668 Mdot
.78571 .21076 Mdot
.79048 .25057 Mdot
.79524 .26135 Mdot
.8 .51392 Mdot
.80476 .2314 Mdot
.80952 .38297 Mdot
.81429 .14317 Mdot
.81905 .217 Mdot
.82381 .5622 Mdot
.82857 .33081 Mdot
.83333 .05774 Mdot
.8381 .24712 Mdot
.84286 .1375 Mdot
.84762 .38153 Mdot
.85238 .36967 Mdot
.8619 .25101 Mdot
.86667 .02855 Mdot
.87143 .18994 Mdot
.87619 .34111 Mdot
.88095 .31275 Mdot
.88571 .42739 Mdot
.89048 .30004 Mdot
.89524 .37181 Mdot
.9 .39334 Mdot
.90476 .50015 Mdot
.90952 .4187 Mdot
.91429 .25712 Mdot
.91905 .28913 Mdot
.92381 .43053 Mdot
.92857 .20145 Mdot
.93333 .32559 Mdot
.9381 .15979 Mdot
.94286 .46008 Mdot
.94762 .077 Mdot
.95238 .47555 Mdot
.95714 .34803 Mdot
.9619 .18017 Mdot
.97143 .17187 Mdot
.97619 .12246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .18004 Mdot
.03333 .26754 Mdot
.0381 .41639 Mdot
.04286 .21617 Mdot
.04762 .1151 Mdot
.05238 .24765 Mdot
.05714 .25232 Mdot
.0619 .22959 Mdot
.06667 .13994 Mdot
.07143 .27538 Mdot
.07619 .19722 Mdot
.08095 .39484 Mdot
.08571 .42179 Mdot
.09048 .50232 Mdot
.09524 .40411 Mdot
.1 .22108 Mdot
.10476 .02137 Mdot
.10952 .38439 Mdot
.11429 .38649 Mdot
.11905 .46645 Mdot
.12381 .04324 Mdot
.12857 .36706 Mdot
.13333 .22958 Mdot
.1381 .05752 Mdot
.14286 .27623 Mdot
.14762 .11588 Mdot
.15238 .07751 Mdot
.15714 .31363 Mdot
.1619 .19283 Mdot
.16667 .11981 Mdot
.17143 .15556 Mdot
.17619 .27962 Mdot
.18095 .08101 Mdot
.18571 .4434 Mdot
.19524 .1337 Mdot
.2 .16934 Mdot
.20476 .04913 Mdot
.20952 .23583 Mdot
.21429 .35273 Mdot
.21905 .26457 Mdot
.22381 .2364 Mdot
.22857 .38512 Mdot
.23333 .35866 Mdot
.2381 .28169 Mdot
.24286 .23037 Mdot
.24762 .06637 Mdot
.25238 .17254 Mdot
.25714 .3056 Mdot
.2619 .08575 Mdot
.26667 .11468 Mdot
.27143 .40865 Mdot
.27619 .3095 Mdot
.28095 .43815 Mdot
.28571 .31148 Mdot
.29048 .27436 Mdot
.29524 .14422 Mdot
.3 .33031 Mdot
.30476 .25982 Mdot
.30952 .22412 Mdot
.31429 .0522 Mdot
.31905 .01788 Mdot
.32381 .299 Mdot
.32857 .29975 Mdot
.33333 .10501 Mdot
.3381 .18132 Mdot
.34286 .12997 Mdot
.34762 .20182 Mdot
.35238 .28623 Mdot
.35714 .20218 Mdot
.3619 .24838 Mdot
.36667 .21195 Mdot
.37143 .1381 Mdot
.37619 .23252 Mdot
.38095 .53753 Mdot
.38571 .27854 Mdot
.39048 .24457 Mdot
.39524 .34149 Mdot
.4 .30639 Mdot
.40476 .06565 Mdot
.40952 .10512 Mdot
.41429 .16828 Mdot
.41905 .13121 Mdot
.42381 .08848 Mdot
.42857 .18733 Mdot
.43333 .444 Mdot
.4381 .24507 Mdot
.44286 .35537 Mdot
.44762 .11028 Mdot
.45238 .04129 Mdot
.45714 .11525 Mdot
.4619 .20495 Mdot
.46667 .33999 Mdot
.47143 .16285 Mdot
.47619 .46459 Mdot
.48095 .30147 Mdot
.48571 .32031 Mdot
.49048 .46397 Mdot
.49524 .32724 Mdot
.5 .19671 Mdot
.50476 .53316 Mdot
.50952 .23287 Mdot
.51429 .26454 Mdot
.51905 .30361 Mdot
.52381 .34264 Mdot
.52857 .37406 Mdot
.53333 .32519 Mdot
.5381 .05586 Mdot
.54286 .38647 Mdot
.54762 .43763 Mdot
.55238 .05083 Mdot
.55714 .26385 Mdot
.5619 .27087 Mdot
.56667 .05944 Mdot
.57143 .18342 Mdot
.57619 .16141 Mdot
.58095 .02846 Mdot
.58571 .23867 Mdot
.59048 .4037 Mdot
.59524 .33066 Mdot
.6 .09606 Mdot
.60476 .28452 Mdot
.60952 .01321 Mdot
.61429 .37076 Mdot
.61905 .11832 Mdot
.62381 .36721 Mdot
.62857 .32981 Mdot
.63333 .21625 Mdot
.6381 .16551 Mdot
.64286 .27626 Mdot
.64762 .05875 Mdot
.65238 .19088 Mdot
.65714 .05816 Mdot
.6619 .15921 Mdot
.66667 .37681 Mdot
.67143 .14313 Mdot
.67619 .15823 Mdot
.68095 .54774 Mdot
.68571 .24601 Mdot
.69048 .4349 Mdot
.69524 .21413 Mdot
.7 .2748 Mdot
.70476 .27128 Mdot
.70952 .36113 Mdot
.71429 .10767 Mdot
.71905 .35955 Mdot
.72381 .23276 Mdot
.72857 .00684 Mdot
.73333 .49921 Mdot
.7381 .41602 Mdot
.74286 .20704 Mdot
.74762 .2962 Mdot
.75238 .17227 Mdot
.75714 .04791 Mdot
.7619 .25664 Mdot
.76667 .47422 Mdot
.77143 .21073 Mdot
.77619 .30242 Mdot
.78095 .29432 Mdot
.78571 .19382 Mdot
.79048 .22321 Mdot
.79524 .178 Mdot
.8 .48678 Mdot
.80476 .2334 Mdot
.80952 .37506 Mdot
.81429 .17523 Mdot
.81905 .24832 Mdot
.82381 .54839 Mdot
.82857 .34618 Mdot
.83333 .0468 Mdot
.8381 .27031 Mdot
.84286 .14957 Mdot
.84762 .34197 Mdot
.85238 .30429 Mdot
.8619 .2723 Mdot
.86667 .00525 Mdot
.87143 .18554 Mdot
.87619 .37387 Mdot
.88095 .33393 Mdot
.88571 .42587 Mdot
.89048 .22871 Mdot
.89524 .36328 Mdot
.9 .40216 Mdot
.90476 .52297 Mdot
.90952 .45501 Mdot
.91429 .26932 Mdot
.91905 .24344 Mdot
.92381 .41337 Mdot
.92857 .16904 Mdot
.93333 .27853 Mdot
.9381 .22183 Mdot
.94286 .42091 Mdot
.94762 .08735 Mdot
.95238 .4154 Mdot
.95714 .39388 Mdot
.9619 .13596 Mdot
.97143 .21404 Mdot
.97619 .13283 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .21128 Mdot
.03333 .23932 Mdot
.0381 .43405 Mdot
.04286 .20452 Mdot
.04762 .02565 Mdot
.05238 .22095 Mdot
.05714 .23601 Mdot
.0619 .22423 Mdot
.06667 .12647 Mdot
.07143 .3534 Mdot
.07619 .17733 Mdot
.08095 .38882 Mdot
.08571 .36882 Mdot
.09048 .45628 Mdot
.09524 .31165 Mdot
.1 .24209 Mdot
.10476 .00151 Mdot
.10952 .39488 Mdot
.11429 .3289 Mdot
.11905 .39279 Mdot
.12381 .05763 Mdot
.12857 .40008 Mdot
.13333 .24279 Mdot
.1381 .06419 Mdot
.14286 .24134 Mdot
.14762 .11712 Mdot
.15238 .05955 Mdot
.15714 .27369 Mdot
.1619 .17456 Mdot
.16667 .11682 Mdot
.17143 .15045 Mdot
.17619 .23764 Mdot
.18095 .0676 Mdot
.18571 .39593 Mdot
.19524 .16917 Mdot
.2 .16704 Mdot
.20476 .01483 Mdot
.20952 .22686 Mdot
.21429 .34352 Mdot
.21905 .2314 Mdot
.22381 .20956 Mdot
.22857 .34251 Mdot
.23333 .32215 Mdot
.2381 .29424 Mdot
.24286 .27704 Mdot
.24762 .08418 Mdot
.25238 .15976 Mdot
.25714 .25102 Mdot
.2619 .16838 Mdot
.26667 .12265 Mdot
.27143 .46133 Mdot
.27619 .24355 Mdot
.28095 .39587 Mdot
.28571 .27091 Mdot
.29048 .22573 Mdot
.29524 .08808 Mdot
.3 .38175 Mdot
.30476 .25778 Mdot
.30952 .20235 Mdot
.31429 .06686 Mdot
.31905 .09434 Mdot
.32381 .27087 Mdot
.32857 .29415 Mdot
.33333 .0705 Mdot
.3381 .16406 Mdot
.34286 .12025 Mdot
.34762 .13767 Mdot
.35238 .22383 Mdot
.35714 .16553 Mdot
.3619 .21101 Mdot
.36667 .23972 Mdot
.37143 .06161 Mdot
.37619 .25285 Mdot
.38095 .56533 Mdot
.38571 .27977 Mdot
.39048 .26369 Mdot
.39524 .3085 Mdot
.4 .34845 Mdot
.40476 .06836 Mdot
.40952 .04685 Mdot
.41429 .11625 Mdot
.41905 .04961 Mdot
.42381 .04425 Mdot
.42857 .26131 Mdot
.43333 .46922 Mdot
.4381 .23798 Mdot
.44286 .39379 Mdot
.44762 .04426 Mdot
.45238 .09142 Mdot
.45714 .12358 Mdot
.4619 .20295 Mdot
.46667 .39934 Mdot
.47143 .1596 Mdot
.47619 .46536 Mdot
.48095 .26616 Mdot
.48571 .29608 Mdot
.49048 .40014 Mdot
.49524 .3284 Mdot
.5 .18876 Mdot
.50476 .56164 Mdot
.50952 .27516 Mdot
.51429 .31546 Mdot
.51905 .36854 Mdot
.52381 .27466 Mdot
.52857 .43946 Mdot
.53333 .25582 Mdot
.5381 .05457 Mdot
.54286 .35597 Mdot
.54762 .46826 Mdot
.55238 .09932 Mdot
.55714 .26422 Mdot
.5619 .20628 Mdot
.56667 .03085 Mdot
.57143 .15465 Mdot
.57619 .21725 Mdot
.58095 .10847 Mdot
.58571 .18414 Mdot
.59048 .38768 Mdot
.59524 .36798 Mdot
.6 .05671 Mdot
.60476 .21999 Mdot
.60952 .11057 Mdot
.61429 .38256 Mdot
.61905 .09499 Mdot
.62381 .36511 Mdot
.62857 .31914 Mdot
.63333 .19296 Mdot
.6381 .12981 Mdot
.64286 .24497 Mdot
.64762 .03755 Mdot
.65238 .16345 Mdot
.65714 .02598 Mdot
.6619 .09451 Mdot
.66667 .42622 Mdot
.67143 .19139 Mdot
.67619 .13179 Mdot
.68095 .50545 Mdot
.68571 .20997 Mdot
.69048 .52947 Mdot
.69524 .24231 Mdot
.7 .20055 Mdot
.70476 .30512 Mdot
.70952 .42242 Mdot
.71429 .07491 Mdot
.71905 .32192 Mdot
.72381 .21154 Mdot
.72857 .08277 Mdot
.73333 .50054 Mdot
.7381 .37459 Mdot
.74286 .2363 Mdot
.74762 .24107 Mdot
.75238 .16689 Mdot
.75714 .09392 Mdot
.7619 .28152 Mdot
.76667 .43486 Mdot
.77143 .21486 Mdot
.77619 .30086 Mdot
.78095 .28508 Mdot
.78571 .18402 Mdot
.79048 .1519 Mdot
.79524 .1258 Mdot
.8 .56035 Mdot
.80476 .1796 Mdot
.80952 .27732 Mdot
.81429 .21361 Mdot
.81905 .31181 Mdot
.82381 .53463 Mdot
.82857 .30506 Mdot
.83333 .08194 Mdot
.8381 .18969 Mdot
.84286 .11792 Mdot
.84762 .28632 Mdot
.85238 .25133 Mdot
.8619 .26397 Mdot
.86667 .06566 Mdot
.87143 .14092 Mdot
.87619 .33126 Mdot
.88095 .3397 Mdot
.88571 .41787 Mdot
.89048 .23816 Mdot
.89524 .37453 Mdot
.9 .38612 Mdot
.90476 .52421 Mdot
.90952 .4773 Mdot
.91429 .26806 Mdot
.91905 .20715 Mdot
.92381 .40339 Mdot
.92857 .19078 Mdot
.93333 .33164 Mdot
.9381 .23989 Mdot
.94286 .41528 Mdot
.94762 .09623 Mdot
.95238 .41277 Mdot
.95714 .34805 Mdot
.9619 .08373 Mdot
.97143 .17334 Mdot
.97619 .12509 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .19126 Mdot
.03333 .30456 Mdot
.0381 .43583 Mdot
.04286 .20617 Mdot
.04762 .09054 Mdot
.05238 .18553 Mdot
.05714 .21562 Mdot
.0619 .234 Mdot
.06667 .08545 Mdot
.07143 .2675 Mdot
.07619 .14279 Mdot
.08095 .42154 Mdot
.08571 .3814 Mdot
.09048 .38801 Mdot
.09524 .32883 Mdot
.1 .25721 Mdot
.10476 .06462 Mdot
.10952 .37381 Mdot
.11429 .35589 Mdot
.11905 .43277 Mdot
.12381 .03191 Mdot
.12857 .34146 Mdot
.13333 .33474 Mdot
.1381 .11949 Mdot
.14286 .16774 Mdot
.14762 .1056 Mdot
.15238 .12633 Mdot
.15714 .21967 Mdot
.1619 .14552 Mdot
.16667 .10512 Mdot
.17143 .14276 Mdot
.17619 .27005 Mdot
.18095 .06853 Mdot
.18571 .37655 Mdot
.19524 .12108 Mdot
.2 .14248 Mdot
.20476 .09948 Mdot
.20952 .13508 Mdot
.21429 .27408 Mdot
.21905 .21444 Mdot
.22381 .16094 Mdot
.22857 .40814 Mdot
.23333 .40206 Mdot
.2381 .29366 Mdot
.24286 .27941 Mdot
.24762 .15939 Mdot
.25238 .10466 Mdot
.25714 .26524 Mdot
.2619 .13168 Mdot
.26667 .14925 Mdot
.27143 .40951 Mdot
.27619 .23428 Mdot
.28095 .3904 Mdot
.28571 .30206 Mdot
.29048 .17408 Mdot
.29524 .07102 Mdot
.3 .28788 Mdot
.30476 .25335 Mdot
.30952 .17947 Mdot
.31429 .06649 Mdot
.31905 .04621 Mdot
.32381 .2235 Mdot
.32857 .36615 Mdot
.33333 .00095 Mdot
.3381 .11869 Mdot
.34286 .14128 Mdot
.34762 .08433 Mdot
.35238 .20875 Mdot
.35714 .14596 Mdot
.3619 .1386 Mdot
.36667 .23419 Mdot
.37143 .05634 Mdot
.37619 .27615 Mdot
.38095 .56397 Mdot
.38571 .30086 Mdot
.39048 .21325 Mdot
.39524 .32035 Mdot
.4 .31108 Mdot
.40476 .08645 Mdot
.40952 .04155 Mdot
.41429 .04572 Mdot
.41905 .07912 Mdot
.42381 .02386 Mdot
.42857 .26711 Mdot
.43333 .44243 Mdot
.4381 .27996 Mdot
.44286 .45385 Mdot
.44762 .08209 Mdot
.45238 .05649 Mdot
.45714 .08653 Mdot
.4619 .15314 Mdot
.46667 .35202 Mdot
.47143 .22127 Mdot
.47619 .38427 Mdot
.48095 .19846 Mdot
.48571 .29715 Mdot
.49048 .38204 Mdot
.49524 .30635 Mdot
.5 .17933 Mdot
.50476 .60244 Mdot
.50952 .22221 Mdot
.51429 .2749 Mdot
.51905 .39743 Mdot
.52381 .3019 Mdot
.52857 .43629 Mdot
.53333 .29419 Mdot
.5381 .09527 Mdot
.54286 .3173 Mdot
.54762 .43609 Mdot
.55238 .00305 Mdot
.55714 .23267 Mdot
.5619 .22704 Mdot
.56667 .00525 Mdot
.57143 .115 Mdot
.57619 .26845 Mdot
.58095 .04111 Mdot
.58571 .18827 Mdot
.59048 .32936 Mdot
.59524 .3377 Mdot
.6 .04216 Mdot
.60476 .23228 Mdot
.60952 .07407 Mdot
.61429 .36319 Mdot
.61905 .1469 Mdot
.62381 .34855 Mdot
.62857 .35847 Mdot
.63333 .21839 Mdot
.6381 .17716 Mdot
.64286 .17425 Mdot
.64762 .00843 Mdot
.65238 .17359 Mdot
.65714 .00411 Mdot
.6619 .06063 Mdot
.66667 .43761 Mdot
.67143 .1247 Mdot
.67619 .14194 Mdot
.68095 .48399 Mdot
.68571 .14925 Mdot
.69048 .50337 Mdot
.69524 .22196 Mdot
.7 .16471 Mdot
.70476 .33552 Mdot
.70952 .44581 Mdot
.71429 .09814 Mdot
.71905 .24354 Mdot
.72381 .20251 Mdot
.72857 .01679 Mdot
.73333 .44311 Mdot
.7381 .40076 Mdot
.74286 .29822 Mdot
.74762 .18009 Mdot
.75238 .08464 Mdot
.75714 .12298 Mdot
.7619 .24239 Mdot
.76667 .39312 Mdot
.77143 .29483 Mdot
.77619 .24268 Mdot
.78095 .24596 Mdot
.78571 .11954 Mdot
.79048 .14759 Mdot
.79524 .12574 Mdot
.8 .55609 Mdot
.80476 .09081 Mdot
.80952 .28103 Mdot
.81429 .22403 Mdot
.81905 .33795 Mdot
.82381 .56432 Mdot
.82857 .26128 Mdot
.83333 .12418 Mdot
.8381 .2062 Mdot
.84286 .18573 Mdot
.84762 .21323 Mdot
.85238 .33242 Mdot
.8619 .2551 Mdot
.86667 .01111 Mdot
.87143 .08106 Mdot
.87619 .30699 Mdot
.88095 .34963 Mdot
.88571 .39829 Mdot
.89048 .28403 Mdot
.89524 .36034 Mdot
.9 .41947 Mdot
.90476 .50292 Mdot
.90952 .43639 Mdot
.91429 .22658 Mdot
.91905 .26202 Mdot
.92381 .43207 Mdot
.92857 .16194 Mdot
.93333 .34713 Mdot
.9381 .25957 Mdot
.94286 .41766 Mdot
.94762 .14286 Mdot
.95238 .45272 Mdot
.95714 .37984 Mdot
.9619 .11018 Mdot
.97143 .25401 Mdot
.97619 .18896 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .1826 Mdot
.03333 .30296 Mdot
.0381 .47762 Mdot
.04286 .1393 Mdot
.04762 .13403 Mdot
.05238 .17197 Mdot
.05714 .22707 Mdot
.0619 .22681 Mdot
.06667 .06003 Mdot
.07143 .20231 Mdot
.07619 .11418 Mdot
.08095 .39199 Mdot
.08571 .33889 Mdot
.09048 .36608 Mdot
.09524 .35545 Mdot
.1 .27159 Mdot
.10476 .079 Mdot
.10952 .38082 Mdot
.11429 .32336 Mdot
.11905 .46432 Mdot
.12381 .09644 Mdot
.12857 .31102 Mdot
.13333 .35935 Mdot
.1381 .07132 Mdot
.14286 .17634 Mdot
.14762 .11164 Mdot
.15238 .15026 Mdot
.15714 .17044 Mdot
.1619 .11244 Mdot
.16667 .0799 Mdot
.17143 .14564 Mdot
.17619 .29214 Mdot
.18095 .07821 Mdot
.18571 .27562 Mdot
.19524 .13882 Mdot
.2 .12353 Mdot
.20476 .16358 Mdot
.20952 .10062 Mdot
.21429 .25101 Mdot
.21905 .18835 Mdot
.22381 .17238 Mdot
.22857 .32929 Mdot
.23333 .33281 Mdot
.2381 .23734 Mdot
.24286 .30378 Mdot
.24762 .09417 Mdot
.25238 .09558 Mdot
.25714 .27068 Mdot
.2619 .15174 Mdot
.26667 .14036 Mdot
.27143 .43444 Mdot
.27619 .18918 Mdot
.28095 .34766 Mdot
.28571 .32806 Mdot
.29048 .14582 Mdot
.29524 .00315 Mdot
.3 .27107 Mdot
.30476 .27463 Mdot
.30952 .14218 Mdot
.31429 .00855 Mdot
.31905 .01798 Mdot
.32381 .18869 Mdot
.32857 .34104 Mdot
.33333 .08082 Mdot
.3381 .06904 Mdot
.34286 .0726 Mdot
.34762 .015 Mdot
.35238 .2826 Mdot
.35714 .15774 Mdot
.3619 .14454 Mdot
.36667 .25649 Mdot
.37143 .05203 Mdot
.37619 .30378 Mdot
.38095 .49095 Mdot
.38571 .35446 Mdot
.39048 .20051 Mdot
.39524 .37331 Mdot
.4 .24655 Mdot
.40476 .07529 Mdot
.40952 .06836 Mdot
.41429 .08998 Mdot
.41905 .14704 Mdot
.42381 .09304 Mdot
.42857 .24385 Mdot
.43333 .42189 Mdot
.4381 .29811 Mdot
.44286 .41821 Mdot
.44762 .04326 Mdot
.45238 .08167 Mdot
.45714 .05601 Mdot
.4619 .12702 Mdot
.46667 .2743 Mdot
.47143 .22803 Mdot
.47619 .43156 Mdot
.48095 .18495 Mdot
.48571 .2761 Mdot
.49048 .4145 Mdot
.49524 .33656 Mdot
.5 .18706 Mdot
.50476 .57608 Mdot
.50952 .26258 Mdot
.51429 .2509 Mdot
.51905 .32876 Mdot
.52381 .36153 Mdot
.52857 .45468 Mdot
.53333 .2694 Mdot
.5381 .17735 Mdot
.54286 .31133 Mdot
.54762 .44645 Mdot
.55238 .10126 Mdot
.55714 .21761 Mdot
.5619 .24916 Mdot
.56667 .05587 Mdot
.57143 .1533 Mdot
.57619 .28143 Mdot
.58095 .10039 Mdot
.58571 .24583 Mdot
.59048 .24345 Mdot
.59524 .36649 Mdot
.6 .01191 Mdot
.60476 .27892 Mdot
.60952 .12618 Mdot
.61429 .30265 Mdot
.61905 .18493 Mdot
.62381 .33696 Mdot
.62857 .42266 Mdot
.63333 .24753 Mdot
.6381 .1658 Mdot
.64286 .15508 Mdot
.64762 .12289 Mdot
.65238 .16993 Mdot
.65714 .08155 Mdot
.6619 .10927 Mdot
.66667 .44413 Mdot
.67143 .03471 Mdot
.67619 .1244 Mdot
.68095 .47034 Mdot
.68571 .09605 Mdot
.69048 .56555 Mdot
.69524 .20769 Mdot
.7 .09291 Mdot
.70476 .31641 Mdot
.70952 .41104 Mdot
.71429 .09235 Mdot
.71905 .22534 Mdot
.72381 .18279 Mdot
.72857 .03206 Mdot
.73333 .40491 Mdot
.7381 .39423 Mdot
.74286 .29394 Mdot
.74762 .16974 Mdot
.75238 .1633 Mdot
.75714 .15111 Mdot
.7619 .24863 Mdot
.76667 .33447 Mdot
.77143 .249 Mdot
.77619 .29238 Mdot
.78095 .22326 Mdot
.78571 .07596 Mdot
.79048 .17352 Mdot
.79524 .0817 Mdot
.8 .54863 Mdot
.80476 .02737 Mdot
.80952 .29537 Mdot
.81429 .22315 Mdot
.81905 .38679 Mdot
.82381 .4919 Mdot
.82857 .22572 Mdot
.83333 .10855 Mdot
.8381 .20188 Mdot
.84286 .22208 Mdot
.84762 .22043 Mdot
.85238 .3458 Mdot
.8619 .29624 Mdot
.86667 .08475 Mdot
.87143 .00883 Mdot
.87619 .25842 Mdot
.88095 .32596 Mdot
.88571 .34243 Mdot
.89048 .33871 Mdot
.89524 .34525 Mdot
.9 .43223 Mdot
.90476 .51483 Mdot
.90952 .44937 Mdot
.91429 .23349 Mdot
.91905 .23111 Mdot
.92381 .41885 Mdot
.92857 .13546 Mdot
.93333 .41261 Mdot
.9381 .19485 Mdot
.94286 .45701 Mdot
.94762 .18021 Mdot
.95238 .40724 Mdot
.95714 .35978 Mdot
.9619 .14981 Mdot
.97143 .27528 Mdot
.97619 .155 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .25552 Mdot
.03333 .2932 Mdot
.0381 .46059 Mdot
.04286 .1312 Mdot
.04762 .13975 Mdot
.05238 .25724 Mdot
.05714 .25006 Mdot
.0619 .16263 Mdot
.06667 .05116 Mdot
.07143 .16401 Mdot
.07619 .1205 Mdot
.08095 .32813 Mdot
.08571 .3612 Mdot
.09048 .45755 Mdot
.09524 .38899 Mdot
.1 .25616 Mdot
.10476 .05683 Mdot
.10952 .32343 Mdot
.11429 .39288 Mdot
.11905 .49725 Mdot
.12381 .05059 Mdot
.12857 .22142 Mdot
.13333 .42037 Mdot
.1381 .06826 Mdot
.14286 .10651 Mdot
.14762 .08805 Mdot
.15238 .17024 Mdot
.15714 .19065 Mdot
.1619 .04435 Mdot
.16667 .07529 Mdot
.17143 .09702 Mdot
.17619 .24524 Mdot
.18095 .0806 Mdot
.18571 .19231 Mdot
.19048 .6134 Mdot
.19524 .10114 Mdot
.2 .09742 Mdot
.20476 .25274 Mdot
.20952 .12373 Mdot
.21429 .21725 Mdot
.21905 .18152 Mdot
.22381 .2179 Mdot
.22857 .25293 Mdot
.23333 .3072 Mdot
.2381 .19587 Mdot
.24286 .25353 Mdot
.24762 .09034 Mdot
.25238 .09218 Mdot
.25714 .24014 Mdot
.2619 .09165 Mdot
.26667 .15972 Mdot
.27143 .3993 Mdot
.27619 .09586 Mdot
.28095 .27519 Mdot
.28571 .40166 Mdot
.29048 .09442 Mdot
.29524 .13086 Mdot
.3 .20537 Mdot
.30476 .22435 Mdot
.30952 .0787 Mdot
.31429 .05769 Mdot
.31905 9e-05 Mdot
.32381 .24489 Mdot
.32857 .363 Mdot
.33333 .07841 Mdot
.3381 .08456 Mdot
.34286 .03985 Mdot
.34762 .06339 Mdot
.35238 .21159 Mdot
.35714 .10764 Mdot
.3619 .23244 Mdot
.36667 .16238 Mdot
.37143 .00635 Mdot
.37619 .30989 Mdot
.38095 .3999 Mdot
.38571 .31429 Mdot
.39048 .11774 Mdot
.39524 .36453 Mdot
.4 .24474 Mdot
.40476 .079 Mdot
.40952 .05767 Mdot
.41429 .09893 Mdot
.41905 .2169 Mdot
.42381 .06113 Mdot
.42857 .25296 Mdot
.43333 .35272 Mdot
.4381 .26886 Mdot
.44286 .44471 Mdot
.44762 .0728 Mdot
.45238 .10145 Mdot
.45714 .06253 Mdot
.4619 .16031 Mdot
.46667 .28209 Mdot
.47143 .1895 Mdot
.47619 .44546 Mdot
.48095 .25359 Mdot
.48571 .32633 Mdot
.49048 .4112 Mdot
.49524 .30623 Mdot
.5 .18755 Mdot
.50476 .53707 Mdot
.50952 .232 Mdot
.51429 .25635 Mdot
.51905 .30893 Mdot
.52381 .38192 Mdot
.52857 .39233 Mdot
.53333 .28481 Mdot
.5381 .16244 Mdot
.54286 .27661 Mdot
.54762 .4129 Mdot
.55238 .07787 Mdot
.55714 .14873 Mdot
.5619 .19759 Mdot
.56667 .11892 Mdot
.57143 .18495 Mdot
.57619 .27611 Mdot
.58095 .15279 Mdot
.58571 .26514 Mdot
.59048 .16864 Mdot
.59524 .30885 Mdot
.6 .10632 Mdot
.60476 .24233 Mdot
.60952 .14807 Mdot
.61429 .25946 Mdot
.61905 .16494 Mdot
.62381 .33796 Mdot
.62857 .45709 Mdot
.63333 .19575 Mdot
.6381 .16883 Mdot
.64286 .11895 Mdot
.64762 .12938 Mdot
.65238 .19865 Mdot
.65714 .07726 Mdot
.6619 .06266 Mdot
.66667 .44818 Mdot
.67143 .13842 Mdot
.67619 .08436 Mdot
.68095 .50125 Mdot
.68571 .06769 Mdot
.69048 .55172 Mdot
.69524 .18768 Mdot
.7 .16107 Mdot
.70476 .255 Mdot
.70952 .46185 Mdot
.71429 .02416 Mdot
.71905 .19619 Mdot
.72381 .22825 Mdot
.72857 .02784 Mdot
.73333 .31475 Mdot
.7381 .39086 Mdot
.74286 .30717 Mdot
.74762 .14679 Mdot
.75238 .12351 Mdot
.75714 .20533 Mdot
.7619 .19174 Mdot
.76667 .33634 Mdot
.77143 .17377 Mdot
.77619 .30004 Mdot
.78095 .21952 Mdot
.78571 .07338 Mdot
.79048 .17815 Mdot
.79524 .06497 Mdot
.8 .46384 Mdot
.80476 .05326 Mdot
.80952 .27142 Mdot
.81429 .13154 Mdot
.81905 .30129 Mdot
.82381 .48795 Mdot
.82857 .18109 Mdot
.83333 .07469 Mdot
.8381 .19086 Mdot
.84286 .20052 Mdot
.84762 .16775 Mdot
.85238 .25264 Mdot
.85714 .59674 Mdot
.8619 .30708 Mdot
.86667 .0563 Mdot
.87143 .10116 Mdot
.87619 .25945 Mdot
.88095 .30095 Mdot
.88571 .32437 Mdot
.89048 .36039 Mdot
.89524 .34387 Mdot
.9 .43555 Mdot
.90476 .54566 Mdot
.90952 .47976 Mdot
.91429 .2136 Mdot
.91905 .18367 Mdot
.92381 .41168 Mdot
.92857 .09082 Mdot
.93333 .36193 Mdot
.9381 .18238 Mdot
.94286 .46434 Mdot
.94762 .10747 Mdot
.95238 .43032 Mdot
.95714 .37856 Mdot
.9619 .14559 Mdot
.97143 .25641 Mdot
.97619 .1348 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .31875 Mdot
.03333 .31821 Mdot
.0381 .5174 Mdot
.04286 .20353 Mdot
.04762 .09652 Mdot
.05238 .26547 Mdot
.05714 .20574 Mdot
.0619 .10072 Mdot
.06667 .0813 Mdot
.07143 .19389 Mdot
.07619 .15307 Mdot
.08095 .36774 Mdot
.08571 .33512 Mdot
.09048 .51086 Mdot
.09524 .45657 Mdot
.1 .20208 Mdot
.10476 .04633 Mdot
.10952 .24787 Mdot
.11429 .43716 Mdot
.11905 .49585 Mdot
.12381 .05424 Mdot
.12857 .17604 Mdot
.13333 .41624 Mdot
.1381 .00754 Mdot
.14286 .09938 Mdot
.14762 .06429 Mdot
.15238 .17659 Mdot
.15714 .1378 Mdot
.1619 .06633 Mdot
.16667 .05699 Mdot
.17143 .07623 Mdot
.17619 .25003 Mdot
.18095 .03012 Mdot
.18571 .15472 Mdot
.19048 .54716 Mdot
.19524 .10892 Mdot
.2 .07875 Mdot
.20476 .23676 Mdot
.20952 .04585 Mdot
.21429 .24827 Mdot
.21905 .16908 Mdot
.22381 .16541 Mdot
.22857 .19581 Mdot
.23333 .22083 Mdot
.2381 .15284 Mdot
.24286 .26212 Mdot
.24762 .12839 Mdot
.25238 .09305 Mdot
.25714 .21488 Mdot
.2619 .10941 Mdot
.26667 .16331 Mdot
.27143 .34271 Mdot
.27619 .01821 Mdot
.28095 .28706 Mdot
.28571 .42983 Mdot
.29048 .11643 Mdot
.29524 .12359 Mdot
.3 .16365 Mdot
.30476 .14903 Mdot
.30952 .06725 Mdot
.31429 .01474 Mdot
.31905 .0026 Mdot
.32381 .26617 Mdot
.32857 .33241 Mdot
.33333 .11081 Mdot
.3381 .09525 Mdot
.34286 .07276 Mdot
.34762 .02086 Mdot
.35238 .24712 Mdot
.35714 .12395 Mdot
.3619 .26447 Mdot
.36667 .08927 Mdot
.37143 .00375 Mdot
.37619 .26885 Mdot
.38095 .35599 Mdot
.38571 .35077 Mdot
.39048 .07721 Mdot
.39524 .38788 Mdot
.4 .20088 Mdot
.40476 .05773 Mdot
.40952 .068 Mdot
.41429 .11673 Mdot
.41905 .20041 Mdot
.42381 .07033 Mdot
.42857 .19899 Mdot
.43333 .41464 Mdot
.4381 .23708 Mdot
.44286 .38442 Mdot
.44762 .06359 Mdot
.45238 .09269 Mdot
.45714 .08357 Mdot
.4619 .1668 Mdot
.46667 .27894 Mdot
.47143 .23105 Mdot
.47619 .46207 Mdot
.48095 .25813 Mdot
.48571 .32783 Mdot
.49048 .41868 Mdot
.49524 .29513 Mdot
.5 .22275 Mdot
.50476 .50056 Mdot
.50952 .26983 Mdot
.51429 .1957 Mdot
.51905 .36325 Mdot
.52381 .32649 Mdot
.52857 .31601 Mdot
.53333 .26982 Mdot
.5381 .17965 Mdot
.54286 .24417 Mdot
.54762 .43946 Mdot
.55238 .13611 Mdot
.55714 .10702 Mdot
.5619 .18124 Mdot
.56667 .03692 Mdot
.57143 .13673 Mdot
.57619 .26237 Mdot
.58095 .16398 Mdot
.58571 .23722 Mdot
.59048 .10621 Mdot
.59524 .27448 Mdot
.6 .10507 Mdot
.60476 .2349 Mdot
.60952 .17115 Mdot
.61429 .24668 Mdot
.61905 .12447 Mdot
.62381 .29063 Mdot
.62857 .51041 Mdot
.63333 .16809 Mdot
.6381 .14374 Mdot
.64286 .11718 Mdot
.64762 .10267 Mdot
.65238 .22348 Mdot
.65714 .04051 Mdot
.6619 .00129 Mdot
.66667 .53033 Mdot
.67143 .14852 Mdot
.67619 .09705 Mdot
.68095 .52693 Mdot
.68571 .08755 Mdot
.69048 .55281 Mdot
.69524 .22951 Mdot
.7 .17778 Mdot
.70476 .26882 Mdot
.70952 .53157 Mdot
.71429 .06294 Mdot
.71905 .19066 Mdot
.72381 .20028 Mdot
.72857 .03397 Mdot
.73333 .25237 Mdot
.7381 .32495 Mdot
.74286 .2803 Mdot
.74762 .13027 Mdot
.75238 .0726 Mdot
.75714 .22775 Mdot
.7619 .18572 Mdot
.76667 .27257 Mdot
.77143 .15053 Mdot
.77619 .30814 Mdot
.78095 .20628 Mdot
.78571 .02982 Mdot
.79048 .1399 Mdot
.79524 .0899 Mdot
.8 .39296 Mdot
.80476 .00619 Mdot
.80952 .21211 Mdot
.81429 .08461 Mdot
.81905 .25894 Mdot
.82381 .45124 Mdot
.82857 .15004 Mdot
.83333 .05422 Mdot
.8381 .18914 Mdot
.84286 .21712 Mdot
.84762 .11919 Mdot
.85238 .19719 Mdot
.85714 .59256 Mdot
.8619 .31919 Mdot
.86667 .02621 Mdot
.87143 .07882 Mdot
.87619 .18664 Mdot
.88095 .22513 Mdot
.88571 .41084 Mdot
.89048 .36031 Mdot
.89524 .41993 Mdot
.9 .37898 Mdot
.90476 .50822 Mdot
.90952 .47357 Mdot
.91429 .27987 Mdot
.91905 .17252 Mdot
.92381 .45692 Mdot
.92857 .10391 Mdot
.93333 .35207 Mdot
.9381 .10294 Mdot
.94286 .44758 Mdot
.94762 .11269 Mdot
.95238 .34617 Mdot
.95714 .32818 Mdot
.9619 .06341 Mdot
.97143 .1901 Mdot
.97619 .09789 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32177 Mdot
.03333 .28788 Mdot
.0381 .53101 Mdot
.04286 .26882 Mdot
.04762 .10712 Mdot
.05238 .19062 Mdot
.05714 .14863 Mdot
.0619 .04208 Mdot
.06667 .04123 Mdot
.07143 .12689 Mdot
.07619 .18011 Mdot
.08095 .30739 Mdot
.08571 .2604 Mdot
.09048 .52437 Mdot
.09524 .44256 Mdot
.1 .17392 Mdot
.10476 .00475 Mdot
.10952 .2278 Mdot
.11429 .38132 Mdot
.11905 .5681 Mdot
.12381 .05373 Mdot
.12857 .16324 Mdot
.13333 .37431 Mdot
.1381 .05105 Mdot
.14286 .09816 Mdot
.14762 .09747 Mdot
.15238 .15427 Mdot
.15714 .20028 Mdot
.1619 .02927 Mdot
.16667 .04861 Mdot
.17143 .13778 Mdot
.17619 .29598 Mdot
.18095 .0529 Mdot
.18571 .15265 Mdot
.19048 .49783 Mdot
.19524 .12673 Mdot
.2 .06591 Mdot
.20476 .15285 Mdot
.20952 .04466 Mdot
.21429 .22494 Mdot
.21905 .11683 Mdot
.22381 .19014 Mdot
.22857 .13552 Mdot
.23333 .18585 Mdot
.2381 .14954 Mdot
.24286 .3066 Mdot
.24762 .04317 Mdot
.25238 .12684 Mdot
.25714 .22029 Mdot
.2619 .10916 Mdot
.26667 .11936 Mdot
.27143 .42686 Mdot
.27619 .00899 Mdot
.28095 .30999 Mdot
.28571 .39087 Mdot
.29048 .09285 Mdot
.29524 .1027 Mdot
.3 .08575 Mdot
.30476 .20308 Mdot
.30952 .08878 Mdot
.31429 .04086 Mdot
.31905 .08272 Mdot
.32381 .25244 Mdot
.32857 .33974 Mdot
.33333 .1116 Mdot
.3381 .09618 Mdot
.34286 .13498 Mdot
.34762 .03915 Mdot
.35238 .24205 Mdot
.35714 .13162 Mdot
.3619 .33619 Mdot
.36667 .07981 Mdot
.37143 .08156 Mdot
.37619 .25033 Mdot
.38095 .30847 Mdot
.38571 .33618 Mdot
.39048 .00649 Mdot
.39524 .40773 Mdot
.4 .19438 Mdot
.40476 .07583 Mdot
.40952 .08936 Mdot
.41429 .03421 Mdot
.41905 .27981 Mdot
.42381 .02317 Mdot
.42857 .2334 Mdot
.43333 .37896 Mdot
.4381 .23634 Mdot
.44286 .35212 Mdot
.44762 .00472 Mdot
.45238 .04181 Mdot
.45714 .09628 Mdot
.4619 .07927 Mdot
.46667 .33237 Mdot
.47143 .13432 Mdot
.47619 .42366 Mdot
.48095 .24594 Mdot
.48571 .2574 Mdot
.49048 .44176 Mdot
.49524 .31468 Mdot
.5 .23244 Mdot
.50476 .55721 Mdot
.50952 .20726 Mdot
.51429 .17562 Mdot
.51905 .37829 Mdot
.52381 .36791 Mdot
.52857 .28319 Mdot
.53333 .22986 Mdot
.5381 .15973 Mdot
.54286 .24223 Mdot
.54762 .4653 Mdot
.55238 .16948 Mdot
.55714 .08474 Mdot
.5619 .15762 Mdot
.56667 .0352 Mdot
.57143 .18276 Mdot
.57619 .20326 Mdot
.58095 .1917 Mdot
.58571 .21599 Mdot
.59048 .1035 Mdot
.59524 .30515 Mdot
.6 .0492 Mdot
.60476 .23721 Mdot
.60952 .15873 Mdot
.61429 .1981 Mdot
.61905 .13147 Mdot
.62381 .26646 Mdot
.62857 .54847 Mdot
.63333 .15812 Mdot
.6381 .16312 Mdot
.64286 .04369 Mdot
.64762 .11396 Mdot
.65238 .17167 Mdot
.65714 .02126 Mdot
.6619 .00916 Mdot
.66667 .58606 Mdot
.67143 .06837 Mdot
.67619 .11287 Mdot
.68095 .46338 Mdot
.68571 .15825 Mdot
.69048 .51295 Mdot
.69524 .23078 Mdot
.7 .14769 Mdot
.70476 .33139 Mdot
.70952 .48379 Mdot
.71429 .00499 Mdot
.71905 .21096 Mdot
.72381 .19509 Mdot
.72857 .03109 Mdot
.73333 .19032 Mdot
.7381 .32168 Mdot
.74286 .28257 Mdot
.74762 .06675 Mdot
.75238 .05492 Mdot
.75714 .2214 Mdot
.7619 .19924 Mdot
.76667 .36701 Mdot
.77143 .14741 Mdot
.77619 .36216 Mdot
.78095 .24852 Mdot
.78571 .00893 Mdot
.79048 .15417 Mdot
.79524 .11489 Mdot
.8 .35038 Mdot
.80476 .10041 Mdot
.80952 .20667 Mdot
.81429 .0785 Mdot
.81905 .20899 Mdot
.82381 .50865 Mdot
.82857 .12808 Mdot
.83333 .02658 Mdot
.8381 .13219 Mdot
.84286 .18878 Mdot
.84762 .09548 Mdot
.85238 .14707 Mdot
.85714 .58955 Mdot
.8619 .23716 Mdot
.86667 .02599 Mdot
.87143 .02143 Mdot
.87619 .19229 Mdot
.88095 .24532 Mdot
.88571 .40231 Mdot
.89048 .33192 Mdot
.89524 .41479 Mdot
.9 .3904 Mdot
.90476 .51 Mdot
.90952 .409 Mdot
.91429 .20427 Mdot
.91905 .09942 Mdot
.92381 .42263 Mdot
.92857 .12283 Mdot
.93333 .32672 Mdot
.9381 .10683 Mdot
.94286 .42404 Mdot
.94762 .03329 Mdot
.95238 .37492 Mdot
.95714 .3096 Mdot
.9619 .06825 Mdot
.97143 .11913 Mdot
.97619 .06981 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33139 Mdot
.03333 .27521 Mdot
.0381 .57592 Mdot
.04286 .27735 Mdot
.04762 .12221 Mdot
.05238 .09654 Mdot
.05714 .17105 Mdot
.0619 .03772 Mdot
.06667 .08722 Mdot
.07143 .22066 Mdot
.07619 .12575 Mdot
.08095 .2368 Mdot
.08571 .28255 Mdot
.09048 .56835 Mdot
.09524 .46538 Mdot
.1 .12142 Mdot
.10476 .00992 Mdot
.10952 .23063 Mdot
.11429 .35981 Mdot
.11905 .50215 Mdot
.12381 .01236 Mdot
.12857 .07787 Mdot
.13333 .3881 Mdot
.1381 .03873 Mdot
.14286 .04389 Mdot
.14762 .13982 Mdot
.15238 .09753 Mdot
.15714 .17079 Mdot
.1619 .09583 Mdot
.16667 .036 Mdot
.17143 .1303 Mdot
.17619 .30037 Mdot
.18095 .00854 Mdot
.18571 .20976 Mdot
.19048 .48454 Mdot
.19524 .11362 Mdot
.2 .02978 Mdot
.20476 .18022 Mdot
.20952 .02165 Mdot
.21429 .15305 Mdot
.21905 .15563 Mdot
.22381 .20155 Mdot
.22857 .14161 Mdot
.23333 .11711 Mdot
.2381 .21329 Mdot
.24286 .32672 Mdot
.24762 .05162 Mdot
.25238 .21869 Mdot
.25714 .20402 Mdot
.2619 .17018 Mdot
.26667 .15278 Mdot
.27143 .34017 Mdot
.27619 .09127 Mdot
.28095 .24268 Mdot
.28571 .42378 Mdot
.29048 .09136 Mdot
.29524 .08112 Mdot
.3 .05889 Mdot
.30476 .14726 Mdot
.30952 .0489 Mdot
.31429 .01051 Mdot
.31905 .03029 Mdot
.32381 .264 Mdot
.32857 .32976 Mdot
.33333 .08308 Mdot
.3381 .11437 Mdot
.34286 .14301 Mdot
.34762 .04085 Mdot
.35238 .2097 Mdot
.35714 .09282 Mdot
.3619 .25034 Mdot
.36667 .07856 Mdot
.37143 .01117 Mdot
.37619 .31152 Mdot
.38095 .26067 Mdot
.38571 .32785 Mdot
.39048 .02376 Mdot
.39524 .39493 Mdot
.4 .1475 Mdot
.40476 .07587 Mdot
.40952 .10437 Mdot
.41429 .03244 Mdot
.41905 .19736 Mdot
.42381 .12089 Mdot
.42857 .21494 Mdot
.43333 .38873 Mdot
.4381 .22692 Mdot
.44286 .39872 Mdot
.44762 .02227 Mdot
.45238 .07908 Mdot
.45714 .09606 Mdot
.4619 .05604 Mdot
.46667 .28825 Mdot
.47143 .07621 Mdot
.47619 .37906 Mdot
.48095 .22139 Mdot
.48571 .24035 Mdot
.49048 .43833 Mdot
.49524 .30643 Mdot
.5 .26505 Mdot
.50476 .57322 Mdot
.50952 .11447 Mdot
.51429 .14389 Mdot
.51905 .45438 Mdot
.52381 .36069 Mdot
.52857 .31596 Mdot
.53333 .18216 Mdot
.5381 .13811 Mdot
.54286 .23548 Mdot
.54762 .42329 Mdot
.55238 .17529 Mdot
.55714 .0608 Mdot
.5619 .12758 Mdot
.56667 .05023 Mdot
.57143 .13026 Mdot
.57619 .20003 Mdot
.58095 .15946 Mdot
.58571 .18654 Mdot
.59048 .04171 Mdot
.59524 .3424 Mdot
.6 .04418 Mdot
.60476 .25223 Mdot
.60952 .15203 Mdot
.61429 .16888 Mdot
.61905 .10044 Mdot
.62381 .28719 Mdot
.62857 .5645 Mdot
.63333 .12272 Mdot
.6381 .21557 Mdot
.64286 .0953 Mdot
.64762 .06949 Mdot
.65238 .12074 Mdot
.65714 .06827 Mdot
.6619 .09445 Mdot
.67143 .12532 Mdot
.67619 .14969 Mdot
.68095 .4123 Mdot
.68571 .21387 Mdot
.69048 .51946 Mdot
.69524 .20668 Mdot
.7 .15512 Mdot
.70476 .32816 Mdot
.70952 .4559 Mdot
.71429 .01965 Mdot
.71905 .22517 Mdot
.72381 .27224 Mdot
.72857 .00286 Mdot
.73333 .16942 Mdot
.7381 .33084 Mdot
.74286 .33248 Mdot
.74762 .0257 Mdot
.75238 .0658 Mdot
.75714 .19563 Mdot
.7619 .16984 Mdot
.76667 .38131 Mdot
.77143 .17776 Mdot
.77619 .30506 Mdot
.78095 .20621 Mdot
.78571 .05414 Mdot
.79048 .17959 Mdot
.79524 .06024 Mdot
.8 .29965 Mdot
.80476 .06899 Mdot
.80952 .22692 Mdot
.81429 .16254 Mdot
.81905 .16763 Mdot
.82381 .49817 Mdot
.82857 .1144 Mdot
.83333 .10184 Mdot
.8381 .13457 Mdot
.84286 .17497 Mdot
.84762 .1555 Mdot
.85238 .10188 Mdot
.8619 .21681 Mdot
.86667 .02447 Mdot
.87143 .05192 Mdot
.87619 .10669 Mdot
.88095 .19568 Mdot
.88571 .40827 Mdot
.89048 .27408 Mdot
.89524 .37295 Mdot
.9 .36454 Mdot
.90476 .4708 Mdot
.90952 .40334 Mdot
.91429 .15994 Mdot
.91905 .13403 Mdot
.92381 .38748 Mdot
.92857 .08942 Mdot
.93333 .23829 Mdot
.9381 .10736 Mdot
.94286 .46543 Mdot
.94762 .10761 Mdot
.95238 .32968 Mdot
.95714 .23561 Mdot
.9619 .13608 Mdot
.97143 .12969 Mdot
.97619 .1039 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .32526 Mdot
.03333 .20995 Mdot
.0381 .56785 Mdot
.04286 .27163 Mdot
.04762 .11114 Mdot
.05238 .07723 Mdot
.05714 .14462 Mdot
.0619 .06334 Mdot
.06667 .05424 Mdot
.07143 .23016 Mdot
.07619 .1099 Mdot
.08095 .20019 Mdot
.08571 .24066 Mdot
.09048 .49375 Mdot
.09524 .53423 Mdot
.1 .15682 Mdot
.10476 .04556 Mdot
.10952 .2143 Mdot
.11429 .29539 Mdot
.11905 .4974 Mdot
.12381 .01519 Mdot
.12857 .03891 Mdot
.13333 .37573 Mdot
.1381 .07236 Mdot
.14286 .11918 Mdot
.14762 .13954 Mdot
.15238 .01418 Mdot
.15714 .21962 Mdot
.1619 .0518 Mdot
.16667 .0842 Mdot
.17143 .15302 Mdot
.17619 .31117 Mdot
.18095 .07206 Mdot
.18571 .25237 Mdot
.19048 .46001 Mdot
.19524 .06139 Mdot
.2 .02495 Mdot
.20476 .13371 Mdot
.20952 .0273 Mdot
.21429 .13899 Mdot
.21905 .1263 Mdot
.22381 .19199 Mdot
.22857 .17821 Mdot
.23333 .15239 Mdot
.2381 .16446 Mdot
.24286 .23426 Mdot
.24762 .00088 Mdot
.25238 .21838 Mdot
.25714 .13333 Mdot
.2619 .18312 Mdot
.26667 .11801 Mdot
.27143 .37411 Mdot
.27619 .14612 Mdot
.28095 .18093 Mdot
.28571 .43032 Mdot
.29048 .05204 Mdot
.29524 .0064 Mdot
.3 .0502 Mdot
.30476 .08662 Mdot
.30952 .02722 Mdot
.31429 .0495 Mdot
.31905 .06747 Mdot
.32381 .27175 Mdot
.32857 .30239 Mdot
.33333 .06664 Mdot
.3381 .08082 Mdot
.34286 .11279 Mdot
.34762 .13363 Mdot
.35238 .24451 Mdot
.35714 .08078 Mdot
.3619 .29069 Mdot
.36667 .06475 Mdot
.37143 .105 Mdot
.37619 .28181 Mdot
.38095 .25731 Mdot
.38571 .2671 Mdot
.39048 .0308 Mdot
.39524 .37664 Mdot
.4 .16138 Mdot
.40476 .07586 Mdot
.40952 .08496 Mdot
.41429 .03097 Mdot
.41905 .2445 Mdot
.42381 .16435 Mdot
.42857 .17864 Mdot
.43333 .37416 Mdot
.4381 .23736 Mdot
.44286 .41038 Mdot
.44762 .09143 Mdot
.45238 .13001 Mdot
.45714 .0358 Mdot
.4619 .05001 Mdot
.46667 .25199 Mdot
.47143 .05594 Mdot
.47619 .37158 Mdot
.48095 .19181 Mdot
.48571 .24436 Mdot
.49048 .45002 Mdot
.49524 .33632 Mdot
.5 .18692 Mdot
.50476 .5454 Mdot
.50952 .14174 Mdot
.51429 .15034 Mdot
.51905 .38614 Mdot
.52381 .39148 Mdot
.52857 .35964 Mdot
.53333 .15368 Mdot
.5381 .12525 Mdot
.54286 .24195 Mdot
.54762 .42342 Mdot
.55238 .22591 Mdot
.55714 .0573 Mdot
.5619 .14911 Mdot
.56667 .02649 Mdot
.57143 .17074 Mdot
.57619 .22873 Mdot
.58095 .17783 Mdot
.58571 .15008 Mdot
.59048 .06728 Mdot
.59524 .31489 Mdot
.6 .07572 Mdot
.60476 .20083 Mdot
.60952 .06239 Mdot
.61429 .16444 Mdot
.61905 .07117 Mdot
.62381 .2056 Mdot
.62857 .57379 Mdot
.63333 .08425 Mdot
.6381 .20112 Mdot
.64286 .1117 Mdot
.64762 .07733 Mdot
.65238 .13116 Mdot
.65714 .15593 Mdot
.6619 .11499 Mdot
.66667 .56141 Mdot
.67143 .14083 Mdot
.67619 .18013 Mdot
.68095 .39795 Mdot
.68571 .26589 Mdot
.69048 .54646 Mdot
.69524 .24582 Mdot
.7 .10226 Mdot
.70476 .3268 Mdot
.70952 .43831 Mdot
.71429 .0636 Mdot
.71905 .25791 Mdot
.72381 .26245 Mdot
.72857 .08065 Mdot
.73333 .22399 Mdot
.7381 .36878 Mdot
.74286 .28803 Mdot
.74762 .06021 Mdot
.75238 .09862 Mdot
.75714 .19391 Mdot
.7619 .1342 Mdot
.76667 .46283 Mdot
.77143 .16755 Mdot
.77619 .25845 Mdot
.78095 .19689 Mdot
.78571 .02131 Mdot
.79048 .23098 Mdot
.79524 .05996 Mdot
.8 .30039 Mdot
.80476 .03793 Mdot
.80952 .16805 Mdot
.81429 .18186 Mdot
.81905 .10094 Mdot
.82381 .47088 Mdot
.82857 .13629 Mdot
.83333 .11876 Mdot
.8381 .09633 Mdot
.84286 .22531 Mdot
.84762 .16108 Mdot
.85238 .03006 Mdot
.85714 .6021 Mdot
.8619 .18167 Mdot
.86667 .09449 Mdot
.87143 .03927 Mdot
.87619 .11528 Mdot
.88095 .16094 Mdot
.88571 .42618 Mdot
.89048 .25691 Mdot
.89524 .31465 Mdot
.9 .34244 Mdot
.90476 .41763 Mdot
.90952 .43669 Mdot
.91429 .23258 Mdot
.91905 .20725 Mdot
.92381 .48063 Mdot
.92857 .12251 Mdot
.93333 .23157 Mdot
.9381 .06804 Mdot
.94286 .4477 Mdot
.94762 .02674 Mdot
.95238 .27991 Mdot
.95714 .27234 Mdot
.9619 .09986 Mdot
.97143 .13269 Mdot
.97619 .12525 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36435 Mdot
.03333 .2913 Mdot
.0381 .57474 Mdot
.04286 .26323 Mdot
.04762 .14238 Mdot
.05238 .15358 Mdot
.05714 .14372 Mdot
.0619 .00519 Mdot
.06667 .03786 Mdot
.07143 .27388 Mdot
.07619 .07171 Mdot
.08095 .21398 Mdot
.08571 .19716 Mdot
.09048 .46447 Mdot
.09524 .45357 Mdot
.1 .13695 Mdot
.10476 .00075 Mdot
.10952 .16926 Mdot
.11429 .27332 Mdot
.11905 .46764 Mdot
.12381 .02188 Mdot
.12857 .09931 Mdot
.13333 .35313 Mdot
.1381 .02643 Mdot
.14286 .06093 Mdot
.14762 .18382 Mdot
.15238 .06411 Mdot
.15714 .18295 Mdot
.1619 .05725 Mdot
.16667 .03031 Mdot
.17143 .19827 Mdot
.17619 .29211 Mdot
.18095 .07668 Mdot
.18571 .27528 Mdot
.19048 .39871 Mdot
.19524 .01509 Mdot
.2 .07892 Mdot
.20476 .14794 Mdot
.20952 .06791 Mdot
.21429 .17817 Mdot
.21905 .14502 Mdot
.22381 .16548 Mdot
.22857 .15296 Mdot
.23333 .09942 Mdot
.2381 .06938 Mdot
.24286 .27357 Mdot
.24762 .00726 Mdot
.25238 .14349 Mdot
.25714 .1647 Mdot
.2619 .18242 Mdot
.26667 .13701 Mdot
.27143 .34721 Mdot
.27619 .07442 Mdot
.28095 .16805 Mdot
.28571 .39842 Mdot
.29048 .03246 Mdot
.29524 .11151 Mdot
.3 .03503 Mdot
.30476 .14801 Mdot
.30952 .09031 Mdot
.31429 .08914 Mdot
.31905 .07586 Mdot
.32381 .33643 Mdot
.32857 .28652 Mdot
.33333 .04048 Mdot
.3381 .15114 Mdot
.34286 .13223 Mdot
.34762 .13 Mdot
.35238 .25555 Mdot
.35714 .10714 Mdot
.3619 .31917 Mdot
.36667 .05709 Mdot
.37143 .08483 Mdot
.37619 .31718 Mdot
.38095 .21879 Mdot
.38571 .25479 Mdot
.39048 .05215 Mdot
.39524 .41238 Mdot
.4 .07357 Mdot
.40476 .06179 Mdot
.40952 .1225 Mdot
.41429 .08648 Mdot
.41905 .23481 Mdot
.42381 .1367 Mdot
.42857 .17305 Mdot
.43333 .44451 Mdot
.4381 .27626 Mdot
.44286 .35293 Mdot
.44762 .16481 Mdot
.45238 .1274 Mdot
.45714 .08195 Mdot
.4619 .00122 Mdot
.46667 .2324 Mdot
.47143 .06578 Mdot
.47619 .46055 Mdot
.48095 .12104 Mdot
.48571 .19814 Mdot
.49048 .42531 Mdot
.49524 .30382 Mdot
.5 .17523 Mdot
.50476 .5439 Mdot
.50952 .06707 Mdot
.51429 .08843 Mdot
.51905 .36341 Mdot
.52381 .32674 Mdot
.52857 .38025 Mdot
.53333 .12288 Mdot
.5381 .13679 Mdot
.54286 .19049 Mdot
.54762 .43378 Mdot
.55238 .20917 Mdot
.55714 .09069 Mdot
.5619 .18699 Mdot
.56667 .05665 Mdot
.57143 .23458 Mdot
.57619 .23263 Mdot
.58095 .12076 Mdot
.58571 .09715 Mdot
.59048 .09968 Mdot
.59524 .26447 Mdot
.6 .04732 Mdot
.60476 .15685 Mdot
.60952 .03524 Mdot
.61429 .16694 Mdot
.61905 .09702 Mdot
.62381 .14633 Mdot
.62857 .55488 Mdot
.63333 .09455 Mdot
.6381 .26203 Mdot
.64286 .0562 Mdot
.64762 .01384 Mdot
.65238 .16467 Mdot
.65714 .12491 Mdot
.6619 .07133 Mdot
.66667 .5691 Mdot
.67143 .19134 Mdot
.67619 .15787 Mdot
.68095 .36619 Mdot
.68571 .22306 Mdot
.69048 .56393 Mdot
.69524 .19919 Mdot
.7 .13569 Mdot
.70476 .32317 Mdot
.70952 .35582 Mdot
.71429 .03955 Mdot
.71905 .18798 Mdot
.72381 .26431 Mdot
.72857 .02395 Mdot
.73333 .21303 Mdot
.7381 .43847 Mdot
.74286 .34671 Mdot
.74762 .02511 Mdot
.75238 .16565 Mdot
.75714 .21521 Mdot
.7619 .07775 Mdot
.76667 .50511 Mdot
.77143 .1833 Mdot
.77619 .20375 Mdot
.78095 .17855 Mdot
.78571 .00775 Mdot
.79048 .28298 Mdot
.79524 .01019 Mdot
.8 .24727 Mdot
.80476 .0263 Mdot
.80952 .21572 Mdot
.81429 .201 Mdot
.81905 .11101 Mdot
.82381 .4147 Mdot
.82857 .13236 Mdot
.83333 .02833 Mdot
.8381 .07782 Mdot
.84286 .19422 Mdot
.84762 .21175 Mdot
.85238 .13759 Mdot
.8619 .18124 Mdot
.86667 .03686 Mdot
.87143 .08178 Mdot
.87619 .02784 Mdot
.88095 .16648 Mdot
.88571 .41163 Mdot
.89048 .22186 Mdot
.89524 .27242 Mdot
.9 .29738 Mdot
.90476 .414 Mdot
.90952 .36149 Mdot
.91429 .16512 Mdot
.91905 .24727 Mdot
.92381 .41528 Mdot
.92857 .12053 Mdot
.93333 .24155 Mdot
.9381 .07551 Mdot
.94286 .41452 Mdot
.94762 .01898 Mdot
.95238 .23089 Mdot
.95714 .27679 Mdot
.9619 .14211 Mdot
.97143 .08317 Mdot
.97619 .05392 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .4414 Mdot
.03333 .19694 Mdot
.0381 .52257 Mdot
.04286 .19969 Mdot
.04762 .16538 Mdot
.05238 .14826 Mdot
.05714 .18151 Mdot
.0619 .0176 Mdot
.06667 .08605 Mdot
.07143 .25888 Mdot
.07619 .07986 Mdot
.08095 .29117 Mdot
.08571 .16377 Mdot
.09048 .49183 Mdot
.09524 .4273 Mdot
.1 .06077 Mdot
.10476 .09901 Mdot
.10952 .175 Mdot
.11429 .31739 Mdot
.11905 .43928 Mdot
.12381 .0775 Mdot
.12857 .07718 Mdot
.13333 .31465 Mdot
.1381 .00083 Mdot
.14286 .09415 Mdot
.14762 .19436 Mdot
.15238 .00872 Mdot
.15714 .17132 Mdot
.1619 .10362 Mdot
.16667 .07558 Mdot
.17143 .24777 Mdot
.17619 .362 Mdot
.18095 .15894 Mdot
.18571 .23278 Mdot
.19048 .48664 Mdot
.19524 .01044 Mdot
.2 .07458 Mdot
.20476 .22525 Mdot
.20952 .00569 Mdot
.21429 .1333 Mdot
.21905 .15379 Mdot
.22381 .15959 Mdot
.22857 .14526 Mdot
.23333 .09464 Mdot
.2381 .02981 Mdot
.24286 .29095 Mdot
.24762 .01727 Mdot
.25238 .12842 Mdot
.25714 .13952 Mdot
.2619 .10771 Mdot
.26667 .1524 Mdot
.27143 .31843 Mdot
.27619 .00725 Mdot
.28095 .19635 Mdot
.28571 .44683 Mdot
.29048 .05016 Mdot
.29524 .02902 Mdot
.3 .06222 Mdot
.30476 .05236 Mdot
.30952 .07464 Mdot
.31429 .08126 Mdot
.31905 .13855 Mdot
.32381 .29428 Mdot
.32857 .24627 Mdot
.33333 .06841 Mdot
.3381 .11601 Mdot
.34286 .09564 Mdot
.34762 .14562 Mdot
.35238 .22494 Mdot
.35714 .07509 Mdot
.3619 .30013 Mdot
.36667 .05635 Mdot
.37143 .05434 Mdot
.37619 .32752 Mdot
.38095 .23485 Mdot
.38571 .26753 Mdot
.39048 .0202 Mdot
.39524 .3445 Mdot
.4 .08857 Mdot
.40476 .06758 Mdot
.40952 .1466 Mdot
.41429 .04095 Mdot
.41905 .21308 Mdot
.42381 .08131 Mdot
.42857 .20687 Mdot
.43333 .46395 Mdot
.4381 .26493 Mdot
.44286 .34279 Mdot
.44762 .0982 Mdot
.45238 .13434 Mdot
.45714 .0765 Mdot
.4619 .09795 Mdot
.46667 .17979 Mdot
.47143 .00976 Mdot
.47619 .46978 Mdot
.48095 .14834 Mdot
.48571 .25342 Mdot
.49048 .40436 Mdot
.49524 .24386 Mdot
.5 .20753 Mdot
.50476 .55162 Mdot
.50952 .07843 Mdot
.51429 .0581 Mdot
.51905 .32315 Mdot
.52381 .28164 Mdot
.52857 .35591 Mdot
.53333 .10171 Mdot
.5381 .11925 Mdot
.54286 .22076 Mdot
.54762 .40214 Mdot
.55238 .17624 Mdot
.55714 .00923 Mdot
.5619 .13784 Mdot
.56667 .13346 Mdot
.57143 .19501 Mdot
.57619 .17729 Mdot
.58095 .09777 Mdot
.58571 .1648 Mdot
.59048 .1517 Mdot
.59524 .27988 Mdot
.6 .09828 Mdot
.60476 .14467 Mdot
.60952 .10672 Mdot
.61429 .18801 Mdot
.61905 .04582 Mdot
.62381 .16303 Mdot
.62857 .48265 Mdot
.63333 .16554 Mdot
.6381 .25599 Mdot
.64286 .03683 Mdot
.64762 .0771 Mdot
.65238 .17595 Mdot
.65714 .05034 Mdot
.6619 .07952 Mdot
.66667 .56163 Mdot
.67143 .14305 Mdot
.67619 .16148 Mdot
.68095 .35412 Mdot
.68571 .24948 Mdot
.69048 .53629 Mdot
.69524 .17331 Mdot
.7 .19333 Mdot
.70476 .32464 Mdot
.70952 .3066 Mdot
.71429 .0975 Mdot
.71905 .20813 Mdot
.72381 .24636 Mdot
.72857 .02229 Mdot
.73333 .19383 Mdot
.7381 .48 Mdot
.74286 .32926 Mdot
.74762 .12878 Mdot
.75238 .20131 Mdot
.75714 .21408 Mdot
.7619 .00135 Mdot
.76667 .52275 Mdot
.77143 .22836 Mdot
.77619 .19803 Mdot
.78095 .18171 Mdot
.78571 .03852 Mdot
.79048 .21997 Mdot
.79524 .11919 Mdot
.8 .19222 Mdot
.80476 .02011 Mdot
.80952 .2518 Mdot
.81429 .17327 Mdot
.81905 .12669 Mdot
.82381 .36386 Mdot
.82857 .12955 Mdot
.83333 .02745 Mdot
.8381 .03197 Mdot
.84286 .24953 Mdot
.84762 .22431 Mdot
.85238 .11298 Mdot
.85714 .61256 Mdot
.8619 .22949 Mdot
.86667 .11356 Mdot
.87143 .12857 Mdot
.87619 .10679 Mdot
.88095 .09608 Mdot
.88571 .43144 Mdot
.89048 .20109 Mdot
.89524 .24762 Mdot
.9 .25372 Mdot
.90476 .46985 Mdot
.90952 .33592 Mdot
.91429 .1547 Mdot
.91905 .2426 Mdot
.92381 .393 Mdot
.92857 .08098 Mdot
.93333 .17978 Mdot
.9381 .04754 Mdot
.94286 .40911 Mdot
.94762 .0567 Mdot
.95238 .19114 Mdot
.95714 .24163 Mdot
.9619 .13015 Mdot
.97143 .06168 Mdot
.97619 .1517 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .46885 Mdot
.03333 .19658 Mdot
.0381 .49843 Mdot
.04286 .15053 Mdot
.04762 .24252 Mdot
.05238 .10974 Mdot
.05714 .22163 Mdot
.0619 .05142 Mdot
.06667 .13092 Mdot
.07143 .28752 Mdot
.07619 .09996 Mdot
.08095 .21299 Mdot
.08571 .08141 Mdot
.09048 .52864 Mdot
.09524 .35627 Mdot
.1 .1202 Mdot
.10476 .18782 Mdot
.10952 .21 Mdot
.11429 .31429 Mdot
.11905 .44606 Mdot
.12381 .00521 Mdot
.12857 .10112 Mdot
.13333 .25042 Mdot
.1381 .00496 Mdot
.14286 .07907 Mdot
.14762 .16765 Mdot
.15238 .07536 Mdot
.15714 .2199 Mdot
.1619 .0098 Mdot
.16667 .07794 Mdot
.17143 .30891 Mdot
.17619 .36334 Mdot
.18095 .1783 Mdot
.18571 .19235 Mdot
.19048 .48595 Mdot
.19524 .09546 Mdot
.2 .00489 Mdot
.20476 .21138 Mdot
.20952 .08895 Mdot
.21429 .17778 Mdot
.21905 .13463 Mdot
.22381 .12738 Mdot
.22857 .12073 Mdot
.23333 .07608 Mdot
.2381 .0963 Mdot
.24286 .29779 Mdot
.24762 .02959 Mdot
.25238 .2067 Mdot
.25714 .21747 Mdot
.2619 .11527 Mdot
.26667 .1533 Mdot
.27143 .32531 Mdot
.27619 .09112 Mdot
.28095 .12878 Mdot
.28571 .44217 Mdot
.29048 .09839 Mdot
.29524 .09391 Mdot
.3 .06364 Mdot
.30476 .11238 Mdot
.30952 .06547 Mdot
.31429 .10901 Mdot
.31905 .0733 Mdot
.32381 .39042 Mdot
.32857 .28738 Mdot
.33333 .08575 Mdot
.3381 .12912 Mdot
.34286 .10904 Mdot
.34762 .20308 Mdot
.35238 .18474 Mdot
.35714 .08071 Mdot
.3619 .21941 Mdot
.36667 .05136 Mdot
.37143 .00864 Mdot
.37619 .2923 Mdot
.38095 .19806 Mdot
.38571 .26969 Mdot
.39048 .06673 Mdot
.39524 .35109 Mdot
.4 .02316 Mdot
.40476 .07222 Mdot
.40952 .16662 Mdot
.41429 .0545 Mdot
.41905 .16502 Mdot
.42381 .07816 Mdot
.42857 .19734 Mdot
.43333 .42249 Mdot
.4381 .33636 Mdot
.44286 .37276 Mdot
.44762 .07307 Mdot
.45238 .11273 Mdot
.45714 .1583 Mdot
.4619 .11492 Mdot
.46667 .11128 Mdot
.47143 .025 Mdot
.47619 .39769 Mdot
.48095 .18343 Mdot
.48571 .2569 Mdot
.49048 .37907 Mdot
.49524 .19188 Mdot
.5 .12918 Mdot
.50476 .54312 Mdot
.50952 .0483 Mdot
.51429 .09964 Mdot
.51905 .28681 Mdot
.52381 .23946 Mdot
.52857 .31997 Mdot
.53333 .14498 Mdot
.5381 .09441 Mdot
.54286 .23614 Mdot
.54762 .34305 Mdot
.55238 .2238 Mdot
.55714 .02711 Mdot
.5619 .16651 Mdot
.56667 .16233 Mdot
.57143 .1823 Mdot
.57619 .1902 Mdot
.58095 .12059 Mdot
.58571 .15814 Mdot
.59048 .19503 Mdot
.59524 .2171 Mdot
.6 .03876 Mdot
.60476 .12953 Mdot
.60952 .09529 Mdot
.61429 .13141 Mdot
.61905 .03946 Mdot
.62381 .12504 Mdot
.62857 .41945 Mdot
.63333 .1789 Mdot
.6381 .16733 Mdot
.64286 .04647 Mdot
.64762 .01127 Mdot
.65238 .13604 Mdot
.65714 .05335 Mdot
.6619 .04897 Mdot
.66667 .61283 Mdot
.67143 .08624 Mdot
.67619 .16898 Mdot
.68095 .34902 Mdot
.68571 .2034 Mdot
.69048 .49667 Mdot
.69524 .17066 Mdot
.7 .25802 Mdot
.70476 .31468 Mdot
.70952 .24688 Mdot
.71429 .03967 Mdot
.71905 .22401 Mdot
.72381 .18217 Mdot
.72857 .00701 Mdot
.73333 .13204 Mdot
.7381 .46712 Mdot
.74286 .26494 Mdot
.74762 .14014 Mdot
.75238 .1614 Mdot
.75714 .21931 Mdot
.7619 .03575 Mdot
.76667 .51495 Mdot
.77143 .22711 Mdot
.77619 .17095 Mdot
.78095 .1243 Mdot
.78571 .07109 Mdot
.79048 .19604 Mdot
.79524 .145 Mdot
.8 .18717 Mdot
.80476 .01823 Mdot
.80952 .27732 Mdot
.81429 .15636 Mdot
.81905 .18887 Mdot
.82381 .40046 Mdot
.82857 .14041 Mdot
.83333 .00377 Mdot
.8381 .06216 Mdot
.84286 .18922 Mdot
.84762 .16571 Mdot
.85238 .16188 Mdot
.8619 .25601 Mdot
.86667 .0718 Mdot
.87143 .07529 Mdot
.87619 .05054 Mdot
.88095 .06767 Mdot
.88571 .405 Mdot
.89048 .1648 Mdot
.89524 .25148 Mdot
.9 .27681 Mdot
.90476 .39631 Mdot
.90952 .31648 Mdot
.91429 .08828 Mdot
.91905 .22071 Mdot
.92381 .36923 Mdot
.92857 .01572 Mdot
.93333 .18535 Mdot
.9381 .06153 Mdot
.94286 .37909 Mdot
.94762 .00144 Mdot
.95238 .1805 Mdot
.95714 .22505 Mdot
.9619 .13025 Mdot
.97143 .06914 Mdot
.97619 .12719 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .39301 Mdot
.03333 .19469 Mdot
.0381 .44332 Mdot
.04286 .1074 Mdot
.04762 .2181 Mdot
.05238 .18347 Mdot
.05714 .22876 Mdot
.0619 .0698 Mdot
.06667 .06448 Mdot
.07143 .21139 Mdot
.07619 .05336 Mdot
.08095 .23463 Mdot
.08571 .05222 Mdot
.09048 .52494 Mdot
.09524 .31727 Mdot
.1 .10367 Mdot
.10476 .13178 Mdot
.10952 .22518 Mdot
.11429 .30523 Mdot
.11905 .41579 Mdot
.12381 .03139 Mdot
.12857 .1099 Mdot
.13333 .26188 Mdot
.1381 .02685 Mdot
.14286 .03103 Mdot
.14762 .08495 Mdot
.15238 .05841 Mdot
.15714 .17059 Mdot
.1619 .07769 Mdot
.16667 .06259 Mdot
.17143 .27265 Mdot
.17619 .4042 Mdot
.18095 .20849 Mdot
.18571 .21217 Mdot
.19048 .51717 Mdot
.19524 .04318 Mdot
.2 .01746 Mdot
.20476 .16706 Mdot
.20952 .17302 Mdot
.21429 .17069 Mdot
.21905 .08027 Mdot
.22381 .19236 Mdot
.22857 .15527 Mdot
.23333 .11079 Mdot
.2381 .03934 Mdot
.24286 .26531 Mdot
.24762 .02947 Mdot
.25238 .28839 Mdot
.25714 .22148 Mdot
.2619 .1154 Mdot
.26667 .14437 Mdot
.27143 .38213 Mdot
.27619 .07346 Mdot
.28095 .11109 Mdot
.28571 .47349 Mdot
.29048 .06469 Mdot
.29524 .05555 Mdot
.3 .02502 Mdot
.30476 .16284 Mdot
.30952 .0303 Mdot
.31429 .03468 Mdot
.31905 .08196 Mdot
.32381 .32564 Mdot
.32857 .23459 Mdot
.33333 .10654 Mdot
.3381 .0851 Mdot
.34286 .1046 Mdot
.34762 .19687 Mdot
.35238 .20528 Mdot
.35714 .03912 Mdot
.3619 .268 Mdot
.36667 .03253 Mdot
.37143 .04345 Mdot
.37619 .35872 Mdot
.38095 .20824 Mdot
.38571 .31485 Mdot
.39048 .14324 Mdot
.39524 .32651 Mdot
.4 .02401 Mdot
.40476 .03747 Mdot
.40952 .16093 Mdot
.41429 .01703 Mdot
.41905 .18768 Mdot
.42381 .06063 Mdot
.42857 .19314 Mdot
.43333 .40209 Mdot
.4381 .26499 Mdot
.44286 .32067 Mdot
.44762 .09723 Mdot
.45238 .16452 Mdot
.45714 .13698 Mdot
.4619 .06789 Mdot
.46667 .14545 Mdot
.47143 .09029 Mdot
.47619 .37851 Mdot
.48095 .15861 Mdot
.48571 .27451 Mdot
.49048 .43487 Mdot
.49524 .18548 Mdot
.5 .12552 Mdot
.50476 .55965 Mdot
.50952 .03032 Mdot
.51429 .11867 Mdot
.51905 .28605 Mdot
.52381 .21793 Mdot
.52857 .30993 Mdot
.53333 .16401 Mdot
.5381 .08362 Mdot
.54286 .15103 Mdot
.54762 .25578 Mdot
.55238 .19528 Mdot
.55714 .04012 Mdot
.5619 .16032 Mdot
.56667 .10069 Mdot
.57143 .12507 Mdot
.57619 .177 Mdot
.58095 .10729 Mdot
.58571 .08037 Mdot
.59048 .20529 Mdot
.59524 .15974 Mdot
.6 .05905 Mdot
.60476 .12559 Mdot
.60952 .08659 Mdot
.61429 .12229 Mdot
.61905 .0864 Mdot
.62381 .12378 Mdot
.62857 .41919 Mdot
.63333 .10629 Mdot
.6381 .13289 Mdot
.64286 .02844 Mdot
.64762 .12469 Mdot
.65238 .11797 Mdot
.65714 .03519 Mdot
.6619 .10875 Mdot
.66667 .60089 Mdot
.67143 .03334 Mdot
.67619 .13339 Mdot
.68095 .39166 Mdot
.68571 .12424 Mdot
.69048 .46722 Mdot
.69524 .13411 Mdot
.7 .17808 Mdot
.70476 .36546 Mdot
.70952 .24941 Mdot
.71429 .08939 Mdot
.71905 .23969 Mdot
.72381 .12583 Mdot
.72857 .02936 Mdot
.73333 .08249 Mdot
.7381 .52286 Mdot
.74286 .21567 Mdot
.74762 .1129 Mdot
.75238 .06724 Mdot
.75714 .24677 Mdot
.7619 .00855 Mdot
.76667 .5125 Mdot
.77143 .18859 Mdot
.77619 .12905 Mdot
.78095 .0513 Mdot
.78571 .06551 Mdot
.79048 .10162 Mdot
.79524 .09525 Mdot
.8 .1099 Mdot
.80476 .07082 Mdot
.80952 .23333 Mdot
.81429 .18778 Mdot
.81905 .12005 Mdot
.82381 .35448 Mdot
.82857 .12938 Mdot
.83333 .05749 Mdot
.8381 .04753 Mdot
.84286 .17128 Mdot
.84762 .15009 Mdot
.85238 .12457 Mdot
.85714 .61078 Mdot
.8619 .29363 Mdot
.86667 .03861 Mdot
.87143 .11507 Mdot
.87619 .02747 Mdot
.88095 .06207 Mdot
.88571 .33769 Mdot
.89048 .07633 Mdot
.89524 .19418 Mdot
.9 .29801 Mdot
.90476 .36131 Mdot
.90952 .31727 Mdot
.91429 .05154 Mdot
.91905 .20857 Mdot
.92381 .45678 Mdot
.92857 .09252 Mdot
.93333 .21318 Mdot
.9381 .04258 Mdot
.94286 .37355 Mdot
.94762 .01627 Mdot
.95238 .26231 Mdot
.95714 .17947 Mdot
.9619 .09057 Mdot
.96667 .609 Mdot
.97143 .03867 Mdot
.97619 .15132 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .34067 Mdot
.03333 .10374 Mdot
.0381 .40012 Mdot
.04286 .06252 Mdot
.04762 .20933 Mdot
.05238 .11149 Mdot
.05714 .17904 Mdot
.0619 .02058 Mdot
.06667 .08149 Mdot
.07143 .25244 Mdot
.07619 .03817 Mdot
.08095 .22004 Mdot
.08571 .09243 Mdot
.09048 .60338 Mdot
.09524 .31243 Mdot
.1 .0691 Mdot
.10476 .15525 Mdot
.10952 .2837 Mdot
.11429 .3406 Mdot
.11905 .43028 Mdot
.12381 .0944 Mdot
.12857 .15763 Mdot
.13333 .26465 Mdot
.1381 .08636 Mdot
.14286 .08481 Mdot
.14762 .14713 Mdot
.15238 .0489 Mdot
.15714 .25783 Mdot
.1619 .03643 Mdot
.16667 .09283 Mdot
.17143 .22524 Mdot
.17619 .48584 Mdot
.18095 .2421 Mdot
.18571 .14765 Mdot
.19048 .47461 Mdot
.19524 .07866 Mdot
.2 .00872 Mdot
.20476 .14811 Mdot
.20952 .18393 Mdot
.21429 .09336 Mdot
.21905 .06958 Mdot
.22381 .16388 Mdot
.22857 .19751 Mdot
.23333 .13607 Mdot
.2381 .03486 Mdot
.24286 .30513 Mdot
.24762 .01794 Mdot
.25238 .20753 Mdot
.25714 .14641 Mdot
.2619 .06686 Mdot
.26667 .19062 Mdot
.27143 .33364 Mdot
.27619 .0885 Mdot
.28095 .15514 Mdot
.28571 .46719 Mdot
.29048 .00509 Mdot
.29524 .06657 Mdot
.3 .00199 Mdot
.30476 .21702 Mdot
.30952 .00566 Mdot
.31429 .03899 Mdot
.31905 .02143 Mdot
.32381 .30829 Mdot
.32857 .21911 Mdot
.33333 .09805 Mdot
.3381 .08755 Mdot
.34286 .15688 Mdot
.34762 .1338 Mdot
.35238 .21479 Mdot
.35714 .04221 Mdot
.3619 .27624 Mdot
.36667 .10375 Mdot
.37143 .02049 Mdot
.37619 .27483 Mdot
.38095 .22598 Mdot
.38571 .31775 Mdot
.39048 .17196 Mdot
.39524 .35717 Mdot
.4 .07565 Mdot
.40476 .08072 Mdot
.40952 .1072 Mdot
.41429 .01538 Mdot
.41905 .13509 Mdot
.42381 .01124 Mdot
.42857 .22451 Mdot
.43333 .35554 Mdot
.4381 .25342 Mdot
.44286 .29419 Mdot
.44762 .0416 Mdot
.45238 .10073 Mdot
.45714 .09334 Mdot
.4619 .00743 Mdot
.46667 .05172 Mdot
.47143 .16834 Mdot
.47619 .42813 Mdot
.48095 .16337 Mdot
.48571 .32436 Mdot
.49048 .42174 Mdot
.49524 .12202 Mdot
.5 .08457 Mdot
.50476 .58753 Mdot
.50952 .12028 Mdot
.51429 .09801 Mdot
.51905 .33352 Mdot
.52381 .21237 Mdot
.52857 .33759 Mdot
.53333 .1324 Mdot
.5381 .08415 Mdot
.54286 .17395 Mdot
.54762 .22291 Mdot
.55238 .15248 Mdot
.55714 .05243 Mdot
.5619 .09786 Mdot
.56667 .03136 Mdot
.57143 .14031 Mdot
.57619 .1988 Mdot
.58095 .14123 Mdot
.58571 .06739 Mdot
.59048 .12102 Mdot
.59524 .10638 Mdot
.6 .02088 Mdot
.60476 .11282 Mdot
.60952 .11581 Mdot
.61429 .11066 Mdot
.61905 .11347 Mdot
.62381 .05725 Mdot
.62857 .40963 Mdot
.63333 .16604 Mdot
.6381 .13357 Mdot
.64286 .03348 Mdot
.64762 .05498 Mdot
.65238 .10177 Mdot
.65714 .07651 Mdot
.6619 .13643 Mdot
.66667 .55202 Mdot
.67143 .05489 Mdot
.67619 .10277 Mdot
.68095 .33063 Mdot
.68571 .0887 Mdot
.69048 .42708 Mdot
.69524 .12391 Mdot
.7 .1439 Mdot
.70476 .38626 Mdot
.70952 .25532 Mdot
.71429 .09534 Mdot
.71905 .25621 Mdot
.72381 .11467 Mdot
.72857 .03321 Mdot
.73333 .10903 Mdot
.7381 .5152 Mdot
.74286 .17718 Mdot
.74762 .11422 Mdot
.75238 .01698 Mdot
.75714 .19116 Mdot
.7619 .08259 Mdot
.76667 .57078 Mdot
.77143 .14827 Mdot
.77619 .19724 Mdot
.78095 .00081 Mdot
.78571 .08033 Mdot
.79048 .10447 Mdot
.79524 .10958 Mdot
.8 .10802 Mdot
.80476 .07981 Mdot
.80952 .22457 Mdot
.81429 .1804 Mdot
.81905 .03468 Mdot
.82381 .34455 Mdot
.82857 .21729 Mdot
.83333 .04655 Mdot
.8381 .07552 Mdot
.84286 .22681 Mdot
.84762 .14549 Mdot
.85238 .18269 Mdot
.8619 .29584 Mdot
.86667 .04142 Mdot
.87143 .08106 Mdot
.87619 .08521 Mdot
.88095 .14497 Mdot
.88571 .31253 Mdot
.89048 .05124 Mdot
.89524 .21584 Mdot
.9 .33579 Mdot
.90476 .35889 Mdot
.90952 .33746 Mdot
.91429 .0999 Mdot
.91905 .24471 Mdot
.92381 .41083 Mdot
.92857 .0449 Mdot
.93333 .23803 Mdot
.9381 .10033 Mdot
.94286 .34275 Mdot
.94762 .06087 Mdot
.95238 .33764 Mdot
.95714 .21531 Mdot
.9619 .13401 Mdot
.96667 .59072 Mdot
.97143 .0706 Mdot
.97619 .09981 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .34529 Mdot
.03333 .02733 Mdot
.0381 .35089 Mdot
.04286 .09955 Mdot
.04762 .19518 Mdot
.05238 .17121 Mdot
.05714 .2134 Mdot
.0619 .08809 Mdot
.06667 .09537 Mdot
.07143 .25696 Mdot
.07619 .07516 Mdot
.08095 .14847 Mdot
.08571 .11998 Mdot
.09048 .53777 Mdot
.09524 .32706 Mdot
.1 .00616 Mdot
.10476 .23175 Mdot
.10952 .27347 Mdot
.11429 .28764 Mdot
.11905 .39308 Mdot
.12381 .0624 Mdot
.12857 .14467 Mdot
.13333 .29003 Mdot
.1381 .05807 Mdot
.14286 .10801 Mdot
.14762 .14807 Mdot
.15238 .11149 Mdot
.15714 .26058 Mdot
.1619 .09315 Mdot
.16667 .10458 Mdot
.17143 .14555 Mdot
.17619 .46462 Mdot
.18095 .2514 Mdot
.18571 .14376 Mdot
.19048 .38682 Mdot
.19524 .0737 Mdot
.2 .04248 Mdot
.20476 .14638 Mdot
.20952 .16804 Mdot
.21429 .09959 Mdot
.21905 .02748 Mdot
.22381 .16192 Mdot
.22857 .15803 Mdot
.23333 .1325 Mdot
.2381 .08454 Mdot
.24286 .26296 Mdot
.24762 .03001 Mdot
.25238 .15268 Mdot
.25714 .1425 Mdot
.2619 .14095 Mdot
.26667 .22147 Mdot
.27143 .29442 Mdot
.27619 .08123 Mdot
.28095 .15043 Mdot
.28571 .41626 Mdot
.29048 .09497 Mdot
.29524 .06596 Mdot
.3 .07291 Mdot
.30476 .22363 Mdot
.30952 .0203 Mdot
.31429 .05262 Mdot
.31905 .09338 Mdot
.32381 .36203 Mdot
.32857 .21955 Mdot
.33333 .06793 Mdot
.3381 .09496 Mdot
.34286 .08601 Mdot
.34762 .16174 Mdot
.35238 .22015 Mdot
.35714 .02664 Mdot
.3619 .256 Mdot
.36667 .02225 Mdot
.37143 .07753 Mdot
.37619 .24693 Mdot
.38095 .28738 Mdot
.38571 .25938 Mdot
.39048 .21553 Mdot
.39524 .3262 Mdot
.4 .05327 Mdot
.40476 .00747 Mdot
.40952 .0844 Mdot
.41429 .01283 Mdot
.41905 .13099 Mdot
.42381 .07326 Mdot
.42857 .13919 Mdot
.43333 .33498 Mdot
.4381 .23241 Mdot
.44286 .23119 Mdot
.44762 .01907 Mdot
.45238 .1431 Mdot
.45714 .04387 Mdot
.4619 .0852 Mdot
.46667 .01141 Mdot
.47143 .17858 Mdot
.47619 .46869 Mdot
.48095 .13929 Mdot
.48571 .342 Mdot
.49048 .41849 Mdot
.49524 .09858 Mdot
.5 .06012 Mdot
.50476 .53285 Mdot
.50952 .13562 Mdot
.51429 .07127 Mdot
.51905 .28728 Mdot
.52381 .30345 Mdot
.52857 .2866 Mdot
.53333 .13238 Mdot
.5381 .0291 Mdot
.54286 .16563 Mdot
.54762 .19096 Mdot
.55238 .11518 Mdot
.55714 .08808 Mdot
.5619 .05865 Mdot
.56667 .0637 Mdot
.57143 .17778 Mdot
.57619 .10037 Mdot
.58095 .0652 Mdot
.58571 .07213 Mdot
.59048 .07452 Mdot
.59524 .00692 Mdot
.6 .01825 Mdot
.60476 .10879 Mdot
.60952 .10404 Mdot
.61429 .02196 Mdot
.61905 .19844 Mdot
.62381 .0744 Mdot
.62857 .42663 Mdot
.63333 .08481 Mdot
.6381 .12653 Mdot
.64286 .06468 Mdot
.64762 .12904 Mdot
.65238 .06438 Mdot
.65714 .10658 Mdot
.6619 .19958 Mdot
.67143 .09309 Mdot
.67619 .08058 Mdot
.68095 .33142 Mdot
.68571 .17473 Mdot
.69048 .3675 Mdot
.69524 .09515 Mdot
.7 .13617 Mdot
.70476 .38563 Mdot
.70952 .22789 Mdot
.71429 .10053 Mdot
.71905 .25865 Mdot
.72381 .11287 Mdot
.72857 .04916 Mdot
.73333 .12858 Mdot
.7381 .50039 Mdot
.74286 .09439 Mdot
.74762 .06149 Mdot
.75238 .07151 Mdot
.75714 .20089 Mdot
.7619 .04071 Mdot
.76667 .53997 Mdot
.77143 .15282 Mdot
.77619 .16815 Mdot
.78095 .01081 Mdot
.78571 .17118 Mdot
.79048 .05594 Mdot
.79524 .08558 Mdot
.8 .09735 Mdot
.80476 .03407 Mdot
.80952 .24254 Mdot
.81429 .15925 Mdot
.81905 .10093 Mdot
.82381 .32603 Mdot
.82857 .16246 Mdot
.83333 .05167 Mdot
.8381 .11393 Mdot
.84286 .21656 Mdot
.84762 .19511 Mdot
.85238 .20723 Mdot
.8619 .28611 Mdot
.86667 .0766 Mdot
.87143 .00689 Mdot
.87619 .02126 Mdot
.88095 .17501 Mdot
.88571 .40494 Mdot
.89048 .03958 Mdot
.89524 .20268 Mdot
.9 .29856 Mdot
.90476 .3781 Mdot
.90952 .24239 Mdot
.91429 .13231 Mdot
.91905 .26006 Mdot
.92381 .45971 Mdot
.92857 .06036 Mdot
.93333 .17195 Mdot
.9381 .03375 Mdot
.94286 .32403 Mdot
.94762 .12843 Mdot
.95238 .36031 Mdot
.95714 .17234 Mdot
.9619 .14735 Mdot
.96667 .5326 Mdot
.97143 .0682 Mdot
.97619 .18288 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .37806 Mdot
.03333 .05966 Mdot
.0381 .37757 Mdot
.04286 .1414 Mdot
.04762 .2223 Mdot
.05238 .1187 Mdot
.05714 .16135 Mdot
.0619 .0829 Mdot
.06667 .07585 Mdot
.07143 .17321 Mdot
.07619 .06758 Mdot
.08095 .17055 Mdot
.08571 .03814 Mdot
.09048 .50047 Mdot
.09524 .36949 Mdot
.1 .12984 Mdot
.10476 .14464 Mdot
.10952 .27761 Mdot
.11429 .24301 Mdot
.11905 .30574 Mdot
.12381 .04485 Mdot
.12857 .22971 Mdot
.13333 .22091 Mdot
.1381 .02101 Mdot
.14286 .10602 Mdot
.14762 .12297 Mdot
.15238 .07757 Mdot
.15714 .20529 Mdot
.1619 .10507 Mdot
.16667 .03888 Mdot
.17143 .08641 Mdot
.17619 .47283 Mdot
.18095 .20777 Mdot
.18571 .1501 Mdot
.19048 .3303 Mdot
.19524 .06754 Mdot
.2 .09764 Mdot
.20476 .1473 Mdot
.20952 .14247 Mdot
.21429 .05745 Mdot
.21905 .07712 Mdot
.22381 .17963 Mdot
.22857 .16875 Mdot
.23333 .14671 Mdot
.2381 .05944 Mdot
.24286 .26891 Mdot
.24762 .05797 Mdot
.25238 .11901 Mdot
.25714 .06076 Mdot
.2619 .12204 Mdot
.26667 .14605 Mdot
.27143 .27711 Mdot
.27619 .06375 Mdot
.28095 .12798 Mdot
.28571 .47359 Mdot
.29048 .04481 Mdot
.29524 .05843 Mdot
.3 .06093 Mdot
.30476 .23603 Mdot
.30952 .06425 Mdot
.31429 .09626 Mdot
.31905 .15602 Mdot
.32381 .27546 Mdot
.32857 .18885 Mdot
.33333 .04752 Mdot
.3381 .06733 Mdot
.34286 .05764 Mdot
.34762 .07081 Mdot
.35238 .2267 Mdot
.35714 .04366 Mdot
.3619 .279 Mdot
.36667 .10104 Mdot
.37143 .04264 Mdot
.37619 .24875 Mdot
.38095 .24928 Mdot
.38571 .22512 Mdot
.39048 .18015 Mdot
.39524 .34004 Mdot
.4 .03835 Mdot
.40476 .04552 Mdot
.40952 .08195 Mdot
.41429 .06358 Mdot
.41905 .06064 Mdot
.42381 .0413 Mdot
.42857 .21411 Mdot
.43333 .29905 Mdot
.4381 .27478 Mdot
.44286 .17949 Mdot
.44762 .07179 Mdot
.45238 .21374 Mdot
.45714 .04596 Mdot
.4619 .01688 Mdot
.46667 .09786 Mdot
.47143 .17503 Mdot
.47619 .41891 Mdot
.48095 .04076 Mdot
.48571 .41055 Mdot
.49048 .4192 Mdot
.49524 .02413 Mdot
.5 .06185 Mdot
.50476 .5204 Mdot
.50952 .17034 Mdot
.51429 .05096 Mdot
.51905 .28009 Mdot
.52381 .34021 Mdot
.52857 .33337 Mdot
.53333 .11661 Mdot
.5381 .03785 Mdot
.54286 .16393 Mdot
.54762 .19893 Mdot
.55238 .10481 Mdot
.55714 .05479 Mdot
.5619 .05947 Mdot
.56667 .12412 Mdot
.57143 .15182 Mdot
.57619 .12183 Mdot
.58095 .11101 Mdot
.58571 .11646 Mdot
.59048 .0807 Mdot
.59524 .03964 Mdot
.6 .04593 Mdot
.60476 .10771 Mdot
.60952 .14018 Mdot
.61429 .08645 Mdot
.61905 .21934 Mdot
.62381 .07091 Mdot
.62857 .42909 Mdot
.63333 .07915 Mdot
.6381 .15132 Mdot
.64286 .0788 Mdot
.64762 .09506 Mdot
.65238 .06585 Mdot
.65714 .12941 Mdot
.6619 .21657 Mdot
.66667 .57964 Mdot
.67143 .0447 Mdot
.67619 .13895 Mdot
.68095 .28953 Mdot
.68571 .10437 Mdot
.69048 .30887 Mdot
.69524 .16941 Mdot
.7 .16476 Mdot
.70476 .30783 Mdot
.70952 .22634 Mdot
.71429 .02786 Mdot
.71905 .21113 Mdot
.72381 .03905 Mdot
.72857 .06829 Mdot
.73333 .11434 Mdot
.7381 .49707 Mdot
.74286 .12891 Mdot
.74762 .11112 Mdot
.75238 .13925 Mdot
.75714 .17394 Mdot
.7619 .00626 Mdot
.76667 .49115 Mdot
.77143 .14474 Mdot
.77619 .08585 Mdot
.78095 .09813 Mdot
.78571 .18468 Mdot
.79048 .00409 Mdot
.79524 .04835 Mdot
.8 .00211 Mdot
.80476 .02795 Mdot
.80952 .2635 Mdot
.81429 .16306 Mdot
.81905 .13468 Mdot
.82381 .27285 Mdot
.82857 .14073 Mdot
.83333 .0709 Mdot
.8381 .11292 Mdot
.84286 .17995 Mdot
.84762 .23715 Mdot
.85238 .16724 Mdot
.8619 .25416 Mdot
.86667 .04265 Mdot
.87143 .08706 Mdot
.87619 .06184 Mdot
.88095 .13659 Mdot
.88571 .48638 Mdot
.89048 .06179 Mdot
.89524 .20372 Mdot
.9 .31214 Mdot
.90476 .36122 Mdot
.90952 .25954 Mdot
.91429 .09846 Mdot
.91905 .26666 Mdot
.92381 .44093 Mdot
.92857 .0266 Mdot
.93333 .12521 Mdot
.9381 .07313 Mdot
.94286 .27609 Mdot
.94762 .14724 Mdot
.95238 .29571 Mdot
.95714 .11537 Mdot
.9619 .18702 Mdot
.96667 .46434 Mdot
.97143 .0418 Mdot
.97619 .18028 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .28429 Mdot
.03333 .05319 Mdot
.0381 .34153 Mdot
.04286 .19558 Mdot
.04762 .17649 Mdot
.05238 .03081 Mdot
.05714 .07527 Mdot
.0619 .04926 Mdot
.06667 .11268 Mdot
.07143 .16151 Mdot
.07619 .05694 Mdot
.08095 .15962 Mdot
.08571 .03402 Mdot
.09048 .44773 Mdot
.09524 .34383 Mdot
.1 .12917 Mdot
.10476 .18068 Mdot
.10952 .31228 Mdot
.11429 .23367 Mdot
.11905 .31923 Mdot
.12381 .09642 Mdot
.12857 .16199 Mdot
.13333 .22776 Mdot
.1381 .02718 Mdot
.14286 .0915 Mdot
.14762 .07763 Mdot
.15238 .15616 Mdot
.15714 .21533 Mdot
.1619 .11198 Mdot
.16667 .01602 Mdot
.17143 .03666 Mdot
.17619 .45552 Mdot
.18095 .15456 Mdot
.18571 .14645 Mdot
.19048 .40765 Mdot
.19524 .03371 Mdot
.2 .07765 Mdot
.20476 .10624 Mdot
.20952 .18479 Mdot
.21429 .0429 Mdot
.21905 .08439 Mdot
.22381 .2081 Mdot
.22857 .08995 Mdot
.23333 .08989 Mdot
.2381 .01335 Mdot
.24286 .26453 Mdot
.24762 .09071 Mdot
.25238 .14386 Mdot
.25714 .01981 Mdot
.2619 .14048 Mdot
.26667 .20219 Mdot
.27143 .25438 Mdot
.27619 .05307 Mdot
.28095 .12277 Mdot
.28571 .38932 Mdot
.29048 .02666 Mdot
.29524 .07129 Mdot
.3 .04643 Mdot
.30476 .19119 Mdot
.30952 .09247 Mdot
.31429 .08585 Mdot
.31905 .15599 Mdot
.32381 .33463 Mdot
.32857 .20867 Mdot
.33333 .03545 Mdot
.3381 .08896 Mdot
.34286 .05526 Mdot
.34762 .07485 Mdot
.35238 .23679 Mdot
.35714 .01027 Mdot
.3619 .32114 Mdot
.36667 .01122 Mdot
.37143 .02676 Mdot
.37619 .21809 Mdot
.38095 .25173 Mdot
.38571 .21042 Mdot
.39048 .08761 Mdot
.39524 .36609 Mdot
.4 .01434 Mdot
.40476 .08813 Mdot
.40952 .11525 Mdot
.41429 .09346 Mdot
.41905 .02896 Mdot
.42381 .03275 Mdot
.42857 .14551 Mdot
.43333 .3105 Mdot
.4381 .28999 Mdot
.44286 .15122 Mdot
.44762 .06856 Mdot
.45238 .19985 Mdot
.45714 .06717 Mdot
.4619 .07342 Mdot
.46667 .04277 Mdot
.47143 .11754 Mdot
.47619 .32476 Mdot
.48095 .12165 Mdot
.48571 .44378 Mdot
.49048 .3714 Mdot
.49524 .12303 Mdot
.5 .04971 Mdot
.50476 .48786 Mdot
.50952 .22431 Mdot
.51429 .06238 Mdot
.51905 .30383 Mdot
.52381 .31882 Mdot
.52857 .30468 Mdot
.53333 .21544 Mdot
.5381 .0158 Mdot
.54286 .15797 Mdot
.54762 .20919 Mdot
.55238 .0676 Mdot
.55714 .0623 Mdot
.5619 .0969 Mdot
.56667 .14109 Mdot
.57143 .13501 Mdot
.57619 .17367 Mdot
.58095 .11816 Mdot
.58571 .15768 Mdot
.59048 .12502 Mdot
.59524 .01699 Mdot
.6 .08989 Mdot
.60476 .17535 Mdot
.60952 .10571 Mdot
.61429 .14706 Mdot
.61905 .18065 Mdot
.62381 .08396 Mdot
.62857 .4064 Mdot
.63333 .02362 Mdot
.6381 .15307 Mdot
.64286 .11053 Mdot
.64762 .04451 Mdot
.65238 .02263 Mdot
.65714 .09082 Mdot
.6619 .25556 Mdot
.67143 .09807 Mdot
.67619 .19162 Mdot
.68095 .26556 Mdot
.68571 .11059 Mdot
.69048 .30792 Mdot
.69524 .22065 Mdot
.7 .15986 Mdot
.70476 .25448 Mdot
.70952 .19507 Mdot
.71429 .08727 Mdot
.71905 .16725 Mdot
.72381 .05495 Mdot
.72857 .06069 Mdot
.73333 .13834 Mdot
.7381 .41439 Mdot
.74286 .17499 Mdot
.74762 .1164 Mdot
.75238 .14705 Mdot
.75714 .0822 Mdot
.7619 .04643 Mdot
.76667 .50357 Mdot
.77143 .20257 Mdot
.77619 .05084 Mdot
.78095 .10031 Mdot
.78571 .25257 Mdot
.79048 .06712 Mdot
.79524 .00762 Mdot
.8 .05116 Mdot
.80476 .06939 Mdot
.80952 .16197 Mdot
.81429 .20911 Mdot
.81905 .10624 Mdot
.82381 .19986 Mdot
.82857 .19188 Mdot
.83333 .10565 Mdot
.8381 .0686 Mdot
.84286 .18592 Mdot
.84762 .15564 Mdot
.85238 .21113 Mdot
.8619 .19637 Mdot
.86667 .10081 Mdot
.87143 .13443 Mdot
.87619 .03297 Mdot
.88095 .13619 Mdot
.88571 .49319 Mdot
.89048 .12664 Mdot
.89524 .17025 Mdot
.9 .33577 Mdot
.90476 .30214 Mdot
.90952 .281 Mdot
.91429 .14139 Mdot
.91905 .24928 Mdot
.92381 .38499 Mdot
.92857 .04867 Mdot
.93333 .19248 Mdot
.9381 .03785 Mdot
.94286 .30626 Mdot
.94762 .13981 Mdot
.95238 .31869 Mdot
.95714 .13961 Mdot
.9619 .11504 Mdot
.96667 .47638 Mdot
.97143 .02336 Mdot
.97619 .24421 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23373 Mdot
.03333 .11866 Mdot
.0381 .38182 Mdot
.04286 .18711 Mdot
.04762 .15829 Mdot
.05238 .00542 Mdot
.05714 .04817 Mdot
.0619 .09503 Mdot
.06667 .08779 Mdot
.07143 .12841 Mdot
.07619 .13523 Mdot
.08095 .17862 Mdot
.08571 .0376 Mdot
.09048 .43778 Mdot
.09524 .31608 Mdot
.1 .04203 Mdot
.10476 .21446 Mdot
.10952 .33469 Mdot
.11429 .25089 Mdot
.11905 .37475 Mdot
.12381 .16505 Mdot
.12857 .14955 Mdot
.13333 .20678 Mdot
.1381 .07619 Mdot
.14286 .08189 Mdot
.14762 .06447 Mdot
.15238 .1625 Mdot
.15714 .15903 Mdot
.1619 .05823 Mdot
.16667 .09071 Mdot
.17143 .0727 Mdot
.17619 .45752 Mdot
.18095 .21581 Mdot
.18571 .14669 Mdot
.19048 .47579 Mdot
.19524 .08682 Mdot
.2 .02313 Mdot
.20476 .02932 Mdot
.20952 .16728 Mdot
.21429 .08539 Mdot
.21905 .15685 Mdot
.22381 .17004 Mdot
.22857 .06676 Mdot
.23333 .06233 Mdot
.2381 .01142 Mdot
.24286 .28369 Mdot
.24762 .06428 Mdot
.25238 .17091 Mdot
.25714 .06128 Mdot
.2619 .18366 Mdot
.26667 .13418 Mdot
.27143 .24208 Mdot
.27619 .10291 Mdot
.28095 .06776 Mdot
.28571 .39688 Mdot
.29048 .05371 Mdot
.29524 .02224 Mdot
.3 .03612 Mdot
.30476 .16484 Mdot
.30952 .07954 Mdot
.31429 .07724 Mdot
.31905 .21941 Mdot
.32381 .35115 Mdot
.32857 .16663 Mdot
.33333 .05252 Mdot
.3381 .05824 Mdot
.34286 .07739 Mdot
.34762 .10154 Mdot
.35238 .19775 Mdot
.35714 .01329 Mdot
.3619 .39431 Mdot
.36667 .00452 Mdot
.37143 .05732 Mdot
.37619 .22983 Mdot
.38095 .25716 Mdot
.38571 .29147 Mdot
.39048 .03991 Mdot
.39524 .32635 Mdot
.4 .14121 Mdot
.40476 .08064 Mdot
.40952 .11622 Mdot
.41429 .05877 Mdot
.41905 .00473 Mdot
.42381 .03073 Mdot
.42857 .17113 Mdot
.43333 .33046 Mdot
.4381 .20129 Mdot
.44286 .10551 Mdot
.44762 .04075 Mdot
.45238 .15346 Mdot
.45714 .06835 Mdot
.4619 .09298 Mdot
.46667 .03451 Mdot
.47143 .15366 Mdot
.47619 .29778 Mdot
.48095 .05703 Mdot
.48571 .41018 Mdot
.49048 .3898 Mdot
.49524 .13117 Mdot
.5 .05336 Mdot
.50476 .48798 Mdot
.50952 .22287 Mdot
.51429 .03953 Mdot
.51905 .34228 Mdot
.52381 .27754 Mdot
.52857 .24421 Mdot
.53333 .19437 Mdot
.5381 .02887 Mdot
.54286 .10668 Mdot
.54762 .13989 Mdot
.55238 .06134 Mdot
.55714 .07178 Mdot
.5619 .06488 Mdot
.56667 .09232 Mdot
.57143 .18112 Mdot
.57619 .13154 Mdot
.58095 .18957 Mdot
.58571 .08998 Mdot
.59048 .10227 Mdot
.59524 .06069 Mdot
.6 .10383 Mdot
.60476 .23167 Mdot
.60952 .09953 Mdot
.61429 .10622 Mdot
.61905 .24111 Mdot
.62381 .03137 Mdot
.62857 .42517 Mdot
.63333 .13128 Mdot
.6381 .10856 Mdot
.64286 .08636 Mdot
.64762 .03077 Mdot
.65238 .03915 Mdot
.65714 .12906 Mdot
.6619 .25537 Mdot
.66667 .57432 Mdot
.67143 .11125 Mdot
.67619 .17769 Mdot
.68095 .29441 Mdot
.68571 .11322 Mdot
.69048 .27596 Mdot
.69524 .22819 Mdot
.7 .16101 Mdot
.70476 .2929 Mdot
.70952 .22177 Mdot
.71429 .14237 Mdot
.71905 .16923 Mdot
.72381 .05193 Mdot
.72857 .08712 Mdot
.73333 .06252 Mdot
.7381 .42638 Mdot
.74286 .1566 Mdot
.74762 .09923 Mdot
.75238 .16151 Mdot
.75714 .07548 Mdot
.7619 .06984 Mdot
.76667 .43074 Mdot
.77143 .19236 Mdot
.77619 .01688 Mdot
.78095 .07342 Mdot
.78571 .21126 Mdot
.79048 .06161 Mdot
.79524 .01313 Mdot
.8 .07704 Mdot
.80476 .01379 Mdot
.80952 .22213 Mdot
.81429 .16597 Mdot
.81905 .11218 Mdot
.82381 .15013 Mdot
.82857 .24977 Mdot
.83333 .00989 Mdot
.8381 .05191 Mdot
.84286 .16873 Mdot
.84762 .11816 Mdot
.85238 .18054 Mdot
.8619 .17376 Mdot
.86667 .15621 Mdot
.87143 .12908 Mdot
.87619 .02932 Mdot
.88095 .12692 Mdot
.88571 .51681 Mdot
.89048 .11269 Mdot
.89524 .22009 Mdot
.9 .33819 Mdot
.90476 .31947 Mdot
.90952 .23684 Mdot
.91429 .09063 Mdot
.91905 .226 Mdot
.92381 .31276 Mdot
.92857 .08107 Mdot
.93333 .19227 Mdot
.9381 .08961 Mdot
.94286 .29331 Mdot
.94762 .11237 Mdot
.95238 .27006 Mdot
.95714 .05132 Mdot
.9619 .18574 Mdot
.96667 .50664 Mdot
.97143 .07059 Mdot
.97619 .19002 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .18614 Mdot
.03333 .05356 Mdot
.0381 .35168 Mdot
.04286 .1435 Mdot
.04762 .11836 Mdot
.05238 .02772 Mdot
.05714 .06378 Mdot
.0619 .10744 Mdot
.06667 .07832 Mdot
.07143 .1474 Mdot
.07619 .07574 Mdot
.08095 .18703 Mdot
.08571 .08263 Mdot
.09048 .43852 Mdot
.09524 .28419 Mdot
.1 .10194 Mdot
.10476 .28393 Mdot
.10952 .30603 Mdot
.11429 .2708 Mdot
.11905 .3717 Mdot
.12381 .19078 Mdot
.12857 .14287 Mdot
.13333 .16705 Mdot
.1381 .13093 Mdot
.14286 .07426 Mdot
.14762 .05839 Mdot
.15238 .17641 Mdot
.15714 .13705 Mdot
.1619 .03728 Mdot
.16667 .11884 Mdot
.17143 .15538 Mdot
.17619 .49386 Mdot
.18095 .22842 Mdot
.18571 .11573 Mdot
.19048 .44026 Mdot
.19524 .01034 Mdot
.2 .09835 Mdot
.20476 .13146 Mdot
.20952 .16396 Mdot
.21429 .14876 Mdot
.21905 .10723 Mdot
.22381 .08947 Mdot
.22857 .03071 Mdot
.23333 .01015 Mdot
.2381 .03047 Mdot
.24286 .27892 Mdot
.24762 .0914 Mdot
.25238 .15444 Mdot
.25714 .04395 Mdot
.2619 .10113 Mdot
.26667 .18199 Mdot
.27143 .2471 Mdot
.27619 .14316 Mdot
.28095 .08391 Mdot
.28571 .32539 Mdot
.29048 .09179 Mdot
.29524 .07707 Mdot
.3 .05569 Mdot
.30476 .22154 Mdot
.30952 .08246 Mdot
.31429 .11074 Mdot
.31905 .19534 Mdot
.32381 .31385 Mdot
.32857 .12371 Mdot
.33333 .0322 Mdot
.3381 .04745 Mdot
.34286 .04404 Mdot
.34762 .12852 Mdot
.35238 .17017 Mdot
.35714 .08839 Mdot
.3619 .35733 Mdot
.36667 .10708 Mdot
.37143 .08816 Mdot
.37619 .1841 Mdot
.38095 .25023 Mdot
.38571 .28708 Mdot
.39048 .09067 Mdot
.39524 .35655 Mdot
.4 .17282 Mdot
.40476 .00858 Mdot
.40952 .1986 Mdot
.41429 .08221 Mdot
.41905 .08348 Mdot
.42381 .08279 Mdot
.42857 .12174 Mdot
.43333 .27645 Mdot
.4381 .18499 Mdot
.44286 .14429 Mdot
.44762 .05858 Mdot
.45238 .09472 Mdot
.45714 .05364 Mdot
.4619 .17065 Mdot
.46667 .05984 Mdot
.47143 .10001 Mdot
.47619 .26612 Mdot
.48095 .06389 Mdot
.48571 .4661 Mdot
.49048 .38159 Mdot
.49524 .08457 Mdot
.5 .0665 Mdot
.50476 .44505 Mdot
.50952 .15392 Mdot
.51429 .00988 Mdot
.51905 .26703 Mdot
.52381 .31624 Mdot
.52857 .19682 Mdot
.53333 .21728 Mdot
.5381 .09016 Mdot
.54286 .09127 Mdot
.54762 .0485 Mdot
.55238 .05559 Mdot
.55714 .04535 Mdot
.5619 .04169 Mdot
.56667 .01583 Mdot
.57143 .1124 Mdot
.57619 .11892 Mdot
.58095 .22704 Mdot
.58571 .10172 Mdot
.59048 .10726 Mdot
.59524 .08493 Mdot
.6 .10615 Mdot
.60476 .21389 Mdot
.60952 .08534 Mdot
.61429 .13474 Mdot
.61905 .20572 Mdot
.62381 .06754 Mdot
.62857 .33755 Mdot
.63333 .04374 Mdot
.6381 .0347 Mdot
.64286 .12006 Mdot
.64762 .04608 Mdot
.65238 .06415 Mdot
.65714 .11009 Mdot
.6619 .1827 Mdot
.66667 .57726 Mdot
.67143 .11861 Mdot
.67619 .23163 Mdot
.68095 .3129 Mdot
.68571 .13098 Mdot
.69048 .24073 Mdot
.69524 .16019 Mdot
.7 .21651 Mdot
.70476 .30505 Mdot
.70952 .21311 Mdot
.71429 .18106 Mdot
.71905 .15637 Mdot
.72381 .02897 Mdot
.72857 .07009 Mdot
.73333 .06513 Mdot
.7381 .43675 Mdot
.74286 .16444 Mdot
.74762 .13075 Mdot
.75238 .12751 Mdot
.75714 .04332 Mdot
.7619 .09882 Mdot
.76667 .52768 Mdot
.77143 .25037 Mdot
.77619 .01865 Mdot
.78095 .02605 Mdot
.78571 .20701 Mdot
.79048 .0048 Mdot
.79524 .08107 Mdot
.8 .00104 Mdot
.80476 .02484 Mdot
.80952 .18873 Mdot
.81429 .24699 Mdot
.81905 .17831 Mdot
.82381 .1064 Mdot
.82857 .26181 Mdot
.83333 .04134 Mdot
.8381 .08525 Mdot
.84286 .11718 Mdot
.84762 .1252 Mdot
.85238 .18584 Mdot
.85714 .56474 Mdot
.8619 .18962 Mdot
.86667 .24226 Mdot
.87143 .17896 Mdot
.87619 .08619 Mdot
.88095 .13776 Mdot
.88571 .44517 Mdot
.89048 .0817 Mdot
.89524 .14978 Mdot
.9 .39152 Mdot
.90476 .26575 Mdot
.90952 .23038 Mdot
.91429 .03877 Mdot
.91905 .23914 Mdot
.92381 .29946 Mdot
.92857 .02682 Mdot
.93333 .12204 Mdot
.9381 .12634 Mdot
.94286 .35296 Mdot
.94762 .09687 Mdot
.95238 .23851 Mdot
.95714 .06266 Mdot
.9619 .21301 Mdot
.96667 .55517 Mdot
.97143 .07094 Mdot
.97619 .21471 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .2049 Mdot
.03333 .00443 Mdot
.0381 .30285 Mdot
.04286 .17979 Mdot
.04762 .09822 Mdot
.05238 .04871 Mdot
.05714 .06057 Mdot
.0619 .09198 Mdot
.06667 .04157 Mdot
.07143 .17877 Mdot
.07619 .02383 Mdot
.08095 .1804 Mdot
.08571 .05157 Mdot
.09048 .3706 Mdot
.09524 .32528 Mdot
.1 .03614 Mdot
.10476 .35336 Mdot
.10952 .2791 Mdot
.11429 .23431 Mdot
.11905 .32103 Mdot
.12381 .24851 Mdot
.12857 .12703 Mdot
.13333 .22706 Mdot
.1381 .11187 Mdot
.14286 .11235 Mdot
.14762 .04632 Mdot
.15238 .16078 Mdot
.15714 .12496 Mdot
.1619 .07159 Mdot
.16667 .13849 Mdot
.17143 .17169 Mdot
.17619 .44694 Mdot
.18095 .23084 Mdot
.18571 .12767 Mdot
.19048 .40923 Mdot
.19524 .05337 Mdot
.2 .16389 Mdot
.20476 .15531 Mdot
.20952 .135 Mdot
.21429 .19427 Mdot
.21905 .14218 Mdot
.22381 .09873 Mdot
.22857 .03139 Mdot
.23333 .04548 Mdot
.2381 .05972 Mdot
.24286 .24094 Mdot
.24762 .03216 Mdot
.25238 .19282 Mdot
.25714 .07705 Mdot
.2619 .18484 Mdot
.26667 .15392 Mdot
.27143 .27286 Mdot
.27619 .1235 Mdot
.28095 .10434 Mdot
.28571 .25721 Mdot
.29048 .01963 Mdot
.29524 .06518 Mdot
.3 .02463 Mdot
.30476 .25248 Mdot
.30952 .09977 Mdot
.31429 .07226 Mdot
.31905 .13162 Mdot
.32381 .23966 Mdot
.32857 .14452 Mdot
.33333 .1336 Mdot
.3381 .03221 Mdot
.34286 .03762 Mdot
.34762 .12249 Mdot
.35238 .16068 Mdot
.35714 .13326 Mdot
.3619 .3406 Mdot
.36667 .09407 Mdot
.37143 .04329 Mdot
.37619 .21955 Mdot
.38095 .20809 Mdot
.38571 .28248 Mdot
.39048 .09387 Mdot
.39524 .34434 Mdot
.4 .13373 Mdot
.40476 .0103 Mdot
.40952 .15188 Mdot
.41429 .07039 Mdot
.41905 .0707 Mdot
.42381 .06216 Mdot
.42857 .13065 Mdot
.43333 .26221 Mdot
.4381 .23703 Mdot
.44286 .14113 Mdot
.44762 .10837 Mdot
.45238 .14415 Mdot
.45714 .07003 Mdot
.4619 .23408 Mdot
.46667 .02119 Mdot
.47143 .06927 Mdot
.47619 .29689 Mdot
.48095 .05938 Mdot
.48571 .45558 Mdot
.49048 .41355 Mdot
.49524 .07748 Mdot
.5 .05771 Mdot
.50476 .38119 Mdot
.50952 .15878 Mdot
.51429 .06742 Mdot
.51905 .19006 Mdot
.52381 .31472 Mdot
.52857 .17272 Mdot
.53333 .22391 Mdot
.5381 .16695 Mdot
.54286 .07756 Mdot
.54762 .08943 Mdot
.55238 .09383 Mdot
.55714 .02603 Mdot
.5619 .05726 Mdot
.56667 .09259 Mdot
.57143 .05349 Mdot
.57619 .08232 Mdot
.58095 .23753 Mdot
.58571 .04807 Mdot
.59048 .04956 Mdot
.59524 .08984 Mdot
.6 .11321 Mdot
.60476 .11882 Mdot
.60952 .08404 Mdot
.61429 .1244 Mdot
.61905 .16716 Mdot
.62381 .10251 Mdot
.62857 .32353 Mdot
.63333 .01597 Mdot
.6381 .08685 Mdot
.64286 .06492 Mdot
.64762 .03835 Mdot
.65238 .01673 Mdot
.65714 .17368 Mdot
.6619 .13546 Mdot
.66667 .59103 Mdot
.67143 .08319 Mdot
.67619 .17658 Mdot
.68095 .27788 Mdot
.68571 .10895 Mdot
.69048 .23744 Mdot
.69524 .1213 Mdot
.7 .16625 Mdot
.70476 .29294 Mdot
.70952 .20244 Mdot
.71429 .16285 Mdot
.71905 .1846 Mdot
.72381 .04645 Mdot
.72857 .09742 Mdot
.73333 .04352 Mdot
.7381 .43259 Mdot
.74286 .13112 Mdot
.74762 .19888 Mdot
.75238 .10192 Mdot
.75714 .02295 Mdot
.7619 .09577 Mdot
.76667 .52799 Mdot
.77143 .16927 Mdot
.77619 .03744 Mdot
.78095 .07635 Mdot
.78571 .19006 Mdot
.79048 .08669 Mdot
.79524 .06009 Mdot
.8 .04379 Mdot
.80476 .01898 Mdot
.80952 .16225 Mdot
.81429 .26223 Mdot
.81905 .17698 Mdot
.82381 .07925 Mdot
.82857 .26668 Mdot
.83333 .05029 Mdot
.8381 .04281 Mdot
.84286 .10791 Mdot
.84762 .18916 Mdot
.85238 .13968 Mdot
.85714 .50534 Mdot
.8619 .17966 Mdot
.86667 .18754 Mdot
.87143 .20989 Mdot
.87619 .03474 Mdot
.88095 .1298 Mdot
.88571 .46429 Mdot
.89048 .07923 Mdot
.89524 .20697 Mdot
.9 .40511 Mdot
.90476 .33192 Mdot
.90952 .18089 Mdot
.91429 .06373 Mdot
.91905 .16936 Mdot
.92381 .31022 Mdot
.92857 .04522 Mdot
.93333 .09397 Mdot
.9381 .13384 Mdot
.94286 .30487 Mdot
.94762 .09699 Mdot
.95238 .2873 Mdot
.95714 .1044 Mdot
.9619 .13609 Mdot
.96667 .55684 Mdot
.97143 .08559 Mdot
.97619 .18834 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .16018 Mdot
.03333 .04777 Mdot
.0381 .24217 Mdot
.04286 .15304 Mdot
.04762 .05663 Mdot
.05238 .11442 Mdot
.05714 .07016 Mdot
.0619 .14586 Mdot
.06667 .09053 Mdot
.07143 .09167 Mdot
.07619 .01842 Mdot
.08095 .11559 Mdot
.08571 .09257 Mdot
.09048 .28598 Mdot
.09524 .3186 Mdot
.1 .03862 Mdot
.10476 .37863 Mdot
.10952 .28708 Mdot
.11429 .22946 Mdot
.11905 .29339 Mdot
.12381 .237 Mdot
.12857 .18787 Mdot
.13333 .18099 Mdot
.1381 .06354 Mdot
.14286 .14342 Mdot
.14762 .08155 Mdot
.15238 .15894 Mdot
.15714 .11468 Mdot
.1619 .03542 Mdot
.16667 .05045 Mdot
.17143 .12443 Mdot
.17619 .46708 Mdot
.18095 .23587 Mdot
.18571 .0921 Mdot
.19048 .3345 Mdot
.19524 .13385 Mdot
.2 .09589 Mdot
.20476 .18802 Mdot
.20952 .11388 Mdot
.21429 .1517 Mdot
.21905 .09399 Mdot
.22381 .12076 Mdot
.22857 .08329 Mdot
.23333 .027 Mdot
.2381 .13186 Mdot
.24286 .24647 Mdot
.24762 .05997 Mdot
.25238 .24384 Mdot
.25714 .05267 Mdot
.2619 .14215 Mdot
.26667 .09384 Mdot
.27143 .25457 Mdot
.27619 .22049 Mdot
.28095 .08826 Mdot
.28571 .17567 Mdot
.29048 .11327 Mdot
.29524 .06879 Mdot
.3 .06961 Mdot
.30476 .22524 Mdot
.30952 .06633 Mdot
.31429 .11267 Mdot
.31905 .10531 Mdot
.32381 .16998 Mdot
.32857 .10369 Mdot
.33333 .12533 Mdot
.3381 .07952 Mdot
.34286 .0307 Mdot
.34762 .1424 Mdot
.35238 .13948 Mdot
.35714 .14879 Mdot
.3619 .31378 Mdot
.36667 .13513 Mdot
.37143 .06957 Mdot
.37619 .19126 Mdot
.38095 .20077 Mdot
.38571 .29042 Mdot
.39048 .12675 Mdot
.39524 .34892 Mdot
.4 .09528 Mdot
.40476 .08138 Mdot
.40952 .21161 Mdot
.41429 .06811 Mdot
.41905 .03245 Mdot
.42381 .08621 Mdot
.42857 .05624 Mdot
.43333 .18576 Mdot
.4381 .20962 Mdot
.44286 .13929 Mdot
.44762 .10964 Mdot
.45238 .07933 Mdot
.45714 .00091 Mdot
.4619 .1626 Mdot
.46667 .04596 Mdot
.47143 .07416 Mdot
.47619 .30337 Mdot
.48095 .02447 Mdot
.48571 .45979 Mdot
.49048 .40687 Mdot
.49524 .12167 Mdot
.5 .09142 Mdot
.50476 .38768 Mdot
.50952 .18501 Mdot
.51429 .08778 Mdot
.51905 .13011 Mdot
.52381 .3649 Mdot
.52857 .24074 Mdot
.53333 .26808 Mdot
.5381 .23513 Mdot
.54286 .06568 Mdot
.54762 .11432 Mdot
.55238 .03743 Mdot
.55714 .09711 Mdot
.5619 .06719 Mdot
.56667 .08809 Mdot
.57143 .12355 Mdot
.57619 .09688 Mdot
.58095 .26147 Mdot
.58571 .02174 Mdot
.59048 .07323 Mdot
.59524 .08922 Mdot
.6 .06063 Mdot
.60476 .067 Mdot
.60952 .07585 Mdot
.61429 .17564 Mdot
.61905 .2154 Mdot
.62381 .04342 Mdot
.62857 .26899 Mdot
.63333 .12459 Mdot
.6381 .0649 Mdot
.64286 .06828 Mdot
.64762 .06155 Mdot
.65238 .10055 Mdot
.65714 .1367 Mdot
.6619 .08913 Mdot
.66667 .60369 Mdot
.67143 .04416 Mdot
.67619 .12055 Mdot
.68095 .23315 Mdot
.68571 .05427 Mdot
.69048 .22337 Mdot
.69524 .06522 Mdot
.7 .10445 Mdot
.70476 .23086 Mdot
.70952 .15481 Mdot
.71429 .12892 Mdot
.71905 .22504 Mdot
.72381 .07189 Mdot
.72857 .03454 Mdot
.73333 .05744 Mdot
.7381 .39362 Mdot
.74286 .19793 Mdot
.74762 .14101 Mdot
.75238 .07466 Mdot
.75714 .09825 Mdot
.7619 .04422 Mdot
.76667 .48927 Mdot
.77143 .1625 Mdot
.77619 .00372 Mdot
.78095 .04424 Mdot
.78571 .21348 Mdot
.79048 .14524 Mdot
.79524 .11776 Mdot
.8 .05247 Mdot
.80476 .08774 Mdot
.80952 .20255 Mdot
.81429 .23143 Mdot
.81905 .09669 Mdot
.82381 .11248 Mdot
.82857 .23944 Mdot
.83333 .11478 Mdot
.8381 .12044 Mdot
.84286 .129 Mdot
.84762 .18722 Mdot
.85238 .09706 Mdot
.85714 .50308 Mdot
.8619 .17641 Mdot
.86667 .12088 Mdot
.87143 .1966 Mdot
.87619 .10256 Mdot
.88095 .13506 Mdot
.88571 .48738 Mdot
.89048 .13324 Mdot
.89524 .20969 Mdot
.9 .37806 Mdot
.90476 .29789 Mdot
.90952 .13602 Mdot
.91429 .0468 Mdot
.91905 .10116 Mdot
.92381 .33334 Mdot
.92857 .05447 Mdot
.93333 .16278 Mdot
.9381 .1491 Mdot
.94286 .33436 Mdot
.94762 .05344 Mdot
.95238 .30278 Mdot
.95714 .10011 Mdot
.9619 .16254 Mdot
.96667 .52789 Mdot
.97143 .04226 Mdot
.97619 .2013 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .11068 Mdot
.03333 .09759 Mdot
.0381 .27094 Mdot
.04286 .21378 Mdot
.04762 .10127 Mdot
.05238 .13889 Mdot
.05714 .13465 Mdot
.0619 .15473 Mdot
.06667 .03445 Mdot
.07143 .08431 Mdot
.07619 .06757 Mdot
.08095 .08139 Mdot
.08571 .01457 Mdot
.09048 .32267 Mdot
.09524 .23017 Mdot
.1 .08866 Mdot
.10476 .37425 Mdot
.10952 .2825 Mdot
.11429 .19184 Mdot
.11905 .2484 Mdot
.12381 .14342 Mdot
.12857 .21352 Mdot
.13333 .1161 Mdot
.1381 .07564 Mdot
.14286 .15278 Mdot
.14762 .01735 Mdot
.15238 .14621 Mdot
.15714 .05108 Mdot
.1619 .07546 Mdot
.16667 .00983 Mdot
.17143 .03322 Mdot
.17619 .47422 Mdot
.18095 .18077 Mdot
.18571 .06594 Mdot
.19048 .40006 Mdot
.19524 .18081 Mdot
.2 .1607 Mdot
.20476 .19608 Mdot
.20952 .08552 Mdot
.21429 .15297 Mdot
.21905 .02679 Mdot
.22381 .08929 Mdot
.22857 .09088 Mdot
.23333 .06768 Mdot
.2381 .13884 Mdot
.24286 .22042 Mdot
.24762 .05246 Mdot
.25238 .24612 Mdot
.25714 .08244 Mdot
.2619 .10309 Mdot
.26667 .0734 Mdot
.27143 .16645 Mdot
.27619 .13378 Mdot
.28095 .06254 Mdot
.28571 .13089 Mdot
.29048 .20681 Mdot
.29524 .01364 Mdot
.3 .09385 Mdot
.30476 .17018 Mdot
.30952 .02507 Mdot
.31429 .05206 Mdot
.31905 .03969 Mdot
.32381 .14413 Mdot
.32857 .10824 Mdot
.33333 .0681 Mdot
.3381 .08819 Mdot
.34286 .05453 Mdot
.34762 .09737 Mdot
.35238 .15085 Mdot
.35714 .17076 Mdot
.3619 .31506 Mdot
.36667 .07098 Mdot
.37143 .09937 Mdot
.37619 .18496 Mdot
.38095 .22309 Mdot
.38571 .21006 Mdot
.39048 .16018 Mdot
.39524 .36561 Mdot
.4 .11783 Mdot
.40476 .14394 Mdot
.40952 .22415 Mdot
.41429 .05787 Mdot
.41905 .02701 Mdot
.42381 .02243 Mdot
.42857 .0343 Mdot
.43333 .19327 Mdot
.4381 .17241 Mdot
.44286 .23599 Mdot
.44762 .00758 Mdot
.45238 .11641 Mdot
.45714 .07937 Mdot
.4619 .18633 Mdot
.46667 .01145 Mdot
.47143 .07709 Mdot
.47619 .31645 Mdot
.48095 .02381 Mdot
.48571 .44474 Mdot
.49048 .48907 Mdot
.49524 .11602 Mdot
.5 .08395 Mdot
.50476 .3244 Mdot
.50952 .17651 Mdot
.51429 .13549 Mdot
.51905 .14802 Mdot
.52381 .32805 Mdot
.52857 .2735 Mdot
.53333 .30342 Mdot
.5381 .28085 Mdot
.54286 .02804 Mdot
.54762 .13691 Mdot
.55238 .00773 Mdot
.55714 .04304 Mdot
.5619 .0461 Mdot
.56667 .12408 Mdot
.57143 .07157 Mdot
.57619 .07055 Mdot
.58095 .27935 Mdot
.58571 .01189 Mdot
.59048 .05485 Mdot
.59524 .09611 Mdot
.6 .11838 Mdot
.60476 .07302 Mdot
.60952 .02167 Mdot
.61429 .17635 Mdot
.61905 .15816 Mdot
.62381 .11583 Mdot
.62857 .25074 Mdot
.63333 .16115 Mdot
.6381 .02365 Mdot
.64286 .04555 Mdot
.64762 .06926 Mdot
.65238 .04669 Mdot
.65714 .10782 Mdot
.6619 .04636 Mdot
.66667 .55202 Mdot
.67143 .07484 Mdot
.67619 .07845 Mdot
.68095 .27575 Mdot
.68571 .09638 Mdot
.69048 .14229 Mdot
.69524 .07089 Mdot
.7 .12549 Mdot
.70476 .25891 Mdot
.70952 .14333 Mdot
.71429 .12637 Mdot
.71905 .21601 Mdot
.72381 .03169 Mdot
.72857 .04064 Mdot
.73333 .03562 Mdot
.7381 .30265 Mdot
.74286 .18643 Mdot
.74762 .18593 Mdot
.75238 .03518 Mdot
.75714 .03137 Mdot
.7619 .00672 Mdot
.76667 .42038 Mdot
.77143 .13931 Mdot
.77619 .02881 Mdot
.78095 .08592 Mdot
.78571 .23451 Mdot
.79048 .11438 Mdot
.79524 .12708 Mdot
.8 .00269 Mdot
.80476 .16198 Mdot
.80952 .15497 Mdot
.81429 .18599 Mdot
.81905 .04069 Mdot
.82381 .0868 Mdot
.82857 .23162 Mdot
.83333 .02725 Mdot
.8381 .13869 Mdot
.84286 .1563 Mdot
.84762 .16379 Mdot
.85238 .08556 Mdot
.85714 .54319 Mdot
.8619 .15904 Mdot
.86667 .16459 Mdot
.87143 .24627 Mdot
.87619 .05146 Mdot
.88095 .11515 Mdot
.88571 .4932 Mdot
.89048 .11564 Mdot
.89524 .2657 Mdot
.9 .33346 Mdot
.90476 .34981 Mdot
.90952 .07532 Mdot
.91429 .05875 Mdot
.91905 .07622 Mdot
.92381 .35923 Mdot
.92857 .09535 Mdot
.93333 .1441 Mdot
.9381 .14116 Mdot
.94286 .26118 Mdot
.94762 .06232 Mdot
.95238 .27184 Mdot
.95714 .06937 Mdot
.9619 .1845 Mdot
.96667 .5876 Mdot
.97143 .06808 Mdot
.97619 .22015 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .14306 Mdot
.03333 .11392 Mdot
.0381 .32896 Mdot
.04286 .19253 Mdot
.04762 .16566 Mdot
.05238 .0869 Mdot
.05714 .08888 Mdot
.0619 .14567 Mdot
.06667 .05682 Mdot
.07143 .03976 Mdot
.07619 .07459 Mdot
.08095 .04273 Mdot
.08571 .08175 Mdot
.09048 .26631 Mdot
.09524 .21628 Mdot
.1 .10882 Mdot
.10476 .38929 Mdot
.10952 .3163 Mdot
.11429 .12152 Mdot
.11905 .21319 Mdot
.12381 .13323 Mdot
.12857 .15777 Mdot
.13333 .07301 Mdot
.1381 .14023 Mdot
.14286 .09908 Mdot
.14762 .056 Mdot
.15238 .16436 Mdot
.15714 .05012 Mdot
.1619 .07764 Mdot
.16667 .08076 Mdot
.17143 .04943 Mdot
.17619 .4784 Mdot
.18095 .13301 Mdot
.18571 .02921 Mdot
.19048 .32761 Mdot
.19524 .19846 Mdot
.2 .15953 Mdot
.20476 .14252 Mdot
.20952 .07393 Mdot
.21429 .15921 Mdot
.21905 .01814 Mdot
.22381 .08141 Mdot
.22857 .02698 Mdot
.23333 .02973 Mdot
.2381 .05507 Mdot
.24286 .27931 Mdot
.24762 .04826 Mdot
.25238 .18511 Mdot
.25714 .12659 Mdot
.2619 .08934 Mdot
.26667 .03503 Mdot
.27143 .09062 Mdot
.27619 .12494 Mdot
.28095 .03586 Mdot
.28571 .17262 Mdot
.29048 .17645 Mdot
.29524 .0883 Mdot
.3 .07888 Mdot
.30476 .14148 Mdot
.30952 .00423 Mdot
.31429 .02086 Mdot
.31905 .08607 Mdot
.32381 .20478 Mdot
.32857 .06535 Mdot
.33333 .10943 Mdot
.3381 .14293 Mdot
.34286 .0057 Mdot
.34762 .10995 Mdot
.35238 .17253 Mdot
.35714 .12182 Mdot
.3619 .2524 Mdot
.36667 .07918 Mdot
.37143 .06087 Mdot
.37619 .22998 Mdot
.38095 .2253 Mdot
.38571 .19854 Mdot
.39048 .18928 Mdot
.39524 .43126 Mdot
.4 .13182 Mdot
.40476 .07193 Mdot
.40952 .20612 Mdot
.41429 .05909 Mdot
.41905 .04897 Mdot
.42381 .07185 Mdot
.42857 .09363 Mdot
.43333 .17422 Mdot
.4381 .20501 Mdot
.44286 .23806 Mdot
.44762 .08414 Mdot
.45238 .1532 Mdot
.45714 .02149 Mdot
.4619 .13063 Mdot
.46667 .02869 Mdot
.47143 .14769 Mdot
.47619 .32068 Mdot
.48095 .02265 Mdot
.48571 .40879 Mdot
.49048 .43394 Mdot
.49524 .08524 Mdot
.5 .06471 Mdot
.50476 .261 Mdot
.50952 .21705 Mdot
.51429 .08205 Mdot
.51905 .1427 Mdot
.52381 .37726 Mdot
.52857 .21463 Mdot
.53333 .31945 Mdot
.5381 .32953 Mdot
.54286 .03892 Mdot
.54762 .08177 Mdot
.55238 .05581 Mdot
.55714 .00748 Mdot
.5619 .07715 Mdot
.56667 .09302 Mdot
.57143 .00707 Mdot
.57619 .07377 Mdot
.58095 .20011 Mdot
.58571 .0197 Mdot
.59048 .08697 Mdot
.59524 .06189 Mdot
.6 .06164 Mdot
.60476 .08479 Mdot
.60952 .06414 Mdot
.61429 .15171 Mdot
.61905 .14347 Mdot
.62381 .07329 Mdot
.62857 .27305 Mdot
.63333 .1664 Mdot
.6381 .01168 Mdot
.64286 .03798 Mdot
.64762 .00635 Mdot
.65238 .03994 Mdot
.65714 .09791 Mdot
.6619 .07804 Mdot
.66667 .54237 Mdot
.67143 .06552 Mdot
.67619 .08982 Mdot
.68095 .27926 Mdot
.68571 .18919 Mdot
.69048 .15603 Mdot
.69524 .0006 Mdot
.7 .15665 Mdot
.70476 .27161 Mdot
.70952 .1405 Mdot
.71429 .0551 Mdot
.71905 .17246 Mdot
.72381 .10458 Mdot
.72857 .02241 Mdot
.73333 .09629 Mdot
.7381 .37342 Mdot
.74286 .15327 Mdot
.74762 .18159 Mdot
.75238 .03135 Mdot
.75714 .07809 Mdot
.7619 .08326 Mdot
.76667 .4179 Mdot
.77143 .16526 Mdot
.77619 .0575 Mdot
.78095 .08077 Mdot
.78571 .19153 Mdot
.79048 .1057 Mdot
.79524 .09575 Mdot
.8 .08095 Mdot
.80476 .21558 Mdot
.80952 .15413 Mdot
.81429 .18006 Mdot
.81905 .07336 Mdot
.82381 .0953 Mdot
.82857 .16358 Mdot
.83333 .035 Mdot
.8381 .09773 Mdot
.84286 .12841 Mdot
.84762 .20625 Mdot
.85238 .02572 Mdot
.85714 .49762 Mdot
.8619 .16112 Mdot
.86667 .16184 Mdot
.87143 .24723 Mdot
.87619 .07101 Mdot
.88095 .16152 Mdot
.88571 .49462 Mdot
.89048 .11239 Mdot
.89524 .25827 Mdot
.9 .26984 Mdot
.90476 .36259 Mdot
.90952 .09424 Mdot
.91429 .05364 Mdot
.91905 .01874 Mdot
.92381 .32278 Mdot
.92857 .12322 Mdot
.93333 .11728 Mdot
.9381 .13849 Mdot
.94286 .21958 Mdot
.94762 .00607 Mdot
.95238 .22346 Mdot
.95714 .00194 Mdot
.9619 .26946 Mdot
.96667 .54498 Mdot
.97143 .06651 Mdot
.97619 .15713 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .14122 Mdot
.03333 .07323 Mdot
.0381 .25101 Mdot
.04286 .24825 Mdot
.04762 .14366 Mdot
.05238 .14683 Mdot
.05714 .05163 Mdot
.0619 .12681 Mdot
.06667 .03335 Mdot
.07143 .02072 Mdot
.07619 .01113 Mdot
.08095 .08024 Mdot
.08571 .04519 Mdot
.09048 .35555 Mdot
.09524 .23581 Mdot
.1 .13925 Mdot
.10476 .30078 Mdot
.10952 .3606 Mdot
.11429 .09245 Mdot
.11905 .16977 Mdot
.12381 .18881 Mdot
.12857 .13763 Mdot
.13333 .03839 Mdot
.1381 .04637 Mdot
.14286 .14453 Mdot
.14762 .10949 Mdot
.15238 .19477 Mdot
.15714 .0514 Mdot
.1619 .04464 Mdot
.16667 .11325 Mdot
.17143 .01945 Mdot
.17619 .46044 Mdot
.18095 .09164 Mdot
.18571 .06752 Mdot
.19048 .36449 Mdot
.19524 .14051 Mdot
.2 .08252 Mdot
.20476 .12632 Mdot
.20952 .0674 Mdot
.21429 .09631 Mdot
.21905 .03902 Mdot
.22381 .09157 Mdot
.22857 .07981 Mdot
.23333 .02068 Mdot
.2381 .09074 Mdot
.24286 .31525 Mdot
.24762 .01796 Mdot
.25238 .18872 Mdot
.25714 .13305 Mdot
.2619 .05547 Mdot
.26667 .06098 Mdot
.27143 .04908 Mdot
.27619 .20645 Mdot
.28095 .04692 Mdot
.28571 .1828 Mdot
.29048 .1767 Mdot
.29524 .12512 Mdot
.3 .08092 Mdot
.30476 .20886 Mdot
.30952 .03973 Mdot
.31429 .0155 Mdot
.31905 .05873 Mdot
.32381 .20345 Mdot
.32857 .08281 Mdot
.33333 .11098 Mdot
.3381 .1187 Mdot
.34286 .05288 Mdot
.34762 .09296 Mdot
.35238 .12655 Mdot
.35714 .11717 Mdot
.3619 .30377 Mdot
.36667 .0085 Mdot
.37143 .1275 Mdot
.37619 .17368 Mdot
.38095 .1769 Mdot
.38571 .17998 Mdot
.39048 .19318 Mdot
.39524 .42114 Mdot
.4 .18867 Mdot
.40476 .04305 Mdot
.40952 .23277 Mdot
.41429 .07988 Mdot
.41905 .04368 Mdot
.42381 .09795 Mdot
.42857 .0925 Mdot
.43333 .14382 Mdot
.4381 .18276 Mdot
.44286 .29512 Mdot
.44762 .0467 Mdot
.45238 .08847 Mdot
.45714 .06804 Mdot
.4619 .10771 Mdot
.46667 .04273 Mdot
.47143 .13339 Mdot
.47619 .33853 Mdot
.48095 .09298 Mdot
.48571 .42628 Mdot
.49048 .39789 Mdot
.49524 .11707 Mdot
.5 .0582 Mdot
.50476 .24254 Mdot
.50952 .24256 Mdot
.51429 .03754 Mdot
.51905 .20996 Mdot
.52381 .3365 Mdot
.52857 .18356 Mdot
.53333 .32339 Mdot
.5381 .25422 Mdot
.54286 .06304 Mdot
.54762 .0948 Mdot
.55238 .05051 Mdot
.55714 .02751 Mdot
.5619 .10692 Mdot
.56667 .11916 Mdot
.57143 .0673 Mdot
.57619 .00176 Mdot
.58095 .18641 Mdot
.58571 .06687 Mdot
.59048 .00544 Mdot
.59524 .03534 Mdot
.6 .08287 Mdot
.60476 .03262 Mdot
.60952 .07904 Mdot
.61429 .18782 Mdot
.61905 .12897 Mdot
.62381 .12323 Mdot
.62857 .26559 Mdot
.63333 .0935 Mdot
.6381 .01066 Mdot
.64286 .01488 Mdot
.64762 .03387 Mdot
.65238 .03314 Mdot
.65714 .15245 Mdot
.6619 .07343 Mdot
.66667 .53011 Mdot
.67143 .06953 Mdot
.67619 .07138 Mdot
.68095 .25725 Mdot
.68571 .15054 Mdot
.69048 .13813 Mdot
.69524 .08731 Mdot
.7 .13505 Mdot
.70476 .19372 Mdot
.70952 .16063 Mdot
.71429 .11854 Mdot
.71905 .19661 Mdot
.72381 .18883 Mdot
.72857 .04339 Mdot
.73333 .09475 Mdot
.7381 .37672 Mdot
.74286 .16256 Mdot
.74762 .23383 Mdot
.75238 .06971 Mdot
.75714 .1355 Mdot
.7619 .08526 Mdot
.76667 .42215 Mdot
.77143 .08466 Mdot
.77619 .02356 Mdot
.78095 .06896 Mdot
.78571 .21838 Mdot
.79048 .11418 Mdot
.79524 .07551 Mdot
.8 .072 Mdot
.80476 .20474 Mdot
.80952 .13947 Mdot
.81429 .16042 Mdot
.81905 .08467 Mdot
.82381 .13259 Mdot
.82857 .18652 Mdot
.83333 .02759 Mdot
.8381 .17038 Mdot
.84286 .11542 Mdot
.84762 .19041 Mdot
.85238 .0647 Mdot
.85714 .42975 Mdot
.8619 .14796 Mdot
.86667 .13066 Mdot
.87143 .22151 Mdot
.87619 .08725 Mdot
.88095 .08114 Mdot
.88571 .48656 Mdot
.89048 .0816 Mdot
.89524 .29417 Mdot
.9 .2268 Mdot
.90476 .35029 Mdot
.90952 .0912 Mdot
.91429 .05111 Mdot
.91905 .11231 Mdot
.92381 .26568 Mdot
.92857 .13122 Mdot
.93333 .10935 Mdot
.9381 .12372 Mdot
.94286 .21149 Mdot
.94762 .07175 Mdot
.95238 .16304 Mdot
.95714 .08597 Mdot
.9619 .28736 Mdot
.96667 .53522 Mdot
.97143 .08411 Mdot
.97619 .19016 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .13031 Mdot
.03333 .09505 Mdot
.0381 .22959 Mdot
.04286 .22506 Mdot
.04762 .16065 Mdot
.05238 .09605 Mdot
.05714 .10754 Mdot
.0619 .13371 Mdot
.06667 .08597 Mdot
.07143 .05758 Mdot
.07619 .05072 Mdot
.08095 .14708 Mdot
.08571 .03966 Mdot
.09048 .33788 Mdot
.09524 .24939 Mdot
.1 .14302 Mdot
.10476 .25903 Mdot
.10952 .36225 Mdot
.11429 .15478 Mdot
.11905 .14242 Mdot
.12381 .23915 Mdot
.12857 .12037 Mdot
.13333 .13134 Mdot
.1381 .10673 Mdot
.14286 .12023 Mdot
.14762 .03911 Mdot
.15238 .1433 Mdot
.15714 .01949 Mdot
.1619 .04105 Mdot
.16667 .07049 Mdot
.17143 .02723 Mdot
.17619 .43223 Mdot
.18095 .04085 Mdot
.18571 .15555 Mdot
.19048 .42063 Mdot
.19524 .18779 Mdot
.2 .07321 Mdot
.20476 .18868 Mdot
.20952 .14042 Mdot
.21429 .02025 Mdot
.21905 .04811 Mdot
.22381 .00834 Mdot
.22857 .12881 Mdot
.23333 .00241 Mdot
.2381 .06533 Mdot
.24286 .34565 Mdot
.24762 .00583 Mdot
.25238 .17137 Mdot
.25714 .06742 Mdot
.2619 .10196 Mdot
.26667 .08063 Mdot
.27143 .02282 Mdot
.27619 .2952 Mdot
.28095 .0662 Mdot
.28571 .19915 Mdot
.29048 .11721 Mdot
.29524 .04087 Mdot
.3 .02107 Mdot
.30476 .12722 Mdot
.30952 .05585 Mdot
.31429 .09414 Mdot
.31905 .0321 Mdot
.32381 .16797 Mdot
.32857 .03184 Mdot
.33333 .1405 Mdot
.3381 .06637 Mdot
.34286 .0053 Mdot
.34762 .10462 Mdot
.35238 .17832 Mdot
.35714 .09699 Mdot
.3619 .25792 Mdot
.36667 .04465 Mdot
.37143 .14932 Mdot
.37619 .15214 Mdot
.38095 .17954 Mdot
.38571 .22327 Mdot
.39048 .13186 Mdot
.39524 .38599 Mdot
.4 .13687 Mdot
.40476 .11617 Mdot
.40952 .19966 Mdot
.41429 .09703 Mdot
.41905 .12158 Mdot
.42381 .08992 Mdot
.42857 .12863 Mdot
.43333 .08773 Mdot
.4381 .21854 Mdot
.44286 .28897 Mdot
.44762 .06729 Mdot
.45238 .09232 Mdot
.45714 .05912 Mdot
.4619 .0386 Mdot
.46667 .07737 Mdot
.47143 .07571 Mdot
.47619 .26114 Mdot
.48095 .09362 Mdot
.48571 .42223 Mdot
.49048 .4345 Mdot
.49524 .14534 Mdot
.5 .07364 Mdot
.50476 .16011 Mdot
.50952 .27644 Mdot
.51429 .03482 Mdot
.51905 .17174 Mdot
.52381 .37115 Mdot
.52857 .15577 Mdot
.53333 .30568 Mdot
.5381 .27705 Mdot
.54286 .04901 Mdot
.54762 .02305 Mdot
.55238 .04723 Mdot
.55714 .06377 Mdot
.5619 .07844 Mdot
.56667 .05692 Mdot
.57143 .15833 Mdot
.57619 .06837 Mdot
.58095 .16221 Mdot
.58571 .08915 Mdot
.59048 .02381 Mdot
.59524 .01029 Mdot
.6 .06678 Mdot
.60476 .05332 Mdot
.60952 .01582 Mdot
.61429 .15177 Mdot
.61905 .20264 Mdot
.62381 .08915 Mdot
.62857 .26692 Mdot
.63333 .09033 Mdot
.6381 .03636 Mdot
.64286 .00155 Mdot
.64762 .01538 Mdot
.65238 .0356 Mdot
.65714 .17394 Mdot
.6619 .03761 Mdot
.66667 .54367 Mdot
.67143 .02727 Mdot
.67619 .08659 Mdot
.68095 .24456 Mdot
.68571 .15089 Mdot
.69048 .12888 Mdot
.69524 .05514 Mdot
.7 .07769 Mdot
.70476 .25605 Mdot
.70952 .18646 Mdot
.71429 .05851 Mdot
.71905 .16645 Mdot
.72381 .193 Mdot
.72857 .05068 Mdot
.73333 .02103 Mdot
.7381 .30134 Mdot
.74286 .23134 Mdot
.74762 .15889 Mdot
.75238 .12309 Mdot
.75714 .1307 Mdot
.7619 .0903 Mdot
.76667 .41989 Mdot
.77143 .10597 Mdot
.77619 .04727 Mdot
.78095 .11189 Mdot
.78571 .24658 Mdot
.79048 .05832 Mdot
.79524 .10266 Mdot
.8 .10341 Mdot
.80476 .19432 Mdot
.80952 .23251 Mdot
.81429 .16318 Mdot
.81905 .1099 Mdot
.82381 .06358 Mdot
.82857 .2484 Mdot
.83333 .09787 Mdot
.8381 .1741 Mdot
.84286 .02654 Mdot
.84762 .13515 Mdot
.85238 .07776 Mdot
.85714 .38427 Mdot
.8619 .16478 Mdot
.86667 .08187 Mdot
.87143 .20909 Mdot
.87619 .10842 Mdot
.88095 .1502 Mdot
.88571 .52459 Mdot
.89048 .0253 Mdot
.89524 .25485 Mdot
.9 .22265 Mdot
.90476 .25383 Mdot
.90952 .10903 Mdot
.91429 .04761 Mdot
.91905 .1241 Mdot
.92381 .23011 Mdot
.92857 .09465 Mdot
.93333 .12012 Mdot
.9381 .0976 Mdot
.94286 .24437 Mdot
.94762 .03822 Mdot
.95238 .17497 Mdot
.95714 .08 Mdot
.9619 .23285 Mdot
.96667 .51845 Mdot
.97143 .07162 Mdot
.97619 .1329 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .07365 Mdot
.03333 .03282 Mdot
.0381 .2604 Mdot
.04286 .22896 Mdot
.04762 .12726 Mdot
.05238 .14524 Mdot
.05714 .132 Mdot
.0619 .19919 Mdot
.06667 .09191 Mdot
.07143 .02222 Mdot
.07619 .0067 Mdot
.08095 .14284 Mdot
.08571 .01907 Mdot
.09048 .31194 Mdot
.09524 .20192 Mdot
.1 .09184 Mdot
.10476 .19482 Mdot
.10952 .36679 Mdot
.11429 .18984 Mdot
.11905 .12808 Mdot
.12381 .23764 Mdot
.12857 .12805 Mdot
.13333 .11155 Mdot
.1381 .09861 Mdot
.14286 .07469 Mdot
.14762 .10506 Mdot
.15238 .16594 Mdot
.15714 .09767 Mdot
.1619 .05612 Mdot
.16667 .0424 Mdot
.17143 .08905 Mdot
.17619 .47277 Mdot
.18095 .12608 Mdot
.18571 .14244 Mdot
.19048 .40549 Mdot
.19524 .184 Mdot
.2 .00291 Mdot
.20476 .24394 Mdot
.20952 .11404 Mdot
.21429 .0531 Mdot
.21905 .09482 Mdot
.22381 .09761 Mdot
.22857 .13364 Mdot
.23333 .05397 Mdot
.2381 .08031 Mdot
.24286 .2991 Mdot
.24762 .13153 Mdot
.25238 .14552 Mdot
.25714 .06147 Mdot
.2619 .0736 Mdot
.26667 .04288 Mdot
.27143 .02255 Mdot
.27619 .31667 Mdot
.28095 .07443 Mdot
.28571 .20515 Mdot
.29048 .13091 Mdot
.29524 .00952 Mdot
.3 .01685 Mdot
.30476 .19178 Mdot
.30952 .13166 Mdot
.31429 .08287 Mdot
.31905 .08383 Mdot
.32381 .17078 Mdot
.32857 .06981 Mdot
.33333 .1403 Mdot
.3381 .10982 Mdot
.34286 .05204 Mdot
.34762 .10476 Mdot
.35238 .19929 Mdot
.35714 .08754 Mdot
.3619 .29483 Mdot
.36667 .10111 Mdot
.37143 .14488 Mdot
.37619 .12031 Mdot
.38095 .2158 Mdot
.38571 .25565 Mdot
.39048 .14011 Mdot
.39524 .37692 Mdot
.4 .15564 Mdot
.40476 .1221 Mdot
.40952 .22378 Mdot
.41429 .11894 Mdot
.41905 .14127 Mdot
.42381 .0315 Mdot
.42857 .0862 Mdot
.43333 .11891 Mdot
.4381 .14873 Mdot
.44286 .25418 Mdot
.44762 .08822 Mdot
.45238 .11696 Mdot
.45714 .00976 Mdot
.4619 .04393 Mdot
.46667 .01104 Mdot
.47143 .05432 Mdot
.47619 .17068 Mdot
.48095 .15659 Mdot
.48571 .38984 Mdot
.49048 .3895 Mdot
.49524 .13297 Mdot
.5 .04926 Mdot
.50476 .09029 Mdot
.50952 .19597 Mdot
.51429 .08524 Mdot
.51905 .15853 Mdot
.52381 .40368 Mdot
.52857 .20545 Mdot
.53333 .21124 Mdot
.5381 .31822 Mdot
.54286 .06437 Mdot
.54762 .0209 Mdot
.55238 .10371 Mdot
.55714 .0269 Mdot
.5619 .0095 Mdot
.56667 .02626 Mdot
.57143 .13776 Mdot
.57619 .14915 Mdot
.58095 .1229 Mdot
.58571 .10388 Mdot
.59048 .0683 Mdot
.59524 .02223 Mdot
.6 .05946 Mdot
.60476 .06634 Mdot
.60952 .0482 Mdot
.61429 .10927 Mdot
.61905 .24283 Mdot
.62381 .08954 Mdot
.62857 .27341 Mdot
.63333 .14304 Mdot
.6381 .08097 Mdot
.64286 .03799 Mdot
.64762 .06858 Mdot
.65238 .05244 Mdot
.65714 .18294 Mdot
.6619 .02598 Mdot
.66667 .4919 Mdot
.67143 .03963 Mdot
.67619 .07287 Mdot
.68095 .27177 Mdot
.68571 .17328 Mdot
.69048 .06346 Mdot
.69524 .10842 Mdot
.7 .06379 Mdot
.70476 .18252 Mdot
.70952 .09407 Mdot
.71429 .06206 Mdot
.71905 .17089 Mdot
.72381 .23925 Mdot
.72857 .03556 Mdot
.73333 .10107 Mdot
.7381 .22511 Mdot
.74286 .23205 Mdot
.74762 .1567 Mdot
.75238 .11518 Mdot
.75714 .15862 Mdot
.7619 .13879 Mdot
.76667 .36563 Mdot
.77143 .04942 Mdot
.77619 .07035 Mdot
.78095 .14372 Mdot
.78571 .22826 Mdot
.79048 .09779 Mdot
.79524 .05449 Mdot
.8 .14341 Mdot
.80476 .20816 Mdot
.80952 .17885 Mdot
.81429 .18423 Mdot
.81905 .11753 Mdot
.82381 .06417 Mdot
.82857 .27616 Mdot
.83333 .11006 Mdot
.8381 .22215 Mdot
.84286 .08163 Mdot
.84762 .13083 Mdot
.85238 .04759 Mdot
.85714 .36503 Mdot
.8619 .1389 Mdot
.86667 .00987 Mdot
.87143 .19837 Mdot
.87619 .089 Mdot
.88095 .13657 Mdot
.88571 .55581 Mdot
.89048 .03118 Mdot
.89524 .19206 Mdot
.9 .21467 Mdot
.90476 .25512 Mdot
.90952 .0474 Mdot
.91429 .01159 Mdot
.91905 .08242 Mdot
.92381 .17708 Mdot
.92857 .12982 Mdot
.93333 .09718 Mdot
.9381 .127 Mdot
.94286 .21142 Mdot
.94762 .09337 Mdot
.95238 .17665 Mdot
.95714 .07501 Mdot
.9619 .2189 Mdot
.96667 .43407 Mdot
.97143 .13928 Mdot
.97619 .10887 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .00854 Mdot
.03333 .01832 Mdot
.0381 .2814 Mdot
.04286 .21095 Mdot
.04762 .12621 Mdot
.05238 .14686 Mdot
.05714 .14528 Mdot
.0619 .22073 Mdot
.06667 .07161 Mdot
.07143 .08945 Mdot
.07619 .04978 Mdot
.08095 .07864 Mdot
.08571 .04946 Mdot
.09048 .25936 Mdot
.09524 .20197 Mdot
.1 .14161 Mdot
.10476 .1631 Mdot
.10952 .40161 Mdot
.11429 .21223 Mdot
.11905 .06873 Mdot
.12381 .27659 Mdot
.12857 .05071 Mdot
.13333 .07153 Mdot
.1381 .05215 Mdot
.14286 .12357 Mdot
.14762 .12552 Mdot
.15238 .14544 Mdot
.15714 .12902 Mdot
.1619 .09379 Mdot
.16667 .06607 Mdot
.17143 .03492 Mdot
.17619 .51629 Mdot
.18095 .11681 Mdot
.18571 .07326 Mdot
.19048 .37652 Mdot
.19524 .11895 Mdot
.2 .03792 Mdot
.20476 .28778 Mdot
.20952 .05285 Mdot
.21429 .09826 Mdot
.21905 .08348 Mdot
.22381 .08704 Mdot
.22857 .0955 Mdot
.23333 .0138 Mdot
.2381 .01096 Mdot
.24286 .27039 Mdot
.24762 .09305 Mdot
.25238 .16943 Mdot
.25714 .01167 Mdot
.2619 .02099 Mdot
.26667 .0225 Mdot
.27143 .09449 Mdot
.27619 .31109 Mdot
.28095 .064 Mdot
.28571 .23263 Mdot
.29048 .08115 Mdot
.29524 .04741 Mdot
.3 .13497 Mdot
.30476 .15489 Mdot
.30952 .08479 Mdot
.31429 .05218 Mdot
.31905 .06264 Mdot
.32381 .15994 Mdot
.32857 .08355 Mdot
.33333 .07133 Mdot
.3381 .06482 Mdot
.34286 .0993 Mdot
.34762 .16314 Mdot
.35238 .1287 Mdot
.35714 .04149 Mdot
.3619 .26653 Mdot
.36667 .05046 Mdot
.37143 .17882 Mdot
.37619 .13155 Mdot
.38095 .18006 Mdot
.38571 .29237 Mdot
.39048 .07523 Mdot
.39524 .44496 Mdot
.4 .16755 Mdot
.40476 .13519 Mdot
.40952 .20178 Mdot
.41429 .13947 Mdot
.41905 .10785 Mdot
.42381 .06472 Mdot
.42857 .0751 Mdot
.43333 .15697 Mdot
.4381 .19751 Mdot
.44286 .2994 Mdot
.44762 .06329 Mdot
.45238 .11115 Mdot
.45714 .04563 Mdot
.4619 .0502 Mdot
.46667 .097 Mdot
.47143 .03497 Mdot
.47619 .14777 Mdot
.48095 .13993 Mdot
.48571 .42767 Mdot
.49048 .34173 Mdot
.49524 .09103 Mdot
.5 .0729 Mdot
.50476 .08386 Mdot
.50952 .14077 Mdot
.51429 .06097 Mdot
.51905 .18875 Mdot
.52381 .36508 Mdot
.52857 .18275 Mdot
.53333 .19278 Mdot
.5381 .30123 Mdot
.54286 .02545 Mdot
.54762 .01603 Mdot
.55238 .05929 Mdot
.55714 .00965 Mdot
.5619 .00613 Mdot
.56667 .06696 Mdot
.57143 .16557 Mdot
.57619 .15327 Mdot
.58095 .0416 Mdot
.58571 .0974 Mdot
.59048 .07721 Mdot
.59524 .04459 Mdot
.6 .08323 Mdot
.60476 .07327 Mdot
.60952 .00522 Mdot
.61429 .1146 Mdot
.61905 .22961 Mdot
.62381 .05322 Mdot
.62857 .2422 Mdot
.63333 .17603 Mdot
.6381 .03427 Mdot
.64286 .06448 Mdot
.64762 .02064 Mdot
.65238 .0153 Mdot
.65714 .13981 Mdot
.6619 .03532 Mdot
.66667 .47729 Mdot
.67143 .09093 Mdot
.67619 .12458 Mdot
.68095 .23936 Mdot
.68571 .14734 Mdot
.69048 .01201 Mdot
.69524 .17921 Mdot
.7 .05901 Mdot
.70476 .1122 Mdot
.70952 .09686 Mdot
.71429 .02031 Mdot
.71905 .11086 Mdot
.72381 .22653 Mdot
.72857 .12405 Mdot
.73333 .05408 Mdot
.7381 .17777 Mdot
.74286 .22216 Mdot
.74762 .08132 Mdot
.75238 .18631 Mdot
.75714 .11827 Mdot
.7619 .18961 Mdot
.76667 .37156 Mdot
.77143 .05226 Mdot
.77619 .12014 Mdot
.78095 .1423 Mdot
.78571 .2577 Mdot
.79048 .09113 Mdot
.79524 .07877 Mdot
.8 .13449 Mdot
.80476 .201 Mdot
.80952 .16547 Mdot
.81429 .10913 Mdot
.81905 .09929 Mdot
.82381 .13167 Mdot
.82857 .22045 Mdot
.83333 .08412 Mdot
.8381 .20386 Mdot
.84286 .11745 Mdot
.84762 .10364 Mdot
.85238 .02829 Mdot
.85714 .35742 Mdot
.8619 .07617 Mdot
.86667 .08326 Mdot
.87143 .21387 Mdot
.87619 .0266 Mdot
.88095 .14286 Mdot
.88571 .54568 Mdot
.89048 .01886 Mdot
.89524 .18599 Mdot
.9 .17123 Mdot
.90476 .28476 Mdot
.90952 .04602 Mdot
.91429 .0604 Mdot
.91905 .06567 Mdot
.92381 .11227 Mdot
.92857 .10749 Mdot
.93333 .03764 Mdot
.9381 .07799 Mdot
.94286 .15362 Mdot
.94762 .13514 Mdot
.95238 .21778 Mdot
.95714 .04517 Mdot
.9619 .17208 Mdot
.96667 .40999 Mdot
.97143 .17591 Mdot
.97619 .16955 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .06667 Mdot
.03333 .03242 Mdot
.0381 .30749 Mdot
.04286 .20921 Mdot
.04762 .1784 Mdot
.05238 .12018 Mdot
.05714 .1348 Mdot
.0619 .16924 Mdot
.06667 .06242 Mdot
.07143 .1323 Mdot
.07619 .04807 Mdot
.08095 .00764 Mdot
.08571 .01117 Mdot
.09048 .20928 Mdot
.09524 .18868 Mdot
.1 .11473 Mdot
.10476 .13233 Mdot
.10952 .32032 Mdot
.11429 .20765 Mdot
.11905 .07395 Mdot
.12381 .32231 Mdot
.12857 .07929 Mdot
.13333 .08875 Mdot
.1381 .08179 Mdot
.14286 .0938 Mdot
.14762 .05999 Mdot
.15238 .11588 Mdot
.15714 .07186 Mdot
.1619 .04295 Mdot
.16667 .03536 Mdot
.17143 .09094 Mdot
.17619 .43306 Mdot
.18095 .07563 Mdot
.18571 .09434 Mdot
.19048 .317 Mdot
.19524 .12819 Mdot
.2 .07276 Mdot
.20476 .24808 Mdot
.20952 .07313 Mdot
.21429 .13311 Mdot
.21905 .08937 Mdot
.22381 .0404 Mdot
.22857 .04618 Mdot
.23333 .02717 Mdot
.2381 .09741 Mdot
.24286 .29347 Mdot
.24762 .04555 Mdot
.25238 .20377 Mdot
.25714 .0638 Mdot
.2619 .14251 Mdot
.26667 .05107 Mdot
.27143 .03153 Mdot
.27619 .24176 Mdot
.28095 .1027 Mdot
.28571 .19169 Mdot
.29048 .11578 Mdot
.29524 .00342 Mdot
.3 .12612 Mdot
.30476 .1467 Mdot
.30952 .0255 Mdot
.31429 .09475 Mdot
.31905 .09224 Mdot
.32381 .10862 Mdot
.32857 .09011 Mdot
.33333 .08539 Mdot
.3381 .09165 Mdot
.34286 .07669 Mdot
.34762 .09748 Mdot
.35238 .1105 Mdot
.35714 .07033 Mdot
.3619 .30571 Mdot
.36667 .09654 Mdot
.37143 .1031 Mdot
.37619 .09172 Mdot
.38095 .1789 Mdot
.38571 .29359 Mdot
.39048 .10959 Mdot
.39524 .43442 Mdot
.4 .16788 Mdot
.40476 .15695 Mdot
.40952 .14669 Mdot
.41429 .10079 Mdot
.41905 .12659 Mdot
.42381 .11474 Mdot
.42857 .12609 Mdot
.43333 .15514 Mdot
.4381 .18337 Mdot
.44286 .2342 Mdot
.44762 .08571 Mdot
.45238 .06855 Mdot
.45714 .08269 Mdot
.4619 .0665 Mdot
.46667 .09972 Mdot
.47143 .01395 Mdot
.47619 .10702 Mdot
.48095 .0852 Mdot
.48571 .43022 Mdot
.49048 .43087 Mdot
.49524 .06177 Mdot
.5 .10052 Mdot
.50476 .05891 Mdot
.50952 .10717 Mdot
.51429 .01934 Mdot
.51905 .19764 Mdot
.52381 .36982 Mdot
.52857 .1696 Mdot
.53333 .12553 Mdot
.5381 .26738 Mdot
.54286 .06541 Mdot
.54762 .09098 Mdot
.55238 .01533 Mdot
.55714 .09383 Mdot
.5619 .04796 Mdot
.56667 .06892 Mdot
.57143 .11765 Mdot
.57619 .12337 Mdot
.58095 .00779 Mdot
.58571 .0399 Mdot
.59048 .04782 Mdot
.59524 .05187 Mdot
.6 .09719 Mdot
.60476 .06626 Mdot
.60952 .12692 Mdot
.61429 .07196 Mdot
.61905 .22654 Mdot
.62381 .0231 Mdot
.62857 .25894 Mdot
.63333 .12356 Mdot
.6381 .02911 Mdot
.64286 .03097 Mdot
.64762 .09849 Mdot
.65238 .03507 Mdot
.65714 .10187 Mdot
.6619 .01584 Mdot
.66667 .49646 Mdot
.67143 .0694 Mdot
.67619 .20025 Mdot
.68095 .20195 Mdot
.68571 .23491 Mdot
.69048 .06974 Mdot
.69524 .12196 Mdot
.7 .11063 Mdot
.70476 .1814 Mdot
.70952 .08562 Mdot
.71429 .0306 Mdot
.71905 .03681 Mdot
.72381 .28513 Mdot
.72857 .11584 Mdot
.73333 .09624 Mdot
.7381 .12866 Mdot
.74286 .23247 Mdot
.74762 .06265 Mdot
.75238 .17407 Mdot
.75714 .13609 Mdot
.7619 .26145 Mdot
.76667 .38786 Mdot
.77143 .06308 Mdot
.77619 .14229 Mdot
.78095 .17508 Mdot
.78571 .22502 Mdot
.79048 .04662 Mdot
.79524 .02916 Mdot
.8 .15021 Mdot
.80476 .24325 Mdot
.80952 .20534 Mdot
.81429 .04924 Mdot
.81905 .11953 Mdot
.82381 .18572 Mdot
.82857 .19718 Mdot
.83333 .08407 Mdot
.8381 .21429 Mdot
.84286 .11059 Mdot
.84762 .10412 Mdot
.85238 .05343 Mdot
.85714 .35802 Mdot
.8619 .07451 Mdot
.86667 .09645 Mdot
.87143 .17635 Mdot
.87619 .05804 Mdot
.88095 .1598 Mdot
.88571 .59256 Mdot
.89048 .02661 Mdot
.89524 .2337 Mdot
.9 .19737 Mdot
.90476 .29656 Mdot
.90952 .02703 Mdot
.91429 .10367 Mdot
.91905 .04858 Mdot
.92381 .11563 Mdot
.92857 .09619 Mdot
.93333 .0234 Mdot
.9381 .08275 Mdot
.94286 .13876 Mdot
.94762 .08884 Mdot
.95238 .23293 Mdot
.95714 .01593 Mdot
.9619 .1797 Mdot
.96667 .34877 Mdot
.97143 .14646 Mdot
.97619 .20438 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .11406 Mdot
.03333 .02476 Mdot
.0381 .30852 Mdot
.04286 .14445 Mdot
.04762 .17304 Mdot
.05238 .12403 Mdot
.05714 .06098 Mdot
.0619 .14928 Mdot
.06667 .00088 Mdot
.07143 .09521 Mdot
.07619 .02407 Mdot
.08095 .04166 Mdot
.08571 .08723 Mdot
.09048 .23258 Mdot
.09524 .22645 Mdot
.1 .07786 Mdot
.10476 .13658 Mdot
.10952 .29018 Mdot
.11429 .24374 Mdot
.11905 .09762 Mdot
.12381 .27452 Mdot
.12857 .06862 Mdot
.13333 .11572 Mdot
.1381 .04805 Mdot
.14286 .17146 Mdot
.14762 .04807 Mdot
.15238 .08227 Mdot
.15714 .16273 Mdot
.1619 .00466 Mdot
.16667 .08054 Mdot
.17143 .05697 Mdot
.17619 .36399 Mdot
.18095 .12791 Mdot
.18571 .05086 Mdot
.19048 .32359 Mdot
.19524 .1113 Mdot
.2 .03626 Mdot
.20476 .28913 Mdot
.20952 .02679 Mdot
.21429 .13371 Mdot
.21905 .11733 Mdot
.22381 .07551 Mdot
.22857 .0471 Mdot
.23333 .03709 Mdot
.2381 .0364 Mdot
.24286 .23029 Mdot
.24762 .05671 Mdot
.25238 .19992 Mdot
.25714 .04532 Mdot
.2619 .15964 Mdot
.26667 .00339 Mdot
.27143 .06905 Mdot
.27619 .25612 Mdot
.28095 .08041 Mdot
.28571 .24319 Mdot
.29048 .1225 Mdot
.29524 .0246 Mdot
.3 .11341 Mdot
.30476 .13537 Mdot
.30952 .01941 Mdot
.31429 .08279 Mdot
.31905 .01647 Mdot
.32381 .05016 Mdot
.32857 .0905 Mdot
.33333 .0948 Mdot
.3381 .08139 Mdot
.34286 .06535 Mdot
.34762 .03298 Mdot
.35238 .08883 Mdot
.35714 .09985 Mdot
.3619 .2942 Mdot
.36667 .09212 Mdot
.37143 .07827 Mdot
.37619 .12215 Mdot
.38095 .1695 Mdot
.38571 .21002 Mdot
.39048 .19359 Mdot
.39524 .43911 Mdot
.4 .14614 Mdot
.40476 .10743 Mdot
.40952 .13837 Mdot
.41429 .10914 Mdot
.41905 .1645 Mdot
.42381 .1174 Mdot
.42857 .0629 Mdot
.43333 .16045 Mdot
.4381 .18075 Mdot
.44286 .1932 Mdot
.44762 .06925 Mdot
.45238 .01637 Mdot
.45714 .11808 Mdot
.4619 .08141 Mdot
.46667 .11647 Mdot
.47143 .02667 Mdot
.47619 .17195 Mdot
.48095 .04283 Mdot
.48571 .42315 Mdot
.49048 .42887 Mdot
.49524 .05095 Mdot
.5 .0246 Mdot
.50476 .05705 Mdot
.50952 .07744 Mdot
.51429 .05562 Mdot
.51905 .20168 Mdot
.52381 .3112 Mdot
.52857 .15506 Mdot
.53333 .07769 Mdot
.5381 .23213 Mdot
.54286 .08655 Mdot
.54762 .0304 Mdot
.55238 .01578 Mdot
.55714 .02805 Mdot
.5619 .0251 Mdot
.56667 .09757 Mdot
.57143 .02769 Mdot
.57619 .14299 Mdot
.58095 .09295 Mdot
.58571 .06465 Mdot
.59048 .03051 Mdot
.59524 .09299 Mdot
.6 .01827 Mdot
.60476 .10342 Mdot
.60952 .10471 Mdot
.61429 .00803 Mdot
.61905 .1569 Mdot
.62381 .09543 Mdot
.62857 .24632 Mdot
.63333 .07714 Mdot
.6381 .03826 Mdot
.64286 .07652 Mdot
.64762 .14591 Mdot
.65238 .01241 Mdot
.65714 .06125 Mdot
.6619 .08212 Mdot
.66667 .45964 Mdot
.67143 .10619 Mdot
.67619 .23208 Mdot
.68095 .1295 Mdot
.68571 .2261 Mdot
.69048 .10421 Mdot
.69524 .12231 Mdot
.7 .07173 Mdot
.70476 .16341 Mdot
.70952 .10091 Mdot
.71429 .02046 Mdot
.71905 .00989 Mdot
.72381 .20148 Mdot
.72857 .14426 Mdot
.73333 .06557 Mdot
.7381 .04618 Mdot
.74286 .19109 Mdot
.74762 .04057 Mdot
.75238 .17956 Mdot
.75714 .15923 Mdot
.7619 .19109 Mdot
.76667 .3763 Mdot
.77143 .02015 Mdot
.77619 .11835 Mdot
.78095 .15575 Mdot
.78571 .19059 Mdot
.79048 .02294 Mdot
.79524 .10121 Mdot
.8 .15119 Mdot
.80476 .25271 Mdot
.80952 .1983 Mdot
.81429 .0136 Mdot
.81905 .11897 Mdot
.82381 .22395 Mdot
.82857 .19971 Mdot
.83333 .10511 Mdot
.8381 .22348 Mdot
.84286 .10071 Mdot
.84762 .14893 Mdot
.85238 .06703 Mdot
.85714 .31651 Mdot
.8619 .07226 Mdot
.86667 .00521 Mdot
.87143 .18086 Mdot
.87619 .03077 Mdot
.88095 .19824 Mdot
.88571 .5576 Mdot
.89048 .00131 Mdot
.89524 .26664 Mdot
.9 .17525 Mdot
.90476 .29216 Mdot
.90952 .01035 Mdot
.91429 .0581 Mdot
.91905 .12492 Mdot
.92381 .08962 Mdot
.92857 .02762 Mdot
.93333 .04748 Mdot
.9381 .0626 Mdot
.94286 .15793 Mdot
.94762 .06294 Mdot
.95238 .18732 Mdot
.95714 .11472 Mdot
.9619 .19117 Mdot
.96667 .30399 Mdot
.97143 .19555 Mdot
.97619 .27477 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .11493 Mdot
.03333 .01529 Mdot
.0381 .33869 Mdot
.04286 .09291 Mdot
.04762 .23008 Mdot
.05238 .13414 Mdot
.05714 .06449 Mdot
.0619 .06581 Mdot
.06667 .08888 Mdot
.07143 .07145 Mdot
.07619 .06579 Mdot
.08095 .05569 Mdot
.08571 .08525 Mdot
.09048 .20663 Mdot
.09524 .19603 Mdot
.1 .06125 Mdot
.10476 .10203 Mdot
.10952 .27637 Mdot
.11429 .27699 Mdot
.11905 .07836 Mdot
.12381 .23014 Mdot
.12857 .0829 Mdot
.13333 .08337 Mdot
.1381 .03733 Mdot
.14286 .18435 Mdot
.14762 .02567 Mdot
.15238 .0651 Mdot
.15714 .10443 Mdot
.1619 .0955 Mdot
.16667 .13827 Mdot
.17143 .07015 Mdot
.17619 .38119 Mdot
.18095 .13743 Mdot
.18571 .02891 Mdot
.19048 .37706 Mdot
.19524 .06048 Mdot
.2 .0721 Mdot
.20476 .27083 Mdot
.20952 .03032 Mdot
.21429 .15878 Mdot
.21905 .08407 Mdot
.22381 .08836 Mdot
.22857 .03355 Mdot
.23333 .03245 Mdot
.2381 .089 Mdot
.24286 .22205 Mdot
.24762 .0155 Mdot
.25238 .17126 Mdot
.25714 .0553 Mdot
.2619 .1404 Mdot
.26667 .00247 Mdot
.27143 .15024 Mdot
.27619 .29196 Mdot
.28095 .03609 Mdot
.28571 .20388 Mdot
.29048 .04665 Mdot
.29524 .0388 Mdot
.3 .11537 Mdot
.30476 .14089 Mdot
.30952 .02047 Mdot
.31429 .03638 Mdot
.31905 .06426 Mdot
.32381 .06333 Mdot
.32857 .09339 Mdot
.33333 .04921 Mdot
.3381 .03342 Mdot
.34286 .10968 Mdot
.34762 .05497 Mdot
.35238 .08058 Mdot
.35714 .0177 Mdot
.3619 .28086 Mdot
.36667 .11343 Mdot
.37143 .07994 Mdot
.37619 .16701 Mdot
.38095 .20321 Mdot
.38571 .15013 Mdot
.39048 .21038 Mdot
.39524 .39609 Mdot
.4 .17621 Mdot
.40476 .09256 Mdot
.40952 .10016 Mdot
.41429 .08547 Mdot
.41905 .13331 Mdot
.42381 .06888 Mdot
.42857 .06919 Mdot
.43333 .17101 Mdot
.4381 .0995 Mdot
.44286 .23936 Mdot
.44762 .04973 Mdot
.45238 .00191 Mdot
.45714 .12948 Mdot
.4619 .0931 Mdot
.46667 .05034 Mdot
.47143 .04569 Mdot
.47619 .13606 Mdot
.48095 .01046 Mdot
.48571 .45313 Mdot
.49048 .45782 Mdot
.49524 .04822 Mdot
.5 .03025 Mdot
.50476 .07806 Mdot
.50952 .07987 Mdot
.51429 .01478 Mdot
.51905 .10769 Mdot
.52381 .26555 Mdot
.52857 .13384 Mdot
.53333 .08935 Mdot
.5381 .29373 Mdot
.54286 .08332 Mdot
.54762 .01641 Mdot
.55238 .03485 Mdot
.55714 .14306 Mdot
.5619 .05386 Mdot
.56667 .05388 Mdot
.57143 .09025 Mdot
.57619 .0732 Mdot
.58095 .06802 Mdot
.58571 .03383 Mdot
.59048 .08841 Mdot
.59524 .08369 Mdot
.6 .11395 Mdot
.60476 .10973 Mdot
.60952 .09996 Mdot
.61429 .00172 Mdot
.61905 .13132 Mdot
.62381 .1427 Mdot
.62857 .2272 Mdot
.63333 .13832 Mdot
.6381 .01186 Mdot
.64286 .08522 Mdot
.64762 .09258 Mdot
.65238 .04323 Mdot
.65714 .04453 Mdot
.6619 .09462 Mdot
.66667 .45118 Mdot
.67143 .0862 Mdot
.67619 .16327 Mdot
.68095 .12709 Mdot
.68571 .20653 Mdot
.69048 .13929 Mdot
.69524 .11637 Mdot
.7 .09369 Mdot
.70476 .16713 Mdot
.70952 .01147 Mdot
.71429 .05145 Mdot
.71905 .06954 Mdot
.72381 .12158 Mdot
.72857 .1335 Mdot
.73333 .10203 Mdot
.7381 .00478 Mdot
.74286 .11634 Mdot
.74762 .02023 Mdot
.75238 .13908 Mdot
.75714 .06352 Mdot
.7619 .23082 Mdot
.76667 .31388 Mdot
.77143 .05817 Mdot
.77619 .13982 Mdot
.78095 .06659 Mdot
.78571 .23675 Mdot
.79048 .03213 Mdot
.79524 .13933 Mdot
.8 .15546 Mdot
.80476 .21051 Mdot
.80952 .12666 Mdot
.81429 .03699 Mdot
.81905 .13 Mdot
.82381 .21639 Mdot
.82857 .18277 Mdot
.83333 .04133 Mdot
.8381 .29092 Mdot
.84286 .04832 Mdot
.84762 .13836 Mdot
.85238 .09445 Mdot
.85714 .29402 Mdot
.8619 .05255 Mdot
.86667 .06378 Mdot
.87143 .12149 Mdot
.87619 .0961 Mdot
.88095 .22888 Mdot
.88571 .48514 Mdot
.89048 .069 Mdot
.89524 .23248 Mdot
.9 .17332 Mdot
.90476 .33116 Mdot
.90952 .0359 Mdot
.91429 .00909 Mdot
.91905 .09268 Mdot
.92381 .0279 Mdot
.92857 .03922 Mdot
.93333 .09242 Mdot
.9381 .07178 Mdot
.94286 .14485 Mdot
.94762 .06313 Mdot
.95238 .10674 Mdot
.95714 .13565 Mdot
.9619 .16592 Mdot
.96667 .33615 Mdot
.97143 .18597 Mdot
.97619 .2637 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .09228 Mdot
.03333 .09256 Mdot
.0381 .33729 Mdot
.04286 .10091 Mdot
.04762 .28838 Mdot
.05238 .08462 Mdot
.05714 .10534 Mdot
.0619 .10076 Mdot
.06667 .12581 Mdot
.07143 .00251 Mdot
.07619 .03322 Mdot
.08095 .06363 Mdot
.08571 .11319 Mdot
.09048 .1879 Mdot
.09524 .26016 Mdot
.1 .0272 Mdot
.10476 .09361 Mdot
.10952 .23365 Mdot
.11429 .36404 Mdot
.11905 .0845 Mdot
.12381 .24419 Mdot
.12857 .09285 Mdot
.13333 .14312 Mdot
.1381 .07901 Mdot
.14286 .24474 Mdot
.14762 .06679 Mdot
.15238 .08239 Mdot
.15714 .14237 Mdot
.1619 .13594 Mdot
.16667 .17417 Mdot
.17143 .06177 Mdot
.17619 .33935 Mdot
.18095 .07549 Mdot
.18571 .02915 Mdot
.19048 .29967 Mdot
.19524 .09169 Mdot
.2 .05596 Mdot
.20476 .24958 Mdot
.20952 .06972 Mdot
.21429 .18907 Mdot
.21905 .04845 Mdot
.22381 .0232 Mdot
.22857 .07749 Mdot
.23333 .08396 Mdot
.2381 .07142 Mdot
.24286 .1641 Mdot
.24762 .09564 Mdot
.25238 .14231 Mdot
.25714 .05554 Mdot
.2619 .13628 Mdot
.26667 .0401 Mdot
.27143 .11496 Mdot
.27619 .31976 Mdot
.28095 .02932 Mdot
.28571 .18865 Mdot
.29048 .05087 Mdot
.29524 .02249 Mdot
.3 .05135 Mdot
.30476 .19164 Mdot
.30952 .01935 Mdot
.31429 .05653 Mdot
.31905 .02411 Mdot
.32381 .03584 Mdot
.32857 .06156 Mdot
.33333 .0641 Mdot
.3381 .05478 Mdot
.34286 .1271 Mdot
.34762 .05321 Mdot
.35238 .13068 Mdot
.35714 .08871 Mdot
.3619 .21301 Mdot
.36667 .11193 Mdot
.37143 .12202 Mdot
.37619 .16518 Mdot
.38095 .20597 Mdot
.38571 .1925 Mdot
.39048 .2139 Mdot
.39524 .33559 Mdot
.4 .17559 Mdot
.40476 .0919 Mdot
.40952 .08472 Mdot
.41429 .11405 Mdot
.41905 .15752 Mdot
.42381 .01757 Mdot
.42857 .10976 Mdot
.43333 .15038 Mdot
.4381 .07441 Mdot
.44286 .25995 Mdot
.44762 .09575 Mdot
.45238 .06243 Mdot
.45714 .14064 Mdot
.4619 .14477 Mdot
.46667 .00688 Mdot
.47143 .04024 Mdot
.47619 .07464 Mdot
.48095 .1508 Mdot
.48571 .42724 Mdot
.49048 .5122 Mdot
.49524 .06232 Mdot
.5 .04194 Mdot
.50476 .10549 Mdot
.50952 .01118 Mdot
.51429 .14769 Mdot
.51905 .0092 Mdot
.52381 .31197 Mdot
.52857 .04728 Mdot
.53333 .0966 Mdot
.5381 .2854 Mdot
.54286 .07394 Mdot
.54762 .01258 Mdot
.55238 .09307 Mdot
.55714 .09977 Mdot
.5619 .09473 Mdot
.56667 .0483 Mdot
.57143 .09183 Mdot
.57619 .0752 Mdot
.58095 .0039 Mdot
.58571 .00122 Mdot
.59048 .13617 Mdot
.59524 .09689 Mdot
.6 .05288 Mdot
.60476 .05167 Mdot
.60952 .09009 Mdot
.61429 .10258 Mdot
.61905 .08815 Mdot
.62381 .2046 Mdot
.62857 .23929 Mdot
.63333 .05592 Mdot
.6381 .0087 Mdot
.64286 .06612 Mdot
.64762 .11807 Mdot
.65238 .04803 Mdot
.65714 .08846 Mdot
.6619 .11304 Mdot
.66667 .44879 Mdot
.67143 .07838 Mdot
.67619 .12219 Mdot
.68095 .05906 Mdot
.68571 .16459 Mdot
.69048 .09178 Mdot
.69524 .08332 Mdot
.7 .10712 Mdot
.70476 .15157 Mdot
.70952 .04769 Mdot
.71429 .01023 Mdot
.71905 .05917 Mdot
.72381 .15144 Mdot
.72857 .08808 Mdot
.73333 .0977 Mdot
.7381 .06202 Mdot
.74286 .13915 Mdot
.74762 .10066 Mdot
.75238 .20486 Mdot
.75714 .04344 Mdot
.7619 .15475 Mdot
.76667 .24554 Mdot
.77143 .037 Mdot
.77619 .16147 Mdot
.78095 .08185 Mdot
.78571 .19076 Mdot
.79048 .10099 Mdot
.79524 .11037 Mdot
.8 .17517 Mdot
.80476 .26257 Mdot
.80952 .12467 Mdot
.81429 .01353 Mdot
.81905 .08725 Mdot
.82381 .17154 Mdot
.82857 .18052 Mdot
.83333 .02274 Mdot
.8381 .30119 Mdot
.84286 .0363 Mdot
.84762 .12413 Mdot
.85238 .01762 Mdot
.85714 .27808 Mdot
.8619 .00805 Mdot
.86667 .07744 Mdot
.87143 .17768 Mdot
.87619 .12613 Mdot
.88095 .14655 Mdot
.88571 .5199 Mdot
.89048 .08554 Mdot
.89524 .20001 Mdot
.9 .12019 Mdot
.90476 .35403 Mdot
.90952 .05191 Mdot
.91429 .00984 Mdot
.91905 .03751 Mdot
.92381 .09271 Mdot
.92857 .00731 Mdot
.93333 .04485 Mdot
.9381 .06268 Mdot
.94286 .05176 Mdot
.94762 .07973 Mdot
.95238 .07317 Mdot
.95714 .09561 Mdot
.9619 .18891 Mdot
.96667 .33974 Mdot
.97143 .17881 Mdot
.97619 .24583 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .10153 Mdot
.03333 .09433 Mdot
.0381 .2729 Mdot
.04286 .13596 Mdot
.04762 .365 Mdot
.05238 .07528 Mdot
.05714 .10218 Mdot
.0619 .11858 Mdot
.06667 .11676 Mdot
.07143 .06123 Mdot
.07619 .00636 Mdot
.08095 .05459 Mdot
.08571 .10825 Mdot
.09048 .26262 Mdot
.09524 .21505 Mdot
.1 .06685 Mdot
.10476 .09315 Mdot
.10952 .22399 Mdot
.11429 .35608 Mdot
.11905 .05596 Mdot
.12381 .16047 Mdot
.12857 .06093 Mdot
.13333 .09558 Mdot
.1381 .10188 Mdot
.14286 .18383 Mdot
.14762 .12912 Mdot
.15238 .08819 Mdot
.15714 .11569 Mdot
.1619 .12626 Mdot
.16667 .17741 Mdot
.17143 .03826 Mdot
.17619 .29785 Mdot
.18095 .02841 Mdot
.18571 .03256 Mdot
.19048 .3084 Mdot
.19524 .00061 Mdot
.2 .08407 Mdot
.20476 .25632 Mdot
.20952 .05989 Mdot
.21429 .23061 Mdot
.21905 .06271 Mdot
.22381 .05617 Mdot
.22857 .14409 Mdot
.23333 .09463 Mdot
.2381 .09775 Mdot
.24286 .23543 Mdot
.24762 .12372 Mdot
.25238 .07441 Mdot
.25714 .03102 Mdot
.2619 .10598 Mdot
.26667 .02595 Mdot
.27143 .13244 Mdot
.27619 .23847 Mdot
.28095 .00079 Mdot
.28571 .2481 Mdot
.29048 .06048 Mdot
.29524 .05591 Mdot
.3 .02382 Mdot
.30476 .2271 Mdot
.30952 .09204 Mdot
.31429 .04989 Mdot
.31905 .04018 Mdot
.32381 .01453 Mdot
.32857 .04276 Mdot
.33333 .05022 Mdot
.3381 .00635 Mdot
.34286 .12582 Mdot
.34762 .07401 Mdot
.35238 .12106 Mdot
.35714 .03968 Mdot
.3619 .26614 Mdot
.36667 .18451 Mdot
.37143 .09928 Mdot
.37619 .11119 Mdot
.38095 .27448 Mdot
.38571 .17545 Mdot
.39048 .21084 Mdot
.39524 .28575 Mdot
.4 .17706 Mdot
.40476 .12216 Mdot
.40952 .08938 Mdot
.41429 .19254 Mdot
.41905 .18274 Mdot
.42381 .04946 Mdot
.42857 .08636 Mdot
.43333 .1452 Mdot
.4381 .09893 Mdot
.44286 .27543 Mdot
.44762 .03923 Mdot
.45238 .0667 Mdot
.45714 .21764 Mdot
.4619 .08314 Mdot
.46667 .10731 Mdot
.47143 .09749 Mdot
.47619 .03355 Mdot
.48095 .18531 Mdot
.48571 .4223 Mdot
.49048 .49773 Mdot
.49524 .00035 Mdot
.5 .05366 Mdot
.50476 .0857 Mdot
.50952 .09258 Mdot
.51429 .15522 Mdot
.51905 .12613 Mdot
.52381 .30579 Mdot
.52857 .08311 Mdot
.53333 .12381 Mdot
.5381 .23004 Mdot
.54286 .0955 Mdot
.54762 .07688 Mdot
.55238 .10666 Mdot
.55714 .0695 Mdot
.5619 .10209 Mdot
.56667 .04113 Mdot
.57143 .12007 Mdot
.57619 .02838 Mdot
.58095 .0208 Mdot
.58571 .08034 Mdot
.59048 .16034 Mdot
.59524 .1121 Mdot
.6 .02582 Mdot
.60476 .07363 Mdot
.60952 .04673 Mdot
.61429 .17434 Mdot
.61905 .09668 Mdot
.62381 .18977 Mdot
.62857 .23445 Mdot
.63333 .09225 Mdot
.6381 .00457 Mdot
.64286 .02686 Mdot
.64762 .15238 Mdot
.65238 .1284 Mdot
.65714 .07944 Mdot
.6619 .05057 Mdot
.66667 .48698 Mdot
.67143 .07193 Mdot
.67619 .07614 Mdot
.68095 .01449 Mdot
.68571 .14858 Mdot
.69048 .12778 Mdot
.69524 .08249 Mdot
.7 .16049 Mdot
.70476 .1447 Mdot
.70952 .01768 Mdot
.71429 .01913 Mdot
.71905 .03385 Mdot
.72381 .12596 Mdot
.72857 .01772 Mdot
.73333 .07228 Mdot
.7381 .07916 Mdot
.74286 .21206 Mdot
.74762 .06859 Mdot
.75238 .20685 Mdot
.75714 .0487 Mdot
.7619 .10334 Mdot
.76667 .23645 Mdot
.77143 .09276 Mdot
.77619 .10913 Mdot
.78095 .02429 Mdot
.78571 .16414 Mdot
.79048 .13482 Mdot
.79524 .02046 Mdot
.8 .21294 Mdot
.80476 .23851 Mdot
.80952 .11896 Mdot
.81429 .0161 Mdot
.81905 .05391 Mdot
.82381 .14162 Mdot
.82857 .15719 Mdot
.83333 .05434 Mdot
.8381 .30114 Mdot
.84286 .08054 Mdot
.84762 .07995 Mdot
.85238 .00955 Mdot
.85714 .30334 Mdot
.8619 .03654 Mdot
.86667 .0031 Mdot
.87143 .14478 Mdot
.87619 .17669 Mdot
.88095 .18131 Mdot
.88571 .53265 Mdot
.89048 .04848 Mdot
.89524 .27901 Mdot
.9 .10519 Mdot
.90476 .29943 Mdot
.90952 .0759 Mdot
.91429 .10395 Mdot
.91905 .04636 Mdot
.92381 .0011 Mdot
.92857 .06189 Mdot
.93333 .04538 Mdot
.9381 .0609 Mdot
.94286 .01594 Mdot
.94762 .05273 Mdot
.95238 .09109 Mdot
.95714 .02329 Mdot
.9619 .1279 Mdot
.96667 .28168 Mdot
.97143 .13158 Mdot
.97619 .22553 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .11992 Mdot
.03333 .01517 Mdot
.0381 .31769 Mdot
.04286 .07526 Mdot
.04762 .33231 Mdot
.05238 .00624 Mdot
.05714 .12076 Mdot
.0619 .10602 Mdot
.06667 .20419 Mdot
.07143 .07961 Mdot
.07619 .06078 Mdot
.08095 .00584 Mdot
.08571 .01223 Mdot
.09048 .24029 Mdot
.09524 .18322 Mdot
.1 .05628 Mdot
.10476 .11569 Mdot
.10952 .265 Mdot
.11429 .30582 Mdot
.11905 .06069 Mdot
.12381 .18551 Mdot
.12857 .11006 Mdot
.13333 .09807 Mdot
.1381 .11707 Mdot
.14286 .11051 Mdot
.14762 .06736 Mdot
.15238 .11403 Mdot
.15714 .07418 Mdot
.1619 .091 Mdot
.16667 .15974 Mdot
.17143 .03685 Mdot
.17619 .30856 Mdot
.18095 .06724 Mdot
.18571 .08689 Mdot
.19048 .30456 Mdot
.19524 .08305 Mdot
.2 .00344 Mdot
.20476 .16316 Mdot
.20952 .11343 Mdot
.21429 .13593 Mdot
.21905 .03056 Mdot
.22381 .08533 Mdot
.22857 .09817 Mdot
.23333 .11517 Mdot
.2381 .10201 Mdot
.24286 .19081 Mdot
.24762 .16374 Mdot
.25238 .07387 Mdot
.25714 .07022 Mdot
.2619 .02921 Mdot
.26667 .10479 Mdot
.27143 .07746 Mdot
.27619 .3138 Mdot
.28095 .07762 Mdot
.28571 .28069 Mdot
.29048 .07875 Mdot
.29524 .04916 Mdot
.3 .03338 Mdot
.30476 .24057 Mdot
.30952 .10412 Mdot
.31429 .01713 Mdot
.31905 .08831 Mdot
.32381 .01036 Mdot
.32857 .08106 Mdot
.33333 .08545 Mdot
.3381 .05921 Mdot
.34286 .12894 Mdot
.34762 .10701 Mdot
.35238 .09722 Mdot
.35714 .00736 Mdot
.3619 .30923 Mdot
.36667 .17539 Mdot
.37143 .12478 Mdot
.37619 .07688 Mdot
.38095 .2469 Mdot
.38571 .21828 Mdot
.39048 .28694 Mdot
.39524 .28428 Mdot
.4 .13445 Mdot
.40476 .12129 Mdot
.40952 .0974 Mdot
.41429 .12819 Mdot
.41905 .18111 Mdot
.42381 .08102 Mdot
.42857 .08752 Mdot
.43333 .07497 Mdot
.4381 .03815 Mdot
.44286 .25879 Mdot
.44762 .05282 Mdot
.45238 .04036 Mdot
.45714 .1912 Mdot
.4619 .07942 Mdot
.46667 .10491 Mdot
.47143 .06248 Mdot
.47619 .02562 Mdot
.48095 .21622 Mdot
.48571 .35089 Mdot
.49048 .58639 Mdot
.49524 .09159 Mdot
.5 .09318 Mdot
.50476 .05331 Mdot
.50952 .05806 Mdot
.51429 .18191 Mdot
.51905 .10658 Mdot
.52381 .30925 Mdot
.52857 .01409 Mdot
.53333 .13934 Mdot
.5381 .29219 Mdot
.54286 .08427 Mdot
.54762 .08226 Mdot
.55238 .09062 Mdot
.55714 .09939 Mdot
.5619 .02697 Mdot
.56667 .074 Mdot
.57143 .09277 Mdot
.57619 .07182 Mdot
.58095 .04647 Mdot
.58571 .14512 Mdot
.59048 .10546 Mdot
.59524 .08284 Mdot
.6 .11524 Mdot
.60476 .09265 Mdot
.60952 .04234 Mdot
.61429 .20171 Mdot
.61905 .03346 Mdot
.62381 .18571 Mdot
.62857 .24808 Mdot
.63333 .09252 Mdot
.6381 .07796 Mdot
.64286 .03409 Mdot
.64762 .18926 Mdot
.65238 .07457 Mdot
.65714 .11641 Mdot
.6619 .03788 Mdot
.66667 .50312 Mdot
.67143 .03488 Mdot
.67619 .12725 Mdot
.68095 .09061 Mdot
.68571 .09762 Mdot
.69048 .14952 Mdot
.69524 .05823 Mdot
.7 .1882 Mdot
.70476 .17163 Mdot
.70952 .03183 Mdot
.71429 .04218 Mdot
.71905 .02996 Mdot
.72381 .14488 Mdot
.72857 .09074 Mdot
.73333 .0637 Mdot
.7381 .04257 Mdot
.74286 .19872 Mdot
.74762 .06636 Mdot
.75238 .15441 Mdot
.75714 .05583 Mdot
.7619 .04717 Mdot
.76667 .21005 Mdot
.77143 .04688 Mdot
.77619 .10906 Mdot
.78095 .095 Mdot
.78571 .12271 Mdot
.79048 .19406 Mdot
.79524 .02483 Mdot
.8 .19835 Mdot
.80476 .23093 Mdot
.80952 .15002 Mdot
.81429 .00998 Mdot
.81905 .03285 Mdot
.82381 .20602 Mdot
.82857 .21858 Mdot
.83333 .02308 Mdot
.8381 .26035 Mdot
.84286 .07897 Mdot
.84762 .08837 Mdot
.85238 .05021 Mdot
.85714 .28597 Mdot
.8619 .02291 Mdot
.86667 .03222 Mdot
.87143 .06781 Mdot
.87619 .25226 Mdot
.88095 .21312 Mdot
.88571 .49172 Mdot
.89048 .13239 Mdot
.89524 .20732 Mdot
.9 .0834 Mdot
.90476 .26658 Mdot
.90952 .01063 Mdot
.91429 .13563 Mdot
.91905 .06743 Mdot
.92381 .05137 Mdot
.92857 .01959 Mdot
.93333 .07361 Mdot
.9381 .06151 Mdot
.94286 .03586 Mdot
.94762 .07268 Mdot
.95238 .08509 Mdot
.95714 .07627 Mdot
.9619 .16516 Mdot
.96667 .27462 Mdot
.97143 .06223 Mdot
.97619 .14143 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .14538 Mdot
.03333 .01724 Mdot
.0381 .30513 Mdot
.04286 .03684 Mdot
.04762 .30917 Mdot
.05238 .08383 Mdot
.05714 .09294 Mdot
.0619 .06437 Mdot
.06667 .21002 Mdot
.07143 .06776 Mdot
.07619 .01742 Mdot
.08095 .08802 Mdot
.08571 .01511 Mdot
.09048 .19046 Mdot
.09524 .09872 Mdot
.1 .05451 Mdot
.10476 .07271 Mdot
.10952 .24725 Mdot
.11429 .31378 Mdot
.11905 .0338 Mdot
.12381 .2011 Mdot
.12857 .05561 Mdot
.13333 .04717 Mdot
.1381 .05263 Mdot
.14286 .14922 Mdot
.14762 .07326 Mdot
.15238 .08825 Mdot
.15714 .03264 Mdot
.1619 .02694 Mdot
.16667 .2102 Mdot
.17143 .11834 Mdot
.17619 .36556 Mdot
.18095 .05142 Mdot
.18571 .10823 Mdot
.19048 .24899 Mdot
.19524 .03926 Mdot
.2 .02982 Mdot
.20476 .11008 Mdot
.20952 .09128 Mdot
.21429 .05763 Mdot
.21905 .03054 Mdot
.22381 .0474 Mdot
.22857 .15644 Mdot
.23333 .04711 Mdot
.2381 .08295 Mdot
.24286 .21953 Mdot
.24762 .10964 Mdot
.25238 .04218 Mdot
.25714 .09992 Mdot
.2619 .05178 Mdot
.26667 .14846 Mdot
.27143 .06327 Mdot
.27619 .26414 Mdot
.28095 .00909 Mdot
.28571 .24496 Mdot
.29048 .05889 Mdot
.29524 .10224 Mdot
.3 .04982 Mdot
.30476 .21588 Mdot
.30952 .0535 Mdot
.31429 .01945 Mdot
.31905 .05174 Mdot
.32381 .00705 Mdot
.32857 .06291 Mdot
.33333 .10293 Mdot
.3381 .08106 Mdot
.34286 .11605 Mdot
.34762 .13153 Mdot
.35238 .07243 Mdot
.35714 .00136 Mdot
.3619 .27887 Mdot
.36667 .15258 Mdot
.37143 .10399 Mdot
.37619 .01904 Mdot
.38095 .21419 Mdot
.38571 .15615 Mdot
.39048 .23403 Mdot
.39524 .28665 Mdot
.4 .21721 Mdot
.40476 .14217 Mdot
.40952 .11111 Mdot
.41429 .08718 Mdot
.41905 .10644 Mdot
.42381 .03913 Mdot
.42857 .08305 Mdot
.43333 .01925 Mdot
.4381 .03502 Mdot
.44286 .21349 Mdot
.44762 .13776 Mdot
.45238 .09245 Mdot
.45714 .12713 Mdot
.4619 .15505 Mdot
.46667 .03168 Mdot
.47143 .03556 Mdot
.47619 .05709 Mdot
.48095 .24985 Mdot
.48571 .40308 Mdot
.49048 .55849 Mdot
.49524 .06996 Mdot
.5 .05865 Mdot
.50476 .10559 Mdot
.50952 .00029 Mdot
.51429 .20447 Mdot
.51905 .0795 Mdot
.52381 .27504 Mdot
.52857 .08909 Mdot
.53333 .0997 Mdot
.5381 .33301 Mdot
.54286 .02143 Mdot
.54762 .09019 Mdot
.55238 .14597 Mdot
.55714 .11399 Mdot
.5619 .00729 Mdot
.56667 .11864 Mdot
.57143 .10368 Mdot
.57619 .03772 Mdot
.58095 .03824 Mdot
.58571 .21449 Mdot
.59048 .1121 Mdot
.59524 .01457 Mdot
.6 .04367 Mdot
.60476 .10135 Mdot
.60952 .01973 Mdot
.61429 .26074 Mdot
.61905 .07101 Mdot
.62381 .10265 Mdot
.62857 .20402 Mdot
.63333 .09794 Mdot
.6381 .13467 Mdot
.64286 .05212 Mdot
.64762 .2239 Mdot
.65238 .00433 Mdot
.65714 .14623 Mdot
.6619 .13615 Mdot
.66667 .50047 Mdot
.67143 .08657 Mdot
.67619 .08517 Mdot
.68095 .1515 Mdot
.68571 .09945 Mdot
.69048 .05006 Mdot
.69524 .03956 Mdot
.7 .23591 Mdot
.70476 .11354 Mdot
.70952 .04621 Mdot
.71429 .02498 Mdot
.71905 .102 Mdot
.72381 .13763 Mdot
.72857 .07031 Mdot
.73333 .08499 Mdot
.7381 .08811 Mdot
.74286 .26119 Mdot
.74762 .02346 Mdot
.75238 .08751 Mdot
.75714 .1155 Mdot
.7619 .02338 Mdot
.76667 .242 Mdot
.77143 .06027 Mdot
.77619 .11803 Mdot
.78095 .13193 Mdot
.78571 .19513 Mdot
.79048 .17784 Mdot
.79524 .04505 Mdot
.8 .18814 Mdot
.80476 .22974 Mdot
.80952 .23436 Mdot
.81429 .03887 Mdot
.81905 .10608 Mdot
.82381 .18122 Mdot
.82857 .2239 Mdot
.83333 .1161 Mdot
.8381 .17041 Mdot
.84286 .08001 Mdot
.84762 .07572 Mdot
.85238 .0731 Mdot
.85714 .3395 Mdot
.8619 .07866 Mdot
.86667 .05802 Mdot
.87143 .11867 Mdot
.87619 .18886 Mdot
.88095 .17477 Mdot
.88571 .42627 Mdot
.89048 .20877 Mdot
.89524 .20657 Mdot
.9 .09279 Mdot
.90476 .28597 Mdot
.90952 .00993 Mdot
.91429 .11225 Mdot
.91905 .08788 Mdot
.92381 .03887 Mdot
.92857 .02575 Mdot
.93333 .05695 Mdot
.9381 .03611 Mdot
.94286 .01799 Mdot
.94762 .09752 Mdot
.95238 .07584 Mdot
.95714 .07445 Mdot
.9619 .11287 Mdot
.96667 .30777 Mdot
.97143 .07918 Mdot
.97619 .05893 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .21298 Mdot
.03333 .03203 Mdot
.0381 .27529 Mdot
.04286 .03263 Mdot
.04762 .33085 Mdot
.05238 .05169 Mdot
.05714 .14177 Mdot
.0619 .09863 Mdot
.06667 .2828 Mdot
.07143 .04403 Mdot
.07619 .05973 Mdot
.08095 .10477 Mdot
.08571 .02924 Mdot
.09048 .10341 Mdot
.09524 .13409 Mdot
.1 .04327 Mdot
.10476 .0501 Mdot
.10952 .29782 Mdot
.11429 .39065 Mdot
.11905 .08075 Mdot
.12381 .14145 Mdot
.12857 .03829 Mdot
.13333 .05335 Mdot
.1381 .00314 Mdot
.14286 .11243 Mdot
.14762 .0529 Mdot
.15238 .09496 Mdot
.15714 .06684 Mdot
.1619 .06368 Mdot
.16667 .25601 Mdot
.17143 .08338 Mdot
.17619 .32522 Mdot
.18095 .05928 Mdot
.18571 .1138 Mdot
.19048 .26943 Mdot
.19524 .04711 Mdot
.2 .0271 Mdot
.20476 .16333 Mdot
.20952 .07111 Mdot
.21429 .00445 Mdot
.21905 .02486 Mdot
.22381 .06068 Mdot
.22857 .21233 Mdot
.23333 .02821 Mdot
.2381 .10198 Mdot
.24286 .25794 Mdot
.24762 .19502 Mdot
.25238 .07432 Mdot
.25714 .03053 Mdot
.2619 .0492 Mdot
.26667 .15207 Mdot
.27143 .01384 Mdot
.27619 .26738 Mdot
.28095 .1276 Mdot
.28571 .21427 Mdot
.29048 .09251 Mdot
.29524 .03701 Mdot
.3 .07329 Mdot
.30476 .1812 Mdot
.30952 .12108 Mdot
.31429 .03836 Mdot
.31905 .02322 Mdot
.32381 .05329 Mdot
.32857 .02409 Mdot
.33333 .1792 Mdot
.3381 .08495 Mdot
.34286 .03323 Mdot
.34762 .09422 Mdot
.35238 .04342 Mdot
.35714 .055 Mdot
.3619 .30901 Mdot
.36667 .09419 Mdot
.37143 .14471 Mdot
.37619 .07735 Mdot
.38095 .16818 Mdot
.38571 .09098 Mdot
.39048 .25458 Mdot
.39524 .29039 Mdot
.4 .2284 Mdot
.40476 .13617 Mdot
.40952 .07011 Mdot
.41429 .16567 Mdot
.41905 .02738 Mdot
.42381 .04861 Mdot
.42857 .12505 Mdot
.43333 .04951 Mdot
.4381 .00022 Mdot
.44286 .19741 Mdot
.44762 .07125 Mdot
.45238 .06501 Mdot
.45714 .04823 Mdot
.4619 .12428 Mdot
.46667 .12556 Mdot
.47143 .07421 Mdot
.47619 .02027 Mdot
.48095 .3303 Mdot
.48571 .38883 Mdot
.49048 .52002 Mdot
.49524 .11354 Mdot
.5 .01963 Mdot
.50476 .1611 Mdot
.50952 .07317 Mdot
.51429 .16658 Mdot
.51905 .04341 Mdot
.52381 .21186 Mdot
.52857 .03885 Mdot
.53333 .09247 Mdot
.5381 .31718 Mdot
.54286 .09828 Mdot
.54762 .08719 Mdot
.55238 .14442 Mdot
.55714 .11931 Mdot
.5619 .04834 Mdot
.56667 .0736 Mdot
.57143 .09219 Mdot
.57619 .08402 Mdot
.58095 .11268 Mdot
.58571 .20591 Mdot
.59048 .17815 Mdot
.59524 .03404 Mdot
.6 .06922 Mdot
.60476 .08467 Mdot
.60952 .05249 Mdot
.61429 .24982 Mdot
.61905 .07976 Mdot
.62381 .13161 Mdot
.62857 .21798 Mdot
.63333 .07833 Mdot
.6381 .09982 Mdot
.64286 .03247 Mdot
.64762 .15881 Mdot
.65238 .0596 Mdot
.65714 .12678 Mdot
.6619 .11978 Mdot
.66667 .50629 Mdot
.67143 .1295 Mdot
.67619 .09061 Mdot
.68095 .18811 Mdot
.68571 .13045 Mdot
.69048 .12883 Mdot
.69524 .03809 Mdot
.7 .15865 Mdot
.70476 .14055 Mdot
.70952 .0341 Mdot
.71429 .0547 Mdot
.71905 .06298 Mdot
.72381 .12955 Mdot
.72857 .10945 Mdot
.73333 .04122 Mdot
.7381 .18437 Mdot
.74286 .27764 Mdot
.74762 .00394 Mdot
.75238 .09376 Mdot
.75714 .14535 Mdot
.7619 .09932 Mdot
.76667 .18248 Mdot
.77143 .00872 Mdot
.77619 .19223 Mdot
.78095 .14166 Mdot
.78571 .19555 Mdot
.79048 .21878 Mdot
.79524 .04652 Mdot
.8 .14534 Mdot
.80476 .26359 Mdot
.80952 .18632 Mdot
.81429 .02694 Mdot
.81905 .19598 Mdot
.82381 .13608 Mdot
.82857 .24614 Mdot
.83333 .10048 Mdot
.8381 .11603 Mdot
.84286 .01116 Mdot
.84762 .07337 Mdot
.85238 .07878 Mdot
.85714 .34624 Mdot
.8619 .05787 Mdot
.86667 .09415 Mdot
.87143 .1164 Mdot
.87619 .17259 Mdot
.88095 .21875 Mdot
.88571 .41701 Mdot
.89048 .19853 Mdot
.89524 .15452 Mdot
.9 .07018 Mdot
.90476 .34231 Mdot
.90952 .11558 Mdot
.91429 .13054 Mdot
.91905 .07597 Mdot
.92381 .02918 Mdot
.92857 .10394 Mdot
.93333 .08714 Mdot
.9381 .03704 Mdot
.94286 .09482 Mdot
.94762 .06797 Mdot
.95238 .09803 Mdot
.95714 .05525 Mdot
.9619 .17468 Mdot
.96667 .33454 Mdot
.97143 .0761 Mdot
.97619 .00467 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .21519 Mdot
.03333 .07358 Mdot
.0381 .30685 Mdot
.04286 .07881 Mdot
.04762 .34314 Mdot
.05238 .00624 Mdot
.05714 .15291 Mdot
.0619 .18945 Mdot
.06667 .36583 Mdot
.07143 .02525 Mdot
.07619 .01683 Mdot
.08095 .14119 Mdot
.08571 .03351 Mdot
.09048 .09498 Mdot
.09524 .06732 Mdot
.1 .01066 Mdot
.10476 .01885 Mdot
.10952 .24323 Mdot
.11429 .40266 Mdot
.11905 .07614 Mdot
.12381 .2 Mdot
.12857 .08443 Mdot
.13333 .12318 Mdot
.1381 .08265 Mdot
.14286 .17673 Mdot
.14762 .08805 Mdot
.15238 .05308 Mdot
.15714 .07961 Mdot
.1619 .00814 Mdot
.16667 .32506 Mdot
.17143 .07134 Mdot
.17619 .33034 Mdot
.18095 .08879 Mdot
.18571 .10755 Mdot
.19048 .29865 Mdot
.19524 .00885 Mdot
.2 .13372 Mdot
.20476 .17671 Mdot
.20952 .04911 Mdot
.21429 .03557 Mdot
.21905 .05811 Mdot
.22381 .02029 Mdot
.22857 .19864 Mdot
.23333 .04669 Mdot
.2381 .06381 Mdot
.24286 .25261 Mdot
.24762 .25298 Mdot
.25238 .02279 Mdot
.25714 .06827 Mdot
.2619 .02905 Mdot
.26667 .15028 Mdot
.27143 .07656 Mdot
.27619 .24198 Mdot
.28095 .10131 Mdot
.28571 .16508 Mdot
.29048 .01525 Mdot
.29524 .02682 Mdot
.3 .10425 Mdot
.30476 .19921 Mdot
.30952 .12272 Mdot
.31429 .12232 Mdot
.31905 .08428 Mdot
.32381 .02566 Mdot
.32857 .0652 Mdot
.33333 .17905 Mdot
.3381 .09973 Mdot
.34286 .00529 Mdot
.34762 .05345 Mdot
.35238 .02988 Mdot
.35714 .09 Mdot
.3619 .2758 Mdot
.36667 .10222 Mdot
.37143 .13355 Mdot
.37619 .09014 Mdot
.38095 .09834 Mdot
.38571 .07804 Mdot
.39048 .25954 Mdot
.39524 .37045 Mdot
.4 .23562 Mdot
.40476 .15495 Mdot
.40952 .09462 Mdot
.41429 .18367 Mdot
.41905 .01301 Mdot
.42381 .11935 Mdot
.42857 .12764 Mdot
.43333 .08362 Mdot
.4381 .01625 Mdot
.44286 .1988 Mdot
.44762 .00843 Mdot
.45238 .08324 Mdot
.45714 .03665 Mdot
.4619 .15466 Mdot
.46667 .22387 Mdot
.47143 .02059 Mdot
.47619 .05139 Mdot
.48095 .34525 Mdot
.48571 .33094 Mdot
.49048 .43938 Mdot
.49524 .03399 Mdot
.5 .06628 Mdot
.50476 .16612 Mdot
.50952 .11979 Mdot
.51429 .12606 Mdot
.51905 .04295 Mdot
.52381 .22353 Mdot
.52857 .07511 Mdot
.53333 .04706 Mdot
.5381 .30777 Mdot
.54286 .14595 Mdot
.54762 .07465 Mdot
.55238 .11183 Mdot
.55714 .17986 Mdot
.5619 .03039 Mdot
.56667 .07469 Mdot
.57143 .12958 Mdot
.57619 .03517 Mdot
.58095 .1116 Mdot
.58571 .16656 Mdot
.59048 .19395 Mdot
.59524 .07662 Mdot
.6 .01765 Mdot
.60476 .09228 Mdot
.60952 .00563 Mdot
.61429 .19865 Mdot
.61905 .09686 Mdot
.62381 .09956 Mdot
.62857 .23006 Mdot
.63333 .04422 Mdot
.6381 .11226 Mdot
.64286 .03329 Mdot
.64762 .19445 Mdot
.65238 .09127 Mdot
.65714 .11092 Mdot
.6619 .0487 Mdot
.66667 .60897 Mdot
.67143 .11758 Mdot
.67619 .02807 Mdot
.68095 .15963 Mdot
.68571 .13565 Mdot
.69048 .09606 Mdot
.69524 .05342 Mdot
.7 .19477 Mdot
.70476 .13381 Mdot
.70952 .00339 Mdot
.71429 .0719 Mdot
.71905 .08223 Mdot
.72381 .16515 Mdot
.72857 .06177 Mdot
.73333 .04939 Mdot
.7381 .13929 Mdot
.74286 .30968 Mdot
.74762 .03058 Mdot
.75238 .07055 Mdot
.75714 .13208 Mdot
.7619 .06947 Mdot
.76667 .10109 Mdot
.77143 .07917 Mdot
.77619 .17065 Mdot
.78095 .14633 Mdot
.78571 .19452 Mdot
.79048 .14759 Mdot
.79524 .08239 Mdot
.8 .14561 Mdot
.80476 .27174 Mdot
.80952 .18359 Mdot
.81429 .01341 Mdot
.81905 .15956 Mdot
.82381 .08321 Mdot
.82857 .22037 Mdot
.83333 .08388 Mdot
.8381 .05138 Mdot
.84286 .05479 Mdot
.84762 .03033 Mdot
.85238 .12308 Mdot
.85714 .35246 Mdot
.8619 .08103 Mdot
.86667 .02129 Mdot
.87143 .13111 Mdot
.87619 .17678 Mdot
.88095 .22798 Mdot
.88571 .41016 Mdot
.89048 .22765 Mdot
.89524 .20756 Mdot
.9 .07885 Mdot
.90476 .31447 Mdot
.90952 .1016 Mdot
.91429 .09639 Mdot
.91905 .08003 Mdot
.92381 .02807 Mdot
.92857 .04096 Mdot
.93333 .07213 Mdot
.9381 .09065 Mdot
.94286 .0135 Mdot
.94762 .04679 Mdot
.95238 .03733 Mdot
.95714 .12923 Mdot
.9619 .16087 Mdot
.96667 .37695 Mdot
.97143 .08233 Mdot
.97619 .05799 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.206011 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .10301 -18 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -6 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -6 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -18 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10301 m
.03006 .10301 L
s
[(0.5)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(1)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1.5)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(2)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(2.5)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(3)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .22568 Mdot
.03333 .0423 Mdot
.0381 .33238 Mdot
.04286 .05924 Mdot
.04762 .32976 Mdot
.05238 .02191 Mdot
.05714 .11594 Mdot
.0619 .14316 Mdot
.06667 .426 Mdot
.07143 .09022 Mdot
.07619 .01579 Mdot
.08095 .11394 Mdot
.08571 .05864 Mdot
.09048 .12736 Mdot
.09524 .1252 Mdot
.1 .09438 Mdot
.10476 .00612 Mdot
.10952 .17499 Mdot
.11429 .38064 Mdot
.11905 .00747 Mdot
.12381 .19636 Mdot
.12857 .16026 Mdot
.13333 .12006 Mdot
.1381 .02687 Mdot
.14286 .20179 Mdot
.14762 .03576 Mdot
.15238 .06164 Mdot
.15714 .11003 Mdot
.1619 .06581 Mdot
.16667 .27178 Mdot
.17143 .03598 Mdot
.17619 .23799 Mdot
.18095 .14424 Mdot
.18571 .12242 Mdot
.19048 .28631 Mdot
.19524 .02159 Mdot
.2 .13791 Mdot
.20476 .19127 Mdot
.20952 .00608 Mdot
.21429 .05621 Mdot
.21905 .06583 Mdot
.22381 .03418 Mdot
.22857 .26845 Mdot
.23333 .09515 Mdot
.2381 .09273 Mdot
.24286 .16937 Mdot
.24762 .19708 Mdot
.25238 .09683 Mdot
.25714 .08121 Mdot
.2619 .10443 Mdot
.26667 .14569 Mdot
.27143 .11429 Mdot
.27619 .18969 Mdot
.28095 .12916 Mdot
.28571 .13739 Mdot
.29048 .02759 Mdot
.29524 .03498 Mdot
.3 .08959 Mdot
.30476 .19011 Mdot
.30952 .18682 Mdot
.31429 .20488 Mdot
.31905 .04643 Mdot
.32381 .05107 Mdot
.32857 .04414 Mdot
.33333 .20912 Mdot
.3381 .0942 Mdot
.34286 .01641 Mdot
.34762 .09122 Mdot
.35238 .07914 Mdot
.35714 .02876 Mdot
.3619 .3481 Mdot
.36667 .1163 Mdot
.37143 .13522 Mdot
.37619 .00888 Mdot
.38095 .06301 Mdot
.38571 .09617 Mdot
.39048 .25542 Mdot
.39524 .38313 Mdot
.4 .22781 Mdot
.40476 .22412 Mdot
.40952 .09128 Mdot
.41429 .23854 Mdot
.41905 .0385 Mdot
.42381 .05926 Mdot
.42857 .05063 Mdot
.43333 .0485 Mdot
.4381 .07601 Mdot
.44286 .16022 Mdot
.44762 .05669 Mdot
.45238 .05312 Mdot
.45714 .00756 Mdot
.4619 .20877 Mdot
.46667 .18641 Mdot
.47143 .03518 Mdot
.47619 .03186 Mdot
.48095 .33514 Mdot
.48571 .35028 Mdot
.49048 .44026 Mdot
.49524 .00491 Mdot
.5 .09534 Mdot
.50476 .07015 Mdot
.50952 .01819 Mdot
.51429 .07696 Mdot
.51905 .04405 Mdot
.52381 .19648 Mdot
.52857 .07419 Mdot
.53333 .06836 Mdot
.5381 .32486 Mdot
.54286 .10522 Mdot
.54762 .02583 Mdot
.55238 .05002 Mdot
.55714 .15144 Mdot
.5619 .04944 Mdot
.56667 .04551 Mdot
.57143 .08651 Mdot
.57619 .04316 Mdot
.58095 .13065 Mdot
.58571 .16207 Mdot
.59048 .16136 Mdot
.59524 .15249 Mdot
.6 .05033 Mdot
.60476 .01017 Mdot
.60952 .074 Mdot
.61429 .20134 Mdot
.61905 .05097 Mdot
.62381 .10735 Mdot
.62857 .23052 Mdot
.63333 .01307 Mdot
.6381 .10605 Mdot
.64286 .11692 Mdot
.64762 .14725 Mdot
.65238 .06619 Mdot
.65714 .06072 Mdot
.6619 .0144 Mdot
.67143 .0284 Mdot
.67619 .01888 Mdot
.68095 .18198 Mdot
.68571 .12137 Mdot
.69048 .0816 Mdot
.69524 .06315 Mdot
.7 .114 Mdot
.70476 .0918 Mdot
.70952 .06097 Mdot
.71429 .01681 Mdot
.71905 .0609 Mdot
.72381 .09001 Mdot
.72857 .10022 Mdot
.73333 .0936 Mdot
.7381 .09522 Mdot
.74286 .35506 Mdot
.74762 .10057 Mdot
.75238 .11345 Mdot
.75714 .17498 Mdot
.7619 .07035 Mdot
.76667 .12397 Mdot
.77143 .11719 Mdot
.77619 .14299 Mdot
.78095 .14172 Mdot
.78571 .11824 Mdot
.79048 .12017 Mdot
.79524 .04824 Mdot
.8 .0546 Mdot
.80476 .28048 Mdot
.80952 .13227 Mdot
.81429 .14448 Mdot
.81905 .10879 Mdot
.82381 .05389 Mdot
.82857 .2647 Mdot
.83333 .12982 Mdot
.8381 .0441 Mdot
.84286 .02543 Mdot
.84762 .01454 Mdot
.85238 .04324 Mdot
.85714 .32763 Mdot
.8619 .1532 Mdot
.86667 .01772 Mdot
.87143 .08971 Mdot
.87619 .2084 Mdot
.88095 .14198 Mdot
.88571 .42174 Mdot
.89048 .2332 Mdot
.89524 .22361 Mdot
.9 .05629 Mdot
.90476 .29877 Mdot
.90952 .1029 Mdot
.91429 .05771 Mdot
.91905 .12931 Mdot
.92381 .03261 Mdot
.92857 .04146 Mdot
.93333 .09586 Mdot
.9381 .01072 Mdot
.94286 .03259 Mdot
.94762 .04189 Mdot
.95238 .04478 Mdot
.95714 .09359 Mdot
.9619 .13959 Mdot
.96667 .34783 Mdot
.97143 .11288 Mdot
.97619 .03919 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-26, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The random diffusion causes the particles to dance above the bottom of the \
container, so that the density distribution attains an equilibrium.  This \
equilibrium can also be seen in the behavior of average quantities, such as \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "x", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", shown in Cell ",
  ButtonBox["8.20",
    ButtonData:>"Cell 8.20",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xav[n_]\  := \ Mean[pos[n]];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[{n, xav[n]}, {n, 0, 150}], 
        AxesLabel \[Rule] {"\<n\>", "\<<x>\>"}, 
        PlotRange \[Rule] {0, 2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.20"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0 0.309017 [
[.15079 -0.0125 -6 -9 ]
[.15079 -0.0125 6 0 ]
[.27778 -0.0125 -6 -9 ]
[.27778 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.53175 -0.0125 -6 -9 ]
[.53175 -0.0125 6 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.9127 -0.0125 -9 -9 ]
[.9127 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -11 0 ]
[.02381 .64303 11 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 0 m
.15079 .00625 L
s
[(20)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(40)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(60)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(80)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(100)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(120)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(140)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .61803 Mdot
.03016 .61442 Mdot
.03651 .60678 Mdot
.04286 .60002 Mdot
.04921 .59432 Mdot
.05556 .58814 Mdot
.0619 .57887 Mdot
.06825 .5646 Mdot
.0746 .5556 Mdot
.08095 .54851 Mdot
.0873 .54249 Mdot
.09365 .52964 Mdot
.1 .52075 Mdot
.10635 .51665 Mdot
.1127 .50673 Mdot
.11905 .49549 Mdot
.1254 .48309 Mdot
.13175 .47343 Mdot
.1381 .46718 Mdot
.14444 .45685 Mdot
.15079 .44996 Mdot
.15714 .44378 Mdot
.16349 .43384 Mdot
.16984 .42544 Mdot
.17619 .41565 Mdot
.18254 .40909 Mdot
.18889 .40713 Mdot
.19524 .39796 Mdot
.20159 .3905 Mdot
.20794 .38321 Mdot
.21429 .37762 Mdot
.22063 .37046 Mdot
.22698 .36618 Mdot
.23333 .36049 Mdot
.23968 .36103 Mdot
.24603 .35609 Mdot
.25238 .34536 Mdot
.25873 .33506 Mdot
.26508 .32812 Mdot
.27143 .32073 Mdot
.27778 .31537 Mdot
.28413 .31264 Mdot
.29048 .3076 Mdot
.29683 .3022 Mdot
.30317 .30341 Mdot
.30952 .30251 Mdot
.31587 .29401 Mdot
.32222 .2907 Mdot
.32857 .29031 Mdot
.33492 .28626 Mdot
.34127 .28194 Mdot
.34762 .27309 Mdot
.35397 .26762 Mdot
.36032 .2669 Mdot
.36667 .26532 Mdot
.37302 .25917 Mdot
.37937 .2597 Mdot
.38571 .2539 Mdot
.39206 .25038 Mdot
.39841 .24454 Mdot
.40476 .24776 Mdot
.41111 .24138 Mdot
.41746 .24441 Mdot
.42381 .24078 Mdot
.43016 .24267 Mdot
.43651 .24181 Mdot
.44286 .23723 Mdot
.44921 .22997 Mdot
.45556 .23301 Mdot
.4619 .22661 Mdot
.46825 .22219 Mdot
.4746 .21581 Mdot
.48095 .21585 Mdot
.4873 .2181 Mdot
.49365 .21585 Mdot
.5 .21377 Mdot
.50635 .21139 Mdot
.5127 .21352 Mdot
.51905 .21219 Mdot
.5254 .20581 Mdot
.53175 .20263 Mdot
.5381 .19515 Mdot
.54444 .20086 Mdot
.55079 .19237 Mdot
.55714 .19085 Mdot
.56349 .18557 Mdot
.56984 .18447 Mdot
.57619 .18329 Mdot
.58254 .1843 Mdot
.58889 .1829 Mdot
.59524 .18453 Mdot
.60159 .18642 Mdot
.60794 .18572 Mdot
.61429 .17954 Mdot
.62063 .181 Mdot
.62698 .1836 Mdot
.63333 .18824 Mdot
.63968 .19107 Mdot
.64603 .18976 Mdot
.65238 .18805 Mdot
.65873 .18518 Mdot
.66508 .18248 Mdot
.67143 .1821 Mdot
.67778 .18267 Mdot
.68413 .18021 Mdot
.69048 .1721 Mdot
.69683 .1746 Mdot
.70317 .18054 Mdot
.70952 .18121 Mdot
.71587 .18008 Mdot
.72222 .18207 Mdot
.72857 .18411 Mdot
.73492 .18215 Mdot
.74127 .18189 Mdot
.74762 .1831 Mdot
.75397 .1803 Mdot
.76032 .17801 Mdot
.76667 .18056 Mdot
.77302 .183 Mdot
.77937 .18324 Mdot
.78571 .1816 Mdot
.79206 .1809 Mdot
.79841 .17755 Mdot
.80476 .18097 Mdot
.81111 .18642 Mdot
.81746 .18776 Mdot
.82381 .18772 Mdot
.83016 .18716 Mdot
.83651 .19181 Mdot
.84286 .19563 Mdot
.84921 .19334 Mdot
.85556 .19287 Mdot
.8619 .18743 Mdot
.86825 .18434 Mdot
.8746 .18712 Mdot
.88095 .18657 Mdot
.8873 .19004 Mdot
.89365 .19663 Mdot
.9 .19655 Mdot
.90635 .1873 Mdot
.9127 .18613 Mdot
.91905 .18482 Mdot
.9254 .18834 Mdot
.93175 .18818 Mdot
.9381 .18806 Mdot
.94444 .19133 Mdot
.95079 .18935 Mdot
.95714 .18693 Mdot
.96349 .18491 Mdot
.96984 .18765 Mdot
.97619 .18841 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Aoooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06Oooool01Oo^k^ko<S8b
o`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo1?l00000
0ol@413oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`Co000000?o
410@ooooooooool00_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
02gooooo0017ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go
EEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0;Oooool004Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41006Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Iooooo`05
o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01Sooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@400Cooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@01Cooooo00?o0000ooooooooool00_ooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400]ooooo`00BOooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000006Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000006Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00000Iooooo`05
oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool00000;Oooool004[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000001Wooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001Wooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooooooooooo
ool000006Oooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`00
000Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000004oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000002gooooo001;ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0Hooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooo
oooooa0@400Iooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo
410@01Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo01;ooooo00?o0000ooooooooool00oooool00omgMgOo
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100;Oooool004Oooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06Oooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`02ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000oooooooo
ool00oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;Oooool004Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01?o<c<coA4A4o`00
0?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Fooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00omEEEGoIVIV
o`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01;ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooEoooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00Wooooo003ooooooeSooooo00Go0000oooooooooooo
ooooo`00000<ooooo`00oooooomHooooo`05o`000?ooooooooooooooool000003?ooool002;ooooo
ool0000[o`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`00:Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?n7QhOoooooojVYZOl000003?ooool002Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Rooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
2_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo?_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool2o`000?oooooo?_ooool000kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00033ooooo`;o0000N?oo
ool002Wooooo00?o0000ooooooooool0`_ooool4o`0007Kooooo000Yooooo`03o`000?oooooooooo
0:cooooo0_l0000Booooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`Co00002Oooool2o`00
05Sooooo000Yooooo`03o`000?oooooooooo0:3ooooo0_l00002ooooo`;o00001_ooool5o`0000[o
oooo1ol00004ooooo`So00000_oooolFo`0005Kooooo000Yooooo`;o0000W_ooool?o`0000;ooooo
0ol00008ooooo`So00001Oooool4o`0000;ooooo2Ol00004ooooo`[o000000?oooooo`000?l00000
0_l00004ooooo`;o00002Oooool6o`0000Sooooo0ol0000:ooooo`Co00009_ooool002Wooooo00?o
0000ooooooooool0WOooool3o`0000;ooooo0_l00002ooooo`Ko00001Oooool2o`0000;ooooo1_l0
000Cooooo`;o00005_ooool8o`0000Oooooo2_l00004ooooo`_o00000_ooool9o`0002?ooooo000Y
ooooo`03o`000?oooooooooo09Wooooo1?l0000Dooooo`So0000;oooool4o`0000;ooooo0_l00002
ooooo`Go00001_ooool2o`0000Cooooo0_l00003ooooo`[o00001?ooool3o`0002?ooooo000Yoooo
o`03o`000?oooooooooo09Gooooo0_l00002ooooo`Co00005_ooool2o`0003Wooooo1ol0000:oooo
o`Co00002oooool2o`0002cooooo000Yooooo`03o`000?oooooooooo09Gooooo0_l0001Iooooo`;o
00003Oooool4o`0003Wooooo000Yooooo`;o0000U?ooool2o`0000;ooooo0_l0002Sooooo`00:Ooo
ool00ol0003oooooooooo`2Aooooo`Co00000_ooool2o`000:?ooooo000Yooooo`03o`000?oooooo
oooo097ooooo0_l0002Yooooo`00:Oooool00ol0003oooooooooo`2:ooooo`Oo0000Zoooool002Wo
oooo0_l00023ooooo`Co00000_ooool9o`000:_ooooo000Yooooo`03o`000?oooooooooo08;ooooo
2?l0002booooo`00:Oooool00ol0003oooooooooo`20ooooo`;o00001?ooool2o`000;Cooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0O_ooool4o`000;[ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07_ooooo0_l000000ooooooo0000
o`00002looooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`;o0000O?ooool3o`000;kooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0NOooool2o`000003ooooool0003o00000;kooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1cooooo`;o00001?ooool2o`000<7ooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Koooool2o`0000;ooooo1_l00033ooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Joooool2o`0000;ooooo1?l00002ooooo`Co0000`oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0001[oooo
o`Go00000_ooool2o`000<Wooooo000Yooooo`03o`000?oooooooooo06Sooooo1?l000000ooooooo
0000o`00003=ooooo`00:Oooool00ol0003oooooooooo`1Xooooo`;o0000d_ooool002Wooooo00?o
0000ooooooooool0I?ooool4o`000=Cooooo000Yooooo`;o0000IOooool4o`000=Cooooo000Yoooo
o`03o`000?oooooooooo05kooooo1_l0003Hooooo`00:Oooool00ol0003oooooooooo`1Nooooo`Ko
0000f?ooool002Wooooo00?o0000ooooooooool0G?ooool2o`000=kooooo000Yooooo`03o`000?oo
oooooooo05cooooo0_l0003Nooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0F_ooool2o`000>3ooooo000Yooooo`03o`000?oooooooooo05Wooooo0ol0003Pooooo`00
:Oooool00ol0003oooooooooo`1Eooooo`Ko0000hOooool002Wooooo0_l0001Dooooo`Ko0000hooo
ool002Wooooo00?o0000ooooooooool0Doooool2o`000>Oooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04go
oooo1_l0003Yooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
2?l0003Yooooo`008Oooool00ol0003oooooooooo`05ooooo`;o0000C?ooool2o`000>oooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool2o`000?7ooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool3o`000?7ooooo000Qooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool4o`000?;ooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool2o`000?Cooooo000Oooooo`03oeEEEOmV
IVKo000000Oooooo0_l00015ooooo`;o0000m_ooool002Wooooo00?o0000ooooooooool0A?ooool2
o`000?Kooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0@_ooool2o`000?Sooooo000Yooooo`;o0000@oooool2o`000?Sooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0@?ooool2o`000?[ooooo000Yoooo
o`03o`000?oooooooooo043ooooo0_l0003jooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000?oooool2o`000?cooooo000Yooooo`03o`000?oooooooooo03[ooooo1_l0
003looooo`00:Oooool00ol0003oooooooooo`0jooooo`Co0000o_ooool002Wooooo00?o0000oooo
ooooool0>?ooool2o`000?oooooo0oooool002Wooooo0_l0000hooooo`?o0000ooooool3ooooo`00
:Oooool00ol0003oooooooooo`0gooooo`;o0000ooooool4ooooo`00:Oooool00ol0003ooooooooo
o`0eooooo`;o0000ooooool6ooooo`001oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=Ooo
ool2o`000?oooooo1_ooool000Wooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<ooo
ool2o`000?oooooo2?ooool000Wooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo0_l0000dooooo`;o0000ooooool8ooooo`002Oooool00ol0
003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0aooooo`;o0000ooooool:ooooo`002Oooool00ol0003oooooooooo`0=ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
037ooooo0_l0003oooooo`[ooooo0009ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0_l0003oooooo`co
oooo0009ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool2o`000?oooooo3?ooool000Oooooo
00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o0000ooooool>ooooo`00:Ooo
ool00ol0003oooooooooo`0[ooooo`Co0000ooooool>ooooo`00:Oooool00ol0003oooooooooo`0[
ooooo`;o0000ooooool@ooooo`00:Oooool2o`0002[ooooo0_l0003ooooooa;ooooo000Yooooo`03
o`000?oooooooooo02Wooooo0_l0003ooooooa;ooooo000Yooooo`03o`000?oooooooooo02Oooooo
0_l0003ooooooaCooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaCooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0000Vooooo`;o0000oooooolFoooo
o`00:Oooool00ol0003oooooooooo`0Uooooo`;o0000oooooolFooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0003ooooooaOooooo000Y
ooooo`;o00009Oooool2o`000?oooooo5oooool002Wooooo00?o0000ooooooooool08_ooool2o`00
0?oooooo6Oooool002Wooooo00?o0000ooooooooool08_ooool2o`000?oooooo6Oooool000oooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool08?ooool2o`000?oooooo6oooool0017ooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000
oooooolKooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0_l0
003oooooockooooo000Aooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0Nooooo`;o0000oooooolMooooo`004Oooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Nooooo`;o0000oooooolM
ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool07?ooool2o`000?oooooo7oooool0017ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01cooooo0_l0003ooooooaoooooo000?ooooo`03oeEE
EOmVIVKo000000gooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`;o0000oooooolQooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000oooooolQ
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o00006Oooool2o`000?oo
oooo8oooool002Wooooo00?o0000ooooooooool06?ooool2o`000?oooooo8oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo01Kooooo0_l0003oooooobGooooo000Yooooo`;o00005oooool2o`000?oo
oooo9Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`0Dooooo`;o0000oooooolWooooo`00:Oooool00ol0003oooooooooo`0Cooooo`?o0000oooooolW
ooooo`00:Oooool2o`0001Cooooo0_l0003oooooobSooooo000Yooooo`03o`000?oooooooooo017o
oooo0_l0003oooooob[ooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0003oooooob[ooooo
0007ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`002Ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`002Oooool00ol0003oooooooooo`0<
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool2o`00013ooooo0_l0003o
ooooobcooooo0009ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0_l0003oooooobcooooo0009ooooo`03
o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool03Oooool2o`000?oooooo;_ooool000Wooooo00?o0000oooooooo
ool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool2o`000?oooooo;_ooool000Wooooo00?o0000ooooooooool02_ooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o
0000ooooool`ooooo`001oooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo
0_l0000<ooooo`;o0000ooooool`ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo00Wooooo0_l0003ooooooc;ooooo000Yooooo`03o`000?oooooooooo
00Wooooo0_l0003ooooooc;ooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocCooooo000Y
ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocCooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l00006ooooo`;o0000oooooolfooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`;o0000oooooolfooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o0000oooo
oolhooooo`00:Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolhooooo`00:Oooool2o`00
00?ooooo0_l0003oooooocWooooo000Yooooo`03o`000?oooooooooo00;o0000oooooolkooooo`00
:Oooool00ol0003oooooooooo`02o`000?oooooo>oooool001kooooo1Ol00006ooooo`03o`000?oo
oooooooo0?oooooo?Oooool001kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`?o0000oooo
oolmooooo`007oooool00onHV9So8B4Qonk^kP06ooooo`Co0000oooooolmooooo`008?ooool00onH
V9So8B4Qonk^kP05ooooo`;o0000ooooooloooooo`008Oooool00omgMgOoIVIVooooo`3oooooodGo
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool001kooooo00Go0000okZj^_ooooooV9RH
oa0@403oooooodKooooo000Nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom6ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`008_ooool01?nHV9So8B4Qooooooooool2o`0000;ooooo0_l000000ooooooo8B4QoiRH
V03ooooooc[ooooo000Oooooo`05omgMgOmVIVKo0000oeEEEOnj^[X00_ooool03?o^k^ko8B4QohN7
Qonj^[[o0000omgMgOooooooZJVYoeEEEOl0003oIVIVomgMgOoooooo=oooool001kooooo00CoV9RH
o`000?l@413ogMgM1Oooool01?oMgMgo0000oa0@4?o<c<`4ooooo`04omgMgOl@413o0000oiRHV?oo
oooo=_ooool001oooooo00GogMgMofIVI_l0003oEEEEokZj^P03ooooo`04onk^k_lQ8B7o410@onk^
kP;ooooo00Go^[ZjoeEEEOl0003oIVIVomgMg@3oooooocOooooo000Rooooo`03oiRHV?lQ8B7ooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b0_ooool00olQ8B7oV9RHooooo`3oooooocWooooo000Voooo
o`;o00000_ooool2o`000?oooooo?Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.7498, -0.162769, \
0.661415, 0.0135898}}]
}, Open  ]],

Cell[TextData[{
  "\tIn a real system, this  equilibrium is called a ",
  StyleBox["thermal equilibrium",
    FontSlant->"Italic"],
  " ",
  StyleBox["state",
    FontSlant->"Italic"],
  ". To what extent does our random process model true thermal equilibrium?  \
In order to answer this question, we  need the proper functional form of the \
thermal equilibrium distribution. "
}], "Text",
  CellTags->"i:80"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["8.2.3 Thermal Equilibrium", "Subsubtitle",
  CellTags->{"i:42", "c:21"}],

Cell[CellGroupData[{

Cell["The Boltzmann Distribution", "Section",
  CellTags->{"i:56", "c:22"}],

Cell[TextData[{
  " The thermal equilibrium distribution of particles in an external \
potential was first derived by Boltzmann, and is referred to as the Boltzmann \
distribution  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Rho]\_B\)(x)\)\(\ \)\)\)]],
  ". One way to derive this distribution is as a time-independent solution of \
the Fokker-Planck equation ",
  ButtonBox["(8.2.18)",
    ButtonData:>{"Chapter8.nb", "(8.2.18)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "=", "  ", 
          RowBox[{\(\[PartialD]\/\[PartialD]x\), "[", " ", 
            RowBox[{
              RowBox[{\(v(x)\), Cell[""], \(\[Rho]\_B\)}], "-", 
              " ", \(\(D(x)\)\ \[PartialD]\[Rho]\_B\/\[PartialD]x\)}], "]"}], 
          " "}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell["Integrating this equation once yields", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma] = \ \ \(v(
              x)\)\ \[Rho]\_B\  - \ \(\(D\)\(\ \)\((x)\) \
\(\[PartialD]\[Rho]\_B\/\[PartialD]x\)\(\ \)\)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)]],
  " is a constant of integration. However, the ",
  "right-hand",
  " side is the particle flux (divided by the total number of particles) \
caused by diffusion and convection at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". Since we assume that ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " is impermeable, the flux must be zero there, and this implies ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma] = 0\)]],
  ", as one would expect in equilibrium. The resulting first -order \
differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\)]],
  " has the general solution "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_B\)(x)\  = \ 
        C\ \[ExponentialE]\^\(\[Integral]\_0\%x\(\( v(x\^\[Prime])\)\/\(D(x\^\
\[Prime])\)\) \[DifferentialD]x\^\[Prime]\)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  "is another constant of integration. (Note that ",
  Cell[BoxData[
      \(TraditionalForm\`v < 0\)]],
  " is assumed, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_B\)(x) \[Rule] 0\)]],
  " exponentially as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \[Infinity]\)]],
  ".) The constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " can be obtained from the normalization condition for all probability \
densities, Eq. ",
  ButtonBox["(8.1.37)",
    ButtonData:>{"Chapter8.nb", "(8.1.37)"},
    ButtonStyle->"Hyperlink"],
  ". The result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_B\)(
          x)\  = \ \[ExponentialE]\^\(\[Integral]\_0\%x\(\( \
v(x\^\[Prime])\)\/\(D(x\^\[Prime])\)\) \[DifferentialD]x\^\[Prime]\)/\(\
\[Integral]\_0\%\[Infinity]\[DifferentialD]x\^\[DoublePrime]\ \[ExponentialE]\
\^\(\[Integral]\_0\%\(x\^\[DoublePrime]\)\(\(v(x\^\[Prime])\)\/\(D(x\^\[Prime]\
)\)\) \[DifferentialD]x\^\[Prime]\)\)\)]],
  "."
}], "NE2",
  CellTags->"(8.2.24)"],

Cell[TextData[{
  "\tThe Boltzmann distribution can also be derived directly using the theory \
of equilibrium statistical mechanics, without reference to the Fokker-Planck \
equation. It is the distribution that maximizes the entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "  for particles trapped in a given potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  ", with given mean potential energy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "\[Phi]", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " per particle.  This form of the Boltzmann distribution is written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_B\)(
          x)\  = \ \[ExponentialE]\^\(\(-\(\[Phi](x)\)\)/k\_B  T\)/\(\
\[Integral]\[DifferentialD]x\^\[DoublePrime]\ \ \[ExponentialE]\^\(\(-\(\[Phi]\
(x\^\[DoublePrime])\)\)/k\_B  T\)\)\)]],
  ","
}], "NE2",
  CellTags->"(8.2.25)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is the temperature of the system, and where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  "is Boltzmann's constant. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Einstein Relations", "Section",
  CellTags->{"i:57", "c:23"}],

Cell[TextData[{
  "\t At first glance, Eqs. ",
  ButtonBox["(8.2.24)",
    ButtonData:>{"Chapter8.nb", "(8.2.24)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.2.25)",
    ButtonData:>{"Chapter8.nb", "(8.2.25)"},
    ButtonStyle->"Hyperlink"],
  " appear to be unrelated. The fact that they are actually identical \
distributions leads to a nontrivial result,  called an ",
  StyleBox["Einstein relation",
    FontSlant->"Italic"],
  ". In order for Eqs. ",
  ButtonBox["(8.2.24)",
    ButtonData:>{"Chapter8.nb", "(8.2.24)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.2.25)",
    ButtonData:>{"Chapter8.nb", "(8.2.25)"},
    ButtonStyle->"Hyperlink"],
  " to be identical distributions, it must be the case that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v(x)\)\/\(D(x)\) = \(-\(1\/\(\(k\_B\) 
                  T\)\)\) \[PartialD]\(\[Phi](x)\)\/\[PartialD]x\)]],
  ". "
}], "NE2",
  CellTags->"(8.2.26)"],

Cell[TextData[{
  "On the other hand, the drift velocity of a particle should be determined \
by the balance between the force ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[PartialD]\[Phi]\)/\[PartialD]x\)]],
  " on the particle and the collisional drag:  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", " ", "=", " ", 
          RowBox[{\(\(-m\)\ \[Gamma]\ v\), " ", "-", " ", 
            FormBox[\(\[PartialD]\[Phi]/\[PartialD]x\),
              "TraditionalForm"], "  "}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the particle mass and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the drag coefficient. This implies that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(v(
        x)\  = \(-\ \(1\/\(m\ \[Gamma]\)\)\) \[PartialD]\(\[Phi](x)\)\/\
\[PartialD]x\)\(,\)\)\)]]], "NE2",
  CellTags->"(8.2.27)"],

Cell[TextData[{
  "which is simply the usual  expression for terminal velocity.  Comparing \
Eqs. ",
  ButtonBox["(8.2.26)",
    ButtonData:>{"Chapter8.nb", "(8.2.26)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(8.2.27)",
    ButtonData:>{"Chapter8.nb", "(8.2.27)"},
    ButtonStyle->"Hyperlink"],
  " leads to the Einstein relation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`D\  = \ \(k\_B\ T\)\/\(m\ \[Gamma]\)\)]],
  "."
}], "NE2",
  CellTags->"(8.2.28)"],

Cell[TextData[{
  "This important and nontrivial relation between seemingly unconnected \
quantities was first discovered by Einstein in his doctoral research on \
Brownian motion of dust grains in a fluid. Diffusion and frictional drag are \
inversely proportional to one another in a thermal-equilibrium system. Note \
that the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " often cannot be calculated directly from the detailed microscopic \
collision processes that are responsible for the diffusion and drag. However, \
the drag rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " can be easily ",
  StyleBox["measured",
    FontSlant->"Italic"],
  " in experiments, and then Eq. ",
  ButtonBox["(8.2.28)",
    ButtonData:>{"Chapter8.nb", "(8.2.28)"},
    ButtonStyle->"Hyperlink"],
  " provides a prediction for ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  ". This prediction has been verified time and again in experiments on \
disparate systems. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Irreversibility and the Free Energy", "Section",
  CellTags->{"i:58", "c:24"}],

Cell[TextData[{
  "\tSolutions to the inhomogeneous Fokker-Planck equation approach thermal \
equilibrium monotonically over time, in the following sense. The following \
function, called the ",
  StyleBox["Helmholtz free energy per particle, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ", ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "decreases monotonically:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(F(t)\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "\[Phi]", 
                "\[RightAngleBracket]"}], \((t)\)}], " ", "-", 
            " ", \(T\ \(S(t)\)\)}], 
          "=", \(\[Integral]\(\[Phi](x)\)\ \(\[Rho](x, 
                  t)\) \[DifferentialD]x\  + \ \(k\_B\) 
              T \(\[Integral]\[DifferentialD]x\ \(\[Rho](x, 
                    t)\)\ ln\ \(\(\[Rho](x, t)\)\(\ \)\(.\)\)\)\)}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(8.2.29)"],

Cell[TextData[{
  "Through an analysis analogous to that used to prove Eq. ",
  ButtonBox["(8.1.44)",
    ButtonData:>{"Chapter8.nb", "(8.1.44)"},
    ButtonStyle->"Hyperlink"],
  ", one can show that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]F/\[DifferentialD]t = \(-k\_B\)\ T \(\
\[Integral]\(\[DifferentialD]x\/\(\(\[Rho](x, t)\)\ \(D(x)\)\)\)[\(v(x)\)\ \(\
\[Rho](x, t)\) - \(D(x)\)\ \[PartialD]\[Rho]\/\[PartialD]x]\^\(\(\ \
\)\(2\)\)\) \[LessEqual] \ \ 0\)]]], "NE2",
  CellTags->"(8.2.30)"],

Cell[TextData[{
  "(see the exercises). When thermal equilibrium is achieved, the particle \
flux (the square bracket) vanishes and ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F/\[DifferentialD]t = 0\)]],
  ".  Thus, solutions of the inhomogeneous Fokker-Planck equation display \
irreversibility: initial conditions that are out of thermal equilibrium never \
recur. The dust never re-forms in a layer back at the top of the fluid. (Of \
course, this neglects the extremely unlikely possibility of Poincar\[EAcute] \
recurrence back to the initial state, as discussed previously in Sec. ",
  ButtonBox["8.1.2",
    ButtonData:>"c:4",
    ButtonStyle->"Hyperlink"],
  ". )"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparison with Simulations", "Section",
  CellTags->"c:25"],

Cell[TextData[{
  "\tLets now compare our previous simulation of dust grains settling in a \
fluid with the predictions of thermal equilibrium.   For these simulations,  \
",
  Cell[BoxData[
      \(TraditionalForm\`v\  = \ \(-1\)/36\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D = 13/1296\)]],
  " are independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", so Eq. ",
  ButtonBox["(8.2.24)",
    ButtonData:>{"Chapter8.nb", "(8.2.24)"},
    ButtonStyle->"Hyperlink"],
  " predicts that the Boltzmann distribution is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\  = \(\(C\)\(\ \
\)\(\[ExponentialE]\^\(-\(\(|\)\(v\)\(|\)\(\ \)\(x/D\)\)\)\)\(\ \)\)\)]],
  " "
}], "NE2",
  CellTags->"(8.2.31)"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`C\  = \ \(\(|\)\(v\)\(|\)\(\(/\)\(D\)\)\)\)]],
  ". This exponential distribution is also what one would obtain from Eq. ",
  ButtonBox["(8.2.25)",
    ButtonData:>{"Chapter8.nb", "(8.2.25)"},
    ButtonStyle->"Hyperlink"],
  " for dust grains in a gravitational field ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\  = \ m\ g\ x\)]],
  ": the grains pile up against the bottom of the container with an \
exponential tail in their density due to finite temperature.  In Cell ",
  ButtonBox["8.21",
    ButtonData:>"Cell 8.21",
    ButtonStyle->"Hyperlink"],
  " this thermal  distribution is compared with a histogram of the particle \
positions, obtained from averaging over the last 20 timesteps in the previous \
simulation of ",
  Cell[BoxData[
      \(TraditionalForm\`M = 200\)]],
  " particles. We take histogram bins of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.1"}], 
        TraditionalForm]]],
  ", so the number of particles in each bin should be ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(H(x)\), " ", "=", " ", 
          RowBox[{"20", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "  ", "M", 
            " ", \(\(\[Rho]\_eq\)(x)\)}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(p1\  = \ 
        Histogram[Flatten[Table[pos[n], {n, 131, 150}]], 
          HistogramRange \[Rule] {0, 2}, HistogramCategories \[Rule] 20, 
          DisplayFunction \[Rule] Identity];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(d = 13/1296; v = 1/36; \[CapitalDelta]x = 0.1;\), "\n", 
    \(\(\[Rho]B[x_]\  = \ v/d\ Exp[\(-v\)\ x/d];\)\), "\n", 
    \(\(\(p2\  = \ 
        Plot[20\ \[CapitalDelta]x\ M\ \[Rho]B[x], {x, 0, 2}, 
          DisplayFunction \[Rule] Identity];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Show[p1, p2, AxesLabel \[Rule] {"\<x\>", "\<h(x)\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.21"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.47619 0.0147151 0.000531379 [
[.2381 .00222 -9 -9 ]
[.2381 .00222 9 0 ]
[.47619 .00222 -3 -9 ]
[.47619 .00222 3 0 ]
[.71429 .00222 -9 -9 ]
[.71429 .00222 9 0 ]
[.95238 .00222 -3 -9 ]
[.95238 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[-0.0125 .12099 -18 -4.5 ]
[-0.0125 .12099 0 4.5 ]
[-0.0125 .22727 -18 -4.5 ]
[-0.0125 .22727 0 4.5 ]
[-0.0125 .33354 -18 -4.5 ]
[-0.0125 .33354 0 4.5 ]
[-0.0125 .43982 -18 -4.5 ]
[-0.0125 .43982 0 4.5 ]
[-0.0125 .54609 -24 -4.5 ]
[-0.0125 .54609 0 4.5 ]
[0 .64303 -14 0 ]
[0 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 .01472 m
.2381 .02097 L
s
[(0.5)] .2381 .00222 0 1 Mshowa
.47619 .01472 m
.47619 .02097 L
s
[(1)] .47619 .00222 0 1 Mshowa
.71429 .01472 m
.71429 .02097 L
s
[(1.5)] .71429 .00222 0 1 Mshowa
.95238 .01472 m
.95238 .02097 L
s
[(2)] .95238 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12099 m
.00625 .12099 L
s
[(200)] -0.0125 .12099 1 0 Mshowa
0 .22727 m
.00625 .22727 L
s
[(400)] -0.0125 .22727 1 0 Mshowa
0 .33354 m
.00625 .33354 L
s
[(600)] -0.0125 .33354 1 0 Mshowa
0 .43982 m
.00625 .43982 L
s
[(800)] -0.0125 .43982 1 0 Mshowa
0 .54609 m
.00625 .54609 L
s
[(1000)] -0.0125 .54609 1 0 Mshowa
.125 Mabswid
0 .04128 m
.00375 .04128 L
s
0 .06785 m
.00375 .06785 L
s
0 .09442 m
.00375 .09442 L
s
0 .14756 m
.00375 .14756 L
s
0 .17413 m
.00375 .17413 L
s
0 .2007 m
.00375 .2007 L
s
0 .25384 m
.00375 .25384 L
s
0 .2804 m
.00375 .2804 L
s
0 .30697 m
.00375 .30697 L
s
0 .36011 m
.00375 .36011 L
s
0 .38668 m
.00375 .38668 L
s
0 .41325 m
.00375 .41325 L
s
0 .46639 m
.00375 .46639 L
s
0 .49296 m
.00375 .49296 L
s
0 .51952 m
.00375 .51952 L
s
0 .57266 m
.00375 .57266 L
s
0 .59923 m
.00375 .59923 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .17891 L
.04762 .17891 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .17891 L
.04762 .17891 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .23949 L
.09524 .23949 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .23949 L
.09524 .23949 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .2719 L
.14286 .2719 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .2719 L
.14286 .2719 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .27243 L
.19048 .27243 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .27243 L
.19048 .27243 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .29209 L
.2381 .29209 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .29209 L
.2381 .29209 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .22355 L
.28571 .22355 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .22355 L
.28571 .22355 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .19166 L
.33333 .19166 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .19166 L
.33333 .19166 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .13853 L
.38095 .13853 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .13853 L
.38095 .13853 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .11408 L
.42857 .11408 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .11408 L
.42857 .11408 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .10292 L
.47619 .10292 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .10292 L
.47619 .10292 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .07742 L
.52381 .07742 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .07742 L
.52381 .07742 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .07742 L
.57143 .07742 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .07742 L
.57143 .07742 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .04872 L
.61905 .04872 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .04872 L
.61905 .04872 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .04235 L
.66667 .04235 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .04235 L
.66667 .04235 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .03438 L
.71429 .03438 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .03438 L
.71429 .03438 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .02587 L
.7619 .02587 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .02587 L
.7619 .02587 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .02428 L
.80952 .02428 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .02428 L
.80952 .02428 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .02056 L
.85714 .02056 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02056 L
.85714 .02056 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .02109 L
.90476 .02109 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02109 L
.90476 .02109 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .0179 L
.95238 .0179 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0179 L
.95238 .0179 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .0179 L
1 .0179 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0179 L
1 .0179 L
1 .01472 L
.95238 .01472 L
s
0 .60332 m
.03864 .48488 L
.08077 .3827 L
.12034 .30705 L
.1584 .24902 L
.19891 .19984 L
.2379 .16228 L
.27935 .13068 L
.31928 .10665 L
.35769 .08824 L
.39856 .07269 L
.43791 .06083 L
.47574 .05172 L
.51603 .04399 L
.5548 .03808 L
.59603 .0331 L
.63573 .02931 L
.67393 .0264 L
.71457 .02394 L
.7537 .02206 L
.79528 .02049 L
.83535 .01929 L
.8739 .01837 L
.91491 .01759 L
.95238 .01703 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00G`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd0?03oool400000003014A4@3oool0oooo03T0oooo10000000
0`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM03/0oooo1@00
000R0?ooo`00G`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c
<c<0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?ooo`808R8R203o
ool00`1gMgL0<c<c0?ooo`0j0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@08P3oool005l0oooo00D0
4A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0VIVI028R8P3^k^h0
8`3oool005l0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo03d0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c<c<0oooo03`0oooo
00<0VIVI028R8P3^k^h08P3oool005l0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000
000R8R80000003<c<`3<c<`0?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0
oooo00D00000028R8P000000<c<c0<c<c00n0?ooo`0307MgM`1VIVH0oooo0240oooo001O0?ooo`05
014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0200oooo001O0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0m0?oo
o`050000002k^k/0oooo09VIV@0A4A408P3oool005l0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<
0?ooo`@00000?@3oool205EEE@030000003oool0oooo03/0oooo0P1EEED00`000000oooo0?ooo`0;
0?ooo`@00000?03oool01@2IVIT04A4A0000000R8R80c<c<0280oooo003o0?ooofT0oooo000R0?oo
o`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3oooli0?ooo`80
00000P3oool2000000D0oooo000R0?ooo`030000003oool0oooo0?l0oooo>@3oool01P3^k^h08R8R
08R8R03<c<`000000<c<c0D0oooo000R0?ooo`030000003oool0oooo0?l0oooo>P3oool0103MgMd0
00000000003<c<`60?ooo`008P3ooooo0000038000002`3oool0103^k^h08R8R0000003^k^h60?oo
o`008P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o000]000000X0oooo00D0k^k^028R8P1gMgL0MgMg03<c<`060?ooo`008P3oool00`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l000030?l003D000003P3oool00`000000oooo0?ooo`0F0?ooo`8000000P3oool2000000D0
oooo000R0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l000050?l000`000002@3o000?000004l0oooo000R0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000203o000<000000H0o`004000001M0?ooo`008P3oool00`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000:
0?l000`00000103o00000`000000o`000?l0000;0?l000030000003oool0oooo06X0oooo000R0?oo
o`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00d0000000<0o`000000003o00003@3o000?000006`0oooo000R0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l000040?l000T000003@3o00000`000000
o`000?l0000<0?l000030000003oool0oooo07P0oooo000R0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o0007000000P0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003oool0oooo07P0oooo000R0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00001P3o0006000000h0o`0000<000000?l0003o00002`3o000@000007X0oooo000R
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0000000001P0000050?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`270?ooo`008P3oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l000090?l000D00000303o00000`000000o`000?l0000<0?l000l00000R@3oool00280
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00001@3o0004000000<0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003oool0oooo09D0oooo000R0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`000080o`00
0`0000070?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo
0?ooo`2E0?ooo`008P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`0000000002000000X0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003oool0oooo09D0oooo000R0?ooo`030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000:0?l000<000003@3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0U@3oool0
0280oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00L0o`000`0000000`3o000000000?l0000=0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000oooo0?ooo`2E0?ooo`008P3oool00`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o0000103o0003000000@0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0U@3oool00280oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000040000
003o0000o`000?l000<000001`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`2E0?ooo`008P3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`001000000:0?l000030000003o0000o`0000`0o`00
7P00002G0?ooo`008P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`000P00
000=0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0/P3oool00280oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l000090?l00080000000<0o`000000003o0000303o0000
0`000000o`000?l0000<0?l000030000003oool0oooo0;80oooo000R0?ooo`030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00001P3o0003000000<0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003oool0oooo0;80oooo000R0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000103o0002000000H0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003oool0oooo0;80oooo000R0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00@000000?l0003o0000o`000`0000080?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000oooo0?ooo`2b0?ooo`008P3oool00`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000040000
003o00000000000000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003oool0oooo0;80oooo000R0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`000P00000=0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`2b0?ooo`008P3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l000080?l000@000003P3o00000`000000o`000?l0000;0?l001000000]03o
ool00280oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00001P3o0002000000<0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003oool0oooo0<40oooo000R0?ooo`030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00@0o`000P0000050?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000oooo0?ooo`310?ooo`001`3oool5000000<0oooo00D0k^k^03<c<`000000<c<c0>k^kP030?oo
o`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l000030?l000030000003o0000
o`0000D0o`0000<000000?l0003o0000303o000?00000<<0oooo00070?ooo`0509VIV@0R8R80k^k^
0?ooo`14A4@00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`060?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000040000003o0000o`000?l000800000203o00000`000000o`000?l0000<0?l00003
0000003oool0oooo0<l0oooo00080?ooo`0309VIV@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0
oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o000010000000o`0000000000000:
0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0c`3oool000T0oooo00<0VIVI028R
8P3^k^h00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000800000303o00000`000000o`000?l0000<0?l000030000003oool0oooo0<l0oooo000:
0?ooo`0307MgM`1VIVH0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002`3o0002000000d0o`0000<000000?l0003o0000303o00000`000000oooo
0?ooo`3?0?ooo`002`3oool01@000000oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0
oooo014A4@030?ooo`03014A4@3oool0oooo00@0oooo00<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000T0o`000P0000000`3o000000000?l0000<0?l00003
0000003o0000o`0000`0o`0000<000000?ooo`3oool0c`3oool000L0oooo00D000000;^k^`3oool0
VIVI014A4@030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00H0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000P0o`0000D000000?l0003o0000o`000000000=0?l000030000003o0000o`0000`0o`0000<0
00000?ooo`3oool0c`3oool000L0oooo00D0VIVI014A4@0000008R8R0<c<c0030?ooo`050>k^kP0c
<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000L0o`0000<000000?l0003o
00000P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0c`3oool00280oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000D0o`000P0000050?l000030000003o0000o`0000/0o`004000003A0?ooo`008P3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000103o
00000`000000o`000?l000050?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0gP3o
ool00280oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000<0o`0000<000000?l0003o00001P3o00000`000000o`000?l0000;0?l000030000003oool0
oooo0=h0oooo000R0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l000020?l000030000003o0000o`0000L0o`0000<000000?l0003o00002`3o00000`00
0000oooo0?ooo`3N0?ooo`008P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00000P00000:0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0gP3oool00280oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000000000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`3N0?ooo`008P3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`000P00000=0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0gP3oool00280oooo00<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3N0?ooo`008P3oool00`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00X0o`000P00000>0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0gP3oool00280
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l000090?l000030000003o0000000000h0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`3N0?ooo`008P3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000<0?l000030000003o0000o`0000P0o`0000@000000?l0003o000000003P3o00000`000000
o`000?l0000;0?l000030000003oool0oooo0=h0oooo000R0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00001`3o00001@000000o`000?l0003o0000000000h0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`3N0?ooo`008P3oool?000000h0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
0P3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0
gP3oool00280oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l000050?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
ool0oooo0=h0oooo000R0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000103o0000
0`000000o`000?l000040?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3N0?ooo`008P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00<0o`0000<000000?l0003o00001@3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0gP3oool00280oooo00<000000?ooo`3oool02`3oool00`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l000020?l000030000003o0000o`0000H0o`0000<000000?l0003o0000303o000?00000>00
oooo000R0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000D000000?l0003o0000o`00000000090?l00003
0000003o0000o`0000`0o`0000<000000?ooo`3oool0k03oool00280oooo00<000000?ooo`3oool0
2`3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o000010000000o`000?l00000000:0?l000030000003o0000o`0000`0o`0000<000000?ooo`3o
ool0k03oool00280oooo0P00000<0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000000000/0o`0000<000000?l0003o0000
303o00000`000000oooo0?ooo`3/0?ooo`008P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000000000/0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`3/0?ooo`008P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000800000303o00000`000000o`000?l0000<0?l000030000003oool0
oooo0>`0oooo000R0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003oool0oooo0>`0oooo000R0?ooo`030000003oool0oooo00/0
oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0
o`000P00000=0?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0k03oool000T0oooo
0P0000002@0A4A40oooo0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kP030?ooo`050>k^kP0c<c<0
000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000000000d0o`0000<0
00000?l0003o0000303o00000`000000oooo0?ooo`3/0?ooo`002P3oool00`000000oooo0?ooo`02
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo
00<000000?ooo`3oool02`3oool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000000000=0?l000030000003o0000o`0000`0o`00
00<000000?ooo`3oool0k03oool000L0oooo1@0000030?ooo`05014A4@3oool0oooo0?ooo`0A4A40
0`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool02`3oool00`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002@3o000010000000
o`000?l00000000=0?l001000000kP3oool000L0oooo00@0A4A40=gMg@3oool00000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`<000002`3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000203o
00001@000000o`000?l0003o0000000000d0o`0000<000000?ooo`3oool0n`3oool000L0oooo00@0
gMgM05EEE@3oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo00/0oooo00<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000L0o`0000<000000?l0003o00000P3o00000`00
0000o`000?l0000;0?l000030000003oool0oooo0?/0oooo00080?ooo`0307MgM`3<c<`0000000@0
oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l000060?l000030000003o0000o`0000<0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3k0?ooo`00203oool00`3^k^h0A4A4000000040?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool02`3o
ool00`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000030?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0n`3o
ool000T0oooo00<0MgMg0000003oool00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00D0
k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo00/0oooo4000000=0?l000030000
003o0000o`0000D0o`0000<000000?l0003o0000103o00000`000000o`000?l0000;0?l000030000
003oool0oooo0?/0oooo000R0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o00002`3o
00000`000000o`000?l000040?l000030000003o0000o`0000D0o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`3k0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`030000003o0000
o`0000/0o`0000<000000?l0003o00000`3o00000`000000o`000?l000060?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0n`3oool00280oooo00<000000?ooo`3oool06P3oool00`00
0000o`000?l0000;0?l000030000003o0000o`000080o`0000<000000?l0003o00001`3o00000`00
0000o`000?l0000;0?l000030000003oool0oooo0?/0oooo000R0?ooo`8000006`3oool00`000000
o`000?l0000;0?l000030000003o0000o`000080o`0000<000000?l0003o00001`3o00000`000000
o`000?l0000;0?l000030000003oool0oooo0?/0oooo000R0?ooo`030000003oool0oooo01X0oooo
00<000000?l0003o00002`3o00001@000000o`000?l0003o0000000000X0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`3k0?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`030000
003o0000o`0000/0o`0000@000000?l0003o000000002`3o00000`000000o`000?l0000;0?l00003
0000003oool0oooo0?/0oooo000R0?ooo`030000003oool0oooo01X0oooo00<000000?l0003o0000
2`3o000010000000o`000?l00000000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0n`3oool00280oooo00<000000?ooo`3oool06P3oool00`000000o`000?l0000;0?l000030000
003o0000000000`0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`3k0?ooo`008P3o
ool00`000000oooo0?ooo`0J0?oooa0000003@3o00000`000000o`000?l0000;0?l000030000003o
ool0oooo0?/0oooo000R0?ooo`030000003oool0oooo02P0oooo4000000=0?l000030000003oool0
oooo0?/0oooo000R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0303oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0?/0oooo000R0?ooo`800000:03oool00`000000
oooo0?ooo`0=0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0n`3oool00280oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`030000003o0000o`0000/0o`00
00<000000?ooo`3oool0n`3oool00280oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0>0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0n`3oool00280oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0?0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0n`3oool00280oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0@0?oo
o`l00000o@3oool00280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?oooah0
oooo000R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`008P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo7`3oool00280oooo0P00000R
0?ooo`030000003oool0oooo0?l0oooo803oool00280oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`3o0?ooob00oooo000R0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0o`3ooolQ0?ooo`008P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo
8@3oool00280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooob80oooo000R
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`001`3oool01@3^
k^h0<c<c0000000A4A40c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP030?ooo`050>k^kP0c
<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo
8`3oool000L0oooo00D0EEEE07MgM`3oool0VIVI028R8P030?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3o0?ooob<0oooo00070?ooo`050000003oool0oooo0?ooo`0000000`3oool01@0A
4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`<000007@3o
ool00`000000oooo0?ooo`3o0?ooob@0oooo00070?ooo`050000002IVIT0oooo09VIV@0R8R800`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`001`3oool01@000000EEEE
0000000A4A40c<c<00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo9@3oool0
00L0oooo00<0EEEE08R8R03oool01@3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A
0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`001`3oool00`3MgMd04A4A09VIV@050?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`3o0?ooobH0oooo00080?ooo`040<c<c014A4@00000014A4@<0oooo00D0k^k^03<c<`000000
<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0?l0oooo9`3oool00280oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooobL0oooo000R0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
o`3ooolX0?ooo`008P3oool2000001X0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`008P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo:@3oool00280oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`3o0?ooobT0oooo000R0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`008P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0?l0oooo:P3oool00280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`3o0?ooob/0oooo000R0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3oool[
0?ooo`008P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo;03oool00280
oooo0P00000F0?ooo`030000003oool0oooo0?l0oooo;03oool00280oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`3o0?ooobd0oooo000R0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0o`3oool]0?ooo`008P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0?l0oooo;@3oool00280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?oo
obh0oooo000R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oool^0?ooo`00
8P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo;`3oool00280oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooobl0oooo000R0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0o`3oool`0?ooo`008P3oool200000180oooo00<000000?oo
o`3oool0o`3oool`0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0
oooo<03oool00280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooc40oooo
000R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooola0?ooo`008P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo<P3oool000L0oooo00D0c<c<028R
8P0000008R8R0<c<c0030?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000
000c<c<0k^k^00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooc80oooo
00070?ooo`05028R8P2IVIT0oooo09VIV@0R8R800`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`060?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooolc0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D04A4A0?oo
o`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0?l0oooo<`3oool000L0oooo00D0<c<c09VIV@3oool0VIVI03<c
<`030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000H0
oooo0`00000>0?ooo`030000003oool0oooo0?l0oooo<`3oool000L0oooo00D0c<c<000000000000
00000<c<c0030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooc@0oooo00070?oo
o`05014A4@2k^k/0oooo0;^k^`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00D0
4A4A0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
o`3ooold0?ooo`001`3oool01@000000^k^k0?ooo`2k^k/0000000<0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo=@3oool000L0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP030?oo
o`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooocD0oooo000R0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0o`3ooole0?ooo`008P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0?l0oooo=P3oool00280oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3o0?ooocH0oooo000R0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooocL0oooo
000R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`008P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo>03oool00280oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?ooocP0oooo000R0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`008P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?l0oooo>@3oool00280oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3o0?ooocT0oooo000R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3oooli
0?ooo`008P3oool2000000P0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`008P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo>P3oool00280oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3o0?ooocX0oooo000R0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0o`3ooolk0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0?l0oooo>`3oool00280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oo
oc/0oooo000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00
8P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo?03oool00280oooo0P00
00060?ooo`030000003oool0oooo0?l0oooo?03oool00280oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooocd0oooo000R0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`008P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
oooo?@3oool00280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooocd0oooo
000400000008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^h30?ooo`050>k^kP0c<c<00000
03<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3o0?oooch0oooo00020?ooo`030000003oool0oooo0080oooo00D0MgMg
09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooch0
oooo00020?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`05
014A4@3oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooch0oooo00020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo0`0000020?ooo`030000003oool0oooo0?l0oooo
?`3oool00080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo?`3oool00080oooo00<000000?ooo`3o
ool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@03
0?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0oooo?`3oool00080oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2I
VIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL01P3oool01@000000oooo0?ooo`3oool000000?l0oooo@P3oool00080EEEE00<000000?ooo`3o
ool00P3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP03
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool01@000000oooo0?ooo`3oool000000?l0oooo
@P3oool00280oooo00D000000?ooo`3oool0oooo0000003o0?oood80oooo000R0?ooo`050000003o
ool0oooo0?ooo`000000o`3ooom20?ooo`008P3oool010000000oooo0?ooo`00003o0?oood<0oooo
000R0?ooo`80000000<0oooo0000003oool0o`3ooom20?ooo`008P3oool010000000oooo0?ooo`00
003o0?oood<0oooo000R0?ooo`030000003oool000000?l0ooooA03oool00280oooo00<000000?oo
o`000000o`3ooom40?ooo`008P3oool00`000000oooo0000003o0?oood@0oooo000R0?ooo`800000
o`3ooom50?ooo`008P3oool200000?l0ooooA@3oool00280oooo0P00003o0?ooodD0oooo000R0?oo
o`800000o`3ooom50?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000
003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280
oooo00<000000?ooo`3oool0o`3ooom40?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`007P3oool2000000/0oooo0P00003o0?oooc`0oooo000N0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00503oool0100A4A4000000000
003oool200000005014A4@3oool0oooo0?ooo`000000103oool200000080oooo0P0000030?ooo`03
0000003oool0oooo0?l0oooo>P3oool001D0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`30?ooo`030000003oool0
oooo0?l0oooo>P3oool001D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00<0oooo00@0gMgM000000000000c<c<103oool00`000000oooo0?ooo`3o0?ooocX0oooo000E
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`040>k^kP0R
8R8000000>k^kP@0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`005@3oool01@000000MgMg0?oo
o`2ZZZX0000000@0oooo00<000000?ooo`3oool00P3oool01@3^k^h08R8R07MgM`1gMgL0<c<c00@0
oooo00<000000?ooo`3oool0o`3ooolj0?ooo`005@3oool01@000000MgMg000000000000VIVI00@0
oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?ooo`030000003oool0oooo0?l0
oooo>P3oool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0oooo>P3oool001D0oooo00<000000?ooo`3oool01P3oool2000000/0oooo0P00
003o0?oooc`0oooo000D0?ooo`03014A4@000000oooo0?l0ooooDP3oool00?l0ooooJ@3oool00?l0
ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.235175, -93.05, \
0.00862086, 7.7255}}]
}, Open  ]],

Cell[TextData[{
  "\tThe thermal equilibrium theory  does not explain our simulation very \
well. This is because the Fokker-Planck equation assumes very small steps are \
being taken, but ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\)]],
  " has finite width ",
  Cell[BoxData[
      \(TraditionalForm\`2  a = 1/2\)]],
  ", which is not much smaller than the width of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\)]],
  ".  Our steps are too large to use the Boltzmann distribution."
}], "Text"],

Cell[TextData[{
  "\tActually, much of this error can be removed by being more careful in \
determining the drift speed ",
  Cell[BoxData[
      \(TraditionalForm\`v(x)\)]],
  ". For our choice of ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\)]],
  ", the drift speed ",
  Cell[BoxData[
      \(TraditionalForm\`v(x)\)]],
  " is ",
  StyleBox["not constant",
    FontSlant->"Italic"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`x < a\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`x < a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\)]],
  " varies with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and it is left as an exercise to  show that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`v(x)\  = 2/9\  - \ x, \ x < a\)]]], "UNNEQ"],

Cell[TextData[{
  "(for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{\(1/4\), "  ", "and", " ", Cell[TextData[{
              "\[CapitalDelta]",
              StyleBox["t ",
                FontSlant->"Italic"],
              "= 1"
            }]]}]}], TraditionalForm]]],
  "). However, as previously noted,  ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " remains fixed at ",
  Cell[BoxData[
      \(TraditionalForm\`D = 13/1296\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". The true Boltzmann distribution using this nonuniform drift speed,  \
described by Eq. ",
  ButtonBox["(8.2.24)",
    ButtonData:>{"Chapter8.nb", "(8.2.24)"},
    ButtonStyle->"Hyperlink"],
  ", is shown in Fig. ",
  ButtonBox["8.7",
    ButtonData:>"Fig. 8.7",
    ButtonStyle->"Hyperlink"],
  " and is a much better fit to the data from the simulation, although there \
is still considerable error for ",
  Cell[BoxData[
      \(TraditionalForm\`x < a\)]],
  ". According to Eq. ",
  ButtonBox["(8.2.27)",
    ButtonData:>{"Chapter8.nb", "(8.2.27)"},
    ButtonStyle->"Hyperlink"],
  ", there is now an effective repulsive potential for ",
  Cell[BoxData[
      \(TraditionalForm\`x < a\)]],
  " that reduces the probability of particles being in this region."
}], "Text"],

Cell[TextData[{
  "\t  One can improve the agreement between theory and simulation by \
reducing the width ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`w(x, s)\)]],
  ", but this increases the time required for the system to come to \
equilibrium. A better simulation method is discussed in Sec. 8.3.\n"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.47619 0.0147151 0.000731511 [
[.2381 .00222 -9 -9 ]
[.2381 .00222 9 0 ]
[.47619 .00222 -3 -9 ]
[.47619 .00222 3 0 ]
[.71429 .00222 -9 -9 ]
[.71429 .00222 9 0 ]
[.95238 .00222 -3 -9 ]
[.95238 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[-0.0125 .16102 -18 -4.5 ]
[-0.0125 .16102 0 4.5 ]
[-0.0125 .30732 -18 -4.5 ]
[-0.0125 .30732 0 4.5 ]
[-0.0125 .45362 -18 -4.5 ]
[-0.0125 .45362 0 4.5 ]
[-0.0125 .59992 -18 -4.5 ]
[-0.0125 .59992 0 4.5 ]
[0 .64303 -14 0 ]
[0 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 .01472 m
.2381 .02097 L
s
[(0.5)] .2381 .00222 0 1 Mshowa
.47619 .01472 m
.47619 .02097 L
s
[(1)] .47619 .00222 0 1 Mshowa
.71429 .01472 m
.71429 .02097 L
s
[(1.5)] .71429 .00222 0 1 Mshowa
.95238 .01472 m
.95238 .02097 L
s
[(2)] .95238 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .16102 m
.00625 .16102 L
s
[(200)] -0.0125 .16102 1 0 Mshowa
0 .30732 m
.00625 .30732 L
s
[(400)] -0.0125 .30732 1 0 Mshowa
0 .45362 m
.00625 .45362 L
s
[(600)] -0.0125 .45362 1 0 Mshowa
0 .59992 m
.00625 .59992 L
s
[(800)] -0.0125 .59992 1 0 Mshowa
.125 Mabswid
0 .05129 m
.00375 .05129 L
s
0 .08787 m
.00375 .08787 L
s
0 .12444 m
.00375 .12444 L
s
0 .19759 m
.00375 .19759 L
s
0 .23417 m
.00375 .23417 L
s
0 .27074 m
.00375 .27074 L
s
0 .34389 m
.00375 .34389 L
s
0 .38047 m
.00375 .38047 L
s
0 .41705 m
.00375 .41705 L
s
0 .4902 m
.00375 .4902 L
s
0 .52677 m
.00375 .52677 L
s
0 .56335 m
.00375 .56335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .24075 L
.04762 .24075 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .24075 L
.04762 .24075 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .32414 L
.09524 .32414 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .32414 L
.09524 .32414 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .36877 L
.14286 .36877 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .36877 L
.14286 .36877 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .3695 L
.19048 .3695 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .3695 L
.19048 .3695 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .39656 L
.2381 .39656 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .39656 L
.2381 .39656 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .3022 L
.28571 .3022 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .3022 L
.28571 .3022 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .25831 L
.33333 .25831 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .25831 L
.33333 .25831 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .18516 L
.38095 .18516 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .18516 L
.38095 .18516 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .15151 L
.42857 .15151 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .15151 L
.42857 .15151 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .13615 L
.47619 .13615 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .13615 L
.47619 .13615 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .10103 L
.52381 .10103 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .10103 L
.52381 .10103 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .10103 L
.57143 .10103 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .10103 L
.57143 .10103 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .06153 L
.61905 .06153 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .06153 L
.61905 .06153 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .05275 L
.66667 .05275 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .05275 L
.66667 .05275 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .04178 L
.71429 .04178 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .04178 L
.71429 .04178 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .03008 L
.7619 .03008 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .03008 L
.7619 .03008 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .02788 L
.80952 .02788 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .02788 L
.80952 .02788 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .02276 L
.85714 .02276 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .02276 L
.85714 .02276 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .02349 L
.90476 .02349 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02349 L
.90476 .02349 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .0191 L
.95238 .0191 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .0191 L
.95238 .0191 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .0191 L
1 .0191 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .0191 L
1 .0191 L
1 .01472 L
.95238 .01472 L
s
0 .06493 m
.00898 .08961 L
.01881 .12615 L
.02907 .17597 L
.03864 .23294 L
.0607 .39094 L
.07032 .46092 L
.08077 .52749 L
.08583 .55382 L
.09119 .57628 L
.09577 .59041 L
.09838 .5962 L
.10081 .60009 L
.10198 .60142 L
.10326 .60248 L
.10446 .60309 L
.10558 .60332 L
.10669 .60323 L
.10769 .60287 L
.10885 .60214 L
.10994 .60113 L
.11114 .59968 L
.1124 .59775 L
.11466 .5933 L
.11709 .58711 L
.11976 .57876 L
.16019 .4606 L
.1991 .37031 L
.24046 .29429 L
.2803 .23646 L
.31863 .19216 L
.35941 .15469 L
.39868 .12612 L
.43643 .10416 L
.47663 .08551 L
.51532 .07125 L
.55646 .05922 L
.59609 .05006 L
.63419 .04303 L
.67476 .03708 L
.7138 .03254 L
.7553 .02872 L
.79528 .02581 L
.83375 .02359 L
.87467 .02171 L
.91407 .02028 L
.95196 .01918 L
.95238 .01917 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00F`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd0?03oool400000003014A4@3oool0oooo03T0oooo10000000
0`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM03/0oooo1@00
000V0?ooo`00F`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c
<c<0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?ooo`808R8R203o
ool00`1gMgL0<c<c0?ooo`0j0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@09P3oool005/0oooo00D0
4A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0VIVI028R8P3^k^h0
9`3oool005/0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo03d0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c<c<0oooo03`0oooo
00<0VIVI028R8P3^k^h09P3oool005/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000
000R8R80000003<c<`3<c<`0?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0
oooo00D00000028R8P000000<c<c0<c<c00n0?ooo`0307MgM`1VIVH0oooo02D0oooo001K0?ooo`05
014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
02@0oooo001K0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0m0?oo
o`050000002k^k/0oooo09VIV@0A4A409P3oool005/0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<
0?ooo`@00000?@3oool205EEE@030000003oool0oooo03/0oooo0P1EEED00`000000oooo0?ooo`0;
0?ooo`@00000?03oool01@2IVIT04A4A0000000R8R80c<c<02H0oooo003o0?ooofT0oooo000N0?oo
o`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3oooli0?ooo`80
00000P3oool2000000T0oooo000N0?ooo`030000003oool0oooo0?l0oooo>@3oool01P3^k^h08R8R
08R8R03<c<`000000<c<c0T0oooo000N0?ooo`030000003oool0oooo0?l0oooo>P3oool0103MgMd0
00000000003<c<`:0?ooo`007P3ooooo0000038000002`3oool0103^k^h08R8R0000003^k^h:0?oo
o`007P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`080?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<02P3oool001h0
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0
o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0
o`00;@00000:0?ooo`8000000P3oool2000000T0oooo000N0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o000N000003H0oooo000N0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000L0o`005@00
001B0?ooo`007P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o000@00000640oooo000N0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l000050?l000T00000KP3oool001h0oooo00<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000;0?l000T000001P3o00000`000000oooo0?ooo`1^0?ooo`00
7P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000D0o`001P0000000`3o00000000
0000000=00000700oooo000N0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0000000001@00
00070?l000030000003oool0oooo07`0oooo000N0?ooo`030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000L0o`001P00000=
0?l000030000003oool0oooo07`0oooo000N0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`000080o`001@0000040?l0
00030000003o0000o`0000`0o`0000<000000?ooo`3oool0O03oool001h0oooo00<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`001@0000090?l00100
0000OP3oool001h0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000T0o`001000000=0?l000030000003oool0oooo08/0oooo000N0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l000050?l000@000000`3o
000?000008d0oooo000N0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
10000000o`000?l0003o0004000000L0o`0000<000000?ooo`3oool0V@3oool001h0oooo00<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000@000002`3o00000`000000oooo0?ooo`2I
0?ooo`007P3oool2000000`0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o0000203o0004000000h0o`0000<000000?oo
o`3oool0V@3oool001h0oooo0P00000<0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000D0o`000`0000030?l00003
0000003o0000o`0000`0o`0000<000000?ooo`3oool0V@3oool001h0oooo0P00000<0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000<0o`000P0000060?l000030000003o0000o`0000`0o`0000<000000?ooo`3oool0
V@3oool001h0oooo00<000000?l0000000002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o000010000000o`000?l0003o0002000000P0o`00
00<000000?l0003o0000303o00000`000000oooo0?ooo`2I0?ooo`007P3oool00`000000o`000000
000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000@000002P3o00000`000000o`000?l0000<0?l000030000003oool0oooo09T0oooo000N
0?ooo`030000003o0000000000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000/0o`000P00000=0?l000030000003o0000o`0000`0o`0000<00000
0?ooo`3oool0V@3oool001h0oooo00@000000?l0003o000000002P3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000203o0003000000030?l000000000
o`0000`0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`2I0?ooo`007P3oool01000
0000o`000?l00000000:0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l000060?l000800000103o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?ooo`3oool0V@3oool001h0oooo00@000000?l0003o000000002P3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000103o0002
000000H0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0
oooo09T0oooo000N0?ooo`050000003o0000o`000?l0000000002@3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;
0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<
0?l000030000003o0000o`0000/0o`0000@000000?l0003o0000o`000`0000080?l001h00000V`3o
ool001h0oooo00D000000?l0003o0000o`00000000090?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o000010000000o`0000000000000;0?l000030000003oool0oooo0;H0oooo
000N0?ooo`050000003o0000o`000?l0000000002@3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`000P00000=0?l000030000003oool0oooo0;H0oooo000N0?ooo`030000003o
0000o`000080o`0000<000000?l0003o00001P3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000X0o`000P00000>0?l000030000003oool0oooo0;H0oooo000N0?ooo`030000003o0000
o`000080o`0000<000000?l0003o00001P3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000P0o`000P0000000`3o000000000?l0000=0?l000030000003oool0oooo0;H0oooo000N0?oo
o`030000003o0000o`000080o`0000<000000?l0003o00001P3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000H0o`000P0000030?l000030000003o0000o`0000`0o`0000<000000?oo
o`3oool0]P3oool001h0oooo00<000000?l0003o00000P3o00000`000000o`000?l000060?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00001@3o00000`000000o`000?l000030?l00003
0000003o0000o`0000`0o`0000<000000?ooo`3oool0]P3oool001h0oooo00<000000?l0003o0000
0`3o00000`000000o`000?l000050?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
0`3o0002000000H0o`0000<000000?l0003o0000303o00000`000000oooo0?ooo`2f0?ooo`007P3o
ool00`000000o`000?l000030?l000030000003o0000o`0000D0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
000010000000o`000?l0003o0002000000P0o`0000<000000?l0003o0000303o00000`000000oooo
0?ooo`2f0?ooo`007P3oool00`000000o`000?l000030?l000030000003o0000o`0000D0o`0000<0
00000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o0000303o000010000000o`000?l00000000:0?l000030000003o0000o`0000`0o`00
00<000000?ooo`3oool0]P3oool001h0oooo00<000000?l0003o00000`3o00000`000000o`000?l0
00050?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?l0000000002`3o00000`000000o`000?l0
000<0?l000030000003oool0oooo0;H0oooo000N0?ooo`030000003o0000o`0000@0o`0000<00000
0?l0003o0000103o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000800000303o000@00000;P0oooo000N0?oo
o`030000003o0000o`0000@0o`0000<000000?l0003o0000103o00000`000000o`000?l0000<0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l0
008000003@3o00000`000000oooo0?ooo`350?ooo`007P3oool00`000000o`000?l000040?l00003
0000003o0000o`0000@0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000000000=0?l00003
0000003oool0oooo0<D0oooo000N0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000
103o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l000080?l0008000000P3o00000`000000o`000?l0000;0?l000030000
003oool0oooo0<D0oooo000N0?ooo`030000003o0000o`0000@0o`0000<000000?l0003o0000103o
00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o
00000`000000o`000?l000070?l000030000003o0000o`000080o`0000<000000?l0003o00002`3o
00000`000000oooo0?ooo`350?ooo`000`3oool5000000<0oooo00D0k^k^03<c<`000000<c<c0>k^
kP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000o`000?l000050?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00001P3o00000`000000o`000?l000030?l000l00000
a`3oool000<0oooo00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?l0003o00001@3o00000`00
0000o`000?l000030?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000@0o`000P0000060?l000030000003oool0oooo
0=<0oooo00040?ooo`0309VIV@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0oooo014A4@030?oo
o`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000o`000?l000050?l000030000003o0000
o`0000<0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00000`3o00000`000000o`000?l000060?l000030000003oool0
oooo0=<0oooo00050?ooo`0309VIV@0R8R80k^k^00<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000o`000?l000050?l000030000003o
0000o`0000<0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00000P3o00000`000000o`000?l000070?l000030000003o
ool0oooo0=<0oooo00060?ooo`0307MgM`1VIVH0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000o`000?l000050?l000030000
003o0000o`0000<0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000D000000?l0003o0000o`000000000:0?l000030000003oool0oooo0=<0
oooo00070?ooo`050000003oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A
00<0oooo00<04A4A0?ooo`3oool0103oool00`000000o`000?l000060?l000030000003o0000o`00
0080o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000@000000?l0003o000000002`3o00000`000000oooo0?ooo`3C0?ooo`000`3oool01@00
0000^k^k0?ooo`2IVIT04A4A00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01P3oool00`000000o`000?l000060?l000030000003o0000o`000080o`00
00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`00
00<000000?l000000000303o00000`000000oooo0?ooo`3C0?ooo`000`3oool01@2IVIT04A4A0000
000R8R80c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c
<`3^k^h01P3oool00`000000o`000?l000060?l000030000003o0000o`000080o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`000P00000=0?l0
00030000003oool0oooo0=<0oooo000N0?ooo`030000003o0000o`0000H0o`0000<000000?l0003o
00000P3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo0=<0oooo000N0?ooo`030000
003o0000o`0000H0o`0000<000000?l0003o00000P3o00000`000000o`000?l0000<0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002P3o0002000000h0o`0000<000000?ooo`3oool0
d`3oool001h0oooo00<000000?l0003o00001P3o00000`000000o`000?l000020?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l000090?l000030000003o
0000000000l00000e@3oool001h0oooo00<000000?l0003o00001`3o00001@000000o`000?l0003o
0000000000h0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l000080?l000040000003o
0000o`0000000>@0oooo000N0?ooo`030000003o0000o`0000L0o`0000D000000?l0003o0000o`00
0000000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00001`3o00001@000000o`00
0?l0003o000000000>@0oooo000N0?ooo`030000003o0000o`0000L0o`0000D000000?l0003o0000
o`000000000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00001`3o00001@000000
o`000?l0003o000000000>@0oooo000N0?ooo`030000003o0000o`0000L0o`0000D000000?l0003o
0000o`000000000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000020?l000030000003oool0oooo0>80oooo000N0?ooo`030000003o0000o`0000L0
o`0000D000000?l0003o0000o`000000000>0?l000030000003o0000o`0000/0o`0000<000000?l0
003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000030?l000030000003oool0oooo0>80oooo000N0?ooo`03
0000003o0000o`0000L0o`0000D000000?l0003o0000o`000000000>0?l000030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o0000103o00000`000000o`000?l000040?l000030000003oool0oooo
0>80oooo000N0?ooo`030000003o0000o`0000P0o`0000@000000?l0003o000000003P3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000<0?l000030000003o0000o`0000<0o`0000<000000?l0003o00001@3o00000`00
0000oooo0?ooo`3R0?ooo`007P3oool00`000000o`000?l000080?l000040000003o0000o`000000
00h0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l000020?l000030000003o0000o`00
00H0o`0000<000000?ooo`3oool0hP3oool001h0oooo00<000000?l0003o0000203o000010000000
o`000?l00000000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000`0o`0000D000000?l0003o0000o`0000000009
0?l000030000003oool0oooo0>80oooo000N0?ooo`030000003o0000o`0000P0o`0000@000000?l0
003o000000003P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000<0?l000050000003o0000o`000?l0000000002@3o
00000`000000oooo0?ooo`3R0?ooo`007P3oool00`000000o`000?l000080?l000040000003o0000
o`00000000h0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o000010000000o`000?l00000000:0?l000030000
003oool0oooo0>80oooo000N0?ooo`030000003o0000o`0000P0o`0000@000000?l0003o00000000
3P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000<0?l000030000003o0000000000/0o`0000<000000?ooo`3oool0
hP3oool001h0oooo00<000000?l0003o00002@3o00000`000000o`000000000>0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`000P00000<0?l000030000003oool0oooo0>80oooo000N0?ooo`030000003o0000
o`0000T0o`0000<000000?l0000000003P3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0hP3oool001h0oooo00<000000?l0003o00002@3o00000`00
0000o`000000000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`000P00000=0?l000030000003oool0oooo
0>80oooo000N0?ooo`030000003o0000o`0000T0o`0000<000000?l0000000003P3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000000000d0o`0000<000000?ooo`3oool0hP3oool001h0oooo
3`00000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0000000003@3o00000`000000oooo
0?ooo`3R0?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000h0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002@3o000010000000o`000?l00000000=0?l000030000003oool0oooo0>80oooo
000N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000003P3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
00080?l000050000003o0000o`000?l0000000003@3o00000`000000oooo0?ooo`3R0?ooo`007P3o
ool00`000000oooo0?ooo`0:0?ooo`8000003P3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l000080?l000050000003o
0000o`000?l0000000003@3o00000`000000oooo0?ooo`3R0?ooo`007P3oool00`000000oooo0?oo
o`0:0?ooo`8000003P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l000070?l000030000003o0000o`000080o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`3R0?ooo`007P3oool00`000000oooo0?ooo`0:
0?ooo`8000003P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l000060?l000030000003o0000o`0000<0o`003`00003T
0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`8000003P3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l000050?l0
00030000003o0000o`0000@0o`0000<000000?ooo`3oool0l03oool001h0oooo00<000000?ooo`3o
ool02P3oool2000000h0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00001@3o00000`000000o`000?l000040?l00003
0000003oool0oooo0?00oooo000N0?ooo`030000003oool0oooo00X0oooo0P00000>0?l000030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000@0o`0000<000000?l0003o00001@3o00000`000000oooo0?ooo`3`0?ooo`007P3o
ool2000000/0oooo0P00000>0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000303o
00000`000000o`000?l0000;0?l000030000003o0000o`0000<0o`0000<000000?l0003o00001P3o
00000`000000oooo0?ooo`3`0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`8000003P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l000030?l000030000003o0000o`0000H0o`0000<000000?ooo`3oool0l03oool0
01h0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000<0?l000030000003o0000o`00
00/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
0080o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`3`0?ooo`007P3oool00`000000
oooo0?ooo`0;0?ooo`030000003o0000o`0000`0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`0000/0o`0000D000000?l0003o0000o`000000000:0?l0
00030000003oool0oooo0?00oooo000N0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o000010000000o`000?l00000000;0?l000030000003oool0oooo0?00oooo000N0?ooo`03
0000003oool0oooo00/0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000`0o`0000<000000?l0003o00002`3o000010000000o`000?l00000000;0?l0
00030000003oool0oooo0?00oooo000N0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o
0000303o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o
00002`3o00000`000000o`000000000<0?l000030000003oool0oooo0?00oooo000N0?ooo`030000
003oool0oooo00/0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000
003o0000o`0000`0o`0000<000000?l0003o00002`3o0002000000d0o`0000<000000?ooo`3oool0
l03oool001h0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000<0?l000030000003o
0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l0000;0?l0008000003@3o
00000`000000oooo0?ooo`3`0?ooo`001@3oool200000009014A4@3oool0oooo0?ooo`3^k^h0<c<c
0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo
00/0oooo00<000000?l0003o0000303o00000`000000o`000?l0000;0?l000030000003o0000o`00
00`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003oool0oooo
0?00oooo00060?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`0;0?ooo`8000003@3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002`3o000@
00000?80oooo00030?ooo`D000000`3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A
0?ooo`3oool0oooo014A4@060?ooo`<000002`3oool2000000d0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000030000003o0000o`0000X0o`000P00003o0?ooo`80oooo0003
0?ooo`0404A4A03MgMd0oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0;0?ooo`8000003@3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o00002@3o00000`000000
o`000000003o0?ooo`80oooo00030?ooo`040=gMg@1EEED0oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0;
0?ooo`8000003@3o00000`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00002@3o00000`000000o`000000003o0?ooo`80oooo00040?ooo`0307MgM`3<c<`00000
00@0oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3o
ool00`000000oooo0?ooo`0;0?ooo`8000003@3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000`0o`0000<000000?l0003o0000203o000010000000o`000?l00000003o0?ooo`80oooo
00040?ooo`030>k^kP14A4@0000000@0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`0;0?ooo`8000003@3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000`0o`0000<000000?l0003o0000203o000010000000
o`000?l00000003o0?ooo`80oooo00050?ooo`0307MgM`000000oooo00<0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0;
0?oooa0000003@3o00000`000000o`000?l0000<0?l000030000003o0000o`0000L0o`0000D00000
0?l0003o0000o`000000003o0?ooo`80oooo000N0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000o`000?l0000;0?l000030000003o0000o`0000`0o`0000<00000
0?l0003o00001`3o00001@000000o`000?l0003o000000000?l0oooo0P3oool001h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`0000<00000
0?l0003o0000303o00000`000000o`000?l000060?l000030000003o0000o`000080o`0000<00000
0?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?oo
o`030000003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l000050?l0
00030000003o0000o`0000<0o`0000<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l000050?l000030000003o0000o`0000<0o`0000<000000?ooo`3o
ool0o`3oool001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o0000303o00000`000000o`000?l000040?l000030000
003o0000o`0000@0o`0000<000000?ooo`3oool0o`3oool001h0oooo0P00000>0?ooo`030000003o
ool0oooo00X0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o
0000o`0000@0o`0000<000000?l0003o0000103o00000`000000oooo0?ooo`3o0?ooo`007P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?l0003o00002`3o0000
0`000000o`000?l0000<0?l000030000003o0000o`0000<0o`0000<000000?l0003o00001@3o0000
0`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00X0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`00
00<0o`0000<000000?l0003o00001@3o00000`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?l0003o00002`3o00000`000000
o`000?l0000<0?l000030000003o0000o`000080o`0000<000000?l0003o00001P3o00000`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo
00<000000?l0003o00002`3o00000`000000o`000?l0000<0?l000030000003o0000o`000080o`00
00<000000?l0003o00001P3o00000`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00T0oooo00<000000?l0003o00002`3o00000`000000o`000?l0
000<0?l000050000003o0000o`000?l0000000002@3o00000`000000oooo0?ooo`3o0?ooo`007P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?l0003o00002`3o
00000`000000o`000?l0000<0?l000040000003o0000o`00000000X0o`0000<000000?ooo`3oool0
o`3oool001h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o0000303o000010000000o`000?l00000000:0?l000030000
003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3o
oolN000000030?l000000000o`0000X0o`0000<000000?ooo`3oool0o`3oool001h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000000000/0o`0000<00000
0?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?oo
o`800000303o00000`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo02H0oooo0P00000<0?l000030000003oool0oooo0?l0oooo000N0?ooo`800000
403oool00`000000oooo0?ooo`0U0?ooo`800000303o00000`000000oooo0?ooo`3o0?ooo`007P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo00<000000?l0003o00002`3o
00000`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02D0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3o0?ooo`007P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0oooo0P00000=0?l000030000003oool0oooo
0?l0oooo000N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0903oool@00000?l0
oooo0P3oool001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0?l0oooo3`3oool001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0oooo403oool001h0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0oooo403oool001h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo4@3oool001h0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0
oooo4@3oool001h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0?l0oooo4@3oool001h0oooo0P00000A0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0o`3ooolB0?ooo`007P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0o`3ooolB0?ooo`007P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooolB0?ooo`007P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00
7P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
o`3ooolC0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0o`3ooolD0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`007P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`000`3oool01@3^k^h0
<c<c0000000A4A40c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP030?ooo`050>k^kP0c<c<0
000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3ooolE0?ooo`000`3oool01@1EEED0MgMg0?ooo`2IVIT08R8R00<0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D04A4A0?ooo`3oool0oooo014A4@030?oo
o`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`000`3oool01@000000VIVI0?ooo`2IVIT0
8R8R00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
1P3oool300000180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oooaH0oooo
00030?ooo`050000001EEED00000014A4@3<c<`00`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`3o0?oooaH0oooo00030?ooo`0305EEE@28R8P0oooo00D0
oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooolG
0?ooo`000`3oool00`3MgMd04A4A09VIV@050?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0?l0oooo5`3oool000@0oooo00@0c<c<04A4A00000004A4A0`3o
ool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oooaP0
oooo000N0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`3o0?oooaP0oooo000N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`3o0?oooaP0oooo000N0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oooaT0oooo000N0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oooaT0oooo000N0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oooaT0
oooo000N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`3o0?oooaX0oooo000N0?ooo`800000503oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0?l0oooo6P3oool001h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?l0oooo6P3oool001h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo6`3oool001h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo6`3oool001h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo
703oool001h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0?l0oooo703oool001h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?l0oooo703oool001h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo7@3oool001h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo7@3oool001h0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo
7@3oool001h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0oooo7P3oool001h0oooo0P00000F0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0o`3ooolN0?ooo`007P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`007P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3o
oolO0?ooo`007P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0o`3ooolP0?ooo`007P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`007P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3o
oolQ0?ooo`007P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`007P3oool2000001T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?ooob80oooo000N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?ooob80oooo000N0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooob<0oooo000N0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooob<0oooo000N
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?ooob<0oooo000N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooob@0oooo000N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooob@0oooo000N0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooob@0oooo000N0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooob@0oooo0003
0?ooo`050<c<c00R8R800000028R8P3<c<`00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo
00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?ooobD0oooo00030?ooo`05028R8P2IVIT0oooo09VIV@0R
8R800`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`06
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?ooobD0oooo00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@0A4A40oooo0?ooo`3o
ool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`<00000703oool010000000oooo
0?ooo`00003o0?ooobP0oooo00030?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<00`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo01`0oooo0`00003o0?ooobT0oooo00030?ooo`050<c<c000000000000000003<c<`00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo0?l0ooooB03oool000<0oooo00D04A4A0;^k^`3oool0^k^k014A4@030?ooo`05014A
4@3oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`000`3oool01@000000^k^k0?ooo`2k^k/0000000<0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo00030?ooo`050:ZZZP0A4A400000014A4@2ZZZX00`3oool01@3^k^h0<c<c0000
000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo0?l0
ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`006P3oool2000000/0oooo0P00003o0?oood00oooo
000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00403oool0
100A4A4000000000003oool200000005014A4@3oool0oooo0?ooo`000000103oool200000080oooo
0P0000030?ooo`030000003oool0oooo0?l0oooo?P3oool00140oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`30?oo
o`030000003oool0oooo0?l0oooo?P3oool00140oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00<0oooo00@0gMgM000000000000c<c<103oool00`000000oooo0?ooo`3o
0?oooch0oooo000A0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`040>k^kP0R8R8000000>k^kP@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`004@3oool0
1@000000MgMg0?ooo`2ZZZX0000000@0oooo00<000000?ooo`3oool00P3oool01@3^k^h08R8R07Mg
M`1gMgL0<c<c00@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`004@3oool01@000000MgMg0000
00000000VIVI00@0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?ooo`030000
003oool0oooo0?l0oooo?P3oool00140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0oooo?P3oool00140oooo00<000000?ooo`3oool01P3oool2
000000/0oooo0P00003o0?oood00oooo000@0?ooo`03014A4@000000oooo0?l0ooooEP3oool00?l0
ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.209312, -67.5927, \
0.00862086, 5.6119}}],

Cell[TextData[{
  "Fig. 8.7 Comparison of the  Boltzmann distribution (line) to histograms \
from a random walk with bias, for ",
  Cell[BoxData[
      \(TraditionalForm\`D(x)\  = \ \(\(13/1296\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v(x)\  = \ 2/9\  - \ x, \ x < 1/4, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v(x) = \(-1\)/36, \ x \[GreaterEqual] \ 1/4\)]],
  "."
}], "Caption",
  CellTags->"Fig. 8.7"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 8.2", "Subsubtitle",
  CellTags->"c:30"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " In a random walk in three dimensions, a particle starts from the origin \
and takes steps of fixed length ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " but with equal probability for any direction. Determine the rms distance \
the particle moves away from the origin in ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " steps. "
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " An integer is chosen randomly in the range 1-20. What is the probability \
that it is prime?  If the number is odd, what is the probability that it is \
prime?"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " In a certain town of 5000 people, 750 have blond hair, 500 have blue \
eyes, and 420 have both blond hair and blue eyes.   A person is selected at \
random from the town."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " If he/she has blond hair, what is the probability that he/she will have \
blue eyes?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " If he/she has blue eyes, what is the probability that he/she does not \
have blond hair?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " What is the probability that he/she has neither blond hair nor blue \
eyes?"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " In a certain college, 7% of the men and 3% of the women are taller than  \
6 ft. Furthermore, 60% of the students are men. If a student is selected at \
random, and is over 6 ft, what is the probability that he/she is a woman?"
}], "Text"],

Cell[TextData[{
  StyleBox["(5)(a)",
    FontWeight->"Bold"],
  " You are somehow transported back to the year 1975, where you find \
yourself in a rabbit costume, as a contestant on the then-popular TV game \
show ",
  StyleBox["Let's Make a Deal",
    FontSlant->"Italic"],
  ".  The host Monty Hall approaches you and demands that you choose either \
door number 1, door number 2, or door number 3. Behind one of these doors \
there are fabulous prizes; behind the other two there are piles of useless \
junk. You choose door number 1. Monty, knowing the right door, opens door \
number 3, revealing that it is one of the no-prize doors. So the right door \
is either door 1, or door 2. Monty then gives you the opportunity to switch \
doors to door 2.  Explain why you should switch to door number 2, by using \
conditional probabilities to determine the probability that door 1 is correct \
vs. the probability that door 2 hides the prizes.  (Hint: It's easiest to see \
the answer for the more general case of ",
  Cell[BoxData[
      \(TraditionalForm\`N >> 1\)]],
  " doors and 1 prize door, where Monty opens all the doors but yours and one \
other.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Prove that it is better to switch by creating a simulation of the game \
with three doors. For 1000 tries, take the case where you don't switch.  How \
many times do you win? Now repeat for the case where you switch doors. Now \
how many times do you win?"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Solve the master equation for a general random walk, Eq. ",
  ButtonBox["(8.2.11)",
    ButtonData:>{"Chapter8.nb", "(8.2.11)"},
    ButtonStyle->"Hyperlink"],
  ", using Fourier transforms, starting all particles at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ". (Hint: Use the convolution theorem.) Show that the solution is"
}], "Text",
  CellTags->"i:73"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, 
          n)\  = \ \[Integral]\(\[DifferentialD]k\/\(2  \[Pi]\)\) \(\
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)[\(w\&~\)(k)]\^n\)]],
  ","
}], "NE2",
  CellTags->"(8.2.32)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\&~\)(k)\)]],
  " is the Fourier transform of the probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](s)\)]],
  " for a step of size ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Prove using Eq. ",
  ButtonBox["(8.2.32)",
    ButtonData:>{"Chapter8.nb", "(8.2.32)"},
    ButtonStyle->"Hyperlink"],
  " that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, n)\)]],
  " is properly normalized: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]x\ \(\[Rho](x, n)\) = 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Prove the following identity for this random walk using Eq. ",
  ButtonBox["(8.2.32)",
    ButtonData:>{"Chapter8.nb", "(8.2.32)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(x\^m\), 
              "\[RightAngleBracket]"}], \((n)\)}], 
          "=", \(\(\(\((\[ImaginaryI])\)\^m\) \
\(\[PartialD]\^m\/\[PartialD]k\^m\)[\(w\&~\)(k)]\^n\)\( | \_\(k = 0\)\)\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(8.2.33)"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " For a step distribution ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\  = \ 
        a\ \[ExponentialE]\^\(\(-a\)\  | s | \)/2\)]],
  ", evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((n)\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(x\^2\), 
              "\[RightAngleBracket]"}], \((n)\)}], ","}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(x\^4\), 
            "\[RightAngleBracket]"}], \((n)\)}], TraditionalForm]]],
  " using Eq. ",
  ButtonBox["(8.2.33)",
    ButtonData:>{"Chapter8.nb", "(8.2.33)"},
    ButtonStyle->"Hyperlink"],
  " and show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, n)\  = 
        a\ \(\((a\  | x | \(\(/\)\(2\)\))\)\^\(n\  - \ 
                1/2\)\) \(\(K\_\(1/2\  - \ n\)\)(
              a\  | x | )\)/\@\[Pi] \(\((n - 1)\)!\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(K\_n\)(x)\)]],
  " is a modified Bessel function.  Animate this result for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5\)]],
  " steps."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)(a)",
    FontWeight->"Bold"],
  " In Brownian motion, the velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  " at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " obeys the finite-differenced Langevin equation ",
  ButtonBox["(8.1.49)",
    ButtonData:>{"Chapter8.nb", "(8.1.49)"},
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n = \[Alpha]\ v\_\(n - 1\) + s\_\(n - 1\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Alpha]", "=", 
          RowBox[{"1", " ", "-", " ", 
            RowBox[{"\[Gamma]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the drag coefficient, and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  " is a random step in velocity with zero mean, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "s", "\[RightAngleBracket]"}], " ", "=", 
          "0"}], TraditionalForm]]],
  ". Solve this equation for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  ", assuming an initial velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ", and prove that"
}], "Text",
  CellTags->"i:92"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(v\_n\ v\_\(n + m\)\), 
            "\[RightAngleBracket]"}], " ", "=", 
          RowBox[{\(\(v\_o\^2\) \[Alpha]\^\(2  n\  + \ m\)\), " ", "+", " ", 
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\^2\), 
                "\[RightAngleBracket]"}], \(\[Alpha]\^m\), \(\(1 - \[Alpha]\^\
\(2  n\)\)\/\(1 - \[Alpha]\^2\)\)}]}]}], TraditionalForm]]],
  ".  "
}], "UNNEQ"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In the long time limit ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}], "\[Rule]", " ", "\[Infinity]"}], 
        TraditionalForm]]],
  ", but taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", "0"}], 
        TraditionalForm]]],
  ", show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(v\_n\ v\_\(n + m\)\), 
            "\[RightAngleBracket]"}], " ", "\[Rule]", 
          " ", \(D\_V\/\[Gamma]\ \[ExponentialE]\^\(\(-\[Gamma]\)\ t\_m\)\)}],
         TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_m\), " ", "=", " ", 
          RowBox[{"m", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_V\)]],
  " is the velocity diffusion coefficient- see Eq. ",
  ButtonBox["(8.1.51)",
    ButtonData:>{"Chapter8.nb", "(8.1.51)"},
    ButtonStyle->"Hyperlink"],
  ". Hence, in thermal equilibrium,  the velocity correlation function ",
  Cell[BoxData[
      \(TraditionalForm\`c(n, n + m)\)]],
  " falls off exponentially with time, as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[Gamma]\)\ t\_m\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  "  Create a random walk simulation using 1000 particles with step \
distribution ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  "given inExercise (6)(d) with ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ". Use the rejection method. Follow the distribution for five steps and \
compare the resulting histograms with the theory of Exercise (6)(d)."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)(a) ",
    FontWeight->"Bold"],
  "Create a random walk simulation with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " particles with steps of fixed size ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)\)]],
  ", but taking ",
  Cell[BoxData[
      \(TraditionalForm\`p = \ 0.4, \ q\  = \ 0.6\)]],
  ". Follow the simulation for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 50\)]],
  " steps, starting all particles at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "x", "\[RightAngleBracket]"}], \((n)\)}], 
        TraditionalForm]]],
  "  and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], 
          RowBox[{"\[Delta]", 
            FormBox[\(\(x\^2\)\(\[RightAngleBracket]\)\),
              "TraditionalForm"], \((n)\)}]}], TraditionalForm]]],
  ", and compare with the theoretical predictions based on the binomial \
distribution."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Make an animation of the histogram of positions, and compare it with the \
binomial distribution itself at each timestep."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Use the transformation method to write a code that distributes a random \
variable ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " according to the probability distribution ",
  Cell[BoxData[
      \(TraditionalForm\`w(s) = \[ExponentialE]\^\(-s\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s > 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w(s) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s < 0\)]],
  ". Test the code for 1000 tries, and compare the resulting histogram for ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " In a 2-dimensional random walk process, the step probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w(x, y)\  = \ 2\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < x\)]],
  ", and is zero otherwise. Particles start from the origin."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Analytically  determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\_n\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(y\_n\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(x\_n\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(y\_n\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " vs. the timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Analytically evaluate the following correlation function: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(c\_\(x\ y\)\)(n, m)\), " ", "=", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(x\_n\ y\_\(n + m\)\), 
                  "\[RightAngleBracket]"}], "-", 
                RowBox[{
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(x\_n\), "\[RightAngleBracket]"}], 
                  
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], \(y\_\(n + \ m\)\), 
                    "\[RightAngleBracket]"}]}]}], ")"}], "/", 
            SqrtBox[
              RowBox[{
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(\[Delta]x\_n\^2\), 
                  "\[RightAngleBracket]"}], 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(\[Delta]y\_\(n + m\)\^2\), 
                  "\[RightAngleBracket]"}]}]]}]}], TraditionalForm]]],
  ",",
  " "
}], "UNNEQ"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Create  a 2D random walk simulation for 1000 particles, and test part (b) \
over 50 steps by plotting the correlation function vs. ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 5\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`10\)]],
  ", along with the theory."
}], "Text"],

Cell[TextData[{
  StyleBox["(12)(a)",
    FontWeight->"Bold"],
  " A particle undergoes Langevin dynamics with ",
  Cell[BoxData[
      FormBox[
        StyleBox["zero",
          FontSlant->"Italic"], TraditionalForm]]],
  " random forcing, taking steps according to ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\  = \ \[Alpha]\ v\_\(n - 1\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Alpha]", "=", 
          RowBox[{"1", "-", 
            RowBox[{"\[Gamma]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ". Show that a distribution of velocities ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](v, n)\)]],
  " evolves in time according to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](v, 
          n) = \(\[Rho](v/\[Alpha], n - 1)\)/\[Alpha]\)]],
  ",  (Hint: Use the transformation method.) "
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "Solve this equation numerically and animate the result over 20 steps for \
the case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 0.9\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](v, 
          0) = \[ExponentialE]\^\(-v\^2\)/\@\[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(13)(a)",
    FontWeight->"Bold"],
  " Show that the master equation for the velocity distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](V, n)\)]],
  " of a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " undergoing Langevin dynamics, ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\  = \ \[Alpha]\ v\_\(n - 1\) + 
          s\_\(n - 1\)\)]],
  ", is"
}], "Text",
  CellTags->"i:74"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](v, 
          n) = \(1\/\[Alpha]\) \(\[Rho](v/\[Alpha], 
              n - 1)\) + \[Integral]\(w(v - v\^\[Prime])\) \(\[Rho](
                v\^\[Prime], n - 1)\) \[DifferentialD]v\^\[Prime]\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`w(s)\)]],
  " is the distribution of the steps. \n",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In the limit as ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and the step size approach zero, show that this master equation becomes \
the Fokker-Planck equation for velocity-diffusion,"
}], "Text",
  CellTags->"i:75"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]\[Rho]\/\[PartialD]t = \[PartialD]\/\
\[PartialD]v\ D\_V\ [\(m\ v\)\/\(\(k\_B\) T\)\ \[Rho]\  + \[PartialD]\[Rho]\/\
\[PartialD]v]\)\(,\)\)\)]]], "NE2",
  CellTags->"(8.2.34)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(D\_V\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(s\^2\), "\[RightAngleBracket]"}], "/",
               "2"}], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " is the velocity diffusion coefficient.  [Hint: Recall the Einstein \
relation ",
  ButtonBox["(8.1.51)",
    ButtonData:>{"Chapter8.nb", "(8.1.51)"},
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that the thermal equilibrium form for the velocity distribution is a \
",
  StyleBox["Maxwellian",
    FontSlant->"Italic"],
  " distribution, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = \ 
        C\ \[ExponentialE]\^\(\(-m\)\ v\^2/2\ k\_B\ T\)\)]],
  ", and find ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  "."
}], "Text",
  CellTags->"i:76"],

Cell[TextData[{
  StyleBox["(14)(a)",
    FontWeight->"Bold"],
  " Assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`D\_V\)]],
  " is constant, apply the method of characteristics to Eq. ",
  ButtonBox["(8.2.34)",
    ButtonData:>{"Chapter8.nb", "(8.2.34)"},
    ButtonStyle->"Hyperlink"],
  " to show that the equation can be written as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\[Rho]\/\[PartialD]t\)\( | \_\(v\_o\)\
\)\) = \[Gamma]\ \[Rho]\  + \ \(\(D\_V\) \(\[ExponentialE]\^\(2  \[Gamma]\ \
t\)\) \(\[PartialD]\^2 \[Rho]\/\[PartialD]v\_o\^2\)\(\ \)\)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o = v\ \[ExponentialE]\^\(\[Gamma]\ t\)\)]],
  "is the initial velocity, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ m\ D\_V/k\_B  T\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve this equation by Fourier transforming in velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " and solving the resulting first-order  ODE in time, with initial \
condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](v, 0) = \(\[Rho]\_o\)(v)\)]],
  ". Show that the solution is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Rho](v, 
        t) = \[Integral]\(\[DifferentialD]k\/\(2\ \[Pi]\)\) \
\(\(\[Rho]\&~\_o\)(
            k)\)\ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ v\ \[ExponentialE]\
\^\(\[Gamma]\ t\)\  + \ \ \[Gamma]\ t\  - \ \(\(D\ k\^2\)\/\(2\ \[Gamma]\)\) \
\((e\^\(\(\ \)\(2  \[Gamma]\ t\)\)\  - 1)\)\)\)\(.\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Perform the Fourier transformation for the case of an initial condition \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_o\)(v)\  = \ \[Delta](v - v\_o)\)]],
  " to show that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho](v, t)\), "=", 
          RowBox[{
            FractionBox["1", 
              SqrtBox[
                RowBox[{"2", " ", "\[Pi]", " ", 
                  RowBox[{
                    FormBox["\[LeftAngleBracket]",
                      "TraditionalForm"], 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[Delta]", 
                          StyleBox["v",
                            FontSlant->"Italic"]}]], "2"], 
                    "\[RightAngleBracket]"}], \((t)\)}]]], 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"v", "-", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[LeftAngleBracket]",
                                "TraditionalForm"], "v", 
                              "\[RightAngleBracket]"}], \((t)\)}]}], ")"}], 
                      "2"]}], "/", "2"}], 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[Delta]", 
                          StyleBox["v",
                            FontSlant->"Italic"]}]], "2"], "(", "t", ")"}], 
                  "\[RightAngleBracket]"}]}]]}]}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "v", "\[RightAngleBracket]"}], \((t)\)}], 
          "=", \(v\_o\ \[ExponentialE]\^\(\(-\[Gamma]\)\(\ \)\(t\)\(\ \
\)\)\)}], TraditionalForm]]],
  " is the mean velocity, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["v",
                    FontSlant->"Italic"]}]], "2"], 
            "\[RightAngleBracket]"}], \((t)\)}], TraditionalForm]]],
  " is given by Eq. ",
  ButtonBox["(8.1.50)",
    ButtonData:>{"Chapter8.nb", "(8.1.50)"},
    ButtonStyle->"Hyperlink"],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o = 2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_V = \(\[Gamma] = 1\)\)]],
  ", over the time ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(8.2.30)",
    ButtonData:>{"Chapter8.nb", "(8.2.30)"},
    ButtonStyle->"Hyperlink"],
  ", which implies that solutions to the inhomogeneous Fokker-Planck equation \
exhibit irreversibility."
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " For particles diffusing in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  ",  the Fokker-Planck equation ",
  ButtonBox["(8.2.18)",
    ButtonData:>{"Chapter8.nb", "(8.2.18)"},
    ButtonStyle->"Hyperlink"],
  " is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]\[Rho]\/\[PartialD]t = \[PartialD]\/\
\[PartialD]x\ \(D(
            x)\)\ [\(1\/\(\(k\_B\) 
                    T\)\) \[PartialD]\[Phi]\/\[PartialD]x\ \[Rho]\  + \
\[PartialD]\[Rho]\/\[PartialD]x]\)\(,\)\)\)]]], "NE2",
  CellTags->"(8.2.35)"],

Cell[TextData[{
  "where we have substituted for ",
  Cell[BoxData[
      \(TraditionalForm\`v(x)\)]],
  " using Eq. ",
  ButtonBox["(8.2.26)",
    ButtonData:>{"Chapter8.nb", "(8.2.26)"},
    ButtonStyle->"Hyperlink"],
  ".  Consider the case ",
  Cell[BoxData[
      \(TraditionalForm\`D = \(\(k\_B\) T = 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = x\^2\)]],
  " (i.e. particles trapped in a harmonic potential). Using any numerical \
method you choose taken from Chapter ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  " or ",
  ButtonBox["7",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  ", solve this problem for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, 0) = 1, \ 0 < x < 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, 0)\  = \ 0\)]],
  " otherwise.  For boundary conditions take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]5\)\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  ", and show that the solution approaches the Boltzmann distribution  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\  = \ \ \[ExponentialE]\^\(-x\^2\)/\@\[Pi]\
\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(17)(a)",
    FontWeight->"Bold"],
  " Solve the Fokker-Planck equation ",
  StyleBox["analytically",
    FontSlant->"Italic"],
  " for dust particles of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " falling in gravity ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " to the bottom of a container  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ". Assume that the diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`D = constant\)]],
  ", and take as the  initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\  = \ \[Delta](x - x\_o)\)]],
  ". Boundary conditions are that the flux is zero at the bottom of the \
container. (Solution:"
}], "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, 
          t)\  = \ \[Kappa]\ \[ExponentialE]\^\(\(-\[Kappa]\)\ x\) + \ \(2\/\
\[Pi]\) \(\[Integral]\_0\%\[Infinity]\[DifferentialD]k\ \(\[ExponentialE]\^\(\
\(-D\)\ \((k\^2 + \ \[Kappa]\^2/4)\) t\ \  + \(\[Kappa](x - x\_o)\)/
                        2\)\) \(\(\([2  k\ \(cos(k\ x\_o)\) - \[Kappa]\ \
\(sin(k\ x\_o)\)\ ]\)\ [2  k\ \(cos(k\ x)\) - \[Kappa]\ \(sin(k\ x)\)]\)\(\ \
\)\)\/\(4\ k\^2 + \[Kappa]\^2\)\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = m\ g/k\_B  T\)]],
  ".) (Hint: Solve as an eigenmode expansion, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " vanishes at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", and then take the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`L \[Rule] \ \(\(\[Infinity]\)\(.\)\)\)]],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For ",
  Cell[BoxData[
      \(TraditionalForm\`D = \(\[Kappa] = \(x\_o = 1\)\)\)]],
  ", evaluate the integral numerically and create an animation of the \
solution over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.3\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(18) ",
    FontWeight->"Bold"],
  StyleBox["Simulation project: The Eden model",
    FontSlant->"Italic"],
  ". Random process models have diffused into many fields of science. \
Consider the following model for the spread of tumors, rumors, disease, urban \
sprawl, or any number of other uncontrolled growth processes: the Eden model, \
named after the biologist ",
  ButtonBox["M. Eden",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". A small cluster of tumor cells infect cells on the perimeter of the \
tumor, and these infect other adjacent cells, and so on. At each step in the \
process, one of the perimeter cells is chosen randomly to become infected, \
after which it is added to the cluster and a new perimeter is calculated, \
from which a new infected cell will be chosen in the next step. The resulting \
tumor growth is surprisingly realistic (and rather horrifying to watch as an \
animation.)  This model is one of a large group of random processes, \
variously referred to as ",
  StyleBox["kinetic growth",
    FontSlant->"Italic"],
  " or ",
  StyleBox["percolation",
    FontSlant->"Italic"],
  " models. We will perform the Eden model on a 2D square lattice. Initially, \
only one cell at the origin is in the tumor cluster:"
}], "Text",
  CellTags->"i:78"],

Cell[BoxData[
    \(\(cluster[0]\  = \ {{0, 0}};\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.22"],

Cell["\<\
The perimeter points of the cluster are held in the list \
perim:\
\>", "Text"],

Cell[BoxData[
    \(\(perim[
          0]\  = \ {{0, 1}, {1, 0}, {\(-1\), 0}, {0, \(-1\)}};\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.23"],

Cell[TextData[{
  "From this perimeter list, a newly-infected cell is chosen at random. We \
define a function ",
  StyleBox["newsite[n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is the position of this cell,  chosen from the previous perimeter \
list, ",
  StyleBox["perim[n-1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(newsite[
        n_]\  := \ \(newsite[
          n]\  = \ \(perim[
            n - 1]\)[\([Random[
              Integer, {1, Length[perim[n - 1]]}]]\)]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.24"],

Cell["\<\
The new cluster is the union of the old cluster with the new \
site:\
\>", "Text"],

Cell[BoxData[
    \(cluster[n_]\  := \ \(cluster[n]\  = \ 
        Append[cluster[n - 1], newsite[n]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.25"],

Cell["\<\
Finally, we must calculate the  new perimeter, by first removing \
the new site from the old perimeter, and then adding the group of nearest \
neighbors to the new site onto the perimeter (making sure to avoid those \
nearest neighbors already in the cluster):\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(perim[n_]\), " ", ":=", " ", 
      RowBox[{\(perim[n]\), "=", " ", 
        RowBox[{"(", 
          
          RowBox[{\(perim1\  = \ Complement[perim[n - 1], {newsite[n]}]\), 
            " ", 
            StyleBox[\( (*removes\ newsite\ from\ the\ perimeter\ *) \),
              FontColor->RGBColor[1, 0, 0]], ";", 
            "\[IndentingNewLine]", \(nn\  = \ 
              Table[newsite[
                    n] + {{0, 1}, {1, 0}, {\(-1\), 
                        0}, {0, \(-1\)}}[\([m]\)], {m, 1, 4}]\), ";", "  ", 
            "\[IndentingNewLine]", \(nn\  = \ Complement[nn, \ cluster[n]]\), 
            ";", "  ", 
            
            StyleBox[\( (*nn\ is\ the\ nearest\ neighbors\ to\ the\ new\ \
site, \ excluding\ those\ in\ the\ cluster\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Union[perim1, nn]\)}], " ", 
          
          StyleBox[\( (*\ 
              add\ nearest\ neighbors\ to\ the\ perimeter\ list\ *) \),
            FontColor->RGBColor[1, 0, 0]], ")"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.26"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Create an animation of the cluster growth for up to ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2000\)]],
  ", showing only every 20th step.  (Use a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to display the positions.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  The edge of the tumor cluster is highly corrugated.  The length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of the perimeter is simply the number of cells in the list ",
  StyleBox["perim",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . Show using a log-log plot that ",
  Cell[BoxData[
      \(TraditionalForm\`L\  \[Proportional] \ n\^b\)]],
  ", and find a value of ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " from your simulation. What value of ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " would you expect if the tumor had a smooth edge?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " The Eden model can be made more realistic by assigning a probability  of \
immunity ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to each member of the perimeter. When a perimeter cell is chosen, use the \
rejection method to determine whether to infect the cell: evaluate a random \
number ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\(0 < r < 1;\)\)]],
  "  if ",
  Cell[BoxData[
      \(TraditionalForm\`r < p\)]],
  ", the cell is not  allowed to be infected in any future step: set it aside \
in a new list ",
  StyleBox["immunes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which can never enter the tumor cluster, and choose another perimeter \
cell until one is found that can be infected."
}], "Text"],

Cell[TextData[{
  "(i) Reevaluate the improved Eden model taking ",
  Cell[BoxData[
      \(TraditionalForm\`p = 0.5\)]],
  " for all cells and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 200\)]],
  ".  Create an animation as in part a), and reevaluate the exponent ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " for the length of the perimeter (include the immunes in the perimeter). \
(See Fig. ",
  ButtonBox["8.8",
    ButtonData:>"Fig. 8.8",
    ButtonStyle->"Hyperlink"],
  ".) Note: If ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(p\)\(\ \)\)\)]],
  "is chosen too large then the tumor has a good probability of not growing, \
as it can be surrounded by immune cells. Did the tumor grow without bound or \
stop?"
}], "Text"],

Cell[TextData[{
  "(ii) Repeat for ",
  Cell[BoxData[
      \(TraditionalForm\`p = 0.2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2000\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.434837 0.0100251 0.253137 0.00745068 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.02 w
.43484 .25314 Mdot
.43484 .24569 Mdot
.43484 .26059 Mdot
.43484 .26804 Mdot
.43484 .23824 Mdot
.43484 .23078 Mdot
.44486 .25314 Mdot
.43484 .22333 Mdot
.44486 .24569 Mdot
.44486 .23078 Mdot
.45489 .25314 Mdot
.44486 .26804 Mdot
.42481 .25314 Mdot
.44486 .26059 Mdot
.44486 .27549 Mdot
.42481 .24569 Mdot
.45489 .24569 Mdot
.42481 .23078 Mdot
.45489 .26059 Mdot
.41479 .23078 Mdot
.43484 .21588 Mdot
.41479 .25314 Mdot
.42481 .21588 Mdot
.44486 .22333 Mdot
.40476 .23078 Mdot
.45489 .26804 Mdot
.45489 .22333 Mdot
.40476 .23824 Mdot
.45489 .21588 Mdot
.42481 .26059 Mdot
.41479 .24569 Mdot
.46491 .26804 Mdot
.40476 .25314 Mdot
.43484 .27549 Mdot
.46491 .26059 Mdot
.40476 .24569 Mdot
.39474 .23824 Mdot
.47494 .26804 Mdot
.43484 .28294 Mdot
.39474 .24569 Mdot
.42481 .27549 Mdot
.42481 .28294 Mdot
.40476 .26059 Mdot
.41479 .26059 Mdot
.43484 .29039 Mdot
.40476 .22333 Mdot
.39474 .22333 Mdot
.47494 .26059 Mdot
.38471 .22333 Mdot
.39474 .21588 Mdot
.47494 .25314 Mdot
.38471 .24569 Mdot
.37469 .22333 Mdot
.39474 .20843 Mdot
.38471 .21588 Mdot
.40476 .20843 Mdot
.41479 .27549 Mdot
.40476 .27549 Mdot
.40476 .21588 Mdot
.41479 .20843 Mdot
.36466 .22333 Mdot
.44486 .29039 Mdot
.44486 .29784 Mdot
.45489 .29039 Mdot
.48496 .26059 Mdot
.46491 .27549 Mdot
.35464 .22333 Mdot
.37469 .21588 Mdot
.37469 .24569 Mdot
.40476 .20098 Mdot
.43484 .29784 Mdot
.38471 .20843 Mdot
.38471 .20098 Mdot
.45489 .29784 Mdot
.40476 .28294 Mdot
.35464 .23078 Mdot
.38471 .19353 Mdot
.38471 .18608 Mdot
.40476 .29039 Mdot
.46491 .28294 Mdot
.35464 .21588 Mdot
.39474 .19353 Mdot
.40476 .19353 Mdot
.40476 .18608 Mdot
.41479 .18608 Mdot
.47494 .28294 Mdot
.48496 .28294 Mdot
.37469 .20843 Mdot
.49499 .28294 Mdot
.42481 .29784 Mdot
.37469 .20098 Mdot
.36466 .20098 Mdot
.50501 .28294 Mdot
.48496 .27549 Mdot
.49499 .29039 Mdot
.42481 .30529 Mdot
.42481 .31274 Mdot
.35464 .20098 Mdot
.49499 .29784 Mdot
.48496 .29039 Mdot
.48496 .29784 Mdot
.41479 .29784 Mdot
.42481 .32019 Mdot
.51504 .28294 Mdot
.47494 .29784 Mdot
.35464 .19353 Mdot
.41479 .30529 Mdot
.51504 .29039 Mdot
.47494 .30529 Mdot
.34461 .20098 Mdot
.52506 .28294 Mdot
.46491 .30529 Mdot
.51504 .27549 Mdot
.41479 .32019 Mdot
.53509 .28294 Mdot
.41479 .32764 Mdot
.40476 .29784 Mdot
.51504 .29784 Mdot
.42481 .32764 Mdot
.51504 .30529 Mdot
.40476 .32764 Mdot
.53509 .29039 Mdot
.35464 .18608 Mdot
.33459 .20098 Mdot
.40476 .33509 Mdot
.34461 .20843 Mdot
.54511 .28294 Mdot
.53509 .29784 Mdot
.40476 .32019 Mdot
.33459 .20843 Mdot
.40476 .34255 Mdot
.40476 .30529 Mdot
.54511 .27549 Mdot
.54511 .29784 Mdot
.35464 .23824 Mdot
.53509 .27549 Mdot
.40476 .35 Mdot
.55514 .28294 Mdot
.39474 .32764 Mdot
.52506 .29039 Mdot
.39474 .35 Mdot
.35464 .17863 Mdot
.42481 .33509 Mdot
.48496 .30529 Mdot
.36466 .17863 Mdot
.38471 .35 Mdot
.54511 .29039 Mdot
.39474 .30529 Mdot
.40476 .31274 Mdot
.52506 .30529 Mdot
.43484 .33509 Mdot
.55514 .27549 Mdot
.41479 .35 Mdot
.53509 .30529 Mdot
.56516 .28294 Mdot
.40476 .35745 Mdot
.37469 .35 Mdot
.50501 .29784 Mdot
.38471 .34255 Mdot
.36466 .23824 Mdot
.39474 .33509 Mdot
.43484 .34255 Mdot
.52506 .31274 Mdot
.57519 .28294 Mdot
.58521 .28294 Mdot
.53509 .26804 Mdot
.32456 .20843 Mdot
.36466 .35 Mdot
.37469 .35745 Mdot
.35464 .24569 Mdot
.37469 .3649 Mdot
.33459 .19353 Mdot
.33459 .21588 Mdot
.55514 .26804 Mdot
.52506 .26804 Mdot
.43484 .35 Mdot
.39474 .29784 Mdot
.38471 .3649 Mdot
.42481 .35 Mdot
.43484 .32764 Mdot
.43484 .35745 Mdot
.55514 .29784 Mdot
.38471 .29784 Mdot
.32456 .19353 Mdot
.44486 .32764 Mdot
.33459 .18608 Mdot
.40476 .3649 Mdot
.52506 .26059 Mdot
.39474 .35745 Mdot
.44486 .34255 Mdot
.46491 .31274 Mdot
.32456 .18608 Mdot
.40476 .37235 Mdot
.33459 .17863 Mdot
.45489 .31274 Mdot
.57519 .29039 Mdot
.32456 .17863 Mdot
.37469 .29784 Mdot
.41479 .37235 Mdot
.56516 .27549 Mdot
.37469 .30529 Mdot
.36466 .17118 Mdot
.36466 .29784 Mdot
.36466 .30529 Mdot
.33459 .17118 Mdot
.55514 .26059 Mdot
.44486 .32019 Mdot
.54511 .30529 Mdot
.37469 .29039 Mdot
.38471 .29039 Mdot
.57519 .27549 Mdot
.53509 .26059 Mdot
.55514 .25314 Mdot
.31454 .18608 Mdot
.55514 .24569 Mdot
.57519 .26804 Mdot
.56516 .24569 Mdot
.40476 .3798 Mdot
.38471 .35745 Mdot
.33459 .16373 Mdot
.39474 .3798 Mdot
.55514 .23824 Mdot
.56516 .25314 Mdot
.54511 .23824 Mdot
.45489 .34255 Mdot
.45489 .32019 Mdot
.35464 .30529 Mdot
.53509 .25314 Mdot
.44486 .35745 Mdot
.35464 .29784 Mdot
.43484 .3649 Mdot
.36466 .34255 Mdot
.34461 .30529 Mdot
.32456 .21588 Mdot
.48496 .31274 Mdot
.34461 .17118 Mdot
.48496 .32019 Mdot
.49499 .32019 Mdot
.35464 .35 Mdot
.34461 .35 Mdot
.41479 .3649 Mdot
.34461 .16373 Mdot
.37469 .17863 Mdot
.45489 .33509 Mdot
.58521 .26804 Mdot
.57519 .25314 Mdot
.58521 .26059 Mdot
.34461 .15628 Mdot
.32456 .22333 Mdot
.34461 .35745 Mdot
.42481 .3649 Mdot
.31454 .22333 Mdot
.38471 .3798 Mdot
.53509 .23824 Mdot
.57519 .26059 Mdot
.56516 .23824 Mdot
.40476 .38725 Mdot
.32456 .23078 Mdot
.44486 .3649 Mdot
.58521 .25314 Mdot
.37469 .3798 Mdot
.33459 .23078 Mdot
.52506 .23824 Mdot
.52506 .23078 Mdot
.41479 .34255 Mdot
.47494 .32019 Mdot
.46491 .32019 Mdot
.34461 .34255 Mdot
.36466 .29039 Mdot
.36466 .28294 Mdot
.35464 .35745 Mdot
.38471 .38725 Mdot
.35464 .31274 Mdot
.36466 .27549 Mdot
.37469 .27549 Mdot
.30451 .22333 Mdot
.46491 .33509 Mdot
.52506 .22333 Mdot
.38471 .3947 Mdot
.51504 .26059 Mdot
.37469 .34255 Mdot
.46491 .34255 Mdot
.32456 .23824 Mdot
.51504 .23078 Mdot
.30451 .21588 Mdot
.51504 .25314 Mdot
.34461 .29784 Mdot
.34461 .3649 Mdot
.50501 .23078 Mdot
.53509 .24569 Mdot
.34461 .33509 Mdot
.45489 .35745 Mdot
.49499 .32764 Mdot
.35464 .33509 Mdot
.35464 .32764 Mdot
.34461 .32764 Mdot
.31454 .23078 Mdot
.33459 .3649 Mdot
.37469 .31274 Mdot
.50501 .22333 Mdot
.52506 .21588 Mdot
.37469 .33509 Mdot
.36466 .26804 Mdot
.30451 .18608 Mdot
.47494 .34255 Mdot
.50501 .25314 Mdot
.37469 .3947 Mdot
.38471 .31274 Mdot
.30451 .19353 Mdot
.33459 .34255 Mdot
.53509 .23078 Mdot
.48496 .34255 Mdot
.43484 .37235 Mdot
.59524 .26804 Mdot
.32456 .24569 Mdot
.33459 .23824 Mdot
.34461 .32019 Mdot
.59524 .27549 Mdot
.30451 .20843 Mdot
.49499 .34255 Mdot
.59524 .25314 Mdot
.46491 .32764 Mdot
.38471 .32019 Mdot
.34461 .29039 Mdot
.35464 .27549 Mdot
.35464 .32019 Mdot
.51504 .23824 Mdot
.53509 .21588 Mdot
.38471 .40215 Mdot
.31454 .24569 Mdot
.34461 .23824 Mdot
.34461 .27549 Mdot
.47494 .35 Mdot
.46491 .35 Mdot
.53509 .22333 Mdot
.54511 .21588 Mdot
.34461 .28294 Mdot
.52506 .20843 Mdot
.33459 .33509 Mdot
.60526 .27549 Mdot
.50501 .26059 Mdot
.36466 .26059 Mdot
.34461 .26804 Mdot
.35464 .3649 Mdot
.49499 .33509 Mdot
.60526 .26804 Mdot
.29449 .19353 Mdot
.49499 .22333 Mdot
.50501 .24569 Mdot
.32456 .25314 Mdot
.49499 .24569 Mdot
.55514 .21588 Mdot
.60526 .26059 Mdot
.34461 .26059 Mdot
.61529 .27549 Mdot
.51504 .20843 Mdot
.32456 .3649 Mdot
.54511 .22333 Mdot
.50501 .26804 Mdot
.50501 .20843 Mdot
.50501 .34255 Mdot
.50501 .20098 Mdot
.50501 .35 Mdot
.55514 .22333 Mdot
.38471 .4096 Mdot
.32456 .33509 Mdot
.61529 .26804 Mdot
.37469 .26059 Mdot
.50501 .33509 Mdot
.34461 .25314 Mdot
.51504 .21588 Mdot
.37469 .4096 Mdot
.31454 .23824 Mdot
.36466 .25314 Mdot
.60526 .28294 Mdot
.60526 .29039 Mdot
.45489 .32764 Mdot
.33459 .29784 Mdot
.62531 .27549 Mdot
.32456 .32764 Mdot
.56516 .22333 Mdot
.51504 .35 Mdot
.31454 .3649 Mdot
.31454 .35745 Mdot
.55514 .20843 Mdot
.61529 .29039 Mdot
.53509 .20843 Mdot
.33459 .26804 Mdot
.59524 .29039 Mdot
.30451 .23824 Mdot
.29449 .23824 Mdot
.63534 .27549 Mdot
.33459 .28294 Mdot
.32456 .29784 Mdot
.38471 .26059 Mdot
.37469 .26804 Mdot
.61529 .29784 Mdot
.62531 .29784 Mdot
.61529 .28294 Mdot
.38471 .26804 Mdot
.31454 .35 Mdot
.32456 .32019 Mdot
.51504 .33509 Mdot
.38471 .41705 Mdot
.31454 .33509 Mdot
.32456 .37235 Mdot
.30451 .35745 Mdot
.32456 .35745 Mdot
.31454 .32019 Mdot
.32456 .26059 Mdot
.52506 .33509 Mdot
.62531 .30529 Mdot
.32456 .26804 Mdot
.39474 .26804 Mdot
.63534 .28294 Mdot
.39474 .41705 Mdot
.29449 .35745 Mdot
.30451 .35 Mdot
.39474 .4245 Mdot
.51504 .32764 Mdot
.61529 .26059 Mdot
.31454 .26804 Mdot
.40476 .41705 Mdot
.32456 .3798 Mdot
.32456 .28294 Mdot
.29449 .24569 Mdot
.31454 .34255 Mdot
.59524 .29784 Mdot
.32456 .30529 Mdot
.28446 .35745 Mdot
.61529 .25314 Mdot
.62531 .29039 Mdot
.59524 .30529 Mdot
.36466 .32764 Mdot
.62531 .26059 Mdot
.30451 .26804 Mdot
.31454 .27549 Mdot
.29449 .35 Mdot
.32456 .29039 Mdot
.41479 .41705 Mdot
.29449 .34255 Mdot
.32456 .27549 Mdot
.63534 .29784 Mdot
.52506 .34255 Mdot
.31454 .29784 Mdot
.29449 .23078 Mdot
.30451 .29784 Mdot
.62531 .25314 Mdot
.30451 .24569 Mdot
.30451 .30529 Mdot
.31454 .30529 Mdot
.60526 .29784 Mdot
.64536 .29784 Mdot
.31454 .3798 Mdot
.28446 .3649 Mdot
.54511 .20843 Mdot
.31454 .29039 Mdot
.30451 .25314 Mdot
.31454 .38725 Mdot
.29449 .30529 Mdot
.63534 .30529 Mdot
.28446 .35 Mdot
.31454 .28294 Mdot
.28446 .30529 Mdot
.51504 .20098 Mdot
.51504 .19353 Mdot
.41479 .4245 Mdot
.30451 .3798 Mdot
.58521 .30529 Mdot
.52506 .19353 Mdot
.39474 .40215 Mdot
.41479 .4096 Mdot
.42481 .41705 Mdot
.63534 .26804 Mdot
.40476 .4096 Mdot
.39474 .43195 Mdot
.32456 .38725 Mdot
.58521 .31274 Mdot
.29449 .29784 Mdot
.30451 .37235 Mdot
.64536 .26804 Mdot
.59524 .31274 Mdot
.28446 .31274 Mdot
.42481 .4245 Mdot
.41479 .43195 Mdot
.40476 .40215 Mdot
.30451 .28294 Mdot
.52506 .18608 Mdot
.29449 .28294 Mdot
.30451 .32019 Mdot
.63534 .31274 Mdot
.29449 .37235 Mdot
.64536 .26059 Mdot
.28446 .32019 Mdot
.63534 .32019 Mdot
.28446 .32764 Mdot
.59524 .32019 Mdot
.63534 .29039 Mdot
.58521 .32019 Mdot
.49499 .20843 Mdot
.29449 .31274 Mdot
.29449 .3798 Mdot
.30451 .38725 Mdot
.54511 .20098 Mdot
.29449 .33509 Mdot
.29449 .29039 Mdot
.64536 .25314 Mdot
.63534 .25314 Mdot
.39474 .4394 Mdot
.30451 .3947 Mdot
.48496 .20843 Mdot
.62531 .32019 Mdot
.38471 .4394 Mdot
.48496 .20098 Mdot
.53509 .33509 Mdot
.64536 .24569 Mdot
.36466 .4096 Mdot
.29449 .3947 Mdot
.31454 .32764 Mdot
.57519 .32019 Mdot
.29449 .32764 Mdot
.30451 .32764 Mdot
.40476 .43195 Mdot
.27444 .31274 Mdot
.61529 .32019 Mdot
.61529 .31274 Mdot
.43484 .4245 Mdot
.64536 .28294 Mdot
.44486 .4245 Mdot
.45489 .4245 Mdot
.53509 .18608 Mdot
.48496 .19353 Mdot
.46491 .4245 Mdot
.65539 .24569 Mdot
.65539 .26059 Mdot
.30451 .40215 Mdot
.43484 .41705 Mdot
.60526 .31274 Mdot
.29449 .40215 Mdot
.66541 .24569 Mdot
.66541 .23824 Mdot
.46491 .43195 Mdot
.54511 .18608 Mdot
.56516 .32019 Mdot
.43484 .43195 Mdot
.43484 .4096 Mdot
.54511 .19353 Mdot
.67544 .23824 Mdot
.47494 .20098 Mdot
.66541 .23078 Mdot
.37469 .41705 Mdot
.67544 .23078 Mdot
.61529 .32764 Mdot
.47494 .4245 Mdot
.39474 .44685 Mdot
.31454 .3947 Mdot
.53509 .17863 Mdot
.68546 .23824 Mdot
.37469 .4245 Mdot
.60526 .32764 Mdot
.49499 .19353 Mdot
.47494 .20843 Mdot
.60526 .33509 Mdot
.51504 .18608 Mdot
.27444 .32764 Mdot
.28446 .29039 Mdot
.57519 .32764 Mdot
.59524 .32764 Mdot
.27444 .33509 Mdot
.66541 .22333 Mdot
.44486 .41705 Mdot
.26441 .31274 Mdot
.28446 .28294 Mdot
.37469 .4394 Mdot
.45489 .41705 Mdot
.48496 .4245 Mdot
.47494 .41705 Mdot
.65539 .22333 Mdot
.51504 .17863 Mdot
.55514 .32019 Mdot
.49499 .18608 Mdot
.59524 .33509 Mdot
.30451 .4096 Mdot
.28446 .27549 Mdot
.26441 .32019 Mdot
.37469 .43195 Mdot
.63534 .32764 Mdot
.50501 .17863 Mdot
.25439 .32019 Mdot
.48496 .43195 Mdot
.26441 .33509 Mdot
.46491 .20098 Mdot
.25439 .33509 Mdot
.53509 .17118 Mdot
.66541 .25314 Mdot
.55514 .18608 Mdot
.56516 .32764 Mdot
.49499 .17863 Mdot
.27444 .34255 Mdot
.29449 .4096 Mdot
.52506 .17118 Mdot
.49499 .4245 Mdot
.56516 .18608 Mdot
.61529 .33509 Mdot
.25439 .31274 Mdot
.25439 .30529 Mdot
.57519 .18608 Mdot
.44486 .4096 Mdot
.58521 .18608 Mdot
.29449 .41705 Mdot
.56516 .19353 Mdot
.55514 .17863 Mdot
.49499 .17118 Mdot
.49499 .16373 Mdot
.31454 .4096 Mdot
.28446 .3798 Mdot
.61529 .34255 Mdot
.55514 .17118 Mdot
.50501 .4245 Mdot
.39474 .45431 Mdot
.55514 .32764 Mdot
.36466 .4394 Mdot
.64536 .32764 Mdot
.58521 .17863 Mdot
.48496 .4394 Mdot
.50501 .43195 Mdot
.24436 .31274 Mdot
.50501 .18608 Mdot
.50501 .4394 Mdot
.57519 .17863 Mdot
.62531 .33509 Mdot
.51504 .43195 Mdot
.64536 .33509 Mdot
.54511 .32764 Mdot
.52506 .43195 Mdot
.27444 .28294 Mdot
.38471 .45431 Mdot
.28446 .29784 Mdot
.24436 .30529 Mdot
.59524 .18608 Mdot
.29449 .4245 Mdot
.65539 .32764 Mdot
.48496 .16373 Mdot
.28446 .26804 Mdot
.37469 .45431 Mdot
.57519 .33509 Mdot
.52506 .4245 Mdot
.49499 .4394 Mdot
.65539 .32019 Mdot
.50501 .16373 Mdot
.49499 .41705 Mdot
.36466 .44685 Mdot
.65539 .31274 Mdot
.32456 .4096 Mdot
.50501 .17118 Mdot
.53509 .43195 Mdot
.54511 .43195 Mdot
.35464 .44685 Mdot
.48496 .15628 Mdot
.65539 .33509 Mdot
.56516 .33509 Mdot
.40476 .45431 Mdot
.59524 .19353 Mdot
.52506 .4394 Mdot
.32456 .40215 Mdot
.28446 .4096 Mdot
.49499 .44685 Mdot
.49499 .43195 Mdot
.53509 .4394 Mdot
.56516 .34255 Mdot
.59524 .34255 Mdot
.58521 .34255 Mdot
.59524 .35 Mdot
.53509 .44685 Mdot
.40476 .46176 Mdot
.64536 .34255 Mdot
.27444 .4096 Mdot
.53509 .45431 Mdot
.59524 .17863 Mdot
.63534 .34255 Mdot
.57519 .34255 Mdot
.25439 .32764 Mdot
.63534 .35 Mdot
.60526 .17863 Mdot
.24436 .32764 Mdot
.64536 .35 Mdot
.56516 .35 Mdot
.28446 .26059 Mdot
.27444 .40215 Mdot
.26441 .40215 Mdot
.33459 .4096 Mdot
.40476 .46921 Mdot
.51504 .4245 Mdot
.41479 .46921 Mdot
.23434 .32764 Mdot
.63534 .35745 Mdot
.52506 .44685 Mdot
.66541 .33509 Mdot
.34461 .4096 Mdot
.23434 .32019 Mdot
.53509 .46176 Mdot
.55514 .34255 Mdot
.22431 .32764 Mdot
.26441 .3947 Mdot
.21429 .32764 Mdot
.27444 .26059 Mdot
.58521 .17118 Mdot
.58521 .16373 Mdot
.57519 .35 Mdot
.57519 .35745 Mdot
.34461 .40215 Mdot
.25439 .40215 Mdot
.60526 .35 Mdot
.58521 .35745 Mdot
.41479 .47666 Mdot
.66541 .34255 Mdot
.41479 .46176 Mdot
.26441 .26059 Mdot
.33459 .41705 Mdot
.39474 .46921 Mdot
.61529 .17863 Mdot
.26441 .25314 Mdot
.58521 .15628 Mdot
.22431 .33509 Mdot
.62531 .35745 Mdot
.58521 .35 Mdot
.58521 .3649 Mdot
.54511 .34255 Mdot
.35464 .40215 Mdot
.39474 .47666 Mdot
.22431 .34255 Mdot
.33459 .4245 Mdot
.57519 .16373 Mdot
.29449 .26059 Mdot
.33459 .43195 Mdot
.58521 .37235 Mdot
.61529 .35745 Mdot
.58521 .14883 Mdot
.57519 .15628 Mdot
.34461 .43195 Mdot
.32456 .43195 Mdot
.41479 .48411 Mdot
.59524 .3649 Mdot
.32456 .4394 Mdot
.21429 .34255 Mdot
.31454 .43195 Mdot
.60526 .3649 Mdot
.34461 .41705 Mdot
.64536 .22333 Mdot
.47494 .16373 Mdot
.31454 .4394 Mdot
.30451 .43195 Mdot
.38471 .46176 Mdot
.31454 .44685 Mdot
.41479 .49156 Mdot
.61529 .18608 Mdot
.25439 .3947 Mdot
.35464 .41705 Mdot
.31454 .4245 Mdot
.21429 .33509 Mdot
.67544 .34255 Mdot
.40476 .49156 Mdot
.59524 .16373 Mdot
.54511 .46176 Mdot
.64536 .21588 Mdot
.67544 .33509 Mdot
.23434 .34255 Mdot
.35464 .4245 Mdot
.68546 .34255 Mdot
.40476 .49901 Mdot
.67544 .32764 Mdot
.55514 .46176 Mdot
.60526 .37235 Mdot
.26441 .26804 Mdot
.56516 .46176 Mdot
.20426 .33509 Mdot
.60526 .3798 Mdot
.58521 .14138 Mdot
.60526 .38725 Mdot
.24436 .40215 Mdot
.24436 .4096 Mdot
.54511 .35 Mdot
.39474 .48411 Mdot
.62531 .17863 Mdot
.20426 .34255 Mdot
.39474 .49156 Mdot
.41479 .49901 Mdot
.24436 .3947 Mdot
.19424 .34255 Mdot
.60526 .3947 Mdot
.60526 .40215 Mdot
.59524 .14138 Mdot
.69549 .34255 Mdot
.54511 .46921 Mdot
.56516 .46921 Mdot
.25439 .38725 Mdot
.68546 .32764 Mdot
.59524 .13393 Mdot
.68546 .35 Mdot
.25439 .3798 Mdot
.26441 .3798 Mdot
.23434 .35 Mdot
.60526 .4096 Mdot
.51504 .41705 Mdot
.38471 .48411 Mdot
.59524 .40215 Mdot
.23434 .35745 Mdot
.59524 .3798 Mdot
.40476 .48411 Mdot
.22431 .35745 Mdot
.61529 .4096 Mdot
.54511 .35745 Mdot
.23434 .4096 Mdot
.42481 .47666 Mdot
.26441 .37235 Mdot
.57519 .37235 Mdot
.52506 .46176 Mdot
.57519 .46921 Mdot
.51504 .4096 Mdot
.60526 .13393 Mdot
.61529 .3947 Mdot
.22431 .3649 Mdot
.38471 .49156 Mdot
.24436 .41705 Mdot
.62531 .3947 Mdot
.61529 .13393 Mdot
.25439 .26804 Mdot
.55514 .35745 Mdot
.59524 .4096 Mdot
.59524 .41705 Mdot
.21429 .3649 Mdot
.23434 .3947 Mdot
.68546 .33509 Mdot
.58521 .46921 Mdot
.62531 .38725 Mdot
.58521 .47666 Mdot
.59524 .12648 Mdot
.23434 .3649 Mdot
.19424 .35 Mdot
.56516 .37235 Mdot
.56516 .47666 Mdot
.63534 .38725 Mdot
.62531 .3798 Mdot
.59524 .11902 Mdot
.61529 .38725 Mdot
.42481 .49156 Mdot
.69549 .32764 Mdot
.60526 .11902 Mdot
.50501 .4096 Mdot
.58521 .46176 Mdot
.69549 .32019 Mdot
.58521 .45431 Mdot
.23434 .41705 Mdot
.62531 .13393 Mdot
.20426 .35 Mdot
.63534 .3947 Mdot
.19424 .35745 Mdot
.56516 .3798 Mdot
.64536 .3947 Mdot
.18421 .35 Mdot
.70551 .32019 Mdot
.22431 .3947 Mdot
.62531 .37235 Mdot
.62531 .14138 Mdot
.24436 .3649 Mdot
.25439 .3649 Mdot
.25439 .41705 Mdot
.25439 .27549 Mdot
.55514 .47666 Mdot
.22431 .41705 Mdot
.17419 .35 Mdot
.69549 .31274 Mdot
.25439 .4245 Mdot
.22431 .4245 Mdot
.51504 .46176 Mdot
.51504 .45431 Mdot
.58521 .44685 Mdot
.55514 .37235 Mdot
.25439 .43195 Mdot
.64536 .40215 Mdot
.24436 .37235 Mdot
.20426 .35745 Mdot
.55514 .35 Mdot
.70551 .32764 Mdot
.63534 .40215 Mdot
.58521 .12648 Mdot
.17419 .35745 Mdot
.58521 .13393 Mdot
.57519 .46176 Mdot
.21429 .41705 Mdot
.60526 .41705 Mdot
.58521 .41705 Mdot
.23434 .40215 Mdot
.19424 .33509 Mdot
.47494 .17118 Mdot
.46491 .17118 Mdot
.63534 .4096 Mdot
.22431 .38725 Mdot
.17419 .34255 Mdot
.63534 .41705 Mdot
.59524 .46176 Mdot
.69549 .30529 Mdot
.17419 .33509 Mdot
.68546 .31274 Mdot
.60526 .12648 Mdot
.59524 .46921 Mdot
.63534 .13393 Mdot
.60526 .4245 Mdot
.65539 .3947 Mdot
.65539 .40215 Mdot
.56516 .48411 Mdot
.61529 .12648 Mdot
.22431 .3798 Mdot
.54511 .37235 Mdot
.57519 .41705 Mdot
.16416 .33509 Mdot
.51504 .46921 Mdot
.57519 .12648 Mdot
.68546 .30529 Mdot
.20426 .41705 Mdot
.57519 .45431 Mdot
.66541 .40215 Mdot
.64536 .41705 Mdot
.62531 .40215 Mdot
.66541 .3947 Mdot
.57519 .48411 Mdot
.16416 .35 Mdot
.59524 .47666 Mdot
.62531 .12648 Mdot
.69549 .29784 Mdot
.20426 .4096 Mdot
.62531 .11902 Mdot
.63534 .4245 Mdot
.58521 .4096 Mdot
.61529 .19353 Mdot
.46491 .17863 Mdot
.50501 .46176 Mdot
.62531 .11157 Mdot
.61529 .4245 Mdot
.23434 .3798 Mdot
.64536 .4245 Mdot
.70551 .30529 Mdot
.62531 .10412 Mdot
.16416 .35745 Mdot
.64536 .13393 Mdot
.61529 .11157 Mdot
.53509 .37235 Mdot
.65539 .41705 Mdot
.67544 .30529 Mdot
.62531 .09667 Mdot
.69549 .29039 Mdot
.49499 .46176 Mdot
.59524 .48411 Mdot
.67544 .3947 Mdot
.59524 .49156 Mdot
.69549 .28294 Mdot
.67544 .29784 Mdot
.19424 .3649 Mdot
.18421 .3649 Mdot
.60526 .49156 Mdot
.15414 .33509 Mdot
.20426 .40215 Mdot
.67544 .38725 Mdot
.20426 .3947 Mdot
.19424 .32764 Mdot
.62531 .08922 Mdot
.62531 .08177 Mdot
.61529 .10412 Mdot
.63534 .08922 Mdot
.65539 .4245 Mdot
.66541 .29784 Mdot
.66541 .29039 Mdot
.65539 .43195 Mdot
.65539 .4394 Mdot
.65539 .29039 Mdot
.61529 .49156 Mdot
.18421 .37235 Mdot
.19424 .40215 Mdot
.63534 .11157 Mdot
.21429 .40215 Mdot
.14411 .33509 Mdot
.21429 .3798 Mdot
.63534 .09667 Mdot
.66541 .28294 Mdot
.66541 .43195 Mdot
.66541 .38725 Mdot
.67544 .43195 Mdot
.64536 .09667 Mdot
.59524 .49901 Mdot
.66541 .4394 Mdot
.16416 .32764 Mdot
.67544 .4394 Mdot
.20426 .3798 Mdot
.58521 .49901 Mdot
.19424 .3947 Mdot
.20426 .37235 Mdot
.65539 .09667 Mdot
.67544 .4245 Mdot
.58521 .49156 Mdot
.16416 .32019 Mdot
.20426 .38725 Mdot
.21429 .38725 Mdot
.18421 .3947 Mdot
.63534 .43195 Mdot
.13409 .33509 Mdot
.65539 .08922 Mdot
.13409 .32764 Mdot
.62531 .07432 Mdot
.64536 .11157 Mdot
.68546 .4394 Mdot
.64536 .11902 Mdot
.54511 .3798 Mdot
.66541 .09667 Mdot
.68546 .4245 Mdot
.62531 .19353 Mdot
.67544 .44685 Mdot
.67544 .41705 Mdot
.64536 .14138 Mdot
.23434 .4245 Mdot
.46491 .18608 Mdot
.66541 .3798 Mdot
.68546 .44685 Mdot
.19424 .32019 Mdot
.19424 .37235 Mdot
.64536 .4394 Mdot
.63534 .4394 Mdot
.68546 .29039 Mdot
.19424 .38725 Mdot
.61529 .07432 Mdot
.14411 .34255 Mdot
.45489 .18608 Mdot
.68546 .28294 Mdot
.48496 .46176 Mdot
.53509 .3798 Mdot
.66541 .4245 Mdot
.18421 .38725 Mdot
.58521 .50646 Mdot
.44486 .18608 Mdot
.20426 .32019 Mdot
.16416 .31274 Mdot
.67544 .45431 Mdot
.12406 .32764 Mdot
.19424 .3798 Mdot
.67544 .4096 Mdot
.15414 .34255 Mdot
.20426 .31274 Mdot
.19424 .31274 Mdot
.18421 .32019 Mdot
.68546 .4096 Mdot
.13409 .34255 Mdot
.58521 .51391 Mdot
.47494 .46176 Mdot
.12406 .32019 Mdot
.58521 .52136 Mdot
.20426 .30529 Mdot
.59524 .50646 Mdot
.17419 .32019 Mdot
.47494 .46921 Mdot
.66541 .45431 Mdot
.58521 .52881 Mdot
.66541 .08922 Mdot
.69549 .27549 Mdot
.61529 .49901 Mdot
.46491 .46176 Mdot
.67544 .08922 Mdot
.68546 .27549 Mdot
.65539 .3798 Mdot
.60526 .49901 Mdot
.64536 .3798 Mdot
.44486 .17863 Mdot
.70551 .27549 Mdot
.43484 .18608 Mdot
.62531 .4394 Mdot
.62531 .44685 Mdot
.67544 .09667 Mdot
.68546 .41705 Mdot
.69549 .4096 Mdot
.71554 .27549 Mdot
.68546 .09667 Mdot
.11404 .32019 Mdot
.66541 .08177 Mdot
.66541 .46176 Mdot
.60526 .50646 Mdot
.62531 .49901 Mdot
.57519 .52881 Mdot
.62531 .20098 Mdot
.69549 .26804 Mdot
.61529 .44685 Mdot
.62531 .45431 Mdot
.46491 .46921 Mdot
.61529 .45431 Mdot
.68546 .10412 Mdot
.16416 .30529 Mdot
.56516 .52881 Mdot
.65539 .11157 Mdot
.67544 .10412 Mdot
.65539 .46176 Mdot
.55514 .52881 Mdot
.64536 .37235 Mdot
.44486 .19353 Mdot
.60526 .44685 Mdot
.60526 .4394 Mdot
.20426 .29784 Mdot
.47494 .45431 Mdot
.53509 .38725 Mdot
.65539 .44685 Mdot
.46491 .47666 Mdot
.61529 .4394 Mdot
.71554 .28294 Mdot
.59524 .52136 Mdot
.47494 .44685 Mdot
.61529 .09667 Mdot
.71554 .29039 Mdot
.72556 .28294 Mdot
.69549 .09667 Mdot
.46491 .45431 Mdot
.60526 .09667 Mdot
.60526 .47666 Mdot
.67544 .11157 Mdot
.69549 .4394 Mdot
.61529 .47666 Mdot
.17419 .30529 Mdot
.56516 .52136 Mdot
.15414 .30529 Mdot
.18421 .30529 Mdot
.68546 .11157 Mdot
.64536 .3649 Mdot
.59524 .4394 Mdot
.12406 .31274 Mdot
.65539 .3649 Mdot
.61529 .46921 Mdot
.45489 .46921 Mdot
.16416 .29784 Mdot
.16416 .29039 Mdot
.20426 .29039 Mdot
.69549 .10412 Mdot
.56516 .51391 Mdot
.18421 .29784 Mdot
.17419 .29039 Mdot
.55514 .51391 Mdot
.60526 .51391 Mdot
.72556 .29039 Mdot
.61529 .51391 Mdot
.59524 .43195 Mdot
.52506 .38725 Mdot
.57519 .53626 Mdot
.61529 .06687 Mdot
.13409 .31274 Mdot
.70551 .10412 Mdot
.65539 .35745 Mdot
.14411 .30529 Mdot
.72556 .29784 Mdot
.45489 .47666 Mdot
.51504 .38725 Mdot
.73559 .28294 Mdot
.51504 .3798 Mdot
.46491 .48411 Mdot
.52506 .3947 Mdot
.50501 .3798 Mdot
.72556 .30529 Mdot
.61529 .52136 Mdot
.73559 .29784 Mdot
.57519 .54371 Mdot
.69549 .11157 Mdot
.56516 .54371 Mdot
.45489 .48411 Mdot
.58521 .54371 Mdot
.73559 .27549 Mdot
.55514 .54371 Mdot
.73559 .26804 Mdot
.59524 .09667 Mdot
.58521 .55116 Mdot
.51504 .3947 Mdot
.45489 .49156 Mdot
.73559 .26059 Mdot
.44486 .49156 Mdot
.57519 .55116 Mdot
.73559 .25314 Mdot
.74561 .26059 Mdot
.12406 .30529 Mdot
.11404 .30529 Mdot
.72556 .26804 Mdot
.18421 .29039 Mdot
.57519 .55861 Mdot
.73559 .24569 Mdot
.71554 .10412 Mdot
.55514 .52136 Mdot
.51504 .37235 Mdot
.13409 .30529 Mdot
.50501 .37235 Mdot
.55514 .55116 Mdot
.72556 .25314 Mdot
.71554 .11157 Mdot
.71554 .11902 Mdot
.52506 .40215 Mdot
.71554 .25314 Mdot
.72556 .11157 Mdot
.19424 .29039 Mdot
.73559 .30529 Mdot
.55514 .55861 Mdot
.54511 .52136 Mdot
.54511 .55861 Mdot
.72556 .26059 Mdot
.62531 .52136 Mdot
.72556 .31274 Mdot
.72556 .32019 Mdot
.10401 .30529 Mdot
.74561 .28294 Mdot
.73559 .11157 Mdot
.13409 .29784 Mdot
.74561 .25314 Mdot
.73559 .10412 Mdot
.58521 .55861 Mdot
.72556 .11902 Mdot
.73559 .11902 Mdot
.61529 .05942 Mdot
.11404 .29784 Mdot
.72556 .12648 Mdot
.10401 .29784 Mdot
.71554 .24569 Mdot
.59524 .54371 Mdot
.71554 .31274 Mdot
.75564 .28294 Mdot
.71554 .23824 Mdot
.74561 .11157 Mdot
.21429 .29039 Mdot
.75564 .11157 Mdot
.74561 .11902 Mdot
.69549 .08922 Mdot
.74561 .27549 Mdot
.59524 .53626 Mdot
.46491 .49156 Mdot
.47494 .49156 Mdot
.76566 .28294 Mdot
.11404 .29039 Mdot
.72556 .10412 Mdot
.69549 .11902 Mdot
.10401 .31274 Mdot
.72556 .09667 Mdot
.09398 .29784 Mdot
.77569 .28294 Mdot
.48496 .49156 Mdot
.69549 .12648 Mdot
.60526 .05942 Mdot
.76566 .29039 Mdot
.72556 .08922 Mdot
.54511 .55116 Mdot
.46491 .49901 Mdot
.71554 .26059 Mdot
.72556 .32764 Mdot
.44486 .47666 Mdot
.69549 .08177 Mdot
.75564 .29039 Mdot
.71554 .23078 Mdot
.72556 .13393 Mdot
.71554 .08922 Mdot
.71554 .22333 Mdot
.73559 .13393 Mdot
.59524 .05942 Mdot
.49499 .49156 Mdot
.49499 .49901 Mdot
.72556 .33509 Mdot
.72556 .14138 Mdot
.73559 .32764 Mdot
.49499 .50646 Mdot
.68546 .12648 Mdot
.60526 .54371 Mdot
.71554 .14138 Mdot
.13409 .29039 Mdot
.70551 .14138 Mdot
.75564 .10412 Mdot
.74561 .10412 Mdot
.74561 .32764 Mdot
.14411 .29039 Mdot
.14411 .28294 Mdot
.75564 .11902 Mdot
.50501 .49156 Mdot
.72556 .08177 Mdot
.76566 .29784 Mdot
.73559 .33509 Mdot
.46491 .50646 Mdot
.19424 .28294 Mdot
.74561 .13393 Mdot
.70551 .26059 Mdot
.09398 .31274 Mdot
.75564 .29784 Mdot
.11404 .28294 Mdot
.77569 .29784 Mdot
.19424 .27549 Mdot
.74561 .33509 Mdot
.61529 .54371 Mdot
.75564 .33509 Mdot
.48496 .50646 Mdot
.71554 .21588 Mdot
.49499 .48411 Mdot
.75564 .13393 Mdot
.15414 .28294 Mdot
.76566 .30529 Mdot
.75564 .14138 Mdot
.75564 .14883 Mdot
.75564 .09667 Mdot
.76566 .13393 Mdot
.09398 .32019 Mdot
.18421 .27549 Mdot
.70551 .08177 Mdot
.73559 .08177 Mdot
.12406 .28294 Mdot
.74561 .34255 Mdot
.09398 .32764 Mdot
.12406 .27549 Mdot
.10401 .32764 Mdot
.08396 .32019 Mdot
.75564 .15628 Mdot
.74561 .08177 Mdot
.76566 .09667 Mdot
.55514 .56607 Mdot
.74561 .07432 Mdot
.19424 .26804 Mdot
.77569 .29039 Mdot
.58521 .56607 Mdot
.50501 .48411 Mdot
.76566 .14138 Mdot
.51504 .48411 Mdot
.08396 .31274 Mdot
.72556 .14883 Mdot
.75564 .07432 Mdot
.69549 .14138 Mdot
.78571 .29784 Mdot
.59524 .56607 Mdot
.72556 .15628 Mdot
.46491 .51391 Mdot
.61529 .53626 Mdot
.76566 .31274 Mdot
.59524 .57352 Mdot
.75564 .31274 Mdot
.18421 .26804 Mdot
.60526 .57352 Mdot
.62531 .53626 Mdot
.75564 .32019 Mdot
.45489 .51391 Mdot
.17419 .26804 Mdot
.70551 .21588 Mdot
.76566 .08922 Mdot
.72556 .16373 Mdot
.72556 .17118 Mdot
.77569 .14138 Mdot
.59524 .10412 Mdot
.73559 .16373 Mdot
.20426 .27549 Mdot
.75564 .34255 Mdot
.07393 .31274 Mdot
.52506 .48411 Mdot
.77569 .27549 Mdot
.74561 .15628 Mdot
.74561 .14883 Mdot
.70551 .23078 Mdot
.52506 .49156 Mdot
.77569 .14883 Mdot
.58521 .10412 Mdot
.77569 .26804 Mdot
.68546 .14138 Mdot
.69549 .23078 Mdot
.74561 .16373 Mdot
.70551 .20843 Mdot
.79574 .29784 Mdot
.74561 .06687 Mdot
.80576 .29784 Mdot
.76566 .15628 Mdot
.77569 .26059 Mdot
.45489 .52136 Mdot
.70551 .20098 Mdot
.63534 .53626 Mdot
.44486 .51391 Mdot
.81579 .29784 Mdot
.78571 .29039 Mdot
.17419 .27549 Mdot
.61529 .55116 Mdot
.81579 .30529 Mdot
.79574 .29039 Mdot
.17419 .26059 Mdot
.75564 .35 Mdot
.76566 .26059 Mdot
.72556 .17863 Mdot
.69549 .07432 Mdot
.82581 .29784 Mdot
.76566 .07432 Mdot
.80576 .29039 Mdot
.53509 .49156 Mdot
.54511 .49156 Mdot
.67544 .14138 Mdot
.69549 .06687 Mdot
.76566 .25314 Mdot
.63534 .54371 Mdot
.72556 .22333 Mdot
.64536 .54371 Mdot
.48496 .49901 Mdot
.69549 .14883 Mdot
.70551 .06687 Mdot
.63534 .52881 Mdot
.73559 .06687 Mdot
.70551 .07432 Mdot
.71554 .17118 Mdot
.77569 .31274 Mdot
.79574 .28294 Mdot
.16416 .26059 Mdot
.45489 .52881 Mdot
.77569 .07432 Mdot
.80576 .28294 Mdot
.64536 .55116 Mdot
.71554 .16373 Mdot
.15414 .26059 Mdot
.78571 .27549 Mdot
.53509 .49901 Mdot
.15414 .25314 Mdot
.70551 .17118 Mdot
.47494 .51391 Mdot
.73559 .07432 Mdot
.69549 .21588 Mdot
.82581 .30529 Mdot
.81579 .29039 Mdot
.68546 .07432 Mdot
.16416 .27549 Mdot
.70551 .19353 Mdot
.75564 .06687 Mdot
.44486 .50646 Mdot
.83584 .30529 Mdot
.78571 .14138 Mdot
.15414 .24569 Mdot
.68546 .21588 Mdot
.50501 .3649 Mdot
.73559 .05942 Mdot
.71554 .06687 Mdot
.75564 .08922 Mdot
.71554 .17863 Mdot
.82581 .31274 Mdot
.21429 .27549 Mdot
.67544 .21588 Mdot
.82581 .32019 Mdot
.45489 .53626 Mdot
.79574 .27549 Mdot
.74561 .17118 Mdot
.79574 .30529 Mdot
.71554 .18608 Mdot
.14411 .24569 Mdot
.69549 .15628 Mdot
.53509 .50646 Mdot
.82581 .29039 Mdot
.44486 .53626 Mdot
.43484 .50646 Mdot
.43484 .53626 Mdot
.73559 .17118 Mdot
.16416 .24569 Mdot
.76566 .34255 Mdot
.79574 .26804 Mdot
.47494 .52136 Mdot
.84586 .30529 Mdot
.65539 .54371 Mdot
.75564 .17118 Mdot
.15414 .23824 Mdot
.54511 .49901 Mdot
.45489 .54371 Mdot
.63534 .55116 Mdot
.15414 .23078 Mdot
.63534 .55861 Mdot
.42481 .50646 Mdot
.46491 .54371 Mdot
.45489 .55116 Mdot
.83584 .29784 Mdot
.14411 .25314 Mdot
.16416 .23824 Mdot
.67544 .20843 Mdot
.82581 .28294 Mdot
.49499 .3649 Mdot
.73559 .17863 Mdot
.45489 .55861 Mdot
.71554 .19353 Mdot
.53509 .48411 Mdot
.65539 .53626 Mdot
.47494 .54371 Mdot
.76566 .35 Mdot
.70551 .18608 Mdot
.53509 .51391 Mdot
.69549 .20843 Mdot
.42481 .51391 Mdot
.66541 .54371 Mdot
.72556 .05942 Mdot
.67544 .20098 Mdot
.83584 .32019 Mdot
.54511 .50646 Mdot
.73559 .05197 Mdot
.70551 .16373 Mdot
.76566 .35745 Mdot
.47494 .52881 Mdot
.63534 .56607 Mdot
.61529 .57352 Mdot
.53509 .47666 Mdot
.65539 .52881 Mdot
.68546 .15628 Mdot
.68546 .22333 Mdot
.48496 .3649 Mdot
.75564 .05942 Mdot
.61529 .56607 Mdot
.68546 .16373 Mdot
.44486 .55116 Mdot
.67544 .16373 Mdot
.44486 .52136 Mdot
.46491 .55116 Mdot
.74561 .05197 Mdot
.42481 .53626 Mdot
.44486 .54371 Mdot
.43484 .49901 Mdot
.47494 .53626 Mdot
.16416 .25314 Mdot
.48496 .37235 Mdot
.77569 .35 Mdot
.74561 .04452 Mdot
.43484 .54371 Mdot
.84586 .32019 Mdot
.78571 .35 Mdot
.66541 .52881 Mdot
.21429 .26804 Mdot
.61529 .58097 Mdot
.78571 .35745 Mdot
.44486 .52881 Mdot
.17419 .23824 Mdot
.78571 .34255 Mdot
.66541 .20098 Mdot
.41479 .53626 Mdot
.43484 .52136 Mdot
.79574 .35 Mdot
.78571 .3649 Mdot
.73559 .04452 Mdot
.17419 .23078 Mdot
.67544 .52881 Mdot
.79574 .3649 Mdot
.66541 .19353 Mdot
.75564 .04452 Mdot
.18421 .23824 Mdot
.18421 .23078 Mdot
.74561 .03707 Mdot
.73559 .18608 Mdot
.13409 .25314 Mdot
.77569 .3649 Mdot
.13409 .26059 Mdot
.48496 .35745 Mdot
.42481 .54371 Mdot
.12406 .26059 Mdot
.22431 .26804 Mdot
.42481 .55116 Mdot
.70551 .17863 Mdot
.85589 .30529 Mdot
.14411 .23078 Mdot
.65539 .20098 Mdot
.13409 .23078 Mdot
.80576 .3649 Mdot
.47494 .3649 Mdot
.46491 .55861 Mdot
.80576 .37235 Mdot
.65539 .20843 Mdot
.41479 .52881 Mdot
.76566 .04452 Mdot
.13409 .26804 Mdot
.66541 .16373 Mdot
.40476 .53626 Mdot
.41479 .52136 Mdot
.48496 .3798 Mdot
.14411 .22333 Mdot
.69549 .17118 Mdot
.47494 .3798 Mdot
.65539 .19353 Mdot
.76566 .05942 Mdot
.78571 .07432 Mdot
.19424 .23824 Mdot
.68546 .20098 Mdot
.46491 .3798 Mdot
.45489 .3798 Mdot
.20426 .23824 Mdot
.67544 .17118 Mdot
.48496 .38725 Mdot
.77569 .37235 Mdot
.84586 .32764 Mdot
.14411 .21588 Mdot
.14411 .26804 Mdot
.48496 .53626 Mdot
.20426 .24569 Mdot
.48496 .52136 Mdot
.13409 .22333 Mdot
.65539 .18608 Mdot
.16416 .23078 Mdot
.13409 .21588 Mdot
.12406 .21588 Mdot
.18421 .24569 Mdot
.21429 .23824 Mdot
.68546 .19353 Mdot
.76566 .16373 Mdot
.42481 .55861 Mdot
.85589 .29784 Mdot
.85589 .31274 Mdot
.15414 .21588 Mdot
.14411 .20843 Mdot
.42481 .56607 Mdot
.77569 .3798 Mdot
.49499 .53626 Mdot
.12406 .23078 Mdot
.19424 .24569 Mdot
.16416 .22333 Mdot
.43484 .56607 Mdot
.18421 .25314 Mdot
.77569 .04452 Mdot
.42481 .57352 Mdot
.14411 .20098 Mdot
.13409 .20098 Mdot
.47494 .37235 Mdot
.64536 .18608 Mdot
.39474 .53626 Mdot
.12406 .20098 Mdot
.63534 .18608 Mdot
.47494 .38725 Mdot
.79574 .34255 Mdot
.78571 .3798 Mdot
.86591 .29784 Mdot
.12406 .19353 Mdot
.21429 .24569 Mdot
.45489 .38725 Mdot
.12406 .18608 Mdot
.14411 .19353 Mdot
.11404 .21588 Mdot
.45489 .37235 Mdot
.81579 .3649 Mdot
.10401 .21588 Mdot
.10401 .22333 Mdot
.68546 .18608 Mdot
.46491 .37235 Mdot
.67544 .18608 Mdot
.44486 .56607 Mdot
.81579 .35745 Mdot
.21429 .25314 Mdot
.09398 .22333 Mdot
.43484 .55861 Mdot
.21429 .23078 Mdot
.78571 .06687 Mdot
.22431 .25314 Mdot
.80576 .34255 Mdot
.13409 .18608 Mdot
.79574 .07432 Mdot
.78571 .04452 Mdot
.78571 .05942 Mdot
.12406 .23824 Mdot
.10401 .20843 Mdot
.79574 .05942 Mdot
.86591 .31274 Mdot
.19424 .23078 Mdot
.87594 .31274 Mdot
.49499 .52136 Mdot
.81579 .34255 Mdot
.11404 .19353 Mdot
.77569 .05942 Mdot
.78571 .33509 Mdot
.46491 .56607 Mdot
.12406 .24569 Mdot
.78571 .38725 Mdot
.47494 .56607 Mdot
.22431 .23078 Mdot
.78571 .3947 Mdot
.79574 .3947 Mdot
.77569 .33509 Mdot
.21429 .26059 Mdot
.77569 .3947 Mdot
.76566 .3947 Mdot
.13409 .17863 Mdot
.12406 .22333 Mdot
.48496 .56607 Mdot
.44486 .38725 Mdot
.40476 .52136 Mdot
.80576 .07432 Mdot
.87594 .30529 Mdot
.10401 .19353 Mdot
.86591 .29039 Mdot
.14411 .17863 Mdot
.11404 .23078 Mdot
.49499 .56607 Mdot
.86591 .32019 Mdot
.15414 .17863 Mdot
.11404 .23824 Mdot
.09398 .21588 Mdot
.39474 .52136 Mdot
.78571 .32764 Mdot
.49499 .57352 Mdot
.50501 .57352 Mdot
.09398 .23078 Mdot
.77569 .32764 Mdot
.81579 .33509 Mdot
.88596 .31274 Mdot
.38471 .53626 Mdot
.77569 .40215 Mdot
.79574 .32764 Mdot
.15414 .20843 Mdot
.48496 .57352 Mdot
.80576 .05942 Mdot
.77569 .4096 Mdot
.15414 .18608 Mdot
.79574 .38725 Mdot
.51504 .57352 Mdot
.38471 .52881 Mdot
.80576 .08177 Mdot
.37469 .52881 Mdot
.81579 .07432 Mdot
.15414 .19353 Mdot
.49499 .58097 Mdot
.16416 .20843 Mdot
.81579 .08177 Mdot
.78571 .4096 Mdot
.38471 .52136 Mdot
.36466 .52881 Mdot
.17419 .20843 Mdot
.16416 .19353 Mdot
.17419 .19353 Mdot
.16416 .17863 Mdot
.79574 .32019 Mdot
.40476 .51391 Mdot
.77569 .41705 Mdot
.36466 .53626 Mdot
.80576 .32764 Mdot
.80576 .38725 Mdot
.82581 .08177 Mdot
.17419 .21588 Mdot
.81579 .38725 Mdot
.36466 .52136 Mdot
.82581 .38725 Mdot
.81579 .06687 Mdot
.51504 .56607 Mdot
.16416 .20098 Mdot
.87594 .32019 Mdot
.48496 .58097 Mdot
.50501 .56607 Mdot
.09398 .23824 Mdot
.16416 .17118 Mdot
.17419 .17118 Mdot
.09398 .24569 Mdot
.17419 .17863 Mdot
.38471 .51391 Mdot
.09398 .19353 Mdot
.17419 .18608 Mdot
.18421 .19353 Mdot
.18421 .17863 Mdot
.18421 .21588 Mdot
.82581 .06687 Mdot
.83584 .06687 Mdot
.86591 .32764 Mdot
.17419 .20098 Mdot
.09398 .18608 Mdot
.09398 .25314 Mdot
.52506 .56607 Mdot
.38471 .50646 Mdot
.10401 .25314 Mdot
.08396 .19353 Mdot
.41479 .57352 Mdot
.18421 .18608 Mdot
.83584 .07432 Mdot
.37469 .50646 Mdot
.08396 .18608 Mdot
.48496 .55861 Mdot
.08396 .20098 Mdot
.18421 .20843 Mdot
.19424 .21588 Mdot
.39474 .50646 Mdot
.84586 .06687 Mdot
.51504 .55861 Mdot
.35464 .53626 Mdot
.36466 .50646 Mdot
.18421 .17118 Mdot
.86591 .33509 Mdot
.19424 .17118 Mdot
.48496 .58842 Mdot
.85589 .06687 Mdot
.09398 .26059 Mdot
.08396 .26059 Mdot
.08396 .26804 Mdot
.19424 .17863 Mdot
.48496 .55116 Mdot
.11404 .25314 Mdot
.13409 .17118 Mdot
.20426 .21588 Mdot
.35464 .52136 Mdot
.85589 .07432 Mdot
.86591 .06687 Mdot
.87594 .06687 Mdot
.49499 .55116 Mdot
.48496 .59587 Mdot
.85589 .05942 Mdot
.37469 .53626 Mdot
.47494 .58097 Mdot
.84586 .07432 Mdot
.21429 .21588 Mdot
.07393 .26804 Mdot
.07393 .20098 Mdot
.86591 .05942 Mdot
.20426 .22333 Mdot
.08396 .17863 Mdot
.17419 .16373 Mdot
.87594 .29039 Mdot
.50501 .55116 Mdot
.10401 .26059 Mdot
.89599 .31274 Mdot
.19424 .19353 Mdot
.35464 .51391 Mdot
.49499 .59587 Mdot
.08396 .23824 Mdot
.80576 .32019 Mdot
.89599 .32019 Mdot
.89599 .32764 Mdot
.85589 .05197 Mdot
.90602 .32019 Mdot
.21429 .20843 Mdot
.87594 .33509 Mdot
.91604 .32019 Mdot
.21429 .20098 Mdot
.92607 .32019 Mdot
.89599 .33509 Mdot
.87594 .05942 Mdot
.88596 .33509 Mdot
.20426 .19353 Mdot
.91604 .32764 Mdot
.88596 .05942 Mdot
.86591 .05197 Mdot
.17419 .15628 Mdot
.34461 .51391 Mdot
.49499 .58842 Mdot
.19424 .16373 Mdot
.41479 .58097 Mdot
.07393 .27549 Mdot
.87594 .34255 Mdot
.90602 .31274 Mdot
.21429 .19353 Mdot
.07393 .20843 Mdot
.85589 .04452 Mdot
.08396 .17118 Mdot
.87594 .05197 Mdot
.08396 .16373 Mdot
.18421 .15628 Mdot
.09398 .16373 Mdot
.07393 .17118 Mdot
.22431 .19353 Mdot
.22431 .18608 Mdot
.80576 .31274 Mdot
.86591 .04452 Mdot
.07393 .16373 Mdot
.50501 .58842 Mdot
.06391 .27549 Mdot
.20426 .18608 Mdot
.92607 .31274 Mdot
.07393 .26059 Mdot
.40476 .58097 Mdot
.92607 .32764 Mdot
.85589 .08177 Mdot
.06391 .20843 Mdot
.23434 .18608 Mdot
.20426 .16373 Mdot
.23434 .17863 Mdot
.19424 .15628 Mdot
.24436 .18608 Mdot
.82581 .08922 Mdot
.05388 .20843 Mdot
.06391 .16373 Mdot
.86591 .03707 Mdot
.93609 .31274 Mdot
.84586 .04452 Mdot
.88596 .05197 Mdot
.89599 .34255 Mdot
.82581 .09667 Mdot
.05388 .21588 Mdot
.06391 .26059 Mdot
.23434 .17118 Mdot
.83584 .04452 Mdot
.06391 .26804 Mdot
.89599 .30529 Mdot
.36466 .49901 Mdot
.04386 .20843 Mdot
.21429 .16373 Mdot
.23434 .16373 Mdot
.93609 .30529 Mdot
.93609 .29784 Mdot
.24436 .17118 Mdot
.22431 .16373 Mdot
.89599 .35 Mdot
.89599 .05197 Mdot
.20426 .15628 Mdot
.19424 .20843 Mdot
.24436 .16373 Mdot
.35464 .49901 Mdot
.78571 .41705 Mdot
.93609 .29039 Mdot
.87594 .35 Mdot
.06391 .17118 Mdot
.33459 .51391 Mdot
.33459 .50646 Mdot
.25439 .18608 Mdot
.24436 .17863 Mdot
.06391 .25314 Mdot
.94612 .30529 Mdot
.05388 .22333 Mdot
.87594 .03707 Mdot
.93609 .28294 Mdot
.94612 .28294 Mdot
.07393 .23824 Mdot
.10401 .26804 Mdot
.04386 .20098 Mdot
.16416 .15628 Mdot
.11404 .26804 Mdot
.24436 .15628 Mdot
.23434 .19353 Mdot
.86591 .35 Mdot
.06391 .24569 Mdot
.95614 .30529 Mdot
.86591 .35745 Mdot
.26441 .18608 Mdot
.05388 .16373 Mdot
.96617 .30529 Mdot
.22431 .20098 Mdot
.07393 .21588 Mdot
.35464 .49156 Mdot
.85589 .08922 Mdot
.21429 .18608 Mdot
.21429 .17863 Mdot
.86591 .02962 Mdot
.03383 .20843 Mdot
.92607 .29039 Mdot
.22431 .15628 Mdot
.27444 .18608 Mdot
.05388 .25314 Mdot
.95614 .28294 Mdot
.95614 .27549 Mdot
.35464 .48411 Mdot
.94612 .29039 Mdot
.88596 .04452 Mdot
.90602 .05197 Mdot
.05388 .17118 Mdot
.95614 .26804 Mdot
.91604 .33509 Mdot
.07393 .22333 Mdot
.91604 .29039 Mdot
.86591 .3649 Mdot
.96617 .31274 Mdot
.27444 .17863 Mdot
.07393 .23078 Mdot
.90602 .04452 Mdot
.06391 .23078 Mdot
.93609 .27549 Mdot
.22431 .17863 Mdot
.84586 .03707 Mdot
.05388 .17863 Mdot
.04386 .25314 Mdot
.05388 .26804 Mdot
.94612 .26804 Mdot
.03383 .25314 Mdot
.96617 .32019 Mdot
.84586 .08922 Mdot
.04386 .22333 Mdot
.27444 .19353 Mdot
.28446 .17863 Mdot
.35464 .50646 Mdot
.33459 .52136 Mdot
.21429 .17118 Mdot
.83584 .03707 Mdot
.33459 .52881 Mdot
.34461 .52881 Mdot
.06391 .20098 Mdot
.32456 .51391 Mdot
.87594 .3649 Mdot
.87594 .37235 Mdot
.95614 .32019 Mdot
.91604 .04452 Mdot
.25439 .19353 Mdot
.03383 .21588 Mdot
.32456 .52136 Mdot
.96617 .28294 Mdot
.25439 .15628 Mdot
.22431 .17118 Mdot
.18421 .14883 Mdot
.35464 .47666 Mdot
.35464 .46921 Mdot
.05388 .18608 Mdot
.87594 .02962 Mdot
.04386 .18608 Mdot
.03383 .24569 Mdot
.92607 .29784 Mdot
.83584 .02962 Mdot
.05388 .19353 Mdot
.04386 .17863 Mdot
.36466 .46921 Mdot
.83584 .02217 Mdot
.94612 .26059 Mdot
.37469 .46921 Mdot
.26441 .15628 Mdot
.26441 .16373 Mdot
.06391 .19353 Mdot
.03383 .20098 Mdot
.94612 .25314 Mdot
.07393 .24569 Mdot
.06391 .18608 Mdot
.26441 .14883 Mdot
1 0 0 r
.015 w
.03383 .17863 Mdot
.03383 .18608 Mdot
.03383 .19353 Mdot
.03383 .22333 Mdot
.03383 .23824 Mdot
.04386 .21588 Mdot
.04386 .23078 Mdot
.04386 .24569 Mdot
.06391 .15628 Mdot
.06391 .22333 Mdot
.09398 .17118 Mdot
.18421 .14138 Mdot
.23434 .15628 Mdot
.24436 .14883 Mdot
.25439 .14883 Mdot
.25439 .20098 Mdot
.26441 .14138 Mdot
.26441 .17118 Mdot
.27444 .14883 Mdot
.27444 .16373 Mdot
.27444 .20098 Mdot
.28446 .18608 Mdot
.29449 .17863 Mdot
.31454 .51391 Mdot
.31454 .52136 Mdot
.33459 .49901 Mdot
.34461 .46921 Mdot
.34461 .47666 Mdot
.34461 .48411 Mdot
.34461 .50646 Mdot
.36466 .46176 Mdot
.36466 .47666 Mdot
.36466 .48411 Mdot
.37469 .47666 Mdot
.82581 .02962 Mdot
.82581 .03707 Mdot
.82581 .10412 Mdot
.83584 .09667 Mdot
.84586 .02217 Mdot
.85589 .35 Mdot
.86591 .08922 Mdot
.86591 .37235 Mdot
.87594 .02217 Mdot
.87594 .3798 Mdot
.88596 .37235 Mdot
.90602 .05942 Mdot
.90602 .29039 Mdot
.91604 .03707 Mdot
.91604 .05197 Mdot
.91604 .29784 Mdot
.92607 .04452 Mdot
.93609 .25314 Mdot
.93609 .26804 Mdot
.94612 .24569 Mdot
.95614 .25314 Mdot
.95614 .26059 Mdot
.95614 .32764 Mdot
.96617 .29039 Mdot
.97619 .28294 Mdot
.97619 .30529 Mdot
.97619 .31274 Mdot
0 1 0 r
.01 w
.44486 .23824 Mdot
.45489 .23078 Mdot
.46491 .25314 Mdot
.42481 .26804 Mdot
.45489 .23824 Mdot
.46491 .24569 Mdot
.42481 .20843 Mdot
.41479 .21588 Mdot
.44486 .21588 Mdot
.41479 .22333 Mdot
.42481 .23824 Mdot
.46491 .22333 Mdot
.45489 .27549 Mdot
.45489 .20843 Mdot
.39474 .25314 Mdot
.43484 .20843 Mdot
.41479 .23824 Mdot
.39474 .23078 Mdot
.46491 .21588 Mdot
.38471 .23824 Mdot
.39474 .26059 Mdot
.40476 .26804 Mdot
.42481 .22333 Mdot
.47494 .27549 Mdot
.44486 .28294 Mdot
.38471 .23078 Mdot
.41479 .26804 Mdot
.41479 .28294 Mdot
.47494 .24569 Mdot
.37469 .23078 Mdot
.48496 .26804 Mdot
.41479 .20098 Mdot
.39474 .27549 Mdot
.39474 .20098 Mdot
.36466 .21588 Mdot
.48496 .25314 Mdot
.42481 .29039 Mdot
.38471 .25314 Mdot
.46491 .29039 Mdot
.45489 .28294 Mdot
.36466 .23078 Mdot
.36466 .24569 Mdot
.37469 .23824 Mdot
.43484 .30529 Mdot
.44486 .30529 Mdot
.45489 .30529 Mdot
.37469 .25314 Mdot
.34461 .22333 Mdot
.46491 .29784 Mdot
.39474 .18608 Mdot
.38471 .17863 Mdot
.37469 .18608 Mdot
.34461 .23078 Mdot
.39474 .29039 Mdot
.42481 .18608 Mdot
.40476 .17863 Mdot
.35464 .20843 Mdot
.34461 .21588 Mdot
.36466 .19353 Mdot
.41479 .19353 Mdot
.39474 .28294 Mdot
.50501 .29039 Mdot
.49499 .27549 Mdot
.37469 .19353 Mdot
.47494 .29039 Mdot
.49499 .30529 Mdot
.43484 .31274 Mdot
.41479 .29039 Mdot
.50501 .27549 Mdot
.41479 .31274 Mdot
.43484 .32019 Mdot
.41479 .17863 Mdot
.36466 .20843 Mdot
.52506 .27549 Mdot
.51504 .26804 Mdot
.47494 .31274 Mdot
.49499 .26059 Mdot
.41479 .33509 Mdot
.39474 .32019 Mdot
.34461 .19353 Mdot
.32456 .20098 Mdot
.34461 .18608 Mdot
.51504 .31274 Mdot
.54511 .26804 Mdot
.39474 .34255 Mdot
.42481 .34255 Mdot
.44486 .33509 Mdot
.35464 .17118 Mdot
.38471 .32764 Mdot
.52506 .29784 Mdot
.38471 .33509 Mdot
.41479 .35745 Mdot
.38471 .30529 Mdot
.59524 .28294 Mdot
.58521 .29039 Mdot
.58521 .27549 Mdot
.36466 .3649 Mdot
.33459 .22333 Mdot
.34461 .24569 Mdot
.52506 .32019 Mdot
.53509 .31274 Mdot
.42481 .35745 Mdot
.31454 .20843 Mdot
.57519 .29784 Mdot
.34461 .17863 Mdot
.50501 .30529 Mdot
.56516 .26804 Mdot
.35464 .25314 Mdot
.41479 .3798 Mdot
.55514 .30529 Mdot
.56516 .29784 Mdot
.36466 .16373 Mdot
.37469 .37235 Mdot
.39474 .31274 Mdot
.44486 .31274 Mdot
.54511 .31274 Mdot
.55514 .29039 Mdot
.36466 .31274 Mdot
.37469 .28294 Mdot
.38471 .28294 Mdot
.36466 .18608 Mdot
.32456 .17118 Mdot
.39474 .38725 Mdot
.35464 .34255 Mdot
.42481 .37235 Mdot
.39474 .3649 Mdot
.54511 .24569 Mdot
.36466 .33509 Mdot
.50501 .32019 Mdot
.31454 .21588 Mdot
.32456 .16373 Mdot
.54511 .23078 Mdot
.31454 .19353 Mdot
.52506 .25314 Mdot
.34461 .31274 Mdot
.33459 .15628 Mdot
.34461 .14883 Mdot
.49499 .31274 Mdot
.57519 .23824 Mdot
.37469 .17118 Mdot
.45489 .35 Mdot
.36466 .3798 Mdot
.58521 .24569 Mdot
.39474 .37235 Mdot
.59524 .26059 Mdot
.56516 .29039 Mdot
.44486 .35 Mdot
.33459 .30529 Mdot
.54511 .25314 Mdot
.40476 .3947 Mdot
.54511 .26059 Mdot
.48496 .32764 Mdot
.35464 .29039 Mdot
.37469 .38725 Mdot
.35464 .16373 Mdot
.57519 .24569 Mdot
.55514 .23078 Mdot
.31454 .17863 Mdot
.38471 .37235 Mdot
.30451 .23078 Mdot
.36466 .35745 Mdot
.39474 .3947 Mdot
.44486 .37235 Mdot
.47494 .32764 Mdot
.56516 .26059 Mdot
.45489 .3649 Mdot
.49499 .23078 Mdot
.33459 .35745 Mdot
.50501 .32764 Mdot
.33459 .35 Mdot
.33459 .37235 Mdot
.50501 .21588 Mdot
.56516 .23078 Mdot
.41479 .38725 Mdot
.50501 .23824 Mdot
.29449 .22333 Mdot
.29449 .21588 Mdot
.35464 .26804 Mdot
.37469 .32019 Mdot
.49499 .25314 Mdot
.38471 .27549 Mdot
.48496 .33509 Mdot
.47494 .33509 Mdot
.59524 .24569 Mdot
.32456 .34255 Mdot
.37469 .40215 Mdot
.51504 .22333 Mdot
.37469 .32764 Mdot
.33459 .29039 Mdot
.36466 .3947 Mdot
.43484 .3798 Mdot
.35464 .28294 Mdot
.48496 .35 Mdot
.33459 .32019 Mdot
.33459 .27549 Mdot
.29449 .20843 Mdot
.30451 .20098 Mdot
.47494 .35745 Mdot
.30451 .17863 Mdot
.46491 .35745 Mdot
.49499 .35 Mdot
.52506 .20098 Mdot
.33459 .25314 Mdot
.49499 .23824 Mdot
.33459 .32764 Mdot
.36466 .32019 Mdot
.28446 .19353 Mdot
.50501 .35745 Mdot
.29449 .18608 Mdot
.49499 .20098 Mdot
.35464 .26059 Mdot
.31454 .25314 Mdot
.39474 .4096 Mdot
.51504 .34255 Mdot
.49499 .26804 Mdot
.35464 .15628 Mdot
.34461 .37235 Mdot
.48496 .24569 Mdot
.51504 .24569 Mdot
.52506 .24569 Mdot
.33459 .26059 Mdot
.35464 .37235 Mdot
.50501 .19353 Mdot
.56516 .21588 Mdot
.62531 .28294 Mdot
.33459 .24569 Mdot
.55514 .20098 Mdot
.32456 .31274 Mdot
.48496 .22333 Mdot
.32456 .35 Mdot
.53509 .20098 Mdot
.62531 .26804 Mdot
.38471 .4245 Mdot
.28446 .23824 Mdot
.30451 .3649 Mdot
.31454 .31274 Mdot
.31454 .26059 Mdot
.60526 .25314 Mdot
.61529 .30529 Mdot
.56516 .20843 Mdot
.62531 .31274 Mdot
.30451 .27549 Mdot
.30451 .34255 Mdot
.30451 .26059 Mdot
.52506 .35 Mdot
.33459 .3798 Mdot
.29449 .25314 Mdot
.57519 .22333 Mdot
.28446 .23078 Mdot
.40476 .4245 Mdot
.51504 .35745 Mdot
.63534 .26059 Mdot
.58521 .29784 Mdot
.28446 .37235 Mdot
.60526 .30529 Mdot
.64536 .29039 Mdot
.51504 .32019 Mdot
.27444 .3649 Mdot
.27444 .35745 Mdot
.57519 .30529 Mdot
.53509 .34255 Mdot
.64536 .27549 Mdot
.62531 .24569 Mdot
.64536 .30529 Mdot
.32456 .3947 Mdot
.42481 .4096 Mdot
.29449 .26804 Mdot
.30451 .31274 Mdot
.29449 .20098 Mdot
.57519 .31274 Mdot
.28446 .24569 Mdot
.29449 .3649 Mdot
.27444 .30529 Mdot
.53509 .19353 Mdot
.65539 .26804 Mdot
.41479 .40215 Mdot
.29449 .32019 Mdot
.27444 .35 Mdot
.60526 .32019 Mdot
.52506 .17863 Mdot
.49499 .21588 Mdot
.28446 .33509 Mdot
.30451 .33509 Mdot
.48496 .21588 Mdot
.28446 .34255 Mdot
.30451 .29039 Mdot
.35464 .4096 Mdot
.61529 .24569 Mdot
.45489 .43195 Mdot
.36466 .41705 Mdot
.64536 .31274 Mdot
.53509 .32764 Mdot
.40476 .4394 Mdot
.31454 .37235 Mdot
.65539 .23824 Mdot
.42481 .43195 Mdot
.67544 .24569 Mdot
.54511 .33509 Mdot
.27444 .32019 Mdot
.29449 .38725 Mdot
.33459 .38725 Mdot
.46491 .41705 Mdot
.43484 .4394 Mdot
.28446 .3947 Mdot
.65539 .23078 Mdot
.46491 .4394 Mdot
.31454 .40215 Mdot
.29449 .27549 Mdot
.52506 .32764 Mdot
.65539 .28294 Mdot
.40476 .44685 Mdot
.43484 .40215 Mdot
.28446 .40215 Mdot
.58521 .32764 Mdot
.65539 .25314 Mdot
.66541 .26059 Mdot
.47494 .43195 Mdot
.60526 .34255 Mdot
.64536 .23824 Mdot
.26441 .30529 Mdot
.38471 .43195 Mdot
.54511 .17863 Mdot
.26441 .32764 Mdot
.47494 .4096 Mdot
.37469 .44685 Mdot
.65539 .21588 Mdot
.62531 .32764 Mdot
.46491 .20843 Mdot
.27444 .27549 Mdot
.56516 .31274 Mdot
.38471 .44685 Mdot
.66541 .21588 Mdot
.65539 .29784 Mdot
.67544 .22333 Mdot
.63534 .33509 Mdot
.26441 .34255 Mdot
.68546 .23078 Mdot
.25439 .34255 Mdot
.30451 .41705 Mdot
.53509 .16373 Mdot
.48496 .41705 Mdot
.67544 .25314 Mdot
.55514 .19353 Mdot
.64536 .32019 Mdot
.41479 .4394 Mdot
.46491 .19353 Mdot
.52506 .16373 Mdot
.54511 .32019 Mdot
.24436 .32019 Mdot
.27444 .29039 Mdot
.69549 .23824 Mdot
.68546 .24569 Mdot
.49499 .15628 Mdot
.47494 .21588 Mdot
.54511 .17118 Mdot
.27444 .3798 Mdot
.63534 .24569 Mdot
.25439 .29784 Mdot
.44486 .40215 Mdot
.58521 .19353 Mdot
.48496 .17118 Mdot
.45489 .20098 Mdot
.58521 .33509 Mdot
.36466 .40215 Mdot
.36466 .4245 Mdot
.39474 .46176 Mdot
.48496 .44685 Mdot
.36466 .43195 Mdot
.23434 .31274 Mdot
.51504 .17118 Mdot
.23434 .30529 Mdot
.47494 .4394 Mdot
.24436 .33509 Mdot
.27444 .29784 Mdot
.48496 .18608 Mdot
.44486 .43195 Mdot
.56516 .20098 Mdot
.36466 .45431 Mdot
.62531 .34255 Mdot
.28446 .38725 Mdot
.55514 .31274 Mdot
.60526 .18608 Mdot
.51504 .4394 Mdot
.29449 .43195 Mdot
.28446 .4245 Mdot
.45489 .4096 Mdot
.35464 .4394 Mdot
.50501 .44685 Mdot
.55514 .33509 Mdot
.54511 .4245 Mdot
.24436 .29784 Mdot
.54511 .4394 Mdot
.65539 .34255 Mdot
.48496 .14883 Mdot
.56516 .17118 Mdot
.60526 .19353 Mdot
.28446 .41705 Mdot
.55514 .43195 Mdot
.30451 .4245 Mdot
.65539 .30529 Mdot
.26441 .28294 Mdot
.55514 .16373 Mdot
.61529 .35 Mdot
.33459 .40215 Mdot
.50501 .15628 Mdot
.50501 .41705 Mdot
.66541 .32019 Mdot
.49499 .4096 Mdot
.51504 .16373 Mdot
.52506 .41705 Mdot
.66541 .31274 Mdot
.56516 .17863 Mdot
.26441 .4096 Mdot
.27444 .41705 Mdot
.59524 .17118 Mdot
.47494 .15628 Mdot
.48496 .17863 Mdot
.59524 .20098 Mdot
.37469 .46176 Mdot
.41479 .45431 Mdot
.59524 .35745 Mdot
.57519 .17118 Mdot
.34461 .44685 Mdot
.47494 .19353 Mdot
.65539 .35 Mdot
.66541 .32764 Mdot
.54511 .45431 Mdot
.49499 .45431 Mdot
.27444 .3947 Mdot
.54511 .44685 Mdot
.22431 .32019 Mdot
.23434 .33509 Mdot
.53509 .46921 Mdot
.51504 .44685 Mdot
.62531 .35 Mdot
.63534 .3649 Mdot
.40476 .47666 Mdot
.32456 .41705 Mdot
.31454 .41705 Mdot
.20426 .32764 Mdot
.25439 .26059 Mdot
.57519 .3649 Mdot
.25439 .4096 Mdot
.21429 .32019 Mdot
.60526 .17118 Mdot
.52506 .45431 Mdot
.38471 .46921 Mdot
.25439 .25314 Mdot
.42481 .46921 Mdot
.26441 .38725 Mdot
.64536 .35745 Mdot
.53509 .4245 Mdot
.35464 .45431 Mdot
.59524 .37235 Mdot
.60526 .35745 Mdot
.59524 .15628 Mdot
.57519 .14883 Mdot
.32456 .4245 Mdot
.66541 .35 Mdot
.28446 .25314 Mdot
.33459 .4394 Mdot
.21429 .35 Mdot
.22431 .35 Mdot
.27444 .26804 Mdot
.46491 .16373 Mdot
.56516 .15628 Mdot
.32456 .44685 Mdot
.30451 .4394 Mdot
.42481 .48411 Mdot
.63534 .22333 Mdot
.38471 .47666 Mdot
.58521 .3798 Mdot
.59524 .14883 Mdot
.61529 .3649 Mdot
.56516 .16373 Mdot
.64536 .23078 Mdot
.35464 .3947 Mdot
.30451 .44685 Mdot
.26441 .27549 Mdot
.61529 .3798 Mdot
.67544 .35 Mdot
.62531 .3649 Mdot
.24436 .34255 Mdot
.35464 .43195 Mdot
.56516 .45431 Mdot
.56516 .35745 Mdot
.26441 .24569 Mdot
.62531 .18608 Mdot
.31454 .45431 Mdot
.34461 .4394 Mdot
.61529 .17118 Mdot
.41479 .50646 Mdot
.34461 .4245 Mdot
.34461 .3947 Mdot
.67544 .32019 Mdot
.59524 .38725 Mdot
.57519 .14138 Mdot
.63534 .21588 Mdot
.39474 .49901 Mdot
.55514 .45431 Mdot
.25439 .37235 Mdot
.27444 .25314 Mdot
.54511 .47666 Mdot
.37469 .48411 Mdot
.24436 .3798 Mdot
.55514 .46921 Mdot
.18421 .34255 Mdot
.70551 .34255 Mdot
.24436 .35 Mdot
.24436 .35745 Mdot
.68546 .32019 Mdot
.69549 .35 Mdot
.26441 .3649 Mdot
.60526 .16373 Mdot
.57519 .19353 Mdot
.62531 .17118 Mdot
.69549 .33509 Mdot
.42481 .46176 Mdot
.64536 .20843 Mdot
.54511 .3649 Mdot
.21429 .35745 Mdot
.55514 .3649 Mdot
.60526 .14138 Mdot
.59524 .4245 Mdot
.20426 .3649 Mdot
.23434 .38725 Mdot
.61529 .40215 Mdot
.57519 .3798 Mdot
.24436 .38725 Mdot
.21429 .37235 Mdot
.62531 .4096 Mdot
.63534 .3798 Mdot
.22431 .37235 Mdot
.42481 .49901 Mdot
.58521 .40215 Mdot
.24436 .26804 Mdot
.61529 .14138 Mdot
.63534 .17863 Mdot
.60526 .11157 Mdot
.61529 .41705 Mdot
.52506 .4096 Mdot
.59524 .45431 Mdot
.43484 .47666 Mdot
.38471 .49901 Mdot
.57519 .47666 Mdot
.63534 .37235 Mdot
.61529 .11902 Mdot
.68546 .35745 Mdot
.51504 .40215 Mdot
.18421 .35745 Mdot
.43484 .49156 Mdot
.53509 .35745 Mdot
.26441 .4245 Mdot
.24436 .43195 Mdot
.55514 .48411 Mdot
.61529 .37235 Mdot
.64536 .38725 Mdot
.25439 .35745 Mdot
.56516 .3649 Mdot
.22431 .40215 Mdot
.24436 .4245 Mdot
.64536 .4096 Mdot
.22431 .4096 Mdot
.25439 .28294 Mdot
.58521 .11902 Mdot
.62531 .14883 Mdot
.21429 .4096 Mdot
.63534 .14138 Mdot
.52506 .46921 Mdot
.58521 .48411 Mdot
.24436 .27549 Mdot
.71554 .32019 Mdot
.55514 .3798 Mdot
.27444 .37235 Mdot
.16416 .34255 Mdot
.70551 .31274 Mdot
.25439 .4394 Mdot
.26441 .43195 Mdot
.17419 .3649 Mdot
.50501 .40215 Mdot
.50501 .45431 Mdot
.70551 .33509 Mdot
.23434 .37235 Mdot
.59524 .3947 Mdot
.65539 .38725 Mdot
.63534 .12648 Mdot
.37469 .49156 Mdot
.22431 .43195 Mdot
.58521 .4245 Mdot
.45489 .17118 Mdot
.20426 .4245 Mdot
.67544 .31274 Mdot
.56516 .41705 Mdot
.56516 .38725 Mdot
.66541 .4096 Mdot
.68546 .29784 Mdot
.53509 .35 Mdot
.57519 .11902 Mdot
.18421 .33509 Mdot
.60526 .46176 Mdot
.59524 .11157 Mdot
.51504 .47666 Mdot
.60526 .46921 Mdot
.26441 .41705 Mdot
.57519 .4245 Mdot
.59524 .44685 Mdot
.50501 .46921 Mdot
.57519 .44685 Mdot
.57519 .49156 Mdot
.15414 .35 Mdot
.71554 .32764 Mdot
.58521 .4394 Mdot
.60526 .43195 Mdot
.40476 .50646 Mdot
.19424 .41705 Mdot
.47494 .17863 Mdot
.45489 .17863 Mdot
.71554 .30529 Mdot
.56516 .49156 Mdot
.17419 .32764 Mdot
.56516 .12648 Mdot
.66541 .41705 Mdot
.57519 .4096 Mdot
.61529 .20098 Mdot
.68546 .3947 Mdot
.64536 .43195 Mdot
.64536 .12648 Mdot
.52506 .37235 Mdot
.61529 .08922 Mdot
.61529 .08177 Mdot
.63534 .11902 Mdot
.67544 .29039 Mdot
.63534 .08177 Mdot
.53509 .3649 Mdot
.65539 .13393 Mdot
.66541 .30529 Mdot
.18421 .32764 Mdot
.65539 .4096 Mdot
.16416 .3649 Mdot
.17419 .37235 Mdot
.62531 .4245 Mdot
.49499 .46921 Mdot
.60526 .10412 Mdot
.66541 .27549 Mdot
.70551 .29039 Mdot
.62531 .41705 Mdot
.57519 .13393 Mdot
.62531 .49156 Mdot
.18421 .40215 Mdot
.15414 .32764 Mdot
.67544 .40215 Mdot
.15414 .35745 Mdot
.70551 .28294 Mdot
.70551 .29784 Mdot
.14411 .32764 Mdot
.61529 .43195 Mdot
.65539 .10412 Mdot
.68546 .43195 Mdot
.15414 .32019 Mdot
.57519 .49901 Mdot
.64536 .10412 Mdot
.63534 .10412 Mdot
.21429 .4245 Mdot
.18421 .3798 Mdot
.65539 .11902 Mdot
.68546 .38725 Mdot
.63534 .19353 Mdot
.21429 .3947 Mdot
.65539 .08177 Mdot
.66541 .44685 Mdot
.47494 .18608 Mdot
.19424 .4096 Mdot
.63534 .44685 Mdot
.23434 .43195 Mdot
.68546 .45431 Mdot
.63534 .07432 Mdot
.61529 .48411 Mdot
.67544 .3798 Mdot
.64536 .44685 Mdot
.45489 .19353 Mdot
.14411 .35 Mdot
.17419 .38725 Mdot
.57519 .50646 Mdot
.15414 .31274 Mdot
.65539 .14138 Mdot
.60526 .48411 Mdot
.12406 .33509 Mdot
.59524 .51391 Mdot
.48496 .46921 Mdot
.60526 .07432 Mdot
.17419 .31274 Mdot
.21429 .31274 Mdot
.54511 .38725 Mdot
.67544 .28294 Mdot
.57519 .52136 Mdot
.64536 .14883 Mdot
.17419 .3947 Mdot
.45489 .46176 Mdot
.66541 .37235 Mdot
.13409 .35 Mdot
.11404 .32764 Mdot
.67544 .46176 Mdot
.64536 .08922 Mdot
.12406 .34255 Mdot
.68546 .40215 Mdot
.66541 .10412 Mdot
.69549 .41705 Mdot
.52506 .3798 Mdot
.62531 .06687 Mdot
.48496 .45431 Mdot
.65539 .37235 Mdot
.67544 .08177 Mdot
.58521 .53626 Mdot
.70551 .4096 Mdot
.65539 .45431 Mdot
.69549 .40215 Mdot
.59524 .52881 Mdot
.57519 .51391 Mdot
.18421 .31274 Mdot
.62531 .43195 Mdot
.19424 .30529 Mdot
.66541 .07432 Mdot
.67544 .27549 Mdot
.62531 .20843 Mdot
.61529 .46176 Mdot
.55514 .53626 Mdot
.65539 .46921 Mdot
.60526 .45431 Mdot
.62531 .50646 Mdot
.62531 .46176 Mdot
.63534 .49901 Mdot
.46491 .44685 Mdot
.54511 .52881 Mdot
.44486 .20098 Mdot
.21429 .30529 Mdot
.43484 .19353 Mdot
.61529 .50646 Mdot
.60526 .52136 Mdot
.60526 .08922 Mdot
.10401 .32019 Mdot
.68546 .08922 Mdot
.45489 .45431 Mdot
.21429 .29784 Mdot
.56516 .53626 Mdot
.70551 .26804 Mdot
.43484 .17863 Mdot
.19424 .29784 Mdot
.64536 .46176 Mdot
.69549 .26059 Mdot
.11404 .31274 Mdot
.17419 .29784 Mdot
.66541 .11157 Mdot
.72556 .27549 Mdot
.70551 .09667 Mdot
.69549 .43195 Mdot
.70551 .4394 Mdot
.53509 .3947 Mdot
.63534 .20098 Mdot
.68546 .11902 Mdot
.66541 .46921 Mdot
.47494 .47666 Mdot
.13409 .32019 Mdot
.20426 .28294 Mdot
.15414 .29039 Mdot
.17419 .28294 Mdot
.16416 .28294 Mdot
.56516 .50646 Mdot
.14411 .31274 Mdot
.62531 .47666 Mdot
.15414 .29784 Mdot
.50501 .38725 Mdot
.66541 .35745 Mdot
.44486 .46921 Mdot
.69549 .44685 Mdot
.58521 .43195 Mdot
.70551 .11157 Mdot
.47494 .48411 Mdot
.54511 .51391 Mdot
.69549 .4245 Mdot
.44486 .17118 Mdot
.71554 .26804 Mdot
.49499 .3798 Mdot
.62531 .46921 Mdot
.73559 .29039 Mdot
.58521 .09667 Mdot
.74561 .26804 Mdot
.60526 .06687 Mdot
.44486 .48411 Mdot
.50501 .3947 Mdot
.59524 .08922 Mdot
.71554 .29784 Mdot
.44486 .49901 Mdot
.74561 .24569 Mdot
.56516 .55116 Mdot
.54511 .54371 Mdot
.56516 .55861 Mdot
.51504 .3649 Mdot
.68546 .26804 Mdot
.45489 .49901 Mdot
.72556 .24569 Mdot
.18421 .28294 Mdot
.57519 .56607 Mdot
.12406 .29784 Mdot
.71554 .09667 Mdot
.74561 .29784 Mdot
.49499 .37235 Mdot
.63534 .52136 Mdot
.55514 .50646 Mdot
.14411 .29784 Mdot
.62531 .51391 Mdot
.09398 .30529 Mdot
.73559 .09667 Mdot
.62531 .05942 Mdot
.53509 .52136 Mdot
.74561 .30529 Mdot
.53509 .40215 Mdot
.72556 .23824 Mdot
.70551 .24569 Mdot
.59524 .55861 Mdot
.54511 .56607 Mdot
.73559 .12648 Mdot
.53509 .55861 Mdot
.63534 .45431 Mdot
.70551 .08922 Mdot
.74561 .29039 Mdot
.76566 .11157 Mdot
.67544 .11902 Mdot
.73559 .23824 Mdot
.70551 .11902 Mdot
.75564 .26059 Mdot
.70551 .23824 Mdot
.73559 .31274 Mdot
.21429 .28294 Mdot
.66541 .3649 Mdot
.71554 .12648 Mdot
.70551 .25314 Mdot
.47494 .49901 Mdot
.75564 .25314 Mdot
.76566 .27549 Mdot
.10401 .29039 Mdot
.08396 .29784 Mdot
.61529 .05197 Mdot
.48496 .48411 Mdot
.73559 .32019 Mdot
.73559 .08922 Mdot
.78571 .28294 Mdot
.75564 .27549 Mdot
.60526 .53626 Mdot
.60526 .05197 Mdot
.72556 .23078 Mdot
.69549 .13393 Mdot
.50501 .49901 Mdot
.60526 .55116 Mdot
.12406 .29039 Mdot
.59524 .05197 Mdot
.74561 .32019 Mdot
.68546 .08177 Mdot
.14411 .27549 Mdot
.76566 .11902 Mdot
.74561 .12648 Mdot
.75564 .12648 Mdot
.71554 .08177 Mdot
.22431 .29039 Mdot
.58521 .05942 Mdot
.70551 .22333 Mdot
.73559 .34255 Mdot
.70551 .13393 Mdot
.71554 .14883 Mdot
.74561 .09667 Mdot
.71554 .33509 Mdot
.72556 .34255 Mdot
.76566 .33509 Mdot
.47494 .50646 Mdot
.67544 .12648 Mdot
.62531 .54371 Mdot
.51504 .49156 Mdot
.74561 .14138 Mdot
.70551 .14883 Mdot
.72556 .07432 Mdot
.71554 .20843 Mdot
.59524 .55116 Mdot
.49499 .51391 Mdot
.59524 .06687 Mdot
.77569 .30529 Mdot
.53509 .55116 Mdot
.15414 .27549 Mdot
.50501 .50646 Mdot
.76566 .12648 Mdot
.75564 .30529 Mdot
.77569 .13393 Mdot
.09398 .33509 Mdot
.70551 .12648 Mdot
.13409 .27549 Mdot
.72556 .21588 Mdot
.10401 .33509 Mdot
.76566 .10412 Mdot
.48496 .51391 Mdot
.73559 .14138 Mdot
.58521 .57352 Mdot
.49499 .47666 Mdot
.10401 .28294 Mdot
.56516 .56607 Mdot
.74561 .08922 Mdot
.60526 .56607 Mdot
.13409 .28294 Mdot
.73559 .15628 Mdot
.18421 .26059 Mdot
.61529 .52881 Mdot
.78571 .30529 Mdot
.12406 .26804 Mdot
.75564 .16373 Mdot
.75564 .32764 Mdot
.08396 .32764 Mdot
.74561 .35 Mdot
.62531 .52881 Mdot
.71554 .15628 Mdot
.52506 .47666 Mdot
.74561 .31274 Mdot
.75564 .08177 Mdot
.74561 .05942 Mdot
.08396 .30529 Mdot
.46491 .52136 Mdot
.60526 .58097 Mdot
.80576 .30529 Mdot
.09398 .29039 Mdot
.55514 .57352 Mdot
.52506 .49901 Mdot
.77569 .15628 Mdot
.78571 .26059 Mdot
.77569 .08922 Mdot
.68546 .13393 Mdot
.76566 .32019 Mdot
.72556 .18608 Mdot
.68546 .14883 Mdot
.67544 .14883 Mdot
.57519 .10412 Mdot
.50501 .47666 Mdot
.43484 .51391 Mdot
.69549 .05942 Mdot
.54511 .48411 Mdot
.66541 .14138 Mdot
.64536 .53626 Mdot
.77569 .09667 Mdot
.19424 .26059 Mdot
.71554 .20098 Mdot
.81579 .31274 Mdot
.16416 .26804 Mdot
.76566 .24569 Mdot
.67544 .13393 Mdot
.76566 .06687 Mdot
.07393 .32019 Mdot
.45489 .50646 Mdot
.69549 .20098 Mdot
.75564 .35745 Mdot
.76566 .08177 Mdot
.73559 .14883 Mdot
.58521 .11157 Mdot
.07393 .30529 Mdot
.73559 .22333 Mdot
.55514 .49156 Mdot
.20426 .26804 Mdot
.62531 .55116 Mdot
.67544 .07432 Mdot
.65539 .55116 Mdot
.69549 .22333 Mdot
.64536 .52881 Mdot
.76566 .26804 Mdot
.78571 .31274 Mdot
.68546 .06687 Mdot
.61529 .55861 Mdot
.68546 .20843 Mdot
.79574 .14138 Mdot
.78571 .13393 Mdot
.70551 .05942 Mdot
.46491 .53626 Mdot
.77569 .08177 Mdot
.69549 .16373 Mdot
.81579 .32019 Mdot
.14411 .26059 Mdot
.43484 .52881 Mdot
.64536 .55861 Mdot
.74561 .17863 Mdot
.71554 .13393 Mdot
.75564 .17863 Mdot
.77569 .06687 Mdot
.77569 .25314 Mdot
.17419 .25314 Mdot
.76566 .14883 Mdot
.83584 .31274 Mdot
.13409 .24569 Mdot
.52506 .50646 Mdot
.11404 .27549 Mdot
.77569 .32019 Mdot
.62531 .55861 Mdot
.83584 .29039 Mdot
.84586 .31274 Mdot
.47494 .55116 Mdot
.72556 .19353 Mdot
.15414 .22333 Mdot
.83584 .28294 Mdot
.82581 .32764 Mdot
.76566 .17118 Mdot
.15414 .26804 Mdot
.72556 .05197 Mdot
.66541 .20843 Mdot
.46491 .52881 Mdot
.66541 .55116 Mdot
.83584 .32764 Mdot
.42481 .52136 Mdot
.44486 .55861 Mdot
.48496 .54371 Mdot
.45489 .56607 Mdot
.52506 .51391 Mdot
.79574 .26059 Mdot
.55514 .49901 Mdot
.80576 .27549 Mdot
.14411 .23824 Mdot
.76566 .3649 Mdot
.78571 .14883 Mdot
.65539 .52136 Mdot
.70551 .15628 Mdot
.67544 .54371 Mdot
.77569 .34255 Mdot
.67544 .19353 Mdot
.72556 .06687 Mdot
.69549 .18608 Mdot
.62531 .56607 Mdot
.69549 .19353 Mdot
.81579 .28294 Mdot
.75564 .05197 Mdot
.84586 .29784 Mdot
.22431 .27549 Mdot
.43484 .55116 Mdot
.71554 .07432 Mdot
.17419 .24569 Mdot
.66541 .53626 Mdot
.06391 .31274 Mdot
.80576 .26804 Mdot
.41479 .54371 Mdot
.63534 .57352 Mdot
.42481 .52881 Mdot
.67544 .52136 Mdot
.41479 .51391 Mdot
.71554 .05942 Mdot
.67544 .15628 Mdot
.48496 .52881 Mdot
.68546 .17118 Mdot
.79574 .35745 Mdot
.68546 .52881 Mdot
.72556 .04452 Mdot
.49499 .35745 Mdot
.59524 .58097 Mdot
.66541 .52136 Mdot
.79574 .31274 Mdot
.74561 .02962 Mdot
.75564 .03707 Mdot
.82581 .27549 Mdot
.61529 .58842 Mdot
.64536 .20098 Mdot
.69549 .17863 Mdot
.73559 .03707 Mdot
.64536 .56607 Mdot
.13409 .23824 Mdot
.80576 .35 Mdot
.66541 .15628 Mdot
.65539 .16373 Mdot
.81579 .37235 Mdot
.17419 .22333 Mdot
.78571 .26804 Mdot
.11404 .26059 Mdot
.46491 .3649 Mdot
.80576 .3798 Mdot
.40476 .52881 Mdot
.67544 .53626 Mdot
.46491 .38725 Mdot
.18421 .22333 Mdot
.76566 .05197 Mdot
.84586 .33509 Mdot
.66541 .18608 Mdot
.86591 .30529 Mdot
.85589 .32019 Mdot
.76566 .03707 Mdot
.62531 .58097 Mdot
.67544 .17863 Mdot
.13409 .20843 Mdot
.85589 .29039 Mdot
.76566 .3798 Mdot
.73559 .19353 Mdot
.64536 .19353 Mdot
.77569 .03707 Mdot
.40476 .54371 Mdot
.79574 .37235 Mdot
.77569 .35745 Mdot
.16416 .21588 Mdot
.22431 .26059 Mdot
.64536 .17863 Mdot
.47494 .55861 Mdot
.42481 .58097 Mdot
.78571 .08177 Mdot
.22431 .24569 Mdot
.78571 .37235 Mdot
.43484 .57352 Mdot
.80576 .35745 Mdot
.49499 .38725 Mdot
.39474 .54371 Mdot
.76566 .37235 Mdot
.77569 .16373 Mdot
.44486 .57352 Mdot
.81579 .35 Mdot
.08396 .22333 Mdot
.41479 .55116 Mdot
.82581 .35745 Mdot
.41479 .56607 Mdot
.20426 .25314 Mdot
.66541 .17118 Mdot
.41479 .55861 Mdot
.15414 .20098 Mdot
.14411 .18608 Mdot
.45489 .3947 Mdot
.22431 .23824 Mdot
.19424 .25314 Mdot
.87594 .29784 Mdot
.77569 .05197 Mdot
.79574 .3798 Mdot
.21429 .22333 Mdot
.13409 .19353 Mdot
.79574 .08177 Mdot
.23434 .25314 Mdot
.85589 .32764 Mdot
.65539 .17863 Mdot
.50501 .53626 Mdot
.09398 .20843 Mdot
.39474 .52881 Mdot
.80576 .33509 Mdot
.12406 .25314 Mdot
.78571 .05197 Mdot
.20426 .23078 Mdot
.62531 .57352 Mdot
.48496 .3947 Mdot
.79574 .06687 Mdot
.78571 .03707 Mdot
.79574 .33509 Mdot
.11404 .18608 Mdot
.82581 .3649 Mdot
.11404 .20843 Mdot
.11404 .20098 Mdot
.49499 .52881 Mdot
.47494 .3947 Mdot
.47494 .57352 Mdot
.78571 .40215 Mdot
.68546 .17863 Mdot
.12406 .20843 Mdot
.79574 .05197 Mdot
.11404 .22333 Mdot
.20426 .26059 Mdot
.43484 .38725 Mdot
.76566 .40215 Mdot
.11404 .24569 Mdot
.10401 .20098 Mdot
.75564 .3947 Mdot
.74561 .18608 Mdot
.19424 .22333 Mdot
.80576 .06687 Mdot
.86591 .28294 Mdot
.82581 .34255 Mdot
.22431 .22333 Mdot
.46491 .57352 Mdot
.49499 .55861 Mdot
.12406 .17863 Mdot
.77569 .38725 Mdot
.76566 .38725 Mdot
.79574 .04452 Mdot
.15414 .17118 Mdot
.88596 .32019 Mdot
.81579 .32764 Mdot
.49499 .54371 Mdot
.38471 .54371 Mdot
.81579 .05942 Mdot
.82581 .07432 Mdot
.51504 .58097 Mdot
.10401 .18608 Mdot
.44486 .3798 Mdot
.14411 .17118 Mdot
.08396 .21588 Mdot
.76566 .32764 Mdot
.39474 .51391 Mdot
.44486 .3947 Mdot
.23434 .23078 Mdot
.23434 .26804 Mdot
.50501 .52136 Mdot
.08396 .23078 Mdot
.10401 .23078 Mdot
.16416 .18608 Mdot
.82581 .3947 Mdot
.80576 .05197 Mdot
.81579 .3947 Mdot
.88596 .30529 Mdot
.82581 .33509 Mdot
.80576 .08922 Mdot
.36466 .51391 Mdot
.77569 .4245 Mdot
.83584 .08177 Mdot
.87594 .32764 Mdot
.80576 .3947 Mdot
.79574 .40215 Mdot
.37469 .52136 Mdot
.82581 .3798 Mdot
.83584 .38725 Mdot
.10401 .23824 Mdot
.76566 .41705 Mdot
.50501 .55861 Mdot
.19424 .18608 Mdot
.08396 .24569 Mdot
.76566 .4096 Mdot
.36466 .54371 Mdot
.18421 .20098 Mdot
.50501 .58097 Mdot
.82581 .05942 Mdot
.07393 .19353 Mdot
.53509 .56607 Mdot
.18421 .16373 Mdot
.37469 .49901 Mdot
.09398 .17863 Mdot
.34461 .53626 Mdot
.08396 .20843 Mdot
.35464 .52881 Mdot
.10401 .24569 Mdot
.81579 .3798 Mdot
.79574 .4096 Mdot
.78571 .32019 Mdot
.16416 .16373 Mdot
.37469 .54371 Mdot
.87594 .07432 Mdot
.52506 .57352 Mdot
.37469 .51391 Mdot
.20426 .17863 Mdot
.86591 .07432 Mdot
.22431 .21588 Mdot
.07393 .17863 Mdot
.51504 .55116 Mdot
.84586 .05942 Mdot
.88596 .29039 Mdot
.52506 .55861 Mdot
.81579 .08922 Mdot
.48496 .60332 Mdot
.90602 .32764 Mdot
.91604 .31274 Mdot
.46491 .58097 Mdot
.88596 .34255 Mdot
.90602 .33509 Mdot
.93609 .32019 Mdot
.83584 .05942 Mdot
.34461 .52136 Mdot
.08396 .27549 Mdot
.17419 .14883 Mdot
.84586 .08177 Mdot
.88596 .06687 Mdot
.85589 .03707 Mdot
.12406 .17118 Mdot
.20426 .17118 Mdot
.35464 .54371 Mdot
.50501 .54371 Mdot
.85589 .33509 Mdot
.47494 .59587 Mdot
.13409 .16373 Mdot
.09398 .15628 Mdot
.19424 .20098 Mdot
.87594 .28294 Mdot
.51504 .58842 Mdot
.39474 .58097 Mdot
.93609 .32764 Mdot
.92607 .30529 Mdot
.09398 .20098 Mdot
.20426 .20843 Mdot
.08396 .15628 Mdot
.07393 .18608 Mdot
.84586 .05197 Mdot
.94612 .31274 Mdot
.20426 .20098 Mdot
.05388 .27549 Mdot
.86591 .34255 Mdot
.08396 .25314 Mdot
.87594 .04452 Mdot
.88596 .32764 Mdot
.89599 .29784 Mdot
.92607 .33509 Mdot
.40476 .57352 Mdot
.05388 .20098 Mdot
.83584 .08922 Mdot
.25439 .17118 Mdot
.41479 .58842 Mdot
.90602 .35 Mdot
.20426 .14883 Mdot
.19424 .14883 Mdot
.78571 .4245 Mdot
.83584 .05197 Mdot
.06391 .17863 Mdot
.07393 .28294 Mdot
.79574 .41705 Mdot
.94612 .29784 Mdot
.09398 .26804 Mdot
.34461 .49901 Mdot
.07393 .15628 Mdot
.22431 .20843 Mdot
.16416 .14883 Mdot
.92607 .28294 Mdot
.06391 .21588 Mdot
.95614 .29784 Mdot
.89599 .04452 Mdot
.26441 .19353 Mdot
.07393 .25314 Mdot
.47494 .58842 Mdot
.26441 .17863 Mdot
.89599 .05942 Mdot
.23434 .20098 Mdot
.50501 .59587 Mdot
.25439 .17863 Mdot
.04386 .19353 Mdot
.36466 .49156 Mdot
.34461 .49156 Mdot
.32456 .50646 Mdot
.96617 .29784 Mdot
.81579 .09667 Mdot
.89599 .35745 Mdot
.90602 .30529 Mdot
.88596 .03707 Mdot
.85589 .09667 Mdot
.21429 .15628 Mdot
.05388 .23078 Mdot
.96617 .27549 Mdot
.05388 .15628 Mdot
.82581 .04452 Mdot
.90602 .34255 Mdot
.24436 .19353 Mdot
.06391 .28294 Mdot
.49499 .60332 Mdot
.10401 .27549 Mdot
.02381 .20843 Mdot
.96617 .26804 Mdot
.10401 .16373 Mdot
.15414 .15628 Mdot
.85589 .02962 Mdot
.06391 .23824 Mdot
.86591 .02217 Mdot
.05388 .26059 Mdot
.87594 .35745 Mdot
.05388 .24569 Mdot
.84586 .02962 Mdot
.91604 .34255 Mdot
.85589 .35745 Mdot
.95614 .29039 Mdot
.91604 .28294 Mdot
.88596 .35 Mdot
.94612 .27549 Mdot
.04386 .16373 Mdot
.25439 .16373 Mdot
.04386 .26804 Mdot
.84586 .09667 Mdot
.32456 .52881 Mdot
.88596 .3649 Mdot
.90602 .03707 Mdot
.94612 .32019 Mdot
.95614 .31274 Mdot
.96617 .32764 Mdot
.04386 .26059 Mdot
.33459 .53626 Mdot
.85589 .3649 Mdot
.02381 .21588 Mdot
.28446 .17118 Mdot
.02381 .24569 Mdot
.22431 .14883 Mdot
.92607 .27549 Mdot
.86591 .08177 Mdot
.03383 .26059 Mdot
.35464 .46176 Mdot
.04386 .17118 Mdot
.40476 .58842 Mdot
.93609 .26059 Mdot
.83584 .01472 Mdot
.27444 .17118 Mdot
.27444 .15628 Mdot
.82581 .02217 Mdot
.02381 .25314 Mdot
.02381 .20098 Mdot
.97619 .32019 Mdot
.88596 .02962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00ooooool[
ooooo`?o0?l0>oooool00?oooooo:_ooool01Ol0003o0?l0o`3o0?l0o`3o000000?oo`002?ooool3
ool002cooooo003oooooobOooooo0ol0o`001?l0003o0?l0o`3o0?l0o`05ool000?ooooo0ol0o`05
ool002_ooooo003oooooobOooooo0ol0o`04o`0000Goo`000oooool3o`3o00Goo`00:oooool00?oo
oooo9oooool3o`3o0004ool00?l0003o0000o`0000Goo`000_ooool01?l0003o0?l0o`3o0?l0o`05
ool002_ooooo003oooooo`_ooooo0ol0o`0Iooooo`Goo`000ol00006o`3o00Go00000ooo0003o`3o
02Wooooo003oooooo`[ooooo00Go0000o`3o0?l0o`3o0?l0o`00000Hooooo`Goo`000ol00006o`3o
00So00000ol0o`0Yooooo`00ooooool9ooooo`;o00000ol0o`02o`0001Oooooo1Ooo0003o`0000Ko
0?l02?l00003o`3o00Sooooo0ooo000Nooooo`00ooooool7ooooo`?o0?l01?l00003o`3o0005o`00
0?l0o`3o0?l0o`3o0?ooool01_l0o`0;ooooo`Goo`001_l00003o`3o00So00000ol0o`04ooooo`?o
0?l01Ooo000Mooooo`00ooooool6ooooo`04o`000?l0o`3o0?l0o`3o00Co00000ol0o`001Ol0003o
0?l0o`3o0?l0o`3o000000Ko0?l000?o0000ooooooooool02?ooool5ool000Ko00000ol0o`08o`00
00?o0?l000Co0000oooooooooooo00000ol0o`07ool001_ooooo003oooooo`Cooooo1_l0o`04o`00
00?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o0004o`000?l0o`3o0?l0o`3o00Oooooo0ol0
o`02ool000Ko00000ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o00Soo`00
6_ooool00?oooooo1?ooool3o`3o01Ko00000ol0o`07ooooo`?o0?l000?oo`00o`000?l000003?l0
0003o`3o00Go00000ol0o`04o`0000Ooo`006_ooool00?oooooo1?ooool3o`3o01Ko00000ol0o`07
ooooo`?o0?l03ol00003o`3o00Go00000ol0o`04o`0000Ooo`006_ooool00=Cooooo1_l0o`001?l0
003o0?l0o`3o0?l0o`0Uooooo`?o0?l01ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000001_l0
o`000ol0003o0?l0o`3o0004o`3o00Oooooo00Go0000o`3o0?l0o`3o0?l0o`000003o`3o01Go0000
1ooo000Kooooo`00doooool00ol0003o0?l0o`3o0004o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
8oooool01?l0003o0?l0o`3o0?l0o`07o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o
0003o`000?l0o`3o0?l000Co0?l000?o0000ooooooooool01Oooool3o`3o0004ooooool0o`3o0?l0
o`3o01Go00001Ooo000Mooooo`00d_ooool2o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l00_l0000Q
ooooo`;o00000ol0o`07o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o0003o`000?l0
o`3o0?l000Co0?l00_l00006ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l04_l00008ool001gooooo
003@ooooo`?o0?l03?l00003o`3o01Kooooo1_l0o`001?l0003o0?l0o`3o0?l0o`08o`0000?o0?l0
5_l00006o`3o0005o`000?l0o`3o0?l0o`3o0?ooool00ol0o`0?o`0000?o0?l01ooo000Nooooo`00
d?ooool3o`3o00co00000ol0o`0Eooooo`03o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o
0?l02?l00003o`3o01Ko00001_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l03ol00003o`3o
00Coo`008Oooool00=3ooooo0ol0o`000ol0003o0?l0o`3o0004o`3o00Go00000ol0o`0Booooo`?o
0?l000?o0000o`3o0?l0o`001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l00003o`3o
00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000Ko0?l000?o0000o`3o0?l0o`001?l0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000?o0?l02ol00003o`3o0004o`000?l0o`3o0?l0o`3o00Coo`00
8Oooool00=Cooooo1_l0o`05o`0000?o0?l04_ooool3o`3o00co00000ol0o`0;o`0000?o0?l000Co
ooooo`3o0?l0o`3o0?l01?l00006o`3o01[o00000ol0o`04ooooo`?oo`008_ooool00=Cooooo1_l0
o`05o`0000?o0?l000?o0000ooooooooool03_ooool01?l0003o0?l0o`3o0?l0o`0<o`0000?o0?l0
2ol00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00001_l0o`0Jo`0000?o0?l0:Oooool00=Oooooo
0ol0o`08o`0000?o0?l02?ooool3o`3o0004ooooool0o`3o0?l0o`3o00_o00000ol0o`001?l0003o
0?l0o`3o0?l0o`0Po`0000?o0?l03?l00006o`3o00;o0000:oooool00=Oooooo0ol0o`08o`0000?o
0?l01oooool01Ol0003o0?l0o`3o0?l0o`3o000000?o0?l02ol00003o`3o0004o`000?l0o`3o0?l0
o`3o023o00000ol0o`0<o`0000Ko0?l000?o0000ooooooooool0:_ooool00=Oooooo0ol0o`08o`00
00?o0?l01_ooool2o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o0004o`000?l0o`3o
0?l0o`3o023o00000ol0o`0<o`0000Ko0?l0;Oooool00=[ooooo00Co0000o`3o0?l0o`3o0?l01?l0
0003o`3o00Cooooo0ol0o`05o`0000Ko0?l02?l00003o`3o00_o00000ol0o`001Ol0003o0?l0o`3o
0?l0o`3o000000Ko0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o0004o`000?l0o`3o0?l0o`3o
00Co00000ol0o`0`ooooo`00foooool3o`3o00Co00000ol0o`001?l0003oooooooooooooool3o`3o
00Go00001_l0o`08o`0000?o0?l02ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000001_l0o`00
1?oooooo0?l0o`3o0?l0o`0;o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o033ooooo
003Dooooo`Ko0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l0
1Ol00006o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000?o0000o`3o0?l0
o`001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000Ko0?l000?oooooo`3o0?l0o`001?l0o`001?l0
003o0?l0o`3o0?l0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l00ol000001Ooo003o0?l0o`3o
0?l0o`3oo`0002oooooo003Dooooo`Ko0?l000Co0000o`3o0?l0o`3o0?l02?l00003o`3o00_o0000
0ol0o`04o`0000?o0?l02?l00003o`3o0004ooooool0o`3o0?l0o`3o00So00000ol0o`07ooooo`?o
0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o00Oo00001Ooo000_ooooo`00doooool00ol0003o
0?l0o`3o0004o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`0;o`0000?o0?l01?l00003o`3o
00So00000ol0o`001?oooooo0?l0o`3o0?l0o`08o`0000?o0?l01oooool3o`3o0004ooooool0o`3o
0?l0o`3o00Co00000ol0o`07o`0000Goo`00;oooool00=3ooooo0ol0o`0Xo`0000?o0?l000Co0000
o`3o0?l0o`3o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00So00000ol0o`0;ooooo`?o0?l0
0ol00005ool000Ko0?l000Co0000ool00?oo003oo`00<?ooool00<oooooo00Co0000o`3o0?l0o`3o
0?l0:?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`08
o`0000?o0?l02oooool3o`3o00?o00001Ooo0006o`3o03Cooooo003>ooooo`;o00000ol0o`0Xo`00
00?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0
o`0;ooooo`?o0?l000?o0000ool00?oo00001Ooo0006o`3o03Cooooo003=ooooo`?o0?l01ol00003
o`3o00So00000ol0o`000ol0003o0?l0o`3o0004o`3o0004o`000?l0o`3o0?l0o`3o027o00000ol0
o`000ol0003oooooooooo`0?ooooo`Ooo`00>oooool00<gooooo0ol0o`07o`0000?o0?l02?l00003
o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l08Ol00003o`3o01;ooooo1Ooo
000mooooo`00cOooool6o`3o0003o`000?l0o`3o0?l000Co0?l02?l00003o`3o0003o`000?l0o`3o
0?l000Co0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o01?o00000ol0o`0Booooo`Goo`00?Ooo
ool00=3ooooo0ol0o`000ooooooo0?l0o`3o0004o`3o01?o00000ol0o`0;o`0000?o0?l04ol00003
o`3o01?ooooo0ooo000nooooo`00d?ooool3o`3o0003o`000?l0o`3o0?l000Co0?l04ol00003o`3o
00_o00000ol0o`0Co`0000?o0?l0E?ooool00<gooooo1_l0o`08o`0000?o0?l01?l00003o`3o00Co
00000ol0o`02o`0000;ooooo00?o0000o`3o0?l0o`001?l0o`04o`0000?o0?l04ol00003o`3o05Co
oooo003<ooooo`03o`000?l0o`3o0?l000Co0?l02?l00003o`3o00Co00000ol0o`04o`0000?o0?l0
00?o0000ooooooooool00_ooool6o`3o00Co00000ol0o`0Co`0000?o0?l0E?ooool00<_ooooo0_l0
0006o`3o00So00000ol0o`04o`0000?o0?l01?l00003o`3o00Gooooo1_l0o`04o`0000?o0?l04ol0
0003o`3o05Cooooo0039ooooo`?o0?l05_l00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000001ooo
ool3o`3o00Oo00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000?o0000o`3o0?l0o`00
1?l0o`001?l0003o0?l0o`3o0?l0o`1Dooooo`00bOooool3o`3o01Ko00000ol0o`001Ol0003o0?l0
o`3o0?l0o`3o000000Oooooo0ol0o`07o`0000?o0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o
0003o`000?l0o`3o0?l000Co0?l000Go0000o`3o0?l0o`3o0?l0o`00001Cooooo`00bOooool3o`3o
0004o`000?l0o`3o0?l0o`3o01;o00000ol0o`000ol0003o0?l0o`3o0004o`3o00Gooooo1_l0o`00
0ol0003o0?l0o`3o0004o`3o0004ooooool0o`3o0?l0o`3o00Co00000ol0o`000ol0003o0?l0o`3o
0004o`3o0005o`000?l0o`3o0?l0o`3o0?l000001_l0o`1=ooooo`00cOooool3o`3o01Wo00000ol0
o`05ooooo`Ko0?l000?oooooo`3o0?l0o`001?l0o`001?l0003o0?l0o`3o0?l0o`0Co`0000Ko0?l0
COooool0047ooooo0ooo000Iooooo`?oo`00KOooool3o`3o01Wo00000ol0o`04ooooo`03o`000?l0
o`3o0?l000Co0?l000?o0000o`3o0?l0o`001?l0o`001?l0003o0?l0o`3o0?l0o`0Co`0000Ko0?l0
00?o0000ooooooooool0B_ooool0043ooooo1Ooo000Gooooo`Goo`00K?ooool3o`3o00Oo00000ol0
o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o01Ko
00000ol0o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l0BOooool0043ooooo1Ooo000Gooooo`Go
o`0000?o0000ooooooooool0JOooool3o`3o00Oo00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`00
00?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o01Ko00000ol0o`001?l0003o0?l0o`3o0?l0
o`0?o`0000?o0?l0BOooool003oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0>
ooooo`?oo`0000?oooooool00?oo00002?oo001Yooooo`?o0?l01ol00003o`3o0004ooooool0o`3o
0?l0o`3o00Co00000ol0o`04o`0000?o0?l000Coooooo`3o0?l0o`3o0?l05_l00003o`3o0004o`00
0?l0o`3o0?l0o`3o00oo00000ol0o`19ooooo`00>Oooool3o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00000ooo0003o`3o0004ooooool0o`3o0?l0o`3o00Cooooo0ol0o`03oooooa3oo`005Oooool3o`3o
02oooooo0ol0o`000ol0003oooooooooo`0Kooooo`?o0?l01?l00003o`3o0003o`000?oooooooooo
00Cooooo00Go0000o`3o0?l0o`3o0?l0o`000002ooooo`05o`000?l0o`3o0?l0o`3o0?l000001_oo
ool00ol0003o0?l0o`3o0004o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l0
2?l00003o`3o00Co00000ol0o`000ol0003oooooooooo`1:ooooo`005_ooool3ool0023ooooo0ol0
o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000002ooooo`05
o`000?l0o`3o0?l0o`3o0?l000002ooo0002o`0000Goo`005?ooool01Ol0003o0?l0o`3o0?l0o`3o
000002kooooo0ol0o`02o`0001_ooooo00Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Sooooo0ol0
o`04ooooo`?o0?l02?ooool6o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l0
2?l00003o`3o00Co00000ol0o`1=ooooo`004_ooool3o`3o00Coo`000ol0o`000ooooooo0?l0o`3o
0004o`3o01?ooooo1_l0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000?o0000o`3o0?l0o`00
1?l0o`001?l0003o0?l0o`3o0?l0o`0<ool000;o000000Goo`00o`3o0?l0o`3o0?l0ool0000Boooo
o`Ko0?l000Co0000o`3o0?l0o`3o0?l0:?ooool6o`3o0005o`000?l0o`3o0?l0o`3o0?ooool00ol0
o`0Booooo`?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Sooooo0ol0o`04ooooo`?o0?l0
1?ooool3o`3o0003ooooool0o`3o0?l000Co0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Co
00000ol0o`08o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`1=ooooo`004_ooool3o`3o00Coo`00
0ol0o`000ooooooo0?l0o`3o0004o`3o0003o`000?oooooooooo013ooooo0ol0o`0Bo`0000?o0?l0
1?l00007ool00004o`000?oo003oo`00ool000Co00000ol0o`0Cooooo`?o0?l01?l00003o`3o02So
oooo0ol0o`04o`0000?o0?l000Coooooo`3o0?l0o`3o0?l04_ooool3o`3o00So00000ol0o`0Foooo
o`?o0?l000Coooooo`3o0?l0o`3o0?l01ol00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0
o`0<o`0000?o0?l0D?ooool0017ooooo00Co0000o`3o0?l0o`3o0?l01?oo0003o`3o0003o`000?l0
o`3o0?l000Co0?l00_l0000Aooooo`?o0?l04_l00003o`3o00Co00001Ooo000:o`0000?o0?l04_oo
ool01?l0003o0?l0o`3o0?l0o`04o`0000?o0?l09oooool01?l0003o0?l0o`3o0?l0o`04o`0000?o
0?l000Go0000o`3o0?l0o`3o0?l0o`00000Aooooo`?o0?l02?l00003o`3o0003o`000?oooooooooo
01;ooooo00Go0000o`3o0?l0o`3o0?l0o`000003o`3o00Oo00000ol0o`001?l0003o0?l0o`3o0?l0
o`04o`0000?o0?l03?l00003o`3o053ooooo000>ooooo`?o0?l01Ol00003ool000_o00000ol0o`08
ooooo`?o0?l01oooool3o`3o00Go00000ol0o`0?o`0000?oo`001?l00003o`3o00?o00001Ooo000>
ooooo`?o0?l02?l00006o`3o027ooooo0ol0o`0?o`0000?o0?l000?oooooo`3o0?l0o`001?l0o`05
ooooo`Ko0?l02ol00003o`3o00oooooo0ol0o`0<o`0000?o0?l04_l00003o`3o00Go00000ol0o`1@
ooooo`003_ooool3o`3o01?o00000ol0o`08ooooo`?o0?l01oooool3o`3o00Go00000ol0o`0Fo`00
00?o0?l00ol00005ool000kooooo0ol0o`08o`0000Ko0?l08Oooool3o`3o00oo00000ol0o`000ooo
oooo0?l0o`3o0004o`3o0003o`000?oooooooooo00;ooooo1_l0o`0;o`0000?o0?l03oooool3o`3o
00co00000ol0o`0Bo`0000?o0?l01Ol00003o`3o053ooooo000>ooooo`?o0?l03ol00003ool00004
o`000?l0o`3o0?l0o`3o00Oooooo00Go0000o`3o0?l0o`3o0?l0o`000006ooooo`?o0?l01Ol00003
o`3o01Ko00000ol0o`08ool000kooooo0ol0o`08o`0000Ko0?l000?o0000ooooooooool07Oooool0
1?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000;ooooo00?o
0000o`3o0?l0o`001?l0o`0;o`0000?o0?l03oooool3o`3o00co00000ol0o`0Bo`0000?o0?l01Ol0
0003o`3o053ooooo000>ooooo`?o0?l03_l00005ool00003o`000?oooooooooo00Cooooo0ol0o`04
o`0000?o0?l000Coooooo`3o0?l0o`3o0?l03ol00003o`3o00oo00000ol0o`04ool000?o0?l000Co
ooooo`3o0?l0o`3o0?l02oooool3o`3o00So00000ol0o`04o`0000?o0?l05_ooool3o`3o0004oooo
ool0o`3o0?l0o`3o00Oo00000ol0o`08o`0000?o0?l02?l00003o`3o00Co00000ol0o`001?l0003o
0?l0o`3o0?l0o`04o`0000Ko0?l000Go0000o`3o0?l0o`3o0?l0ooooo`03o`3o00[ooooo00Co0000
o`3o0?l0o`3o0?l01?l00003o`3o01[o00000ol0o`000ol0003oooooooooo`1Aooooo`002oooool3
ool000?o0?l03_l00005ool000Oooooo0ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l03ol0
0003o`3o00oo00000ol0o`04ool000?o0?l000Co0000o`3o0?l0o`3o0?l00ooo0007ooooo`04o`00
0?l0o`3o0?l0o`3o00So00000ol0o`04o`0000?o0?l000?o0000ooooooooool04_ooool01Ol0003o
0?l0o`3o0?l0o`3o000000?o0?l01ol00003o`3o00So00000ol0o`08o`0000?o0?l01?l00003o`3o
0004o`000?l0o`3o0?l0o`3o00Co00001_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000?o
0000ooooooooool02?ooool3o`3o00Co00000ol0o`0Jo`0000?o0?l0E?ooool000[ooooo1?oo0003
o`3o00Go00001_l0o`03o`000005ool00?l0o`3o0?l0o`3o0?oo00001oooool3o`3o00Co00000ol0
o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l03ol00006o`3o0005ool00?l0o`3o0?l0o`3o0?l0
00000ol0o`04ool000Ko0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0
o`3o00Co00001_l0o`05ooooo`Ko0?l01?ooool3o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0
o`04o`0000Ko0?l02?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l0
00Co0000o`3o0?l0o`3o0?l01?l00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000001_l0o`000ooo
oooo0?l0o`3o0004o`3o0005ooooool0o`3o0?l0o`3o0?l000001_l0o`001?l0003o0?l0o`3o0?l0
o`0?o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l0E?ooool000[ooooo1Ooo0007o`0000Ko0?l01?l0
0003o`3o0003o`000?oooooooooo00Gooooo0ol0o`0Jo`0000?o0?l03ol00006o`3o00Oo00001Ooo
0006o`3o00So00000ol0o`0;o`0000?o0?l000?o0000ooooooooool00_ooool6o`3o00Cooooo0ol0
o`05o`0000?o0?l01?l00006o`3o00co00000ol0o`04o`0000?o0?l01?l00003o`3o01Ko00000ol0
o`000ooooooo0?l0o`3o0004o`3o0005o`000?ooooooooooooooool000001_l0o`001?l0003o0?l0
o`3o0?l0o`0?o`0000Ko0?l00_l0001Fooooo`002_ooool5ool000Oo00001_l0o`04o`0000?o0?l0
0_l00005ooooo`04o`000?l0o`3o0?l0o`3o01[o00000ol0o`0?o`0000Ko0?l01Ol00007ool000Ko
0?l02?l00003o`3o00_o00000ol0o`02o`0000;ooooo00?o0000o`3o0?l0o`001?l0o`001?l0003o
ooooooooooooool3o`3o00Go00000ol0o`04o`0000Ko0?l03?l00003o`3o00Co00000ol0o`04o`00
00?o0?l05_l00003o`3o0003o`000?l0o`3o0?l000Co0?l00_l00002ooooo`03o`000?l0o`3o0?l0
00Co0?l000Co0000o`3o0?l0o`3o0?l03ol00006o`3o0003o`000?oooooooooo05Gooooo000:oooo
o`Goo`002_l00003o`3o00So00000ol0o`001?oooooo0?l0o`3o0?l0o`07o`0000?o0?l01?l00003
o`3o00So00000ol0o`0Mo`0000Coo`000ol0o`0?o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o
0?l0o`3o00Co00000ol0o`08o`0000?o0?l03ol00006o`3o02So00000ol0o`05o`0000?o0?l02ol0
0003o`3o00So00000ol0o`08o`0000?o0?l01?l00003o`3o05_ooooo000:ooooo`Goo`002_l00003
o`3o00So00000ol0o`001?oooooo0?l0o`3o0?l0o`07o`0000?o0?l01?l00003o`3o00So00000ol0
o`0Mo`0000Coo`000ol0o`0?o`0000?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Co0000
0ol0o`08o`0000?o0?l03ol00006o`3o02So00000ol0o`05o`0000?o0?l02ol00003o`3o00So0000
0ol0o`08o`0000?o0?l01?l00003o`3o05_ooooo000:ooooo`Goo`002_l00003o`3o00So00000ol0
o`001?l0003o0?l0o`3o0?l0o`07o`0000?o0?l01?l00003o`3o00So00000ol0o`0Mo`0000Coo`00
0ol0o`0?o`0000?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o
0?l03ol00006o`3o02So00000ol0o`05o`0000?o0?l02ol00003o`3o00So00000ol0o`08o`0000?o
0?l01?l00003o`3o05_ooooo000:ooooo`Coo`000ol0o`08o`0000?o0?l04ol00003o`3o02Co0000
0ol0o`04o`0000?o0?l01Ol00003o`3o00Oo00000ol0o`08o`0000?o0?l01?l00003o`3o0004oooo
ool0o`3o0?l0o`3o00_o00000ol0o`001?l0003oooooooooooooool3o`3o00Go00001_l0o`001?l0
003o0?l0o`3o0?l0o`08o`0000?o0?l01ol00003o`3o00Go00000ol0o`04o`0000Ko0?l01?l00003
o`3o00So00000ol0o`001?l0003o0?l0o`3o0?l0o`08o`0000?o0?l01?l00003o`3o00So00001_l0
o`000ol0003oooooooooo`1Looooo`002_ooool4ool000?o0?l02?l00003o`3o01?o00000ol0o`0T
o`0000?o0?l000Co0000ool00?oo003oo`000ol0o`001Ol0003oo`00ool00?oo003o000000?o0?l0
1ol00003o`3o00So00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o00Co
oooo0ol0o`05o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l02?l00003o`3o00Oo00000ol0o`05o`00
00?o0?l01?l00006o`3o00Co00000ol0o`08o`0000?o0?l000Coooooo`3o0?l0o`3o0?l02?l00003
o`3o00Co00000ol0o`08o`0000Ko0?l0Goooool000Oooooo0ol0o`04ool000?o0?l000Co0000o`3o
0?l0o`3o0?l01?l00003o`3o00Co00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l0
0003o`3o00Co00000ol0o`08o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l02?l00006o`3o00Coo`00
0ol0o`05ool000Ko0?l000?o0000o`3o0?l0o`001?l0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o
0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l01?ooool3o`3o
0005o`000?l0o`3o0?l0o`3o0?l000001_l0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000Co
0000o`3o0?l0o`3o0?l01?l00006o`3o00Go00001_l0o`000ol0003o0?l0o`3o0004o`3o0003o`00
0?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o
00So00000ol0o`04o`0000?o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l0Goooool000Oo
oooo0ol0o`001?l0003oo`00ool00?oo0004o`0000?o0?l02ol00003o`3o0005o`000?l0o`3o0?l0
o`3o0?l000000ol0o`0;o`0000?o0?l02?l00006o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0
o`000ol0003oooooooooo`05ool000;ooooo1Ooo0002ooooo`05o`000?l0o`3o0?l0o`3o0?l00000
0ol0o`001?l0003oooooooooool00003o`3o01Ko00000ol0o`04o`0000?o0?l01oooool01Ol0003o
0?l0o`3o0?l0o`3o000000?o0?l02ol00003o`3o00So00001_l0o`05o`0000Ko0?l000?o0000oooo
ooooool01?ooool01Ol0003o0?l0o`3o0?l0o`3o000000;ooooo00Co0000o`3o0?l0o`3o0?l01?l0
0003o`3o0004ooooool0o`3o0?l0o`3o00oo00000ol0o`04o`0000?o0?l000?o0000ooooooooool0
Hoooool000Oooooo0ol0o`08o`0000?o0?l02ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0ol0o`0;o`0000?o0?l02?l00006o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`03ooooo`Go
o`000_ooool5ool000?ooooo0ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000;ooooo00Co0000o`3o
0?l0o`3o0?l05_l00003o`3o00Co00000ol0o`000ol0003oooooooooo`05ooooo`?o0?l000Cooooo
o`3o0?l0o`3o0?l02ol00003o`3o00So00001_l0o`05o`0000Ko0?l02?ooool3o`3o00Cooooo0ol0
o`04o`0000?o0?l000Coooooo`3o0?l0o`3o0?l03ol00003o`3o00Co00000ol0o`1Vooooo`001ooo
ool3o`3o01?o00001_l0o`05o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l05_l00003o`3o00Co0000
0ol0o`000ol0003oooooooooo`05ooooo`?oo`001?ooool3ool000Cooooo0ol0o`04o`0000?o0?l0
3?l00006o`3o01?o00001_l0o`05ooooo`Ko0?l08Ol00003o`3o01;ooooo00Go0000o`3o0?l0o`3o
0?l0o`000003ooooo`?o0?l01?l00003o`3o00Co00000ol0o`08o`0000?o0?l0I_ooool000Oooooo
0ol0o`0Co`0000Ko0?l01Ol00006o`3o0004ooooool0o`3o0?l0o`3o01Ko00000ol0o`04o`0000?o
0?l05_ooool3o`3o00Co00000ol0o`0<o`0000Ko0?l04ol00006o`3o0003o`000?oooooooooo00;o
oooo1_l0o`0Qo`0000?o0?l04oooool3o`3o00Cooooo0ol0o`04o`0000?o0?l01?l00003o`3o00So
00000ol0o`1Vooooo`001oooool3o`3o00Co00000ooo000<o`0000Ko0?l01Ol00006o`3o0004o`00
0?l0o`3o0?l0o`3o01Ko00000ol0o`04o`0000?o0?l05_ooool3o`3o00Co00000ol0o`0<o`0000Ko
0?l04ol00006o`3o00;o00000_ooool00ol0003o0?l0o`3o0004o`3o027o00000ol0o`0Cooooo`?o
0?l00oooool01?l0003o0?l0o`3o0?l0o`04o`0000?o0?l01?l00003o`3o00So00000ol0o`000ol0
003oooooooooo`1Sooooo`001oooool3o`3o00?o00001Ooo0004o`0000?o0?l01?l00003o`3o01Wo
00000ol0o`0Co`0000?o0?l05_ooool3o`3o00Co00000ol0o`08o`0000?o0?l01?l00003o`3o00oo
00000ol0o`08o`0000?o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l000Go0000o`3o0?l0
o`3o0?l0o`000003o`3o01;o00000ol0o`0Fooooo`?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0
o`3o01?o00000ol0o`1Rooooo`001oooool3o`3o0003o`000?oo003oo`0000Goo`001?l00003o`3o
00Co00000ol0o`0Io`0000?o0?l04ol00003o`3o01Kooooo0ol0o`04o`0000?o0?l02?l00003o`3o
00Co00000ol0o`0?o`0000?o0?l02?l00003o`3o00Co00000ol0o`000ooooooo0?l0o`3o0004o`3o
0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`0Bo`0000?o0?l000?o0000ooooooooool04oooool3
o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`0Co`0000?o0?l000?o0000ooooooooool0Gooo
ool000Oooooo0ol0o`08ool000?o000000Goo`00o`3o0?l0o`3o0?l0ool00003o`0000?o0?l02?l0
0003o`3o00_o00001_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000Ko0?l01?l00003o`3o0004o`00
0?l0o`3o0?l0o`3o01Kooooo0ol0o`04o`0000?o0?l01Ol00006o`3o00Co00000ol0o`0?o`0000?o
0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Co00000ol0o`000ooooooo0?l0o`3o0004o`3o
0005o`000?l0o`3o0?l0o`3o0?l000001_l0o`0?o`0000?o0?l000Co0000o`3o0?l0o`3o0?l04_oo
ool3o`3o00Co00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l00006o`3o00Go0000
1_l0o`1Oooooo`002_ooool7ool000Co00001Ooo0003o`0000?o0?l02?l00003o`3o00_o00000ol0
o`04o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l0
5_ooool3o`3o00co00001_l0o`0Fo`0000?o0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o00Co
oooo0ol0o`08o`0000?o0?l04ol00003o`3o01;ooooo0ol0o`0<o`0000?o0?l01?l00006o`3o00So
00000ol0o`1Oooooo`002_ooool7ool000Co00001Ooo0003o`0000?o0?l02?l00003o`3o00_o0000
0ol0o`04o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o
0?l0o`00000Dooooo`04o`000?l0o`3o0?l0o`3o00co00001_l0o`0Fo`0000?o0?l000Co0000o`3o
0?l0o`3o0?l02ol00003o`3o00Cooooo0ol0o`08o`0000?o0?l04ol00003o`3o01;ooooo0ol0o`0<
o`0000?o0?l01?l00006o`3o00So00000ol0o`1Oooooo`002oooool7ool000?o0?l000Co0000ool0
0?oo003oo`001?l00003o`3o00Co00000ol0o`0Qo`0000?o0?l02?l00003o`3o00oooooo0ol0o`04
o`0000?o0?l02ol00003o`3o00Co00000ol0o`000ol0003o0?l0o`3o0004o`3o0004o`000?l0o`3o
0?l0o`3o01?o00000ol0o`000ol0003oooooooooo`07ooooo`04o`000?l0o`3o0?l0o`3o00oo0000
0ol0o`000ol0003o0?l0o`3o0004o`3o0003o`000?oooooooooo01Kooooo00?o0000o`3o0?l0o`00
1?l0o`08o`0000?o0?l03?l00003o`3o0003o`000?oooooooooo05oooooo000=ooooo`Goo`000ol0
o`08o`0000?o0?l01?l00003o`3o027o00000ol0o`08o`0000?o0?l03oooool3o`3o00Co00000ol0
o`0;o`0000?o0?l01?l00003o`3o0003ooooool0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l0
4ol00003o`3o00_ooooo0ol0o`0?o`0000?o0?l000?oooooo`3o0?l0o`001?l0o`0Jooooo`Ko0?l0
2?l00003o`3o00co00000ol0o`1Rooooo`002oooool7ool000?o0?l02?l00003o`3o00Co00000ol0
o`0Qo`0000?o0?l02?l00003o`3o00oooooo0ol0o`04o`0000?o0?l02ol00003o`3o00Co00000ol0
o`000ol0003o0?l0o`3o0004o`3o0004o`000?l0o`3o0?l0o`3o01?o00000ol0o`0;ooooo`?o0?l0
3ol00003o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000ooooooooool05oooool6o`3o00So0000
0ol0o`0<o`0000?o0?l0H_ooool000[ooooo1ooo0004ooooo`04o`000?l0o`3o0?l0o`3o00_o0000
0ol0o`08o`0000Ko0?l06_l00003o`3o0003o`000?oooooooooo013ooooo0ol0o`0Mo`0000Ko0?l0
2?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`0;oooo
o`?o0?l000Co0000o`3o0?l0o`3o0?l05_l00003o`3o01Kooooo1_l0o`0<o`0000Ko0?l01Ol00006
o`3o05oooooo000:ooooo`Ooo`001?ooool01?l0003o0?l0o`3o0?l0o`0;o`0000?o0?l02?l00006
o`3o01[o00000ol0o`0Cooooo`?o0?l07Ol00006o`3o00So00000ol0o`001?l0003o0?l0o`3o0?l0
o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000009ooooo`05o`000?l0o`3o0?l0o`3o0?l0
00000ol0o`0Fo`0000?o0?l05Oooool00ol0003o0?l0o`3o0004o`3o00co00001_l0o`05o`0000Ko
0?l000?o0000ooooooooool0A_ooool3ool001?ooooo0007ooooo`?o0?l02?oo0003o`3o0004o`00
0?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00006o`3o
00So00000ol0o`0?o`0000?o0?l02oooool3o`3o00Gooooo0ol0o`0?o`0000Ko0?l01?l00003o`3o
0003o`000?l0o`3o0?l000Co0?l02?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`00
0ol0003o0?l0o`3o0004o`3o0003ooooool0o`3o0?l000Co0?l000Go0000o`3o0?l0o`3o0?l0o`00
0006o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000Ko0?l000Coooooo`3o0?l0o`3o
0?l01?ooool3o`3o0003ooooool0o`3o0?l000Co0?l000?o0000o`3o0?l0o`001?l0o`05o`0000Ko
0?l000?o0000o`3o0?l0o`001?l0o`05o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l01?ooool3o`3o
03gooooo1Ooo000Booooo`001oooool3o`3o0003o`000?oo003oo`0000Goo`000ol0o`08o`0000?o
0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`0;o`0000?o0?l03ol00003o`3o
00_ooooo0ol0o`000ol0003oooooooooo`02ooooo`?o0?l03ol00006o`3o00Co00000ol0o`0Qo`00
00?o0?l000?oooooo`3o0?l0o`001?l0o`08o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003
o`3o00So00001_l0o`001?oooooo0?l0o`3o0?l0o`04ooooo`?o0?l000?oooooo`3o0?l0o`001?l0
o`0<o`0000Ko0?l000Co0000oooooooooooooooo0ol0o`05o`0000?o0?l01?l00003o`3o00Cooooo
0ol0o`0mooooo`Goo`004_ooool000Oooooo0ol0o`03o`0000Goo`000ol0o`08o`0000?o0?l01?l0
0003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`0;o`0000?o0?l03ol00003o`3o0003o`00
0?oooooooooo00Sooooo0ol0o`02o`0000?ooooo0ol0o`0?o`0000Ko0?l01?l00003o`3o027o0000
0ol0o`000ol0003o0?l0o`3o0004o`3o00So00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o
0?l02?l00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_ooool01Ol0003o0?l0o`3o0?l0o`3o
000000Ko0?l03?l00006o`3o00Cooooo0ol0o`05o`0000?o0?l01?l00003o`3o0004o`000?oooooo
ooooo`0000?o0?l000?o0000ooooooooool0=oooool:ool0013ooooo0007ooooo`?o0?l01?l00003
ool000So00000ol0o`001?l0003o0?l0o`3o0?l0o`0;o`0000?o0?l03ol00003o`3o00Co00000ol0
o`001?l0003o0?l0o`3o0?l0o`08o`0000?o0?l01?ooool3o`3o00Co00000ol0o`000ooooooo0?l0
o`3o0004o`3o00Co00000ol0o`05o`0000?o0?l01?l00003o`3o00Co00001_l0o`001?l0003o0?l0
o`3o0?l0o`0Fo`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`04o`00
00?o0?l04_l00003o`3o00oo00000ol0o`05o`0000?o0?l01oooool3o`3o00oo00000ol0o`05o`00
00?o0?l0=Oooool<ool000oooooo0007ooooo`?o0?l03ol00003o`3o0004ooooool0o`3o0?l0o`3o
00_o00000ol0o`0?o`0000?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00So00000ol0o`04
ooooo`?o0?l01?l00003o`3o0003ooooool0o`3o0?l000Co0?l01?l00003o`3o00Go00000ol0o`04
o`0000?o0?l01?l00006o`3o0004o`000?l0o`3o0?l0o`3o01Ko00000ol0o`04o`0000?o0?l000Co
0000o`3o0?l0o`3o0?l02?l00003o`3o00Co00000ol0o`0Bo`0000?o0?l03ol00003o`3o00Go0000
0ol0o`07ooooo`?o0?l03ol00003o`3o00Go00000ol0o`0eooooo`Goo`000_l00005ool000oooooo
0007ooooo`?o0?l03ol00003o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0o`0?o`0000?o0?l0
1?l00003o`3o0004ooooool0o`3o0?l0o`3o00So00000ol0o`04ooooo`?o0?l01?l00003o`3o0003
o`000?l0o`3o0?l000Co0?l01?l00003o`3o00Go00000ol0o`04o`0000?o0?l01?l00006o`3o0004
o`000?l0o`3o0?l0o`3o01Ko00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02?l00003
o`3o00Co00000ol0o`0Bo`0000?o0?l03ol00003o`3o00Go00000ol0o`07ooooo`?o0?l03ol00003
o`3o00Go00000ol0o`000ol0003oooooooooo`0booooo`Goo`000_l00005ool000oooooo000:oooo
o`03o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l04ol00003o`3o00Oo00000ol0o`0<
o`0000Ko0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o0003o`000?oooooooooo00Gooooo0ol0
o`0?o`0000Ko0?l01Ol00003o`3o00Co00000ol0o`0;o`0000?o0?l08Ol00003o`3o00oo00000ol0
o`04o`0000?o0?l02?l00003o`3o00_o00000ol0o`08o`0000?o0?l000?o0000ooooooooool01Ooo
ool3o`3o01;o00000ol0o`08o`0000?o0?l000Coooooo`3o0?l0o`3o0?l0;oooool3o`3o00?o0000
1Ooo000?ooooo`002oooool6o`3o0004o`000?l0o`3o0?l0o`3o01?o00000ol0o`07o`0000?o0?l0
3?l00006o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`000ol0003oooooooooo`04ooooo`04
o`000?l0o`3o0?l0o`3o00oo00001_l0o`05o`0000?o0?l01?l00003o`3o00_o00000ol0o`0Qo`00
00?o0?l03ol00003o`3o00Co00000ol0o`08o`0000?o0?l02ol00003o`3o00So00000ol0o`07oooo
o`04o`000?l0o`3o0?l0o`3o01;o00000ol0o`08o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00
000^ooooo`?o0?l00ol00005ool000oooooo000;ooooo`Ko0?l000Co0000o`3o0?l0o`3o0?l02ol0
0003o`3o00Go00001_l0o`04o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`05o`0000Ko0?l000Co
0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o
0?l01?l00003o`3o00Co00000ol0o`000ol0003o0?l0o`3o0004o`3o00Go00000ol0o`04o`0000?o
0?l02ol00003o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l04_l00003o`3o
0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l01?l00003o`3o00So00000ol0o`08
o`0000Ko0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Cooooo0ol0o`000ol0003o0?l0o`3o
0004o`3o0004o`000?l0o`3o0?l0o`3o00So00001_l0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o
0?l000?o0000o`3o0?l0o`001?l0o`0[ooooo`05ool00?l0o`3o0?l0o`3o0?oo00000_l00005ool0
00?o0?l03?ooool000kooooo0ol0o`0?o`0000?o0?l02?l00003o`3o00So00001_l0o`0<o`0000?o
0?l02?l00006o`3o00So00000ol0o`04o`0000?o0?l04ol00003o`3o00oo00001_l0o`001?l0003o
0?l0o`3o0?l0o`0Bo`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00So00000ol0o`04
o`0000?o0?l04ol00003o`3o00Oo00000ol0o`02o`0000Kooooo0ol0o`04o`0000?o0?l000Co0000
o`3o0?l0o`3o0?l02?l00003o`3o0004o`000?ooooooooooo`0000?o0?l01?l00003o`3o00Co0000
0ol0o`0[ooooo`Goo`000ol00003ool00004o`000?l0o`3o0?l0o`3o00cooooo000>ooooo`?o0?l0
3ol00003o`3o00So00000ol0o`08o`0000Ko0?l03?l00003o`3o00So00001_l0o`08o`0000?o0?l0
1?l00003o`3o01?o00000ol0o`0?o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l04_l00003o`3o0004
o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l01?l00003o`3o01?o00000ol0o`07o`00
00?o0?l000?o0000ooooooooool01?ooool01?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000Co0000
o`3o0?l0o`3o0?l02?l00003o`3o0004o`000?ooooooooooooooo`?o0?l01?l00003o`3o00Co0000
0ol0o`0[ooooo`Goo`001ol00003o`3o00cooooo000Aooooo`04o`000?l0o`3o0?l0o`3o00So0000
0ol0o`001?l0003oooooooooool00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00001_l0o`001?l0
003o0?l0o`3o0?l0o`0Fo`0000?o0?l000Co0000oooooooooooooooo0ol0o`04o`0000?o0?l000Co
0000o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`0>o`0000?o
0?l000Co0000o`3o0?l0o`3o0?l04ol00003o`3o00Co00000ol0o`04o`0000?o0?l000Co0000o`3o
0?l0o`3o0?l01?l00003o`3o01;o00000ol0o`0Co`0000?o0?l000Co0000oooooooooooooooo0ol0
o`001?oooooo0?l0o`3o0?l0o`0?o`0000?o0?l01ol00003o`3o0004ooooool0o`3o0?l0o`3o00_o
00000ol0o`04ooooo`?o0?l08Oooool3o`3o0005o`000?oo003oo`00ool00?l000000ol0o`04o`00
00?o0?l03?ooool001;ooooo0ol0o`08o`0000?o0?l01?ooool3o`3o0004ooooool0o`3o0?l0o`3o
00Co00001_l0o`001?oooooo0?l0o`3o0?l0o`0Fo`0000?o0?l01?ooool3o`3o00Co00000ol0o`00
1?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000Coooooo`3o0?l0o`3o0?l02?l00003o`3o00ko0000
0ol0o`001?l0003o0?l0o`3o0?l0o`0Co`0000?o0?l01?l00003o`3o00Co00000ol0o`001?oooooo
0?l0o`3o0?l0o`04o`0000?o0?l04_l00003o`3o01?o00000ol0o`04ooooo`?o0?l000Coooooo`3o
0?l0o`3o0?l03ol00003o`3o00Oo00000ol0o`001?l0003o0?l0o`3o0?l0o`0;o`0000?o0?l01?oo
ool3o`3o0003o`000?oooooooooo01kooooo0ol0o`05o`0000?o0?l01?l00003o`3o00cooooo000B
ooooo`?o0?l02?l00003o`3o00Cooooo0ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000Ko0?l000Co
0000o`3o0?l0o`3o0?l05_l00003o`3o00Cooooo0ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o
0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`0>o`0000?o0?l000Coooooo`3o
0?l0o`3o0?l04ol00003o`3o00Co00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l0
0003o`3o01;o00000ol0o`0Co`0000?o0?l000Co0000oooooooooooo00000ol0o`001?l0003o0?l0
o`3o0?l0o`0?o`0000?o0?l01ol00003o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0o`001?l0
003oooooooooooooool3o`3o00;o00007oooool3o`3o00Go00000ol0o`04o`0000?o0?l00ooo0009
ooooo`005Oooool00ol0003o0?l0o`3o0004o`3o0003o`000?oooooooooo00Gooooo0ol0o`08o`00
00?o0?l01ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`04o`0000Ko0?l00_l00009
ooooo`03o`000?l0o`3o0?l000Co0?l07_l00003o`3o00Co00001_l0o`001?l0003o0?l0o`3o0?l0
o`04o`0000?o0?l02?l00003o`3o0004o`000?l0o`3o0?l0o`3o02oo00000ol0o`08o`0000?o0?l0
1ol00003o`3o00Go00000ol0o`07o`0000?o0?l06_l00003o`3o00So00000ol0o`04o`0000?o0?l0
2?ooool6o`3o0003o`000?oooooooooo00Wooooo1_l0o`0>o`0000Goo`002?ooool001Kooooo1_l0
o`08ooooo`?o0?l02?l00003o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
1?l00006o`3o00;o00002_ooool6o`3o01ko00000ol0o`04o`0000Ko0?l000Co0000o`3o0?l0o`3o
0?l01?l00003o`3o00So00000ol0o`001?l0003o0?l0o`3o0?l0o`0_o`0000?o0?l02?l00003o`3o
00Oo00000ol0o`05o`0000?o0?l01ol00003o`3o01[o00000ol0o`08o`0000?o0?l01?l00003o`3o
00Oooooo00?o0000o`3o0?l0o`001?l0o`02o`0000Kooooo0ooo00000ol0003o0?l0o`3o0004o`3o
00co00001ooo0008ooooo`005_ooool6o`3o00Cooooo0ol0o`001?oooooo0?l0o`3o0?l0o`04o`00
00?o0?l000Co0000o`3o0?l0o`3o0?l01?l00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0
o`04o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l02?ooool6o`3o0004o`000?l0o`3o0?l0o`3o00So
00000ol0o`08o`0000?o0?l01?l00003o`3o00Co00001_l0o`001?l0003o0?l0o`3o0?l0o`04o`00
00?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000
o`3o0?l0o`3o0?l02?l00003o`3o00oo00001_l0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l0
2?l00003o`3o00Co00001_l0o`05o`0000?o0?l01ol00003o`3o00So00000ol0o`001?l0003o0?l0
o`3o0?l0o`0;o`0000?o0?l02?l00003o`3o00Co00000ol0o`04ooooo`?o0?l000?o0000o`3o0?l0
o`001?l0o`001?l0003o0?l0o`3o0?l0o`03ooooo`Goo`001_l0o`08o`0000?o0?l02?oo0008oooo
o`008?ooool3o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l05_l00003o`3o
00kooooo00Co0000o`3o0?l0o`3o0?l02?l00003o`3o00So00000ol0o`04o`0000?o0?l02ol00003
o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`0;o`0000?o0?l000Co0000o`3o0?l0o`3o0?l0
2?l00003o`3o00oo00001_l0o`04o`0000?o0?l04ol00003o`3o00So00000ol0o`07o`0000?o0?l0
2?l00003o`3o0004o`000?l0o`3o0?l0o`3o01go00000ol0o`04ooooo`?o0?l02?l00003o`3o00?o
oooo1Ooo000>o`0000?o0?l01ooo0009ooooo`008?ooool3o`3o0004o`000?l0o`3o0?l0o`3o00Co
00000ol0o`08o`0000?o0?l05_l00003o`3o00oooooo0ol0o`08o`0000?o0?l02?l00003o`3o00Co
00000ol0o`0;o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0o`001?l0
003o0?l0o`3o0?l0o`08o`0000?o0?l03ol00006o`3o00Co00000ol0o`0Co`0000?o0?l02?l00003
o`3o00Oo00000ol0o`08o`0000?o0?l000Co0000o`3o0?l0o`3o0?l07Ol00003o`3o0004o`000?oo
ooooooooo`0000?o0?l02?l00003o`3o00?ooooo2?oo000;o`0000?o0?l01Ooo000;ooooo`007Ooo
ool3o`3o00_o00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Co0000
0ol0o`04o`0000?o0?l00_l00006ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l01?ooool3o`3o047o
00000ol0o`0Co`0000?o0?l02ol00003o`3o0003o`000?l0o`3o0?l000Co0?l05_l00003o`3o00So
00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02?l00003o`3o027o00000ol0o`07o`00
00?o0?l00_l00003ooooo`?o0?l02?oo0007o`0000Ko0?l000Coooooo`3o0?l0o`3o0?l03?ooool0
01gooooo0ol0o`0;o`0000?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Co00000ol0o`04
o`0000?o0?l01?l00003o`3o0003o`000?oooooooooo00Gooooo0ol0o`001?oooooo0?l0o`3o0?l0
o`04ooooo`?o0?l0@Ol00003o`3o01?o00000ol0o`0;o`0000?o0?l000?oooooo`3o0?l0o`001?l0
o`0Fo`0000?o0?l02?l00003o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`08o`0000?o0?l0
8Ol00003o`3o00Oo00000ol0o`000ol0003oooooooooo`02ooooo`?o0?l00oooool5ool000Oo0000
1_l0o`001?oooooo0?l0o`3o0?l0o`0<ooooo`007Oooool3o`3o00_o00000ol0o`04o`0000?o0?l0
00Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Co00000ol0o`04o`0000?o0?l01oooool01Ol0003o
0?l0o`3o0?l0o`3o000000?o0?l000Co0000oooooooooooooooo0ol0o`11o`0000?o0?l04ol00003
o`3o00_o00000ol0o`000ooooooo0?l0o`3o0004o`3o01Ko00000ol0o`08o`0000?o0?l01?l00003
o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`0Qo`0000?o0?l01ol00003o`3o00;o00000_oo
ool01Ol0003o0?l0o`3o0?l0o`3o000000;ooooo1Ooo0007o`0000Ko0?l000Co0000o`3o0?l0o`3o
0?l00ooo0009ooooo`006Oooool3o`3o0003ooooool0o`3o0?l000Co0?l08Ol00003o`3o00Co0000
0ol0o`05ooooo`?o0?l01ol00003o`3o0004o`000?l0o`3o0?l0o`3o01?o00000ol0o`0>o`0000?o
0?l03ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`0;o`0000?o0?l000Co0000o`3o
0?l0o`3o0?l03ol00003o`3o0004o`000?ooooooooooooooo`?o0?l01ol00003o`3o0004o`000?l0
o`3o0?l0o`3o00So00001_l0o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l02?l00006o`3o00Go
00001_l0o`04o`0000?o0?l04ol00003o`3o00Co00000ol0o`04o`0000?o0?l000Coooooool00?oo
003oo`000ol0o`0>o`0000Goo`002?ooool001Sooooo00Go0000o`3o0?l0o`3o0?l0o`000006o`3o
027o00000ol0o`04o`0000?o0?l01Oooool3o`3o00Oo00000ol0o`001?l0003o0?l0o`3o0?l0o`0C
o`0000?o0?l03_l00003o`3o00oo00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l02ol0
0003o`3o0004ooooool0o`3o0?l0o`3o00oo00000ol0o`04ooooo`?o0?l01ol00003o`3o0004o`00
0?l0o`3o0?l0o`3o00So00001_l0o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l02?l00006o`3o
00Go00001_l0o`04o`0000?o0?l04ol00003o`3o00Co00000ol0o`04o`0000?o0?l000Co0000oooo
oooooooooooo0ol0o`0>o`0000Goo`002?ooool001Kooooo1_l0o`000ol0003o0?l0o`3o0004o`3o
00Go00000ol0o`07o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o
0?l000Co0?l01?l00003o`3o00Gooooo0ol0o`07o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02?l0
0006o`3o0005o`000?l0o`3o0?l0o`3o0?l000001_l0o`04o`0000?o0?l01?l00003o`3o0004o`00
0?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l000Goooooo`3o0?l0o`3o0?l0o`000003o`3o
00Co00000ol0o`04o`0000?o0?l000?oooooo`3o0?l0o`001?l0o`04o`0000?o0?l000Go0000o`3o
0?l0o`3o0?l0o`000006o`3o0004ooooool0o`3o0?l0o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o
0?l0o`3o000000?o0?l01?l00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`07o`0000?o
0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l01Ol00006o`3o
0003o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o
0?l0o`3o00Co00000ol0o`04o`0000?o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l01Ol0
0006o`3o00?o00001Ooo0008ooooo`005_ooool3o`3o00oo00000ol0o`07o`0000?o0?l000Co0000
o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Oo00000ol0o`05ooooo`?o0?l0
5_l00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_ooool01?l0003o0?l0o`3o0?l0o`04o`00
00?o0?l02?l00003o`3o00Co00000ol0o`04o`0000?o0?l000Coooooo`3o0?l0o`3o0?l02?l00003
o`3o00Co00000ol0o`03ooooo`04o`000?l0o`3o0?l0o`3o00Co00000ol0o`001Ol0003o0?l0o`3o
0?l0o`3o000000Ko0?l000Coooooo`3o0?l0o`3o0?l03ol00003o`3o00Co00000ol0o`04o`0000?o
0?l000Co0000o`3o0?l0o`3o0?l01ol00003o`3o00So00000ol0o`001?l0003o0?l0o`3o0?l0o`0;
o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Co00000ol0o`001?l0003o0?l0o`3o
0?l0o`0Fo`0000?o0?l02?l00006o`3o00?o00001Ooo0008ooooo`005_ooool3o`3o00oo00000ol0
o`07o`0000?o0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Oo
00000ol0o`04ooooo`04o`000?l0o`3o0?l0o`3o01Ko00001_l0o`001Ol0003o0?l0o`3o0?l0o`3o
000000;ooooo00Co0000o`3o0?l0o`3o0?l01?l00003o`3o00So00000ol0o`04o`0000?o0?l01?l0
0003o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`04o`0000?o0?l000Co0000oooooooooooo
oooo0ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o0004o`000?l0o`3o0?l0
o`3o00oo00000ol0o`04o`0000?o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Oo00000ol0
o`08o`0000?o0?l000Coooooo`3o0?l0o`3o0?l02ol00003o`3o0004o`000?l0o`3o0?l0o`3o00Co
00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l05_l00003o`3o00So00001_l0o`03o`00
00Goo`002?ooool001Sooooo00Co0000o`3o0?l0o`3o0?l02?l00003o`3o00So00000ol0o`001?l0
003oooooooooooooool3o`3o01;o00000ol0o`001?oooooo0?l0o`3o0?l0o`04o`0000?o0?l02?l0
0003o`3o00Co00000ol0o`0<o`0000?o0?l01ol00003o`3o0004o`000?l0o`3o0?l0o`3o00Co0000
0ol0o`0;o`0000?o0?l05ol00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000000oooool3o`3o01;o
00000ol0o`0<o`0000?o0?l01?l00003o`3o0003ooooool0o`3o0?l000Co0?l02?l00003o`3o00Co
00000ol0o`001?oooooo0?l0o`3o0?l0o`04o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`08o`00
00?o0?l02ol00003o`3o00So00000ol0o`0?o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01ol00003
o`3o00Wooooo000Iooooo`?o0?l02?l00003o`3o00So00000ol0o`04ooooo`?o0?l04_l00003o`3o
0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l01?l00003o`3o00co00000ol0o`07
o`0000?o0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o00_o00000ol0o`0Go`0000Ko0?l000Co
ooooo`3o0?l0o`3o0?l01?ooool3o`3o01;o00000ol0o`0<o`0000?o0?l01?l00003o`3o0003oooo
ool0o`3o0?l000Co0?l02?l00003o`3o00Co00000ol0o`001?oooooo0?l0o`3o0?l0o`04o`0000?o
0?l000?oooooo`3o0?l0o`001?l0o`08o`0000?o0?l02ol00003o`3o00So00000ol0o`0?o`0000?o
0?l000Coooooo`3o0?l0o`3o0?l01ol00003o`3o00Wooooo000Iooooo`?o0?l02?l00003o`3o00So
00000ol0o`001?l0003oooooooooooooool3o`3o01;o00000ol0o`001?l0003o0?l0o`3o0?l0o`04
o`0000?o0?l02?l00003o`3o00Co00000ol0o`0<o`0000?o0?l01ol00003o`3o0004o`000?l0o`3o
0?l0o`3o00Co00000ol0o`0;o`0000?o0?l05ol00006o`3o0004o`000?l0o`3o0?l0o`3o00?ooooo
00Co0000o`3o0?l0o`3o0?l04_l00003o`3o00co00000ol0o`04o`0000?o0?l000?o0000o`3o0?l0
o`001?l0o`08o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`000ol0
003o0?l0o`3o0004o`3o00So00000ol0o`0;o`0000?o0?l02?l00003o`3o00oo00000ol0o`001?oo
oooo0?l0o`3o0?l0o`03ool000Co00000ol0o`09ooooo`007?ooool01?l0003o0?l0o`3o0?l0o`08
o`0000?o0?l01ol00003o`3o0004ooooool0o`3o0?l0o`3o00Co00000ol0o`001?l0003o0?l0o`3o
0?l0o`04o`0000?o0?l04_l00003o`3o01Oo00000ol0o`0;o`0000Ko0?l07_l00006o`3o00Go0000
0ol0o`04o`0000Ko0?l03ol00003o`3o00co00000ol0o`0;o`0000?o0?l03ol00003o`3o00_o0000
0ol0o`001?l0003o0?l0o`3o0?l0o`0?o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o
00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l02?l00003o`3o00?ooooo1Ooo0003
o`3o0003o`000?oooooooooo00Wooooo000Mooooo`?o0?l02?l00003o`3o00Oo00000ol0o`001?l0
003o0?l0o`3o0?l0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o01;o00000ol0
o`0Go`0000?o0?l02ol00006o`3o01ko00001_l0o`05o`0000?o0?l01?l00006o`3o00oo00000ol0
o`0<o`0000?o0?l02ol00003o`3o00oo00000ol0o`0;o`0000?o0?l000Co0000o`3o0?l0o`3o0?l0
3ol00006o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0
o`3o0?l01?l00003o`3o00So00000ol0o`03ooooo`Goo`000ol0o`0<ooooo`007Oooool6o`3o0005
o`000?l0o`3o0?l0o`3o0?l000001_l0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003
o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000Ko0?l01?l00003o`3o00Go00000ol0
o`04o`0000?o0?l02?l00003o`3o00Oo00000ol0o`000ol0003o0?l0o`3o0004o`3o00So00000ol0
o`08o`0000?o0?l02?l00006o`3o00Go00000ol0o`04o`0000Ko0?l000Go0000o`3o0?l0o`3o0?l0
o`000003o`3o00Oo00000ol0o`0<o`0000Ko0?l02?l00003o`3o00So00001_l0o`001?l0003o0?l0
o`3o0?l0o`0;o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02?l00006o`3o0003o`000?l0o`3o0?l0
00Co0?l000Goooooo`3o0?l0o`3o0?l0o`000006o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0
o`04o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00?ooooo1Ooo0003o`3o00cooooo
000Pooooo`?o0?l000Go0000o`3o0?l0o`3o0?l0o`000002ooooo`04o`000?l0o`3o0?l0o`3o01?o
00000ol0o`0?o`0000Ko0?l03?l00003o`3o00Co00000ol0o`0Bo`0000?o0?l01?l00003o`3o00So
00000ol0o`08o`0000?o0?l02?l00006o`3o01?o00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`00
00?o0?l03ol00003o`3o01?o00001_l0o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l02?l00006
o`3o00Co00000ol0o`04ooooo`03o`000?l0o`3o0?l000Co0?l03ol00003o`3o00Co00000ol0o`02
o`0000Kooooo0ooo000@ooooo`008?ooool3o`3o0004o`000?l0o`3o0?l0o`3o00Cooooo0ol0o`0C
o`0000?o0?l03ol00006o`3o00co00000ol0o`04o`0000?o0?l04_l00003o`3o00Co00000ol0o`08
o`0000?o0?l02?l00003o`3o00So00001_l0o`0Co`0000?o0?l000Co0000o`3o0?l0o`3o0?l01ol0
0003o`3o00oo00000ol0o`0Co`0000Ko0?l000Co0000o`3o0?l0o`3o0?l03ol00003o`3o00So0000
1_l0o`04o`0000?o0?l01Oooool6o`3o00oo00000ol0o`04o`0000?o0?l000?o0000ooooooooool0
6?ooool002_ooooo0ol0o`0;o`0000?o0?l01Ol00003o`3o01;o00000ol0o`000ol0003o0?l0o`3o
0004o`3o00Go00000ol0o`04o`0000?o0?l01?l00003o`3o00So00000ol0o`0;o`0000?o0?l02?l0
0003o`3o01go00000ol0o`04o`0000?o0?l05_l00003o`3o00Go00000ol0o`07o`0000?o0?l03ol0
0003o`3o00Cooooo00?o0000o`3o0?l0o`001?l0o`0<o`0000?o0?l03_l00003o`3o00_ooooo00Co
0000o`3o0?l0o`3o0?l01?l00003o`3o00Co00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000001go
oooo000[ooooo`?o0?l02ol00003o`3o00Go00000ol0o`0Bo`0000?o0?l000?oooooo`3o0?l0o`00
1?l0o`05o`0000?o0?l01?l00003o`3o00Co00000ol0o`08o`0000?o0?l02ol00003o`3o00So0000
0ol0o`0Mo`0000?o0?l01?l00003o`3o01Ko00000ol0o`05o`0000?o0?l01ol00003o`3o00oo0000
0ol0o`05ooooo`Ko0?l03?l00003o`3o00ko00000ol0o`0<ooooo`?o0?l01?l00003o`3o00Co0000
0ol0o`001?oooooo0?l0o`3o0?l0o`0Nooooo`00:oooool3o`3o00_o00000ol0o`05o`0000?o0?l0
4_l00003o`3o0003ooooool0o`3o0?l000Co0?l01Ol00003o`3o00Co00000ol0o`04o`0000?o0?l0
2?l00003o`3o00_o00000ol0o`08o`0000?o0?l07Ol00003o`3o00Co00000ol0o`0Fo`0000?o0?l0
1Ol00003o`3o00Oo00000ol0o`0?o`0000?o0?l01Oooool6o`3o00co00000ol0o`0>o`0000?o0?l0
2?ooool3ool00004o`000?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l000Coooooo`3o0?l0
o`3o0?l07_ooool002kooooo00?o0000o`3o0?l0o`001?l0o`001?l0003o0?l0o`3o0?l0o`0Bo`00
00?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Oooooo00Co0000o`3o0?l0o`3o0?l03ol0
0003o`3o0004o`000?l0o`3o0?l0o`3o02Co00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`0000?o
0?l000Co0000o`3o0?l0o`3o0?l02?l00006o`3o01[o00000ol0o`001?l0003o0?l0o`3o0?l0o`07
o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00Co00000ol0o`000ol0003ooooooooo
o`0;ooooo`04o`000?l0o`3o0?l0o`3o01;o00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000Wo
oooo1Ooo0007o`0000?o0?l01?l00003o`3o02;ooooo000_ooooo`Ko0?l000Coooooo`3o0?l0o`3o
0?l04_l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08ooooo`?o0?l03ol00003o`3o
0004o`000?l0o`3o0?l0o`3o02Co00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`0000?o0?l000Co
0000o`3o0?l0o`3o0?l02?l00006o`3o01[o00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`0000?o
0?l000Go0000o`3o0?l0o`3o0?l0ooooo`03o`3o00Co00000ol0o`0?ooooo`?o0?l04_l00003o`3o
0005o`000?l0o`3o0?l0o`3o0?l000002Oooool5ool000Oo00000ol0o`04o`0000?o0?l08_ooool0
02oooooo1_l0o`001?oooooo0?l0o`3o0?l0o`08o`0000?o0?l01ol00003o`3o0004o`000?l0o`3o
0?l0o`3o00Co00000ol0o`001?oooooo0?l0o`3o0?l0o`04ooooo`?o0?l03ol00003o`3o0004o`00
0?l0o`3o0?l0o`3o00Oo00000ol0o`0?o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o
0003o`000?l0o`3o0?l000Co0?l000?o0000o`3o0?l0o`001?l0o`001Ol0003o0?l0o`3o0?l0o`3o
000000Ko0?l000?o0000o`3o0?l0o`001?l0o`08o`0000?o0?l02?l00006o`3o0005o`000?l0o`3o
0?l0o`3o0?l000000ol0o`04o`0000Ko0?l000Go0000o`3o0?l0o`3o0?l0ooooo`06o`3o0004o`00
0?l0o`3o0?l0o`3o00oooooo1_l0o`05o`0000?o0?l01?l00006o`3o0003o`000?l0o`3o0?l000Co
0?l01oooool01Ooo003o0?l0o`3o0?l0o`3oo`0000?o00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o
000000Ko0?l08_ooool003Kooooo0ol0o`08o`0000?o0?l01ol00003o`3o00So00000ol0o`001?oo
oooo0?l0o`3o0?l0o`04ooooo`?o0?l04ol00003o`3o00Oo00000ol0o`0?o`0000?o0?l000Co0000
o`3o0?l0o`3o0?l02ol00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`000ol0003o0?l0
o`3o0004o`3o0004o`000?ooooooooooooooo`?o0?l02?l00003o`3o00So00001_l0o`0<o`0000?o
0?l01?l00003o`3o00?ooooo00Go0000o`3o0?l0o`3o0?l0o`00000Eooooo`?o0?l01Ol00003o`3o
00Co00001_l0o`04o`0000?o0?l02?ooool3o`3o00Co00000ol0o`02o`0000;ooooo00Go0000o`3o
0?l0o`3o0?l0o`00000Tooooo`00=_ooool3o`3o00So00000ol0o`07o`0000?o0?l02?l00003o`3o
0005o`000?l0o`3o0?l0o`3o0?l000000oooool3o`3o01?o00000ol0o`07o`0000?o0?l03ol00003
o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l0
00?o0000o`3o0?l0o`001?l0o`04ooooo`?o0?l02?l00003o`3o00So00001_l0o`0<o`0000?o0?l0
1?l00003o`3o00Cooooo0ol0o`0Fooooo`?o0?l01Ol00003o`3o00Co00001_l0o`04o`0000?o0?l0
2?ooool3o`3o00Co00000ol0o`02o`0000?ooooo0ol0o`0Uooooo`00>Oooool3o`3o0004o`000?l0
o`3o0?l0o`3o00So00000ol0o`0Bo`0000?o0?l000Coooooo`3o0?l0o`3o0?l01?l00003o`3o0004
o`000?l0o`3o0?l0o`3o01;o00000ol0o`08o`0000?o0?l04ol00006o`3o00oo00000ol0o`04oooo
o`?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0
o`000ol0003o0?l0o`3o0004o`3o00So00000ol0o`0Pooooo`04o`000?l0o`3o0?l0o`3o01;o0000
0ol0o`08ooooo`?o0?l02?l00003o`3o02Wooooo000iooooo`?o0?l000Co0000o`3o0?l0o`3o0?l0
2?l00003o`3o01;o00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l000Coooooo`3o0?l0
o`3o0?l04_l00003o`3o00So00000ol0o`0Co`0000Ko0?l03ol00003o`3o00Cooooo0ol0o`001Ol0
003o0?l0o`3o0?l0o`3ooooo00Ko0?l000Coooooo`3o0?l0o`3o0?l02ol00003o`3o0003ooooool0
o`3o0?l000Co0?l02?l00003o`3o027ooooo0ol0o`0Bo`0000?o0?l02?ooool3o`3o00So00000ol0
o`0Yooooo`00>Oooool3o`3o0004ooooool0o`3o0?l0o`3o00So00000ol0o`0Bo`0000?o0?l000Co
0000o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o01;o00000ol0o`08o`0000?o
0?l04ol00006o`3o00oo00000ol0o`001?l0003oooooooooooooool3o`3o0005o`000?l0o`3o0?l0
o`3o0?l000001_l0o`001?l0003o0?l0o`3o0?l0o`0;o`0000?o0?l000?o0000o`3o0?l0o`001?l0
o`08o`0000?o0?l08Oooool3o`3o01;o00000ol0o`08ooooo`?o0?l000Co0000ool00?oo003oo`00
1?l00003o`3o02Wooooo000mooooo`?o0?l02ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0ol0o`04o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Oo00000ol0o`05o`0000Ko
0?l000Go0000o`3o0?l0o`3o0?l0o`000002ooooo`03o`000?l0o`3o0?l000Co0?l000Co0000o`3o
0?l0o`3o0?l02?l00003o`3o00Co00000ol0o`0?o`0000?o0?l02?l00003o`3o01Ko00000ol0o`04
o`0000?o0?l01?l00003o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`0Qooooo`?o0?l01?l0
0003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`000ol0003oooooooooo`0;ooooo`Goo`00
0_l00005ool002Sooooo000mooooo`?o0?l02ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0ol0o`04o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Oo00000ol0o`05o`0000Ko
0?l000Coooooo`3o0?l0o`3o0?l00oooool00ol0003o0?l0o`3o0004o`3o0004o`000?l0o`3o0?l0
o`3o00So00000ol0o`04o`0000?o0?l03ol00003o`3o00So00000ol0o`0Fo`0000?o0?l01?l00003
o`3o00Co00000ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00000Pooooo`?o0?l01?l0
0003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`0>ooooo`coo`00:?ooool003gooooo0ol0
o`001?l0003o0?l0o`3o0?l0o`07o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o0004
o`000?l0o`3o0?l0o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`0000?o0?l01Ol00006
o`3o0003ooooool0o`3o0?l000Co0?l000?o0000o`3o0?l0o`001?l0o`001?l0003o0?l0o`3o0?l0
o`04o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o0?l0
2?l00003o`3o00So00000ol0o`04o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00Co
00000ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o01gooooo0ol0o`04o`00
00?o0?l000?o0000o`3o0?l0o`001?l0o`000ol0003o0?l0o`3o0004o`3o00_ooooo3?oo000Xoooo
o`00@?ooool01?l0003o0?l0o`3o0?l0o`0Bo`0000?o0?l02?l00003o`3o01?o00000ol0o`07oooo
o`?o0?l03ol00003o`3o0004o`000?ooooooooooooooo`?o0?l000Co0000o`3o0?l0o`3o0?l03ol0
0003o`3o00So00000ol0o`08o`0000?o0?l01?l00006o`3o00So00000ol0o`04o`0000?o0?l03?l0
0003o`3o01gooooo0ol0o`08o`0000Ko0?l000?o0000o`3o0?l0o`001?l0o`000ol0003ooooooooo
o`09ooooo`[oo`00:Oooool0043ooooo00Co0000o`3o0?l0o`3o0?l04_l00003o`3o00So00000ol0
o`0Co`0000?o0?l01oooool3o`3o00oo00000ol0o`04ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l0
3ol00003o`3o00So00000ol0o`08o`0000?o0?l01?l00006o`3o00So00000ol0o`04o`0000?o0?l0
3?l00003o`3o0003o`000?oooooooooo01[ooooo0ol0o`08o`0000Ko0?l000?o0000o`3o0?l0o`00
1?l0o`02o`0000gooooo1Ooo000[ooooo`00?Oooool3o`3o01?o00001_l0o`04o`0000?o0?l00_l0
0002ooooo`03o`000?l0o`3o0?l000Co0?l03?l00003o`3o00[ooooo00Co0000o`3o0?l0o`3o0?l0
1?l00003o`3o00Co00000ol0o`04ooooo`?o0?l02?l00003o`3o00So00000ol0o`001?l0003o0?l0
o`3o0?l0o`0;o`0000?o0?l000Co0000oooooooooooo00000ol0o`000ol0003oooooooooo`04oooo
o`04o`000?l0o`3o0?l0o`3o00oo00001_l0o`08o`0000?o0?l06_ooool3o`3o0004o`000?l0o`3o
0?l0o`3o01;o00000ol0o`0<ooooo`?oo`00;?ooool003gooooo0ol0o`0Co`0000Ko0?l01?l00003
o`3o0003o`000?oooooooooo00;ooooo1_l0o`0<o`0000?o0?l02oooool3o`3o00Co00000ol0o`04
o`0000?o0?l01?ooool3o`3o00So00000ol0o`08o`0000?o0?l000Coooooo`3o0?l0o`3o0?l02ol0
0003o`3o00Cooooo0ol0o`08ooooo`?o0?l03ol00006o`3o00So00000ol0o`0Jooooo`?o0?l000Co
ooooo`3o0?l0o`3o0?l04_l00003o`3o03_ooooo000mooooo`?o0?l04ol00006o`3o00Co00000ol0
o`02o`0000?ooooo1_l0o`0<o`0000?o0?l02_ooool01?l0003o0?l0o`3o0?l0o`04o`0000?o0?l0
1?l00003o`3o00Cooooo0ol0o`08o`0000?o0?l02?l00003o`3o0004ooooool0o`3o0?l0o`3o00_o
00000ol0o`04ooooo`?o0?l02?ooool3o`3o00oo00001_l0o`08o`0000?o0?l06Oooool01Ol0003o
0?l0o`3o0?l0o`3o000000?o0?l04_l00003o`3o03_ooooo000mooooo`?o0?l02ol00003o`3o01?o
00000ol0o`001?oooooo0?l0o`3o0?l0o`0;o`0000?o0?l000Co0000oooooooooooooooo0ol0o`00
0ooooooo0?l0o`3o0004o`3o00So00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000Wooooo00Go
0000o`3o0?l0o`3o0?l0o`000003o`3o0004o`000?ooooooooooo`0000Ko0?l00_l00003ooooo`?o
0?l01ol00003o`3o00;o00004Oooool3o`3o01go00000ol0o`0Fooooo`?o0?l03ol00003o`3o0003
o`000?l0o`3o0?l000Co0?l00_l0000mooooo`00?Oooool3o`3o00_o00000ol0o`0Co`0000?o0?l0
00Co0000o`3o0?l0o`3o0?l02ol00003o`3o0004o`000?ooooooooooo`0000?o0?l000?o0000o`3o
0?l0o`001?l0o`08o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00000:ooooo`?o0?l000Cooooo
o`3o0?l0o`3o0?l01?ooool6o`3o0003o`000?oooooooooo00;ooooo0ol0o`07o`0000?o0?l000?o
0000ooooooooool03oooool01?l0003o0?l0o`3o0?l0o`0Mo`0000?o0?l05_ooool3o`3o00oo0000
0ol0o`000ooooooo0?l0o`3o0004o`3o0003o`000?oooooooooo03cooooo000mooooo`?o0?l000Co
0000o`3o0?l0o`3o0?l01ol00003o`3o0004o`000?l0o`3o0?l0o`3o00oo00000ol0o`001?l0003o
0?l0o`3o0?l0o`07o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000006o`3o0003o`000?l0o`3o
0?l000Co0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o0?l000Co0?l01?oo
ool3o`3o0005ooooool0o`3o0?l0o`3o0?ooool00ol0o`04ooooo`Ko0?l01Oooool6o`3o00Co0000
0ol0o`0?ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o01?o00001_l0o`001?oooooo
0?l0o`3o0?l0o`0Booooo`?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0o`3o
0?l000Co0?l000?oooooo`3o0?l0o`001?l0o`0oooooo`00@?ooool01?l0003o0?l0o`3o0?l0o`0;
o`0000?o0?l04ol00003o`3o00Oo00000ol0o`05o`0000?o0?l01ol00003o`3o0004o`000?l0o`3o
0?l0o`3o00_o00000ol0o`04ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l04oooool6o`3o00Co0000
0ol0o`0?ooooo`?o0?l02?l00003o`3o01?o00001_l0o`001?oooooo0?l0o`3o0?l0o`0Eooooo`04
o`000?l0o`3o0?l0o`3o00Co00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000004Sooooo0011oooo
o`?o0?l02ol00003o`3o01?o00000ol0o`07o`0000?o0?l01Ol00003o`3o00Oo00000ol0o`001?l0
003o0?l0o`3o0?l0o`0;o`0000?o0?l000Co0000oooooooooooooooo0ol0o`001Ol0003o0?l0o`3o
0?l0o`3o0000017ooooo00?o0000o`3o0?l0o`001?l0o`04o`0000?o0?l03_ooool01?l0003o0?l0
o`3o0?l0o`08o`0000?o0?l04ol00006o`3o0005o`000?l0o`3o0?l0o`3o0?l000005Oooool3o`3o
00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`19ooooo`00@oooool01?l0003o0?l0o`3o0?l0o`04
o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02?l00006o`3o01ko00000ol0o`0;o`0000?o0?l02?l0
0003o`3o00So00000ol0o`04ooooo`?o0?l01?ooool3o`3o00So00000ol0o`000ol0003ooooooooo
o`0<ooooo`?o0?l03ol00003o`3o00Co00001_l0o`001?l0003o0?l0o`3o0?l0o`0;o`0000?o0?l0
4oooool3o`3o00So00000ol0o`19ooooo`00A?ooool3o`3o00Co00000ol0o`001?l0003o0?l0o`3o
0?l0o`08o`0000Ko0?l07_l00003o`3o00_o00000ol0o`08o`0000?o0?l02?l00003o`3o00Cooooo
0ol0o`04ooooo`?o0?l02?l00003o`3o00oooooo0ol0o`0?o`0000?o0?l01?l00006o`3o0004o`00
0?l0o`3o0?l0o`3o00_o00000ol0o`0Cooooo`?o0?l02?l00003o`3o04Wooooo0014ooooo`?o0?l0
1?l00003o`3o0004o`000?l0o`3o0?l0o`3o00So00001_l0o`0No`0000?o0?l02ol00003o`3o00So
00000ol0o`08o`0000?o0?l000Co0000oooooooooooo00000ol0o`001?l0003oooooooooool00003
o`3o00So00000ol0o`0>ooooo`04o`000?l0o`3o0?l0o`3o00oo00000ol0o`04o`0000Ko0?l000Co
0000o`3o0?l0o`3o0?l02ol00003o`3o01?ooooo0ol0o`08o`0000?o0?l0BOooool004Cooooo0ol0
o`0Fo`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00Co00001_l0o`001?l0003o0?l0
o`3o0?l0o`0;o`0000?o0?l08Ol00003o`3o00Co00000ol0o`05o`0000?o0?l01?l00003o`3o00_o
oooo0ol0o`0?o`0000?o0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o00So00000ol0o`000ol0
003oooooooooo`0Cooooo`?o0?l02?l00003o`3o04Wooooo0014ooooo`?o0?l05_l00003o`3o0005
ooooool0o`3o0?l0o`3o0?ooool00ol0o`04o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l02ol00003
o`3o027o00000ol0o`04o`0000?o0?l01Ol00003o`3o00Co00000ol0o`000ol0003oooooooooo`08
ooooo`?o0?l03ol00003o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0o`08o`0000?o0?l05_oo
ool3o`3o00So00000ol0o`19ooooo`00A?ooool3o`3o0003o`000?l0o`3o0?l000Co0?l02?l00003
o`3o00Co00000ol0o`001Ooooooo0?l0o`3o0?l0o`3ooooo00?o0?l01?l00006o`3o0004o`000?l0
o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l01?l00003o`3o00Go00000ol0o`0Bo`0000?o0?l0
1?l00003o`3o00Go00000ol0o`04o`0000Ko0?l000Coooooo`3o0?l0o`3o0?l01?ooool3o`3o0003
o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0004o`000?l0o`3o0?l0
o`3o00_o00000ol0o`08o`0000?o0?l05_ooool3o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000
o`3o0?l0o`3o0?l0BOooool004Oooooo00?o0000o`3o0?l0o`001?l0o`08o`0000?o0?l01?l00003
o`3o00Gooooo0ol0o`04o`0000?o0?l01?l00003o`3o00Co00000ol0o`04o`0000?o0?l01?l00003
o`3o00Go00000ol0o`0[o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01oooool00ol0003o0?l0o`3o
0004o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`0Fo`0000?o0?l06Oooool00ol0003o0?l0
o`3o0004o`3o0003o`000?oooooooooo04[ooooo0018ooooo`Ko0?l02?l00003o`3o00Co00000ol0
o`05ooooo`?o0?l01?l00003o`3o00Co00000ol0o`04o`0000?o0?l01?l00003o`3o00Co00000ol0
o`05o`0000?o0?l0:ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000001oooool6o`3o0004o`00
0?l0o`3o0?l0o`3o00So00000ol0o`0Fo`0000?o0?l06_ooool6o`3o04gooooo001>ooooo`05o`00
0?l0o`3o0?l0o`3o0?l000001_l0o`04o`0000?o0?l01oooool01?l0003o0?l0o`3o0?l0o`0Co`00
00Ko0?l01?l00003o`3o00co00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003
o`3o01[o00000ol0o`07ooooo`?o0?l01?l00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0
o`04o`0000?o0?l02ol00003o`3o0004o`000?l0o`3o0?l0o`3o06gooooo001?ooooo`?o0?l000?o
ooooo`3o0?l0o`001?l0o`04o`0000?o0?l02?ooool3o`3o01?o00001_l0o`04o`0000?o0?l03?l0
0003o`3o00Co00000ol0o`001?oooooo0?l0o`3o0?l0o`04o`0000?o0?l06_l00003o`3o00Oooooo
0ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0ooooo`03o`3o00Co00000ol0o`0;o`0000?o
0?l000Coooooo`3o0?l0o`3o0?l0KOooool004oooooo0ol0o`000ooooooo0?l0o`3o0004o`3o00Co
00000ol0o`08ooooo`?o0?l04ol00006o`3o00Co00000ol0o`0<o`0000?o0?l01?l00003o`3o0004
ooooool0o`3o0?l0o`3o00Co00000ol0o`0Jo`0000?o0?l01oooool3o`3o00Co00000ol0o`001Ol0
003o0?l0o`3o0?l0o`3o000000?o0?l01?l00003o`3o00_o00000ol0o`001Ol0003o0?l0o`3o0?l0
o`3o000006cooooo001Iooooo`05o`000?l0o`3o0?l0o`3o0?l000003Oooool01?l0003o0?l0o`3o
0?l0o`08o`0000Ko0?l000Co0000o`3o0?l0o`3o0?l03ol00006o`3o0004o`000?oooooooooooooo
o`?o0?l00_l00005ooooo`05o`000?l0o`3o0?l0o`3o0?l000000ol0o`0;o`0000?o0?l02?l00003
o`3o0003o`000?oooooooooo00Sooooo0ol0o`0Xo`0000?o0?l0J_ooool005[ooooo0ol0o`0?oooo
o`?o0?l02?l00006o`3o0004o`000?l0o`3o0?l0o`3o00oo00001_l0o`04ooooo`?o0?l000?o0000
ooooooooool01Oooool3o`3o0004o`000?l0o`3o0?l0o`3o00_o00000ol0o`08o`0000?o0?l02_oo
ool01?l0003o0?l0o`3o0?l0o`0Xo`0000?o0?l0J_ooool005[ooooo0ol0o`0?ooooo`?o0?l01?l0
0003o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l01?l00006o`3o00Go0000
1_l0o`04ooooo`?o0?l02?ooool3o`3o0003o`000?l0o`3o0?l000Co0?l01Ol00006o`3o00So0000
0ol0o`08ooooo`Ko0?l000Co0000o`3o0?l0o`3o0?l02ol00003o`3o0004o`000?l0o`3o0?l0o`3o
00Co00000ol0o`08o`0000Ko0?l0J_ooool006cooooo0ol0o`04o`0000?o0?l000Co0000oooooooo
oooooooo0ol0o`08o`0000Ko0?l01Ol00003o`3o01;ooooo0ol0o`04o`0000?o0?l01Ol00006o`3o
00So00000ol0o`08ooooo`?o0?l01?l00003o`3o00_o00000ol0o`001?l0003o0?l0o`3o0?l0o`04
o`0000?o0?l02?l00003o`3o0003o`000?oooooooooo06[ooooo001/ooooo`?o0?l01?l00003o`3o
00Cooooo0ol0o`08o`0000Ko0?l01Ol00003o`3o0003o`000?oooooooooo00kooooo00Co0000o`3o
0?l0o`3o0?l01?l00003o`3o00Go00001_l0o`08o`0000?o0?l01oooool01?l0003o0?l0o`3o0?l0
o`04o`0000?o0?l02ol00003o`3o0004ooooool0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l0
KOooool006oooooo0ol0o`02o`0000Wooooo00?o0000o`3o0?l0o`001?l0o`0?o`0000?o0?l03?oo
ool3o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l00003o`3o00Co0000
0ol0o`000ooooooo0?l0o`3o0004o`3o00So00001_l0o`08o`0000?o0?l01?ooool3o`3o00So0000
0ol0o`000ol0003oooooooooo`1^ooooo`00Koooool3o`3o0003o`000?oooooooooo00Wooooo1_l0
o`0?o`0000?o0?l03?ooool3o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o0?l0o`3ooooo00?o0?l0
1?l00003o`3o00Co00000ol0o`000ooooooo0?l0o`3o0004o`3o00So00001_l0o`08o`0000?o0?l0
1?ooool3o`3o00So00000ol0o`1aooooo`00Koooool3o`3o00cooooo1_l0o`0?o`0000?o0?l000?o
0000ooooooooool02Oooool3o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
1?l00003o`3o00Co00000ol0o`000ol0003o0?l0o`3o0004o`3o00So00001_l0o`08o`0000?o0?l0
1?ooool3o`3o00So00000ol0o`1aooooo`00O_ooool3o`3o00Coo`000ol0o`04o`0000?o0?l02?l0
0003o`3o00Sooooo0ol0o`0bo`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0004o`00
0?ooooooooooooooo`?o0?l02?l00003o`3o0003o`000?oooooooooo077ooooo001jooooo`?oo`00
00Co0000o`3o0?l0o`3o0?l01?oo0003o`3o00Co00000ol0o`08o`0000?o0?l01oooool01?l0003o
0?l0o`3o0?l0o`0bo`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00Cooooo0ol0o`08
o`0000?o0?l0M?ooool007Wooooo1Ooo0003o`3o00Coo`001_l0o`001?l0003o0?l0o`3o0?l0o`08
o`0000?o0?l01?ooool3o`3o0004o`000?l0o`3o0?l0o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o
0?l0o`3o000000?o0?l01?l00006o`3o00Go00000ol0o`0>o`0000?o0?l000Go0000o`3o0?l0o`3o
0?l0o`000003o`3o00Cooooo1_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0M?ooool007Wo
oooo1Ooo0003o`0000?oo`001?l00003o`3o00co00000ol0o`04ooooo`?o0?l02ol00003o`3o0005
o`000?l0o`3o0?l0o`3o0?l000000ol0o`04o`0000Ko0?l01Ol00003o`3o00ko00000ol0o`05o`00
00?o0?l01oooool3o`3o0005o`000?l0o`3o0?l0o`3o0?l00000Moooool007Wooooo1Ooo0003o`00
00?oo`0000Co0000ool00?oo003oo`000ol0o`0<o`0000?o0?l000Co0000oooooooooooo00000ol0
o`0;o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0ooooo`03o`3o00Co00001_l0o`05o`0000?o0?l0
3_l00003o`3o00Go00000ol0o`07ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l0N?ooool007Wooooo
1Ooo0002o`0000Soo`000ol0o`05o`0000?o0?l01ol00003o`3o00co00000ol0o`001?l0003ooooo
ooooooooool3o`3o0003ooooool0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o
00So00000ol0o`0?o`0000?o0?l0Q_ooool007Wooooo1Ooo0002o`0000Soo`000ol0o`05o`0000?o
0?l01ol00003o`3o00co00000ol0o`04ooooo`?o0?l000?oooooo`3o0?l0o`001?l0o`001?oooooo
0?l0o`3o0?l0o`04o`0000?o0?l02?l00003o`3o00oo00000ol0o`26ooooo`00NOooool5ool000;o
00002?oo0003o`3o00Go00000ol0o`07o`0000?o0?l03?l00003o`3o00?ooooo00Go0000o`3o0?l0
o`3o0?l0o`000006o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l03ol00003
o`3o08Kooooo001iooooo`Goo`000_l00005ool000?o0?l03ol00003o`3o0004o`000?oooooooooo
o`0000?o0?l02?l00006o`3o01?o00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`0000?o0?l01?l0
0003o`3o0005o`000?l0o`3o0?l0o`3o0?l00000ROooool007Wooooo1Ooo0002o`0000Goo`000ol0
o`0?o`0000?o0?l000Co0000oooooooooooo00000ol0o`08o`0000Ko0?l04ol00003o`3o0004o`00
0?l0o`3o0?l0o`3o00Oo00000ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000029oooo
o`00NOooool01Ooo003o0?l0o`3o0?l0o`3oo`0000;o000000Goo`00o`3o0?l0o`3o0?l0ool00003
o`3o00oo00001_l0o`001?l0003o0?l0o`3o0?l0o`08o`0000Ko0?l02?l00003o`3o00So00000ol0
o`000ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l01?l00003o`3o0005o`000?l0
o`3o0?l0o`3o0?l000000ol0o`26ooooo`00N_ooool3o`3o00Co00000ol0o`001?oooooo0?l0o`3o
0?l0o`0Bo`0000?o0?l06_l00003o`3o00co00001_l0o`001?l0003o0?l0o`3o0?l0o`0?o`0000?o
0?l0Q_ooool007Oooooo0ooo0003o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`0Bo`0000?o
0?l06_l00003o`3o00co00001_l0o`001?oooooo0?l0o`3o0?l0o`0?o`0000?o0?l000?o0000oooo
ooooool0Poooool007Kooooo1?oo0003o`3o00So00001_l0o`001?l0003o0?l0o`3o0?l0o`08o`00
00?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o0?l000Co0000
oooooooooooo00000ol0o`08o`0000?o0?l01?ooool3o`3o01;o00000ol0o`23ooooo`00M_ooool4
ool000?o0?l02?l00006o`3o0004o`000?l0o`3o0?l0o`3o00So00000ol0o`04o`0000?o0?l000Co
ooooo`3o0?l0o`3o0?l01?l00003o`3o00So00000ol0o`04ooooo`?o0?l02?l00003o`3o00Cooooo
0ol0o`0Bo`0000?o0?l0Poooool007Kooooo1?oo0003o`3o00So00001_l0o`001?l0003o0?l0o`3o
0?l0o`08o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`08o`0000?o
0?l01?ooool3o`3o00So00000ol0o`04ooooo`?o0?l04_l00003o`3o08?ooooo001cooooo`?o0?l0
00?o0000ool00?oo00001Ooo000Bo`0000Ko0?l03?l00003o`3o00Co00000ol0o`08o`0000?o0?l0
1?ooool3o`3o00So00001_l0o`001?oooooo0?l0o`3o0?l0o`0;o`0000?o0?l000Go0000o`3o0?l0
o`3o0?l0o`000025ooooo`00Koooool3ool00004o`000?l0o`3o0?l0o`3o00?o00001Ooo000Bo`00
00Ko0?l03?l00003o`3o00Co00000ol0o`08o`0000?o0?l01?ooool3o`3o00So00001_l0o`001?l0
003o0?l0o`3o0?l0o`0;o`0000?o0?l000Co0000o`3o0?l0o`3o0?l0Q_ooool006kooooo1Ooo0003
o`3o00?o00001Ooo0003o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o0003o`000?l0
o`3o0?l000Co0?l01?l00003o`3o00Go00000ol0o`04o`0000Ko0?l000Go0000o`3o0?l0o`3o0?l0
o`000003o`3o00Cooooo0ol0o`04o`0000?o0?l000?o0000o`3o0?l0o`001?l0o`001?l0003o0?l0
o`3o0?l0o`04o`0000?o0?l01?l00003o`3o0004o`000?l0o`3o0?l0o`3o08Kooooo001^ooooo`Go
o`001ol00003ool000Co00000ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000?o0?l01?l00003o`3o
00Co00000ol0o`0?o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000007ooooo`?o0?l01?l00003
o`3o00So00000ol0o`04o`0000?o0?l02?l00003o`3o08Kooooo001^ooooo`Goo`003_l00003o`3o
0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`04o`0000?o0?l01?l00003o`3o00oo00000ol0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000Oooooo0ol0o`04o`0000?o0?l02?l00003o`3o00Co00000ol0
o`08o`0000?o0?l000?o0000ooooooooool0Poooool006kooooo1Ooo0007o`0000?o0?l02?l00003
o`3o00oo00000ol0o`0;o`0000?o0?l03?l00003o`3o00Oooooo0ol0o`0<o`0000?o0?l01ol00003
o`3o00So00000ol0o`04ooooo`?o0?l000Goooooo`3o0?l0o`3o0?l0ooooo`03o`3o07Cooooo001^
ooooo`Goo`001ol00003o`3o00So00000ol0o`0?o`0000?o0?l02ol00003o`3o00co00000ol0o`07
ooooo`?o0?l03?l00003o`3o00Oo00000ol0o`08o`0000?o0?l01?ooool3o`3o0005o`000?l0o`3o
0?l0o`3o0?ooool00ol0o`1dooooo`00K_ooool5ool000Oo00000ol0o`08o`0000?o0?l03ol00003
o`3o00_o00000ol0o`0<o`0000?o0?l01oooool3o`3o00co00000ol0o`07o`0000?o0?l02?l00003
o`3o0004o`000?ooooooooooooooo`?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0003o`00
0?oooooooooo077ooooo001_ooooo`?oo`0000Co0000o`3o0?l0o`3o0?l02?l00003o`3o00_o0000
0ol0o`001?l0003o0?l0o`3o0?l0o`04o`0000Ko0?l02?l00003o`3o00Co00000ol0o`001Ol0003o
0?l0o`3o0?l0o`3o000000gooooo00Co0000o`3o0?l0o`3o0?l03ol00003o`3o0004o`000?oooooo
ooooo`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00_o00000ol0o`1aooooo`00Looo
ool3o`3o00So00000ol0o`0;o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00006o`3o00So0000
0ol0o`04o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00000>ooooo`?o0?l03ol00003o`3o0004
o`000?ooooooooooo`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l00003o`3o00_o00000ol0o`1a
ooooo`00Loooool3o`3o0003o`000?l0o`3o0?l000Co0?l000Co0000o`3o0?l0o`3o0?l02ol00003
o`3o0004o`000?l0o`3o0?l0o`3o00Co00001_l0o`08o`0000?o0?l01?l00003o`3o0005o`000?l0
o`3o0?l0o`3o0?l000000ol0o`0;ooooo`?o0?l000?o0000o`3o0?l0o`001?l0o`04o`0000?o0?l0
00?o0000o`3o0?l0o`001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l00003o`3o00Co
00000ol0o`000ol0003o0?l0o`3o0004o`3o077ooooo001fooooo`03o`000?l0o`3o0?l000Co0?l0
:?l00003o`3o00co00000ol0o`0>ooooo`03o`000?l0o`3o0?l000Co0?l01?l00003o`3o00Co0000
0ol0o`0<o`0000?o0?l01?l00003o`3o0005o`000?l0o`3o0?l0o`3o0?l00000Loooool007Oooooo
1_l0o`0Xo`0000?o0?l03?l00003o`3o00kooooo00?o0000o`3o0?l0o`001?l0o`04o`0000?o0?l0
1?l00003o`3o00co00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l0M?ooool007gooooo
00?o0000o`3o0?l0o`001?l0o`000ol0003o0?l0o`3o0004o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00001_l0o`0Fo`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00_ooooo0ol0o`0Jo`00
00?o0?l03ol00003o`3o07Cooooo001nooooo`Ko0?l000?oooooo`3o0?l0o`001?l0o`001Ol0003o
0?l0o`3o0?l0o`3ooooo00Ko0?l05_l00003o`3o0005o`000?l0o`3o0?l0o`3o0?ooool00ol0o`0;
ooooo`?o0?l06_l00003o`3o00oo00000ol0o`1dooooo`00O_ooool6o`3o0003ooooool0o`3o0?l0
00Co0?l000Goooooo`3o0?l0o`3o0?l0ooooo`06o`3o01Ko00000ol0o`001Ol0003o0?l0o`3o0?l0
o`3o000000?o0?l000?o0000ooooooooool01oooool01?l0003o0?l0o`3o0?l0o`0Jo`0000?o0?l0
3ol00003o`3o07Cooooo002Cooooo`?o0?l01?l00003o`3o00co00000ol0o`0;o`0000?o0?l01?oo
ool3o`3o00So00000ol0o`08o`0000Ko0?l01Ol00003o`3o00Oo00000ol0o`001Ol0003o0?l0o`3o
0?l0o`3o000007Oooooo002Cooooo`?o0?l01?l00003o`3o00co00000ol0o`0;o`0000?o0?l000Co
0000oooooooooooooooo0ol0o`08o`0000?o0?l02?l00006o`3o00Go00000ol0o`07o`0000?o0?l0
00Co0000o`3o0?l0o`3o0?l0N?ooool009?ooooo0ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o
0?l02?l00003o`3o00Co00000ol0o`000ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co
0?l02?l00003o`3o00So00001_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l00006o`3o
0004ooooool0o`3o0?l0o`3o07Sooooo002Cooooo`?o0?l02?l00003o`3o00So00000ol0o`04o`00
00?o0?l000Co0000o`3o0?l0o`3o0?l01?l00006o`3o00So00000ol0o`08o`0000?o0?l00oooool0
1Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01?l00003o`3o0003o`000?oooooooooo07cooooo002C
ooooo`?o0?l02?l00003o`3o00So00000ol0o`04o`0000?o0?l000Co0000o`3o0?l0o`3o0?l01?l0
0006o`3o00So00000ol0o`08o`0000?o0?l000Co0000oooooooooooo00000ol0o`001?l0003o0?l0
o`3o0?l0o`04o`0000?o0?l0Ooooool009?ooooo0ol0o`0<o`0000?o0?l06Ol00003o`3o0004o`00
0?l0o`3o0?l0o`3o00Co00000ol0o`001?l0003o0?l0o`3o0?l0o`07o`0000?o0?l01Ol00003o`3o
00Co00000ol0o`1oooooo`00Toooool3o`3o00co00000ol0o`0Io`0000?o0?l000Coooooo`3o0?l0
o`3o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Oo00000ol0o`05o`0000?o0?l01?l00003
o`3o07oooooo002Booooo`04o`000?l0o`3o0?l0o`3o00co00000ol0o`0Io`0000?o0?l000Cooooo
o`3o0?l0o`3o0?l01?l00003o`3o0004ooooool0o`3o0?l0o`3o00Oo00000ol0o`05o`0000?o0?l0
1?l00003o`3o07oooooo002@ooooo`?o0?l01ol00003o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0_ooool01Ol0003o0?l0o`3o0?l0o`3o000000?o0?l03ol00003o`3o0003o`000?oooooooooo00Co
oooo00Go0000o`3o0?l0o`3o0?l0o`000005ooooo`04o`000?l0o`3o0?l0o`3o00co00001_l0o`00
0ol0003oooooooooo`20ooooo`00Soooool01?l0003o0?l0o`3o0?l0o`07o`0000?o0?l000Co0000
o`3o0?l0o`3o0?l01?ooool3o`3o0004o`000?l0o`3o0?l0o`3o00oo00000ol0o`08ooooo`?o0?l0
1oooool3o`3o00co00001_l0o`23ooooo`00S?ooool3o`3o0004o`000?l0o`3o0?l0o`3o00Co0000
1_l0o`001?oooooo0?l0o`3o0?l0o`04ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l02?l00006o`3o
0004o`000?l0o`3o0?l0o`3o00Sooooo0ol0o`07ooooo`?o0?l000?o0000o`3o0?l0o`001?l0o`05
o`0000Ko0?l0Poooool008cooooo0ol0o`08o`0000?o0?l000?o0000ooooooooool02?ooool3o`3o
00co00001_l0o`000ol0003oooooooooo`0Fooooo`03o`000?l0o`3o0?l000Co0?l01Ol00003o`3o
08Kooooo002<ooooo`?o0?l02?l00003o`3o00_ooooo0ol0o`0<o`0000Ko0?l06_ooool6o`3o00Go
00000ol0o`26ooooo`00Soooool00ol0003o0?l0o`3o0004o`3o0003o`000?oooooooooo00oooooo
00Co0000o`3o0?l0o`3o0?l02ol00003o`3o023ooooo00Go0000o`3o0?l0o`3o0?l0o`000029oooo
o`00T?ooool6o`3o01?ooooo0ol0o`0;o`0000?o0?l08Oooool3o`3o08[ooooo002@ooooo`Ko0?l0
4oooool3o`3o00_o00000ol0o`0Qooooo`?o0?l0R_ooool00:Wooooo0ol0o`08o`0000?o0?l000?o
0000ooooooooool0[_ooool00:Wooooo0ol0o`08o`0000?o0?l0/Oooool00:Wooooo1_l0o`001Ol0
003o0?l0o`3o0?l0o`3o000000?o0?l0/Oooool00:cooooo0ol0o`001Ol0003o0?l0o`3o0?l0o`3o
00000;Cooooo002/ooooo`?o0?l000Co0000o`3o0?l0o`3o0?l0]Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-43.4875, -33.9754, \
0.348102, 0.468381}}],

Cell[TextData[{
  "Fig. 8.8 Typical tumor growth in the improved Eden model with ",
  Cell[BoxData[
      \(TraditionalForm\`p = 0.4\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2000\)]],
  " steps. Green cells are immune, red cells are on the perimeter where more \
growth can occur."
}], "Caption",
  CellTags->"Fig. 8.8"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["8.3 The Rosenbluth-Teller-Metropolis Monte Carlo Method", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:59", "c:26"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["8.3.1 Theory", "Subsubtitle",
  CellTags->"c:27"],

Cell[TextData[{
  "We have seen that a random walk simulation can bring a system of particles \
to thermal equilibrium, provided that the steps are sufficiently small so \
that the dynamics of the random walk are well approximated by the \
Fokker-Planck equation. This thermal equilibrium state is of great interest, \
particularly for particles that interact with one another. For ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles, we assume that this interaction is described by a potential \
energy function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"U", "(", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["2",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], ",", 
            StyleBox[" ",
              FontWeight->"Bold"], "...", ",", 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["N",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  " is the position of the ",
  Cell[BoxData[
      \(TraditionalForm\`ith\)]],
  " particle, and that this term plus the kinetic energy yields the total \
energy of the system, a constant of the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(-\)\)\)]],
  "particle motion.  According to the principles of statistical mechanics,  \
the thermal equilibrium state of the system is then described by the ",
  StyleBox["Gibbs distribution",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Rho]\_G\), 
            RowBox[{"(", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontSlant->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Bold"], 
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontSlant->"Plain"], 
                    StyleBox["2",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ",", 
                StyleBox[" ",
                  FontWeight->"Bold"], "...", ",", 
                StyleBox[" ",
                  FontWeight->"Bold"], 
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontSlant->"Plain"], 
                    StyleBox["N",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"]}], ")"}]}], "=", 
          RowBox[{\(Z\^\(-1\)\), " ", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"U", "(", 
                      RowBox[{
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontSlant->"Plain"], 
                            StyleBox["1",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"], 
                        StyleBox[",",
                          FontWeight->"Plain"], 
                        StyleBox[" ",
                          FontWeight->"Bold"], 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontSlant->"Plain"], 
                            StyleBox["2",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"], ",", " ", "...", ",", " ", 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontSlant->"Plain"], 
                            StyleBox["N",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"]}], ")"}]}], "/", \(k\_B\)}], 
                "T"}]]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.1)"],

Cell[TextData[{
  " This multivariate probability density is a generalization of the \
Boltzmann distribution, allowing for interacting particles. It determines the \
probability of a given configuration when the system is in thermal \
equilibrium with a heat reservoir (i.e. a much larger system) at fixed \
temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". It is normalized to unity in the usual manner:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"\[Integral]", 
              RowBox[{\(\[Rho]\_G\), 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox["r", 
                        StyleBox["1",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["2",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"], ",", 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox["...",
                      FontWeight->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox[
                      SubscriptBox["r", 
                        StyleBox["N",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"]}], ")"}], 
                RowBox[{"\[DifferentialD]", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "1"]}], 
                RowBox[{"\[DifferentialD]", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "2"]}]}]}], "..."}], " ", 
          RowBox[{"\[DifferentialD]", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["N",
                FontWeight->"Plain"]]}]}], "=", "1"}], 
      TraditionalForm]]]], "UNNEQ"],

Cell[TextData[{
  "which implies that the constant ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"Z", "=", 
          RowBox[{
            RowBox[{
              RowBox[{"\[Integral]", " ", 
                RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"U", "(", 
                            RowBox[{
                              StyleBox[
                                SubscriptBox[
                                  StyleBox["r",
                                    FontSlant->"Plain"], 
                                  StyleBox["1",
                                    FontWeight->"Plain"]],
                                FontWeight->"Bold"], 
                              StyleBox[",",
                                FontWeight->"Plain"], 
                              StyleBox[" ",
                                FontWeight->"Bold"], 
                              StyleBox[
                                SubscriptBox[
                                  StyleBox["r",
                                    FontSlant->"Plain"], 
                                  StyleBox["2",
                                    FontWeight->"Plain"]],
                                FontWeight->"Bold"], ",", "...", ",", " ", 
                              StyleBox[
                                SubscriptBox[
                                  StyleBox["r",
                                    FontSlant->"Plain"], 
                                  StyleBox["N",
                                    FontWeight->"Plain"]],
                                FontWeight->"Bold"]}], ")"}]}], 
                        "/", \(k\_B\)}], "T"}]], 
                  RowBox[{"\[DifferentialD]", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "1"]}], 
                  RowBox[{"\[DifferentialD]", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "2"]}]}]}], "..."}], " ", 
            RowBox[{"\[DifferentialD]", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["N",
                  FontWeight->"Plain"]]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.2)"],

Cell[TextData[{
  "\tIt is best to think of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_G\)]],
  " in terms of an ",
  StyleBox["ensemble",
    FontSlant->"Italic"],
  ", or large group of systems, distributed through ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(3\)  \(N\)\(\ \)\)\)]],
  "-dimensional configuration space ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["2",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], ",", " ", "...", ",", 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["N",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  ". Any one system corresponds to a point in configuration space that \
evolves in time as the particles in the system interact and move.  The \
ensemble of systems corresponds to many points in configuration space, and \
can be represented by a density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "(", 
          RowBox[{
            StyleBox[
              SubscriptBox["r", 
                StyleBox["1",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["2",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], ",", " ", "...", ",", 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox["r", 
                StyleBox["N",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], ")"}], TraditionalForm]]],
  ", the number of points per unit volume in configuration space. This \
density distribution evolves in time until a thermal equilibrium state is \
achieved, distributed according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_G\)]],
  "."
}], "Text",
  CellTags->"i:61"],

Cell[TextData[{
  " \t After equilibrium is achieved, each system in the ensemble fluctuates \
randomly through configuration space, spending a fraction of time in each \
volume element ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "1"]}], 
              RowBox[{"\[DifferentialD]", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"]}]}], "..."}], " ", 
          RowBox[{"\[DifferentialD]", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["N",
                FontWeight->"Plain"]]}]}], TraditionalForm]]],
  " that is equal to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[Rho]\_G\), 
              RowBox[{"\[DifferentialD]", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "1"]}], 
              RowBox[{"\[DifferentialD]", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"]}]}], "..."}], " ", 
          RowBox[{"\[DifferentialD]", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["N",
                FontWeight->"Plain"]]}]}], TraditionalForm]]],
  ". (This is, after all, what defines ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_G\)]],
  "as a probability density).  In equilibrium, the time-averaged value of any \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{
            StyleBox[
              SubscriptBox["r", 
                StyleBox["1",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["2",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], "...", ",", 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[
              SubscriptBox["r", 
                StyleBox["N",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  ", evaluated by averaging in time over the dynamics of one system, is  \
equal to an average over the entire ensemble:"
}], "Text"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "f", "\[RightAngleBracket]"}], " ", "=", 
        RowBox[{\(lim\_\(T \[Rule] \ \[Infinity]\)\), " ", 
          RowBox[{\(\[Integral]\_0\%T\), 
            RowBox[{
              RowBox[{"f", "(", 
                RowBox[{
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["r",
                          FontSlant->"Plain"], 
                        StyleBox["1",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"], 
                    StyleBox["(",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], ",", 
                  StyleBox[" ",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["r",
                          FontSlant->"Plain"], 
                        StyleBox["2",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"], 
                    StyleBox["(",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], ",", " ", "...", ",", 
                  StyleBox[" ",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["r",
                          FontSlant->"Plain"], 
                        StyleBox["N",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"], 
                    StyleBox["(",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}]}], ")"}], \(\[DifferentialD]t/
                T\)}]}]}]}], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"              ", 
        RowBox[{"=", 
          RowBox[{
            RowBox[{
              RowBox[{"\[Integral]", 
                RowBox[{
                  RowBox[{"f", "(", 
                    RowBox[{
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontSlant->"Plain"], 
                          StyleBox["1",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontWeight->"Bold"], 
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], 
                          StyleBox["2",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontWeight->"Plain"], 
                      StyleBox[" ",
                        FontWeight->"Bold"], "...", ",", 
                      StyleBox[" ",
                        FontWeight->"Bold"], 
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontSlant->"Plain"], 
                          StyleBox["N",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"]}], ")"}], 
                  RowBox[{\(\[Rho]\_G\), "(", 
                    RowBox[{
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontSlant->"Plain"], 
                          StyleBox["1",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontWeight->"Bold"], 
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], 
                          StyleBox["2",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontWeight->"Plain"], 
                      StyleBox[" ",
                        FontWeight->"Plain"], 
                      StyleBox["...",
                        FontWeight->"Plain"], 
                      StyleBox[",",
                        FontWeight->"Plain"], 
                      StyleBox[" ",
                        FontWeight->"Bold"], 
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontSlant->"Plain"], 
                          StyleBox["N",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"]}], ")"}], 
                  RowBox[{"\[DifferentialD]", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "1"]}], 
                  RowBox[{"\[DifferentialD]", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "2"]}]}]}], "..."}], " ", 
            RowBox[{"\[DifferentialD]", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[\(\(N\)\(.\)\),
                  FontWeight->"Plain"]]}]}]}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(8.3.3)"],

Cell[TextData[{
  "\t For example, the average potential energy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " of the system of particles can be obtained either by a time average of a \
single system's energy as it fluctuates around thermal equilibrium, or by \
averaging over ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_G\)]],
  ".  Another example of an average quantity is the equilibrium particle \
density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", which is obtained from the probability density that one particle is at \
",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", for any position of the other particles:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"n", "(", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "1"], ")"}], "=", 
          RowBox[{
            RowBox[{
              RowBox[{"N", 
                RowBox[{"\[Integral]", 
                  RowBox[{
                    RowBox[{\(\[Rho]\_G\), "(", 
                      RowBox[{
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], 
                            StyleBox["1",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"], 
                        StyleBox[",",
                          FontWeight->"Plain"], 
                        StyleBox[" ",
                          FontWeight->"Bold"], 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], 
                            StyleBox["2",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"], ",", " ", "...", ",", 
                        StyleBox[" ",
                          FontWeight->"Bold"], 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], 
                            StyleBox["N",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"]}], ")"}], 
                    RowBox[{"\[DifferentialD]", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "2"]}]}]}]}], "..."}], " ", 
            RowBox[{"\[DifferentialD]", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["N",
                  FontWeight->"Plain"]]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.4)"],

Cell["\<\
This function can also be written as a time average over a single \
system:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"n", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", " ", 
          RowBox[{\(lim\_\(T \[Rule] \ \[Infinity]\)\), " ", 
            RowBox[{\(\[Integral]\_0\%T\), 
              RowBox[{"N", " ", 
                RowBox[{"\[Delta]", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "-", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "1"], "(", "t", ")"}]}], 
                  ")"}], \(\[DifferentialD]t/T\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.5)"],

Cell[TextData[{
  "\tFor a system of noninteracting particles in an external potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"U", "=", 
          RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
            RowBox[{"\[Phi]", "(", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "i"], ")"}]}]}], TraditionalForm]]],
  ", the Gibbs distribution separates into a product of single-particle \
distributions, each of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[Phi]\)/k\_B  T\)\)]],
  ".  Then each integration in Eq. ",
  ButtonBox["(8.3.4)",
    ButtonData:>{"Chapter8.nb", "(8.3.4)"},
    ButtonStyle->"Hyperlink"],
  " can be performed separately, and  we return to the Boltzmann result ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"n", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox[\(\[Rho]\_B\),
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\)]],
  " is given by Eq. ",
  ButtonBox["(8.2.25)",
    ButtonData:>{"Chapter8.nb", "(8.2.25)"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\t  For interacting particles, however, it is impossible to evaluate the \
required integrals over ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_G\)]],
  " analytically. Even if we wished to determine the average over a simple \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "1"], ")"}], TraditionalForm]]],
  " of one particle's position, the Gibbs distribution requires us to perform \
",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " integrations over all the particle positions, which becomes intractable \
for ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " larger than a handful of particles. Physically, this difficulty arises \
because particle ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " is correlated with the positions of all the other particles through the \
potential interaction with these particles. While it is possible to  make \
theoretical progress in cases where the interaction between particles is weak \
or short-ranged, in general the integrations cannot be done analytically."
}], "Text"],

Cell[TextData[{
  "\tOn the other hand, it is possible to design a random walk process that \
distributes particles according to the Gibbs distribution. This allows us to \
numerically determine average quantities such as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", by evaluating time averages once the system has achieved thermal \
equilibrium.   The method, first discovered Los Alamos researchers Ariana and \
",
  ButtonBox["Marshall Rosenbluth",
    ButtonData:>{
      URL[ "http://www.aps.org/praw/nicholso/00winner.html"], None},
    ButtonStyle->"Hyperlink"],
  "  along with Augusta and ",
  ButtonBox["Edward Teller",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/biography/Teller.html"], None},
    ButtonStyle->"Hyperlink"],
  ", and Nicholas ",
  ButtonBox["Metropolis",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/biography/Metropolis.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", is one of the most important and widely-used numerical methods in the \
field of statistical physics. (The story goes that the authors searched in \
vain for another physicist named Metropolis, so that the paper could have the \
symmetrical author list Metropolis, Metropolis, Rosenbluth,Rosenbluth, Teller \
and Teller! Metropolis, an early pioneer in Monte Carlo methods and group \
leader at Los Alamos,  is first author on the ",
  ButtonBox["paper",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " that appeared in ",
  StyleBox["J. Chem Phys.",
    FontSlant->"Italic"],
  ", and as a result many people refer to this method as the Metropolis Monte \
Carlo method. However, Marshall Rosenbluth actually invented the algorithm, \
and this is why it is referred to here as the Rosenbluth-Teller-Metropolis \
method.)"
}], "Text",
  CellTags->"i:85"],

Cell[TextData[{
  "\tFirst, some notation. It is convenient to describe the configuration of \
a system by a single vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["{",
              FontWeight->"Plain"], " ", 
            FormBox[
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontSlant->"Plain"], 
                    StyleBox["1",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ",", " ", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"], ",", " ", "...", ",", " ", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["N",
                    FontWeight->"Plain"]]}],
              "TraditionalForm"], "}"}]}], TraditionalForm]]],
  ". This vector describes the state of the entire system. Although the state \
is a continuous function of the positions, it is easier to think of a \
countable set of states by dividing up the configuration space into small ",
  Cell[BoxData[
      \(TraditionalForm\`3  N\)]],
  "- dimensional volume elements ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[DifferentialD]", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". Then integrals over ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " become sums, and we deal with the probability ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "(", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " of a state rather than the probability density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "(", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ", the connection being  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"P", "(", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["\[Rho]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["\[DifferentialD]",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNow consider a general random walk that steps particles between these \
states. At timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " the probability distribution for the particles is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["n",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ".   Let ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w\&_\), "(", 
          RowBox[{
            StyleBox[
              SuperscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["\[Prime]",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " be the probability that a particle makes a step from state ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["z",
              FontSlant->"Plain"], 
            StyleBox["\[Prime]",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " to state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at any given timestep. This transition probability is written in a \
different way than our previous transition probability function ",
  Cell[BoxData[
      \(TraditionalForm\`w(x\^\[Prime], s)\)]],
  " [the analogous function for the multidimensional system is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"w", "(", 
          RowBox[{
            StyleBox[
              SuperscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["\[Prime]",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["s",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["s",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["-",
              FontWeight->"Plain"], 
            StyleBox[
              SuperscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["\[Prime]",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " is the step through configuration space]. The connection between these \
two equivalent forms for the transition probability is"
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["w",
                    FontWeight->"Plain"], "_"],
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ",", 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["w",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["-",
                    FontWeight->"Plain"], 
                  StyleBox[
                    SuperscriptBox[
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["\[Prime]",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.6)"],

Cell[TextData[{
  "For the purposes of our argument here, the notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["w",
                  FontWeight->"Plain"], "_"],
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["\[Prime]",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], ",", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " is more convenient. Of course, such transition probabilities are \
normalized so that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Sum]\+z\), 
          RowBox[{\(w\&_\), "(", 
            RowBox[{
              StyleBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["\[Prime]",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}]}], "=", "1"}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(8.3.7)"],

Cell[TextData[{
  "(That is, in any transition out of state ",
  Cell[BoxData[
      FormBox[
        FormBox[
          StyleBox[
            SuperscriptBox[
              StyleBox["z",
                FontSlant->"Plain"], 
              StyleBox["\[Prime]",
                FontWeight->"Plain"]],
            FontWeight->"Bold"],
          "TraditionalForm"], TraditionalForm]]],
  " the system ends up in ",
  StyleBox["some",
    FontSlant->"Italic"],
  " final state.)"
}], "Text"],

Cell[TextData[{
  "\tWe wish to determine a form for the transition probability ",
  Cell[BoxData[
      \(TraditionalForm\`w\&_\)]],
  " that will cause the system to relax toward thermal equilibrium. The \
master equation for this random walk is, in analogy  to Eq. ",
  ButtonBox["(8.1.33)",
    ButtonData:>{"Chapter8.nb", "(8.1.33)"},
    ButtonStyle->"Hyperlink"],
  ",\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"P", "(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[\(n + 1\),
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{
                StyleBox["P",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["n",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}], "  ", 
              FormBox[
                RowBox[{
                  RowBox[{
                    RowBox[{"+", " ", 
                      SubscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["P",
                              FontSlant->"Italic"]}]], "+"]}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], ",", "n"}], ")"}]}], "-", " ", 
                  
                  RowBox[{
                    SubscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["P",
                            FontSlant->"Italic"]}]], "-"], "(", 
                    RowBox[{
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ",", "n"}], ")"}]}],
                "TraditionalForm"]}]}], ","}], TraditionalForm]]]
}], "Text",
  CellTags->"i:65"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["P",
                  FontSlant->"Italic"]}]], \(+\((-)\)\)], " ", 
          RowBox[{"(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "n"}], ")"}]}], TraditionalForm]]],
  " is the fractional number of particles entering (leaving)  state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". These numbers are determined by ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ". For instance, the fraction entering state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " from all other states ",
  Cell[BoxData[
      FormBox[
        FormBox[
          StyleBox[
            SuperscriptBox[
              StyleBox["z",
                FontSlant->"Plain"], 
              StyleBox["\[Prime]",
                FontWeight->"Plain"]],
            FontWeight->"Bold"],
          "TraditionalForm"], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]], "+"], " ", 
            RowBox[{"(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "n"}], ")"}]}], "=", 
          RowBox[{
            UnderscriptBox["\[Sum]", 
              RowBox[{
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], "\[NotEqual]", "  ", 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]], 
            RowBox[{
              RowBox[{\(w\&_\), "(", 
                RowBox[{
                  StyleBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], ")"}], 
              RowBox[{
                StyleBox["P",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["n",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ", and the fraction leaving state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold"],
  " to all other states ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[
            FormBox[
              StyleBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontSlant->"Plain"], 
                  StyleBox["\[Prime]",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"],
              "TraditionalForm"],
            FontWeight->"Bold"]}], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]], "-"], " ", 
            RowBox[{"(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "n"}], ")"}]}], "=", 
          RowBox[{
            UnderscriptBox["\[Sum]", 
              RowBox[{
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], "\[NotEqual]", " ", 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]], 
            RowBox[{
              RowBox[{\(w\&_\), "(", 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"]}], ")"}], 
              RowBox[{
                StyleBox["P",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["n",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ". Therefore, "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"P", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[\(n + 1\),
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], 
        StyleBox["=",
          FontWeight->"Plain"], 
        RowBox[{
          RowBox[{
            StyleBox["P",
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["n",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], "  ", 
          RowBox[{
            FormBox[
              RowBox[{"+", " ", 
                RowBox[{
                  UnderscriptBox["\[Sum]", 
                    RowBox[{
                      StyleBox[
                        FormBox[
                          StyleBox[
                            SuperscriptBox[
                              StyleBox["z",
                                FontSlant->"Plain"], 
                              StyleBox["\[Prime]",
                                FontWeight->"Plain"]],
                            FontWeight->"Bold"],
                          "TraditionalForm"],
                        FontWeight->"Bold"], "\[NotEqual]", 
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]], 
                  RowBox[{"[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{\(w\&_\), "(", 
                          RowBox[{
                            StyleBox[
                              FormBox[
                                StyleBox[
                                  SuperscriptBox[
                                    StyleBox["z",
                                      FontSlant->"Plain"], 
                                    StyleBox["\[Prime]",
                                      FontWeight->"Plain"]],
                                  FontWeight->"Bold"],
                                "TraditionalForm"],
                              FontWeight->"Bold"], 
                            StyleBox[",",
                              FontWeight->"Plain"], 
                            StyleBox["z",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], ")"}], 
                        RowBox[{
                          StyleBox["P",
                            FontWeight->"Plain"], 
                          StyleBox["(",
                            FontWeight->"Plain"], 
                          RowBox[{
                            FormBox[
                              StyleBox[
                                SuperscriptBox[
                                  StyleBox["z",
                                    FontSlant->"Plain"], 
                                  StyleBox["\[Prime]",
                                    FontWeight->"Plain"]],
                                FontWeight->"Bold"],
                              "TraditionalForm"], 
                            StyleBox[",",
                              FontWeight->"Plain"], 
                            StyleBox["n",
                              FontWeight->"Plain"]}], 
                          StyleBox[")",
                            FontWeight->"Plain"]}]}], "-", " ", 
                      RowBox[{
                        RowBox[{\(w\&_\), "(", 
                          RowBox[{
                            StyleBox["z",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], 
                            StyleBox[",",
                              FontWeight->"Plain"], 
                            StyleBox[
                              FormBox[
                                StyleBox[
                                  SuperscriptBox[
                                    StyleBox["z",
                                      FontSlant->"Plain"], 
                                    StyleBox["\[Prime]",
                                      FontWeight->"Plain"]],
                                  FontWeight->"Bold"],
                                "TraditionalForm"],
                              FontWeight->"Bold"]}], ")"}], 
                        RowBox[{
                          StyleBox["P",
                            FontWeight->"Plain"], 
                          StyleBox["(",
                            FontWeight->"Plain"], 
                          RowBox[{
                            StyleBox["z",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], 
                            StyleBox[",",
                              FontWeight->"Plain"], 
                            StyleBox["n",
                              FontWeight->"Plain"]}], 
                          StyleBox[")",
                            FontWeight->"Plain"]}]}]}], 
                    StyleBox["]",
                      FontWeight->"Plain"]}]}]}],
              "TraditionalForm"], "."}]}]}], TraditionalForm]]]], "NE3",
  CellTags->"(8.3.8)"],

Cell[TextData[{
  " \tAn equilibrium in this process will be achieved when ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"P", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[\(n + 1\),
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["P",
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["n",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". A sufficient condition for equilibrium is that the quantity in the \
square brackets vanishes for every state ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["z", 
            StyleBox["\[Prime]",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " : ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{\(w\&_\), "(", 
                RowBox[{
                  StyleBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], ")"}], 
              RowBox[{
                StyleBox["P",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["n",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], "-", " ", 
            RowBox[{
              RowBox[{\(w\&_\), "(", 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"]}], ")"}], 
              RowBox[{
                StyleBox["P",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["n",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", or in other words,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(w\&_\), "(", 
              RowBox[{
                StyleBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], ")"}], "/", 
            RowBox[{\(w\&_\), "(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  FontWeight->"Bold"]}], ")"}]}], "=", 
          RowBox[{
            RowBox[{"P", "(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "n"}], ")"}], "/", 
            RowBox[{
              StyleBox["P",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["n",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SuperscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["\[Prime]",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "\[NotEqual]", " ", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.9)"],

Cell[TextData[{
  " However, we want a process for which the equilibrium is a thermal \
equilibrium, where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"P", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["n",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["\[DifferentialD]",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox[\(\[Rho]\_G\),
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ". In this case, Eq. ",
  ButtonBox["(8.3.9)",
    ButtonData:>{"Chapter8.nb", "(8.3.9)"},
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(w\&_\), "(", 
              RowBox[{
                StyleBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], ")"}], "/", 
            RowBox[{\(w\&_\), "(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  FontWeight->"Bold"]}], ")"}]}], "=", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]]}], "/", " ", \(k\_B\)}], 
              "T"}]]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SuperscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["\[Prime]",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "\[NotEqual]", " ", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(8.3.10)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], 
          StyleBox["=",
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{"U", "(", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}], "-", 
            RowBox[{"U", "(", 
              StyleBox[
                FormBox[
                  StyleBox[
                    SuperscriptBox[
                      StyleBox["z",
                        FontSlant->"Plain"], 
                      StyleBox["\[Prime]",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                FontWeight->"Bold"], ")"}]}]}], TraditionalForm]]],
  " is the change in potential energy in the transition from ",
  Cell[BoxData[
      FormBox[
        FormBox[
          FormBox[
            StyleBox[
              SuperscriptBox[
                StyleBox["z",
                  FontSlant->"Plain"], 
                StyleBox["\[Prime]",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"],
            "TraditionalForm"],
          "TraditionalForm"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ".  Equation ",
  ButtonBox["(8.3.10)",
    ButtonData:>{"Chapter8.nb", "(8.3.10)"},
    ButtonStyle->"Hyperlink"],
  " is the condition of ",
  StyleBox["detailed balance",
    FontSlant->"Italic"],
  ".  Detailed balance says that if state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " has lower energy than state ",
  Cell[BoxData[
      FormBox[
        FormBox[
          FormBox[
            StyleBox[
              SuperscriptBox[
                StyleBox["z",
                  FontSlant->"Plain"], 
                StyleBox["\[Prime]",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"],
            "TraditionalForm"],
          "TraditionalForm"], TraditionalForm]]],
  ",  (i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], 
          StyleBox["<",
            FontSlant->"Plain"], 
          StyleBox["0",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "), then it is more probable to make a transition from ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox[
            FormBox[
              StyleBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontSlant->"Plain"], 
                  StyleBox["\[Prime]",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"],
              "TraditionalForm"],
            "TraditionalForm"],
          FontWeight->"Bold"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " than vice versa: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(w\&_\), "(", 
            RowBox[{
              StyleBox[
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], ">", 
          RowBox[{\(w\&_\), "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[
                FormBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"]}], ")"}]}], TraditionalForm]]],
  " by the factor ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]]}], "/", " ", \(k\_B\)}], "T"}]],
         TraditionalForm]]],
  "."
}], "Text",
  CellTags->"i:66"],

Cell[TextData[{
  "\t  We will choose a form for the transition probabilities that satisfies \
this condition in order for the system to relax to thermal equilibrium. In \
the Rosenbluth-Teller-Metropolis method, the following choice for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w\&_\), "(", 
          RowBox[{
            StyleBox[
              FormBox[
                StyleBox[
                  FormBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  FontWeight->"Bold"],
                "TraditionalForm"],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  "is made: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(w\&_\), "(", 
            RowBox[{
              StyleBox[
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {
                      RowBox[{" ", 
                        RowBox[{
                          RowBox[{"p", "(", 
                            RowBox[{
                              StyleBox[
                                FormBox[
                                  FormBox[
                                    StyleBox[
                                      SuperscriptBox[
                                        StyleBox["z",
                                        FontSlant->"Plain"], 
                                        StyleBox["\[Prime]",
                                        FontWeight->"Plain"]],
                                      FontWeight->"Bold"],
                                    "TraditionalForm"],
                                  "TraditionalForm"],
                                FontWeight->"Bold"], 
                              StyleBox[",",
                                FontWeight->"Plain"], 
                              StyleBox["z",
                                FontWeight->"Bold",
                                FontSlant->"Plain"]}], ")"}], ","}]}], 
                      RowBox[{
                        RowBox[{
                          StyleBox[
                            RowBox[{"\[CapitalDelta]", 
                              StyleBox["U",
                                FontSlant->"Italic"]}]], "<", "0"}], ","}]},
                    {
                      RowBox[{" ", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"p", "(", 
                              RowBox[{
                                StyleBox[
                                  FormBox[
                                    StyleBox[
                                      FormBox[
                                        FormBox[
                                        StyleBox[
                                        SuperscriptBox[
                                        StyleBox["z",
                                        FontSlant->"Plain"], 
                                        StyleBox["\[Prime]",
                                        FontWeight->"Plain"]],
                                        FontWeight->"Bold"],
                                        "TraditionalForm"],
                                        "TraditionalForm"],
                                      FontWeight->"Bold"],
                                    "TraditionalForm"],
                                  FontWeight->"Bold"], 
                                StyleBox[",",
                                  FontWeight->"Plain"], 
                                StyleBox["z",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"]}], 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox[" ",
                              FontWeight->"Plain"], 
                            StyleBox[
                              SuperscriptBox["\[ExponentialE]", 
                                RowBox[{
                                  RowBox[{
                                    RowBox[{"-", 
                                      StyleBox[
                                        RowBox[{"\[CapitalDelta]", 
                                        StyleBox["U",
                                        FontSlant->"Italic"]}]]}], 
                                    StyleBox["/",
                                      FontSlant->"Plain"], \(k\_B\)}], "T"}]],
                              
                              FontWeight->"Plain"]}], 
                          StyleBox[",",
                            FontWeight->"Bold"]}]}], 
                      RowBox[{
                        RowBox[{
                          StyleBox[
                            RowBox[{"\[CapitalDelta]", 
                              StyleBox["U",
                                FontSlant->"Italic"]}]], "\[GreaterEqual]", 
                          " ", "0"}], ","}]}
                    }],
                ShowAutoStyles->False]}],
            (#&)]}], TraditionalForm]]],
  "       for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FormBox[
              FormBox[
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"],
                "TraditionalForm"],
              "TraditionalForm"],
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["\[NotEqual]",
            FontWeight->"Plain"], " ", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(8.3.11)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", "(", 
          RowBox[{
            StyleBox[
              FormBox[
                FormBox[
                  StyleBox[
                    SuperscriptBox[
                      StyleBox["z",
                        FontSlant->"Plain"], 
                      StyleBox["\[Prime]",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                "TraditionalForm"],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " is any transition probability function that satisfies Eq. ",
  ButtonBox["(8.3.7)",
    ButtonData:>{"Chapter8.nb", "(8.3.7)"},
    ButtonStyle->"Hyperlink"],
  " and is symmetric: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox[
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], "=", 
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ".  Although ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w\&_\), "(", 
          RowBox[{
            FormBox[
              FormBox[
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"],
                "TraditionalForm"],
              "TraditionalForm"], ",", 
            FormBox[
              FormBox[
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"],
                "TraditionalForm"],
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  " is not required in Eqs. ",
  ButtonBox["(8.3.8)",
    ButtonData:>{"Chapter8.nb", "(8.3.8)"},
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(8.3.11)",
    ButtonData:>{"Chapter8.nb", "(8.3.11)"},
    ButtonStyle->"Hyperlink"],
  ", for completeness we note that in order for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w\&_\), "(", 
          RowBox[{
            StyleBox[
              FormBox[
                FormBox[
                  StyleBox[
                    SuperscriptBox[
                      StyleBox["z",
                        FontSlant->"Plain"], 
                      StyleBox["\[Prime]",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                "TraditionalForm"],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " to also satisfy Eq. ",
  ButtonBox["(8.3.7)",
    ButtonData:>{"Chapter8.nb", "(8.3.7)"},
    ButtonStyle->"Hyperlink"],
  ", the probability that no transition is made must be ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(w\&_\), 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"], ",", 
                FormBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  "TraditionalForm"]}], ")"}]}], "=", 
          RowBox[{"1", "-", 
            RowBox[{
              UnderscriptBox["\[Sum]", 
                RowBox[{
                  RowBox[{
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[NotEqual]", " ", 
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"]}], 
                  StyleBox[",",
                    FontWeight->"Plain"], " "}]], 
              RowBox[{\(w\&_\), "(", 
                RowBox[{
                  FormBox[
                    StyleBox[
                      FormBox[
                        FormBox[
                          StyleBox[
                            SuperscriptBox[
                              StyleBox["z",
                                FontSlant->"Plain"], 
                              StyleBox["\[Prime]",
                                FontWeight->"Plain"]],
                            FontWeight->"Bold"],
                          "TraditionalForm"],
                        "TraditionalForm"],
                      FontWeight->"Bold"],
                    "TraditionalForm"], ",", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], ")"}]}]}]}], TraditionalForm]]],
  " . "
}], "Text"],

Cell[TextData[{
  "\tIt takes some thought to understand why Eq. ",
  ButtonBox["(8.3.11)",
    ButtonData:>{"Chapter8.nb", "(8.3.11)"},
    ButtonStyle->"Hyperlink"],
  " recovers detailed balance.  Let's assume for the sake of argument that \
state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold"],
  " has higher energy than state ",
  Cell[BoxData[
      FormBox[
        FormBox[
          StyleBox[
            SuperscriptBox[
              StyleBox["z",
                FontSlant->"Plain"], 
              StyleBox["\[Prime]",
                FontWeight->"Plain"]],
            FontWeight->"Bold"],
          "TraditionalForm"], TraditionalForm]]],
  ". Then in a transition from ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox[
            FormBox[
              StyleBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontSlant->"Plain"], 
                  StyleBox["\[Prime]",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"],
              "TraditionalForm"],
            "TraditionalForm"],
          FontWeight->"Bold"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], ">", "0"}], TraditionalForm]]],
  " and, according to Eq. ",
  ButtonBox["(8.3.11)",
    ButtonData:>{"Chapter8.nb", "(8.3.11)"},
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(w\&_\), "(", 
            RowBox[{
              StyleBox[
                FormBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], "=", 
          RowBox[{
            RowBox[{"p", "(", 
              RowBox[{
                FormBox[
                  FormBox[
                    RowBox[{
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"], ","}],
                    "TraditionalForm"],
                  "TraditionalForm"], 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["U",
                            FontSlant->"Italic"]}]]}], 
                    StyleBox["/",
                      FontSlant->"Plain"], \(k\_B\)}], "T"}]],
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Now consider the reverse process, governed by the transition probability \
",
  Cell[BoxData[
      FormBox[
        RowBox[{\(w\&_\), "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", 
            StyleBox[
              FormBox[
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                "TraditionalForm"],
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  ". In this transition from  ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        FormBox[
          FormBox[
            FormBox[
              StyleBox[
                SuperscriptBox[
                  StyleBox["z",
                    FontSlant->"Plain"], 
                  StyleBox["\[Prime]",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"],
              "TraditionalForm"],
            "TraditionalForm"],
          "TraditionalForm"], TraditionalForm]]],
  ", we have  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["U",
                  FontSlant->"Italic"]}]], "<", "0"}], ","}], 
        TraditionalForm]]],
  " so according to Eq. ",
  ButtonBox["(8.3.11)",
    ButtonData:>{"Chapter8.nb", "(8.3.11)"},
    ButtonStyle->"Hyperlink"],
  " the transition probability is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(w\&_\), "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox[
                FormBox[
                  FormBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["z",
                              FontSlant->"Plain"], 
                            StyleBox["\[Prime]",
                              FontWeight->"Plain"]],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"]}], ")"}], "=", " ", 
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox[
                FormBox[
                  FormBox[
                    FormBox[
                      StyleBox[
                        FormBox[
                          FormBox[
                            FormBox[
                              StyleBox[
                                SuperscriptBox[
                                  StyleBox["z",
                                    FontSlant->"Plain"], 
                                  StyleBox["\[Prime]",
                                    FontWeight->"Plain"]],
                                FontWeight->"Bold"],
                              "TraditionalForm"],
                            "TraditionalForm"],
                          "TraditionalForm"],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"]}], ")"}]}], TraditionalForm]]],
  ". But recall that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox[
                FormBox[
                  FormBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"]}], ")"}], "=", 
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox[
                FormBox[
                  FormBox[
                    FormBox[
                      StyleBox[
                        FormBox[
                          FormBox[
                            FormBox[
                              StyleBox[
                                SuperscriptBox[
                                  StyleBox["z",
                                    FontSlant->"Plain"], 
                                  StyleBox["\[Prime]",
                                    FontWeight->"Plain"]],
                                FontWeight->"Bold"],
                              "TraditionalForm"],
                            "TraditionalForm"],
                          "TraditionalForm"],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", so ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(w\&_\), "(", 
              RowBox[{
                StyleBox[
                  FormBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          FormBox[
                            FormBox[
                              FormBox[
                                StyleBox[
                                  SuperscriptBox[
                                    StyleBox["z",
                                      FontSlant->"Plain"], 
                                    StyleBox["\[Prime]",
                                      FontWeight->"Plain"]],
                                  FontWeight->"Bold"],
                                "TraditionalForm"],
                              "TraditionalForm"],
                            "TraditionalForm"],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], ")"}], "/", 
            RowBox[{\(w\&_\), "(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", 
                StyleBox[
                  FormBox[
                    FormBox[
                      FormBox[
                        StyleBox[
                          FormBox[
                            FormBox[
                              FormBox[
                                StyleBox[
                                  SuperscriptBox[
                                    StyleBox["z",
                                      FontSlant->"Plain"], 
                                    StyleBox["\[Prime]",
                                      FontWeight->"Plain"]],
                                  FontWeight->"Bold"],
                                "TraditionalForm"],
                              "TraditionalForm"],
                            "TraditionalForm"],
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  FontWeight->"Bold"]}], ")"}]}], "=", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]]}], "/", " ", \(k\_B\)}], 
              "T"}]]}], TraditionalForm]]],
  ", as required by detailed balance. "
}], "Text"],

Cell[TextData[{
  "\tTransition probabilities of the form of Eq. ",
  ButtonBox["(8.3.11)",
    ButtonData:>{"Chapter8.nb", "(8.3.11)"},
    ButtonStyle->"Hyperlink"],
  " can be created in a random walk process using the rejection method. \
Starting from state ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox[
            FormBox[
              FormBox[
                FormBox[
                  StyleBox[
                    FormBox[
                      FormBox[
                        FormBox[
                          StyleBox[
                            SuperscriptBox[
                              StyleBox["z",
                                FontSlant->"Plain"], 
                              StyleBox["\[Prime]",
                                FontWeight->"Plain"]],
                            FontWeight->"Bold"],
                          "TraditionalForm"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                "TraditionalForm"],
              "TraditionalForm"],
            "TraditionalForm"],
          FontWeight->"Bold"], TraditionalForm]]],
  ", we move one or more of the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles to  new positions using a random step, so that the system moves \
to the new state ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " with a probability  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", "(", 
          RowBox[{
            StyleBox[
              FormBox[
                FormBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                "TraditionalForm"],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  ".  This random step must be ",
  StyleBox["unbiased, ",
    FontSlant->"Italic"],
  " so that starting from ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " it is equally likely to return back to ",
  Cell[BoxData[
      FormBox[
        FormBox[
          FormBox[
            FormBox[
              FormBox[
                StyleBox[
                  SuperscriptBox[
                    StyleBox["z",
                      FontSlant->"Plain"], 
                    StyleBox["\[Prime]",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"],
                "TraditionalForm"],
              "TraditionalForm"],
            "TraditionalForm"],
          "TraditionalForm"], TraditionalForm]]],
  " . This is what is meant by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox[
                FormBox[
                  FormBox[
                    FormBox[
                      StyleBox[
                        SuperscriptBox[
                          StyleBox["z",
                            FontSlant->"Plain"], 
                          StyleBox["\[Prime]",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], "=", 
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[
                FormBox[
                  FormBox[
                    FormBox[
                      FormBox[
                        FormBox[
                          StyleBox[
                            FormBox[
                              FormBox[
                                FormBox[
                                  StyleBox[
                                    SuperscriptBox[
                                      StyleBox["z",
                                        FontSlant->"Plain"], 
                                      StyleBox["\[Prime]",
                                        FontWeight->"Plain"]],
                                    FontWeight->"Bold"],
                                  "TraditionalForm"],
                                "TraditionalForm"],
                              "TraditionalForm"],
                            FontWeight->"Bold"],
                          "TraditionalForm"],
                        "TraditionalForm"],
                      "TraditionalForm"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " ."
}], "Text"],

Cell[TextData[{
  "\tNow we apply the rejection method to determine whether we will keep the \
new state, or reject it and put the system back into state ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox[
            FormBox[
              FormBox[
                FormBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox[
                        StyleBox["z",
                          FontSlant->"Plain"], 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                "TraditionalForm"],
              "TraditionalForm"],
            "TraditionalForm"],
          FontWeight->"Bold"], TraditionalForm]]],
  " . According to Eq. ",
  ButtonBox["(8.3.11)",
    ButtonData:>{"Chapter8.nb", "(8.3.11)"},
    ButtonStyle->"Hyperlink"],
  ", if  the change of energy in the step is less than zero, we keep the \
step. If  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "\[GreaterEqual]", " ", "0"}], 
        TraditionalForm]]],
  ", however, we only keep the new state ",
  StyleBox["with probability",
    FontSlant->"Italic"],
  "  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]]}], 
                StyleBox["/",
                  FontSlant->"Plain"], \(k\_B\)}], "T"}]],
          FontWeight->"Plain"], TraditionalForm]]],
  ". In other words, if we were to perform this random walk many times, the \
fraction of times that we would keep the new state would be ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]]}], 
                StyleBox["/",
                  FontSlant->"Plain"], \(k\_B\)}], "T"}]],
          FontWeight->"Plain"], TraditionalForm]]],
  ", and the rest of the time we would put the system back into state ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox[
            FormBox[
              FormBox[
                FormBox[
                  FormBox[
                    StyleBox[
                      SuperscriptBox["z", 
                        StyleBox["\[Prime]",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  "TraditionalForm"],
                "TraditionalForm"],
              "TraditionalForm"],
            "TraditionalForm"],
          FontWeight->"Bold"], TraditionalForm]]],
  ".  In order to accomplish this feat, we choose a random real number ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 1\)]],
  ". If ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", "\[LessEqual]", " ", 
          StyleBox[
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["U",
                          FontSlant->"Italic"]}]]}], 
                  StyleBox["/",
                    FontSlant->"Plain"], \(k\_B\)}], "T"}]],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", we keep the new state; otherwise we reject it and put the system back \
into state ",
  Cell[BoxData[
      FormBox[
        FormBox[
          FormBox[
            FormBox[
              FormBox[
                FormBox[
                  StyleBox[
                    SuperscriptBox[
                      StyleBox["z",
                        FontSlant->"Plain"], 
                      StyleBox["\[Prime]",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"],
                  "TraditionalForm"],
                "TraditionalForm"],
              "TraditionalForm"],
            "TraditionalForm"],
          "TraditionalForm"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tOne can see immediately that if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["U",
                  FontSlant->"Italic"]}]], 
            StyleBox["/",
              FontSlant->"Italic"], 
            StyleBox[\(k\_B\),
              FontSlant->"Italic"]}], 
          StyleBox["T",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " is large so that ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]]}], 
                StyleBox["/",
                  FontSlant->"Plain"], \(k\_B\)}], "T"}]],
          FontWeight->"Plain"], TraditionalForm]]],
  " is a very small number, we almost never keep the new state, but if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], 
                StyleBox["/",
                  FontSlant->"Plain"], \(k\_B\)}], "T"}], "<", "1"}], ","}], 
        TraditionalForm]]],
  " so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["U",
                          FontSlant->"Italic"]}]]}], 
                  StyleBox["/",
                    FontSlant->"Plain"], \(k\_B\)}], "T"}]],
            FontWeight->"Plain"], "\[LessTilde]", "1"}], TraditionalForm]]],
  ", we often keep the new state. This allows the energy to fluctuate both up \
and down, with the size of the fluctuations governed by the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ".  If ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is very large, then new states are always accepted and the system \
diffuses randomly from state to state, as is desired for a high-temperature \
system. On the other hand, if ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "  is small, then steps that increase the energy are rejected and only \
steps that decrease the energy are accepted, until the system approaches a \
minimum energy state.  Of course, this is just what is required for thermal \
equilibrium as ",
  Cell[BoxData[
      \(TraditionalForm\`T \[Rule] 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIt is also possible to show that the Rosenbluth-Teller-Metropolis Monte \
Carlo method  causes a system to ",
  StyleBox["approach",
    FontSlant->"Italic"],
  " thermal equilibrium: that is, thermal equilibrium is not just a \
time-independent solution for this random walk process, it is an  ",
  StyleBox["attracting fixed point",
    FontSlant->"Italic"],
  " of the dynamics toward which an ensemble of systems evolves. A general \
argument relying on the ergodicity of the dynamics and on detailed balance \
can be found in the original paper. Here, we content ourselves with a proof \
that assumes that steps between states are sufficiently small so that one can \
Taylor expand Eq. ",
  ButtonBox["(8.3.8)",
    ButtonData:>{"Chapter8.nb", "(8.3.8)"},
    ButtonStyle->"Hyperlink"],
  " in the small difference ",
  Cell[BoxData[
      FormBox[
        StyleBox["s",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " between ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["z", 
            StyleBox["\[Prime]",
              FontWeight->"Plain"]],
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", in order to obtain a generalized Fokker-Planck equation of the form"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              RowBox[{"\[Rho]", "(", 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", "t"}], ")"}]}], "+", 
            RowBox[{
              FractionBox["\[PartialD]", 
                RowBox[{"\[PartialD]", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], "\[CenterDot]", 
              RowBox[{"[", " ", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox["v",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ")"}], " ", "\[Rho]"}], " ", "-",
                   "  ", 
                  RowBox[{
                    RowBox[{
                      StyleBox["D",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ")"}], 
                    "\[CenterDot]", \(\[PartialD]\[Rho]\/\[PartialD]z\)}]}], 
                "]"}]}]}], "=", "0"}], ","}], TraditionalForm]]]], "NE3",
  CellTags->{"i:67", "(8.3.12)"}],

Cell["where ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}], "=", 
            RowBox[{
              RowBox[{"\[Integral]", 
                RowBox[{
                  RowBox[{"w", "(", 
                    RowBox[{
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ",", 
                      StyleBox["s",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}], ")"}], 
                  StyleBox["s",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  RowBox[{
                    RowBox[{"\[DifferentialD]", 
                      StyleBox["s",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}], "/", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}]}]}], "-", 
              RowBox[{
                FractionBox["\[PartialD]", 
                  RowBox[{"\[PartialD]", 
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], "\[CenterDot]", 
                RowBox[{
                  StyleBox["D",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "(", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}]}]}]}]}], TraditionalForm]]],
  " "
}], "UNNEQ"],

Cell["\<\
is a generalized drift velocity of the probability distribution \
through configuration space, and \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["D",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], 
        StyleBox["=",
          FontWeight->"Plain"], 
        RowBox[{"\[Integral]", 
          RowBox[{
            RowBox[{"w", "(", 
              RowBox[{
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", 
                StyleBox["s",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], ")"}], 
            StyleBox["s",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["s",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["s",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", "2"}], 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]]], "UNNEQ"],

Cell[TextData[{
  "is a diffusion tensor. In component form, if ",
  Cell[BoxData[
      FormBox[
        StyleBox["s",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " has components ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  ", this tensor has components "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(D\_\(i\ j\)\), "(", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{"w", "(", 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", 
                  StyleBox["s",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], ")"}], \(s\_i\), " ", \(s\_j\), 
              RowBox[{
                RowBox[{"\[DifferentialD]", 
                  StyleBox["s",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], "/", "2"}], 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "\tJust as for the one-dimensional Fokker-Planck equation, a quantity ",
  Cell[BoxData[
      \(TraditionalForm\`F\_N\)]],
  " can be defined that decreases monotonically until thermal equilibrium \
(the Gibbs distribution) is achieved.  This quantity, the Helmholtz free \
energy for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-particle system,  is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(F\_N\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "U", "\[RightAngleBracket]"}], " ", "-", 
          " ", \(T\ S\_N\)}]}], TraditionalForm]]]], "NE3",
  CellTags->"(8.3.13)"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-particle entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\_N\)]],
  " is given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(S\_N\)(t)\), " ", "=", " ", 
          RowBox[{\(-k\_B\), 
            RowBox[{\(\[Sum]\+z\), 
              RowBox[{
                RowBox[{"\[Rho]", "(", 
                  RowBox[{
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], " ", "ln", " ", 
                RowBox[{"\[Rho]", "(", 
                  RowBox[{
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(8.3.14)"],

Cell[TextData[{
  "The proof that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\_N/\[DifferentialD]t \[LessEqual] \
\ 0\)]],
  ", with equality when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho]\_G\)]],
  ",  follows along the same lines as that required for ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ", and is left as an exercise. Thus, if sufficiently small steps are taken \
in the ",
  "Monte Carlo",
  " method, the probability distribution for the ensemble of systems  \
approaches thermal equilibrium monotonically. "
}], "Text"],

Cell[TextData[{
  "\tAlthough Eq. ",
  ButtonBox["(8.3.12)",
    ButtonData:>{"Chapter8.nb", "(8.3.12)"},
    ButtonStyle->"Hyperlink"],
  " employs the assumption that infinitessimal steps are taken, this is not \
necessary in the numerical procedure. Finite steps can be taken, and the \
method still works to distribute particles in thermal equilibrium. This is a \
big advantage compared to our previous simulation results, shown in Fig. ",
  ButtonBox["8.7",
    ButtonData:>"Fig. 8.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8.3.2 ", "Text"],
  "Simulations "
}], "Subsubtitle",
  CellTags->"c:32"],

Cell[CellGroupData[{

Cell["Example 1: Ideal Gas in Gravity", "Section",
  CellTags->"c:28"],

Cell[CellGroupData[{

Cell["Running the Simulation", "Subsubsection",
  CellTags->"i:68"],

Cell[TextData[{
  "As our first example of the Rosenbluth-Teller-Metropolis method, we return \
to the evaluation of the thermal equilibrium of a collection of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "dust grains in gravity.  We neglect interactions between the grains, \
writing the potential energy  as a simple sum of the potentials for all the \
grains in the gravity well: ",
  Cell[BoxData[
      \(TraditionalForm\`U\  = \ \[Sum]\+\(j = 1\)\%N\ \[Phi](x\_j)\)]],
  ", where  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\  = \ m\ g\ x\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\  = \ \[Infinity]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[LessEqual] \ 0\)]],
  " (i.e., there is a hard wall at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "). "
}], "Text"],

Cell[TextData[{
  "\tBelow, we implement the method by first choosing a random step ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " in the range ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"-", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], "<", "s", "<", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", applied to each particle: ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k\%\(n + 1\) = x\_k\%n + \ s\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(s[]\  := \ \[CapitalDelta]x\ Random[Real, {\(-1\), 1}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.27"],

Cell[TextData[{
  "We then accept or reject this step according to the prescription of the \
Monte Carlo method. That is, we determine the change in potential energy ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["U",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " that arises from moving the particle. We then choose a random number ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 1\)]],
  ". If ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", ">", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]]}], "/", \(k\_B\)}], "T"}]]}], 
        TraditionalForm]]],
  " for some given temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", we reject the step and put the particle back: "
}], "Text"],

Cell[BoxData[
    RowBox[{\(x[k_, n_]\), " ", ":=", 
      RowBox[{\(x[k, n]\), "=", "\[IndentingNewLine]", 
        StyleBox[\( (*\ step\ randomly\ to\ new\ position\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
        RowBox[{"(", 
          
          RowBox[{\(x1\  = \ \ x[k, n - 1]\  + \ s[]\), ";", " ", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ test\ the\ new\ position\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[CapitalDelta]U = \[Phi][x1] - \ \[Phi][
                  x[k, n - 1]]\), ";", 
            "\[IndentingNewLine]", \(nkept[k, n] = 1\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{\(\[CapitalDelta]U > 0\), ",", " ", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(Random[] > \ \ Exp[\(-\[CapitalDelta]U\)/T]\), 
                    ",", "\[IndentingNewLine]", 
                    StyleBox[\( (*\ reject\ the\ step\ *) \),
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[" ",
                      FontColor->RGBColor[1, 0, 0]], 
                    "\[IndentingNewLine]", \(nkept[k, n] = 
                      0; \[IndentingNewLine]x1\  = \ x[k, n - 1];\)}], 
                  "]"}]}], "]"}], ";", "\[IndentingNewLine]", "x1"}], 
          ")"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.28"],

Cell[TextData[{
  "We use two ",
  StyleBox["If",
    FontWeight->"Bold"],
  " statements rather than one because evaluation of exponentials and random \
numbers is time-consuming and is unnecessary if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "<", "0"}], TraditionalForm]]],
  ". In addition, we define a quantity ",
  StyleBox["nkept[j,n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is set equal to zero if the step is rejected, and is set equal to \
unity if the step is accepted. The reason for doing so is that it is a good \
idea to keep track of the fraction of times that steps are accepted. We want \
the fraction of accepted steps to be around 50%.   If it is much smaller than \
this, then the system will not equilibrate very efficiently; rather, it will \
be stuck in the same state for many steps. In this case one should reduce the \
step size  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " so that the energy changes ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["U",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " are not so large.   On the other hand, if the fraction of accepted steps \
is too large, then ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is  too small, and we are taking many steps that could be achieved with a \
single larger step. In this case,  we should increase ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:86"],

Cell[TextData[{
  "\tWe choose some initial distribution for the particles; for instance, all \
particles at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  " :"
}], "Text"],

Cell[BoxData[
    \(\(x[k_, 0]\  = \ 1;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.29"],

Cell["We also define the potential energy for a particle:", "Text"],

Cell[BoxData[{
    \(\(\[Phi][x_]\  := \ m\ g\ x\ \  /; \ x > 0;\)\), "\n", 
    \(\[Phi][x_]\  := \ 10^5\  /; \ x \[LessEqual] \ 0\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.30"],

Cell[TextData[{
  "We then choose ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(g = 1\)\)]],
  " and choose a temperature ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(k\_B\) T = 1/2\)\(,\)\)\)]],
  " and  a step size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.4"}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[BoxData[
    \(m = \(g = 1\); \ T = 1/2; \ \[CapitalDelta]x\  = \ 0.4;\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.31"],

Cell[TextData[{
  "and we evaluate the random walk for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 200\)]],
  " particles over 20 steps:"
}], "Text"],

Cell[BoxData[
    \(\(positions\  = 
        Table[Table[x[k, n], {n, 0, 80}], {k, 1, 200}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.32"],

Cell["\<\
This is not enough steps to give good statistics, but is enough to \
determine the fraction of steps that are accepted:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Statistics`;\)\), "\n", 
    \(Mean[Flatten[Table[nkept[k, n], {n, 1, 20}, {k, 1, 200}]]] // 
      N\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.33"],

Cell[BoxData[
    \(0.7645`\)], "Output"]
}, Open  ]],

Cell["\<\
This is somewhat too large an acceptance rate, so we will increase \
the step size and run 300 steps:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CapitalDelta]x\  = \ 0.8;\)\), "\n", 
    \(\(\(positions\  = 
        Table[Table[x[k, n], {n, 0, 300}], {k, 1, 200}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Mean[Flatten[Table[nkept[k, n], {n, 21, 300}, {k, 1, 200}]]] // 
      N\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.34"],

Cell[BoxData[
    \(0.49278571428571427`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The acceptance rate is now closer to 50%. In Cell ",
  ButtonBox["8.30",
    ButtonData:>"Cell 8.30",
    ButtonStyle->"Hyperlink"],
  ", we display the particle positions over the first 100 steps."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pos[n_]\  := \ 
        Table[positions[\([k, n + 1]\)], {k, 1, 200}];\)\), "\n", 
    \(\(Table[
        ListPlot[pos[n], PlotRange \[Rule] {0, 2}], {n, 0, 100, 
          2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.35"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30902 Mdot
.03333 .30902 Mdot
.0381 .30902 Mdot
.04286 .30902 Mdot
.04762 .30902 Mdot
.05238 .30902 Mdot
.05714 .30902 Mdot
.0619 .30902 Mdot
.06667 .30902 Mdot
.07143 .30902 Mdot
.07619 .30902 Mdot
.08095 .30902 Mdot
.08571 .30902 Mdot
.09048 .30902 Mdot
.09524 .30902 Mdot
.1 .30902 Mdot
.10476 .30902 Mdot
.10952 .30902 Mdot
.11429 .30902 Mdot
.11905 .30902 Mdot
.12381 .30902 Mdot
.12857 .30902 Mdot
.13333 .30902 Mdot
.1381 .30902 Mdot
.14286 .30902 Mdot
.14762 .30902 Mdot
.15238 .30902 Mdot
.15714 .30902 Mdot
.1619 .30902 Mdot
.16667 .30902 Mdot
.17143 .30902 Mdot
.17619 .30902 Mdot
.18095 .30902 Mdot
.18571 .30902 Mdot
.19048 .30902 Mdot
.19524 .30902 Mdot
.2 .30902 Mdot
.20476 .30902 Mdot
.20952 .30902 Mdot
.21429 .30902 Mdot
.21905 .30902 Mdot
.22381 .30902 Mdot
.22857 .30902 Mdot
.23333 .30902 Mdot
.2381 .30902 Mdot
.24286 .30902 Mdot
.24762 .30902 Mdot
.25238 .30902 Mdot
.25714 .30902 Mdot
.2619 .30902 Mdot
.26667 .30902 Mdot
.27143 .30902 Mdot
.27619 .30902 Mdot
.28095 .30902 Mdot
.28571 .30902 Mdot
.29048 .30902 Mdot
.29524 .30902 Mdot
.3 .30902 Mdot
.30476 .30902 Mdot
.30952 .30902 Mdot
.31429 .30902 Mdot
.31905 .30902 Mdot
.32381 .30902 Mdot
.32857 .30902 Mdot
.33333 .30902 Mdot
.3381 .30902 Mdot
.34286 .30902 Mdot
.34762 .30902 Mdot
.35238 .30902 Mdot
.35714 .30902 Mdot
.3619 .30902 Mdot
.36667 .30902 Mdot
.37143 .30902 Mdot
.37619 .30902 Mdot
.38095 .30902 Mdot
.38571 .30902 Mdot
.39048 .30902 Mdot
.39524 .30902 Mdot
.4 .30902 Mdot
.40476 .30902 Mdot
.40952 .30902 Mdot
.41429 .30902 Mdot
.41905 .30902 Mdot
.42381 .30902 Mdot
.42857 .30902 Mdot
.43333 .30902 Mdot
.4381 .30902 Mdot
.44286 .30902 Mdot
.44762 .30902 Mdot
.45238 .30902 Mdot
.45714 .30902 Mdot
.4619 .30902 Mdot
.46667 .30902 Mdot
.47143 .30902 Mdot
.47619 .30902 Mdot
.48095 .30902 Mdot
.48571 .30902 Mdot
.49048 .30902 Mdot
.49524 .30902 Mdot
.5 .30902 Mdot
.50476 .30902 Mdot
.50952 .30902 Mdot
.51429 .30902 Mdot
.51905 .30902 Mdot
.52381 .30902 Mdot
.52857 .30902 Mdot
.53333 .30902 Mdot
.5381 .30902 Mdot
.54286 .30902 Mdot
.54762 .30902 Mdot
.55238 .30902 Mdot
.55714 .30902 Mdot
.5619 .30902 Mdot
.56667 .30902 Mdot
.57143 .30902 Mdot
.57619 .30902 Mdot
.58095 .30902 Mdot
.58571 .30902 Mdot
.59048 .30902 Mdot
.59524 .30902 Mdot
.6 .30902 Mdot
.60476 .30902 Mdot
.60952 .30902 Mdot
.61429 .30902 Mdot
.61905 .30902 Mdot
.62381 .30902 Mdot
.62857 .30902 Mdot
.63333 .30902 Mdot
.6381 .30902 Mdot
.64286 .30902 Mdot
.64762 .30902 Mdot
.65238 .30902 Mdot
.65714 .30902 Mdot
.6619 .30902 Mdot
.66667 .30902 Mdot
.67143 .30902 Mdot
.67619 .30902 Mdot
.68095 .30902 Mdot
.68571 .30902 Mdot
.69048 .30902 Mdot
.69524 .30902 Mdot
.7 .30902 Mdot
.70476 .30902 Mdot
.70952 .30902 Mdot
.71429 .30902 Mdot
.71905 .30902 Mdot
.72381 .30902 Mdot
.72857 .30902 Mdot
.73333 .30902 Mdot
.7381 .30902 Mdot
.74286 .30902 Mdot
.74762 .30902 Mdot
.75238 .30902 Mdot
.75714 .30902 Mdot
.7619 .30902 Mdot
.76667 .30902 Mdot
.77143 .30902 Mdot
.77619 .30902 Mdot
.78095 .30902 Mdot
.78571 .30902 Mdot
.79048 .30902 Mdot
.79524 .30902 Mdot
.8 .30902 Mdot
.80476 .30902 Mdot
.80952 .30902 Mdot
.81429 .30902 Mdot
.81905 .30902 Mdot
.82381 .30902 Mdot
.82857 .30902 Mdot
.83333 .30902 Mdot
.8381 .30902 Mdot
.84286 .30902 Mdot
.84762 .30902 Mdot
.85238 .30902 Mdot
.85714 .30902 Mdot
.8619 .30902 Mdot
.86667 .30902 Mdot
.87143 .30902 Mdot
.87619 .30902 Mdot
.88095 .30902 Mdot
.88571 .30902 Mdot
.89048 .30902 Mdot
.89524 .30902 Mdot
.9 .30902 Mdot
.90476 .30902 Mdot
.90952 .30902 Mdot
.91429 .30902 Mdot
.91905 .30902 Mdot
.92381 .30902 Mdot
.92857 .30902 Mdot
.93333 .30902 Mdot
.9381 .30902 Mdot
.94286 .30902 Mdot
.94762 .30902 Mdot
.95238 .30902 Mdot
.95714 .30902 Mdot
.9619 .30902 Mdot
.96667 .30902 Mdot
.97143 .30902 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00J`3oool01@14A4@000000000000c<c<0gMgM0080oooo00D0k^k^03<c
<`000000<c<c0>k^kP0m0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kP<0
oooo00D0k^k^03<c<`000000<c<c0>k^kP0j0?ooo`@0000000D04A4A0?ooo`3oool0oooo04A4A002
0000000903<c<`3MgMd0oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^03P0oooo1@0000030?ooo`05
0>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo001^0?oo
o`0907MgM`0c<c<0oooo0?ooo`1gMgL0VIVI0?ooo`2IVIT0MgMg03l0oooo00<000000?ooo`3oool0
0P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0l0?oo
o`030000003oool0oooo00H0oooo00T0MgMg03<c<`3oool0oooo07MgM`2IVIT0oooo09VIV@1gMgL0
>03oool01@2IVIT08R8R0>k^kP3oool0A4A400<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool006l0oooo00@000000?ooo`3oool04A4A0`3oool0
0`0A4A40oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A
4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A40?03oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo014A4@<0oooo00<04A4A0?ooo`3oool0=`3oool00`2IVIT08R8R0>k^kP040?ooo`05
014A4@3oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A00D0oooo001^0?oo
o`0507MgM`0c<c<0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
?03oool00`000000oooo0?ooo`060?ooo`0507MgM`0c<c<0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0h0?ooo`0309VIV@0R8R80k^k^00<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000001@3oool006/0oooo00D00000028R8P000000<c<c0<c<c002
0?ooo`050000003oool0oooo0?ooo`000000?`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003`0oooo00<000000?ooo`3o
ool00`3oool01@0000008R8R0000000c<c<0c<c<0080oooo00D000000?ooo`3oool0oooo0000000k
0?ooo`0307MgM`1VIVH0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000001@3oool006/0oooo00<000000?ooo`3oool0103oool01@0A4A40oooo0?oo
o`3oool04A4A03l0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00<0
oooo00D04A4A0?ooo`3oool0oooo014A4@0l0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool01@0A4A40oooo0?ooo`3oool04A4A03`0oooo00D000000?ooo`3oool0oooo014A
4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool00`0A4A40oooo0?ooo`030?ooo`00J`3o
ool00`000000oooo0?ooo`040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0?`3oool00`000000oooo
0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL0>03oool01@000000^k^k0?ooo`2IVIT04A4A00<0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool006/0oooo100000030?ooo`050>k^
kP0c<c<0000003<c<`3^k^h0?@3oool205EEE@030000003oool0oooo0080oooo00D0k^k^03<c<`00
0000<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h0>P3oool205EEE@030000003oool0
oooo00<0oooo100000030?ooo`050>k^kP0c<c<0000003<c<`3^k^h0>03oool01@2IVIT04A4A0000
000R8R80c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c
<`3^k^h01@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool001`0ooooo`000017000000H0oooo000T0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`00903oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool002@0oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`80
0000o`3ooom30?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003o
ool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`00
0000oooo0?ooo`3o0?oood80oooo000T0?ooo`800000o`3ooom30?ooo`00903oool00`000000oooo
0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`80
0000o`3ooom30?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003o
ool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`00
0000oooo0?ooo`3o0?oood80oooo000T0?ooo`800000o`3ooom30?ooo`00903oool00`000000oooo
0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool000060?ooo`3^k^h0
<c<c0000000c<c<0k^k^1@3oool2028R8P@0oooo1@0000040?ooo`0504A4A0000000000003<c<`3M
gMd01@3oool00`000000oooo0?ooo`3o0?oood80oooo00001P3oool0MgMg09VIV@3oool0VIVI07Mg
M`D0oooo0P0R8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01`3oool00`1gMgL0<c<c0?ooo`04
0?ooo`030000003oool0oooo0?l0oooo@P3oool000030?ooo`0A4A40oooo0080oooo00<04A4A0?oo
o`3oool02P3oool00`2IVIT08R8R0>k^kP090?ooo`030000003oool0oooo00<0oooo0`00003o0?oo
od80oooo00000`3oool000000?ooo`020?ooo`030000003oool0oooo00/0oooo00<0VIVI028R8P3^
k^h01`3oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0?l0oooo@P3oool000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool0303oool00`1gMgL0IVIV0?ooo`030?ooo`050000
000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?ooo`3o0?oood80oooo00000`3oool04A4A
0?ooo`020?ooo`03014A4@3oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0oooo@P3oool000060?ooo`1gMgL0VIVI0?ooo`2IVIT0
MgMg2`3oool01@000000^k^k0?ooo`2IVIT04A4A00@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?oood80oooo00001P3oool0k^k^03<c<`000000<c<c0>k^kP/0oooo00D0VIVI
014A4@0000008R8R0<c<c0040?ooo`@000001P3oool200000?l0oooo@`3oool002@0oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`03
0000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903o
ool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`800000o`3ooom30?ooo`00903oool00`00
0000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo
00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T
0?ooo`800000o`3ooom30?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`03
0000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903o
ool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`800000o`3ooom30?ooo`00903oool00`00
0000oooo0?ooo`3o0?oood80oooo00090?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R
8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo0?l0oooo@P3oool0
00T0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`04
0?ooo`030000003oool0oooo0?l0oooo@P3oool000T0oooo00D04A4A0?ooo`3oool0oooo014A4@0@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom20?ooo`002@3oool01@00
0000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool300000?l0oooo@P3oool0
00T0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`01@3o
ool00`000000oooo0?ooo`3o0?oood80oooo00090?ooo`05014A4@3oool0oooo0?ooo`0A4A40303o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo@P3oool000T0oooo00D0MgMg
09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3o
oom20?ooo`002@3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo100000060?ooo`030000003o
ool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo
0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo
0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o
0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003o
ool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo
0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo
0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o
0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool000060?ooo`3^k^h0<c<c0000
000c<c<0k^k^1@3oool2028R8PH0oooo00<000000>k^kP3oool0103oool01@14A4@000000000000c
<c<0gMgM00D0oooo00<000000?ooo`3oool0o`3ooom20?ooo`0000H0oooo07MgM`2IVIT0oooo09VI
V@1gMgL50?ooo`808R8R1P3oool00`1EEED0ZZZZ0?ooo`070?ooo`0307MgM`0c<c<0oooo00@0oooo
00<000000?ooo`3oool0o`3ooom20?ooo`0000<0oooo014A4@3oool00P3oool00`0A4A40oooo0?oo
o`0;0?ooo`030:ZZZP1EEED0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?oood80oooo00000`3oool000000?ooo`020?ooo`030000003oool0oooo00`0oooo00<04A4A
0?ooo`3oool01P3oool00`1gMgL0<c<c0?ooo`040?ooo`<00000o`3ooom20?ooo`0000<0oooo0000
003oool00P3oool00`000000oooo0?ooo`0<0?ooo`0305EEE@3<c<`0oooo00<0oooo00D00000028R
8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0?l0oooo@P3oool000030?ooo`0A4A40oooo
0080oooo00<04A4A0?ooo`3oool0303oool00`2ZZZX0MgMg0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooom20?ooo`0000H0oooo07MgM`2IVIT0oooo09VIV@1gMgL;
0?ooo`05014A4@3oool0oooo0?ooo`0c<c<0103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0oooo@P3oool000060?ooo`3^k^h0<c<c0000000c<c<0k^k^2`3oool5000000@0oooo
100000060?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo
@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80
oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo
@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
01X0oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo@P3oool001`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood80oooo000L0?ooo`030000
003oool0oooo00D0ooooo`00000g000000h0oooo000L0?ooo`030000003oool0oooo00D0ooooo`00
000g000000h0oooo000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`00703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo@P3oool001`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood80oooo000J0?ooo`80EEEE
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`800000o`3o
oom30?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo
0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo
0?ooo`3o0?oood80oooo000T0?ooo`800000o`3ooom30?ooo`00903oool00`000000oooo0?ooo`3o
0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`800000o`3o
oom30?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo
0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo
0?ooo`3o0?oood80oooo000T0?ooo`800000o`3ooom30?ooo`00903oool00`000000oooo0?ooo`3o
0?oood80oooo00020?ooo`@0000000<04A4A0?ooo`3oool00P3oool2028R8P@0oooo1@0000040?oo
o`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`3o0?oood80oooo00040?oo
o`030000003oool0oooo00@0oooo0P0R8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01`3oool0
0`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0?l0oooo@P3oool000@0oooo00<000000?oo
o`3oool02`3oool00`2IVIT08R8R0>k^kP090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3ooom20?ooo`00103oool00`000000oooo0?ooo`0<0?ooo`0309VIV@0R8R80k^k^00L0
oooo00<0MgMg03<c<`3oool0103oool300000?l0oooo@P3oool000@0oooo00<000000?ooo`3oool0
3@3oool00`1gMgL0IVIV0?ooo`030?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000
oooo0?ooo`3o0?oood80oooo00040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo@P3oool000@0oooo00<0
00000?ooo`3oool02P3oool01@000000^k^k0?ooo`2IVIT04A4A00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3o0?oood80oooo00020?ooo`80EEEE00<000000?ooo`3oool02P3o
ool01@2IVIT04A4A0000000R8R80c<c<00@0oooo100000060?ooo`030000003oool0oooo0?l0oooo
@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80
oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo
@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80
oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool000X0oooo100000000`0A4A40oooo0?ooo`020?oo
o`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`00303oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?oo
o`030000003oool0oooo0?l0oooo@P3oool000`0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo@P3oool000`0oooo00<000000?ooo`3oool0
3P3oool00`1gMgL0<c<c0?ooo`040?ooo`<00000o`3ooom20?ooo`00303oool00`000000oooo0?oo
o`0;0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?ooo`3o0?oood80oooo
000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?oood80oooo000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oood80oooo000:0?ooo`80EEEE00<000000?ooo`3oool02`3oool40000
00H0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool200000?l0oooo@`3oool002@0oooo
00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool200000?l0oooo@`3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903o
ool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool200000?l0oooo@`3oool002@0oooo
00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool200000?l0oooo@`3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`000P3o
ool400000003014A4@3oool0oooo0080oooo0P0R8R860?ooo`030000003^k^h0oooo00@0oooo00D0
A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo0?l0oooo@P3oool000@0oooo00<0
00000?ooo`3oool0103oool2028R8PH0oooo00<0EEEE0:ZZZP3oool01`3oool00`1gMgL0<c<c0?oo
o`040?ooo`030000003oool0oooo0?l0oooo@P3oool000@0oooo00<000000?ooo`3oool0303oool0
0`2ZZZX0EEEE0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`00103oool00`000000oooo0?ooo`0=0?ooo`03014A4@3oool0oooo00H0oooo00<0MgMg03<c
<`3oool0103oool300000?l0oooo@P3oool000@0oooo00<000000?ooo`3oool03@3oool00`1EEED0
c<c<0?ooo`030?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?ooo`3o0?oo
od80oooo00040?ooo`030000003oool0oooo00d0oooo00<0ZZZZ07MgM`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo@P3oool000@0oooo00<000000?ooo`3oool0
2P3oool01@0A4A40oooo0?ooo`3oool0<c<c00@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3o0?oood80oooo00020?ooo`80EEEE00<000000?ooo`3oool02P3oool5000000@0oooo
100000060?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo
@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
02@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00903oool00`000000oooo0?ooo`3o0?oood80
oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo0P00003o0?oood<0oooo000T
0?ooo`030000003oool0oooo0?l0oooo@P3oool002@0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`00903oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo0?l0oooo
@P3oool002@0oooo0P00003o0?oood<0oooo000T0?ooo`030000003oool0oooo0?l0oooo@P3oool0
01T0oooo1@0000060?ooo`030000003oool0oooo0?l0oooo@P3oool001T0oooo00D0VIVI028R8P3^
k^h0oooo04A4A0060?ooo`030000003oool0oooo0?l0oooo@P3oool001X0oooo00<0VIVI028R8P3^
k^h01`3oool00`000000oooo0?ooo`3o0?oood80oooo000K0?ooo`0309VIV@0R8R80k^k^00H0oooo
0`00003o0?oood80oooo000L0?ooo`0307MgM`1VIVH0oooo0?l0ooooBP3oool001d0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`006@3oool01@000000^k^k0?ooo`2IVIT04A4A0?l0ooooB`3oool0
01T0oooo00D0VIVI014A4@0000008R8R0<c<c03o0?oood/0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30917 Mdot
.03333 .38943 Mdot
.0381 .3737 Mdot
.04286 .3652 Mdot
.04762 .36147 Mdot
.05238 .35894 Mdot
.05714 .40092 Mdot
.0619 .22908 Mdot
.06667 .25474 Mdot
.07143 .39252 Mdot
.07619 .21244 Mdot
.08095 .39394 Mdot
.08571 .23391 Mdot
.09048 .25356 Mdot
.09524 .32483 Mdot
.1 .31892 Mdot
.10476 .1642 Mdot
.10952 .39304 Mdot
.11429 .42468 Mdot
.11905 .19383 Mdot
.12381 .36713 Mdot
.12857 .28335 Mdot
.13333 .09527 Mdot
.1381 .10789 Mdot
.14286 .34227 Mdot
.14762 .26249 Mdot
.15238 .2537 Mdot
.15714 .30452 Mdot
.1619 .25243 Mdot
.16667 .26934 Mdot
.17143 .2358 Mdot
.17619 .34718 Mdot
.18095 .3365 Mdot
.18571 .30523 Mdot
.19048 .26439 Mdot
.19524 .26096 Mdot
.2 .14895 Mdot
.20476 .15174 Mdot
.20952 .19974 Mdot
.21429 .26551 Mdot
.21905 .33555 Mdot
.22381 .30154 Mdot
.22857 .34331 Mdot
.23333 .32355 Mdot
.2381 .2015 Mdot
.24286 .30635 Mdot
.24762 .343 Mdot
.25238 .38726 Mdot
.25714 .20317 Mdot
.2619 .16883 Mdot
.26667 .29039 Mdot
.27143 .27122 Mdot
.27619 .16837 Mdot
.28095 .32131 Mdot
.28571 .28576 Mdot
.29048 .35063 Mdot
.29524 .22883 Mdot
.3 .26071 Mdot
.30476 .20236 Mdot
.30952 .20475 Mdot
.31429 .26133 Mdot
.31905 .19917 Mdot
.32381 .22121 Mdot
.32857 .32165 Mdot
.33333 .17211 Mdot
.3381 .31943 Mdot
.34286 .28345 Mdot
.34762 .12318 Mdot
.35238 .36705 Mdot
.35714 .24936 Mdot
.3619 .32329 Mdot
.36667 .29919 Mdot
.37143 .45047 Mdot
.37619 .38314 Mdot
.38095 .39755 Mdot
.38571 .30738 Mdot
.39048 .30902 Mdot
.39524 .26198 Mdot
.4 .23075 Mdot
.40476 .2321 Mdot
.40952 .2258 Mdot
.41429 .20124 Mdot
.41905 .46746 Mdot
.42381 .33789 Mdot
.42857 .24727 Mdot
.43333 .29686 Mdot
.4381 .30902 Mdot
.44286 .3949 Mdot
.44762 .40889 Mdot
.45238 .20869 Mdot
.45714 .12773 Mdot
.4619 .19166 Mdot
.46667 .30902 Mdot
.47143 .25147 Mdot
.47619 .16524 Mdot
.48095 .34723 Mdot
.48571 .40607 Mdot
.49048 .23151 Mdot
.49524 .21903 Mdot
.5 .0997 Mdot
.50476 .27999 Mdot
.50952 .47716 Mdot
.51429 .26544 Mdot
.51905 .24367 Mdot
.52381 .32771 Mdot
.52857 .25486 Mdot
.53333 .31779 Mdot
.5381 .27214 Mdot
.54286 .30902 Mdot
.54762 .20394 Mdot
.55238 .38203 Mdot
.55714 .2544 Mdot
.5619 .23616 Mdot
.56667 .3098 Mdot
.57143 .22378 Mdot
.57619 .1687 Mdot
.58095 .2596 Mdot
.58571 .25248 Mdot
.59048 .11195 Mdot
.59524 .1648 Mdot
.6 .16303 Mdot
.60476 .28695 Mdot
.60952 .4373 Mdot
.61429 .22047 Mdot
.61905 .34631 Mdot
.62381 .19991 Mdot
.62857 .27584 Mdot
.63333 .18421 Mdot
.6381 .50866 Mdot
.64286 .10926 Mdot
.64762 .38849 Mdot
.65238 .48482 Mdot
.65714 .21493 Mdot
.6619 .30008 Mdot
.66667 .30913 Mdot
.67143 .28692 Mdot
.67619 .21864 Mdot
.68095 .22733 Mdot
.68571 .15224 Mdot
.69048 .26446 Mdot
.69524 .36168 Mdot
.7 .30037 Mdot
.70476 .36651 Mdot
.70952 .3707 Mdot
.71429 .35295 Mdot
.71905 .27105 Mdot
.72381 .27987 Mdot
.72857 .37894 Mdot
.73333 .29403 Mdot
.7381 .40484 Mdot
.74286 .2556 Mdot
.74762 .35894 Mdot
.75238 .29328 Mdot
.75714 .15011 Mdot
.7619 .37088 Mdot
.76667 .42501 Mdot
.77143 .11705 Mdot
.77619 .11524 Mdot
.78095 .26154 Mdot
.78571 .13582 Mdot
.79048 .24343 Mdot
.79524 .30588 Mdot
.8 .4096 Mdot
.80476 .12862 Mdot
.80952 .23661 Mdot
.81429 .22027 Mdot
.81905 .1968 Mdot
.82381 .25441 Mdot
.82857 .2179 Mdot
.83333 .17472 Mdot
.8381 .32338 Mdot
.84286 .22502 Mdot
.84762 .19278 Mdot
.85238 .19372 Mdot
.85714 .40443 Mdot
.8619 .37269 Mdot
.86667 .36051 Mdot
.87143 .34213 Mdot
.87619 .10937 Mdot
.88095 .28889 Mdot
.88571 .28392 Mdot
.89048 .25555 Mdot
.89524 .1273 Mdot
.9 .37918 Mdot
.90476 .33138 Mdot
.90952 .17829 Mdot
.91429 .38212 Mdot
.91905 .33269 Mdot
.92381 .2569 Mdot
.92857 .17316 Mdot
.93333 .33466 Mdot
.9381 .12983 Mdot
.94286 .39941 Mdot
.94762 .16654 Mdot
.95238 .2013 Mdot
.95714 .20312 Mdot
.9619 .23521 Mdot
.96667 .19276 Mdot
.97143 .2151 Mdot
.97619 .40304 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom2ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo@_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom2ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`0P
ooooo`;o0000oooooolPooooo`009?ooool00ol0003oooooooooo`0Pooooo`;o0000oooooolPoooo
o`009?ooool00ol0003oooooooooo`2Gooooo`;o0000Z?ooool002Cooooo00?o0000ooooooooool0
Uoooool2o`000:Sooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0003ooooooaoooooo000T
ooooo`;o00008_ooool2o`00097ooooo0_l0000?ooooo`;o0000B_ooool2o`0002kooooo000Toooo
o`03o`000?oooooooooo0;Cooooo0_l0000?ooooo`;o0000B_ooool2o`0002kooooo000Tooooo`03
o`000?oooooooooo0>oooooo0ol0001?ooooo`009?ooool00ol0003oooooooooo`3_ooooo`?o0000
Coooool002Cooooo00?o0000ooooooooool0IOooool2o`000=[ooooo000Tooooo`;o0000I_ooool2
o`000;3ooooo0_l0000Xooooo`009?ooool00ol0003oooooooooo`29ooooo`;o0000K_ooool2o`00
01cooooo0_l0000<ooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0ROooool2o`0006ko
oooo0_l0000Zooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0loooool2o`0004cooooo
000Tooooo`03o`000?oooooooooo0??ooooo0_l0001<ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0e
ooooo`;o0000ooooool;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=Oooool4o`000;7ooooo0_l0001E
ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0gooooo`;o0000V_ooool2o`0001Gooooo0_l0001Eooooo`002Oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`000=?ooooo0_l0001/
ooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Wooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool2o`0009oooooo0_l0
0028ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`;o0000Moooool2o`0002Gooooo0ol0001_ooooo`;o00005ooo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooooooo
o`19ooooo`;o00000oooool2o`0003oooooo0_l0000Nooooo`;o00001Oooool2o`00073ooooo0_l0
000Gooooo`009?ooool2o`0004[ooooo0_l00003ooooo`;o00004Oooool2o`0004cooooo0_l0001a
ooooo`;o00007Oooool002Cooooo00?o0000ooooooooool0HOooool2o`000:3ooooo0_l0000Moooo
o`;o00007Oooool002Cooooo00?o0000ooooooooool0ooooool4ooooo`;o00005_ooool2o`0002Co
oooo000Tooooo`03o`000?oooooooooo0?oooooo7?ooool2o`0002Cooooo000Tooooo`03o`000?oo
oooooooo0<;ooooo0_l0001mooooo`009?ooool2o`000<?ooooo0_l0001mooooo`009?ooool00ol0
003oooooooooo`2:ooooo`;o0000]Oooool002Cooooo00?o0000ooooooooool06oooool2o`0006go
oooo0_l0001kooooo`Co00008oooool2o`00017ooooo000Tooooo`03o`000?oooooooooo01_ooooo
0_l0003Qooooo`;o00001oooool4o`0002?ooooo0_l0000Aooooo`009?ooool00ol0003ooooooooo
o`0hooooo`;o00008_ooool2o`0001gooooo0_l00012ooooo`;o0000?Oooool2o`0002Wooooo0_l0
000Fooooo`009?ooool2o`0003Wooooo0_l00008ooooo`;o00001?ooool2o`0000gooooo0_l00003
ooooo`;o00007Oooool2o`0002Wooooo0_l0000Gooooo`;o0000J?ooool4o`0001Cooooo000Toooo
o`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o00003Oooool4o`0004_ooooo0_l00023oooo
o`;o00005?ooool002Cooooo00?o0000ooooooooool0FOooool2o`0002cooooo0_l0002hooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`;o0000N?ooool2o`000;Sooooo000Tooooo`03o`000?oo
oooooooo00gooooo0_l0002kooooo`;o0000I?ooool2o`0000oooooo000Tooooo`;o0000U_ooool2
o`0003?ooooo0_l00004ooooo`;o0000;oooool2o`0002gooooo0_l0000?ooooo`009?ooool00ol0
003oooooooooo`1Nooooo`;o0000=Oooool2o`0002Gooooo0_l0000Booooo`;o0000:oooool2o`00
00;ooooo0_l0000nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`1Nooooo`;o00006Oooool2o`0003?ooooo0_l0000<ooooo`;o0000?oooool2o`0000Oooooo0_l0
000iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`0004Wooooo
0_l0000Sooooo`;o0000<oooool2o`00027ooooo0_l0000cooooo`;o0000>Oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool2o`0004Wooooo0_l0000Pooooo`Co00006_oo
ool2o`0003_ooooo0_l0001^ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00013ooooo0_l0001T
ooooo`Co00006_ooool2o`0009Kooooo0_l0000Cooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo013ooooo0_l0000Jooooo`;o0000OOooool2o`0004kooooo0_l0000_
ooooo`;o00004oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool2o`00
07gooooo0_l0001>ooooo`;o0000A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2Mooooo`;o0000E_ooool2o`0004[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`1oooooo`;o00007?ooool2o`0005Kooooo
0_l0001:ooooo`009?ooool2o`0006Wooooo0_l0000Eooooo`;o0000`?ooool002Cooooo00?o0000
ooooooooool04_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000mooooo`;o00008oooool2
o`0002?ooooo0_l0002=ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`00
01;ooooo0_l000000ooooooo0000o`00001Rooooo`;o00004Oooool2o`0000Oooooo0_l00007oooo
o`;o0000<Oooool2o`0001Wooooo0_l0000Cooooo`;o00002Oooool2o`0001oooooo000Tooooo`03
o`000?oooooooooo00[ooooo0_l0002Dooooo`;o00001oooool2o`0000Kooooo0_l0000booooo`;o
00006Oooool2o`0001?ooooo0_l00009ooooo`;o00007oooool002Cooooo00?o0000ooooooooool0
9?ooool2o`0000kooooo0_l0000Pooooo`;o00000_ooool2o`0001Wooooo0_l0000jooooo`;o0000
?oooool2o`0004gooooo000Tooooo`;o00009Oooool2o`0000cooooo1?l00004ooooo`;o00006_oo
ool2o`0000;ooooo0_l0000Iooooo`;o00009?ooool2o`0003Oooooo0_l0000Looooo`;o0000COoo
ool002Cooooo00?o0000ooooooooool0<_ooool2o`0000Kooooo0_l0001Oooooo`;o0000=oooool2
o`0006_ooooo000Tooooo`03o`000?oooooooooo02_ooooo0_l0000Pooooo`;o0000E?ooool2o`00
03Wooooo0_l0001Qooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o00008?ooool2o`0005Co
oooo0_l0000iooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0`?ooool2o`0007oooooo
000Tooooo`;o0000VOooool2o`0002Kooooo0_l0000Mooooo`;o0000H?ooool002Cooooo00?o0000
ooooooooool07_ooool2o`0004Cooooo0_l0000booooo`;o0000AOooool2o`0003?ooooo0_l0000[
ooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000<Oooool2o`00017ooooo0_l0001Coooo
o`;o00004oooool2o`0004Cooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`1;ooooo`;o
00001?ooool2o`0006Kooooo0_l0000Cooooo`;o0000@_ooool2o`0002gooooo000Tooooo`03o`00
0?oooooooooo04_ooooo0_l0002Looooo`;o00009oooool2o`0002gooooo000Tooooo`;o0000P_oo
ool2o`0005oooooo0_l00005ooooo`;o0000E_ooool002Cooooo00?o0000ooooooooool0Joooool2
o`0001Cooooo0_l0001Oooooo`;o0000GOooool001[ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo03gooooo0_l0000/ooooo`;o0000G_ooool2o`0000_ooooo0_l0001Woooo
o`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o
00002_ooool2o`0008cooooo0_l0000;ooooo`;o00007?ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo00Gooooo0ol0000Wooooo`;o00002?ooool2o`00013ooooo0_l0000]ooooo`?o0000
3_ooool2o`0000Oooooo0_l0000Gooooo`;o00009_ooool2o`0002Oooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`?o0000@oooool2o`0002gooooo0ol0000>ooooo`;o00001ooo
ool2o`0001Oooooo0_l00005ooooo`;o00007oooool2o`0007;ooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0[?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0XOooool2o`0009kooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05Oooool2o`0003Wooooo0_l0000=ooooo`;o000000?oooooo`000?l0
0000?Oooool2o`0009kooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
5Oooool2o`0002Wooooo0_l0000>ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo
0_l0002Hooooo`;o0000>oooool002Cooooo0_l0000Dooooo`;o0000:oooool2o`0002Sooooo0_l0
000booooo`;o0000I?ooool2o`0003_ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l00029
ooooo`;o0000XOooool002Cooooo00?o0000ooooooooool0oooooolKooooo`;o00000oooool2o`00
023ooooo000Tooooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o0000g?ooool2o`0000?o
oooo0_l00002ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0;oooool2o`0000_ooooo
0_l00010ooooo`;o0000Xoooool2o`0001cooooo000Tooooo`;o00009?ooool2o`00023ooooo0_l0
000gooooo`;o0000Soooool2o`00033ooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0000J
ooooo`;o00001?ooool2o`0007Kooooo0_l0001@ooooo`;o0000<?ooool002Cooooo00?o0000oooo
ooooool0;_ooool2o`0000oooooo0_l0001?ooooo`;o0000:oooool2o`0008;ooooo000Tooooo`03
o`000?oooooooooo02kooooo0_l0000Sooooo`;o0000>oooool2o`000:oooooo000Tooooo`03o`00
0?oooooooooo05?ooooo0_l00027ooooo`;o0000Hoooool002Cooooo0_l0003Mooooo`;o0000Hooo
ool002Cooooo00?o0000ooooooooool01?ooool3o`000<oooooo0_l0000?ooooo`;o00009Oooool2
o`00037ooooo000Tooooo`03o`000?oooooooooo00Cooooo0ol0003?ooooo`;o00003oooool2o`00
02Gooooo0_l0000aooooo`009?ooool00ol0003oooooooooo`02ooooo`;o00006Oooool2o`0004So
oooo0_l0001`ooooo`;o0000I_ooool002Cooooo00?o0000ooooooooool00_ooool2o`0001Wooooo
0_l00018ooooo`;o0000L?ooool4o`0000oooooo0_l0001Cooooo`009?ooool2o`0000;ooooo0_l0
003Hooooo`;o00003oooool2o`0001kooooo0_l0000cooooo`009?ooool01?l0003ooooooooooooo
ool2o`000?oooooo2_ooool2o`0003?ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3Qooooo`;o0000=Oooool2o`0002Oooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo06kooooo0_l0000hooooo`;o0000=oooool2o`0003Gooooo0_l00003ooooo`;o00008_oo
ool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0K_ooool2o`0003Sooooo0_l0001cooooo`;o00008_ooool0
00Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo1?l00015ooooo`;o0000Ooooool2o`0007Sooooo0004ooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooo
ool0003o00002oooool2o`0003Sooooo0_l0001oooooo`;o0000N?ooool000Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool2o`000003ooooool0003o000000Oooooo0_l0001Zooooo`;o0000^oooool000Co
oooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`;o00001oooool2o`0005Kooooo0_l0000Boooo
o`;o0000^oooool000;ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo00Oooooo0_l0001Wooooo`;o0000]?ooool2o`00
01Wooooo000Tooooo`;o00002?ooool2o`000=_ooooo0_l0000Tooooo`;o00006_ooool2o`0000Wo
oooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`2Booooo`;o0000D?ooool2o`0002Cooooo
0_l0000Uooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0Q_ooool2o`0000[ooooo0_l0
001Tooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0Q_ooool2o`00073ooooo0_l00017
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo01[ooooo0_l0
003Aooooo`;o0000D_ooool002Cooooo00?o0000ooooooooool06_ooool2o`000=7ooooo0_l0001B
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`2jooooo`;o0000QOooool002Cooooo00?o0000ooooooooool0^_oo
ool2o`0008Gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`0006kooooo0_l0003Booooo`009?ooool00ol0003ooooo
ooooo`1]ooooo`;o0000d_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1looooo`;o0000`oooool000co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07co
oooo0_l00033ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_oo
ool00ol0003oooooooooo`2Jooooo`;o0000YOooool002Cooooo0_l0002Kooooo`;o0000YOooool0
02Cooooo00?o0000ooooooooool0b?ooool2o`0007Oooooo000Tooooo`03o`000?oooooooooo0<So
oooo0_l0001gooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0<?ooooo0_l0001looooo`009?ooool2
o`000<Cooooo0_l0001looooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`00
1?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_oo
ool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_oo
ool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000Koooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo0?oo
ooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[Zjoooo
oonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33099 Mdot
.03333 .30652 Mdot
.0381 .48438 Mdot
.04286 .29588 Mdot
.04762 .32017 Mdot
.05238 .53391 Mdot
.05714 .36956 Mdot
.0619 .13012 Mdot
.06667 .29419 Mdot
.07143 .46113 Mdot
.07619 .20796 Mdot
.08095 .24986 Mdot
.08571 .28623 Mdot
.09048 .13962 Mdot
.09524 .23431 Mdot
.1 .20306 Mdot
.10476 .04746 Mdot
.10952 .20965 Mdot
.11429 .5444 Mdot
.11905 .20236 Mdot
.12381 .34125 Mdot
.12857 .33203 Mdot
.13333 .00938 Mdot
.1381 .02534 Mdot
.14286 .24334 Mdot
.14762 .23315 Mdot
.15238 .21696 Mdot
.15714 .20101 Mdot
.1619 .17983 Mdot
.16667 .39361 Mdot
.17143 .25101 Mdot
.17619 .28767 Mdot
.18095 .31379 Mdot
.18571 .26155 Mdot
.19048 .24962 Mdot
.19524 .33513 Mdot
.2 .0438 Mdot
.20476 .18452 Mdot
.20952 .23747 Mdot
.21429 .16103 Mdot
.21905 .36761 Mdot
.22381 .27932 Mdot
.22857 .29625 Mdot
.23333 .42726 Mdot
.2381 .1943 Mdot
.24286 .1884 Mdot
.24762 .18841 Mdot
.25238 .42598 Mdot
.25714 .09516 Mdot
.2619 .07906 Mdot
.26667 .18811 Mdot
.27143 .14163 Mdot
.27619 .20417 Mdot
.28095 .41687 Mdot
.28571 .26969 Mdot
.29048 .33069 Mdot
.29524 .30107 Mdot
.3 .22491 Mdot
.30476 .09093 Mdot
.30952 .13559 Mdot
.31429 .17985 Mdot
.31905 .21179 Mdot
.32381 .15428 Mdot
.32857 .23492 Mdot
.33333 .04625 Mdot
.3381 .17289 Mdot
.34286 .16075 Mdot
.34762 .06836 Mdot
.35238 .39663 Mdot
.35714 .39379 Mdot
.3619 .2665 Mdot
.36667 .3114 Mdot
.37143 .58199 Mdot
.37619 .51658 Mdot
.38095 .25504 Mdot
.38571 .33093 Mdot
.39048 .50402 Mdot
.39524 .11885 Mdot
.4 .27664 Mdot
.40476 .11702 Mdot
.40952 .11778 Mdot
.41429 .20892 Mdot
.41905 .41473 Mdot
.42381 .40279 Mdot
.42857 .05711 Mdot
.43333 .38966 Mdot
.4381 .28805 Mdot
.44286 .38543 Mdot
.44762 .37352 Mdot
.45238 .24838 Mdot
.45714 .17704 Mdot
.4619 .24183 Mdot
.46667 .32642 Mdot
.47143 .37287 Mdot
.47619 .31606 Mdot
.48095 .3957 Mdot
.48571 .34033 Mdot
.49048 .26744 Mdot
.49524 .31459 Mdot
.5 .16411 Mdot
.50476 .30982 Mdot
.50952 .47716 Mdot
.51429 .33658 Mdot
.51905 .38517 Mdot
.52381 .24101 Mdot
.52857 .05891 Mdot
.53333 .43969 Mdot
.5381 .15559 Mdot
.54286 .35975 Mdot
.54762 .18983 Mdot
.55238 .47695 Mdot
.55714 .1431 Mdot
.5619 .15637 Mdot
.56667 .41934 Mdot
.57143 .34095 Mdot
.57619 .25655 Mdot
.58095 .34116 Mdot
.58571 .21888 Mdot
.59048 .15455 Mdot
.59524 .12333 Mdot
.6 .05138 Mdot
.60476 .3761 Mdot
.60952 .39421 Mdot
.61429 .25375 Mdot
.61905 .41562 Mdot
.62381 .20777 Mdot
.62857 .23606 Mdot
.63333 .08231 Mdot
.6381 .59509 Mdot
.64286 .1553 Mdot
.64762 .32744 Mdot
.65238 .37974 Mdot
.65714 .12545 Mdot
.6619 .21174 Mdot
.66667 .3547 Mdot
.67143 .1449 Mdot
.67619 .10865 Mdot
.68095 .09038 Mdot
.68571 .10645 Mdot
.69048 .24816 Mdot
.69524 .22121 Mdot
.7 .31182 Mdot
.70476 .30306 Mdot
.70952 .23418 Mdot
.71429 .44255 Mdot
.71905 .12848 Mdot
.72381 .21269 Mdot
.72857 .29073 Mdot
.73333 .38191 Mdot
.7381 .54537 Mdot
.74286 .07404 Mdot
.74762 .27508 Mdot
.75238 .3134 Mdot
.75714 .08162 Mdot
.7619 .41655 Mdot
.76667 .30402 Mdot
.77143 .10151 Mdot
.77619 .14503 Mdot
.78095 .25272 Mdot
.78571 .01943 Mdot
.79048 .26056 Mdot
.79524 .29586 Mdot
.8 .38269 Mdot
.80476 .02896 Mdot
.80952 .16689 Mdot
.81429 .16363 Mdot
.81905 .08521 Mdot
.82381 .27348 Mdot
.82857 .19523 Mdot
.83333 .11144 Mdot
.8381 .26733 Mdot
.84286 .24402 Mdot
.84762 .12995 Mdot
.85238 .09907 Mdot
.85714 .20995 Mdot
.8619 .34173 Mdot
.86667 .27737 Mdot
.87143 .44309 Mdot
.87619 .25484 Mdot
.88095 .28514 Mdot
.88571 .29634 Mdot
.89048 .43276 Mdot
.89524 .02522 Mdot
.9 .37644 Mdot
.90476 .29657 Mdot
.90952 .05089 Mdot
.91429 .45251 Mdot
.91905 .15558 Mdot
.92381 .09042 Mdot
.92857 .16471 Mdot
.93333 .33466 Mdot
.9381 .12048 Mdot
.94286 .42708 Mdot
.94762 .30775 Mdot
.95238 .10783 Mdot
.95714 .15518 Mdot
.9619 .22186 Mdot
.96667 .13818 Mdot
.97143 .13094 Mdot
.97619 .18863 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0P
ooooo`;o0000oooooolPooooo`009?ooool00ol0003oooooooooo`0Pooooo`;o0000oooooolPoooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0loooool2o`0004cooooo
000Tooooo`03o`000?oooooooooo0??ooooo0_l0001<ooooo`009?ooool00ol0003oooooooooo`0Q
ooooo`;o0000m?ooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0003doooo
o`;o0000:?ooool002Cooooo0_l0003jooooo`;o0000A_ooool002Cooooo00?o0000ooooooooool0
nOooool2o`0004Kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0eooooo`;o0000ooooool;oooo
o`009?ooool2o`0003Kooooo0_l0000Zooooo`;o0000g_ooool002Cooooo00?o0000ooooooooool0
5_ooool2o`0004Wooooo0_l0003Nooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000Wooo
ool2o`0006;ooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`2gooooo`;o0000H_ooool2
o`0002Cooooo000Tooooo`03o`000?oooooooooo07oooooo0_l0000Oooooo`;o0000Woooool002Co
oooo0_l00020ooooo`;o00007oooool2o`0009oooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0IOooool2o`000=[ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0IOooool2o`000=[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0>Gooooo0_l0001Jooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
0>Gooooo0_l0001Jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`19ooooo`;o
0000m_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`19ooooo`;o
0000Moooool2o`0002Kooooo0_l0001Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`32ooooo`;o00009_ooool2o`0001;ooooo0_l00011ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0=7ooooo0_l0000[ooooo`;o0000@Oooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000F?oo
ool2o`0007Sooooo0_l0001=ooooo`;o00007oooool002Cooooo00?o0000ooooooooool0B?ooool2
o`0000gooooo0_l00037ooooo`;o00007oooool002Cooooo00?o0000ooooooooool0B?ooool2o`00
0;oooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`3_ooooo`;o00006?ooool2o`0003Ko
oooo000Tooooo`03o`000?oooooooooo0>oooooo0_l0001@ooooo`009?ooool00ol0003ooooooooo
o`3@ooooo`;o000000?oooooo`000?l00000E?ooool2o`0001Kooooo000Tooooo`;o0000dOooool2
o`000003ooooool0003o000002kooooo0_l0000Tooooo`;o00005_ooool002Cooooo00?o0000oooo
ooooool0ooooool4ooooo`;o0000??ooool002Cooooo00?o0000ooooooooool0N?ooool3o`000<Ko
oooo000Tooooo`03o`000?oooooooooo07Gooooo0_l000001?oooooo0000o`000?l0002Zooooo`;o
00006_ooool002Cooooo00?o0000ooooooooool0MOooool2o`0003oooooo0_l0001]ooooo`;o0000
6_ooool002Cooooo0_l0002gooooo`;o00004_ooool2o`0007Gooooo000Tooooo`03o`000?oooooo
oooo00Wooooo0_l0002oooooo`;o00004_ooool2o`0002Oooooo0_l0000hooooo`009?ooool00ol0
003oooooooooo`09ooooo`;o0000doooool2o`0002Oooooo0_l0000Wooooo`;o00003oooool002Co
oooo00?o0000ooooooooool0FOooool2o`000=Gooooo0_l0000?ooooo`009?ooool00ol0003ooooo
ooooo`0Booooo`;o0000AOooool2o`000=?ooooo0_l0000Aooooo`009?ooool2o`0001?ooooo0_l0
000iooooo`;o0000goooool2o`00017ooooo000Tooooo`03o`000?oooooooooo04gooooo0_l0001J
ooooo`;o00008oooool2o`00023ooooo0_l0001?ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2Yooooo`;o00008oooool2o`00023ooooo0_l0001?ooooo`002Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom2ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Nooooo`;o0000E?ooool2o`0008_ooooo0009ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000G_ooool2o`0004?ooooo0_l0
0006ooooo`;o00001oooool2o`0000oooooo0_l0001Hooooo`;o00002_ooool2o`0001Cooooo0009
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0>_ooool2o`0002Sooooo0_l0000mooooo`;o00001_ooool2o`0001Sooooo
0_l0001Hooooo`;o00002_ooool2o`0001Cooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03[ooooo0_l0000Xooooo`;o0000
<Oooool2o`0006Cooooo0_l00012ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2Gooooo`;o0000H_ooool4o`0002?ooooo
0_l0000Mooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`00
0?oooooooooo0?_ooooo0_l0000Uooooo`;o00007Oooool002Cooooo0_l0001Sooooo`;o0000gOoo
ool002Cooooo00?o0000ooooooooool0H_ooool2o`000=gooooo000Tooooo`03o`000?oooooooooo
08Wooooo0_l0002fooooo`009?ooool00ol0003oooooooooo`0Yooooo`;o0000;oooool2o`0002go
oooo0_l0002fooooo`009?ooool00ol0003oooooooooo`0Yooooo`;o00003?ooool2o`00027ooooo
0_l0003Uooooo`009?ooool2o`0003Sooooo0_l0000:ooooo`Co00001?ooool2o`000>Cooooo0_l0
000>ooooo`009?ooool00ol0003oooooooooo`13ooooo`Co00001?ooool2o`0005Wooooo0_l00029
ooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0@_ooool2o`0006;ooooo0_l0001Ioooo
o`;o0000?_ooool002Cooooo00?o0000ooooooooool0@_ooool2o`000;gooooo0_l0000nooooo`00
9?ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolIooooo`009?ooool2o`0001Kooooo0_l0
0004ooooo`;o00002_ooool2o`0002Gooooo0_l0003aooooo`009?ooool00ol0003oooooooooo`0E
ooooo`;o00001?ooool2o`00037ooooo0_l0003aooooo`009?ooool00ol0003oooooooooo`0=oooo
o`;o00002Oooool2o`00067ooooo0_l00012ooooo`;o0000BOooool2o`0003Gooooo000Tooooo`03
o`000?oooooooooo00gooooo0_l00009ooooo`;o0000@_ooool2o`0001gooooo0_l00012ooooo`;o
00002_ooool2o`0001;ooooo0_l0000Yooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0
G?ooool2o`0006gooooo0_l0000Booooo`;o0000H?ooool002Cooooo0_l0000Wooooo`;o0000R_oo
ool2o`0008gooooo000Tooooo`03o`000?oooooooooo02Kooooo0_l0002:ooooo`;o00008_ooool2
o`0005Cooooo0_l0000Cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`1Fooooo`;o0000O_ooool2o`0005Cooooo0_l0000Cooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0E_ooool2o`000>Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Cooooo`;o00003ooo
ool2o`0003Wooooo0_l0001jooooo`;o0000I?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Cooooo`;o00003oooool2o`0001;ooooo0_l0000Uooooo`;o0000Gooo
ool2o`0001Wooooo0_l0001Tooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0h
ooooo`;o0000I?ooool2o`00023ooooo0_l0001oooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02?ooooo0_l0001Uooooo`;o00004_ooool2o`0006Kooooo0_l0000iooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool08oooool2o`0006Gooooo0_l0001jooooo`;o0000>Oooool002Cooooo0_l0000@ooooo`;o0000
8Oooool2o`0005?ooooo0_l0001;ooooo`;o0000Joooool002Cooooo00?o0000ooooooooool03ooo
ool2o`0001_ooooo0_l00004ooooo`;o0000Doooool2o`0003?ooooo0_l0000Fooooo`;o00007?oo
ool2o`0004gooooo000Tooooo`03o`000?oooooooooo02cooooo0_l00012ooooo`;o0000?Oooool2
o`0000_ooooo0_l0000dooooo`;o00007Oooool2o`0002kooooo000Tooooo`03o`000?oooooooooo
073ooooo0_l0000mooooo`;o0000H?ooool2o`0002kooooo000Tooooo`03o`000?oooooooooo037o
oooo0_l00032ooooo`;o0000B_ooool002Cooooo0_l0000booooo`;o0000`_ooool2o`0004[ooooo
000Tooooo`03o`000?oooooooooo06[ooooo0_l0000Xooooo`;o0000K_ooool2o`0003_ooooo000T
ooooo`03o`000?oooooooooo057ooooo0_l0000Gooooo`;o0000:?ooool2o`0006kooooo0_l0000k
ooooo`009?ooool00ol0003oooooooooo`1Aooooo`;o0000U?ooool2o`0001Oooooo0_l0000ooooo
o`009?ooool00ol0003oooooooooo`1fooooo`;o0000Koooool2o`0001Oooooo0_l0000<ooooo`;o
0000<Oooool002Cooooo0_l0000nooooo`;o0000=oooool2o`0009Kooooo0_l0000aooooo`009?oo
ool00ol0003oooooooooo`0mooooo`;o0000ooooool3ooooo`009?ooool00ol0003oooooooooo`0@
ooooo`;o00007?ooool2o`000>;ooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`0@oooo
o`;o00007?ooool2o`0005?ooooo0_l0001Looooo`;o0000;oooool2o`0002gooooo000Tooooo`03
o`000?oooooooooo08?ooooo0_l0001Looooo`;o0000G_ooool002Cooooo0_l00003ooooo`;o0000
1_ooool2o`0003?ooooo0_l0002eooooo`;o00007?ooool2o`0000Cooooo0_l0000Uooooo`009?oo
ool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`0003?ooooo0_l0002eooooo`;o00007?oo
ool2o`0000Cooooo0_l0000Uooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0E?ooool2o`0008?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05Cooooo0_l00023ooooo`;o00004_ooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo00Gooooo00Co0000ooooool0003o0000k?ooool2o`0003Wooooo0_l0000Goooo
o`007?ooool00ol0003oooooooooo`05ooooo`Co0000J_ooool2o`0002_ooooo0_l0000nooooo`;o
0000C_ooool2o`0001Oooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;oooool2o`0003[ooooo0_l0000Xooooo`;o000000?oooooo`000?l00000?_ooool2o`0000oooooo
0_l0001Fooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0
001Nooooo`;o00001?ooool2o`0005;ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00029ooooo`;o0000/?ooool001[ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`04ooooo`;o0000oooooollooooo`009?ooool2o`0008go
oooo0_l0000iooooo`;o0000N?ooool002Cooooo00?o0000ooooooooool0Doooool2o`0003Oooooo
0_l0000iooooo`;o0000N?ooool002Cooooo0ol0000Nooooo`;o0000<oooool2o`0001gooooo0_l0
003=ooooo`009?ooool3o`0001kooooo0_l0000Dooooo`;o0000??ooool2o`0002Oooooo0_l00026
ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0=?ooool2o`0006Gooooo0_l00026oooo
o`;o00007?ooool002Cooooo0_l0000Nooooo`;o0000Loooool2o`0001[ooooo0_l000000ooooooo
0000o`00001Iooooo`;o0000<oooool002Cooooo00?o0000ooooooooool07Oooool2o`0007?ooooo
0_l0000Jooooo`;o000000?oooooo`000?l00000FOooool2o`0003?ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3=ooooo`;o0000L_ooool002Cooooo0_l0003>ooooo`;o0000L_ooool002Cooooo
00?o0000ooooooooool0YOooool2o`0009[ooooo000Tooooo`03o`000?oooooooooo0:Gooooo0_l0
002Jooooo`009?ooool00ol0003oooooooooo`0looooo`;o0000ooooool4ooooo`009?ooool00ol0
003oooooooooo`07ooooo`;o0000<oooool2o`000?oooooo1?ooool002Cooooo0_l00008ooooo`;o
0000OOooool2o`0000Gooooo0_l0002booooo`009?ooool00ol0003oooooooooo`26ooooo`;o0000
1Oooool2o`0002[ooooo0_l0001Mooooo`;o00009oooool000;ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;Wooooo0_l0000=ooooo`;o0000C_ooool2o`0002Oooooo0004ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0<Sooooo0_l0000Hooooo`;o00005?ooool2o`0004Oooooo
0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo08Cooooo0_l0000Gooooo`;o0000@oooool2o`0001Cooooo0_l0
0017ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0008Cooooo0_l0000Gooooo`;o0000X_ooool000Cooooo00?o0000oooo
ooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`21ooooo`;o0000__ooool000Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool2o`00
03_ooooo0_l0000Gooooo`;o0000=oooool2o`0008Gooooo0004ooooo`03o`000?oooooooooo00[o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:oooool2o`0003[ooooo0ol0000Vooooo`;o0000:?ooool2o`0008Gooooo0002ooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`1Wooooo`;o00009oooool2o`000:oooooo000Tooooo`;o0000Ooooool2o`000<7o
oooo000Tooooo`03o`000?oooooooooo07kooooo0_l00031ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0D?ooool2o`0002[ooooo0_l0000oooooo`;o0000;Oooool2o`0005?ooooo000Tooooo`;o
0000DOooool2o`0002[ooooo0_l0000^ooooo`;o00003oooool2o`0002gooooo0_l0001Cooooo`00
9?ooool00ol0003oooooooooo`2/ooooo`;o0000Toooool002Cooooo00?o0000ooooooooool0A_oo
ool2o`000?Wooooo000Tooooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o0000g_ooool2
o`0001Wooooo000Tooooo`03o`000?oooooooooo043ooooo0_l0003Tooooo`;o00006Oooool002Co
oooo0_l0003ooooooaOooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`3ooooooaKooooo
0_l0000Zooooo`009?ooool00ol0003oooooooooo`2Qooooo`;o0000W_ooool002Cooooo00?o0000
ooooooooool0XOooool2o`0003Wooooo0_l0000aooooo`;o0000<?ooool002Cooooo00?o0000oooo
ooooool0g?ooool2o`00037ooooo0_l0000`ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooolNooooo`;o00008_ooool000[ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolNooooo`;o00008_ooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o0000oooooold
ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000<oooo
o`;o0000ooooooldooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo
000:ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo09[ooooo0_l0
000<ooooo`;o0000Uoooool002Cooooo0_l0002Kooooo`;o00003?ooool2o`0009Oooooo000Toooo
o`04o`000?ooooooooooooooo`;o0000ooooooloooooo`009?ooool01?l0003oooooooooooooool2
o`000?oooooo?oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0Loooool2o`000<cooooo000Tooooo`03o`000?oooooooooo07?ooooo0_l0003<ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`1^ooooo`;o0000dOooool002Cooooo00?o0000ooooooooool0K_ooool2o`00
0=7ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`05ooooo`;o0000oooooolkooooo`001?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool01Oooool2o`000?oooooo>oooool000Cooooo00?o0000ooooooooool03?ooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2oooo
o`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Jooooo`;o
0000b?ooool2o`0005_ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo0_l00038ooooo`;o0000
Foooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmV
IVKo000000cooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0KOooool2o`000=;ooooo000Tooooo`03o`000?oooooooooo06gooooo0_l0
003Booooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`33ooooo`;o0000O?ooool002Cooooo00?o0000ooooooooool0
`oooool2o`0007cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003o
oooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000L
ooooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9oooo
o`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30959 Mdot
.03333 .3785 Mdot
.0381 .27743 Mdot
.04286 .24061 Mdot
.04762 .43183 Mdot
.05238 .39965 Mdot
.05714 .39747 Mdot
.0619 .13012 Mdot
.06667 .28798 Mdot
.07143 .41882 Mdot
.07619 .20796 Mdot
.08095 .24986 Mdot
.08571 .31912 Mdot
.09048 .27909 Mdot
.09524 .15557 Mdot
.1 .07659 Mdot
.10476 .04746 Mdot
.10952 .20108 Mdot
.11429 .54448 Mdot
.11905 .00896 Mdot
.12381 .26721 Mdot
.12857 .12141 Mdot
.13333 .00938 Mdot
.1381 .07387 Mdot
.14286 .1166 Mdot
.14762 .0424 Mdot
.15238 .23472 Mdot
.15714 .25505 Mdot
.1619 .1834 Mdot
.16667 .39361 Mdot
.17143 .21902 Mdot
.17619 .17424 Mdot
.18095 .3589 Mdot
.18571 .30219 Mdot
.19048 .213 Mdot
.19524 .21577 Mdot
.2 .0438 Mdot
.20476 .27566 Mdot
.20952 .26502 Mdot
.21429 .04458 Mdot
.21905 .44049 Mdot
.22381 .19308 Mdot
.22857 .3438 Mdot
.23333 .33255 Mdot
.2381 .11616 Mdot
.24286 .22161 Mdot
.24762 .26087 Mdot
.25238 .41304 Mdot
.25714 .02807 Mdot
.2619 .03873 Mdot
.26667 .18455 Mdot
.27143 .10682 Mdot
.27619 .22453 Mdot
.28095 .41687 Mdot
.28571 .13653 Mdot
.29048 .1247 Mdot
.29524 .18778 Mdot
.3 .17903 Mdot
.30476 .09093 Mdot
.30952 .16717 Mdot
.31429 .33905 Mdot
.31905 .09151 Mdot
.32381 .09812 Mdot
.32857 .16723 Mdot
.33333 .10738 Mdot
.3381 .12593 Mdot
.34286 .23535 Mdot
.34762 .06836 Mdot
.35238 .46381 Mdot
.35714 .34781 Mdot
.3619 .21237 Mdot
.36667 .50774 Mdot
.37619 .43598 Mdot
.38095 .23347 Mdot
.38571 .26406 Mdot
.39524 .10762 Mdot
.4 .07715 Mdot
.40476 .00035 Mdot
.40952 .05014 Mdot
.41429 .25061 Mdot
.41905 .5877 Mdot
.42381 .29523 Mdot
.42857 .058 Mdot
.43333 .35217 Mdot
.4381 .35029 Mdot
.44286 .35005 Mdot
.44762 .43628 Mdot
.45238 .12183 Mdot
.45714 .2788 Mdot
.4619 .21032 Mdot
.46667 .30284 Mdot
.47143 .24747 Mdot
.47619 .31606 Mdot
.48095 .20038 Mdot
.48571 .20525 Mdot
.49048 .22418 Mdot
.49524 .3876 Mdot
.5 .16411 Mdot
.50476 .17984 Mdot
.50952 .3921 Mdot
.51429 .25937 Mdot
.51905 .33025 Mdot
.52381 .16749 Mdot
.52857 .18406 Mdot
.53333 .43916 Mdot
.5381 .19389 Mdot
.54286 .37165 Mdot
.54762 .17671 Mdot
.55238 .43531 Mdot
.55714 .02463 Mdot
.5619 .03603 Mdot
.56667 .45201 Mdot
.57143 .34095 Mdot
.57619 .14231 Mdot
.58095 .26902 Mdot
.58571 .06857 Mdot
.59048 .13276 Mdot
.59524 .02962 Mdot
.6 .05138 Mdot
.60476 .51317 Mdot
.60952 .44253 Mdot
.61429 .11626 Mdot
.61905 .27795 Mdot
.62381 .15022 Mdot
.62857 .32209 Mdot
.63333 .04063 Mdot
.64286 .20343 Mdot
.64762 .24759 Mdot
.65238 .23633 Mdot
.65714 .11548 Mdot
.6619 .04336 Mdot
.66667 .29099 Mdot
.67143 .03386 Mdot
.67619 .10363 Mdot
.68095 .04638 Mdot
.68571 .07165 Mdot
.69048 .31385 Mdot
.69524 .18188 Mdot
.7 .30105 Mdot
.70476 .13795 Mdot
.70952 .24223 Mdot
.71429 .23117 Mdot
.71905 .20698 Mdot
.72381 .20336 Mdot
.72857 .25069 Mdot
.73333 .41702 Mdot
.74286 .1825 Mdot
.74762 .27672 Mdot
.75238 .45871 Mdot
.75714 .13098 Mdot
.7619 .36029 Mdot
.76667 .33631 Mdot
.77143 .10151 Mdot
.77619 .14503 Mdot
.78095 .33672 Mdot
.78571 .04943 Mdot
.79048 .40402 Mdot
.79524 .20647 Mdot
.8 .26509 Mdot
.80476 .06847 Mdot
.80952 .25372 Mdot
.81429 .15269 Mdot
.81905 .06032 Mdot
.82381 .27348 Mdot
.82857 .11954 Mdot
.83333 .08789 Mdot
.8381 .2375 Mdot
.84286 .33511 Mdot
.84762 .00774 Mdot
.85238 .06104 Mdot
.85714 .18476 Mdot
.8619 .31139 Mdot
.86667 .20657 Mdot
.87143 .36882 Mdot
.87619 .28789 Mdot
.88095 .30061 Mdot
.88571 .37113 Mdot
.89048 .42187 Mdot
.89524 .08753 Mdot
.9 .56725 Mdot
.90476 .22204 Mdot
.90952 .0522 Mdot
.91429 .56035 Mdot
.91905 .15558 Mdot
.92381 .16313 Mdot
.92857 .07092 Mdot
.93333 .2675 Mdot
.9381 .02614 Mdot
.94286 .36638 Mdot
.94762 .27571 Mdot
.95238 .17046 Mdot
.95714 .11616 Mdot
.9619 .19476 Mdot
.96667 .13818 Mdot
.97143 .01526 Mdot
.97619 .3046 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo01_ooooo0_l00003
ooooo`;o0000iOooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo01_ooooo0_l00003oooo
o`;o0000iOooool2o`0003Sooooo000Tooooo`;o0000oooooolbooooo`;o00003oooool002Cooooo
00?o0000ooooooooool0oooooolaooooo`;o00003oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`2Yooooo`;o0000U_ooool002Cooooo00?o0000oooo
ooooool0B?ooool2o`0005oooooo0_l0001jooooo`;o00006_ooool002Cooooo0_l00019ooooo`;o
0000K?ooool2o`0006gooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`2fooooo`;o0000
5_ooool2o`00077ooooo000Tooooo`03o`000?oooooooooo0:_ooooo0_l0000Qooooo`;o0000LOoo
ool002Cooooo00?o0000ooooooooool0BOooool2o`00063ooooo0_l0000Eooooo`;o0000OOooool0
02Cooooo00?o0000ooooooooool09?ooool2o`0000oooooo0_l0000Booooo`;o0000Moooool2o`00
00Oooooo0_l0001dooooo`009?ooool2o`0002Gooooo0_l0000?ooooo`;o00000oooool2o`0008oo
oooo0_l00004ooooo`;o0000K_ooool002Cooooo00?o0000ooooooooool05_ooool2o`0002;ooooo
0_l0000mooooo`;o0000E_ooool2o`00023ooooo0_l0001<ooooo`009?ooool00ol0003ooooooooo
o`0Fooooo`;o0000HOooool2o`0003cooooo0_l0000jooooo`;o00009_ooool2o`0002Cooooo000T
ooooo`03o`000?oooooooooo0;Oooooo0_l0001Rooooo`;o00009?ooool002Cooooo00?o0000oooo
ooooool0Ooooool2o`000<3ooooo000Tooooo`;o0000P?ooool2o`0007gooooo0_l00009ooooo`;o
0000=_ooool002Cooooo00?o0000ooooooooool0o_ooool2o`0000Wooooo0_l0000fooooo`009?oo
ool00ol0003oooooooooo`1Uooooo`;o0000Boooool2o`0004Gooooo0_l00016ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo06Gooooo0_l0001;ooooo`;o00007oooool2o`0002Co
oooo0_l0000Wooooo`;o00007Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool08Oooool2o`000;3ooooo0_l0001=ooooo`;o00007Oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo0ol0000Eooooo`;o00002_ooool2o`0005?ooooo0_l00039ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0Eooooo`;o0000Goooool2o`000<Wooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3ooooood;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0ooooool4ooooo`;o00004_ooool2o`0002Sooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0005Sooooo0_l0
0003ooooo`;o0000YOooool2o`0001;ooooo0_l0000Xooooo`009?ooool00ol0003oooooooooo`1G
ooooo`;o00000oooool2o`000>?ooooo000Tooooo`03o`000?oooooooooo05kooooo0_l0003Qoooo
o`009?ooool00ol0003oooooooooo`1Nooooo`;o0000Soooool2o`00053ooooo000Tooooo`03o`00
0?oooooooooo0=3ooooo0_l0000Mooooo`;o0000D?ooool002Cooooo00?o0000ooooooooool0COoo
ool2o`0001;ooooo0_l0000Booooo`;o0000FOooool2o`0006oooooo000Tooooo`;o0000C_ooool2
o`0001;ooooo0_l0000Booooo`;o0000b_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`0Sooooo`;o00007Oooool2o`0007Sooooo0_l0000<ooooo`;o
0000Goooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0000Mooooo`;o0000
N?ooool2o`0000cooooo0_l0000eooooo`;o0000:?ooool2o`0001Cooooo000Tooooo`03o`000?oo
oooooooo01kooooo0_l0001Wooooo`;o0000N?ooool2o`0003kooooo000Tooooo`;o00007oooool2
o`0003?ooooo0_l0000=ooooo`;o00008oooool2o`000;Sooooo000Tooooo`03o`000?oooooooooo
00Wooooo0_l00018ooooo`;o00003Oooool2o`000=gooooo000Tooooo`03o`000?oooooooooo00Wo
oooo0_l0002Yooooo`;o0000=?ooool2o`0005Gooooo000Tooooo`03o`000?oooooooooo057ooooo
0_l0001Qooooo`;o0000=?ooool2o`0005Gooooo000Tooooo`03o`000?oooooooooo057ooooo0_l0
0026ooooo`;o0000Doooool2o`00017ooooo000Tooooo`;o0000/?ooool2o`0002Sooooo0_l0001C
ooooo`;o00004Oooool002Cooooo00?o0000ooooooooool0[oooool2o`0003oooooo0_l0001?oooo
o`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3`ooooo`;o0000Coooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;oooooo0_l00020ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2oooooo`;o0000??ooool2o`0004;ooooo0009oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00004oooool2
o`000>Sooooo0_l0000Pooooo`;o00008?ooool000Wooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Cooooo`;o0000oooo
ool;ooooo`;o00008?ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Uoooool2o`0008Oooooo0_l0000Oooooo`002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Iooooo`;o00001?ooool2o`0003Kooooo0_l00005ooooo`;o0000P?ooool2o`0001oooooo0009
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0FOoo
ool2o`0000Cooooo0_l0000mooooo`;o0000ROooool2o`0001Kooooo000Tooooo`;o0000ooooool[
ooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0;_ooool2o`0007Kooooo0_l0002Ioooo
o`009?ooool00ol0003oooooooooo`0^ooooo`;o00009_ooool2o`0004kooooo0_l0002Iooooo`00
9?ooool00ol0003oooooooooo`1Fooooo`;o0000@?ooool2o`0003cooooo0_l0000=ooooo`;o0000
F_ooool002Cooooo00?o0000ooooooooool0:Oooool2o`00023ooooo0_l0001;ooooo`;o00001_oo
ool2o`0003Cooooo0_l0000=ooooo`;o00008oooool2o`0003Gooooo000Tooooo`;o0000:_ooool2
o`00023ooooo0_l00007ooooo`;o0000B_ooool2o`0006Sooooo0_l0000eooooo`009?ooool00ol0
003oooooooooo`1Dooooo`;o0000joooool002Cooooo00?o0000ooooooooool0?Oooool2o`0006Co
oooo0_l00027ooooo`;o00004oooool002Cooooo00?o0000ooooooooool0?Oooool2o`0006Cooooo
0_l00027ooooo`;o00004oooool002Cooooo00?o0000ooooooooool06?ooool2o`0007Kooooo0_l0
002_ooooo`009?ooool2o`0001Wooooo0_l0001fooooo`;o0000<oooool2o`0001Sooooo0_l0001P
ooooo`009?ooool00ol0003oooooooooo`2Booooo`;o0000<Oooool2o`0001Oooooo0ol0000Eoooo
o`;o00005_ooool2o`00037ooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0001kooooo`;o
00001_ooool2o`0004[ooooo0_l0000Fooooo`;o00005_ooool2o`00037ooooo000Tooooo`03o`00
0?oooooooooo00gooooo0_l0000Sooooo`;o0000=_ooool2o`0001kooooo0_l0002eooooo`009?oo
ool00ol0003oooooooooo`0booooo`Co0000=?ooool2o`000=Gooooo000Tooooo`;o0000;Oooool2
o`0000Kooooo0_l0003oooooo`cooooo000Tooooo`03o`000?oooooooooo02cooooo0_l0000Eoooo
o`;o0000eOooool2o`0002Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo04?ooooo0_l00009ooooo`;o0000A?ooool2o`0008Cooooo0_l0000Uooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0C_ooool2o`0004Cooooo0_l0002[ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3Looooo`;o0000Hoooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Vooooo`;o0000B?ooool2o`0006[ooooo0_l0001Sooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Kooooo0_l0000looooo`;o00002_ooool2
o`0005Kooooo0_l0000jooooo`;o0000>oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool2o`00063ooooo0_l0001Rooooo`;o0000>_ooool2o`0003_ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool2o`000=Oooooo0_l0001Tooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
SOooool2o`0003Sooooo0_l0000Booooo`;o0000I?ooool002Cooooo0_l0000@ooooo`;o0000J_oo
ool2o`00013ooooo0_l0000hooooo`;o00006?ooool2o`0005kooooo000Tooooo`03o`000?oooooo
oooo00oooooo0_l0001Zooooo`;o0000I?ooool2o`0001Sooooo0_l00014ooooo`009?ooool00ol0
003oooooooooo`0Wooooo`;o0000d_ooool2o`0004Cooooo000Tooooo`03o`000?oooooooooo02Oo
oooo0_l0001booooo`;o0000Y?ooool002Cooooo00?o0000ooooooooool0AOooool2o`0005Cooooo
0_l0002Tooooo`009?ooool2o`0003Wooooo0_l0000;ooooo`;o0000:oooool2o`0008Cooooo0_l0
0017ooooo`009?ooool00ol0003oooooooooo`0Mooooo`;o00006Oooool2o`0003Sooooo0_l0000m
ooooo`;o0000AOooool2o`0002Wooooo0_l0000Looooo`009?ooool00ol0003oooooooooo`0Moooo
o`;o0000T_ooool2o`00073ooooo0_l0000Looooo`009?ooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000oooooo`009?ooool01?l0003oooooooooooooool2o`0003Cooooo0_l00024ooooo`;o
0000:?ooool2o`0001Oooooo0_l0000Vooooo`;o00005oooool002Cooooo0_l00002ooooo`;o0000
3oooool2o`0002?ooooo0_l0001@ooooo`;o0000<_ooool2o`0002Sooooo0_l0000oooooo`;o0000
5oooool002Cooooo00?o0000ooooooooool04_ooool2o`0007Gooooo0_l0002fooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0003ooooo
o`Kooooo0_l0000^ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000`Oooool2o`0004;o
oooo0_l0000^ooooo`009?ooool2o`0007oooooo0_l0001=ooooo`;o0000L_ooool002Cooooo00?o
0000ooooooooool0O_ooool2o`000<7ooooo000Jooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`0aooooo`;o0000FOooool2o`0004[ooooo0_l0000hooooo`;o0000;Oooool0
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0aooooo`;o0000FOooool2o`00
04[ooooo0_l0000hooooo`;o00007Oooool2o`0000kooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolbooooo`;o00003_ooool001cooooo00?o0000ooooooooool0
1Oooool3o`000?oooooo3Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0
003Dooooo`;o0000=_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Soooool2o`0004?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo0_l0001mooooo`;o0000/?ooool001[ooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`0@ooooo`;o0000[_ooool2o`0007oooooo000Tooooo`;o0000
`Oooool2o`0007oooooo000Tooooo`03o`000?oooooooooo09gooooo0_l0002Rooooo`009?ooool0
0ol0003oooooooooo`10ooooo`;o0000Foooool2o`000:;ooooo000Tooooo`03o`000?oooooooooo
043ooooo0_l0002[ooooo`;o00000oooool2o`0001;ooooo0_l0000iooooo`009?ooool00ol0003o
ooooooooo`1Jooooo`;o0000TOooool2o`0000?ooooo0_l0000Booooo`;o0000>Oooool002Cooooo
0_l0001Kooooo`;o0000D_ooool2o`00097ooooo000Tooooo`03o`000?oooooooooo03oooooo0_l0
001]ooooo`;o0000TOooool002Cooooo00?o0000ooooooooool0?oooool2o`0002Oooooo0_l0003G
ooooo`009?ooool00ol0003oooooooooo`1Xooooo`;o00005oooool5o`000;_ooooo000Tooooo`03
o`000?oooooooooo087ooooo1Ol0002kooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0;oooool2o`000;_ooooo0_l0001Cooooo`009?ooool00ol0003oooooooooo`0_
ooooo`;o0000^oooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo0?oooooo9oooool2o`00
01Wooooo000Tooooo`03o`000?oooooooooo0?oooooo4?ooool2o`0001Gooooo0_l0000Iooooo`00
9?ooool2o`000:Kooooo0_l0001Xooooo`;o00000oooool2o`0002_ooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo0_l0001]ooooo`;o0000:oooool000;ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`000?oo
oooo0000o`000?oooooo@Oooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o
0000oooooom1ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oo
oooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000UOoo
ool2o`000:[ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0UOooool2o`0000?ooooo0_l0
002Uooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0[ooooo`;o0000KOooool2o`000:Gooooo0004oooo
o`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool2o`0002;ooooo0_l0003ooooooaGooooo0002oooo
o`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`05ooooo`Co0000ooooooliooooo`009?ooool2o`0000Kooooo0_l0003^oooo
o`;o0000B_ooool002Cooooo00?o0000ooooooooool0mOooool2o`0004[ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0A_ooool2o`000?Wooooo000T
ooooo`03o`000?oooooooooo04Kooooo0_l00008ooooo`;o0000T?ooool2o`0005gooooo000Toooo
o`;o00003Oooool2o`0004;ooooo0_l0002@ooooo`;o0000GOooool002Cooooo00?o0000oooooooo
ool03?ooool2o`000?oooooo2?ooool2o`0002[ooooo000Tooooo`03o`000?oooooooooo0?oooooo
5_ooool2o`0002[ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool01?ooool2o`000?oooooo??ooool002Cooooo0_l00005ooooo`;o0000X_ooool2o`00
09Oooooo000Tooooo`03o`000?oooooooooo06kooooo0_l0000Fooooo`;o00008?ooool2o`0009Oo
oooo000Tooooo`03o`000?oooooooooo03cooooo0_l0000`ooooo`;o00005_ooool2o`0001Wooooo
0_l0002Nooooo`009?ooool00ol0003oooooooooo`0looooo`;o0000Hoooool2o`0001Oooooo0_l0
0025ooooo`009?ooool00ol0003oooooooooo`2jooooo`;o0000QOooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0:cooooo0_l0002Cooooo`002_ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2/ooooo`;o0000Toooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3Yooooo`;o0000E_ooool000cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Wooooo0_l0
001Fooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001W
ooooo`;o0000f?ooool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0Ioooool2o`000=Sooooo000<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;o
oooo000:ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo06_ooooo
0_l0003Dooooo`009?ooool2o`0006cooooo0_l0003Dooooo`009?ooool00ol0003oooooooooo`2i
ooooo`;o0000Q_ooool002Cooooo00?o0000ooooooooool0^Oooool2o`0008Kooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`00
1?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Jooooo`;o0000
oooooolVooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`;o0000oooooolVooooo`001?ooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo7_ooool2o`0002;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo7_ooool2o`0002;ooooo000Tooooo`03o`000?oooooooooo0?oooooo6Ooo
ool2o`0002Oooooo000Tooooo`03o`000?oooooooooo0?oooooo6Oooool2o`0002Oooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000OOooool2o`000<?ooooo000Tooooo`03
o`000?oooooooooo07cooooo0_l00033ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
6Oooool5o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?oooooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003o
ooooooooo`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`00
6Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .26337 Mdot
.03333 .31317 Mdot
.0381 .17273 Mdot
.04286 .32985 Mdot
.05238 .32673 Mdot
.05714 .3755 Mdot
.0619 .0722 Mdot
.06667 .30583 Mdot
.07143 .36737 Mdot
.07619 .22971 Mdot
.08095 .34478 Mdot
.08571 .24371 Mdot
.09048 .34122 Mdot
.09524 .10314 Mdot
.1 .16086 Mdot
.10476 .12534 Mdot
.10952 .28362 Mdot
.11429 .47731 Mdot
.11905 .00896 Mdot
.12381 .18762 Mdot
.12857 .18134 Mdot
.13333 .00938 Mdot
.1381 .00719 Mdot
.14286 .19531 Mdot
.14762 .02799 Mdot
.15238 .19223 Mdot
.15714 .26574 Mdot
.1619 .24414 Mdot
.16667 .44958 Mdot
.17143 .2629 Mdot
.17619 .0776 Mdot
.18095 .54986 Mdot
.18571 .27625 Mdot
.19048 .04483 Mdot
.19524 .22323 Mdot
.2 .0438 Mdot
.20476 .37205 Mdot
.20952 .26502 Mdot
.21429 .05293 Mdot
.21905 .24884 Mdot
.22381 .16061 Mdot
.22857 .41816 Mdot
.23333 .24696 Mdot
.2381 .02934 Mdot
.24286 .1277 Mdot
.24762 .15591 Mdot
.25238 .4111 Mdot
.25714 .02807 Mdot
.2619 .0965 Mdot
.26667 .10173 Mdot
.27143 .12695 Mdot
.27619 .18778 Mdot
.28095 .39321 Mdot
.28571 .11115 Mdot
.29048 .22689 Mdot
.29524 .2596 Mdot
.3 .18818 Mdot
.30476 .04831 Mdot
.30952 .06188 Mdot
.31429 .26462 Mdot
.31905 .09151 Mdot
.32381 .00868 Mdot
.32857 .21386 Mdot
.33333 .0188 Mdot
.3381 .15809 Mdot
.34286 .14841 Mdot
.34762 .147 Mdot
.35238 .35943 Mdot
.35714 .34992 Mdot
.3619 .27283 Mdot
.36667 .56865 Mdot
.37619 .38532 Mdot
.38095 .26387 Mdot
.38571 .33959 Mdot
.39524 .10955 Mdot
.4 .14538 Mdot
.40476 .10318 Mdot
.40952 .05512 Mdot
.41429 .20028 Mdot
.41905 .57212 Mdot
.42381 .21626 Mdot
.42857 .09232 Mdot
.43333 .24908 Mdot
.4381 .33906 Mdot
.44286 .34597 Mdot
.44762 .5113 Mdot
.45238 .07362 Mdot
.45714 .16542 Mdot
.4619 .21032 Mdot
.46667 .20967 Mdot
.47143 .22164 Mdot
.47619 .43723 Mdot
.48095 .02794 Mdot
.48571 .3192 Mdot
.49048 .16869 Mdot
.49524 .31653 Mdot
.5 .09663 Mdot
.50476 .1842 Mdot
.50952 .22124 Mdot
.51429 .24438 Mdot
.51905 .28891 Mdot
.52381 .03814 Mdot
.52857 .22574 Mdot
.53333 .45991 Mdot
.5381 .18885 Mdot
.54286 .52178 Mdot
.54762 .23784 Mdot
.55238 .41428 Mdot
.55714 .1345 Mdot
.5619 .12644 Mdot
.56667 .41106 Mdot
.57143 .3287 Mdot
.57619 .16595 Mdot
.58095 .30237 Mdot
.58571 .02212 Mdot
.59048 .24655 Mdot
.59524 .10836 Mdot
.6 .0194 Mdot
.60476 .51317 Mdot
.60952 .28636 Mdot
.61429 .16906 Mdot
.61905 .27795 Mdot
.62381 .14286 Mdot
.62857 .3042 Mdot
.63333 .20525 Mdot
.6381 .59777 Mdot
.64286 .19123 Mdot
.64762 .28831 Mdot
.65238 .16951 Mdot
.65714 .22745 Mdot
.6619 .08699 Mdot
.66667 .35329 Mdot
.67143 .04106 Mdot
.67619 .0692 Mdot
.68095 .06527 Mdot
.68571 .12639 Mdot
.69048 .18335 Mdot
.69524 .29246 Mdot
.7 .39928 Mdot
.70476 .14438 Mdot
.70952 .13195 Mdot
.71429 .07767 Mdot
.71905 .21038 Mdot
.72381 .15782 Mdot
.72857 .26737 Mdot
.73333 .19065 Mdot
.74286 .18341 Mdot
.74762 .17446 Mdot
.75238 .51459 Mdot
.75714 .02986 Mdot
.7619 .40188 Mdot
.76667 .26848 Mdot
.77143 .10151 Mdot
.77619 .02562 Mdot
.78095 .26009 Mdot
.78571 .04943 Mdot
.79048 .27415 Mdot
.79524 .03582 Mdot
.8 .39541 Mdot
.80476 .12549 Mdot
.80952 .2653 Mdot
.81429 .1996 Mdot
.81905 .01384 Mdot
.82381 .18371 Mdot
.82857 .00807 Mdot
.83333 .11425 Mdot
.8381 .07604 Mdot
.84286 .27248 Mdot
.84762 .00774 Mdot
.85238 .03584 Mdot
.85714 .24538 Mdot
.8619 .32218 Mdot
.86667 .17226 Mdot
.87143 .22851 Mdot
.87619 .27871 Mdot
.88095 .34707 Mdot
.88571 .17667 Mdot
.89048 .30131 Mdot
.89524 .00957 Mdot
.9 .38229 Mdot
.90476 .18698 Mdot
.90952 .02211 Mdot
.91905 .16464 Mdot
.92381 .10067 Mdot
.92857 .03487 Mdot
.93333 .20682 Mdot
.9381 .00994 Mdot
.94286 .25419 Mdot
.94762 .20711 Mdot
.95238 .16224 Mdot
.95714 .25361 Mdot
.9619 .26532 Mdot
.96667 .16869 Mdot
.97143 .20791 Mdot
.97619 .20326 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0K
ooooo`;o00000oooool3o`0003_ooooo0_l0002Qooooo`;o00001?ooool2o`0000kooooo0_l0000<
ooooo`;o00006_ooool002Cooooo00?o0000ooooooooool06oooool2o`0000?ooooo0ol0000koooo
o`;o0000XOooool2o`0000Cooooo0_l0000>ooooo`;o00003?ooool2o`0001[ooooo000Tooooo`;o
0000ooooool2o`00047ooooo000Tooooo`03o`000?oooooooooo067ooooo0_l0001Dooooo`;o0000
AOooool2o`00047ooooo000Tooooo`03o`000?oooooooooo067ooooo0_l0001?ooooo`;o00000ooo
ool2o`0006;ooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`2booooo`;o0000??ooool2
o`0002Wooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o00008_ooool2o`00
04Kooooo0_l0001Nooooo`;o0000Coooool002Cooooo0_l0000Uooooo`;o00007?ooool2o`0000Co
oooo0_l00016ooooo`;o0000F?ooool2o`0005Gooooo000Tooooo`03o`000?oooooooooo04;ooooo
0_l0002Vooooo`;o0000=_ooool2o`0001gooooo000Tooooo`03o`000?oooooooooo0?Kooooo0_l0
000Aooooo`;o00005oooool2o`0001gooooo000Tooooo`03o`000?oooooooooo09kooooo0_l0000^
ooooo`;o00009_ooool2o`00017ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`0eoooo
o`;o0000Ioooool2o`0002kooooo0_l0001aooooo`009?ooool2o`0003?ooooo0_l000000ooooooo
0000o`00003oooooo`_ooooo000Tooooo`03o`000?oooooooooo03;ooooo0_l0000Sooooo`;o0000
V_ooool2o`0004cooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0000Kooooo`;o0000V_oo
ool2o`0004cooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0000mooooo`;o0000a_ooool0
02Cooooo00?o0000ooooooooool0NOooool2o`000<Kooooo000Tooooo`;o0000F_ooool2o`000>Ko
oooo000Tooooo`03o`000?oooooooooo05Wooooo0_l0001fooooo`;o0000K_ooool002Cooooo00?o
0000ooooooooool0dOooool2o`0006kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0d?ooool2o`0006oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00Wooooo0_l0001looooo`;o0000Aoooool2o`0006oooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`?o00002Oooool2o`0002?ooooo0_l0001Gooooo`;o0000Doooool2o`0002Kooooo0_l0000koooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0^ooooo`;o0000[?ooool2o`0002Ko
oooo0_l0000kooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo@_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0boooool2o`0007Cooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0boooool2o`0007Cooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`0005gooooo0_l0000Qooooo`;o0000`?ooool002Cooooo00?o0000ooooooooool0BOooool2
o`00017ooooo0_l0000Qooooo`;o0000`?ooool002Cooooo00?o0000ooooooooool0BOooool2o`00
04cooooo0_l0002Xooooo`009?ooool00ol0003oooooooooo`1;ooooo`;o0000B_ooool2o`0005Ko
oooo0_l0000_ooooo`;o00007oooool002Cooooo00?o0000ooooooooool04oooool2o`0003Kooooo
0_l0000[ooooo`;o0000MOooool2o`0002oooooo0_l0000Oooooo`009?ooool00ol0003ooooooooo
o`0Cooooo`;o0000Hoooool2o`0003cooooo0_l00029ooooo`009?ooool2o`0005;ooooo0_l0000R
ooooo`;o0000?oooool2o`0008Wooooo000Tooooo`03o`000?oooooooooo057ooooo0_l0000Roooo
o`;o0000S?ooool2o`0003cooooo000Tooooo`03o`000?oooooooooo0?oooooo1?ooool2o`0003co
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool2o`0001Oooooo0_l0000eooooo`;o0000G?ooool2o`0002Kooooo0_l0000T
ooooo`;o0000A_ooool002Cooooo00?o0000ooooooooool05_ooool2o`0002_ooooo0_l00008oooo
o`;o0000G?ooool2o`0002Kooooo0_l0000Tooooo`;o0000A_ooool002Cooooo00?o0000oooooooo
ool0@oooool2o`0009Kooooo0_l0001Tooooo`009?ooool00ol0003oooooooooo`2Yooooo`;o0000
<?ooool2o`0006Cooooo000Tooooo`03o`000?oooooooooo0:Wooooo0_l0002Fooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0M_ooool2o`0004Oooooo0_l0000Hoooo
o`;o0000I_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0I?ooool3o`0000oooooo0_l00017
ooooo`;o00006?ooool2o`0006Kooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Tooooo`?o0000f_ooool0
00Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom2ooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0004Gooooo0_l0000Kooooo`;o0000Noooool2o`00063ooooo0009oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool05Oooool2o`0002Kooooo0_l00006ooooo`;o00006oooool2o`0007_ooooo0_l0
001Pooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Eooooo`;o00009_ooool2o`000>[ooooo0_l0000Fooooo`002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`29ooooo`;o00009?ooool2o`0006kooooo0_l00008ooooo`;o00005_ooool000Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`29ooooo`;o00002Ooo
ool2o`0001Wooooo0_l0000;ooooo`;o00002_ooool2o`0005Gooooo0_l0000=ooooo`;o00004Ooo
ool002Cooooo0_l00002ooooo`;o0000TOooool2o`0002Kooooo0_l0000:ooooo`;o0000A?ooool2
o`0001kooooo0_l0000Aooooo`009?ooool01?l0003oooooooooooooool2o`000>Cooooo0_l0000U
ooooo`;o00001?ooool2o`0002_ooooo000Tooooo`03o`000?oooooooooo0>Oooooo0_l0000[oooo
o`;o0000:oooool002Cooooo00?o0000ooooooooool07_ooool2o`000?oooooo8_ooool002Cooooo
00?o0000ooooooooool07_ooool2o`0007Sooooo0_l0000jooooo`;o00003oooool2o`0001Wooooo
0_l0000oooooo`009?ooool2o`0001kooooo0_l0000_ooooo`;o00001_ooool2o`00043ooooo0_l0
0009ooooo`;o0000;oooool2o`0000oooooo0_l0000Iooooo`;o00006?ooool2o`0002Gooooo000T
ooooo`03o`000?oooooooooo01gooooo0_l0000_ooooo`;o00001_ooool2o`0004_ooooo0_l0000P
ooooo`;o00006oooool2o`0003Kooooo0_l0000Uooooo`009?ooool00ol0003oooooooooo`0Voooo
o`;o0000WOooool2o`0001_ooooo0_l0001Mooooo`009?ooool00ol0003oooooooooo`0Sooooo`;o
000000?oooooo`000?l00000oooooolJooooo`009?ooool00ol0003oooooooooo`0Sooooo`;o0000
E_ooool2o`00083ooooo0_l00012ooooo`009?ooool2o`0007cooooo0_l00020ooooo`;o0000<_oo
ool2o`0000kooooo000Tooooo`03o`000?oooooooooo0<;ooooo0_l0001Oooooo`;o00000oooool2
o`0000Oooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`2:ooooo`Co0000=?ooool2o`00
01[ooooo0_l00013ooooo`;o00000oooool2o`0000Kooooo0_l0000?ooooo`009?ooool00ol0003o
ooooooooo`2:ooooo`Co0000D?ooool2o`00053ooooo0_l0000?ooooo`009?ooool00ol0003ooooo
ooooo`1Oooooo`;o00007Oooool2o`000<7ooooo000Tooooo`;o0000H?ooool2o`0001gooooo0_l0
0031ooooo`009?ooool00ol0003oooooooooo`2=ooooo`;o00002oooool2o`000:Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Cooooo0_l0001Gooooo`;o0000
2oooool2o`0000Cooooo0_l0002Oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0=?ooool2o`0001gooooo0_l0001;ooooo`;o0000:?ooool2o`0004?ooooo0_l0000`ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`;o0000A?ooool2o`0007Gooooo
0_l00013ooooo`;o0000<?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000=ooooo`;o0000oooo
oolcooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0:Kooooo0_l0
002Iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Vooooo`;o0000VOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o00005oooool2o`00073ooooo
0_l0002Tooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool04?ooool2o`0001Oooooo0_l0000Eooooo`;o0000FOooool2o`0001Oo
oooo0_l0001Dooooo`;o0000=Oooool002Cooooo0_l0000mooooo`;o00000_ooool2o`0003oooooo
0_l0000aooooo`;o0000E?ooool2o`0003Gooooo000Tooooo`03o`000?oooooooooo03cooooo0_l0
0013ooooo`;o0000Z?ooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo0?oooooo9oooool2
o`0000?ooooo0_l0000Dooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o0000d?ooool2o`00
01Wooooo000Tooooo`03o`000?oooooooooo02cooooo0_l0000Vooooo`;o0000W?ooool2o`0004go
oooo000Tooooo`?o00009oooool2o`0000?ooooo0_l0000:ooooo`;o00008?ooool2o`0001Cooooo
0_l00020ooooo`;o00001oooool2o`0002oooooo0_l0000Cooooo`009?ooool3o`0002Oooooo0_l0
000?ooooo`;o00008?ooool2o`0001Cooooo0_l0001_ooooo`;o00002_ooool2o`0000cooooo0_l0
000_ooooo`;o00004oooool002Cooooo00?o0000ooooooooool0hOooool2o`0000[ooooo0_l0001B
ooooo`009?ooool00ol0003oooooooooo`1Zooooo`;o0000ROooool2o`0000oooooo0_l0000ioooo
o`009?ooool00ol0003oooooooooo`0aooooo`;o0000=oooool2o`00057ooooo0_l0000fooooo`;o
00003oooool2o`0003Wooooo000Tooooo`;o0000<_ooool2o`0008[ooooo0_l0001Booooo`;o0000
;_ooool002Cooooo00?o0000ooooooooool06?ooool2o`000?Oooooo0_l0000^ooooo`009?ooool0
0ol0003oooooooooo`0Hooooo`;o0000X?ooool2o`0008Gooooo000Tooooo`03o`000?oooooooooo
09gooooo0_l0000Kooooo`;o00002oooool2o`0007Sooooo000Tooooo`03o`000?oooooooooo09go
oooo0_l0000Xooooo`;o00003Oooool2o`0006Wooooo000Tooooo`;o0000eoooool2o`0006Wooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;7ooooo0_l0001Rooooo`;o0000:_ooool001cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`;o0000YOooool2o`0000gooooo0_l0001Coooo
o`;o0000:_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o
0000]?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0003ooooood;ooooo
000Looooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o0000oooooom1ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0009Cooooo0_l0002Zooooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09;ooooo0_l000000ooooooo0000o`00
002Zooooo`006_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo09;ooooo0_l0001h
ooooo`;o0000<oooool002Cooooo0_l00006ooooo`;o0000ooooool6ooooo`;o0000<oooool002Co
oooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o00000:Oooooo0_l0002Aooooo`00
9?ooool00ol0003oooooooooo`02ooooo`;o0000Z_ooool2o`00097ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0L_ooool2o`0000oooooo0_l0002l
ooooo`009?ooool2o`0001?ooooo0_l0001Nooooo`;o00003oooool2o`000;cooooo000Tooooo`03
o`000?oooooooooo00oooooo0_l000000ooooooo0000o`00001`ooooo`;o0000^oooool002Cooooo
00?o0000ooooooooool03oooool2o`0007?ooooo0_l0002<ooooo`;o0000;Oooool002Cooooo00?o
0000ooooooooool0J?ooool2o`000:Sooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`1X
ooooo`;o0000Hoooool2o`0007;ooooo000Tooooo`;o0000c_ooool2o`0007;ooooo000Tooooo`03
o`000?oooooooooo06Oooooo0_l0003Hooooo`009?ooool00ol0003oooooooooo`1Wooooo`;o0000
f?ooool002Cooooo00?o0000ooooooooool03?ooool2o`000?oooooo=?ooool002Cooooo00?o0000
ooooooooool03?ooool2o`000?oooooo=?ooool002Cooooo0_l0000hooooo`;o0000ooooool9oooo
o`009?ooool00ol0003oooooooooo`07ooooo`;o0000;_ooool2o`000?oooooo2Oooool000;ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocWooooo0004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo6Oooool2o`0002Oooooo0004ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06kooooo0_l0002Xooooo`;o00009oooool000Cooooo00?o0000ooooooooool03?oo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001^ooooo`;o0000dOoo
ool000Cooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo053ooooo0_l0002Vooooo`;o0000Aoooool000Cooooo00?o0000ooooooooool02_ooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@
ooooo`;o0000Y_ooool2o`0004Oooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`3Hooooo`;o0000Ioooool0
02Cooooo0_l0003Iooooo`;o00004_ooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo0>co
oooo0_l0001Cooooo`009?ooool00ol0003oooooooooo`2/ooooo`;o0000Toooool002Cooooo00?o
0000ooooooooool0A_ooool2o`0006Cooooo0_l0002Cooooo`009?ooool00ol0003oooooooooo`16
ooooo`;o0000H?ooool2o`0009Oooooo000Tooooo`;o0000@?ooool2o`0006Oooooo0_l0002Goooo
o`009?ooool00ol0003oooooooooo`0oooooo`;o0000ooooool1ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0Soooool2o`000;3ooooo000Tooooo`03o`000?oooooooooo08oooooo0_l0002`ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0000/ooooo`;o0000oooooolEooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o
0000oooooolEooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
XOooool2o`0009kooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Qooooo`;o0000W_ooool000cooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo000<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
od;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3ooooood;ooooo000:ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`00
0?oooooooooo01[ooooo0_l0003oooooobKooooo000Tooooo`;o00006oooool2o`000?oooooo9_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0008Oooooo0_l0
002iooooo`009?ooool00ol0003oooooooooo`26ooooo`;o0000<Oooool2o`0002kooooo0_l0001F
ooooo`009?ooool00ol0003oooooooooo`2iooooo`;o0000;_ooool2o`0005Kooooo000Tooooo`03
o`000?oooooooooo0:Gooooo0_l0002Jooooo`009?ooool00ol0003oooooooooo`2Uooooo`;o0000
V_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
00;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo0004oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00co
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0;oooool2o`000?oooooo4Oooool000;ooooo00?oEEEEofIVI_l000003?ooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo02oooooo0_l0003ooooooa7ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`1[ooooo`;o0000e?ooool002Cooooo0_l0001/ooooo`;o00003oooool2o`00
0<?ooooo000Tooooo`03o`000?oooooooooo07cooooo0_l00033ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0<?ooooo0_l0001looooo`009?ooool00ol0003oooooooooo`33ooooo`;o0000O?ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003o
oooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000oooooooo
ool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .38629 Mdot
.03333 .25694 Mdot
.0381 .12766 Mdot
.04286 .25783 Mdot
.05238 .23328 Mdot
.05714 .37117 Mdot
.0619 .00133 Mdot
.06667 .44383 Mdot
.07143 .3359 Mdot
.07619 .21629 Mdot
.08095 .35149 Mdot
.08571 .15398 Mdot
.09048 .4133 Mdot
.09524 .10761 Mdot
.1 .07173 Mdot
.10476 .03471 Mdot
.10952 .10719 Mdot
.11429 .43916 Mdot
.11905 .07623 Mdot
.12381 .01571 Mdot
.12857 .10223 Mdot
.13333 .07826 Mdot
.1381 .00719 Mdot
.14286 .02525 Mdot
.14762 .08446 Mdot
.15238 .09998 Mdot
.15714 .32578 Mdot
.1619 .02734 Mdot
.16667 .54636 Mdot
.17143 .37416 Mdot
.17619 .0776 Mdot
.18095 .55843 Mdot
.18571 .2434 Mdot
.19048 .13434 Mdot
.19524 .00823 Mdot
.2 .11436 Mdot
.20476 .36207 Mdot
.20952 .19193 Mdot
.21429 .021 Mdot
.21905 .27664 Mdot
.22381 .16113 Mdot
.22857 .48775 Mdot
.23333 .20504 Mdot
.2381 .12471 Mdot
.24286 .12738 Mdot
.24762 .0812 Mdot
.25238 .44443 Mdot
.25714 .1252 Mdot
.2619 .19432 Mdot
.26667 .03959 Mdot
.27143 .01566 Mdot
.27619 .14069 Mdot
.28095 .2546 Mdot
.28571 .00928 Mdot
.29048 .31338 Mdot
.29524 .25491 Mdot
.3 .17586 Mdot
.30476 .00525 Mdot
.30952 .01134 Mdot
.31429 .37273 Mdot
.31905 .035 Mdot
.32381 .00198 Mdot
.32857 .13595 Mdot
.33333 .13596 Mdot
.3381 .20808 Mdot
.34286 .04483 Mdot
.34762 .13541 Mdot
.35238 .331 Mdot
.35714 .34732 Mdot
.3619 .19102 Mdot
.36667 .56865 Mdot
.37143 .50813 Mdot
.37619 .47245 Mdot
.38095 .194 Mdot
.38571 .42085 Mdot
.39524 .00121 Mdot
.4 .01682 Mdot
.40476 .06949 Mdot
.40952 .1154 Mdot
.41429 .31294 Mdot
.41905 .54025 Mdot
.42381 .1134 Mdot
.42857 .02107 Mdot
.43333 .23485 Mdot
.4381 .57653 Mdot
.44286 .31473 Mdot
.44762 .54819 Mdot
.45238 .07362 Mdot
.45714 .09389 Mdot
.4619 .19588 Mdot
.46667 .29971 Mdot
.47143 .22616 Mdot
.47619 .31791 Mdot
.48095 .05796 Mdot
.48571 .36053 Mdot
.49048 .06356 Mdot
.49524 .14759 Mdot
.5 .07949 Mdot
.50476 .04911 Mdot
.50952 .28181 Mdot
.51429 .14654 Mdot
.51905 .29557 Mdot
.52381 .03814 Mdot
.52857 .24632 Mdot
.53333 .35445 Mdot
.5381 .1689 Mdot
.54286 .41287 Mdot
.54762 .27524 Mdot
.55238 .3212 Mdot
.55714 .13206 Mdot
.5619 .06787 Mdot
.56667 .31758 Mdot
.57143 .14277 Mdot
.57619 .12821 Mdot
.58095 .23814 Mdot
.58571 .07511 Mdot
.59048 .25129 Mdot
.59524 .08542 Mdot
.6 .0194 Mdot
.60476 .49592 Mdot
.60952 .16477 Mdot
.61429 .07885 Mdot
.61905 .33325 Mdot
.62381 .19173 Mdot
.62857 .43919 Mdot
.63333 .19808 Mdot
.6381 .54304 Mdot
.64286 .10829 Mdot
.64762 .37692 Mdot
.65238 .04385 Mdot
.65714 .23105 Mdot
.6619 .08699 Mdot
.66667 .19944 Mdot
.67143 .02205 Mdot
.67619 .16375 Mdot
.68095 .01191 Mdot
.68571 .14059 Mdot
.69048 .13727 Mdot
.69524 .15242 Mdot
.7 .38657 Mdot
.70476 .08472 Mdot
.70952 .03795 Mdot
.71429 .17048 Mdot
.71905 .29253 Mdot
.72381 .15782 Mdot
.72857 .33915 Mdot
.73333 .08461 Mdot
.7381 .59198 Mdot
.74286 .02446 Mdot
.74762 .26241 Mdot
.75238 .49541 Mdot
.75714 .06338 Mdot
.7619 .2374 Mdot
.76667 .16235 Mdot
.77143 .02936 Mdot
.77619 .02562 Mdot
.78095 .31106 Mdot
.78571 .14398 Mdot
.79048 .27432 Mdot
.79524 .0383 Mdot
.8 .44909 Mdot
.80476 .1398 Mdot
.80952 .20806 Mdot
.81429 .34363 Mdot
.81905 .05023 Mdot
.82381 .09911 Mdot
.82857 .00807 Mdot
.83333 .11425 Mdot
.8381 .11075 Mdot
.84286 .2743 Mdot
.84762 .00774 Mdot
.85238 .03584 Mdot
.85714 .14763 Mdot
.8619 .32218 Mdot
.86667 .07427 Mdot
.87143 .3389 Mdot
.87619 .23532 Mdot
.88095 .32344 Mdot
.88571 .26311 Mdot
.89048 .32405 Mdot
.89524 .12848 Mdot
.9 .37524 Mdot
.90476 .18469 Mdot
.90952 .03359 Mdot
.91905 .18102 Mdot
.92381 .1674 Mdot
.92857 .03487 Mdot
.93333 .08675 Mdot
.9381 .00994 Mdot
.94286 .33224 Mdot
.94762 .14975 Mdot
.95238 .14525 Mdot
.95714 .25761 Mdot
.9619 .20536 Mdot
.96667 .13689 Mdot
.97143 .33037 Mdot
.97619 .18353 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000Wo
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo
00?o0000ooooooooool02Oooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool2o`000003ooooool0003ooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo
0_l00002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0
000Aooooo`;o00006oooool2o`0000Cooooo0_l0002Xooooo`;o00001?ooool2o`0001cooooo0_l0
000Jooooo`009?ooool00ol0003oooooooooo`0Qooooo`;o00004Oooool2o`0001_ooooo0_l00006
ooooo`;o0000M_ooool2o`0002kooooo0_l00004ooooo`;o00007?ooool2o`0001[ooooo000Toooo
o`;o00007_ooool2o`0002kooooo0_l0000:ooooo`;o0000M_ooool2o`0006kooooo000Tooooo`03
o`000?oooooooooo01gooooo0_l0000^ooooo`;o00009oooool2o`0003oooooo0_l00028ooooo`00
9?ooool00ol0003oooooooooo`0jooooo`;o0000>_ooool2o`0000Oooooo0_l0000fooooo`;o0000
5Oooool2o`00077ooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0000Eooooo`;o0000@ooo
ool2o`0004gooooo0_l0000Eooooo`;o00002Oooool2o`0004oooooo000Tooooo`03o`000?oooooo
oooo02?ooooo0_l00004ooooo`;o0000^_ooool2o`0000Wooooo0_l0001?ooooo`009?ooool2o`00
02[ooooo0_l00034ooooo`;o0000D?ooool002Cooooo00?o0000ooooooooool05_ooool2o`000=Oo
oooo0_l0000Zooooo`;o00001Oooool2o`0001gooooo000Tooooo`03o`000?oooooooooo01Kooooo
0_l00014ooooo`;o0000OOooool2o`0002cooooo0_l0000@ooooo`;o00001Oooool2o`0001gooooo
000Tooooo`03o`000?oooooooooo04_ooooo0_l0000?ooooo`;o0000@?ooool2o`0003_ooooo0_l0
000Iooooo`;o00004Oooool2o`0003Kooooo000Tooooo`03o`000?oooooooooo04_ooooo0_l0001A
ooooo`;o0000:?ooool2o`0002cooooo0_l00019ooooo`009?ooool2o`0006Gooooo0_l0001Roooo
o`;o0000Moooool002Cooooo00?o0000ooooooooool0I?ooool2o`0003;ooooo0_l0001Tooooo`;o
0000@Oooool002Cooooo00?o0000ooooooooool0V?ooool2o`0006Cooooo0_l00011ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo093ooooo0_l0002_
ooooo`009?ooool2o`00097ooooo0_l0002_ooooo`009?ooool00ol0003oooooooooo`2Dooooo`;o
0000E?ooool2o`0005Gooooo000Tooooo`03o`000?oooooooooo09Cooooo0_l0000Eooooo`;o0000
?Oooool2o`0005Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05Oooool2o`00
067ooooo0_l0000aooooo`;o0000U?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool05Oooool2o`00067ooooo0_l0000=ooooo`;o0000QOooool2o`00037ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`?o00006oooool2o`00017ooooo0_l0001Gooooo`;o0000:Oooool2
o`0005[ooooo0_l0000aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Koooo
o`;o00000oooool2o`0000cooooo0_l0001Wooooo`;o00006Oooool2o`0000Sooooo0_l00023oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo023ooooo0_l0000Soooo
o`;o0000D?ooool2o`0002?ooooo0_l00023ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Tooooo`;o00007oooool2o`0006oooooo0_l0000Cooooo`;o00003?ooool2o`0000Oo
oooo0_l0000oooooo`;o00007?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0T
ooooo`;o0000T?ooool2o`0001?ooooo0_l0000<ooooo`;o00001oooool2o`0003oooooo0_l0000L
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo08Wooooo0_l0
002fooooo`009?ooool00ol0003oooooooooo`29ooooo`;o0000MOooool2o`0003oooooo000Toooo
o`03o`000?oooooooooo01kooooo0_l00006ooooo`;o0000f?ooool2o`0003oooooo000Tooooo`03
o`000?oooooooooo01kooooo0_l00006ooooo`;o0000oooooolJooooo`009?ooool00ol0003ooooo
ooooo`0Cooooo`;o00000oooool2o`000:_ooooo0_l0001jooooo`009?ooool2o`0001Cooooo0_l0
0003ooooo`;o0000Zoooool2o`0003gooooo0_l0000kooooo`009?ooool00ol0003oooooooooo`0e
ooooo`;o0000Aoooool2o`0008?ooooo0ol0000kooooo`009?ooool00ol0003oooooooooo`0eoooo
o`;o0000@_ooool2o`0000?ooooo0_l00023ooooo`;o0000??ooool002Cooooo00?o0000oooooooo
ool0NOooool2o`000<Kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
0013ooooo`?o00000oooool2o`000?Oooooo000Tooooo`04o`000?ooooooooooooooo`;o0000?ooo
ool3o`0000?ooooo0_l0001Uooooo`;o0000I_ooool2o`0002Sooooo000Tooooo`04o`000?oooooo
ooooooooo`;o0000Y_ooool2o`0000Cooooo0_l0001Vooooo`;o0000:?ooool002Cooooo00?o0000
ooooooooool0<_ooool2o`0002_ooooo1?l00002ooooo`;o0000@_ooool2o`0009Kooooo000Toooo
o`03o`000?oooooooooo03;ooooo0_l0000[ooooo`Co00000_ooool2o`0006gooooo0_l0001Hoooo
o`;o00004Oooool002Cooooo0_l0001?ooooo`;o0000G_ooool2o`0002?ooooo0ol0000Sooooo`;o
0000<oooool2o`00017ooooo000Tooooo`03o`000?oooooooooo04kooooo0_l0001Nooooo`;o0000
8oooool2o`0001kooooo0_l00004ooooo`;o0000;_ooool2o`0001Kooooo0009ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo09Gooooo0_l00004ooooo`;o0000E_ooool2o`0001Gooooo0_l0000Mooooo`;o
00005_ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo09Gooooo0_l00004ooooo`;o0000KOooool2o`0001co
oooo0_l0000Gooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0@ooooo`;o0000a?ooool2o`00053ooooo0_l0000Gooooo`00
2Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00013o
oooo0_l00034ooooo`;o00001oooool2o`00063ooooo0009ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0?Oooool2o`00
0:3ooooo0_l0001Pooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0mooooo`;o0000TOooool2o`0001_ooooo0_l0001Boooo
o`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2jooooo`;o00005?ooool2o`0001_ooooo0_l0000aooooo`;o00007oooool000Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2Soooo
o`;o00005Oooool2o`00023ooooo0_l00012ooooo`;o00007oooool002Cooooo0_l0002Tooooo`;o
0000=oooool2o`0006?ooooo000Tooooo`03o`000?oooooooooo05Kooooo0_l0003Yooooo`009?oo
ool00ol0003oooooooooo`1Fooooo`;o0000jOooool002Cooooo00?o0000ooooooooool0oooooolP
ooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0oooooolKooooo`;o00000oooool2o`00
013ooooo0_l0000>ooooo`009?ooool2o`000?oooooo7?ooool2o`0001Gooooo0_l0000>ooooo`00
9?ooool00ol0003oooooooooo`0hooooo`;o0000<?ooool2o`0005?ooooo0_l00020ooooo`009?oo
ool00ol0003oooooooooo`0hooooo`;o00003oooool2o`0001oooooo0_l00004ooooo`;o0000COoo
ool2o`00083ooooo000Tooooo`03o`000?oooooooooo04Wooooo0_l0000Uooooo`;o00006?ooool2
o`0003Kooooo0_l0001mooooo`009?ooool00ol0003oooooooooo`2:ooooo`;o0000=_ooool2o`00
00Wooooo0_l0001booooo`009?ooool2o`000<kooooo0_l0001booooo`009?ooool00ol0003ooooo
ooooo`10ooooo`;o0000j_ooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo043ooooo0_l0
000Pooooo`;o0000Uoooool2o`0002oooooo0_l0000Cooooo`009?ooool00ol0003oooooooooo`1R
ooooo`;o0000Uoooool2o`0004Cooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0003ooooo
oc?ooooo000Tooooo`;o00003_ooool2o`000?oooooo<oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2=ooooo`;o0000/_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0SOooool2o`0003_ooooo0_l0001eoooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000Gooooo0_l0001jooooo`;o0000Aoooool2o`0004Go
oooo0_l0000^ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Go
oooo0_l0001jooooo`;o0000;_ooool2o`0003Wooooo0_l0000Sooooo`;o0000;_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/Oooool2o`0003Wooooo0_l0001Cooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo0_l0003oooooo`oooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0a
ooooo`;o0000KOooool2o`0009oooooo000Tooooo`;o0000XOooool2o`0009oooooo000Tooooo`03
o`000?oooooooooo0;Cooooo0_l0002;ooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000
0_ooool2o`0005kooooo0_l0002;ooooo`009?ooool01Ol0003oooooo`000?l0003ooooo00;o0000
C?ooool2o`0000;ooooo0_l0003Eooooo`;o00005?ooool002Cooooo00Go0000ooooool0003o0000
ooooo`02o`000>?ooooo0_l00012ooooo`;o00005?ooool002Cooooo0_l0003Xooooo`;o0000:ooo
ool2o`0002_ooooo000Tooooo`03o`000?oooooooooo0?oooooo5Oooool2o`0002_ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Y_ooool2o`0004go
oooo0_l0000?ooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool0??ooool2o`0006Sooooo
0_l0001=ooooo`;o00003oooool2o`0003Wooooo000Tooooo`;o0000?Oooool2o`000?oooooo1?oo
ool002Cooooo00?o0000ooooooooool0V_ooool2o`000:Gooooo000Tooooo`03o`000?oooooooooo
09[ooooo0_l0002Uooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0=kooooo0_l0001Qooooo`009?ooool2o`0009kooooo0_l0000oooooo`;o0000HOoo
ool002Cooooo00?o0000ooooooooool0S?ooool2o`0000oooooo0_l0002Rooooo`006_ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0S?ooool2o`000;?ooooo000Looooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Ooo
ool3o`000?;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05?ooooo0_l0000Vooooo`;o00001oooool2o`0006cooooo0_l0001=ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05?ooooo0_l0000Vooooo`;o00001oooool2o`00
00Wooooo0_l0000Kooooo`;o0000Toooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2?ooooo`;o00005oooool2o`0000;ooooo0_l0002Cooooo`006_ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0:Sooooo0_l0001Rooooo`;o00001?ooool2o`000003oooo
ool0003o000002[ooooo000Tooooo`;o0000:?ooool2o`000>?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l00000:_ooool002Cooooo00?o0000ooooooooool09oooool2o`000?oooooo2?ooool2
o`0000oooooo000Tooooo`03o`000?oooooooooo06Oooooo0_l0001Dooooo`;o0000Ioooool2o`00
00Sooooo0_l0000?ooooo`009?ooool00ol0003oooooooooo`0<ooooo`;o0000FOooool2o`0005Co
oooo0_l0001Wooooo`;o00006Oooool002Cooooo00?o0000ooooooooool03?ooool2o`000=?ooooo
0_l0000/ooooo`;o0000<?ooool002Cooooo0_l0003Rooooo`;o0000;?ooool2o`00033ooooo000T
ooooo`03o`000?oooooooooo0?gooooo0_l00012ooooo`009?ooool00ol0003oooooooooo`1Xoooo
o`;o0000Toooool2o`0004;ooooo000Tooooo`03o`000?oooooooooo00oooooo0_l0001Gooooo`;o
0000eoooool002Cooooo00?o0000ooooooooool03oooool2o`00093ooooo0_l0002Nooooo`009?oo
ool2o`000:;ooooo0_l0002Nooooo`009?ooool00ol0003oooooooooo`2Booooo`;o0000[Oooool0
02Cooooo00?o0000ooooooooool0=oooool2o`0005Wooooo0_l0002]ooooo`009?ooool00ol0003o
ooooooooo`0gooooo`;o0000ooooool9ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o00002?ooool2o`00057ooooo0_l0003Uooooo`009?ooool00ol0003oooooooooo`07
ooooo`;o00008oooool2o`0002cooooo0_l0001[ooooo`;o0000Coooool2o`0002Oooooo0002oooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0/ooooo`;o0000VOooool2o`0004oooooo0_l0000W
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004oooo
o`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`000=Sooooo0_l0001Wooooo`001?ooool00ol0003ooooo
ooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0=Sooooo0_l0001Wooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00
000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo01;o
oooo0_l0002Aooooo`;o0000V_ooool002Cooooo00?o0000ooooooooool04_ooool2o`00097ooooo
0_l0002Jooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0L_ooool2
o`000<gooooo000Tooooo`03o`000?oooooooooo07;ooooo0_l0003=ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool06_ooool2o`000:Cooooo0_l0001oooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o
00003_ooool2o`0002[ooooo0_l0001hooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0
2_ooool2o`0003[ooooo0_l0003iooooo`009?ooool2o`000?Wooooo0_l00017ooooo`009?ooool0
0ol0003oooooooooo`3hooooo`;o0000Aoooool000[ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2
ooooo`003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool0
3_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo
000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`;o0000dOooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo06kooooo0_l0003Aooooo`002_ooool00omEEEGoIVIVo`00000=oooo
o`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo03oooooo0_l0
003oooooo`7ooooo000Tooooo`03o`000?oooooooooo03oooooo0_l0003oooooo`7ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0002jooooo`;o0000;_ooool2o`0005Ko
oooo000Tooooo`03o`000?oooooooooo0;Wooooo0_l0000^ooooo`;o0000E_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo06gooooo0_l0003Booooo`009?ooool2o`0006kooooo0_l0003Booooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1l
ooooo`;o0000`oooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0001looooo`;o0000AOooool2o`0007cooooo0004ooooo`03
o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0:oooool2o`0009Kooooo0_l0001looooo`001?ooool00ol0003o
ooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0[ooooo`;o0000FOooool2o`000;Wooooo0004ooooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Q_ooool2o`000;Wooooo0002ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co0000
1_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000<?ooool2o`000?oooooo4Ooo
ool002Cooooo00?o0000ooooooooool0;oooool2o`000?oooooo4Oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo06_ooooo0_l0003Dooooo`009?ooool2o`0006cooooo0_l0003Dooooo`009?ooool0
0ol0003oooooooooo`23ooooo`;o0000_?ooool002Cooooo00?o0000ooooooooool0Poooool2o`00
0;cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0i?ooool2
o`0005_ooooo000Tooooo`03o`000?oooooooooo0>Cooooo0_l0001Kooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006oooo
o`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo
000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9
ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44906 Mdot
.03333 .20294 Mdot
.0381 .12766 Mdot
.04286 .10747 Mdot
.05238 .1364 Mdot
.05714 .28941 Mdot
.0619 .01872 Mdot
.06667 .41152 Mdot
.07143 .24158 Mdot
.07619 .1577 Mdot
.08095 .22659 Mdot
.08571 .13782 Mdot
.09048 .36907 Mdot
.09524 .04246 Mdot
.1 .07173 Mdot
.10476 .08021 Mdot
.10952 .20038 Mdot
.11429 .45302 Mdot
.11905 .13019 Mdot
.12381 .05118 Mdot
.12857 .03831 Mdot
.13333 .07975 Mdot
.1381 .00719 Mdot
.14286 .02353 Mdot
.14762 .12485 Mdot
.15238 .13279 Mdot
.15714 .44752 Mdot
.1619 .13627 Mdot
.16667 .4773 Mdot
.17143 .41778 Mdot
.17619 .08593 Mdot
.18095 .55843 Mdot
.18571 .2726 Mdot
.19048 .22998 Mdot
.19524 .00823 Mdot
.2 .21561 Mdot
.20476 .34832 Mdot
.20952 .18028 Mdot
.21429 .1038 Mdot
.21905 .15117 Mdot
.22381 .10293 Mdot
.22857 .55524 Mdot
.23333 .27102 Mdot
.2381 .1224 Mdot
.24286 .28235 Mdot
.24762 .07524 Mdot
.25238 .39668 Mdot
.25714 .05699 Mdot
.2619 .20357 Mdot
.26667 .0546 Mdot
.27143 .10991 Mdot
.27619 .1489 Mdot
.28095 .22187 Mdot
.28571 .00928 Mdot
.29048 .25924 Mdot
.29524 .24203 Mdot
.3 .2711 Mdot
.30476 .00525 Mdot
.30952 .01134 Mdot
.31429 .4411 Mdot
.31905 .035 Mdot
.32381 .02402 Mdot
.32857 .05322 Mdot
.33333 .07932 Mdot
.3381 .20211 Mdot
.34286 .09467 Mdot
.34762 .09097 Mdot
.35238 .27772 Mdot
.35714 .28155 Mdot
.3619 .20407 Mdot
.36667 .40879 Mdot
.37143 .5128 Mdot
.37619 .43929 Mdot
.38095 .194 Mdot
.38571 .29822 Mdot
.39048 .53032 Mdot
.39524 .00121 Mdot
.4 .01217 Mdot
.40476 .00472 Mdot
.40952 .02294 Mdot
.41429 .37751 Mdot
.41905 .54068 Mdot
.42381 .11117 Mdot
.42857 .18966 Mdot
.43333 .29084 Mdot
.4381 .46049 Mdot
.44286 .17273 Mdot
.44762 .4806 Mdot
.45238 .09952 Mdot
.45714 .13099 Mdot
.4619 .07405 Mdot
.46667 .17432 Mdot
.47143 .25311 Mdot
.47619 .25436 Mdot
.48095 .05796 Mdot
.48571 .29378 Mdot
.49048 .01774 Mdot
.49524 .19585 Mdot
.5 .10371 Mdot
.50476 .11364 Mdot
.50952 .39693 Mdot
.51429 .12468 Mdot
.51905 .26889 Mdot
.52381 .03814 Mdot
.52857 .33193 Mdot
.53333 .54065 Mdot
.5381 .15793 Mdot
.54286 .38983 Mdot
.54762 .27524 Mdot
.55238 .37312 Mdot
.55714 .14106 Mdot
.5619 .18115 Mdot
.56667 .28881 Mdot
.57143 .17321 Mdot
.57619 .02269 Mdot
.58095 .21381 Mdot
.58571 .02508 Mdot
.59048 .26715 Mdot
.59524 .00976 Mdot
.6 .0194 Mdot
.60476 .43916 Mdot
.60952 .1508 Mdot
.61429 .25454 Mdot
.61905 .44799 Mdot
.62381 .05158 Mdot
.62857 .50952 Mdot
.63333 .20084 Mdot
.64286 .06382 Mdot
.64762 .40121 Mdot
.65238 .0708 Mdot
.65714 .16146 Mdot
.6619 .08699 Mdot
.66667 .28255 Mdot
.67143 .02205 Mdot
.67619 .23468 Mdot
.68095 .0265 Mdot
.68571 .15876 Mdot
.69048 .02 Mdot
.69524 .19329 Mdot
.7 .3321 Mdot
.70476 .08472 Mdot
.70952 .11206 Mdot
.71429 .17247 Mdot
.71905 .36669 Mdot
.72381 .12036 Mdot
.72857 .32628 Mdot
.73333 .00994 Mdot
.74286 .02052 Mdot
.74762 .28656 Mdot
.75238 .48747 Mdot
.75714 .2713 Mdot
.7619 .23455 Mdot
.76667 .09546 Mdot
.77143 .02936 Mdot
.77619 .11591 Mdot
.78095 .21826 Mdot
.78571 .07234 Mdot
.79048 .39843 Mdot
.79524 .01549 Mdot
.8 .51897 Mdot
.80476 .03014 Mdot
.80952 .10358 Mdot
.81429 .45692 Mdot
.81905 .04791 Mdot
.82381 .08051 Mdot
.82857 .03329 Mdot
.83333 .27756 Mdot
.8381 .01214 Mdot
.84286 .36947 Mdot
.84762 .16222 Mdot
.85238 .02446 Mdot
.85714 .06126 Mdot
.8619 .42463 Mdot
.86667 .12845 Mdot
.87143 .26688 Mdot
.87619 .14435 Mdot
.88095 .36232 Mdot
.88571 .15662 Mdot
.89048 .37371 Mdot
.89524 .22246 Mdot
.9 .19159 Mdot
.90476 .16099 Mdot
.90952 .01694 Mdot
.91905 .15931 Mdot
.92381 .24621 Mdot
.92857 .03487 Mdot
.93333 .0379 Mdot
.9381 .01296 Mdot
.94286 .34146 Mdot
.94762 .1256 Mdot
.95238 .17877 Mdot
.95714 .21604 Mdot
.9619 .14083 Mdot
.96667 .12121 Mdot
.97143 .31349 Mdot
.97619 .0735 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool2o`000003ooooool0
003ooooo00gooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000000kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000T
ooooo`03o`000?oooooooooo027ooooo0_l0000Aooooo`;o00006oooool2o`0000Cooooo0_l0000O
ooooo`;o0000??ooool2o`0002[ooooo0_l0001Mooooo`009?ooool00ol0003oooooooooo`0Qoooo
o`;o00004Oooool2o`0001_ooooo0_l00006ooooo`;o00006oooool2o`0003kooooo0_l0000Zoooo
o`;o00008?ooool2o`0001oooooo0_l0000Jooooo`009?ooool2o`0005[ooooo0_l0000Kooooo`;o
0000O_ooool2o`0000cooooo0_l0000Oooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0
2Oooool2o`0008Wooooo0_l0000Qooooo`;o0000?Oooool2o`0002?ooooo0_l0000Tooooo`009?oo
ool00ol0003oooooooooo`09ooooo`;o0000ROooool2o`00027ooooo0_l0000Eooooo`;o00001?oo
ool2o`0000oooooo0_l0000dooooo`;o00009?ooool002Cooooo00?o0000ooooooooool08oooool2
o`0003Wooooo0_l0000Iooooo`;o0000=?ooool2o`000003ooooool0003o000001[ooooo0_l00004
ooooo`;o00003oooool2o`0002;ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`0Soooo
o`;o0000>Oooool2o`0001Wooooo0_l0000dooooo`;o000000?oooooo`000?l000007Oooool2o`00
03Kooooo0_l0000fooooo`009?ooool2o`000=;ooooo0_l0000Looooo`;o00002?ooool2o`0004Ko
oooo000Tooooo`03o`000?oooooooooo0>oooooo0_l00008ooooo`;o00001_ooool2o`0001oooooo
0_l0000Mooooo`009?ooool00ol0003oooooooooo`1Looooo`;o0000Xoooool2o`0001oooooo0ol0
000Looooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000??ooool2o`00043ooooo0_l00023
ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool04oooool2o`0000Wooooo0_l0001noooo
o`;o0000XOooool002Cooooo0_l0000Dooooo`;o0000ooooool]ooooo`009?ooool00ol0003ooooo
ooooo`3nooooo`;o0000@Oooool002Cooooo00?o0000ooooooooool07Oooool2o`00043ooooo0_l0
001Nooooo`;o0000?Oooool2o`00047ooooo000Tooooo`03o`000?oooooooooo01gooooo0_l0000/
ooooo`;o00004_ooool2o`0005kooooo0_l00020ooooo`009?ooool00ol0003oooooooooo`18oooo
o`;o000000?oooooo`000?l00000@oooool2o`000:oooooo000Tooooo`;o0000BOooool2o`0004Ko
oooo0_l0001hooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0aOooool2o`0004?ooooo
0_l0000eooooo`009?ooool00ol0003oooooooooo`35ooooo`;o0000N_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000/Oooool2o`0007Oooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo0_l0001cooooo`;o0000??ooool2
o`0002Wooooo0_l0000looooo`;o00003_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00015oooo
o`;o0000@oooool2o`0006Oooooo0_l0000looooo`;o00003_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool05_ooool2o`0000Sooooo0_l0000Sooooo`;o00006_ooool2o`0009go
oooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Ko
oooo0_l00008ooooo`;o0000?oooool2o`0009gooooo0_l0000oooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0^ooooo`;o0000Voooool2o`0000cooooo0_l0001Vooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo0_l0002Kooooo`;o00003?ooool2o`00
06Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`0006Kooooo0_l0003Jooooo`009?ooool00ol0003oooooooooo`1T
ooooo`?o0000Q_ooool2o`0005;ooooo000Tooooo`03o`000?oooooooooo06Cooooo0_l0000Qoooo
o`;o0000I?ooool2o`0005;ooooo000Tooooo`03o`000?oooooooooo08Oooooo0_l0002hooooo`00
9?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l00000F?ooool2o`0006;ooooo
0_l00014ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000=_ooool2o`000003ooooool0
003o000005Sooooo0_l0001Rooooo`;o0000A?ooool002Cooooo0_l00003ooooo`;o0000BOooool2
o`0002oooooo0_l00031ooooo`009?ooool00ol0003oooooooooo`1=ooooo`;o0000;oooool2o`00
01Sooooo0_l00011ooooo`;o0000I?ooool002Cooooo00?o0000ooooooooool0V?ooool2o`00047o
oooo0_l0000Cooooo`;o0000Coooool002Cooooo00?o0000ooooooooool0goooool2o`0000oooooo
0_l0000looooo`;o00004Oooool002Cooooo00?o0000ooooooooool0@_ooool2o`0009_ooooo0_l0
001=ooooo`;o00004Oooool002Cooooo0_l0000Uooooo`;o00007?ooool2o`0005Oooooo0_l0002;
ooooo`;o00005oooool002Cooooo00Co0000oooooooooooooooo0_l0000Hooooo`;o00001oooool2
o`0007Gooooo0_l0001aooooo`;o00006?ooool2o`0001Oooooo000Tooooo`04o`000?oooooooooo
ooooo`;o00006?ooool2o`0000Wooooo0_l0001Qooooo`;o0000Poooool2o`00037ooooo000Toooo
o`03o`000?oooooooooo00Gooooo0_l0000Oooooo`;o000000?oooooo`000?l00000G_ooool2o`00
0;Kooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o00005oooool2o`000?oo
oooo5oooool002Cooooo0_l0000Aooooo`;o0000Uoooool2o`00087ooooo0_l0000Cooooo`009?oo
ool00ol0003oooooooooo`2Yooooo`;o0000I_ooool2o`0001Wooooo0_l0000Cooooo`002Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`1>ooooo`;o0000`Oooool2o`0002kooooo0009ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0looooo`;o00004?ooool2o`0006[ooooo0_l00025ooooo`002Oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`;o0000
O?ooool2o`0008Gooooo0009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`?o00003Oooool2o`0009Cooooo0_l0001_ooooo`;o0000:oooool000Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0=ooooo`;o0000U?ooool2o`0002kooooo0_l0000oooooo`;o00001?ooool2o`0000?o
oooo0_l0000Pooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3:ooooo`;o00001oooool2o`0003;ooooo0_l0000Aooooo`;o
00000oooool2o`00023ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0<[ooooo0_l0000kooooo`;o0000>?ooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`;o0000QOooool2o`0002Sooooo0_l0000/ooooo`;o0000Hoooool002Cooooo00?o
0000ooooooooool0Q?ooool2o`0000Kooooo0_l0000Pooooo`;o0000;?ooool2o`0006?ooooo000T
ooooo`03o`000?oooooooooo08cooooo0_l0002Kooooo`;o00005_ooool002Cooooo00?o0000oooo
ooooool0>?ooool2o`00077ooooo0_l0001looooo`;o00005_ooool002Cooooo00?o0000oooooooo
ool0>?ooool2o`00077ooooo0_l0002Dooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0Ooooool2o`0009Oooooo0_l0000Wooooo`009?ooool00ol0003oooooooooo`1`
ooooo`;o00003Oooool2o`0005Gooooo0_l00010ooooo`;o00009oooool002Cooooo00?o0000oooo
ooooool0L?ooool2o`0002?ooooo0_l0000oooooo`;o0000JOooool002Cooooo00?o0000oooooooo
ool06?ooool2o`0007_ooooo0_l0000[ooooo`;o0000OOooool002Cooooo1?l0000Gooooo`;o0000
;oooool2o`0001Oooooo0_l00006ooooo`;o0000E_ooool2o`0007gooooo000Tooooo`04o`000?oo
oooo0000o`0004Sooooo0_l0000Gooooo`;o00001_ooool2o`000=Gooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`0eooooo`;o0000N_ooool2o`0007Sooooo0_l0000Dooooo`009?ooool2o`0003Ko
oooo0_l0001jooooo`;o0000?oooool2o`0003Oooooo0_l0000Dooooo`009?ooool00ol0003ooooo
ooooo`1@ooooo`;o0000X?ooool2o`0002?ooooo0_l0000Xooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`1@ooooo`;o0000aOooool2o`0002Sooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o0000oooooolaooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`;o00008Oooool2o`000?oooooo3_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000booooo`;o0000W?ooool2o`0001[ooooo0_l0001Cooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0=3ooooo0_l0000Jooooo`;o
0000Doooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l00016ooooo`;o0000joooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo00cooooo0_l00016ooooo`;o0000b_ooool2o`0001oooooo000Tooooo`;o0000oooooolRoooo
o`;o00007oooool002Cooooo00?o0000ooooooooool0SOooool2o`000;;ooooo000Tooooo`03o`00
0?oooooooooo08gooooo1?l0000[ooooo`;o0000Poooool002Cooooo00?o0000ooooooooool0Dooo
ool2o`0003[ooooo0_l0000[ooooo`;o0000Poooool002Cooooo00?o0000ooooooooool0Doooool2
o`000>cooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`2Mooooo`;o
00005Oooool2o`0005Wooooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000
5?ooool2o`0004Gooooo0_l0000Eooooo`;o0000=?ooool2o`0002?ooooo0_l0000`ooooo`009?oo
ool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0001Cooooo0_l0001>ooooo`;o0000@_oo
ool2o`0005Gooooo000Tooooo`03o`000?oooooooooo037ooooo0_l0000dooooo`;o0000?Oooool2
o`0005_ooooo0_l0000looooo`009?ooool2o`0006Sooooo0ol0002Iooooo`;o0000??ooool002Co
oooo00?o0000ooooooooool0@oooool2o`0002?ooooo0_l0001Sooooo`;o0000L_ooool002Cooooo
00?o0000ooooooooool0@oooool2o`0008Sooooo0_l0000Hooooo`;o0000F?ooool002Cooooo00?o
0000ooooooooool01oooool2o`000:?ooooo0_l0000iooooo`;o0000F?ooool002Cooooo00?o0000
ooooooooool01oooool2o`0007Sooooo0_l0000?ooooo`;o00006?ooool2o`0009?ooooo000Toooo
o`;o0000P_ooool2o`0000oooooo0_l0002]ooooo`009?ooool00ol0003oooooooooo`1booooo`;o
0000cOooool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo
0_l0003=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_oo
ool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Loooo
o`03o`000?oooooooooo00Gooooo0ol0003ooooood;ooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolaooooo`;o00003oooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooooc7ooooo0_l0000?ooooo`007?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000h_ooool2o`0005kooooo000Tooooo`03
o`000?oooooooooo0>7ooooo0_l0001Nooooo`009?ooool00ol0003oooooooooo`2Pooooo`;o0000
=_ooool2o`0006Oooooo000Tooooo`03o`000?oooooooooo0:3ooooo0_l0000fooooo`;o0000Iooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo:?ooool2o`00
01Wooooo000Tooooo`03o`000?oooooooooo0?oooooo9oooool2o`0001Wooooo000Tooooo`03o`00
0?oooooooooo03Oooooo0_l0003oooooo`Wooooo000Tooooo`03o`000?oooooooooo03Oooooo0_l0
003oooooo`Wooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooolCooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool0g_ooool2o`0003;ooooo0_l0
000]ooooo`009?ooool00ol0003oooooooooo`0Booooo`;o0000b_ooool2o`0002Kooooo0_l0000i
ooooo`009?ooool2o`0001?ooooo0_l0002Dooooo`;o0000G?ooool2o`0000gooooo0_l0000Zoooo
o`009?ooool00ol0003oooooooooo`2Xooooo`;o0000Joooool2o`0002[ooooo0002ooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`1kooooo`;o0000a?ooool000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0Noooool2o`000<Cooooo0004ooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0YOoo
ool2o`0009[ooooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Gooooo0_l0002Jooooo`001?ooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04Kooooo0_l0001Booooo`;o0000FOooool2o`0004[ooooo0002oooo
o`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`16ooooo`;o0000D_ooool2o`0002_ooooo0_l0000/ooooo`;o0000B_ooool0
02Cooooo0_l00038ooooo`;o0000N?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`1[ooooo`;o0000e?ooool002Cooooo00?o0000ooooooooool02_oo
ool2o`0005oooooo0_l0003Dooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000oooooolf
ooooo`009?ooool2o`0002gooooo0_l0003ooooooaCooooo000Tooooo`03o`000?oooooooooo02co
oooo0_l0003ooooooaCooooo000Tooooo`03o`000?oooooooooo0?oooooo3Oooool2o`0003?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo3Oooool2o`0003?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0F_ooool2o`0001;ooooo0_l00019ooooo`;o0000
Q_ooool002Cooooo00?o0000ooooooooool0F_ooool2o`0001;ooooo0_l00019ooooo`;o0000Q_oo
ool002Cooooo00?o0000ooooooooool09oooool2o`0009Cooooo0_l00022ooooo`009?ooool3o`00
02Oooooo0_l0002Dooooo`;o0000P_ooool002Cooooo0ol0000Jooooo`;o0000oooooolVooooo`00
2_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Jooooo`;o0000hOooool2o`0004;ooooo000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oOooool2o`0004;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`23ooooo`;o0000_?ooool000cooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`?o0000Poooool2o`000;cooooo000<ooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo
00?o0000ooooooooool0:oooool2o`000?oooooo5Oooool002Cooooo0_l0000/ooooo`;o0000FOoo
ool2o`000;Wooooo000Tooooo`03o`000?oooooooooo08Kooooo0_l0002iooooo`009?ooool00ol0
003oooooooooo`3Yooooo`;o0000E_ooool002Cooooo00?o0000ooooooooool0jOooool2o`0005Ko
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0<3ooooo
0_l0001oooooo`009?ooool2o`0006kooooo0_l0001Aooooo`;o0000Ooooool002Cooooo00?o0000
ooooooooool0KOooool2o`000=;ooooo000Tooooo`03o`000?oooooooooo0?Sooooo0_l00017oooo
o`009?ooool00ol0003oooooooooo`3hooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0Loooool2
o`000<cooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Loooool2
o`000<cooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03
o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001looooo`;o00008oooool2o`0009kooooo
0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0O?ooool2o`0002?ooooo0_l0002Nooooo`001?oo
ool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0?oooool2o`000?oooooo0Oooool002Cooooo0_l0000`ooooo`;o00003_ooool2o`00
0?oooooo0Oooool002Cooooo00?o0000ooooooooool0;oooool2o`000?oooooo4Oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo
@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo
@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo
0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[Zj
oooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_o
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .57018 Mdot
.03333 .03467 Mdot
.0381 .07301 Mdot
.04286 .19596 Mdot
.05238 .02206 Mdot
.05714 .24079 Mdot
.0619 .01872 Mdot
.06667 .34315 Mdot
.07143 .34675 Mdot
.07619 .1577 Mdot
.08095 .16101 Mdot
.08571 .19156 Mdot
.09048 .25833 Mdot
.09524 .04246 Mdot
.1 .06989 Mdot
.10476 .06191 Mdot
.10952 .14097 Mdot
.11429 .3516 Mdot
.11905 .07826 Mdot
.12381 .15969 Mdot
.12857 .06093 Mdot
.13333 .08532 Mdot
.1381 .08315 Mdot
.14286 .00228 Mdot
.14762 .00834 Mdot
.15238 .10915 Mdot
.15714 .46164 Mdot
.1619 .09851 Mdot
.16667 .53661 Mdot
.17143 .45666 Mdot
.17619 .17844 Mdot
.18095 .48181 Mdot
.18571 .21448 Mdot
.19048 .12558 Mdot
.19524 .00823 Mdot
.2 .36192 Mdot
.20476 .2843 Mdot
.20952 .06464 Mdot
.21429 .05166 Mdot
.21905 .05445 Mdot
.22381 .17251 Mdot
.22857 .61651 Mdot
.23333 .25963 Mdot
.2381 .04269 Mdot
.24286 .31631 Mdot
.24762 .07524 Mdot
.25238 .50039 Mdot
.25714 .05699 Mdot
.2619 .19819 Mdot
.26667 .14915 Mdot
.27143 .0243 Mdot
.27619 .16882 Mdot
.28095 .09269 Mdot
.28571 .00928 Mdot
.29048 .17944 Mdot
.29524 .26139 Mdot
.3 .25949 Mdot
.30476 .00525 Mdot
.30952 .12666 Mdot
.31429 .48015 Mdot
.31905 .0235 Mdot
.32381 .01263 Mdot
.32857 .05322 Mdot
.33333 .08733 Mdot
.3381 .06875 Mdot
.34286 .01292 Mdot
.34762 .2841 Mdot
.35238 .17102 Mdot
.35714 .28915 Mdot
.3619 .19164 Mdot
.36667 .43357 Mdot
.37143 .43232 Mdot
.37619 .47088 Mdot
.38095 .20089 Mdot
.38571 .26164 Mdot
.39048 .44308 Mdot
.39524 .02834 Mdot
.4 .0125 Mdot
.40476 .07793 Mdot
.40952 .08311 Mdot
.41429 .43984 Mdot
.41905 .54498 Mdot
.42381 .31885 Mdot
.42857 .30411 Mdot
.43333 .08437 Mdot
.4381 .41262 Mdot
.44286 .10917 Mdot
.44762 .37699 Mdot
.45238 .07056 Mdot
.45714 .13099 Mdot
.4619 .24807 Mdot
.46667 .20951 Mdot
.47143 .14458 Mdot
.47619 .27048 Mdot
.48095 .02447 Mdot
.48571 .2173 Mdot
.49048 .0327 Mdot
.49524 .26746 Mdot
.5 .23794 Mdot
.50476 .1518 Mdot
.50952 .44771 Mdot
.51429 .10998 Mdot
.51905 .20956 Mdot
.52381 .15212 Mdot
.52857 .285 Mdot
.53333 .57199 Mdot
.5381 .25795 Mdot
.54286 .53433 Mdot
.54762 .27524 Mdot
.55238 .3755 Mdot
.55714 .07539 Mdot
.5619 .16194 Mdot
.56667 .1832 Mdot
.57143 .13758 Mdot
.57619 .00163 Mdot
.58095 .16327 Mdot
.58571 .02203 Mdot
.59048 .40038 Mdot
.59524 .08226 Mdot
.6 .0194 Mdot
.60476 .41746 Mdot
.60952 .09155 Mdot
.61429 .22481 Mdot
.61905 .5541 Mdot
.62381 .14658 Mdot
.62857 .50491 Mdot
.63333 .11281 Mdot
.64286 .08962 Mdot
.64762 .37934 Mdot
.65238 .07674 Mdot
.65714 .1903 Mdot
.6619 .08699 Mdot
.66667 .28788 Mdot
.67143 .20359 Mdot
.67619 .10848 Mdot
.68095 .07326 Mdot
.68571 .30528 Mdot
.69048 .02 Mdot
.69524 .07897 Mdot
.7 .26761 Mdot
.70476 .07945 Mdot
.70952 .13548 Mdot
.71429 .08735 Mdot
.71905 .27039 Mdot
.72381 .14716 Mdot
.72857 .39142 Mdot
.73333 .08406 Mdot
.74286 .03018 Mdot
.74762 .12767 Mdot
.75238 .53422 Mdot
.75714 .20698 Mdot
.7619 .23455 Mdot
.76667 .08459 Mdot
.77143 .12368 Mdot
.77619 .07409 Mdot
.78095 .08892 Mdot
.78571 .11048 Mdot
.79048 .39843 Mdot
.79524 .18096 Mdot
.8 .3502 Mdot
.80476 .03014 Mdot
.80952 .11956 Mdot
.81429 .48393 Mdot
.81905 .05506 Mdot
.82381 .05154 Mdot
.82857 .08066 Mdot
.83333 .3431 Mdot
.8381 .07855 Mdot
.84286 .34874 Mdot
.84762 .06557 Mdot
.85238 .02446 Mdot
.85714 .09285 Mdot
.8619 .45273 Mdot
.86667 .06244 Mdot
.87143 .25455 Mdot
.87619 .22743 Mdot
.88095 .25716 Mdot
.88571 .12905 Mdot
.89048 .37243 Mdot
.89524 .09571 Mdot
.9 .20659 Mdot
.90476 .20602 Mdot
.90952 .01694 Mdot
.91905 .08973 Mdot
.92381 .30778 Mdot
.92857 .12868 Mdot
.93333 .0379 Mdot
.9381 .11588 Mdot
.94286 .4044 Mdot
.94762 .1541 Mdot
.95238 .08388 Mdot
.95714 .11538 Mdot
.9619 .14083 Mdot
.96667 .06738 Mdot
.97143 .31349 Mdot
.97619 .23038 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l0
0006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0:ooooo`;o000000?oooooo`000?ooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o00003_ooool2
o`0001_ooooo0_l00004ooooo`;o0000j?ooool002Cooooo00?o0000ooooooooool09?ooool2o`00
00kooooo0_l0000Kooooo`;o00002oooool2o`0000Cooooo0_l0000@ooooo`;o0000bOooool002Co
oooo0_l0001Oooooo`;o00001?ooool2o`00013ooooo0_l00039ooooo`009?ooool00ol0003ooooo
ooooo`09ooooo`;o0000[?ooool2o`0006;ooooo0_l0000Tooooo`009?ooool00ol0003ooooooooo
o`05ooooo`;o00000_ooool2o`000:Oooooo0_l00003ooooo`;o00006oooool2o`0004Gooooo0_l0
000Tooooo`009?ooool00ol0003oooooooooo`05ooooo`;o0000A_ooool2o`0000gooooo0_l0000b
ooooo`;o00008?ooool2o`00023ooooo0_l0000cooooo`;o0000=_ooool002Cooooo00?o0000oooo
ooooool0COooool2o`0000gooooo0_l0000Gooooo`;o00006Oooool2o`0007Oooooo0_l0000foooo
o`009?ooool2o`0007Kooooo0_l0001^ooooo`;o00004_ooool2o`0004Kooooo000Tooooo`04o`00
0?oooooo0000o`0009?ooooo0_l0001?ooooo`;o00004_ooool2o`0004Kooooo000Tooooo`04o`00
0?oooooo0000o`0009?ooooo0_l0002=ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0
oooooolTooooo`;o00007?ooool002Cooooo00?o0000ooooooooool04oooool2o`0002gooooo0_l0
003mooooo`009?ooool2o`0001Cooooo0_l0000]ooooo`;o0000oOooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0jooooo`;o00008oooool2o`0009oo
oooo0_l0000oooooo`009?ooool00ol0003oooooooooo`0jooooo`Co00008Oooool2o`0009gooooo
1?l0000oooooo`009?ooool00ol0003oooooooooo`0looooo`;o00002_ooool2o`000;Cooooo0_l0
0011ooooo`009?ooool2o`0001Oooooo0_l00006ooooo`;o0000:?ooool2o`000<Cooooo0_l0000a
ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o00001_ooool2o`0001Sooooo0_l0003=oooo
o`;o00001Oooool2o`00037ooooo000Tooooo`03o`000?oooooooooo03Sooooo0_l0000Xooooo`;o
0000Xoooool2o`0002Gooooo0_l0000Aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01Gooooo0_l0001;ooooo`;o00008oooool2o`000:Gooooo0_l0000Aooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool01?l0003oooooooooooooool2o`0001;ooooo0_l0001`ooooo`;o
0000B?ooool2o`0001gooooo0_l0001?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000003oooo
ool0003o000004;ooooo0_l0000aooooo`;o0000;oooool2o`0001gooooo0_l00007ooooo`;o0000
7Oooool2o`0004oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo0_l0
000Xooooo`;o0000<Oooool2o`0002oooooo0_l0000Mooooo`;o00003?ooool2o`000003ooooool0
003o000002Kooooo0_l000000ooooooo0000o`00000kooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`;o0000E_ooool2o`0003_ooooo0_l0
000Nooooo`;o000000?oooooo`000?l000001oooool2o`0001gooooo0_l000000ooooooo0000o`00
000Sooooo`;o00005_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool3
o`0005Kooooo0_l00006ooooo`;o0000<oooool2o`0001?ooooo0_l0000Eooooo`;o00002Oooool2
o`0003[ooooo0_l0000Fooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo
0_l0000oooooo`;o00007_ooool2o`0004;ooooo0_l00004ooooo`;o00003oooool2o`0000oooooo
0_l00003ooooo`;o0000:oooool2o`00023ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00057ooooo0_l0000?oooo
o`;o0000Eoooool2o`0000Wooooo0_l0000Eooooo`;o00005?ooool2o`0001Kooooo0_l0000Coooo
o`;o00008?ooool002Cooooo00?o0000ooooooooool0D?ooool2o`0006Sooooo0_l0001>ooooo`;o
00002oooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo02Wooooo0_l0003/ooooo`;o0000
:?ooool002Cooooo00?o0000ooooooooool0:Oooool2o`000?oooooo5oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3@ooooo`;o0000Koooool002Co
oooo0_l0000Wooooo`;o0000G?ooool2o`0001Gooooo0_l0000cooooo`;o00008Oooool2o`0004co
oooo000Tooooo`03o`000?oooooooooo02Kooooo0_l0001Looooo`;o00005Oooool2o`0002Gooooo
0_l0000_ooooo`;o0000C?ooool002Cooooo00?o0000ooooooooool0`_ooool2o`00067ooooo0_l0
0004ooooo`;o00005?ooool002Cooooo00?o0000ooooooooool0noooool2o`0002Sooooo0_l00004
ooooo`;o00005?ooool002Cooooo00?o0000ooooooooool0koooool2o`0000[ooooo0_l00014oooo
o`009?ooool2o`0003?ooooo0_l0000Uooooo`;o0000U?ooool2o`00053ooooo000Tooooo`03o`00
0?oooooooooo03;ooooo0_l0000Uooooo`;o0000S?ooool2o`0002_ooooo0_l0000<ooooo`;o0000
7Oooool002Cooooo00?o0000ooooooooool0ROooool2o`0005cooooo0_l0000[ooooo`;o00003?oo
ool2o`0001gooooo000Tooooo`03o`000?oooooooooo08Wooooo0_l0001@ooooo`;o0000I?ooool0
02Cooooo00?o0000ooooooooool0[_ooool2o`0002_ooooo0_l0001Tooooo`009?ooool2o`0001Wo
oooo0_l0002Dooooo`;o0000O?ooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo01Sooooo
0_l0001cooooo`;o0000WOooool2o`0001?ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo08go
oooo0_l0000`ooooo`;o00007_ooool2o`00063ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1;ooooo`;o
0000Boooool2o`0002Gooooo0_l0000Nooooo`;o0000H?ooool000Wooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool2o`0004_o
oooo0_l00004ooooo`;o0000R?ooool2o`0001Oooooo0009ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`?o00003Oooool2o`0008oooooo0_l00028ooooo`;o
00005oooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0=ooooo`Co00003?ooool2o`000?oooooo8oooool000Wo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool2o`0000cooooo0_l0002<ooooo`;o00001?ooool2o`0008kooooo0009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0:_ooooo0_l00004ooooo`;o0000S_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`1>ooooo`;o0000lOooool002Cooooo0_l0000nooooo`;o
00003oooool2o`0001Oooooo0_l0003Hooooo`009?ooool00ol0003oooooooooo`0mooooo`;o0000
:?ooool2o`000=Sooooo000Tooooo`03o`000?oooooooooo02kooooo0_l0000Sooooo`;o0000k?oo
ool002Cooooo00?o0000ooooooooool0;_ooool2o`0002?ooooo0_l0002Qooooo`;o0000BOooool0
02Cooooo00?o0000ooooooooool0[?ooool2o`0004Sooooo0_l00019ooooo`009?ooool2o`000:go
oooo0_l0002Cooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o0000F?ooool2o`0005kooooo
0_l0001eooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o0000F?ooool2o`0005kooooo0_l0
001eooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000AOooool2o`000?Kooooo000Toooo
o`03o`000?oooooooooo00;ooooo0_l00015ooooo`;o00009Oooool2o`000<oooooo000Tooooo`;o
0000LOooool2o`0005cooooo0_l0001aooooo`009?ooool00ol0003oooooooooo`3>ooooo`;o0000
6_ooool2o`0002cooooo1?l0000Uooooo`009?ooool00ol0003oooooooooo`2<ooooo`;o00003ooo
ool2o`0004_ooooo0_l0000/ooooo`Co00009Oooool002Cooooo00?o0000ooooooooool0S?ooool2
o`0000oooooo0_l0002Rooooo`009?ooool00ol0003oooooooooo`0aooooo`;o0000ooooool?oooo
o`009?ooool2o`0003;ooooo0_l0001Oooooo`;o0000[Oooool002Cooooo00?o0000ooooooooool0
T_ooool2o`000:gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;cooooo0_l00023ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0_?ooool2
o`0005?ooooo0_l0000^ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
oa;ooooo0_l0000Nooooo`;o00003_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003/ooooo`;o
0000@oooool2o`0000kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0Uoooool2o`0005?ooooo0_l0001Cooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`;o0000S_ooool2o`000:Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool2o`000?oooooo>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0002;oooo
o`;o0000]Oooool002Cooooo00?o0000ooooooooool0R_ooool2o`000;Gooooo000Tooooo`03o`00
0?oooooooooo0?oooooo4?ooool2o`00033ooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0
000/ooooo`;o00005?ooool2o`0004_ooooo0_l0001Zooooo`;o000000?oooooo`000?l00000;Ooo
ool002Cooooo00?o0000ooooooooool04_ooool2o`0002cooooo0_l0000Booooo`Co00006_ooool2
o`0002oooooo0_l0001]ooooo`;o0000;Oooool002Cooooo0_l0001Eooooo`;o00007?ooool2o`00
0<gooooo000Tooooo`03o`000?oooooooooo09Gooooo0_l00011ooooo`;o0000Ioooool002Cooooo
00?o0000ooooooooool0Soooool2o`0000Cooooo0_l00011ooooo`;o00001?ooool2o`00067ooooo
000Tooooo`03o`000?oooooooooo08oooooo0_l0000Eooooo`;o0000=_ooool2o`00067ooooo000T
ooooo`03o`000?oooooooooo0:Kooooo0_l0002Iooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0=oooool2o`0002cooooo0_l0003Jooooo`009?ooool00ol0003ooooo
ooooo`0gooooo`;o0000;?ooool2o`0003Wooooo0_l0002Oooooo`009?ooool00ol0003ooooooooo
o`1Xooooo`;o0000=_ooool2o`0002_ooooo0_l0001booooo`009?ooool00ol0003oooooooooo`1X
ooooo`;o0000Hoooool2o`0007;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Oooo
ool2o`0005;ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07oooooo0_l0001Booooo`;o0000Boooool2o`0001oooooo000Looooo`03o`000?oooooooooo
00Gooooo0ol0003oooooob7ooooo0_l0000Oooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo<Oooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0@oooool2o`000>_ooooo0_l0000?ooooo`007?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04?ooooo0_l0000iooooo`;o0000`Oooool001[ooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`1nooooo`;o0000`Oooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l0000;ooooo`;o0000moooool2o`0003cooooo000Tooooo`03
o`000?oooooooooo00[ooooo0_l0003gooooo`;o0000??ooool002Cooooo00?o0000ooooooooool0
3?ooool2o`000?Sooooo0_l0000iooooo`009?ooool00ol0003oooooooooo`0<ooooo`;o00003?oo
ool2o`000=cooooo0_l0000<ooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool06_ooool2
o`000=cooooo0_l00017ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0eooooo`;o0000ooooool;ooooo`009?oo
ool00ol0003oooooooooo`0eooooo`;o0000ooooool;ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooolGooooo`;o0000:_ooool002Cooooo00?o0000oooooooo
ool0Q_ooool2o`00023ooooo0_l0001[ooooo`;o0000:_ooool000;ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo08Kooooo0_l0000Pooooo`;o00007Oooool2o`0007Sooooo0004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0<Oooooo0_l0001hooooo`001?ooool00ol0003ooooo
ooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0>7ooooo0_l0001Nooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Qooooo`;o0000G_ooool0
00Cooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3eooooo`;o0000B_ooool000;ooooo00?oEEEEofIV
I_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo0;Cooooo0_l0000oooooo`;o0000B_ooool002Cooooo0_l0002eooooo`;o0000L?ooool2o`00
01Wooooo000Tooooo`03o`000?oooooooooo0?oooooo9oooool2o`0001Wooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Poooool2o`000;cooooo000T
ooooo`03o`000?oooooooooo08?ooooo0_l0002looooo`009?ooool2o`000;[ooooo0_l00026oooo
o`009?ooool00ol0003oooooooooo`2iooooo`;o0000Q_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo06gooooo0_l0003Booooo`009?ooool2o`0006cooooo1?l0003Booooo`009?ooool00ol0003o
ooooooooo`1[ooooo`;o0000e?ooool002Cooooo00?o0000ooooooooool0Noooool2o`000<Cooooo
000Tooooo`03o`000?oooooooooo07?ooooo0_l00006ooooo`;o0000a?ooool002Cooooo00?o0000
ooooooooool0Loooool2o`0002Gooooo0_l0002Uooooo`009?ooool2o`0009_ooooo0_l0002Uoooo
o`009?ooool00ol0003oooooooooo`3oooooo`gooooo0_l0000cooooo`002_ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0/ooooo`;o0000g_ooool2o`0003?ooooo000<ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;?ooool2o`000?oooooo
5?ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Oooooo0_l0003ooooooaWooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0002Oooooo0_l0003ooooooaWooooo000<ooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06kooooo0_l0003Aooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0K_ooool2o`000=7ooooo000:ooooo`03oeEEEOmVIVKo000000gooooo
1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0000`ooooo`;o0000:Ooo
ool2o`000>Gooooo000Tooooo`03o`000?oooooooooo02oooooo0_l0000Yooooo`;o0000XOooool2
o`0004;ooooo000Tooooo`03o`000?oooooooooo0?gooooo0_l00012ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo04Kooooo0_l0003iooooo`009?ooool00ol0
003oooooooooo`16ooooo`;o0000nOooool002Cooooo00?o0000ooooooooool0`?ooool2o`0007oo
oooo000Tooooo`03o`000?oooooooooo0<3ooooo0_l0001oooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0:Gooooo0_l00012
ooooo`;o0000E_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02_ooooo0_l0001hoooo
o`;o0000@_ooool2o`0005Kooooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo0_l0003ooooooaGo
oooo0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07cooooo
0_l00033ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1looooo`;o0000`oooool000Cooooo00?o0000
ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004
ooooo`Co00001_ooool00ol0003oooooooooo`2mooooo`;o0000P_ooool002Cooooo0_l0002noooo
o`;o0000P_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0ol0003o
oooood;ooooo000Tooooo`?o0000XOooool2o`0009kooooo000Tooooo`03o`000?oooooooooo0:7o
oooo0_l0002Nooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo03oooooo0_l0003oooooo`7ooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000oooooo`;o0000ooooool1ooooo`007?ooool00omg
MgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wooooo
00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .59301 Mdot
.03333 .1702 Mdot
.0381 .13404 Mdot
.04286 .18169 Mdot
.05238 .0249 Mdot
.05714 .38729 Mdot
.0619 .12446 Mdot
.06667 .23935 Mdot
.07143 .27979 Mdot
.07619 .22521 Mdot
.08095 .08299 Mdot
.08571 .06792 Mdot
.09048 .06589 Mdot
.09524 .00464 Mdot
.1 .14042 Mdot
.10476 .06191 Mdot
.10952 .03618 Mdot
.11429 .3516 Mdot
.11905 .07826 Mdot
.12381 .23275 Mdot
.12857 .01467 Mdot
.13333 .01953 Mdot
.1381 .10438 Mdot
.14286 .00228 Mdot
.14762 .00834 Mdot
.15238 .05603 Mdot
.15714 .46164 Mdot
.1619 .03289 Mdot
.16667 .51199 Mdot
.17143 .36659 Mdot
.17619 .1345 Mdot
.18095 .36665 Mdot
.18571 .16755 Mdot
.19048 .13312 Mdot
.19524 .00823 Mdot
.2 .34468 Mdot
.20476 .13238 Mdot
.20952 .08193 Mdot
.21429 .06261 Mdot
.21905 .16128 Mdot
.22381 .09622 Mdot
.22857 .59799 Mdot
.23333 .17306 Mdot
.2381 .04215 Mdot
.24286 .20249 Mdot
.24762 .05462 Mdot
.25238 .53255 Mdot
.25714 .06493 Mdot
.2619 .24186 Mdot
.26667 .04171 Mdot
.27143 .00909 Mdot
.27619 .11938 Mdot
.28095 .23003 Mdot
.28571 .00928 Mdot
.29048 .32206 Mdot
.29524 .32653 Mdot
.3 .36459 Mdot
.30476 .0078 Mdot
.30952 .06752 Mdot
.31429 .42488 Mdot
.31905 .03563 Mdot
.32381 .02664 Mdot
.32857 .07122 Mdot
.33333 .05606 Mdot
.3381 .06875 Mdot
.34286 .01664 Mdot
.34762 .2841 Mdot
.35238 .08542 Mdot
.35714 .23608 Mdot
.3619 .19279 Mdot
.36667 .46391 Mdot
.37143 .47861 Mdot
.37619 .47208 Mdot
.38095 .10474 Mdot
.38571 .26164 Mdot
.39524 .02834 Mdot
.4 .08773 Mdot
.40476 .07652 Mdot
.40952 .02179 Mdot
.41429 .35935 Mdot
.41905 .50095 Mdot
.42381 .39261 Mdot
.42857 .35776 Mdot
.43333 .15758 Mdot
.4381 .18751 Mdot
.44286 .17511 Mdot
.44762 .33832 Mdot
.45238 .12945 Mdot
.45714 .08518 Mdot
.4619 .28241 Mdot
.46667 .22232 Mdot
.47143 .22513 Mdot
.47619 .31907 Mdot
.48095 .02447 Mdot
.48571 .25626 Mdot
.49048 .21663 Mdot
.49524 .24901 Mdot
.5 .36885 Mdot
.50476 .26861 Mdot
.50952 .37057 Mdot
.51429 .20953 Mdot
.51905 .24144 Mdot
.52381 .02434 Mdot
.52857 .20191 Mdot
.53333 .57287 Mdot
.5381 .33543 Mdot
.54286 .53433 Mdot
.54762 .27446 Mdot
.55238 .2631 Mdot
.55714 .07539 Mdot
.5619 .24259 Mdot
.56667 .33766 Mdot
.57143 .14882 Mdot
.57619 .04894 Mdot
.58095 .16824 Mdot
.58571 .04439 Mdot
.59048 .3366 Mdot
.59524 .08226 Mdot
.6 .03148 Mdot
.60476 .40482 Mdot
.60952 .04617 Mdot
.61429 .04275 Mdot
.61905 .47521 Mdot
.62381 .20064 Mdot
.62857 .55461 Mdot
.63333 .06109 Mdot
.6381 .60219 Mdot
.64286 .08962 Mdot
.64762 .34838 Mdot
.65238 .13277 Mdot
.65714 .3148 Mdot
.6619 .01445 Mdot
.66667 .17216 Mdot
.67143 .22722 Mdot
.67619 .00386 Mdot
.68095 .06836 Mdot
.68571 .1674 Mdot
.69048 .10909 Mdot
.69524 .04887 Mdot
.7 .18934 Mdot
.70476 .14295 Mdot
.70952 .13282 Mdot
.71429 .00216 Mdot
.71905 .2452 Mdot
.72381 .0359 Mdot
.72857 .28604 Mdot
.73333 .08305 Mdot
.74286 .00641 Mdot
.74762 .25552 Mdot
.75238 .37364 Mdot
.75714 .17983 Mdot
.7619 .07942 Mdot
.76667 .08459 Mdot
.77143 .12015 Mdot
.77619 .07409 Mdot
.78095 .075 Mdot
.78571 .01602 Mdot
.79048 .30912 Mdot
.79524 .18892 Mdot
.8 .46152 Mdot
.80476 .02951 Mdot
.80952 .10472 Mdot
.81905 .03167 Mdot
.82381 .01397 Mdot
.82857 .19923 Mdot
.83333 .2944 Mdot
.8381 .07685 Mdot
.84286 .23776 Mdot
.84762 .06557 Mdot
.85238 .04144 Mdot
.85714 .15711 Mdot
.8619 .35206 Mdot
.86667 .06244 Mdot
.87143 .25155 Mdot
.87619 .32389 Mdot
.88095 .36278 Mdot
.88571 .05113 Mdot
.89048 .27269 Mdot
.89524 .21722 Mdot
.9 .21017 Mdot
.90476 .20764 Mdot
.90952 .03765 Mdot
.91429 .53743 Mdot
.91905 .07282 Mdot
.92381 .28335 Mdot
.92857 .10735 Mdot
.93333 .0379 Mdot
.9381 .11588 Mdot
.94286 .38843 Mdot
.94762 .20087 Mdot
.95238 .11257 Mdot
.95714 .05557 Mdot
.9619 .10986 Mdot
.96667 .28084 Mdot
.97143 .39025 Mdot
.97619 .09895 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01oooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
000Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`07ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0C
ooooo`;o00003oooool2o`0000kooooo0_l0000Gooooo`;o00000_ooool2o`0000Cooooo0_l0002<
ooooo`;o0000F_ooool002Cooooo00?o0000ooooooooool09?ooool2o`0000kooooo0_l0000Goooo
o`;o00000_ooool2o`0000Cooooo0_l0003Xooooo`009?ooool2o`0001oooooo0_l0002[ooooo`;o
00009_ooool2o`0000_ooooo0_l0000oooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000
A?ooool2o`0006Gooooo0_l0000Vooooo`;o00002oooool2o`0003oooooo000Tooooo`03o`000?oo
oooooooo023ooooo0_l00012ooooo`;o00004oooool2o`000<Kooooo000Tooooo`03o`000?oooooo
oooo00Gooooo0_l0000Iooooo`;o0000Eoooool2o`0001Gooooo0_l0000<ooooo`;o0000XOooool0
02Cooooo00?o0000ooooooooool01Oooool2o`0005Oooooo0_l0000Eooooo`;o00006Oooool2o`00
00cooooo0_l0002Qooooo`009?ooool2o`0005oooooo0_l0000Eooooo`;o0000@?ooool2o`00043o
oooo0_l00003ooooo`;o0000@Oooool002Cooooo00?o0000ooooooooool0:Oooool2o`0008cooooo
0_l00010ooooo`;o00000oooool2o`00047ooooo000Tooooo`03o`000?oooooooooo01Sooooo0_l0
000?ooooo`;o0000<Oooool2o`00087ooooo0_l0000jooooo`;o00001_ooool2o`0001cooooo000T
ooooo`03o`000?oooooooooo01Sooooo0_l00012ooooo`;o0000POooool2o`0003[ooooo0_l00006
ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo0_l0001_oooo
o`;o0000Boooool2o`0003Kooooo000Tooooo`;o0000@oooool2o`0000Oooooo0_l0001Uooooo`;o
00001_ooool4o`0004_ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`2_ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0001[ooooo0_l0001Yooooo`009?ooool00ol0003ooooooooo
o`2_ooooo`;o00009Oooool2o`0003cooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`0V
ooooo`;o00007Oooool2o`0001[ooooo0_l0002aooooo`;o00005Oooool2o`0001Cooooo000Toooo
o`03o`000?oooooooooo02Kooooo0_l0000Mooooo`;o00006_ooool2o`000<Sooooo0_l0000Doooo
o`009?ooool2o`0001Oooooo0_l0000Rooooo`;o0000Q_ooool2o`0004[ooooo0_l0000aooooo`00
9?ooool00ol0003oooooooooo`0Fooooo`;o00008_ooool2o`0000cooooo0_l0001hooooo`;o0000
@oooool2o`0000Gooooo0_l0000aooooo`009?ooool00ol0003oooooooooo`0@ooooo`Co0000=?oo
ool2o`0000oooooo0_l00007ooooo`;o0000KOooool2o`0003Cooooo0_l0000hooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo013ooooo1?l00015ooooo`;o00001?ooool2o`000003
ooooool0003o000006gooooo0_l0001^ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Oooooo`;o0000Soooool2o`0002gooooo0_l0000Pooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool3o`0007Sooooo0_l0000_ooooo`;o0000AOooool4o`00013ooooo0_l0000Ioooo
o`;o00008?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool06oooool2o`0005_o
oooo0_l0000_ooooo`;o0000@Oooool2o`0000Cooooo0_l0000@ooooo`;o0000>oooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0?ooooo`;o00002_ooool2o`0001_o
oooo0_l0001looooo`;o0000:_ooool2o`0000Sooooo0_l0001Cooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0?ooooo`;o00009oooool2o`0002gooooo0_l0000Pooooo`;o0000
:oooool2o`0002[ooooo0_l00009ooooo`;o0000D_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Wooooo`;o00003Oooool2o`00017ooooo0_l0000jooooo`;o00009_ooool2o`00
05;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`0007Oooooo0_l0001=ooooo`;o0000N_ooool002Cooooo00?o0000
ooooooooool0?Oooool2o`000?oooooo0oooool002Cooooo00?o0000ooooooooool0?Oooool2o`00
0?;ooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`3ooooooc;ooooo0_l0000>ooooo`00
9?ooool00ol0003oooooooooo`0Qooooo`;o0000COooool2o`0008Wooooo0_l00014ooooo`009?oo
ool00ol0003oooooooooo`0Qooooo`;o0000COooool2o`0008Wooooo0_l0000Uooooo`;o00007Ooo
ool002Cooooo0_l0003Eooooo`;o0000C?ooool2o`0000Sooooo0_l0000Cooooo`009?ooool00ol0
003oooooooooo`3Dooooo`;o0000Doooool2o`000003ooooool0003o000001?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo9_ooool2o`0000;ooooo0_l0000Fooooo`009?ooool00ol0003ooooo
ooooo`1>ooooo`;o0000Woooool2o`0003Cooooo0_l0000Jooooo`009?ooool00ol0003ooooooooo
o`1>ooooo`;o0000Woooool2o`00053ooooo000Tooooo`;o00002_ooool2o`000?oooooo=oooool0
02Cooooo00?o0000ooooooooool02Oooool2o`0007cooooo0_l0002hooooo`009?ooool00ol0003o
ooooooooo`0booooo`;o00000oooool2o`0004kooooo0_l0000oooooo`;o00004Oooool2o`0006Co
oooo000Tooooo`04o`000?ooooooooooooooo`;o0000:oooool2o`0000;ooooo0_l00003ooooo`;o
0000Soooool2o`00017ooooo0_l0001Tooooo`009?ooool01?l0003oooooooooooooool2o`0002_o
oooo0_l0003ooooooa;ooooo000Tooooo`;o00005_ooool2o`000?oooooo:oooool002Cooooo00?o
0000ooooooooool05Oooool2o`000<;ooooo0_l0001Vooooo`002Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2^ooooo`;o0000:Oooool2o`0006Kooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2^ooooo`;o0000
TOooool000Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom2ooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool3o`00087ooooo0_l00027ooooo`;o0000=Oooool000Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0looooo`;o0000@oooool2o`0008Oooooo0_l0000eooooo`002Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0looooo`;o
0000ooooool4ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3Cooooo`;o0000K?ooool000Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool01?l0003oooooo`000?l0000`ooooo`;o0000O_ooool2o`00
023ooooo0_l0001/ooooo`009?ooool4o`00033ooooo0_l0000=ooooo`;o0000Koooool2o`0001[o
oooo0_l0001booooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000@_ooool2o`0004Oooooo
0_l0001booooo`009?ooool00ol0003oooooooooo`24ooooo`;o0000^oooool002Cooooo00?o0000
ooooooooool00_ooool2o`000>Kooooo0_l0001Eooooo`009?ooool00ol0003oooooooooo`02oooo
o`;o0000i_ooool2o`0005Gooooo000Tooooo`;o0000Q?ooool2o`00077ooooo0_l00019ooooo`00
9?ooool00ol0003oooooooooo`23ooooo`;o0000Doooool2o`0001cooooo0_l00019ooooo`009?oo
ool00ol0003oooooooooo`1Zooooo`;o0000K?ooool2o`0006Oooooo000Tooooo`03o`000?oooooo
oooo06[ooooo0_l0003Eooooo`009?ooool00ol0003oooooooooo`2oooooo`;o0000@?ooool2o`00
02Gooooo0_l0000Gooooo`009?ooool2o`0004Cooooo0_l0001Kooooo`;o00007Oooool2o`00043o
oooo0_l0000Uooooo`;o00005oooool002Cooooo00?o0000ooooooooool0@oooool2o`0005_ooooo
0_l0002Oooooo`009?ooool00ol0003oooooooooo`2Kooooo`;o0000Noooool4o`0002Gooooo000T
ooooo`03o`000?oooooooooo09_ooooo0_l0001kooooo`Co00009Oooool002Cooooo00?o0000oooo
ooooool0U?ooool2o`000:_ooooo000Tooooo`;o0000UOooool2o`00087ooooo0_l0000Xooooo`00
9?ooool00ol0003oooooooooo`2<ooooo`;o0000ROooool2o`0002Sooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo00gooooo0_l0001mooooo`?o0000/_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00gooooo0_l0001nooooo`;o0000?oooool2
o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo0_l0001loooo
o`;o0000LOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Mooooo`;o0000<Oooool2o`000>oo
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07Oooool2o`0004Wo
oooo0_l0002Looooo`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
3?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool2o`0005cooooo0_l0000cooooo`;o0000Ioooool2o`0003Wooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool2o`0003gooooo0_l0001Booooo`;o00003?ooool2o`00
09Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool0
0ol0003oooooooooo`19ooooo`;o0000H?ooool2o`00037ooooo0_l0001Qooooo`009?ooool2o`00
09Kooooo0_l00017ooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0UOooool2o`0007So
oooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`2Booooo`;o0000Doooool2o`0002Kooooo
0_l0000`ooooo`009?ooool00ol0003oooooooooo`2Booooo`;o0000Doooool2o`0005Sooooo000T
ooooo`03o`000?oooooooooo07;ooooo0_l0003=ooooo`009?ooool2o`0007?ooooo0_l0000doooo
o`;o0000Uoooool002Cooooo00?o0000ooooooooool0V?ooool2o`0000kooooo0_l0002Gooooo`00
9?ooool00ol0003oooooooooo`2Hooooo`;o0000Yoooool002Cooooo00?o0000ooooooooool0Y_oo
ool2o`0006gooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`2Vooooo`;o0000KOooool2
o`0002[ooooo000Tooooo`;o00003Oooool2o`000?oooooo8Oooool2o`00017ooooo000Tooooo`03
o`000?oooooooooo00cooooo0_l0001Gooooo`;o00008oooool2o`0009Cooooo0_l0000<ooooo`;o
00004Oooool002Cooooo00?o0000ooooooooool0IOooool2o`0002?ooooo0_l0001Eooooo`;o0000
?Oooool2o`0001oooooo000Tooooo`03o`000?oooooooooo0>7ooooo0_l0001Nooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000ooooool5ooooo`;o0000??ooool002Co
oooo00?o0000ooooooooool0ooooool4ooooo`;o0000??ooool001[ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0mOooool2o`0004[ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0003eoooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3:ooooo`;o
0000MOooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3:ooooo`;o0000
MOooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2?ooooo`;o0000/?oo
ool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1Cooooo`;o0000>_ooool2
o`00083ooooo0_l0000^ooooo`009?ooool2o`0005Cooooo0ol0002kooooo`;o0000;_ooool002Co
oooo00?o0000ooooooooool0E?ooool2o`000>_ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0Xoooool2o`0000oooooo0_l0002;ooooo`009?ooool0
0ol0003oooooooooo`26ooooo`;o00006oooool2o`0000Oooooo0_l00006ooooo`;o0000Roooool0
02Cooooo0_l00027ooooo`;o00009?ooool2o`0009?ooooo000Tooooo`03o`000?oooooooooo03Go
oooo0_l0003oooooo`_ooooo000Tooooo`03o`000?oooooooooo03Gooooo0_l0002@ooooo`;o0000
N?ooool002Cooooo00?o0000ooooooooool06_ooool2o`000:_ooooo0_l00013ooooo`;o0000<ooo
ool002Cooooo00?o0000ooooooooool06_ooool2o`000?3ooooo0_l0000cooooo`009?ooool2o`00
083ooooo0_l00030ooooo`009?ooool00ol0003oooooooooo`1kooooo`;o00000_ooool2o`000<3o
oooo000Tooooo`03o`000?oooooooooo05Kooooo0_l0000Sooooo`;o0000UOooool2o`0002gooooo
000Tooooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`00000Uooooo`;o0000^_oo
ool2o`0002gooooo000Tooooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`00001V
ooooo`;o000000?oooooo`000?l00000YOooool002Cooooo0_l0002Hooooo`;o000000?oooooo`00
0?l00000COooool2o`0005Kooooo000Tooooo`03o`000?oooooooooo0>Wooooo0_l0001Fooooo`00
0_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00007ooooo`;o0000oooooolNooooo`;o00006Oooool000Cooooo00?o0000
ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`07ooooo`;o0000oooooolNooooo`;o00002?ooool2o`0000oooooo0004
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo07kooooo0_l0002`ooooo`;o00003oooool000Cooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1nooooo`;o0000`Oooool000;ooooo00?oEEEEofIVI_l000003?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0002jooooo`;o0000Q_ooool002Cooooo00?o0000ooooooooool0^Oooool2o`0008Ko
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo05[ooooo
0_l0003Uooooo`009?ooool00ol0003oooooooooo`1Jooooo`;o0000iOooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool2o`000<oooooo0_l0
0017ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000W
ooooo`;o0000@_ooool2o`0008_ooooo0_l00017ooooo`003?ooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1[ooooo`;o0000e?ooool0
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06kooooo0_l0003Aooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0K_ooool2o`0004gooooo0_l00022ooooo`002_ooool00omEEEGoIVIV
o`00000=ooooo`Co00001_ooool00ol0003oooooooooo`1]ooooo`;o0000C_ooool2o`0008;ooooo
000Tooooo`;o0000K_ooool2o`000=;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0O?ooool2o`00
0<?ooooo000Tooooo`03o`000?oooooooooo07cooooo0_l00033ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000;?ooool2o`000?oooooo5Oooool002Cooooo00?o0000
ooooooooool0:oooool2o`000?oooooo5Oooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
00;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`16ooooo`;o0000GOooool2
o`0009[ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`16ooooo`;o0000GOooool2o`00
07Kooooo0_l0000Rooooo`001?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooakooooo0_l0000Rooooo`00
1?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_ooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool0
0ol0003oooooooooo`30ooooo`;o0000Ooooool002Cooooo0_l00031ooooo`;o0000Ooooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`000:;ooooo0_l0002Nooooo`009?ooool00ol0003oooooooooo`2Qooooo`;o
0000W_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0ol0003ooooood;ooooo
000Tooooo`?o0000?oooool2o`000?oooooo0Oooool002Cooooo00?o0000ooooooooool0?oooool2
o`0008;ooooo0_l0001looooo`009?ooool2o`000<Cooooo0_l0001looooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`3ooooood;ooooo
000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood;ooooo
000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooom2ooooo`006oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?ooool00omgMgOoIVIVooooo`3ooooo
od[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wooooo00Go0000okZj^_oooooo
V9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;ooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .07118 Mdot
.0381 .08777 Mdot
.04286 .08813 Mdot
.05238 .00131 Mdot
.05714 .39386 Mdot
.0619 .11002 Mdot
.06667 .23935 Mdot
.07143 .27979 Mdot
.07619 .27282 Mdot
.08095 .08299 Mdot
.08571 .06792 Mdot
.09048 .05096 Mdot
.09524 .00464 Mdot
.1 .18447 Mdot
.10476 .10867 Mdot
.10952 .03618 Mdot
.11429 .37721 Mdot
.11905 .15801 Mdot
.12381 .12533 Mdot
.12857 .06929 Mdot
.13333 .01953 Mdot
.1381 .07897 Mdot
.14286 .00228 Mdot
.14762 .095 Mdot
.15238 .09817 Mdot
.15714 .55937 Mdot
.1619 .11198 Mdot
.16667 .51673 Mdot
.17143 .34309 Mdot
.17619 .22981 Mdot
.18095 .27579 Mdot
.18571 .27458 Mdot
.19048 .13312 Mdot
.19524 .00823 Mdot
.2 .16957 Mdot
.20476 .04993 Mdot
.20952 .05276 Mdot
.21429 .01994 Mdot
.21905 .09549 Mdot
.22381 .13763 Mdot
.23333 .26632 Mdot
.2381 .04215 Mdot
.24286 .08447 Mdot
.24762 .11127 Mdot
.25238 .52902 Mdot
.25714 .07088 Mdot
.2619 .24047 Mdot
.26667 .04171 Mdot
.27143 .00909 Mdot
.27619 .18461 Mdot
.28095 .23003 Mdot
.28571 .02066 Mdot
.29048 .23142 Mdot
.29524 .36633 Mdot
.3 .3328 Mdot
.30476 .01621 Mdot
.30952 .06752 Mdot
.31429 .32793 Mdot
.31905 .02392 Mdot
.32381 .09176 Mdot
.32857 .07122 Mdot
.33333 .14275 Mdot
.3381 .03833 Mdot
.34286 .01664 Mdot
.34762 .32889 Mdot
.35238 .06514 Mdot
.35714 .23123 Mdot
.3619 .23323 Mdot
.36667 .44978 Mdot
.37143 .56911 Mdot
.37619 .52159 Mdot
.38095 .19223 Mdot
.38571 .2432 Mdot
.39048 .51684 Mdot
.39524 .06026 Mdot
.4 .11284 Mdot
.40476 .00352 Mdot
.40952 .01514 Mdot
.41429 .30727 Mdot
.41905 .37465 Mdot
.42381 .40408 Mdot
.42857 .42084 Mdot
.43333 .19703 Mdot
.4381 .27296 Mdot
.44286 .08083 Mdot
.44762 .32546 Mdot
.45238 .05847 Mdot
.45714 .12305 Mdot
.4619 .30499 Mdot
.46667 .26887 Mdot
.47143 .20594 Mdot
.47619 .31907 Mdot
.48095 .15406 Mdot
.48571 .16915 Mdot
.49048 .21546 Mdot
.49524 .26199 Mdot
.5 .17545 Mdot
.50476 .07762 Mdot
.50952 .50811 Mdot
.51429 .23477 Mdot
.51905 .05498 Mdot
.52381 .02434 Mdot
.52857 .01494 Mdot
.53333 .46703 Mdot
.5381 .30423 Mdot
.54286 .57052 Mdot
.54762 .48307 Mdot
.55238 .14562 Mdot
.55714 .0119 Mdot
.5619 .30855 Mdot
.56667 .37775 Mdot
.57143 .36302 Mdot
.57619 .04894 Mdot
.58095 .35236 Mdot
.58571 .0398 Mdot
.59048 .3366 Mdot
.59524 .08226 Mdot
.6 .09118 Mdot
.60476 .53924 Mdot
.60952 .04617 Mdot
.61429 .0774 Mdot
.61905 .4826 Mdot
.62381 .27671 Mdot
.62857 .44644 Mdot
.63333 .10216 Mdot
.6381 .50683 Mdot
.64286 .1117 Mdot
.64762 .26115 Mdot
.65238 .0967 Mdot
.65714 .15247 Mdot
.6619 .04898 Mdot
.66667 .20939 Mdot
.67143 .11721 Mdot
.67619 .00386 Mdot
.68095 .09889 Mdot
.68571 .17706 Mdot
.69048 .13055 Mdot
.69524 .13938 Mdot
.7 .34402 Mdot
.70476 .0488 Mdot
.70952 .16937 Mdot
.71429 .00216 Mdot
.71905 .22639 Mdot
.72381 .0359 Mdot
.72857 .14982 Mdot
.73333 .08305 Mdot
.7381 .56233 Mdot
.74286 .00641 Mdot
.74762 .20241 Mdot
.75238 .44836 Mdot
.75714 .23851 Mdot
.7619 .05166 Mdot
.76667 .18342 Mdot
.77143 .12015 Mdot
.77619 .02529 Mdot
.78095 .21065 Mdot
.78571 .03776 Mdot
.79048 .19711 Mdot
.79524 .30185 Mdot
.8 .43961 Mdot
.80476 .0253 Mdot
.80952 .13386 Mdot
.81905 .03167 Mdot
.82381 .03007 Mdot
.82857 .1085 Mdot
.83333 .37755 Mdot
.8381 .19693 Mdot
.84286 .28977 Mdot
.84762 .09593 Mdot
.85238 .02327 Mdot
.85714 .26665 Mdot
.8619 .29559 Mdot
.86667 .12771 Mdot
.87143 .16006 Mdot
.87619 .28708 Mdot
.88095 .43667 Mdot
.88571 .05005 Mdot
.89048 .18667 Mdot
.89524 .28251 Mdot
.9 .34252 Mdot
.90476 .10715 Mdot
.90952 .03643 Mdot
.91429 .55481 Mdot
.91905 .02577 Mdot
.92381 .31543 Mdot
.92857 .07229 Mdot
.93333 .03889 Mdot
.9381 .0029 Mdot
.94286 .56186 Mdot
.94762 .25925 Mdot
.95238 .03553 Mdot
.95714 .03546 Mdot
.9619 .01244 Mdot
.96667 .38335 Mdot
.97143 .37761 Mdot
.97619 .11591 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01oooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool0
3?ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000
ooooooooool04oooool2o`0001oooooo0_l0000Gooooo`;o0000U_ooool2o`0005[ooooo000Toooo
o`03o`000?oooooooooo03Cooooo0_l0000Gooooo`;o0000F_ooool2o`00087ooooo0_l0000Coooo
o`009?ooool2o`0005Sooooo0_l0000Pooooo`;o00009Oooool2o`0000Oooooo0_l00021ooooo`;o
00004oooool002Cooooo00?o0000ooooooooool0Eoooool2o`0000_ooooo0_l0000Cooooo`;o0000
9Oooool2o`0009oooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000Hooooo`;o00005Ooo
ool2o`00017ooooo0_l0003Kooooo`009?ooool00ol0003oooooooooo`0Pooooo`;o00006?ooool2
o`0001Gooooo0_l00009ooooo`;o0000@?ooool2o`00053ooooo0_l00007ooooo`;o00003_ooool2
o`0003Kooooo000Tooooo`03o`000?oooooooooo05cooooo0_l00010ooooo`;o0000D?ooool2o`00
00Oooooo0_l0000>ooooo`;o00005?ooool2o`00023ooooo000Tooooo`;o0000ooooool4o`0001go
oooo0_l0000Pooooo`009?ooool00ol0003oooooooooo`3nooooo`Co0000?oooool002Cooooo00?o
0000ooooooooool06?ooool2o`000<Gooooo0_l0000Booooo`;o00009_ooool2o`0000cooooo1?l0
000Dooooo`009?ooool00ol0003oooooooooo`0Hooooo`;o0000B?ooool2o`0004kooooo0_l0000[
ooooo`;o00004_ooool2o`0002Kooooo0_l00006ooooo`;o00001?ooool4o`0001Cooooo000Toooo
o`03o`000?oooooooooo04;ooooo0_l00007ooooo`;o00005Oooool2o`0004kooooo0_l0001_oooo
o`;o00007?ooool002Cooooo0_l00013ooooo`;o00001oooool2o`0006gooooo0_l00025ooooo`00
9?ooool00ol0003oooooooooo`0gooooo`;o0000M_ooool2o`0000Wooooo0_l0000?ooooo`;o0000
3?ooool2o`0003Wooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`0Booooo`;o00008ooo
ool3o`0007Gooooo0_l0000Jooooo`;o00003?ooool2o`00017ooooo0_l0000Vooooo`;o0000:ooo
ool002Cooooo00?o0000ooooooooool04_ooool2o`0002Cooooo0_l0001Sooooo`;o0000COooool2
o`0005?ooooo000Tooooo`03o`000?oooooooooo08Oooooo0_l0000Dooooo`;o0000X_ooool002Co
oooo0_l0001fooooo`;o00004?ooool2o`000;Sooooo000Tooooo`03o`000?oooooooooo06Oooooo
0_l0000<ooooo`;o0000b_ooool002Cooooo00?o0000ooooooooool04?ooool2o`0004Oooooo0_l0
000<ooooo`;o0000f?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003oooooo`000?l0000?oooo
o`;o00003?ooool2o`0002Sooooo0_l0000?ooooo`;o00001?ooool2o`000>3ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`04o`000?oooooo0000o`0001gooooo0_l0000Xooooo`;o0000
5Oooool2o`000<7ooooo0_l0000Mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0009Sooooo0_l0
000Rooooo`;o0000I?ooool2o`0001gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo027ooooo0_l0001Qooooo`;o00004_ooool2o`0002;ooooo0_l00023ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00oooooo0_l0000@ooooo`;o0000HOooool2
o`00033ooooo0_l0000Zooooo`;o0000GOooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool2o`0003;ooooo0_l0001aooooo`;o0000:_ooool2o`0005gooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooooooo0ol0000oooooo`;o0000o?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o00000_ooool3o`0005[ooooo0_l0001Gooooo`;o0000R?ooool002Cooooo00?o0000oooooooo
ool09?ooool2o`0001Kooooo0_l0000Pooooo`;o0000Eoooool2o`0004kooooo0_l0000hooooo`00
9?ooool00ol0003oooooooooo`0Tooooo`Co00005?ooool2o`0008[ooooo0_l00007ooooo`;o0000
=?ooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo02Kooooo0_l0002Jooooo`;o00001?oo
ool2o`0000Oooooo0_l0001^ooooo`009?ooool00ol0003oooooooooo`32ooooo`;o0000OOooool0
02Cooooo00?o0000ooooooooool05_ooool2o`000>Wooooo0_l0000Gooooo`;o00009Oooool002Co
oooo0_l0000:ooooo`;o00002oooool2o`00017ooooo0_l0000Jooooo`;o0000O_ooool2o`0003[o
oooo0_l0000Gooooo`;o00009Oooool002Cooooo00?o0000ooooooooool02Oooool2o`0001kooooo
0_l0000Jooooo`;o0000;oooool2o`0004gooooo0_l0001jooooo`009?ooool00ol0003ooooooooo
o`1fooooo`;o0000E_ooool2o`00067ooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`3>
ooooo`;o00007oooool2o`00043ooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`29oooo
o`;o0000I?ooool2o`00053ooooo000Tooooo`;o00007_ooool2o`0006[ooooo0_l0002fooooo`00
9?ooool00ol0003oooooooooo`0Mooooo`;o0000koooool2o`00037ooooo000Tooooo`03o`000?oo
oooooooo03;ooooo0_l0002Pooooo`;o0000>?ooool2o`00037ooooo000Tooooo`03o`000?oooooo
oooo03;ooooo0_l0002Pooooo`;o00009Oooool2o`0004Cooooo000Tooooo`03o`000?oooooooooo
03gooooo0_l0002Gooooo`;o00008oooool2o`0004Cooooo000Tooooo`;o0000?_ooool2o`0002;o
oooo0_l0001cooooo`;o0000JOooool002Cooooo00?o0000ooooooooool0HOooool2o`0004Gooooo
0_l0002Gooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Xooooo`;o0000Uoooool000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0>7ooooo0_l0001Nooooo`002Oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2@ooooo`;o0000>?ooool2o`0001Go
oooo0_l0001Nooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0001_ooooo0_l0001cooooo`;o0000>?ooool2o`0007Gooooo0009ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool06oooool2o`000?;ooooo0_l0000`ooooo`002Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooa3ooooo0_l0000`oooo
o`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3ooooood;ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo00?o0000ooooooooool0=Oooool2o`0005_ooooo0_l00017ooooo`;o0000I?ooool002Co
oooo0_l0000fooooo`;o0000Foooool2o`0004Oooooo0_l0001Tooooo`009?ooool00ol0003ooooo
ooooo`2Gooooo`;o0000Z?ooool002Cooooo00?o0000ooooooooool0Uoooool2o`0003[ooooo0_l0
001/ooooo`009?ooool00ol0003oooooooooo`3Cooooo`;o0000K?ooool002Cooooo00?o0000oooo
ooooool05Oooool2o`0003Oooooo0_l0002Mooooo`;o0000D_ooool002Cooooo0_l0000Fooooo`;o
0000=oooool2o`0009gooooo0_l0000Vooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool0
oooooolFooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool0L?ooool2o`000<oooooo000T
ooooo`03o`000?oooooooooo073ooooo0_l0000?ooooo`;o0000L_ooool2o`0000gooooo0_l0000k
ooooo`009?ooool00ol0003oooooooooo`21ooooo`;o0000L_ooool2o`0000gooooo0_l0000koooo
o`009?ooool2o`000>Sooooo0_l0001Hooooo`009?ooool00ol0003oooooooooo`2=ooooo`;o0000
F?ooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo08gooooo0_l0000nooooo`;o00008ooo
ool2o`0004gooooo000Tooooo`03o`000?oooooooooo0<gooooo0_l0000Sooooo`;o0000COooool0
02Cooooo00?o0000ooooooooool0U?ooool2o`000:_ooooo000Tooooo`;o0000UOooool2o`000:_o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom2ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0g_ooool2o`00067ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02kooooo0_l0000Pooooo`;o000000?oooooo`000?l000004oooool2o`0007Cooooo0_l0001Qoooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`0002kooooo0_l0000Pooooo`;o000000?oooooo`000?l0
00004oooool4o`0002oooooo0_l0002Tooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo06[ooooo0_l0000_ooooo`;o0000Y?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool2o`0003gooooo0_l0002Oooooo`;o0000EOooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`;o0000?Oooool2o`0002Oooooo0_l0001foooo
o`;o0000EOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006
ooooo`03o`000?oooooooooo07;ooooo0_l0003=ooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo:Oooool2o`0001Oooooo000Tooooo`03o`000?oooooo
oooo09Gooooo0_l0000`ooooo`;o0000Goooool2o`0001Oooooo000Tooooo`;o0000U_ooool2o`00
033ooooo0_l0001hooooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000B_ooool2o`0007co
oooo0_l0000eooooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000B_ooool2o`0007cooooo
0_l0000eooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o00008_ooool2o`00053ooooo0_l0
002looooo`009?ooool00ol0003oooooooooo`0=ooooo`;o00008?ooool4o`00053ooooo0_l0000j
ooooo`;o0000P?ooool002Cooooo0_l0000=ooooo`;o00008Oooool2o`0008kooooo0_l00020oooo
o`009?ooool00ol0003oooooooooo`0<ooooo`;o0000ooooool:ooooo`;o0000:?ooool002Cooooo
00?o0000ooooooooool0oooooolBooooo`;o00001?ooool2o`0002Sooooo000Tooooo`03o`000?oo
oooooooo0?oooooo1oooool2o`0000Wooooo0_l0000^ooooo`009?ooool00ol0003oooooooooo`3o
ooooo`Oooooo0_l0000iooooo`009?ooool2o`000?oooooo3_ooool2o`0003?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo3Oooool2o`0003?ooooo000Jooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3fooooo`;o0000BOooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2:ooooo`;o00005oooool2o`00057ooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07_ooooo0_l0000=ooooo`;o00005oooool2
o`0000Kooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`05ooooo`?o0000Noooool2o`00
02kooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo8Oooool2o`0001oooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolQooooo`;o00007oooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2?ooooo`;o0000/?ooool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2?
ooooo`;o0000/?ooool002Cooooo0_l00027ooooo`;o0000^Oooool002Cooooo00?o0000oooooooo
ool0F_ooool2o`0000Wooooo0_l0000Oooooo`;o0000^Oooool002Cooooo00?o0000ooooooooool0
E_ooool2o`0000;ooooo0_l00009ooooo`;o0000f_ooool002Cooooo00?o0000ooooooooool0E_oo
ool2o`0005cooooo0_l0002;ooooo`009?ooool00ol0003oooooooooo`2dooooo`;o0000Roooool0
02Cooooo0_l0000]ooooo`;o0000j_ooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo02co
oooo0_l0002Zooooo`;o0000?_ooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo0=Sooooo
0_l0001Wooooo`009?ooool00ol0003oooooooooo`2aooooo`;o0000S_ooool002Cooooo00?o0000
ooooooooool0/Oooool2o`0008kooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0:kooooo0_l0002Aooooo`009?oo
ool00ol0003oooooooooo`1Dooooo`;o0000F?ooool2o`00097ooooo000Tooooo`03o`000?oooooo
oooo05Cooooo0_l0003[ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0O?ooool2o`000<?ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Jooooo`;o
0000H?ooool2o`0002kooooo0_l0001Eooooo`;o0000:oooool2o`0000oooooo0004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo01[ooooo0_l0002@ooooo`;o0000EOooool2o`0002_o
oooo0_l0000?ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooboooooo0_l0000Aooooo`001?oo
ool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000?oooooo;oooool2o`00017ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o0000ooooooliooooo`001?ooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocWooooo0002ooooo`03oeEEEOmVIVKo0000
00cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000Ooooool2o`000<7ooooo000Tooooo`03o`000?oooooooooo07ko
oooo0_l00031ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0Ooooool2o`000<3ooooo000Tooooo`03o`00
0?oooooooooo07oooooo0_l00030ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo4oooool2o`0002gooooo000Tooooo`03o`000?oooooooooo0?Sooooo
0_l0000Hooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool0n?ooool2o`0004Oooooo000T
ooooo`03o`000?oooooooooo0<3ooooo0_l0001oooooo`009?ooool2o`0006cooooo0_l0001Coooo
o`;o00009oooool2o`0005Kooooo000Tooooo`03o`000?oooooooooo06_ooooo0_l0001looooo`;o
0000E_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04
ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2Qooooo`;o0000W_ooool000cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:7ooooo0_l0002Noooo
o`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`2V
ooooo`;o00005Oooool2o`0008;ooooo000Tooooo`03o`000?oooooooooo0:Kooooo0_l0000Eoooo
o`;o0000P_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2Jooooo`;o00009oooool2o`0007cooooo
000Tooooo`;o0000Voooool2o`0002Oooooo0_l0001looooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo02_ooooo0_l00016ooooo`;o0000c?ooool002Co
oooo00?o0000ooooooooool0:oooool2o`00047ooooo0_l00003ooooo`;o0000c?ooool002Cooooo
00?o0000ooooooooool0K_ooool2o`000=7ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`16ooooo`;o0000nOooool000;ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`16ooooo`;o0000nOooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool2o`0008Kooooo0004ooooo`03o`00
0?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000
^Oooool2o`0008Kooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?oo
ool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0oooooolNooooo`;o00008_ooool002Cooooo0_l0003ooooooaoooooo0_l0000Roooo
o`009?ooool00ol0003oooooooooo`0Wooooo`;o0000oOooool2o`0001Wooooo000Tooooo`03o`00
0?oooooooooo02Oooooo0_l0002kooooo`;o0000@?ooool2o`0001Wooooo000Tooooo`03o`000?oo
oooooooo0>Cooooo0_l0001Kooooo`009?ooool00ol0003oooooooooo`1]ooooo`;o0000=_ooool2
o`0009[ooooo000Tooooo`;o0000K_ooool2o`0003Kooooo0_l0002Jooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`3ooooood;ooooo
000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood;ooooo
000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooom2ooooo`006oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?ooool00omgMgOoIVIVooooo`3ooooo
od[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wooooo00Go0000okZj^_oooooo
V9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;ooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 5e-05 Mdot
.0381 .24315 Mdot
.04286 .04734 Mdot
.05238 .00131 Mdot
.05714 .24688 Mdot
.0619 .01287 Mdot
.06667 .12248 Mdot
.07143 .14772 Mdot
.07619 .23465 Mdot
.08095 .09781 Mdot
.08571 .10122 Mdot
.09048 .09391 Mdot
.09524 .13268 Mdot
.1 .05826 Mdot
.10476 .10193 Mdot
.10952 .02785 Mdot
.11429 .23682 Mdot
.11905 .0559 Mdot
.12381 .0019 Mdot
.12857 .04734 Mdot
.13333 .00066 Mdot
.1381 .01052 Mdot
.14286 .09092 Mdot
.14762 .14329 Mdot
.15238 .08271 Mdot
.15714 .4917 Mdot
.1619 .0209 Mdot
.16667 .30804 Mdot
.17143 .25076 Mdot
.17619 .14774 Mdot
.18095 .20122 Mdot
.18571 .25914 Mdot
.19048 .08462 Mdot
.19524 .00823 Mdot
.2 .1794 Mdot
.20476 .07124 Mdot
.20952 .04061 Mdot
.21429 .04916 Mdot
.21905 .09112 Mdot
.22381 .06071 Mdot
.23333 .28101 Mdot
.2381 .08874 Mdot
.24286 .06614 Mdot
.24762 .06912 Mdot
.25238 .53876 Mdot
.25714 .08779 Mdot
.2619 .21265 Mdot
.26667 .0431 Mdot
.27143 .01631 Mdot
.27619 .04379 Mdot
.28095 .17262 Mdot
.28571 .02066 Mdot
.29048 .16081 Mdot
.29524 .55221 Mdot
.3 .30575 Mdot
.30476 .10138 Mdot
.30952 .02097 Mdot
.31429 .21406 Mdot
.31905 .00699 Mdot
.32381 .07725 Mdot
.32857 .1464 Mdot
.33333 .00646 Mdot
.3381 .06571 Mdot
.34286 .01664 Mdot
.34762 .30823 Mdot
.35238 .06514 Mdot
.35714 .09431 Mdot
.3619 .2077 Mdot
.36667 .34156 Mdot
.37143 .50603 Mdot
.37619 .39864 Mdot
.38095 .09949 Mdot
.38571 .32519 Mdot
.39048 .5892 Mdot
.39524 .05957 Mdot
.4 .01541 Mdot
.40476 .00352 Mdot
.40952 .01514 Mdot
.41429 .19619 Mdot
.41905 .29588 Mdot
.42381 .60189 Mdot
.42857 .31558 Mdot
.43333 .05561 Mdot
.4381 .21022 Mdot
.44286 .02828 Mdot
.44762 .33451 Mdot
.45238 .03762 Mdot
.45714 .03853 Mdot
.4619 .46109 Mdot
.46667 .23113 Mdot
.47143 .14719 Mdot
.47619 .11451 Mdot
.48095 .17079 Mdot
.48571 .12737 Mdot
.49048 .3929 Mdot
.49524 .32534 Mdot
.5 .09837 Mdot
.50476 .0028 Mdot
.50952 .57925 Mdot
.51429 .01609 Mdot
.51905 .15067 Mdot
.52381 .07371 Mdot
.52857 .07255 Mdot
.53333 .46283 Mdot
.5381 .27614 Mdot
.54286 .57052 Mdot
.54762 .58329 Mdot
.55238 .20357 Mdot
.55714 .06904 Mdot
.5619 .18589 Mdot
.56667 .4413 Mdot
.57143 .3324 Mdot
.57619 .03985 Mdot
.58095 .21367 Mdot
.58571 .02812 Mdot
.59048 .37345 Mdot
.59524 .08226 Mdot
.6 .00072 Mdot
.60476 .41969 Mdot
.60952 .14656 Mdot
.61429 .08029 Mdot
.61905 .56271 Mdot
.62381 .2179 Mdot
.62857 .42099 Mdot
.63333 .01232 Mdot
.6381 .4827 Mdot
.64286 .13263 Mdot
.64762 .16099 Mdot
.65238 .1859 Mdot
.65714 .06733 Mdot
.6619 .14235 Mdot
.66667 .20644 Mdot
.67143 .04573 Mdot
.67619 .03416 Mdot
.68095 .11801 Mdot
.68571 .22611 Mdot
.69048 .03908 Mdot
.69524 .16443 Mdot
.7 .24926 Mdot
.70476 .10119 Mdot
.70952 .12988 Mdot
.71429 .00216 Mdot
.71905 .24338 Mdot
.72381 .04017 Mdot
.72857 .11218 Mdot
.73333 .03532 Mdot
.7381 .47628 Mdot
.74286 .00641 Mdot
.74762 .09098 Mdot
.75238 .44921 Mdot
.75714 .25364 Mdot
.7619 .05166 Mdot
.76667 .2708 Mdot
.77143 .22262 Mdot
.77619 .01929 Mdot
.78095 .03552 Mdot
.78571 .10439 Mdot
.79048 .13552 Mdot
.79524 .36522 Mdot
.8 .32755 Mdot
.80476 .03692 Mdot
.80952 .05168 Mdot
.81905 .03167 Mdot
.82381 .06451 Mdot
.82857 .14684 Mdot
.83333 .32621 Mdot
.8381 .13682 Mdot
.84286 .25881 Mdot
.84762 .17779 Mdot
.85238 .12877 Mdot
.85714 .183 Mdot
.8619 .2846 Mdot
.86667 .0685 Mdot
.87143 .13266 Mdot
.87619 .18275 Mdot
.88095 .34864 Mdot
.88571 .0158 Mdot
.89048 .06924 Mdot
.89524 .25645 Mdot
.9 .22116 Mdot
.90476 .09656 Mdot
.90952 .10671 Mdot
.91429 .54943 Mdot
.91905 .0063 Mdot
.92381 .33417 Mdot
.92857 .02115 Mdot
.93333 .06259 Mdot
.9381 .04809 Mdot
.94286 .50851 Mdot
.94762 .2972 Mdot
.95238 .0793 Mdot
.95714 .0386 Mdot
.9619 .00133 Mdot
.96667 .26133 Mdot
.97143 .53323 Mdot
.97619 .10765 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00Co0000ooooool0003o00001?ooool2o`0000Go
oooo00?o0000ooooooooool03Oooool3o`000003ooooool0003o000000Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0<ooooo`?o
00003Oooool00ol0003oooooooooo`0<ooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool2o`0000Cooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool3o`0000cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o
00000oooool2o`0000Kooooo00?o0000ooooooooool03?ooool2o`0000kooooo00?o0000oooooooo
ool03?ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`;o
000000?oooooo`000?ooool02?ooool2o`0000Cooooo00?o0000ooooooooool03?ooool002Cooooo
00?o0000ooooooooool0=?ooool2o`0002Kooooo0_l00003ooooo`;o0000P_ooool2o`0003Sooooo
0_l0000Pooooo`009?ooool00ol0003oooooooooo`09ooooo`;o00005_ooool2o`00017ooooo0_l0
002<ooooo`;o0000OOooool002Cooooo0_l0000:ooooo`;o00005_ooool2o`0002[ooooo0_l0000W
ooooo`;o000000?oooooo`000?l000008?ooool2o`0002Gooooo0_l0001@ooooo`;o0000:oooool0
02Cooooo00?o0000ooooooooool0COooool2o`0001Gooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000008?ooool2o`0005?ooooo0_l0000Rooooo`;o0000:oooool002Cooooo00?o0000oooooooo
ool0:Oooool2o`0002Kooooo0_l00006ooooo`;o00002Oooool2o`0008[ooooo0_l0000`ooooo`;o
00007Oooool002Cooooo00?o0000ooooooooool0:Oooool2o`0002Kooooo0_l00006ooooo`;o0000
aoooool2o`0001gooooo000Tooooo`03o`000?oooooooooo01Sooooo0_l0001Zooooo`;o0000;?oo
ool2o`0008gooooo000Tooooo`;o00006Oooool2o`0006[ooooo0_l0000/ooooo`;o0000B_ooool2
o`00047ooooo000Tooooo`03o`000?oooooooooo0=3ooooo0_l0000/ooooo`;o0000@Oooool002Co
oooo00?o0000ooooooooool0Qoooool2o`0004Oooooo0_l0000@ooooo`;o00003_ooool2o`0000Go
oooo0_l00016ooooo`009?ooool00ol0003oooooooooo`0hooooo`;o0000COooool4o`0002Cooooo
0_l0000Sooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo0_l00005ooooo`;o0000
<?ooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo03Sooooo0_l0000Aooooo`;o000000?o
ooooo`000?l00000>Oooool2o`0002Cooooo0_l0000Sooooo`;o00002Oooool2o`0004[ooooo0_l0
000Dooooo`009?ooool2o`0004cooooo0_l000000ooooooo0000o`00001nooooo`;o0000LOooool0
02Cooooo00?o0000ooooooooool00_ooool2o`0001[ooooo0_l0000Jooooo`;o0000T_ooool2o`00
05Gooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool2o`0001[o
oooo0_l0002`ooooo`;o00003Oooool2o`0002Sooooo0_l0000Jooooo`009?ooool00ol0003ooooo
ooooo`0Kooooo`;o0000I?ooool2o`0006Wooooo0_l0000=ooooo`;o0000A?ooool002Cooooo00?o
0000ooooooooool05Oooool2o`0000Cooooo0_l0001Hooooo`;o00002_ooool2o`000;kooooo000T
ooooo`;o00005_ooool2o`0002Kooooo0_l0000fooooo`;o0000[?ooool2o`0001cooooo000Toooo
o`03o`000?oooooooooo03gooooo0_l0000Sooooo`;o00000oooool2o`0009Oooooo0_l0000Qoooo
o`;o00007?ooool002Cooooo00?o0000ooooooooool0@oooool2o`0001gooooo0_l00003ooooo`;o
0000HOooool2o`0003Cooooo0_l0000<ooooo`;o0000<Oooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0gooooo`;o00002_ooool4o`0006;ooooo0_l0000Oooooo`;o0000@_ooool2
o`0000Gooooo0_l0000Zooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0gooooo`;o00003?ooool2o`0005Oooooo1?l00007ooooo`;o0000J_ooool2o`0002[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`?o0000G_ooool2o`0003kooooo1?l0002Oooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`1Nooooo`;o0000G?ooool2o`0006_ooooo0_l0000F
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Kooooo0_l0002>
ooooo`;o00001?ooool2o`0006_ooooo0_l0000Fooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Vooooo`;o00002_ooool2o`0008;ooooo0_l00029ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03;ooooo0_l0000>ooooo`;o00001?ooool2o`000?Oooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool2o`0002Cooooo0_l0000Gooooo`;o00001?ooool2o`0000Cooooo0_l0002Mooooo`;o
0000F?ooool002Cooooo00?o0000ooooooooool04_ooool2o`0000oooooo0_l0000Gooooo`;o0000
:_ooool2o`0007gooooo0_l0000aooooo`;o00009Oooool002Cooooo00?o0000ooooooooool03ooo
ool2o`000003ooooool0003o000005Cooooo0_l00006ooooo`;o00009Oooool2o`00087ooooo0_l0
000Uooooo`009?ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool2o`0003oooooo0_l0000G
ooooo`;o00009Oooool2o`00043ooooo0_l0001Vooooo`009?ooool00ol0003oooooooooo`0@oooo
o`;o00001?ooool2o`0003oooooo0_l00020ooooo`;o00006?ooool2o`0004cooooo000Tooooo`03
o`000?oooooooooo0??ooooo0_l0000Vooooo`;o00005?ooool2o`0000kooooo000Tooooo`;o0000
oooooolMooooo`;o00005?ooool2o`0000kooooo000Tooooo`03o`000?oooooooooo08oooooo0_l0
001@ooooo`;o0000G_ooool002Cooooo00?o0000ooooooooool0Soooool2o`00043ooooo0_l0000>
ooooo`;o0000G_ooool002Cooooo00?o0000ooooooooool0dOooool2o`0006kooooo000Tooooo`03
o`000?oooooooooo00[ooooo0_l0003oooooocKooooo000Tooooo`;o00002oooool2o`0008Kooooo
0_l0002]ooooo`009?ooool00ol0003oooooooooo`2Booooo`;o0000Aoooool2o`0002cooooo0_l0
000fooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o0000/?ooool2o`0001Cooooo0_l0000/
ooooo`;o00001?ooool2o`00033ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l0002`oooo
o`;o0000;_ooool2o`0001Sooooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`3eooooo`;o
00003Oooool2o`0003_ooooo000Tooooo`;o0000c?ooool2o`0003Oooooo0_l0000kooooo`009?oo
ool00ol0003oooooooooo`0Tooooo`;o0000YOooool2o`0007Cooooo0009ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00cooooo0_l0000Fooooo`;o00002?ooool2o`0002oooooo0_l0000/ooooo`;o0000
:oooool2o`0004Gooooo0_l0000nooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2o`00023ooooo
0_l0000_ooooo`;o0000;?ooool2o`0000kooooo0_l0000Kooooo`;o0000AOooool2o`0003kooooo
0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09gooooo0_l0002Rooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Wooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Cooooo`;o
0000L_ooool2o`0007Sooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05?ooooo0_l0001booooo`;o0000N?ooool000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0e_ooool2o`0006Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo00?o0000ooooooooool0e_ooool2o`0006Wooooo000Tooooo`;o0000DOooool2o`0003kooooo
0_l0002_ooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000?_ooool2o`000:oooooo000T
ooooo`03o`000?oooooooooo03Gooooo0_l0003@ooooo`;o0000>?ooool002Cooooo00?o0000oooo
ooooool0=Oooool2o`000=3ooooo0_l00008ooooo`;o0000;_ooool002Cooooo00?o0000oooooooo
ool0Zoooool2o`0001_ooooo0_l00010ooooo`;o00001Oooool2o`0002kooooo000Tooooo`;o0000
[?ooool2o`0001_ooooo0_l00010ooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
07_ooooo0_l00034ooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000B_ooool2o`000<Co
oooo000Tooooo`;o0000<?ooool2o`0007Oooooo0_l0002Gooooo`009?ooool00ol0003ooooooooo
o`2Xooooo`;o00008oooool2o`0007;ooooo000Tooooo`03o`000?oooooooooo06[ooooo0_l0000G
ooooo`;o0000B?ooool2o`0007;ooooo000Tooooo`03o`000?oooooooooo04Wooooo0_l0000Ooooo
o`;o00005oooool2o`0002cooooo0_l0002>ooooo`009?ooool00ol0003oooooooooo`19ooooo`;o
00003oooool2o`0005Gooooo0_l0002>ooooo`009?ooool2o`0005_ooooo0_l0001Sooooo`;o0000
P?ooool002Cooooo00?o0000ooooooooool0_oooool2o`0002kooooo0_l0000Wooooo`;o00009ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0koooool2o`0002Oo
oooo0_l0000Wooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0doooool2o`00
06cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08cooooo0_l00015ooooo`;o
0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000=ooooo`;o0000OOooool2o`000;?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2o`0000_ooooo
0_l0003oooooobKooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo0_l0
003oooooobKooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l0003Koooo
o`;o0000HOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006
ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`000=Gooooo0_l0001Qooooo`009?ooool2
o`0000Sooooo0_l0003?ooooo`;o0000Ioooool002Cooooo00?o0000ooooooooool0;?ooool2o`00
0:[ooooo0_l0000@ooooo`;o0000EOooool002Cooooo00?o0000ooooooooool0;?ooool2o`000;co
oooo0_l0000[ooooo`;o0000:?ooool002Cooooo00?o0000ooooooooool0<Oooool2o`000=?ooooo
0_l0000?ooooo`;o0000:?ooool002Cooooo00?o0000ooooooooool0<Oooool2o`000=?ooooo0_l0
000Vooooo`;o00004Oooool002Cooooo0_l0003ooooooc3ooooo0_l0000Aooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0>gooooo0_l0001Booooo`00
9?ooool00ol0003oooooooooo`3]ooooo`;o0000D_ooool002Cooooo00?o0000ooooooooool0Xooo
ool2o`0009cooooo000Tooooo`;o0000@Oooool2o`00067ooooo0_l0002Looooo`009?ooool00ol0
003oooooooooo`10ooooo`;o0000b_ooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo3Oooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`0007gooooo0_l00033ooooo`009?ooool00ol0
003oooooooooo`1looooo`;o0000Z_ooool2o`0001Oooooo000Jooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3oooooobWooooo0_l0000Gooooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05Kooooo0_l0003Yooooo`007?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02_ooooo0_l0000Yooooo`;o00003Oooool2o`000=[ooooo000L
ooooo`03o`000?oooooooooo00Gooooo0ol0000[ooooo`;o0000>?ooool2o`000=[ooooo000Loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`006_ooool00omEEEGoIVIVo`00
0007ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0001cooooo`;o00008Oooool2
o`00067ooooo0_l00009ooooo`;o0000??ooool002Cooooo00?o0000ooooooooool0L_ooool2o`00
027ooooo0_l0001Qooooo`;o00002Oooool2o`0003cooooo000Tooooo`03o`000?oooooooooo0:ko
oooo0_l0002Aooooo`009?ooool00ol0003oooooooooo`26ooooo`;o00009_ooool2o`00073ooooo
0_l0000Oooooo`009?ooool00ol0003oooooooooo`26ooooo`;o0000V?ooool2o`0001oooooo000T
ooooo`;o0000K?ooool2o`000=Cooooo000Tooooo`03o`000?oooooooooo06_ooooo0_l0003Doooo
o`009?ooool00ol0003oooooooooo`3ooooooa?ooooo0_l0000]ooooo`009?ooool00ol0003ooooo
ooooo`3ooooooa?ooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0m_ooool2o`0004Wooooo
000Tooooo`03o`000?oooooooooo0?Kooooo0_l00019ooooo`009?ooool2o`000;Gooooo0_l0002;
ooooo`009?ooool00ol0003oooooooooo`2dooooo`;o0000Roooool000;ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0U?ooool2o`000:_ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_oo
ool2o`0002Cooooo0_l0002[ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0K_ooool2o`000=7ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000^_ooool2o`0008Kooooo000Toooo
o`03o`000?oooooooooo0;Wooooo0_l00005ooooo`;o0000Ooooool002Cooooo00?o0000oooooooo
ool0`?ooool2o`0007oooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2/ooooo`;o0000Toooool002Cooooo
00?o0000ooooooooool0[?ooool2o`0009?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo0_l0003Zooooo`;o0000E_ooool002Cooooo00?o0000ooooooooool0jOooool2o`00
05Kooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;o
oooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2:ooooo`;o00005Oooool2o`0009kooooo000<ooooo`03o`000?oooooooooo00kooooo00?o
MgMgoc8b<_ooool01?ooool3o`0008[ooooo0_l0000Eooooo`;o0000W_ooool000cooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co
00001_ooool00ol0003oooooooooo`3Tooooo`;o0000Foooool002Cooooo0_l0003Uooooo`;o0000
Foooool002Cooooo00?o0000ooooooooool0`oooool2o`0007cooooo000Tooooo`03o`000?oooooo
oooo0<?ooooo0_l0001looooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo02Oooooo0_l0003ooooooaWooooo000Tooooo`;o0000:?ooool2o`000?oooooo
6Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo06gooooo0_l0003Booooo`009?ooool00ol0003o
ooooooooo`1]ooooo`;o0000]oooool2o`0001Wooooo000Tooooo`;o0000oooooolXooooo`;o0000
6Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo<Ooo
ool2o`0000oooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooooc7ooooo0_l0000?
ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`16ooooo`;o0000nOooool000Cooooo00?o0000oooooooo
ool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00016ooooo`;o
0000nOooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo7_ooool2o`0002;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
E?ooool2o`000<Oooooo0_l0000Rooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool0E?ooool2o`000>_ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0;go
oooo0_l00022ooooo`009?ooool00ol0003oooooooooo`2mooooo`;o0000P_ooool002Cooooo00?o
0000ooooooooool0YOooool2o`0009[ooooo000Tooooo`;o0000Y_ooool2o`0009[ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0V_ooool2o`000:Go
oooo000Tooooo`03o`000?oooooooooo09[ooooo0_l0000:ooooo`;o0000VOooool002Cooooo00?o
0000ooooooooool0Y_ooool2o`0009Wooooo000Tooooo`;o0000M?ooool2o`000<cooooo000Toooo
o`03o`000?oooooooooo07?ooooo0_l0003<ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0O_oo
ool2o`000<7ooooo000Tooooo`;o0000Ooooool2o`000<7ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool0
01gooooo00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@
0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 5e-05 Mdot
.0381 .02526 Mdot
.04286 .04734 Mdot
.05238 .00131 Mdot
.05714 .29225 Mdot
.0619 .01287 Mdot
.06667 .06278 Mdot
.07143 .26464 Mdot
.07619 .12318 Mdot
.08095 .09781 Mdot
.08571 .10122 Mdot
.09048 .07313 Mdot
.09524 .13268 Mdot
.1 .05826 Mdot
.10476 .05325 Mdot
.10952 .02785 Mdot
.11429 .10602 Mdot
.11905 .01153 Mdot
.12381 .0667 Mdot
.12857 .04734 Mdot
.13333 .00729 Mdot
.1381 .09304 Mdot
.14286 .09092 Mdot
.14762 .06553 Mdot
.15238 .08271 Mdot
.15714 .518 Mdot
.1619 .0209 Mdot
.16667 .30804 Mdot
.17143 .5939 Mdot
.17619 .05059 Mdot
.18095 .10853 Mdot
.18571 .18092 Mdot
.19048 .10016 Mdot
.19524 .00823 Mdot
.2 .00826 Mdot
.20476 .09674 Mdot
.20952 .00896 Mdot
.21429 .07645 Mdot
.21905 .22331 Mdot
.22381 .06071 Mdot
.22857 .59812 Mdot
.23333 .34106 Mdot
.2381 .27892 Mdot
.24286 .24884 Mdot
.24762 .06912 Mdot
.25238 .38785 Mdot
.25714 .08779 Mdot
.2619 .16467 Mdot
.26667 .03917 Mdot
.27143 .03736 Mdot
.27619 .02319 Mdot
.28095 .17262 Mdot
.28571 .10617 Mdot
.29048 .31074 Mdot
.29524 .38141 Mdot
.3 .32171 Mdot
.30476 .10138 Mdot
.30952 .02097 Mdot
.31429 .19985 Mdot
.31905 .00699 Mdot
.32381 .12842 Mdot
.32857 .08838 Mdot
.33333 .38837 Mdot
.3381 .34285 Mdot
.34286 .13908 Mdot
.34762 .55096 Mdot
.35238 .40143 Mdot
.35714 .09431 Mdot
.3619 .18707 Mdot
.36667 .36827 Mdot
.37143 .50603 Mdot
.37619 .26472 Mdot
.38095 .19668 Mdot
.38571 .41832 Mdot
.39048 .40711 Mdot
.39524 .03188 Mdot
.4 .01541 Mdot
.40476 .02841 Mdot
.40952 .09622 Mdot
.41429 .20659 Mdot
.41905 .08993 Mdot
.42381 .60189 Mdot
.42857 .31438 Mdot
.43333 .05561 Mdot
.4381 .08049 Mdot
.44286 .02828 Mdot
.44762 .33749 Mdot
.45238 .03762 Mdot
.45714 .03853 Mdot
.4619 .5148 Mdot
.46667 .31503 Mdot
.47143 .05457 Mdot
.47619 .08522 Mdot
.48095 .17079 Mdot
.48571 .03929 Mdot
.49048 .40255 Mdot
.49524 .46684 Mdot
.5 .09837 Mdot
.50476 .0028 Mdot
.50952 .47433 Mdot
.51429 .14716 Mdot
.51905 .34601 Mdot
.52381 .21567 Mdot
.52857 .07255 Mdot
.53333 .41078 Mdot
.5381 .04051 Mdot
.54286 .40365 Mdot
.54762 .43894 Mdot
.55238 .02189 Mdot
.55714 .09762 Mdot
.5619 .18589 Mdot
.56667 .42773 Mdot
.57143 .34209 Mdot
.57619 .21196 Mdot
.58095 .26231 Mdot
.58571 .08476 Mdot
.59048 .54708 Mdot
.59524 .08226 Mdot
.6 .07273 Mdot
.60476 .22802 Mdot
.60952 .14656 Mdot
.61429 .00462 Mdot
.61905 .28105 Mdot
.62381 .10351 Mdot
.62857 .35571 Mdot
.63333 .01232 Mdot
.6381 .55407 Mdot
.64286 .05 Mdot
.64762 .16099 Mdot
.65238 .34732 Mdot
.65714 .18978 Mdot
.6619 .27176 Mdot
.66667 .02602 Mdot
.67143 .04573 Mdot
.67619 .33252 Mdot
.68095 .11801 Mdot
.68571 .05355 Mdot
.69048 .04683 Mdot
.69524 .0398 Mdot
.7 .24926 Mdot
.70476 .10123 Mdot
.70952 .01511 Mdot
.71429 .00216 Mdot
.71905 .2008 Mdot
.72381 .04017 Mdot
.72857 .00614 Mdot
.73333 .03532 Mdot
.74286 .07634 Mdot
.74762 .09098 Mdot
.75238 .25928 Mdot
.75714 .37118 Mdot
.7619 .05166 Mdot
.76667 .08097 Mdot
.77143 .22499 Mdot
.77619 .01929 Mdot
.78095 .03842 Mdot
.78571 .13747 Mdot
.79048 .23915 Mdot
.79524 .46653 Mdot
.8 .09037 Mdot
.80476 .03692 Mdot
.80952 .05168 Mdot
.81905 .12938 Mdot
.82381 .03665 Mdot
.82857 .07292 Mdot
.83333 .12237 Mdot
.8381 .09076 Mdot
.84286 .24415 Mdot
.84762 .04989 Mdot
.85238 .33184 Mdot
.85714 .183 Mdot
.8619 .39754 Mdot
.86667 .03099 Mdot
.87143 .02251 Mdot
.87619 .04338 Mdot
.88095 .30613 Mdot
.88571 .0158 Mdot
.89048 .06924 Mdot
.89524 .29602 Mdot
.9 .18539 Mdot
.90476 .14417 Mdot
.90952 .07674 Mdot
.91905 .03693 Mdot
.92381 .12432 Mdot
.92857 .04898 Mdot
.93333 .07697 Mdot
.9381 .07685 Mdot
.94762 .1719 Mdot
.95238 .13358 Mdot
.95714 .0386 Mdot
.9619 .00133 Mdot
.96667 .30375 Mdot
.97143 .60879 Mdot
.97619 .12465 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00Co0000ooooool0003o00001?ooool2o`0000Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool03?ooool002Cooooo
00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooo
ooooo`0Pooooo`;o00004_ooool3o`000003ooooool0003o000002;ooooo0_l0001Nooooo`;o0000
8oooool2o`0005kooooo000Tooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o00000ooo
ool2o`0001;ooooo0ol000000ooooooo0000o`000028ooooo`;o0000OOooool002Cooooo0_l0000:
ooooo`;o00004?ooool2o`0005Wooooo0_l0001:ooooo`;o00005oooool2o`0003Oooooo0_l0000[
ooooo`009?ooool00ol0003oooooooooo`1fooooo`;o0000Hoooool2o`0001?ooooo0_l0000Roooo
o`;o0000:oooool002Cooooo00?o0000ooooooooool0:Oooool2o`0002kooooo0_l0001=ooooo`;o
0000A_ooool2o`0001gooooo0_l0000`ooooo`009?ooool01?l0003oooooooooooooool2o`0002Ko
oooo0_l0000Sooooo`;o00002Oooool2o`0004gooooo0_l0001Uooooo`;o0000<?ooool002Cooooo
00Co0000oooooooooooooooo0_l0000Eooooo`;o0000=?ooool2o`0002Sooooo0_l0000:ooooo`;o
0000Aoooool2o`0007;ooooo000Tooooo`;o00006Oooool2o`0005kooooo0_l0000:ooooo`;o0000
Aoooool2o`0003oooooo0_l0000aooooo`009?ooool00ol0003oooooooooo`1eooooo`;o0000Uooo
ool2o`00037ooooo000Tooooo`03o`000?oooooooooo04gooooo0_l0000Vooooo`;o00004?ooool2
o`0005Wooooo0_l0000Eooooo`;o00001Oooool2o`0001gooooo0_l0000Pooooo`009?ooool00ol0
003oooooooooo`1;ooooo`Co0000>?ooool4o`0000Oooooo0_l0000?ooooo`;o0000<Oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000>ooooo`;o00001Oooool2o`0000Gooooo0_l0000Moooo
o`;o00002_ooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo04_ooooo0_l0000looooo`;o
00001oooool2o`0000oooooo0_l0000aooooo`;o00001oooool2o`00017ooooo0_l0000Mooooo`;o
00006?ooool2o`0001Cooooo000Tooooo`;o0000coooool2o`0000Cooooo0_l0000kooooo`;o0000
;_ooool002Cooooo00?o0000ooooooooool00_ooool2o`0001[ooooo0_l0002Uooooo`;o00001ooo
ool2o`0000Cooooo0_l0000aooooo`;o00006Oooool2o`0001gooooo000Tooooo`03o`000?oooooo
oooo00;ooooo0_l0000Booooo`;o00001_ooool2o`0000kooooo0_l0002Eooooo`;o00009Oooool2
o`0000gooooo0_l0000:ooooo`;o00006Oooool2o`0001gooooo000Tooooo`03o`000?oooooooooo
01Kooooo0_l0000Fooooo`;o0000DOooool2o`0000[ooooo0_l00014ooooo`;o00005oooool2o`00
00gooooo0_l00014ooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000J_ooool2o`0000[o
oooo0_l00014ooooo`;o0000K?ooool002Cooooo0_l0000Fooooo`;o00009_ooool2o`000?oooooo
0oooool002Cooooo00?o0000ooooooooool02_ooool2o`0001Sooooo0_l0000Gooooo`;o0000oooo
ool3ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o00004Oooool2o`0000Gooooo0_l0003o
oooooacooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Oooool2o`0002Kooooo
0_l0003>ooooo`;o0000:_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool04_ooool2o`00037ooooo0_l0001Iooooo`;o00005Oooool2o`0004Sooooo0_l0000Boooo
o`;o0000:_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Booooo`;o00009_ooool2o`0006Co
oooo0_l0000Eooooo`;o0000;?ooool2o`0001[ooooo0_l0000Hooooo`;o00001_ooool4o`0001[o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03[ooooo0_l00017ooooo`;o0000
H?ooool2o`0000Kooooo0_l0000/ooooo`;o00001_ooool4o`0001[ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_ooool2o`0005_ooooo0_l0000aooooo`;o0000
=Oooool2o`0005;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo0_l0
001Wooooo`;o00008Oooool2o`0000;ooooo0_l00029ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Sooooo0_l0000Eooooo`;o00006oooool2o`00017ooooo0_l0000Qooooo`;o
0000A?ooool2o`0004Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002;ooooo1?l0000Sooooo`;o00005Oooool2
o`0001_ooooo0_l0001Yooooo`;o00003oooool2o`0000[ooooo0_l0000kooooo`009?ooool00ol0
003oooooooooo`0Qooooo`Co0000@oooool2o`0000oooooo0_l0001/ooooo`;o00006oooool2o`00
03_ooooo000Tooooo`03o`000?oooooooooo00oooooo0_l0000Vooooo`;o0000;oooool2o`0000oo
oooo0_l0000Looooo`;o00004?ooool2o`0009Kooooo000Tooooo`03o`000?oooooooooo00oooooo
0ol0000Pooooo`;o00000oooool2o`0001kooooo0_l0000nooooo`;o00004?ooool2o`0002kooooo
0_l0001Vooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o00008?ooool2o`0002?ooooo0_l0
001Vooooo`;o00006?ooool2o`0006Kooooo000Tooooo`03o`000?oooooooooo01[ooooo0_l0000C
ooooo`;o00008?ooool2o`0006cooooo0_l00020ooooo`009?ooool2o`0001_ooooo0_l0000Coooo
o`;o00008?ooool2o`000>kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0dOooool2o`0006kooooo000Tooooo`03o`000?oooooooooo0=7ooooo0_l0
001^ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o0000m?ooool2o`0001_ooooo0_l0000O
ooooo`009?ooool2o`0000kooooo0_l0003dooooo`;o00006oooool2o`0000oooooo0_l0000>oooo
o`009?ooool00ol0003oooooooooo`1Nooooo`;o0000W_ooool2o`00037ooooo0_l0000>ooooo`00
9?ooool00ol0003oooooooooo`0Cooooo`;o0000BOooool2o`0009kooooo0_l00011ooooo`009?oo
ool00ol0003oooooooooo`0Cooooo`;o0000oooooolEooooo`;o00005_ooool002Cooooo00?o0000
ooooooooool0I?ooool2o`0008gooooo0_l0000dooooo`;o00005_ooool002Cooooo0_l0001Uoooo
o`;o0000SOooool2o`0004cooooo000Tooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002Go
oooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo09_ooooo0_l0000Mooooo`;o0000G_ooool2o`00
02Gooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2Kooooo`;o00007Oooool2o`0008Gooooo0009ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0003ooooood;ooooo0009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0aoooool2o`0007Sooooo0009oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0<Oooooo0_l0001hooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`19ooooo`;o0000m_ooool000Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`19ooooo`;o0000m_ooool0
02Cooooo0_l0001Aooooo`;o0000?_ooool2o`0009Kooooo0_l0000Gooooo`009?ooool00ol0003o
ooooooooo`1@ooooo`;o0000?_ooool2o`0009Kooooo0_l0000Gooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo037ooooo0_l0003oooooo`oooooo000T
ooooo`03o`000?oooooooooo037ooooo0_l0001hooooo`;o0000GOooool2o`0000cooooo0_l0000W
ooooo`009?ooool2o`0006_ooooo0_l0000oooooo`;o0000GOooool2o`0000cooooo0_l0000Woooo
o`009?ooool00ol0003oooooooooo`1Zooooo`;o0000G_ooool2o`0007Gooooo000Tooooo`03o`00
0?oooooooooo0<[ooooo0_l0001eooooo`009?ooool00ol0003oooooooooo`1`ooooo`;o0000cooo
ool002Cooooo00?o0000ooooooooool0F_ooool2o`0001Cooooo0_l0001/ooooo`;o0000HOooool0
02Cooooo0_l0001Kooooo`;o0000P_ooool2o`00067ooooo000Tooooo`03o`000?oooooooooo07_o
oooo0_l00034ooooo`009?ooool00ol0003oooooooooo`1kooooo`;o0000a?ooool002Cooooo00?o
0000ooooooooool0[oooool2o`00093ooooo000Tooooo`03o`000?oooooooooo09kooooo0_l0000?
ooooo`;o0000T?ooool002Cooooo0_l0002Oooooo`;o0000XOooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0l
ooooo`;o0000/Oooool2o`00053ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0looooo`;o0000Noooool2o`0003Cooooo0_l0001@ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2iooooo`;o0000Q_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooo
od;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3eooooo`;o0000B_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3eooooo`;o00003oooool2o`0003Wooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooooooo
o`3oooooo`Oooooo0_l0000iooooo`009?ooool2o`0004Cooooo0_l0002Cooooo`;o0000Ioooool0
02Cooooo00?o0000ooooooooool0@oooool2o`0009?ooooo0_l0001Wooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0>Wooooo0_l0001Fooooo`009?oo
ool00ol0003oooooooooo`2aooooo`;o0000=_ooool2o`0005Kooooo000Tooooo`;o00003Oooool2
o`00063ooooo0_l00011ooooo`;o0000S_ooool002Cooooo00?o0000ooooooooool03?ooool2o`00
063ooooo0_l0003Aooooo`009?ooool00ol0003oooooooooo`3;ooooo`;o0000M?ooool002Cooooo
00?o0000ooooooooool0boooool2o`0007Cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo0_l00013ooooo`;o0000NOooool2o`0008;ooooo000Tooooo`03o`000?oooooooooo
04;ooooo0_l0001iooooo`;o0000P_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo00Oooooo0_l0
003oooooocWooooo000Tooooo`;o00002?ooool2o`000?oooooo3oooool2o`0002Sooooo000Toooo
o`03o`000?oooooooooo0?oooooo6?ooool2o`0002Sooooo000Jooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolCooooo`;o00006_ooool2o`00017ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:oooool2o`000>Gooooo0_l0000Jooooo`;o00004Ooo
ool001cooooo00?o0000ooooooooool01Oooool3o`0002_ooooo0_l0000Vooooo`;o0000k?ooool0
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Cooooo`;o0000:_ooool2o`00
00_ooooo0_l0002cooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oo
oooo0_l0000;ooooo`;o0000/oooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood;ooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0E_oo
ool2o`000>Wooooo000Tooooo`;o0000Eoooool2o`000>Wooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0d?ooool2o`0003Oooooo0_l0000fooooo`00
9?ooool00ol0003oooooooooo`3@ooooo`;o0000=oooool2o`0003Kooooo000Tooooo`03o`000?oo
oooooooo08Kooooo0_l0002iooooo`009?ooool2o`00047ooooo0_l0000Pooooo`;o00008_ooool2
o`0002Kooooo0_l0002Aooooo`009?ooool00ol0003oooooooooo`10ooooo`;o00008?ooool2o`00
03Wooooo0_l0000?ooooo`;o0000TOooool002Cooooo00?o0000ooooooooool0WOooool2o`0002Wo
oooo0_l0001gooooo`009?ooool00ol0003oooooooooo`38ooooo`;o0000Moooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000<7ooooo0_l0001oooooo`009?ooool00ol0
003oooooooooo`30ooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo06_ooooo0_l0
003Dooooo`009?ooool2o`0006cooooo0_l0001mooooo`;o0000EOooool002Cooooo00?o0000oooo
ooooool0j_ooool2o`0005Gooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Cooooo0_l0003[oooo
o`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Dooooo`;o0000joooool000Cooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00016ooooo`;o0000
6Oooool2o`000=kooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0A_ooool2o`0001Wooooo
0_l0003Nooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0ooooool=ooooo`;o0000<oooool000;ooooo00?oEEEEofIVI_l000003?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo06Oooooo0_l0
002Sooooo`;o0000<oooool002Cooooo0_l0001Xooooo`;o0000:oooool2o`0000oooooo0_l0002J
ooooo`009?ooool00ol0003oooooooooo`1cooooo`;o00007oooool2o`0000oooooo0_l0002Joooo
o`009?ooool00ol0003oooooooooo`1cooooo`;o0000;?ooool2o`0009kooooo000Tooooo`03o`00
0?oooooooooo0:7ooooo0_l0002Nooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000Loooool2o`000<gooooo000Tooooo`03o`000?oooooooooo07;ooooo0_l0003=oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0:cooooo
0_l0002Cooooo`009?ooool00ol0003oooooooooo`2/ooooo`;o0000Toooool002Cooooo0_l0003o
oooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0Y_ooool2o`0009Wooooo000Tooooo`03o`000?oooooooooo0:Kooooo0_l0002Iooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000co
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?Kooooo0_l00019ooooo`003?ooool00ol0003oooooooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2Eooooo`;o0000Gooo
ool2o`0004Wooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Eooooo`;o0000Z_ooool000cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo09[ooooo0_l0002Uooooo`002_ooool00omEEEGo
IVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`2Jooooo`;o0000YOooool002Cooooo
0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`1]ooooo`;o0000d_ooool002Cooooo00?o0000ooooooooool0KOooool2o`000=;o
oooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`2:ooooo`;o0000]Ooo
ool002Cooooo00?o0000ooooooooool09oooool2o`00067ooooo0_l0002eooooo`009?ooool00ol0
003oooooooooo`0Wooooo`;o0000oooooolIooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo0002
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool0
0ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
od;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0]?ooool2o`0008_ooooo0004ooooo`03o`000?oo
oooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0IOooool2o`0004gooooo0_l0002;ooooo`000_ooool00omEEEGoIVIVo`00
000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0IOooool2o`0005cooooo0_l0
001looooo`009?ooool2o`000<Cooooo0_l0001looooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo02cooooo0_l0003ooooooaCooooo000Tooooo`03o`00
0?oooooooooo02cooooo0_l0000Aooooo`;o0000ooooool1ooooo`009?ooool00ol0003ooooooooo
o`0oooooo`;o0000?Oooool2o`000<7ooooo000Tooooo`;o0000Ooooool2o`000<7ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo<Oooool2o`0000oooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3ooooooc7ooooo0_l0000?ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo@_oo
ool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3ooooo
odWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 5e-05 Mdot
.0381 .02526 Mdot
.04286 .19034 Mdot
.05238 .18425 Mdot
.05714 .14417 Mdot
.0619 .01287 Mdot
.06667 .15149 Mdot
.07143 .31444 Mdot
.07619 .11855 Mdot
.08095 .26695 Mdot
.08571 .24362 Mdot
.09048 .07313 Mdot
.09524 .14217 Mdot
.1 .02251 Mdot
.10476 .05325 Mdot
.10952 .21488 Mdot
.11429 .00949 Mdot
.11905 .01045 Mdot
.12381 .19717 Mdot
.12857 .04734 Mdot
.13333 .00729 Mdot
.1381 .14037 Mdot
.14286 .09092 Mdot
.14762 .3049 Mdot
.15238 .08271 Mdot
.15714 .31065 Mdot
.1619 .11263 Mdot
.16667 .01293 Mdot
.17143 .3804 Mdot
.17619 .27079 Mdot
.18095 .2307 Mdot
.18571 .07559 Mdot
.19048 .10016 Mdot
.19524 .18546 Mdot
.2 .00826 Mdot
.20476 .09674 Mdot
.20952 .19175 Mdot
.21429 .07645 Mdot
.21905 .08527 Mdot
.22381 .06071 Mdot
.22857 .20726 Mdot
.23333 .16445 Mdot
.2381 .44334 Mdot
.24286 .30118 Mdot
.24762 .05849 Mdot
.25238 .14903 Mdot
.25714 .08779 Mdot
.2619 .34033 Mdot
.26667 .03917 Mdot
.27143 .05123 Mdot
.27619 .02319 Mdot
.28095 .32742 Mdot
.28571 .07025 Mdot
.29048 .12161 Mdot
.29524 .19729 Mdot
.3 .39784 Mdot
.30476 .04146 Mdot
.30952 .24003 Mdot
.31429 .30175 Mdot
.31905 .04959 Mdot
.32381 .15709 Mdot
.32857 .22253 Mdot
.33333 .58259 Mdot
.3381 .09601 Mdot
.34286 .29914 Mdot
.34762 .55096 Mdot
.35238 .15053 Mdot
.35714 .09431 Mdot
.3619 .22288 Mdot
.36667 .36827 Mdot
.37143 .59912 Mdot
.37619 .27339 Mdot
.38095 .00314 Mdot
.38571 .11604 Mdot
.39048 .01979 Mdot
.39524 .25831 Mdot
.4 .01541 Mdot
.40476 .02841 Mdot
.40952 .22822 Mdot
.41429 .08034 Mdot
.41905 .27176 Mdot
.42381 .32415 Mdot
.42857 .41774 Mdot
.43333 .05561 Mdot
.4381 .08395 Mdot
.44286 .02828 Mdot
.44762 .18585 Mdot
.45238 .03762 Mdot
.45714 .01046 Mdot
.4619 .5128 Mdot
.46667 .27679 Mdot
.47143 .133 Mdot
.47619 .08522 Mdot
.48095 .1334 Mdot
.48571 .24214 Mdot
.49048 .30242 Mdot
.49524 .37604 Mdot
.5 .20719 Mdot
.50476 .05763 Mdot
.50952 .36337 Mdot
.51429 .18972 Mdot
.51905 .06982 Mdot
.52381 .08488 Mdot
.52857 .07255 Mdot
.53333 .31525 Mdot
.5381 .26339 Mdot
.54286 .21552 Mdot
.54762 .20981 Mdot
.55238 .02189 Mdot
.55714 .09762 Mdot
.5619 .05523 Mdot
.56667 .41949 Mdot
.57143 .19252 Mdot
.57619 .1862 Mdot
.58095 .09438 Mdot
.58571 .08476 Mdot
.59524 .08226 Mdot
.6 .01606 Mdot
.60476 .1093 Mdot
.60952 .14656 Mdot
.61429 .01804 Mdot
.61905 .06255 Mdot
.62381 .10351 Mdot
.62857 .20763 Mdot
.63333 .00787 Mdot
.6381 .52572 Mdot
.64286 .05 Mdot
.64762 .27602 Mdot
.65238 .20688 Mdot
.65714 .3442 Mdot
.6619 .14529 Mdot
.66667 .23376 Mdot
.67143 .04573 Mdot
.67619 .2829 Mdot
.68095 .19593 Mdot
.68571 .04342 Mdot
.69048 .04683 Mdot
.69524 .02215 Mdot
.7 .16453 Mdot
.70476 .30867 Mdot
.70952 .01511 Mdot
.71429 .02995 Mdot
.71905 .1206 Mdot
.72381 .04017 Mdot
.72857 .00614 Mdot
.73333 .03532 Mdot
.74286 .07634 Mdot
.74762 .05943 Mdot
.75238 .37671 Mdot
.75714 .52999 Mdot
.7619 .0312 Mdot
.76667 .0051 Mdot
.77143 .04688 Mdot
.77619 .33791 Mdot
.78095 .02484 Mdot
.78571 .13747 Mdot
.79048 .23915 Mdot
.79524 .48685 Mdot
.8 .04755 Mdot
.80476 .02457 Mdot
.80952 .0539 Mdot
.81429 .58366 Mdot
.81905 .08941 Mdot
.82381 .03665 Mdot
.82857 .10257 Mdot
.83333 .11011 Mdot
.8381 .09075 Mdot
.84286 .00764 Mdot
.84762 .16768 Mdot
.85238 .29367 Mdot
.85714 .29134 Mdot
.8619 .46176 Mdot
.86667 .03099 Mdot
.87143 .02066 Mdot
.87619 .42265 Mdot
.88095 .1306 Mdot
.88571 .08475 Mdot
.89048 .06924 Mdot
.89524 .22955 Mdot
.9 .17822 Mdot
.90476 .23537 Mdot
.90952 .12332 Mdot
.91905 .03693 Mdot
.92381 .21619 Mdot
.92857 .04898 Mdot
.93333 .07697 Mdot
.9381 .23593 Mdot
.94762 .16477 Mdot
.95238 .13358 Mdot
.95714 .12283 Mdot
.9619 .00133 Mdot
.96667 .16065 Mdot
.97619 .29649 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00Co0000ooooool0003o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool03?ooool002Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooooooo
o`0Jooooo`;o00001?ooool2o`0001?ooooo0_l0002;ooooo`;o00007Oooool2o`0000[ooooo0_l0
000Gooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool02Oooool2o`0000oooooo0ol00003
ooooo`;o00002Oooool2o`0000Sooooo0_l0001Booooo`;o0000=oooool2o`0004;ooooo0_l0000i
ooooo`009?ooool2o`0000[ooooo0_l0000@ooooo`;o00003_ooool2o`0004Wooooo0_l0000Aoooo
o`;o0000;?ooool2o`0002;ooooo0_l0001Tooooo`009?ooool00ol0003oooooooooo`1fooooo`;o
0000?oooool2o`0000?ooooo0_l0000Mooooo`;o0000I?ooool002Cooooo00?o0000ooooooooool0
5Oooool2o`0005cooooo0_l0000cooooo`;o00004_ooool2o`0001Sooooo0_l0000gooooo`;o0000
<?ooool002Cooooo00Co0000oooooooooooooooo0_l0000Booooo`;o0000=oooool2o`0002?ooooo
0_l0000cooooo`;o0000;?ooool2o`0001[ooooo0_l00005ooooo`;o00005?ooool2o`00033ooooo
000Tooooo`04o`000?ooooooooooooooo`;o0000Boooool2o`0002Sooooo0_l0000:ooooo`;o0000
K?ooool2o`0000Gooooo0_l00016ooooo`009?ooool2o`0007Wooooo0_l0000:ooooo`;o0000E_oo
ool2o`0000kooooo0_l0000Pooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool0g?ooool2
o`0000kooooo0_l0000Pooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool0Qoooool2o`00
05Wooooo0_l0000Looooo`;o00007Oooool2o`00023ooooo000Tooooo`03o`000?oooooooooo04_o
oooo0_l0000jooooo`;o0000E_ooool2o`000003ooooool0003o000001cooooo0_l0000Mooooo`;o
00008?ooool002Cooooo00?o0000ooooooooool0Boooool2o`0000[ooooo0_l0001jooooo`;o0000
2_ooool2o`00063ooooo000Tooooo`;o0000F?ooool2o`0007Gooooo0_l00003ooooo`?o00006Ooo
ool2o`00053ooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0000looooo`;o0000Ioooool2
o`0000Oooooo0_l00004ooooo`;o00006Oooool2o`0000Oooooo0_l0000Xooooo`;o00007Oooool0
02Cooooo00?o0000ooooooooool05_ooool2o`0000Kooooo0_l0000]ooooo`;o00003Oooool2o`00
06Oooooo0_l0000aooooo`;o0000:?ooool2o`0001gooooo000Tooooo`03o`000?oooooooooo01Ko
oooo0_l0000eooooo`;o0000<_ooool2o`0002Sooooo0_l0001>ooooo`;o0000A?ooool002Cooooo
00?o0000ooooooooool0AOooool2o`0003[ooooo0_l0000Eooooo`;o00004Oooool2o`0003[ooooo
0_l0000Booooo`;o0000A?ooool002Cooooo0_l0000nooooo`;o00001_ooool2o`00057ooooo0_l0
000Sooooo`;o0000:?ooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo03gooooo0_l0001n
ooooo`;o0000P_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo057ooooo0_l0001:ooooo`;o0000M_ooool2o`0002[ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo0_l0000mooooo`;o
0000B_ooool2o`000003ooooool0003o000007?ooooo0_l0000Zooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool3o`0001;ooooo0_l0000Mooooo`;o00001oooool2o`0006Cooooo0_l00013ooooo`;o0000
??ooool2o`0001cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo037ooooo0_l0
0007ooooo`;o0000?oooool2o`0006Sooooo0_l0000looooo`;o00007?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Vooooo`;o0000Doooool2o`0000Kooooo0_l0
000aooooo`;o0000ROooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool2
o`0001Cooooo0_l00015ooooo`;o00002_ooool2o`0000gooooo0_l0000Booooo`;o00000_ooool2
o`0005cooooo0_l0000[ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo
0_l0000:ooooo`;o0000AOooool2o`0000gooooo0_l0000Booooo`;o0000B_ooool2o`0001Cooooo
0_l0000[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0000Tooooo`;o00008oooool2o`000;Cooooo0_l00004oooo
o`;o0000>oooool002Cooooo00?o0000ooooooooool08oooool2o`0003gooooo0_l00004ooooo`;o
0000Aoooool2o`00057ooooo0_l0000kooooo`009?ooool00ol0003oooooooooo`0gooooo`;o0000
:Oooool2o`0000Cooooo0_l0000oooooo`;o00001_ooool2o`0008kooooo000Tooooo`03o`000?oo
oooooooo03;ooooo0_l00003ooooo`;o0000L?ooool2o`0005Kooooo0_l0000nooooo`009?ooool0
0ol0003oooooooooo`0booooo`;o0000Roooool2o`00043ooooo0_l0000nooooo`009?ooool00ol0
003oooooooooo`2oooooo`;o0000P?ooool002Cooooo0_l0002jooooo`;o0000B?ooool2o`0003co
oooo000Tooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`;o0000B?ooool2o`0003cooooo
000Tooooo`03o`000?oooooooooo02Wooooo0_l00017ooooo`;o0000cOooool002Cooooo00?o0000
ooooooooool03Oooool2o`0006?ooooo0_l0001Zooooo`;o0000HOooool002Cooooo00?o0000oooo
ooooool03Oooool2o`0004Cooooo0_l00029ooooo`;o0000>oooool2o`0000kooooo0_l0000Doooo
o`009?ooool2o`0005Cooooo0_l00036ooooo`;o00003_ooool2o`0001Cooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0SOooool2o`000003ooooool0
003o0000083ooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`2=ooooo`;o000000?ooooo
o`000?l00000P?ooool2o`0001Gooooo0_l0000Fooooo`009?ooool00ol0003oooooooooo`3coooo
o`;o0000=?ooool2o`0001Kooooo000Tooooo`;o00005?ooool2o`0000cooooo0_l0003@ooooo`;o
0000C?ooool002Cooooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l0000<ooooo`;o0000
Z?ooool2o`0007Cooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l0002aooooo`;o
00003oooool2o`0007Cooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o0000>_ooool2o`0001oo
oooo0_l0001Aooooo`;o0000QOooool000Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool2o`0003[ooooo0_l0000Oooooo`;o
0000f?ooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0001Nooooo`;o0000hOooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Nooooo`;o0000c_ooool2o`00
017ooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo;oooool2o`00017ooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo043ooooo0_l0002Foooo
o`;o0000C_ooool2o`0001Oooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo00?o0000ooooooooool0@?ooool2o`0009Kooooo0_l0000]ooooo`;o00007oooool2o`00
01Oooooo000Tooooo`;o0000ooooool9ooooo`;o0000>?ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooooaWooooo0_l0000Wooooo`009?ooool0
0ol0003oooooooooo`3ooooooaWooooo0_l0000Wooooo`009?ooool00ol0003oooooooooo`05oooo
o`;o0000;Oooool2o`00053ooooo0_l0002iooooo`009?ooool2o`0000Kooooo0_l0000]ooooo`;o
0000D?ooool2o`0002Oooooo0_l0002@ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000
=?ooool2o`00067ooooo0_l0000Booooo`;o0000T?ooool002Cooooo00?o0000ooooooooool00_oo
ool2o`0003Cooooo0_l0001Qooooo`;o00004Oooool2o`00097ooooo000Tooooo`03o`000?oooooo
oooo01gooooo0_l0000eooooo`;o0000F?ooool2o`00027ooooo0_l0001^ooooo`009?ooool00ol0
003oooooooooo`0Mooooo`;o0000=Oooool2o`0007_ooooo0_l0001^ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0?oooool2o`0005Kooooo0_l0000_ooooo`;o0000
Moooool002Cooooo00?o0000ooooooooool0?oooool2o`0005Kooooo0_l0000=ooooo`;o00006?oo
ool2o`0000Kooooo0_l0001gooooo`009?ooool00ol0003oooooooooo`2Vooooo`;o00006?ooool2
o`0007oooooo000Tooooo`03o`000?oooooooooo01Sooooo0_l0002;ooooo`;o0000NOooool2o`00
01oooooo000Tooooo`;o00006Oooool2o`0008_ooooo0_l0001iooooo`;o00007oooool002Cooooo
00?o0000ooooooooool0Goooool2o`0000Wooooo0_l0003Eooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`1Oooooo`;o00002Oooool2o`000=Gooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`1iooooo`;o0000a_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0;oooool2o`0004Sooooo0_l0002Looooo`;o0000:?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000_ooooo`;o0000W?ooool2o`0004Sooooo0_l0000Xooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<gooooo0_l0001;ooooo`;o
00002Oooool2o`0001[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Wooooo
0_l0002Jooooo`;o00008oooool2o`0000Wooooo0_l0000Jooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo0_l00017ooooo`;o0000=oooool2o`00067ooooo0_l0001:oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool04?ooool2o`00083ooooo0_l0002]ooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo07Gooooo0_l0003:ooooo`009?ooool00ol0003oooooooooo`1e
ooooo`;o0000b_ooool002Cooooo0_l0002Tooooo`;o0000W?ooool002Cooooo00?o0000oooooooo
ool03oooool2o`0009;ooooo0_l0002Looooo`009?ooool00ol0003oooooooooo`0?ooooo`;o0000
7Oooool2o`0004cooooo0_l00033ooooo`009?ooool00ol0003oooooooooo`0^ooooo`;o0000?_oo
ool2o`0000cooooo0_l00033ooooo`009?ooool00ol0003oooooooooo`1^ooooo`;o00007?ooool2
o`0003Wooooo0_l0001hooooo`009?ooool2o`0008gooooo0_l0000iooooo`;o0000N?ooool002Co
oooo00?o0000ooooooooool0d?ooool2o`0006oooooo000Tooooo`03o`000?oooooooooo0=3ooooo
0_l0001_ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo2_ooool3o`0003Gooooo000Tooooo`;o0000ooooool;ooooo`?o00009Oooool2o`00
00kooooo000Tooooo`03o`000?oooooooooo06Cooooo0_l0003;ooooo`;o00003_ooool001[ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo0_l0000Eooooo`;o0000
2?ooool2o`0002kooooo0_l0002[ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Cooooo0_l0000Mooooo`;o00005Oooool2o`0003Sooooo0_l0002[ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l0002cooooo`;o0000I_ooool0
01cooooo00?o0000ooooooooool01Oooool3o`0002Oooooo0_l0002`ooooo`;o0000I_ooool001co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`;o00006Oooool2o`0007So
oooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo
0_l0002Cooooo`;o0000W_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooood;ooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0O_ooool2
o`000<7ooooo000Tooooo`;o0000DOooool2o`0002cooooo0_l00031ooooo`009?ooool00ol0003o
ooooooooo`1@ooooo`;o0000koooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?3ooooo0_l0001?
ooooo`009?ooool2o`0004[ooooo0_l0002Uooooo`;o0000Coooool002Cooooo00?o0000oooooooo
ool0BOooool2o`0007oooooo0_l0001eooooo`009?ooool00ol0003oooooooooo`3:ooooo`;o0000
MOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo09[ooooo0_l0002Uooooo`009?ooool00ol0003ooooooooo
o`2Jooooo`;o0000YOooool002Cooooo00?o0000ooooooooool0Joooool2o`000=Cooooo000Toooo
o`;o0000K?ooool2o`000=Cooooo000Tooooo`03o`000?oooooooooo09Gooooo0_l0001Booooo`;o
0000E_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo09Gooooo0_l0001Booooo`;o
0000E_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;?ooool2o`000?oo
oooo5?ooool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool2o`000?oooooo5?ooool000Cooooo00?o
0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool2
o`000>Wooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`1Fooooo`;o0000jOooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l00020ooooo`;o0000:oooool2o`0009?ooooo000Tooooo`03
o`000?oooooooooo07oooooo0_l0000[ooooo`;o0000Hoooool2o`0002kooooo000Tooooo`03o`00
0?oooooooooo0?oooooo4_ooool2o`0002kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo04;ooooo0_l0003mooooo`009?ooool00ol0003oooooooooo`12
ooooo`;o0000oOooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo3Oooool2o`0003?ooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMg
oc8b<_ooool01?ooool3o`000?oooooo3Oooool2o`0003?ooooo000<ooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3fooooo`;o0000BOooool002Co
oooo00?o0000ooooooooool0m_ooool2o`0004Wooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0002;ooooo`;o0000]Ooo
ool002Cooooo00?o0000ooooooooool0R_ooool2o`000;Gooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000a?ooool2o`0007cooooo000Tooooo`03o`000?oooooo
oooo0<?ooooo0_l0000Uooooo`;o0000EOooool000;ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3Zooooo`;o0000EOooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooo
ooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo
@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oo
oooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Uooooo`;o0000f_oo
ool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo06Gooooo0_l0003Jooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo067ooooo0_l0002Jooooo`;o0000@_oo
ool002Cooooo00?o0000ooooooooool0HOooool2o`0009[ooooo0_l00012ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo06gooooo0_l0003Booooo`009?ooool0
0ol0003oooooooooo`1]ooooo`;o0000d_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo
@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo
@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo
0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[Zj
oooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_o
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .07729 Mdot
.0381 .02526 Mdot
.04286 .17536 Mdot
.05238 .18425 Mdot
.05714 .18219 Mdot
.0619 .01287 Mdot
.06667 .0044 Mdot
.07619 .11855 Mdot
.08095 .22204 Mdot
.08571 .06336 Mdot
.09048 .19238 Mdot
.09524 .05474 Mdot
.1 .01868 Mdot
.10476 .05325 Mdot
.10952 .11568 Mdot
.11429 .02215 Mdot
.11905 .01045 Mdot
.12381 .03054 Mdot
.12857 .03381 Mdot
.13333 .00729 Mdot
.1381 .17095 Mdot
.14286 .08028 Mdot
.14762 .27944 Mdot
.15238 .08271 Mdot
.15714 .07514 Mdot
.1619 .053 Mdot
.16667 .34613 Mdot
.17143 .30013 Mdot
.17619 .38146 Mdot
.18095 .33635 Mdot
.18571 .07559 Mdot
.19048 .14594 Mdot
.19524 .10954 Mdot
.2 .09861 Mdot
.20476 .13493 Mdot
.20952 .11065 Mdot
.21429 .07645 Mdot
.21905 .08527 Mdot
.22381 .06071 Mdot
.22857 .01691 Mdot
.23333 .16445 Mdot
.2381 .59483 Mdot
.24286 .10086 Mdot
.24762 .01387 Mdot
.25238 .06447 Mdot
.25714 .08779 Mdot
.2619 .14228 Mdot
.26667 .15899 Mdot
.27143 .16569 Mdot
.27619 .0475 Mdot
.28095 .15591 Mdot
.28571 .07025 Mdot
.29048 .2871 Mdot
.29524 .3175 Mdot
.3 .19213 Mdot
.30476 .04775 Mdot
.30952 .18653 Mdot
.31429 .30175 Mdot
.31905 .06843 Mdot
.32381 .15768 Mdot
.32857 .02243 Mdot
.3381 .02075 Mdot
.34286 .1713 Mdot
.34762 .5147 Mdot
.35238 .15053 Mdot
.35714 .12027 Mdot
.3619 .02258 Mdot
.36667 .20478 Mdot
.37619 .58319 Mdot
.38095 .23824 Mdot
.38571 .15093 Mdot
.39048 .01979 Mdot
.39524 .14623 Mdot
.4 .17205 Mdot
.40476 .19832 Mdot
.40952 .10207 Mdot
.41429 .03636 Mdot
.41905 .29351 Mdot
.42381 .31449 Mdot
.42857 .50314 Mdot
.43333 .13083 Mdot
.4381 .04816 Mdot
.44286 .02828 Mdot
.44762 .22762 Mdot
.45238 .03762 Mdot
.45714 .01046 Mdot
.4619 .27354 Mdot
.46667 .05182 Mdot
.47143 .133 Mdot
.47619 .03091 Mdot
.48095 .0395 Mdot
.48571 .18029 Mdot
.49048 .31294 Mdot
.49524 .14191 Mdot
.5 .20719 Mdot
.50476 .10689 Mdot
.50952 .1835 Mdot
.51429 .01005 Mdot
.51905 .06982 Mdot
.52381 .00275 Mdot
.52857 .29217 Mdot
.53333 .29971 Mdot
.5381 .1183 Mdot
.54286 .14219 Mdot
.54762 .36959 Mdot
.55238 .02189 Mdot
.55714 .02865 Mdot
.5619 .11887 Mdot
.56667 .51198 Mdot
.57143 .09064 Mdot
.57619 .37833 Mdot
.58095 .09438 Mdot
.58571 .06243 Mdot
.59048 .47881 Mdot
.59524 .00838 Mdot
.6 .01606 Mdot
.60476 .06785 Mdot
.60952 .1339 Mdot
.61429 .11037 Mdot
.61905 .04884 Mdot
.62381 .10351 Mdot
.62857 .27444 Mdot
.63333 .00787 Mdot
.6381 .16917 Mdot
.64286 .02577 Mdot
.64762 .21125 Mdot
.65238 .26566 Mdot
.65714 .3442 Mdot
.6619 .0292 Mdot
.66667 .05395 Mdot
.67143 .11647 Mdot
.67619 .16039 Mdot
.68095 .06316 Mdot
.68571 .04342 Mdot
.69048 .10266 Mdot
.69524 .02215 Mdot
.7 .11494 Mdot
.70476 .36138 Mdot
.70952 .01511 Mdot
.71429 .03093 Mdot
.71905 .27974 Mdot
.72381 .00011 Mdot
.72857 .15525 Mdot
.73333 .27615 Mdot
.7381 .41354 Mdot
.74286 .07634 Mdot
.74762 .05943 Mdot
.75238 .14035 Mdot
.75714 .15958 Mdot
.7619 .0291 Mdot
.76667 .02168 Mdot
.77143 .0611 Mdot
.77619 .24726 Mdot
.78095 .06262 Mdot
.78571 .25777 Mdot
.79048 .08031 Mdot
.79524 .45671 Mdot
.8 .04755 Mdot
.80476 .02457 Mdot
.80952 .0539 Mdot
.81429 .49616 Mdot
.81905 .14894 Mdot
.82381 .01351 Mdot
.82857 .10257 Mdot
.83333 .28475 Mdot
.8381 .09075 Mdot
.84286 .04539 Mdot
.84762 .00463 Mdot
.85238 .1395 Mdot
.85714 .48606 Mdot
.8619 .51472 Mdot
.86667 .03099 Mdot
.87143 .00412 Mdot
.87619 .18906 Mdot
.88095 .19433 Mdot
.88571 .06553 Mdot
.89048 .06924 Mdot
.89524 .22955 Mdot
.9 .01341 Mdot
.90476 .40629 Mdot
.90952 .24587 Mdot
.91905 .15594 Mdot
.92381 .18784 Mdot
.92857 .04898 Mdot
.93333 .07697 Mdot
.9381 .03424 Mdot
.94286 .33493 Mdot
.94762 .16477 Mdot
.95238 .0022 Mdot
.95714 .46046 Mdot
.9619 .00133 Mdot
.96667 .09359 Mdot
.97143 .20629 Mdot
.97619 .26184 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000004ooooo`03o`00
0?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00[ooooo0ol0000?ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01?ooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool03?oo
ool002Cooooo00?o0000ooooooooool02_ooool2o`0001Cooooo0_l0001iooooo`;o00006Oooool2
o`0000[ooooo0_l00013ooooo`;o00001_ooool2o`00033ooooo000Tooooo`03o`000?oooooooooo
00Wooooo0_l0000@ooooo`;o00000oooool2o`0006Oooooo0_l0000@ooooo`;o00006Oooool2o`00
00[ooooo0_l0001mooooo`009?ooool2o`0000[ooooo0_l0000@ooooo`;o0000:?ooool2o`0004;o
oooo0_l0000/ooooo`;o00008_ooool2o`0002?ooooo0_l0000Fooooo`;o00009oooool002Cooooo
00?o0000ooooooooool05Oooool2o`0002Sooooo0_l00004ooooo`;o0000L?ooool2o`0002;ooooo
0_l0000Sooooo`;o00005_ooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo01Gooooo0_l0
0003ooooo`;o00008oooool2o`0001kooooo0_l000000ooooooo0000o`00000?ooooo`;o0000<ooo
ool2o`0002cooooo0_l0000Eooooo`;o0000D_ooool002Cooooo00Co0000oooooooooooooooo0_l0
000Gooooo`;o0000@oooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o0000<ooo
ool2o`0002cooooo0_l0000Eooooo`;o00002_ooool2o`0004Kooooo000Tooooo`04o`000?oooooo
ooooooooo`;o0000Ioooool2o`0001Sooooo0_l0000Sooooo`;o00006_ooool2o`0003;ooooo0_l0
0016ooooo`009?ooool2o`0001kooooo0_l0001Uooooo`;o00002Oooool2o`0001Sooooo0_l0000J
ooooo`;o00001?ooool2o`0000oooooo0_l0000>ooooo`;o00008?ooool2o`00037ooooo000Toooo
o`03o`000?oooooooooo01gooooo0ol0001_ooooo`;o0000>_ooool2o`0000oooooo0_l0000>oooo
o`;o00008?ooool2o`0001Gooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o
0000Foooool2o`0000[ooooo0_l0002Looooo`;o00006_ooool002Cooooo00?o0000ooooooooool0
Noooool2o`0000[ooooo0_l00007ooooo`;o0000[oooool002Cooooo00?o0000ooooooooool0T?oo
ool2o`00047ooooo0_l0001/ooooo`009?ooool2o`000=Cooooo0_l0000aooooo`;o0000>Oooool0
02Cooooo00?o0000ooooooooool0C_ooool2o`0000Oooooo0_l0000Zooooo`;o0000>?ooool2o`00
03Wooooo0_l0000<ooooo`;o00006_ooool2o`0001gooooo000Tooooo`03o`000?oooooooooo01Ko
oooo0_l0000Aooooo`;o00008oooool2o`0000Oooooo0_l0000Zooooo`;o00001oooool2o`0002oo
oooo0_l0000iooooo`;o0000:?ooool2o`0001gooooo000Tooooo`03o`000?oooooooooo01?ooooo
0_l000000ooooooo0000o`00000Aooooo`;o0000HOooool2o`0003oooooo0_l0000/ooooo`;o0000
A?ooool002Cooooo00?o0000ooooooooool04oooool2o`000;Sooooo0_l0000Hooooo`;o00004_oo
ool2o`0004Cooooo000Tooooo`;o0000?_ooool2o`0007?ooooo0_l0000cooooo`;o00001_ooool2
o`000003ooooool0003o000004gooooo000Tooooo`03o`000?oooooooooo013ooooo0_l0000[oooo
o`;o00001oooool2o`0006[ooooo0_l0000Mooooo`;o00007?ooool2o`000003ooooool0003o0000
023ooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o0000=?ooool2o`0001Co
oooo0_l0001Kooooo`;o00005_ooool2o`00047ooooo0_l0000[ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo057ooooo0_l00009ooooo`;o0000?oooool2o`0001[ooooo0_l0001J
ooooo`;o0000:_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
DOooool2o`0004[ooooo0_l0001fooooo`;o0000:_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo1?l0
000Vooooo`;o00002?ooool2o`0000Oooooo0_l0002Yooooo`;o0000??ooool2o`0001cooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`04o`000?oooooo0000o`0002;ooooo0_l00002ooooo`;o00002?oo
ool2o`0000Oooooo0_l0002Yooooo`;o00003_ooool2o`0002cooooo0_l0000Looooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02?ooooo0_l000000ooooooo0000o`00
003=ooooo`;o0000B_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool2
o`0001Cooooo0_l0003oooooo`Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
??ooool2o`0000[ooooo0_l0003gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00019ooooo`;o0000I?ooool2o`00
05Cooooo0_l0000kooooo`009?ooool00ol0003oooooooooo`2^ooooo`;o000000?oooooo`000?l0
0000DOooool2o`0002Sooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`0eooooo`;o0000
N_ooool2o`0007_ooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`0eooooo`;o00003?oo
ool2o`0003Cooooo0_l0001Iooooo`;o0000:oooool2o`0003kooooo000Tooooo`03o`000?oooooo
oooo04?ooooo0_l0000dooooo`;o0000A?ooool2o`0001?ooooo0_l0000[ooooo`;o0000?_ooool0
02Cooooo00?o0000ooooooooool0V?ooool2o`0002Gooooo0_l00020ooooo`009?ooool2o`0003Go
oooo0_l00002ooooo`;o0000G_ooool2o`0002;ooooo0_l00023ooooo`009?ooool00ol0003ooooo
ooooo`0dooooo`;o00000_ooool2o`0008;ooooo0_l0000Jooooo`;o0000Ioooool002Cooooo00?o
0000ooooooooool06?ooool2o`000;Cooooo0_l00008ooooo`;o0000Ioooool002Cooooo00?o0000
ooooooooool03Oooool2o`0000Wooooo0_l0001>ooooo`;o0000>Oooool2o`0000Kooooo0_l0000Q
ooooo`;o0000LOooool002Cooooo00?o0000ooooooooool03Oooool2o`0005Wooooo0_l0000ioooo
o`;o00001_ooool2o`0009Cooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo087ooooo0_l0000:ooooo`;o0000/_oo
ool002Cooooo00?o0000ooooooooool0=oooool2o`0004Sooooo0_l0000:ooooo`;o0000:oooool2
o`0008Gooooo000Tooooo`03o`000?oooooooooo03Oooooo0_l00021ooooo`;o0000COooool2o`00
03Kooooo000Tooooo`;o0000B_ooool2o`0004[ooooo0_l0000>ooooo`;o0000@_ooool2o`0001ko
oooo0_l0000fooooo`009?ooool00ol0003oooooooooo`19ooooo`;o0000B_ooool2o`0000kooooo
0_l00012ooooo`;o0000E_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<_ooool2o`00047o
oooo0_l00027ooooo`;o0000@Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03;ooooo0_l0000cooooo`;o
00002Oooool2o`000003ooooool0003o000008Oooooo0_l00011ooooo`002Oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Wooooo`;o
00002Oooool2o`000<gooooo0009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`?o0000D?ooool2o`0000cooooo0_l00021ooooo`;o0000??ooool2o`00023o
oooo0009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l0000<ooooo`;o0000L?ooool2o`00
00oooooo0_l00007ooooo`;o0000<oooool2o`00023ooooo0009ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo0_l00023oooo
o`;o00006?ooool2o`0005Gooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo043ooooo0_l0000;ooooo`;o0000fOooool2o`00
01Oooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool0@?ooool2o`0000_ooooo0_l0001dooooo`;o0000Hoooool2o`0001Oooooo000Tooooo`;o
00008_ooool2o`00047ooooo0_l0000@ooooo`;o0000Boooool2o`0007cooooo000Tooooo`03o`00
0?oooooooooo00;ooooo0_l0000Mooooo`;o0000@Oooool2o`00013ooooo0_l00039ooooo`009?oo
ool00ol0003oooooooooo`02ooooo`;o0000oooooolnooooo`009?ooool00ol0003oooooooooo`07
ooooo`;o0000ROooool2o`000:gooooo000Tooooo`03o`000?oooooooooo00Gooooo1?l00029oooo
o`;o00001_ooool2o`000:Gooooo000Tooooo`;o00001_ooool2o`0005;ooooo0_l0000oooooo`;o
0000MOooool2o`0000gooooo0_l0000Oooooo`009?ooool00ol0003oooooooooo`1Fooooo`;o0000
00?oooooo`000?l00000]_ooool2o`0000gooooo0_l0000Oooooo`009?ooool00ol0003ooooooooo
o`0Booooo`;o0000@_ooool2o`000;[ooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`0B
ooooo`;o0000I?ooool2o`0009Sooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`1hoooo
o`;o0000aoooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo06_ooooo
0_l0000Zooooo`;o0000Uoooool2o`0000oooooo000Tooooo`03o`000?oooooooooo06_ooooo0_l0
000Zooooo`;o0000Uoooool2o`0000oooooo000Tooooo`03o`000?oooooooooo0<Oooooo0_l0001h
ooooo`009?ooool00ol0003oooooooooo`37ooooo`;o0000N?ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo00oooooo0_l0003ooooooc7ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo00oooooo0_l0003ooooooc7ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`26ooooo`;o0000^Oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Q_ooool2o`0008oooooo0_l0000Xooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000?oooooo6?ooool2o`0002Sooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0L?ooool2o`000<oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo073ooooo0_l0003?ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006
ooooo`03o`000?oooooooooo0?3ooooo0_l0000Yooooo`;o00009?ooool002Cooooo0_l0003aoooo
o`;o0000:Oooool2o`0002Cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3cooooo`;o0000C?oo
ool002Cooooo00?o0000ooooooooool0loooool2o`0003cooooo0_l0000>ooooo`009?ooool2o`00
0<Wooooo0_l0001Wooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0b?ooool2o`0007Oo
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0R_oo
ool2o`0003Cooooo0_l0001oooooo`009?ooool00ol0003oooooooooo`2:ooooo`;o0000=?ooool2
o`00023ooooo0_l0001Mooooo`009?ooool2o`0002Gooooo0_l0002hooooo`;o00000_ooool2o`00
05gooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l0002hooooo`;o0000HOooool002Cooooo
00?o0000ooooooooool0Doooool2o`000:kooooo0_l0000looooo`009?ooool00ol0003ooooooooo
o`1Cooooo`;o0000[_ooool2o`0003cooooo000Tooooo`03o`000?oooooooooo07cooooo0_l0000R
ooooo`;o0000Woooool002Cooooo0_l0001mooooo`;o00008_ooool2o`0009oooooo000Tooooo`03
o`000?oooooooooo0:7ooooo0_l0002Nooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0;?ooool2o`0002cooooo0_l00015ooooo`;o0000W_ooool001cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`;o0000;?ooool2o`000>Gooooo000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo07kooooo0_l0000Dooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Dooooo`;o0000:?ooool2o`0001Cooooo0_l0002[ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo0_l0003[ooooo`006_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000mOooool2o`0001Wooooo000T
ooooo`03o`000?oooooooooo02oooooo0_l0003eooooo`;o00006Oooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo02_ooooo0_l0002Mooooo`;o0000MOooool002Cooooo
00?o0000ooooooooool0:oooool2o`0009gooooo0_l0001eooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0=Wooooo0_l0001Vooooo`009?ooool00ol0003ooooo
ooooo`3Iooooo`;o0000I_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`2Vooooo`;o0000VOooool002Cooooo0_l0002Wooooo`;o0000VOooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0[oooool2o`00093ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02ko
oooo0_l0001oooooo`;o0000T?ooool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool2o`000?oooooo
4_ooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo
00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooolKooooo`;o00009Oooool002Cooooo
00?o0000ooooooooool0oooooolKooooo`;o00009Oooool002Cooooo00?o0000ooooooooool0i?oo
ool2o`0005_ooooo000Tooooo`03o`000?oooooooooo0>Cooooo0_l0001Kooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3fooooo`;o0000BOooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3fooooo`;o0000BOooool000cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo;?oo
ool2o`0001Cooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000?oooooo;?ooool2o`0001Cooooo000<ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0
]?ooool2o`0008_ooooo000Tooooo`;o0000]Oooool2o`0008_ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0ooooool;ooooo`;o0000=Oooool002Co
oooo00?o0000ooooooooool0ooooool;ooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?kooooo0_l00012ooooo`009?ooool00ol0003oooooooooo`3m
ooooo`;o0000@_ooool002Cooooo00?o0000ooooooooool0Ooooool2o`000<3ooooo000Tooooo`03
o`000?oooooooooo07oooooo0_l00030ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000[Oooool2o`0009?ooooo000Tooooo`03o`000?oooooooooo06Gooooo0_l00015
ooooo`;o0000G_ooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo06Gooooo0_l0002Uoooo
o`;o0000<oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003o
ooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003ooooooooo
o`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`1^ooooo`;o0000dOooool002Cooooo00?o0000ooooooooool0K_ooool2o`000=7ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo04;ooooo0_l0003mooooo`009?ooool00ol0003oooooooooo`12ooooo`;o0000oOoo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0
oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo@_oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo@_ooool001cooooo00?oMgMgofIV
I_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo000Iooooo`05o`00
0?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oo
ooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .60987 Mdot
.03333 .20463 Mdot
.0381 .02526 Mdot
.04286 .07102 Mdot
.05238 .18425 Mdot
.05714 .2311 Mdot
.0619 .01287 Mdot
.06667 .29919 Mdot
.07619 .11855 Mdot
.08095 .06882 Mdot
.08571 .06336 Mdot
.09048 .10806 Mdot
.09524 .09403 Mdot
.1 .01868 Mdot
.10476 .09611 Mdot
.10952 .03317 Mdot
.11429 .06819 Mdot
.11905 .034 Mdot
.12381 .03054 Mdot
.12857 .03381 Mdot
.13333 .06444 Mdot
.1381 .04723 Mdot
.14286 .05091 Mdot
.14762 .27944 Mdot
.15238 .23569 Mdot
.15714 .02303 Mdot
.1619 .09922 Mdot
.16667 .00864 Mdot
.17143 .09541 Mdot
.17619 .17483 Mdot
.18095 .23519 Mdot
.18571 .01122 Mdot
.19048 .16632 Mdot
.19524 .01217 Mdot
.2 .02917 Mdot
.20476 .08655 Mdot
.20952 .28713 Mdot
.21429 .09975 Mdot
.21905 .0545 Mdot
.22381 .0266 Mdot
.22857 .01691 Mdot
.23333 .10457 Mdot
.2381 .50342 Mdot
.24286 .40072 Mdot
.24762 .02325 Mdot
.25238 .06447 Mdot
.25714 .07662 Mdot
.2619 .02492 Mdot
.26667 .04308 Mdot
.27143 .1229 Mdot
.27619 .01675 Mdot
.28095 .15591 Mdot
.28571 .32003 Mdot
.29048 .13269 Mdot
.29524 .04049 Mdot
.3 .06865 Mdot
.30476 .01007 Mdot
.30952 .0993 Mdot
.31429 .20325 Mdot
.31905 .06843 Mdot
.32381 .07187 Mdot
.32857 .02676 Mdot
.33333 .45421 Mdot
.3381 .02075 Mdot
.34286 .1713 Mdot
.34762 .27864 Mdot
.35238 .15053 Mdot
.35714 .02579 Mdot
.3619 .02258 Mdot
.36667 .03537 Mdot
.37619 .36053 Mdot
.38095 .14115 Mdot
.38571 .09065 Mdot
.39048 .07011 Mdot
.39524 .14623 Mdot
.4 .0645 Mdot
.40476 .19832 Mdot
.40952 .10207 Mdot
.41429 .00513 Mdot
.41905 .27712 Mdot
.42381 .41191 Mdot
.42857 .51855 Mdot
.43333 .02578 Mdot
.4381 .07202 Mdot
.44286 .20454 Mdot
.44762 .07015 Mdot
.45238 .03762 Mdot
.45714 .05892 Mdot
.4619 .01988 Mdot
.46667 .05182 Mdot
.47143 .01831 Mdot
.47619 .03091 Mdot
.48095 .14411 Mdot
.48571 .09734 Mdot
.49048 .27279 Mdot
.49524 .0581 Mdot
.5 .26024 Mdot
.50476 .00708 Mdot
.50952 .25985 Mdot
.51429 .01005 Mdot
.51905 .07439 Mdot
.52381 .03152 Mdot
.52857 .48393 Mdot
.53333 .01958 Mdot
.5381 .15125 Mdot
.54286 .14219 Mdot
.54762 .18737 Mdot
.55238 .02189 Mdot
.55714 .02865 Mdot
.5619 .22438 Mdot
.56667 .24431 Mdot
.57143 .09064 Mdot
.57619 .03581 Mdot
.58095 .04624 Mdot
.58571 .06243 Mdot
.59048 .4723 Mdot
.59524 .19535 Mdot
.6 .24477 Mdot
.60476 .14421 Mdot
.60952 .07588 Mdot
.61429 .10226 Mdot
.61905 .04884 Mdot
.62381 .10351 Mdot
.62857 .32622 Mdot
.63333 .05032 Mdot
.6381 .15414 Mdot
.64286 .09491 Mdot
.64762 .06198 Mdot
.65238 .23002 Mdot
.65714 .177 Mdot
.6619 .0292 Mdot
.66667 .02521 Mdot
.67143 .11647 Mdot
.67619 .16039 Mdot
.68095 .21821 Mdot
.68571 .01835 Mdot
.69048 .00028 Mdot
.69524 .02215 Mdot
.7 .01991 Mdot
.70476 .21525 Mdot
.70952 .01511 Mdot
.71429 .13764 Mdot
.71905 .27974 Mdot
.72381 .05813 Mdot
.72857 .15525 Mdot
.73333 .41471 Mdot
.7381 .41354 Mdot
.74286 .32962 Mdot
.74762 .00966 Mdot
.75238 .14035 Mdot
.75714 .3641 Mdot
.7619 .0707 Mdot
.76667 .02168 Mdot
.77143 .17029 Mdot
.77619 .3251 Mdot
.78095 .06262 Mdot
.78571 .14262 Mdot
.79048 .16625 Mdot
.79524 .51092 Mdot
.8 .04755 Mdot
.80476 .02457 Mdot
.80952 .15561 Mdot
.81429 .43001 Mdot
.81905 .18573 Mdot
.82381 .02139 Mdot
.82857 .03527 Mdot
.83333 .35129 Mdot
.8381 .10821 Mdot
.84286 .11068 Mdot
.84762 .1104 Mdot
.85238 .07932 Mdot
.85714 .48606 Mdot
.8619 .47376 Mdot
.86667 .01363 Mdot
.87143 .00412 Mdot
.87619 .17471 Mdot
.88095 .19433 Mdot
.88571 .06553 Mdot
.89048 .06924 Mdot
.89524 .14759 Mdot
.9 .04117 Mdot
.90476 .53621 Mdot
.90952 .4727 Mdot
.91905 .19812 Mdot
.92381 .18784 Mdot
.92857 .04305 Mdot
.93333 .14869 Mdot
.9381 .03424 Mdot
.94286 .10857 Mdot
.94762 .16477 Mdot
.95238 .0022 Mdot
.95714 .44182 Mdot
.9619 .04473 Mdot
.96667 .103 Mdot
.97143 .26071 Mdot
.97619 .57425 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`;o00003oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo
0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03?ooool002Cooooo00?o
0000ooooooooool0:oooool2o`0002[ooooo0_l0000Rooooo`;o00006oooool2o`000003ooooool0
003o000004[ooooo0_l0000Vooooo`;o0000<?ooool002Cooooo00?o0000ooooooooool02Oooool2
o`00023ooooo0_l00004ooooo`;o000000?oooooo`000?l000008Oooool2o`0004;ooooo0_l0001:
ooooo`;o0000F?ooool002Cooooo0_l0000:ooooo`;o00009_ooool2o`000003ooooool0003o0000
0:Gooooo0_l0000aooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool05Oooool2o`0002So
oooo0_l0000=ooooo`;o0000?Oooool2o`0004Cooooo0_l00006ooooo`;o0000<Oooool2o`00037o
oooo000Tooooo`03o`000?oooooooooo01Gooooo0_l0000Xooooo`;o00003Oooool2o`0001;ooooo
0_l0000Vooooo`;o000000?oooooo`000?l000004_ooool2o`0000Gooooo0_l0000Yooooo`;o0000
00?oooooo`000?l000000_l0000Cooooo`;o00004Oooool2o`0003oooooo000Tooooo`04o`000?oo
ooooooooooooo`;o00009?ooool2o`0001cooooo0_l00002ooooo`;o00005oooool2o`0000Kooooo
0_l0000Nooooo`;o00005Oooool2o`0000Gooooo0_l0000Sooooo`;o00001oooool4o`0001?ooooo
0_l0000:ooooo`;o00001Oooool2o`0003oooooo000Tooooo`04o`000?ooooooooooooooo`;o0000
9?ooool2o`0001Cooooo0_l00006ooooo`;o00000_ooool2o`0001Cooooo0_l00007ooooo`Co0000
5Oooool2o`0002Kooooo0_l0000Rooooo`;o0000:_ooool2o`0004Kooooo000Tooooo`;o00007_oo
ool2o`0001Kooooo0_l00006ooooo`;o00008?ooool2o`0000Oooooo0_l0000Gooooo`;o00003?oo
ool2o`0000gooooo0_l00009ooooo`;o00008?ooool2o`0007Cooooo000Tooooo`03o`000?oooooo
oooo01Sooooo0_l000000ooooooo0000o`000003o`0001Gooooo0_l0001Hooooo`;o00003Oooool2
o`0002_ooooo0_l0001Hooooo`;o00006_ooool002Cooooo00?o0000ooooooooool06?ooool2o`00
0004ooooool0003o0000ooooo`;o0000Boooool2o`0001[ooooo0_l0000Vooooo`;o0000D?ooool2
o`0002;ooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o00005Oooool2o`00
01[ooooo0_l0000Vooooo`;o0000D?ooool2o`0003kooooo000Tooooo`03o`000?oooooooooo04_o
oooo0_l00007ooooo`;o0000`_ooool2o`0000Sooooo0_l0000Mooooo`009?ooool2o`0002;ooooo
0_l0000Xooooo`;o0000I?ooool2o`0006Gooooo0_l00008ooooo`;o00002?ooool2o`0001?ooooo
000Tooooo`03o`000?oooooooooo027ooooo0_l0002>ooooo`;o00002_ooool2o`0000?ooooo0_l0
000dooooo`;o0000<_ooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0001W
ooooo`;o0000;oooool2o`0000?ooooo0_l0000dooooo`;o0000Aoooool002Cooooo00?o0000oooo
ooooool08oooool2o`0001Oooooo0_l0001>ooooo`;o0000/oooool002Cooooo00?o0000oooooooo
ool0??ooool2o`0004_ooooo0_l0000:ooooo`;o0000B?ooool2o`00063ooooo000Tooooo`;o0000
R_ooool2o`0000[ooooo0_l0000Kooooo`;o00004oooool2o`0001Kooooo0_l0000Aooooo`;o0000
COooool002Cooooo00?o0000ooooooooool04?ooool2o`0000kooooo0_l0000Tooooo`;o0000;_oo
ool2o`0003[ooooo0_l0000Cooooo`;o0000:Oooool2o`00023ooooo0_l0000[ooooo`009?ooool0
0ol0003oooooooooo`0?ooooo`?o00002?ooool2o`0000Cooooo0_l0000Tooooo`;o00003_ooool2
o`0000Cooooo0_l0000Hooooo`;o0000W?ooool2o`0002_ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool00_ooool2o`0000_ooooo0_l00009ooooo`;o0000>_ooool2o`0000Cooooo
1?l0000Cooooo`;o00004Oooool2o`0006Cooooo0_l0000Wooooo`;o0000:_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_ooool2o`0005[ooooo0_l0000Coooo
o`;o00003_ooool2o`000003ooooool0003o000001Gooooo0_l0001=ooooo`;o00009oooool2o`00
02[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000B?ooool2o`0003Wooooo0_l0000Hooooo`;o
00006oooool2o`0008Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Sooooo
0_l0001`ooooo`;o0000COooool2o`0003Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0ooooool:ooooo`;o0000=_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0=oooool2o`000?oooooo2Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0gooooo`;o0000ooooool9ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001cooooo`;o0000>_ooool2
o`00097ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00000Doooo
o`;o0000A?ooool2o`0003[ooooo0_l0000Eooooo`;o0000N_ooool002Cooooo00?o0000oooooooo
ool04oooool2o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`00000[ooooo`;o
0000=oooool2o`00037ooooo0_l0001jooooo`009?ooool00ol0003oooooooooo`0Yooooo`;o0000
3oooool2o`0001gooooo0_l0000Nooooo`;o00005oooool2o`0002Sooooo0_l00023ooooo`009?oo
ool00ol0003oooooooooo`0jooooo`;o00001?ooool2o`0003Oooooo0_l00011ooooo`;o000000?o
ooooo`000?l00000KOooool2o`00017ooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0000/
ooooo`;o0000OOooool2o`0004?ooooo0_l0000Pooooo`;o00001_ooool2o`00017ooooo000Toooo
o`;o00004oooool2o`000?3ooooo1Ol0000Mooooo`;o00006Oooool002Cooooo00?o0000oooooooo
ool0ooooool7ooooo`?o0000>?ooool002Cooooo00?o0000ooooooooool0c_ooool2o`00077ooooo
000Tooooo`03o`000?oooooooooo00gooooo0_l0002oooooo`;o0000LOooool002Cooooo00?o0000
ooooooooool03Oooool2o`0003kooooo0_l0003booooo`009?ooool2o`0004kooooo0_l0003boooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo05?ooooo
0_l0003/ooooo`009?ooool00ol0003oooooooooo`1Cooooo`;o0000k?ooool002Cooooo00?o0000
ooooooooool0g?ooool2o`0006?ooooo000Tooooo`;o0000LOooool2o`0003?ooooo0_l0000eoooo
o`;o00002oooool2o`0000Sooooo0_l0001<ooooo`009?ooool00ol0003oooooooooo`1`ooooo`;o
00007_ooool2o`0001?ooooo0_l0000Booooo`;o0000;_ooool2o`0000Sooooo0_l0001<ooooo`00
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`1eooooo`;o00006Oooool2o`0002Oooooo0_l0001Loooo
o`;o00002_ooool2o`0001cooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Wooooo`;o00003?ooool2o`00
02cooooo0_l0001booooo`;o00002_ooool2o`0001cooooo0009ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Oooooo0_l0000joooo
o`;o00007_ooool2o`0007cooooo0009ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`04ooooo`?o0000D?ooool2o`00077ooooo0_l0000Looooo`;o00006?ooool2o`00
04Cooooo0009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0D?ooool2o`0007kooooo0_l0000?ooooo`;o00006?ooool2
o`0004Cooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0=3ooooo0_l0001_ooooo`002Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`;o0000`Oooool2
o`00037ooooo0_l0000Gooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`03o`000?oooooooooo03;ooooo0_l0002kooooo`;o00001?ooool2o`00037ooooo0_l0000G
ooooo`009?ooool2o`0006Gooooo0_l00029ooooo`;o0000D?ooool002Cooooo00?o0000oooooooo
ool0;_ooool2o`0003Cooooo0_l0002[ooooo`;o0000;_ooool002Cooooo00?o0000ooooooooool0
;_ooool2o`0009[ooooo0_l00015ooooo`;o0000;_ooool002Cooooo00?o0000ooooooooool0b_oo
ool2o`0007Gooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0003gooooo`;o0000@Oooool0
02Cooooo0_l00006ooooo`;o0000Woooool2o`0005Kooooo0_l0000Pooooo`;o00007oooool002Co
oooo00?o0000ooooooooool0Y_ooool2o`0007Sooooo0_l0000Oooooo`009?ooool00ol0003ooooo
ooooo`3ooooooa?ooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`1hooooo`;o0000??oo
ool2o`0005[ooooo0_l0000;ooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0N?ooool2
o`0003cooooo0_l0001Wooooo`;o00008?ooool002Cooooo0_l0001Kooooo`;o0000iOooool002Co
oooo00Co0000ooooool0003o0000FOooool2o`0002Sooooo0_l0002kooooo`009?ooool01?l0003o
ooooo`000?l00023ooooo`;o0000^oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3Iooooo`;o0000I_ooool002Cooooo0_l0003Booooo`;o00001_oo
ool2o`0006Kooooo000Tooooo`03o`000?oooooooooo0=7ooooo0_l0001^ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2[ooooo`;o0000U?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0:_ooooo0_l0002Dooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`;o0000_oooool2o`0007Oooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`?o00001oooool2o`0002Kooooo0_l0002Gooooo`;o0000Moooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Vooooo`;o00001oooool2o`000?oooooo4Ooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool2o`000?oooooo6_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2/ooooo`;o0000Toooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0:co
oooo0_l00009ooooo`;o0000R?ooool002Cooooo0_l0002hooooo`;o0000R?ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo09[ooooo0_l0002Uooooo`009?ooool00ol0003oooooooooo`2Gooooo`;o
000000?oooooo`000?l00000U?ooool2o`0000oooooo000Tooooo`;o0000V?ooool2o`0009Oooooo
0_l0000?ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0U?ooool2o`000:_ooooo000Tooooo`03
o`000?oooooooooo07cooooo0_l0000Fooooo`;o0000Zoooool002Cooooo0_l0000Uooooo`;o0000
?oooool2o`0001Gooooo0_l0001Pooooo`;o0000HOooool002Cooooo00?o0000ooooooooool09?oo
ool2o`0003oooooo0_l0001gooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0>?ooool2
o`000?oooooo2?ooool002Cooooo00?o0000ooooooooool0>?ooool2o`000?oooooo2?ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool02_ooool2o`000?oooooo=_ooool001[ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo0_l0003oooooocKooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo0_l0003^ooooo`006_ooool00omEEEGo
IVIVo`000007ooooo`03o`000?oooooooooo057ooooo0_l0003^ooooo`009?ooool2o`000<7ooooo
0_l0000^ooooo`;o0000Coooool002Cooooo00?o0000ooooooooool0`?ooool2o`0002?ooooo0_l0
0009ooooo`;o0000Coooool002Cooooo00?o0000ooooooooool0iOooool2o`0005[ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo1?ooool2o`00
03cooooo000Tooooo`03o`000?oooooooooo0?oooooo1?ooool2o`0003cooooo000Tooooo`;o0000
oooooom3ooooo`009?ooool00ol0003oooooooooo`1^ooooo`;o0000dOooool002Cooooo00?o0000
ooooooooool0K_ooool2o`0007[ooooo0_l0001Eooooo`009?ooool00ol0003oooooooooo`3Zoooo
o`;o0000EOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo
@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooo
od;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`00
0_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo00?o0000ooooooooool0@oooool2o`000?cooooo000Tooooo`;o0000A?ooool2o`000?cooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`1nooooo`;o0000I?ooool2o`0005_ooooo000Tooooo`03
o`000?oooooooooo07kooooo0_l0001Rooooo`Co0000Foooool002Cooooo0_l0003Sooooo`;o0000
GOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oOooool2o`0004;ooooo000Tooooo`;o0000o_ooool2o`0004;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0ooooool/ooooo`;o00005?ooool0
02Cooooo00?o0000ooooooooool0ooooool/ooooo`;o00005?ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0HOoo
ool2o`000=kooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo067ooooo0_l0003Nooooo`003?ooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo
<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2dooooo`;o0000
IOooool2o`0002Cooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2dooooo`;o0000E_ooool2o`0000gooooo0_l0000Tooooo`002_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooo`gooooo0_l0000c
ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0X?ooool2o`0009oo
oooo000Tooooo`03o`000?oooooooooo0:3ooooo0_l0001Xooooo`;o0000=Oooool002Cooooo00?o
0000ooooooooool0ooooool;ooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`12ooooo`;o0000oOooool002Cooooo00?o0000ooooooooool0@_oo
ool2o`000?gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003goooo
o`;o0000BOooool002Cooooo00?o0000ooooooooool0m_ooool2o`0004Wooooo000Tooooo`03o`00
0?oooooooooo07oooooo0_l00030ooooo`009?ooool00ol0003oooooooooo`1oooooo`;o0000`?oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
6oooool2o`0002Gooooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002Gooooo0004
ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
0_l0003ooooooc?ooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`3ooooooc;ooooo0_l0
000>ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo
@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`006Oooool5o`0000Kooooo0ol0003ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool3o`000?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;o
oooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooo
oom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .5995 Mdot
.03333 .37405 Mdot
.0381 .02526 Mdot
.04286 .04755 Mdot
.04762 .57939 Mdot
.05238 .27726 Mdot
.05714 .50429 Mdot
.0619 .014 Mdot
.06667 .05864 Mdot
.07143 .4743 Mdot
.07619 .01019 Mdot
.08095 .03488 Mdot
.08571 .07014 Mdot
.09048 .10806 Mdot
.09524 .15179 Mdot
.1 .19827 Mdot
.10476 .20969 Mdot
.10952 .04626 Mdot
.11429 .03455 Mdot
.11905 .05252 Mdot
.12381 .03054 Mdot
.12857 .13463 Mdot
.13333 .06444 Mdot
.1381 .01813 Mdot
.14286 .3063 Mdot
.14762 .2361 Mdot
.15238 .18865 Mdot
.15714 .03535 Mdot
.1619 .12665 Mdot
.16667 .05109 Mdot
.17143 .04054 Mdot
.17619 .22413 Mdot
.18095 .39624 Mdot
.18571 .01122 Mdot
.19048 .14355 Mdot
.19524 .01217 Mdot
.2 .02917 Mdot
.20476 .12936 Mdot
.20952 .07935 Mdot
.21429 .07078 Mdot
.21905 .26807 Mdot
.22381 .0266 Mdot
.22857 .01691 Mdot
.23333 .10901 Mdot
.2381 .50104 Mdot
.24286 .35492 Mdot
.24762 .14994 Mdot
.25238 .06722 Mdot
.25714 .13031 Mdot
.2619 .02492 Mdot
.26667 .04308 Mdot
.27143 .1229 Mdot
.27619 .01675 Mdot
.28095 .09887 Mdot
.28571 .11474 Mdot
.29048 .38422 Mdot
.29524 .04049 Mdot
.3 .06865 Mdot
.30476 .01007 Mdot
.30952 .01964 Mdot
.31429 .20325 Mdot
.31905 .06843 Mdot
.32381 .17455 Mdot
.32857 .07703 Mdot
.33333 .06761 Mdot
.3381 .02075 Mdot
.34286 .1102 Mdot
.34762 .37117 Mdot
.35238 .11138 Mdot
.35714 .24982 Mdot
.3619 .22674 Mdot
.36667 .03537 Mdot
.37619 .36053 Mdot
.38095 .14115 Mdot
.38571 .09065 Mdot
.39048 .03806 Mdot
.39524 .01778 Mdot
.4 .15718 Mdot
.40476 .23225 Mdot
.40952 .10207 Mdot
.41429 .00422 Mdot
.41905 .08345 Mdot
.42381 .28815 Mdot
.42857 .51985 Mdot
.43333 .25022 Mdot
.4381 .28489 Mdot
.44286 .01916 Mdot
.44762 .01986 Mdot
.45238 .24096 Mdot
.45714 .05892 Mdot
.4619 .01988 Mdot
.46667 .24739 Mdot
.47143 .11768 Mdot
.47619 .00763 Mdot
.48095 .17735 Mdot
.48571 .22454 Mdot
.49048 .04907 Mdot
.49524 .0581 Mdot
.5 .29087 Mdot
.50476 .00708 Mdot
.50952 .04281 Mdot
.51429 .19055 Mdot
.51905 .22809 Mdot
.52381 .01639 Mdot
.53333 .01552 Mdot
.5381 .26924 Mdot
.54286 .18799 Mdot
.54762 .37683 Mdot
.55238 .02189 Mdot
.55714 .05438 Mdot
.5619 .08175 Mdot
.56667 .12758 Mdot
.57143 .04981 Mdot
.57619 .28298 Mdot
.58095 .04624 Mdot
.58571 .06243 Mdot
.59048 .23044 Mdot
.59524 .29778 Mdot
.6 .11519 Mdot
.60476 .29781 Mdot
.60952 .20573 Mdot
.61429 .0083 Mdot
.61905 .17122 Mdot
.62381 .22778 Mdot
.62857 .10166 Mdot
.63333 .29667 Mdot
.6381 .1031 Mdot
.64286 .09491 Mdot
.64762 .29018 Mdot
.65238 .05543 Mdot
.65714 .04791 Mdot
.6619 .14361 Mdot
.66667 .0121 Mdot
.67143 .0354 Mdot
.67619 .16039 Mdot
.68095 .28434 Mdot
.68571 .01835 Mdot
.69048 .02005 Mdot
.69524 .19024 Mdot
.7 .03567 Mdot
.70476 .2719 Mdot
.70952 .02781 Mdot
.71429 .10037 Mdot
.71905 .6048 Mdot
.72381 .22265 Mdot
.72857 .35551 Mdot
.73333 .36198 Mdot
.7381 .1778 Mdot
.74286 .31787 Mdot
.74762 .00966 Mdot
.75238 .18727 Mdot
.75714 .24777 Mdot
.7619 .0707 Mdot
.76667 .02168 Mdot
.77143 .25425 Mdot
.77619 .07903 Mdot
.78095 .05767 Mdot
.78571 .06647 Mdot
.79048 .37042 Mdot
.79524 .48559 Mdot
.8 .04755 Mdot
.80476 .02457 Mdot
.80952 .03522 Mdot
.81429 .45839 Mdot
.81905 .19237 Mdot
.82381 .24067 Mdot
.82857 .03527 Mdot
.83333 .23778 Mdot
.8381 .22355 Mdot
.84286 .19588 Mdot
.84762 .14681 Mdot
.85238 .07932 Mdot
.85714 .16412 Mdot
.8619 .40766 Mdot
.86667 .03462 Mdot
.87143 .1042 Mdot
.87619 .15365 Mdot
.88095 .13959 Mdot
.88571 .05096 Mdot
.89048 .11123 Mdot
.89524 .07759 Mdot
.9 .04117 Mdot
.90476 .36054 Mdot
.90952 .46394 Mdot
.91905 .00385 Mdot
.92381 .18784 Mdot
.92857 .01209 Mdot
.93333 .02061 Mdot
.9381 .08619 Mdot
.94286 .10857 Mdot
.94762 .09922 Mdot
.95238 .05184 Mdot
.95714 .42938 Mdot
.9619 .28343 Mdot
.96667 .13164 Mdot
.97143 .22288 Mdot
.97619 .40974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00kooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool0
3?ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`;o0000
00?oooooo`000?ooool03_ooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooooooo
o`0=ooooo`;o0000B?ooool2o`0002;ooooo0_l0000Booooo`;o00001oooool2o`0002;ooooo0_l0
000Yooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool03Oooool2o`0002;ooooo0_l00000
0ooooooo0000o`00000Qooooo`;o0000=_ooool2o`0002_ooooo0_l0000?ooooo`;o00006?ooool2
o`0003Wooooo0_l0000Mooooo`009?ooool2o`0000[ooooo0_l0000Vooooo`;o000000?oooooo`00
0?l00000J?ooool2o`000003ooooool0003o000002[ooooo0_l0001Cooooo`;o00007Oooool002Co
oooo00?o0000ooooooooool02Oooool2o`0001Kooooo0_l0000Looooo`;o00003Oooool2o`0002Go
oooo0_l0000=ooooo`;o00006?ooool2o`000003ooooool0003o0000033ooooo0_l0001/ooooo`00
9?ooool00ol0003oooooooooo`0Qooooo`;o00007?ooool2o`0000gooooo0_l00009ooooo`;o0000
1oooool2o`00017ooooo0_l0000=ooooo`Co00000_ooool2o`0001cooooo0_l0000Yooooo`?o0000
5oooool2o`0003Cooooo0_l0000Looooo`009?ooool01?l0003oooooooooooooool2o`0004Kooooo
0_l0000>ooooo`;o00001oooool2o`0002;ooooo0_l00002ooooo`;o00007?ooool2o`0002[ooooo
0_l0000Gooooo`;o00002_ooool2o`0002Sooooo0_l0000Looooo`009?ooool01?l0003ooooooooo
ooooool2o`0003[ooooo0_l0000:ooooo`;o0000T?ooool2o`0001cooooo0_l00016ooooo`009?oo
ool2o`0001kooooo0_l0000Fooooo`;o00001_ooool2o`0009cooooo0_l0001Tooooo`009?ooool0
0ol0003oooooooooo`0?ooooo`;o00002Oooool2o`000003ooooool0003o000001Kooooo0_l0003G
ooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool03oooool2o`0000Wooooo0_l0000;oooo
o`;o0000@_ooool2o`00067ooooo0_l00008ooooo`;o00008Oooool2o`0000Cooooo0_l0000;oooo
o`;o0000<Oooool002Cooooo00?o0000ooooooooool09oooool2o`0000?ooooo0_l0000Vooooo`;o
00005Oooool2o`0000Kooooo0_l0001Iooooo`;o00002?ooool2o`00027ooooo0_l00004ooooo`;o
0000?_ooool002Cooooo00?o0000ooooooooool0;?ooool2o`0001gooooo0_l00007ooooo`;o0000
7Oooool2o`0002Gooooo0_l0001looooo`;o00009oooool002Cooooo0_l0000Iooooo`;o0000<Ooo
ool2o`0004gooooo0_l0000Eooooo`;o0000IOooool2o`0002Oooooo000Tooooo`03o`000?oooooo
oooo00;ooooo0_l0000Dooooo`;o0000N_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000G
ooooo`;o0000;?ooool2o`0004Oooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0000Goooo
o`;o00003_ooool2o`0006Oooooo0_l0000Hooooo`;o00006_ooool2o`0002cooooo0_l0000Joooo
o`;o00004oooool2o`0001Kooooo000Tooooo`03o`000?oooooooooo01_ooooo0_l0000>ooooo`;o
0000O?ooool2o`0001gooooo0_l0001:ooooo`;o00004oooool2o`0001Kooooo000Tooooo`03o`00
0?oooooooooo00[ooooo0_l0001mooooo`;o00002_ooool2o`0001;ooooo0_l0000Mooooo`;o0000
:?ooool2o`0004gooooo000Tooooo`;o00002oooool2o`0007gooooo0_l0000:ooooo`;o00006ooo
ool2o`0003kooooo0_l0001=ooooo`009?ooool00ol0003oooooooooo`0Pooooo`;o0000T?ooool2
o`0008gooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000Tooooo`;o00003_ooool2o`00
00Cooooo0_l00003ooooo`;o0000T?ooool2o`0004cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool04?ooool2o`0002Sooooo0_l0000:ooooo`;o00003_ooool2o`0000Cooooo0_l0
0003ooooo`;o0000ROooool2o`0000Gooooo0_l0001<ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0@ooooo`;o0000:?ooool2o`000;3ooooo0_l0001Cooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool3o`0005oooooo0_l0002fooooo`;o0000:?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0>?ooool2o`0002Gooooo0_l0002?ooooo`;o00005ooo
ool2o`0000cooooo0_l0000Xooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo03Sooooo0_l00012ooooo`;o0000;Oooool2o`0004?ooooo0_l0000Gooooo`;o0000=_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool2o`0002gooooo0_l0001h
ooooo`;o00006_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooobKooooo
0_l0000Jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0001cooooo`;o0000cOooool002Cooooo00?o0000oooooooo
ool0L_ooool2o`00057ooooo0_l0001jooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000
Loooool2o`00067ooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o00009ooo
ool2o`0004Gooooo0_l0000Jooooo`;o0000B_ooool2o`0001Oooooo000Tooooo`03o`000?oooooo
oooo07Wooooo0_l00015ooooo`;o000000?oooooo`000?l000005oooool2o`00037ooooo0_l0000`
ooooo`009?ooool00ol0003oooooooooo`0Booooo`;o0000[oooool2o`0004[ooooo0_l0000Eoooo
o`;o00006Oooool002Cooooo0_l0000Cooooo`;o0000;?ooool2o`0002;ooooo0_l000000ooooooo
0000o`00002/ooooo`;o00003oooool2o`0001Wooooo000Tooooo`03o`000?oooooooooo043ooooo
0_l0000?ooooo`;o00004Oooool2o`000003ooooool0003o00000:cooooo0_l0000Zooooo`009?oo
ool00ol0003oooooooooo`1Aooooo`;o0000>_ooool2o`0002Sooooo0_l00028ooooo`009?ooool0
0ol0003oooooooooo`2=ooooo`;o0000:?ooool2o`0008Sooooo000Tooooo`03o`000?oooooooooo
04gooooo0_l0003booooo`009?ooool2o`0002[ooooo0_l0000Rooooo`;o0000l_ooool002Cooooo
00?o0000ooooooooool0:Oooool2o`0000cooooo0_l0000?ooooo`;o0000H_ooool2o`0009?ooooo
000Tooooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`;o0000H_ooool2o`00083ooooo0_l0
000Aooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000ooooool?ooooo`;o00004Oooool0
02Cooooo00?o0000ooooooooool07_ooool2o`000?;ooooo0_l0000]ooooo`009?ooool2o`00077o
oooo0_l0002Pooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool0<_ooool2o`0003cooooo
0_l0001Iooooo`;o0000M?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<_ooool2o`0009Oo
oooo0_l0000jooooo`;o0000>?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo0_l0000`ooooo`;o
0000`?ooool2o`0003Sooooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo0_l0000`ooooo`;o0000b_ooool2o`0002ko
oooo0009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o
0000M_ooool2o`0009Wooooo0_l0000^ooooo`002Oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Kooooo0_l0001Hoooo
o`;o0000Koooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0d?ooool2o`0003Sooooo0_l0000eooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
o`_ooooo0_l0000eooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0002nooooo`;o0000P_ooool002Cooooo
00?o0000ooooooooool0G_ooool2o`0005gooooo0_l00022ooooo`009?ooool00ol0003ooooooooo
o`1Nooooo`;o0000<?ooool2o`0005;ooooo0_l0001Kooooo`009?ooool00ol0003oooooooooo`2@
ooooo`;o0000D_ooool2o`0005_ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0000Wooooo`;o0000OOooool2o`0004;ooooo0_l0000eooooo`;o00007oooool002Cooooo
00?o0000ooooooooool09_ooool2o`0007?ooooo0_l00008ooooo`;o0000;oooool2o`00017ooooo
0_l0000eooooo`;o00007oooool002Cooooo00?o0000ooooooooool0Voooool2o`0003Wooooo0_l0
000Vooooo`;o0000@Oooool002Cooooo00?o0000ooooooooool05Oooool2o`000>Oooooo0_l00006
ooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool05Oooool2o`000>oooooo0_l0000ioooo
o`009?ooool2o`0005_ooooo0_l0003Uooooo`009?ooool00ol0003oooooooooo`1Jooooo`;o0000
G_ooool2o`0008Gooooo000Tooooo`03o`000?oooooooooo01Kooooo0_l0002Rooooo`;o0000QOoo
ool002Cooooo00?o0000ooooooooool05_ooool2o`000?oooooo:_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
goooool2o`0004oooooo0_l0000?ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0^ooooo`;o0000H_ooool2o`0004_ooooo0_l0000Sooooo`;o0000:_ooool2o`00
00oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0^ooooo`;o0000>_ooool2
o`0002Kooooo0_l00009ooooo`;o00008?ooool2o`0004?ooooo0_l0000kooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Zooooo`;o0000<Oooool2o`0001Gooooo0_l00009oooo
o`;o0000P?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001hooooo`;o0000>_ooool2o`0008_o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09?ooool2o`0005;o
oooo0_l00029ooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
3?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9?ooool2o`00067ooooo0_l0001gooooo`;o000000?oooooo`000?l00000??ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`27ooooo`;o0000Moooool2o`0003oooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2<
ooooo`;o0000/oooool002Cooooo0_l0001Yooooo`;o00005oooool2o`0000Wooooo0_l0001Loooo
o`;o0000EOooool002Cooooo00?o0000ooooooooool0J?ooool2o`0001Oooooo0_l0001Wooooo`;o
0000EOooool002Cooooo00?o0000ooooooooool0koooool2o`00053ooooo000Tooooo`03o`000?oo
oooooooo0>oooooo0_l0001@ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`0looooo`;o0000IOooool2o`0009co
oooo000Tooooo`03o`000?oooooooooo03cooooo0_l0001Uooooo`;o0000=?ooool2o`0006Kooooo
000Tooooo`03o`000?oooooooooo0=Wooooo0_l0001Vooooo`009?ooool00ol0003oooooooooo`05
ooooo`;o0000oooooolkooooo`009?ooool2o`0000Kooooo0_l0003ooooooc_ooooo000Tooooo`03
o`000?oooooooooo0:oooooo0_l0000Pooooo`;o0000FOooool2o`0001?ooooo000Tooooo`03o`00
0?oooooooooo08?ooooo0_l0000Zooooo`;o00008?ooool2o`0005Wooooo0_l0000Cooooo`009?oo
ool00ol0003oooooooooo`1nooooo`;o00000oooool2o`0004;ooooo0_l0001hooooo`009?ooool0
0ol0003oooooooooo`1nooooo`;o00005oooool2o`0002kooooo0_l0001hooooo`009?ooool2o`00
09Sooooo0_l0000Yooooo`;o0000OOooool002Cooooo00?o0000ooooooooool0]_ooool2o`000003
ooooool0003o000000Oooooo0_l0001mooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0]_ooool2o`000003ooooool0003o000008Kooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02?ooooo0_l0003ooooooagooooo000Looooo`03o`000?oooooooooo
00Gooooo0ol0000Sooooo`;o0000oooooolMooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3Uooooo`;o0000F_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3Uooooo`;o0000F_ooool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`13
ooooo`;o0000W?ooool2o`0005kooooo000Tooooo`;o0000A?ooool2o`0009cooooo0_l0001Noooo
o`009?ooool00ol0003oooooooooo`1^ooooo`;o0000Z_ooool2o`0002Gooooo000Tooooo`03o`00
0?oooooooooo06kooooo0_l0001booooo`;o0000=_ooool2o`0002Gooooo000Tooooo`03o`000?oo
oooooooo0>;ooooo0_l0001Mooooo`009?ooool00ol0003oooooooooo`3eooooo`;o0000B_ooool0
02Cooooo1?l0001Tooooo`;o0000S_ooool2o`0004[ooooo000Tooooo`04o`000?oooooo0000o`00
06Cooooo0_l0000oooooo`;o0000VOooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0:Kooooo0_l0002Iooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
od;ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05?ooooo0_l0003/ooooo`001?ooool00ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0005?ooooo
0_l0003/ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0_l0
003ooooooa7ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`0_ooooo`;o0000oooooolAooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0ooooool=ooooo`;o0000<oooool002Co
oooo00?o0000ooooooooool0ooooool=ooooo`;o00008oooool2o`0000kooooo000Tooooo`03o`00
0?oooooooooo0?oooooo<_ooool2o`0000kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3oooooobcooooo
0_l0000Dooooo`009?ooool00ol0003oooooooooo`3oooooobcooooo0_l0000Dooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oOooool2o`0004;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3mooooo`;o0000@_ooool000cooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`04ooooo`?o0000oooooolLooooo`;o00009?ooool000cooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolLooooo`;o00009?ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l0003oooooocCooooo000:ooooo`03
oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo00cooooo0_l0003oooooocCo
oooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?Kooooo0_l00019ooooo`009?ooool00ol0003oooooooooo`3foooo
o`;o0000BOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo
@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`12
ooooo`;o0000oOooool002Cooooo00?o0000ooooooooool01oooool2o`0003Wooooo0_l0003moooo
o`009?ooool00ol0003oooooooooo`07ooooo`;o0000ooooooliooooo`009?ooool2o`000?oooooo
@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`009?ooool00ol0003o
ooooooooo`1oooooo`;o0000`?ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004oooo
o`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00
000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`04ooooo`;o0000oooooollooooo`00
9?ooool00ol0003oooooooooo`04ooooo`;o0000oooooollooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool3o`000?oooooo@_ooool002Cooooo0ol0003Nooooo`;o0000HOooool0
02Cooooo00?o0000ooooooooool0g_ooool2o`00067ooooo000Iooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?ooool0
0omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wo
oooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .37046 Mdot
.03333 .37405 Mdot
.0381 .08009 Mdot
.04286 .04755 Mdot
.04762 .42338 Mdot
.05238 .17863 Mdot
.05714 .52602 Mdot
.0619 .014 Mdot
.06667 .05864 Mdot
.07143 .4743 Mdot
.07619 .19142 Mdot
.08095 .03488 Mdot
.08571 .07014 Mdot
.09048 .25712 Mdot
.09524 .5627 Mdot
.1 .14475 Mdot
.10476 .25453 Mdot
.10952 .03509 Mdot
.11429 .00193 Mdot
.11905 .05252 Mdot
.12381 .00914 Mdot
.12857 .05086 Mdot
.13333 .06444 Mdot
.1381 .17059 Mdot
.14286 .27607 Mdot
.14762 .29727 Mdot
.15238 .18865 Mdot
.15714 .03535 Mdot
.1619 .12665 Mdot
.16667 .11831 Mdot
.17143 .0283 Mdot
.17619 .20374 Mdot
.18095 .0794 Mdot
.18571 .07233 Mdot
.19048 .15215 Mdot
.19524 .01217 Mdot
.2 .02917 Mdot
.20476 .25111 Mdot
.20952 .21258 Mdot
.21429 .04015 Mdot
.21905 .25486 Mdot
.22381 .0266 Mdot
.22857 .08207 Mdot
.23333 .10537 Mdot
.2381 .51388 Mdot
.24286 .33367 Mdot
.24762 .14994 Mdot
.25238 .05589 Mdot
.25714 .01111 Mdot
.2619 .02492 Mdot
.26667 .1397 Mdot
.27143 .2811 Mdot
.27619 .09262 Mdot
.28095 .09887 Mdot
.28571 .11474 Mdot
.29048 .33592 Mdot
.29524 .17497 Mdot
.3 .06865 Mdot
.30476 .14825 Mdot
.30952 .13566 Mdot
.31429 .01963 Mdot
.31905 .06843 Mdot
.32381 .02762 Mdot
.32857 .07703 Mdot
.33333 .02005 Mdot
.3381 .14385 Mdot
.34286 .19175 Mdot
.34762 .18135 Mdot
.35238 .19856 Mdot
.35714 .15512 Mdot
.3619 .11506 Mdot
.36667 .23582 Mdot
.37143 .43319 Mdot
.38095 .29142 Mdot
.38571 .05969 Mdot
.39048 .03806 Mdot
.39524 .01778 Mdot
.4 .14157 Mdot
.40476 .02412 Mdot
.40952 .10207 Mdot
.41429 .15297 Mdot
.41905 .08345 Mdot
.42381 .37283 Mdot
.43333 .182 Mdot
.4381 .33361 Mdot
.44286 .01916 Mdot
.44762 .01986 Mdot
.45238 .38871 Mdot
.45714 .02088 Mdot
.4619 .01988 Mdot
.46667 .12172 Mdot
.47143 .00552 Mdot
.47619 .14931 Mdot
.48095 .09183 Mdot
.48571 .0924 Mdot
.49048 .04332 Mdot
.49524 .0581 Mdot
.5 .29087 Mdot
.50476 .00708 Mdot
.50952 .06255 Mdot
.51429 .37255 Mdot
.51905 .3011 Mdot
.52381 .01639 Mdot
.52857 .43823 Mdot
.53333 .01552 Mdot
.5381 .26924 Mdot
.54286 .15287 Mdot
.54762 .19229 Mdot
.55238 .02189 Mdot
.55714 .19503 Mdot
.5619 .08175 Mdot
.56667 .16652 Mdot
.57143 .04981 Mdot
.57619 .25998 Mdot
.58095 .04624 Mdot
.58571 .11804 Mdot
.59048 .14217 Mdot
.59524 .46401 Mdot
.6 .0576 Mdot
.60476 .19439 Mdot
.60952 .0199 Mdot
.61429 .0083 Mdot
.61905 .17122 Mdot
.62381 .20409 Mdot
.62857 .14189 Mdot
.63333 .01903 Mdot
.6381 .05261 Mdot
.64286 .04446 Mdot
.64762 .39916 Mdot
.65238 .05543 Mdot
.65714 .04791 Mdot
.6619 .27515 Mdot
.66667 .08507 Mdot
.67143 .0354 Mdot
.67619 .20463 Mdot
.68095 .15443 Mdot
.68571 .1164 Mdot
.69048 .02005 Mdot
.69524 .32729 Mdot
.7 .03567 Mdot
.70476 .00195 Mdot
.70952 .02781 Mdot
.71429 .10037 Mdot
.71905 .41811 Mdot
.72381 .07574 Mdot
.72857 .19245 Mdot
.73333 .11488 Mdot
.7381 .49632 Mdot
.74286 .06545 Mdot
.74762 .00966 Mdot
.75238 .18727 Mdot
.75714 .24777 Mdot
.7619 .0707 Mdot
.76667 .05864 Mdot
.77143 .02751 Mdot
.77619 .2254 Mdot
.78095 .05767 Mdot
.78571 .06647 Mdot
.79048 .30367 Mdot
.79524 .48559 Mdot
.8 .0931 Mdot
.80476 .02457 Mdot
.80952 .08369 Mdot
.81429 .26952 Mdot
.81905 .13012 Mdot
.82381 .15851 Mdot
.82857 .19803 Mdot
.83333 .13419 Mdot
.8381 .35268 Mdot
.84286 .05803 Mdot
.84762 .18781 Mdot
.85238 .02182 Mdot
.85714 .16412 Mdot
.8619 .24733 Mdot
.86667 .17091 Mdot
.87143 .16215 Mdot
.87619 .05515 Mdot
.88095 .10158 Mdot
.88571 .05096 Mdot
.89048 .22308 Mdot
.89524 .07759 Mdot
.9 .0291 Mdot
.90476 .42832 Mdot
.90952 .52977 Mdot
.91905 .12807 Mdot
.92381 .18784 Mdot
.92857 .01209 Mdot
.93333 .02061 Mdot
.9381 .05416 Mdot
.94286 .03475 Mdot
.94762 .09922 Mdot
.95238 .00994 Mdot
.95714 .39767 Mdot
.9619 .37974 Mdot
.96667 .13164 Mdot
.97143 .01438 Mdot
.97619 .38757 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo0ol0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`?o0000
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo01gooooo
0_l0001^ooooo`;o00002Oooool2o`0002;ooooo0_l0000Yooooo`;o0000@?ooool2o`0001Kooooo
000Tooooo`03o`000?oooooooooo01gooooo0_l0000Eooooo`;o00004_ooool2o`0007;ooooo0_l0
000Yooooo`;o0000>Oooool2o`0000Gooooo0_l0000Fooooo`009?ooool2o`0000[ooooo0_l0000Y
ooooo`;o00004_ooool2o`0005Cooooo0_l000000ooooooo0000o`00001oooooo`;o00003?ooool2
o`0000oooooo000Tooooo`03o`000?oooooooooo00Wooooo0_l0001Zooooo`;o00003Oooool2o`00
01Sooooo0_l000000ooooooo0000o`00000Oooooo`;o0000K?ooool2o`0000oooooo000Tooooo`03
o`000?oooooooooo05[ooooo0_l00005ooooo`;o00004_ooool2o`0000gooooo1?l000001?oooooo
0000o`000?l0000Looooo`;o00004?ooool2o`0000Kooooo0_l0000@ooooo`;o0000<oooool2o`00
01Sooooo0_l0000Looooo`009?ooool00ol0003oooooooooo`19ooooo`;o00003oooool2o`0000Go
oooo0_l0000Eooooo`;o00003?ooool2o`000004ooooool0003o0000o`0001cooooo0_l0000@oooo
o`;o00006?ooool2o`0002?ooooo0_l0000>ooooo`;o00006?ooool2o`0001cooooo000Tooooo`03
o`000?oooooooooo02cooooo0_l0000?ooooo`;o00002_ooool2o`0001?ooooo0_l0000Hooooo`;o
0000HOooool2o`0001;ooooo0_l00008ooooo`;o0000A_ooool002Cooooo0_l0000]ooooo`;o0000
1oooool2o`0000Kooooo0_l0000Oooooo`;o0000Noooool2o`0001;ooooo0_l0000Wooooo`;o0000
9oooool002Cooooo00?o0000ooooooooool03oooool2o`0002Cooooo0_l0003Qooooo`;o00003?oo
ool2o`0001Wooooo000Tooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`;o00003Oooool2
o`000:Gooooo0_l00008ooooo`;o0000C?ooool2o`0001Wooooo000Tooooo`03o`000?oooooooooo
01Sooooo0_l0000=ooooo`;o00004Oooool2o`0003Oooooo0_l0001Iooooo`;o00002?ooool2o`00
06Oooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0000gooooo`;o00007oooool2o`000:_o
oooo000Tooooo`;o0000UOooool2o`0001_ooooo0_l0000Booooo`;o0000N_ooool002Cooooo00?o
0000ooooooooool00_ooool2o`000:[ooooo0_l000000ooooooo0000o`00000Booooo`;o00000ooo
ool2o`0007Gooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0000Gooooo`;o000000?ooooo
o`000?l00000S_ooool2o`0001?ooooo0_l00005ooooo`;o0000B?ooool2o`0002_ooooo000Toooo
o`03o`000?oooooooooo01_ooooo0_l000000ooooooo0000o`00000Vooooo`;o0000Noooool2o`00
00?ooooo0_l00017ooooo`;o000000?oooooo`000?l000003oooool2o`0001[ooooo000Tooooo`03
o`000?oooooooooo00[ooooo0_l0000jooooo`;o0000COooool2o`00023ooooo0_l0000?ooooo`;o
00008oooool2o`0000?ooooo0_l0000Booooo`;o00002Oooool2o`0001;ooooo0_l0000Jooooo`00
9?ooool2o`0000_ooooo0_l0001Vooooo`;o00008Oooool2o`0000?ooooo0_l0000Kooooo`;o0000
=?ooool2o`0000?ooooo0_l0000Booooo`;o0000>Oooool002Cooooo00?o0000ooooooooool08?oo
ool2o`00053ooooo0_l0000Vooooo`;o0000BOooool2o`0005[ooooo000Tooooo`03o`000?oooooo
oooo023ooooo0_l0000dooooo`;o00001?ooool2o`0008Oooooo0_l0000<ooooo`;o0000C?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0@ooooo`;o0000A?ooool2o`0000Cooooo
0_l0002>ooooo`;o00001Oooool2o`0004cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo013ooooo0_l0000Oooooo`;o0000^Oooool2o`0005?ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000<Oooool2o`0002cooooo0_l0001nooooo`;o0000=_ooool2o`0002So
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`;o0000;?ooool2o`0002ko
oooo0_l0001nooooo`;o0000=_ooool2o`0002Sooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00Co0000oooooooooooooooo0_l0000/ooooo`;o00003_ooool2o`0003_ooooo0_l0000]oooo
o`;o0000C_ooool2o`0004Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oo
oooo0_l0000kooooo`;o0000;Oooool2o`00023ooooo0_l0000/ooooo`;o0000A?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3=ooooo`;o0000L_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000
Coooool2o`00043ooooo1?l0001Tooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0C_oo
ool2o`00043ooooo1?l0001Tooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0D?ooool2
o`000=Kooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o00009oooool2o`00
067ooooo0_l0000dooooo`;o00005?ooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo043o
oooo0_l0000gooooo`;o0000HOooool2o`0003Cooooo0_l0000]ooooo`009?ooool00ol0003ooooo
ooooo`10ooooo`;o0000ooooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo057ooooo0_l0000Gooooo`;o0000M_ooool2o`0005gooooo000Tooooo`03o`000?oooooooooo
057ooooo0_l0000Gooooo`;o0000A_ooool2o`0001oooooo0_l0000=ooooo`;o0000GOooool002Co
oooo00?o0000ooooooooool0:oooool2o`0008Gooooo0_l0000Oooooo`;o0000K?ooool002Cooooo
00?o0000ooooooooool0:oooool2o`0005oooooo0_l0002cooooo`009?ooool2o`0002[ooooo0_l0
001Qooooo`;o0000/oooool002Cooooo00?o0000ooooooooool0:Oooool2o`000=?ooooo0_l0000O
ooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0o_ooool2o`0001oooooo0_l0000=oooo
o`;o00004Oooool002Cooooo00?o0000ooooooooool0FOooool2o`000:Sooooo0_l0000Yooooo`;o
00004Oooool002Cooooo00?o0000ooooooooool0Boooool2o`0000cooooo0_l0002Xooooo`;o0000
??ooool002Cooooo0_l0001<ooooo`;o0000:Oooool2o`0003cooooo0_l0000:ooooo`;o0000Oooo
ool002Cooooo00?o0000ooooooooool05Oooool2o`0004_ooooo0_l0000Booooo`;o0000??ooool2
o`0000[ooooo0_l0001oooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000@?oo
ool2o`0000Wooooo0_l0003Mooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0AOooool2o`00013ooooo0_l0
000fooooo`;o0000/?ooool000Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0<_ooool2o`00017ooooo0_l0000Qooooo`;o00004Ooo
ool2o`0001;ooooo0_l0000Dooooo`;o0000:_ooool2o`0006kooooo0009ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000<_ooool2o`0003Cooooo0_l0
000Aooooo`;o0000:?ooool2o`0002[ooooo0_l0001^ooooo`002Oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
0Oooool2o`0003oooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0000Sooooo0_l00003ooooo`;o0000
<?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0[?ooool2o`0005cooooo0_l00003ooooo`;o0000<?ooool000Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2/ooooo`;o0000
Toooool002Cooooo0_l0000Rooooo`;o0000V_ooool2o`0004oooooo0_l0000aooooo`009?ooool0
0ol0003oooooooooo`0Qooooo`;o0000<Oooool2o`0006Oooooo0_l0001?ooooo`;o0000<Oooool0
02Cooooo00?o0000ooooooooool01Oooool2o`0004gooooo0_l0003[ooooo`009?ooool00ol0003o
ooooooooo`05ooooo`;o0000G_ooool2o`0001[ooooo0_l0002nooooo`009?ooool00ol0003ooooo
ooooo`1Uooooo`;o00006_ooool2o`000;kooooo000Tooooo`;o00009oooool2o`000<7ooooo0_l0
000Looooo`;o00005oooool2o`0001oooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0000G
ooooo`;o0000??ooool2o`0008?ooooo0_l0000Looooo`;o00005oooool2o`0001oooooo000Toooo
o`03o`000?oooooooooo00gooooo0_l0001Eooooo`;o0000@?ooool2o`000003ooooool0003o0000
00kooooo0_l0000Vooooo`;o0000G_ooool002Cooooo00?o0000ooooooooool0Y_ooool2o`000003
ooooool0003o000000kooooo0_l0000Vooooo`;o00007_ooool2o`0003kooooo000Tooooo`03o`00
0?oooooooooo06Oooooo0_l0002Hooooo`;o0000?_ooool002Cooooo0_l0000_ooooo`;o0000=ooo
ool2o`0005Kooooo0_l00020ooooo`009?ooool00ol0003oooooooooo`0^ooooo`;o0000Soooool2
o`0000oooooo0_l0001_ooooo`009?ooool00ol0003oooooooooo`3@ooooo`;o0000Koooool002Co
oooo00?o0000ooooooooool0>?ooool2o`000?oooooo2?ooool002Cooooo00?o0000ooooooooool0
>?ooool2o`000?oooooo2?ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
l?ooool2o`0002?ooooo0_l0000Zooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0l?ooool2o`0002?ooooo0_l0000Zooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06_ooooo0_l0003Dooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1[ooooo`;o0000e?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3ooooood;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`3oooooo`gooooo0_l0000cooooo`00
9?ooool2o`000>_ooooo0_l0000Pooooo`;o0000<oooool002Cooooo00?o0000ooooooooool0=ooo
ool2o`000;7ooooo0_l0001Eooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o00007oooool2
o`0000?ooooo0_l0003oooooo`Cooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l00002oooo
o`;o00009?ooool2o`00077ooooo0_l0002@ooooo`009?ooool00ol0003oooooooooo`0Booooo`;o
0000Voooool2o`00093ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`2Sooooo`;o0000W?ooool002Cooooo00?o0000ooooooooool0Xoooool2o`0005Sooooo0_l00012
ooooo`009?ooool00ol0003oooooooooo`3;ooooo`;o0000<?ooool2o`0004;ooooo000Tooooo`03
o`000?oooooooooo02?ooooo0_l0002Vooooo`;o0000M?ooool002Cooooo0_l0000Tooooo`;o0000
:?ooool2o`000?;ooooo000Tooooo`03o`000?oooooooooo04gooooo0_l0003booooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0L?ooool2o`0002Gooooo0_l0002Xooooo`009?ooool2o`00077ooooo
0_l0000Uooooo`;o0000Z?ooool002Cooooo00?o0000ooooooooool09?ooool2o`000?oooooo7?oo
ool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo0_l0001g
ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Moooo
o`;o0000E_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0mOooool2o`0004[ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0003ooooood;ooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oeEEEOmVIVKo000000Oo
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000=Oooooo0_l0001Yooooo`009?oo
ool00ol0003oooooooooo`3Fooooo`;o0000JOooool002Cooooo00?o0000ooooooooool0@oooool2
o`0003kooooo0_l0002looooo`009?ooool00ol0003oooooooooo`13ooooo`;o00003_ooool2o`00
02kooooo0_l0002looooo`009?ooool00ol0003oooooooooo`1Cooooo`;o0000k?ooool002Cooooo
0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo1Oooool2o`0003_ooooo000Tooooo`;o0000ooooool6ooooo`;o0000
>oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0ol0003ooooood;o
oooo000Tooooo`Co0000OOooool2o`0001_ooooo0_l0002Tooooo`009?ooool01?l0003oooooo`00
0?l0001mooooo`;o00006oooool2o`000:Cooooo0002ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`3oooooobgooooo0_l0000Cooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooobgooooo0_l0000Cooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`?o0000Qoooool2o`000:Sooooo0_l0000>ooooo`001?ooool00ol0003oooooooooo`0=oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo08Oooooo0_l0002Xooooo`;o00003_ooool000Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2oooo
o`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo;?ooool2o`0001Cooooo0002ooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`37ooooo`;o0000H_ooool2o`0001Cooooo000Tooooo`;o0000b?ooool2o`0007So
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003Oooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0
1?ooool2o`000=Sooooo0_l0001Qooooo`009?ooool00ol0003oooooooooo`04ooooo`;o0000oooo
oollooooo`009?ooool00ol0003oooooooooo`3ooooooa_ooooo0_l0000Uooooo`009?ooool00ol0
003oooooooooo`3ooooooa_ooooo0_l0000Uooooo`009?ooool2o`0006kooooo0_l0003Booooo`00
9?ooool00ol0003oooooooooo`1]ooooo`;o0000<Oooool2o`0009oooooo000Tooooo`03o`000?oo
oooooooo0:3ooooo0_l0002Oooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`04ooooo`?o0000]_ooool2o`0008Wooooo000<ooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Kooooo0_l00029oooo
o`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03?ooool2o`000?oooooo=?ooool000[ooooo00?oEEEEofIVI_l000003Ooo
ool4o`0000Kooooo00?o0000ooooooooool03?ooool2o`000?oooooo=?ooool002Cooooo0_l0003o
oooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0m_ooool2o`0004Wooooo000Tooooo`03o`000?oooooooooo0?Kooooo0_l00019ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000iOooool2o`0005_ooooo000Toooo
o`03o`000?oooooooooo0>Cooooo0_l0001Kooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0@_ooool2o`00
0?gooooo000Tooooo`03o`000?oooooooooo04;ooooo0_l0003mooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l00008
ooooo`;o0000ooooooliooooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000oooooolCoooo
o`;o00009?ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
oacooooo0_l0000Tooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`00
1?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool04oooool2o`000?oooooo;Oooool002Cooooo00?o0000ooooooooool04oooool2
o`000?oooooo;Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o
0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo@_ooool001co
oooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo
000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .58714 Mdot
.03333 .40898 Mdot
.0381 .08009 Mdot
.04286 .11832 Mdot
.04762 .18663 Mdot
.05238 .15827 Mdot
.0619 .0359 Mdot
.06667 .02613 Mdot
.07143 .54572 Mdot
.07619 .32119 Mdot
.08095 .07977 Mdot
.08571 .07014 Mdot
.09048 .20518 Mdot
.09524 .32719 Mdot
.1 .06536 Mdot
.10476 .26189 Mdot
.10952 .03509 Mdot
.11429 .00193 Mdot
.11905 .08266 Mdot
.12381 .00914 Mdot
.12857 .05086 Mdot
.13333 .09409 Mdot
.1381 .2058 Mdot
.14286 .06293 Mdot
.14762 .46771 Mdot
.15238 .11049 Mdot
.15714 .06919 Mdot
.1619 .01483 Mdot
.16667 .06315 Mdot
.17143 .1529 Mdot
.17619 .02224 Mdot
.18095 .31546 Mdot
.18571 .08326 Mdot
.19048 .06748 Mdot
.19524 .01217 Mdot
.2 .02917 Mdot
.20476 .10013 Mdot
.20952 .21258 Mdot
.21429 .04015 Mdot
.21905 .25486 Mdot
.22381 .0266 Mdot
.22857 .08207 Mdot
.23333 .10537 Mdot
.2381 .24793 Mdot
.24286 .15448 Mdot
.24762 .06704 Mdot
.25238 .0242 Mdot
.25714 .01111 Mdot
.2619 .06996 Mdot
.26667 .21624 Mdot
.27143 .26496 Mdot
.27619 .09262 Mdot
.28095 .03801 Mdot
.28571 .11474 Mdot
.29048 .5513 Mdot
.29524 .16749 Mdot
.3 .07931 Mdot
.30476 .23414 Mdot
.30952 .14104 Mdot
.31429 .14324 Mdot
.31905 .03418 Mdot
.32381 .02762 Mdot
.32857 .04821 Mdot
.33333 .02005 Mdot
.3381 .15492 Mdot
.34286 .11814 Mdot
.34762 .28408 Mdot
.35238 .10946 Mdot
.35714 .00199 Mdot
.3619 .13072 Mdot
.36667 .26823 Mdot
.37143 .51023 Mdot
.37619 .39127 Mdot
.38095 .13858 Mdot
.38571 .04936 Mdot
.39048 .01968 Mdot
.39524 .10774 Mdot
.4 .18082 Mdot
.40476 .02412 Mdot
.40952 .11472 Mdot
.41429 .08205 Mdot
.41905 .27965 Mdot
.42381 .39419 Mdot
.42857 .61425 Mdot
.43333 .14672 Mdot
.4381 .10009 Mdot
.44286 .01916 Mdot
.44762 .01986 Mdot
.45238 .54376 Mdot
.45714 .09529 Mdot
.4619 .01988 Mdot
.46667 .20055 Mdot
.47143 .00552 Mdot
.47619 .17525 Mdot
.48095 .18734 Mdot
.48571 .05236 Mdot
.49048 .04332 Mdot
.49524 .0581 Mdot
.5 .25325 Mdot
.50476 .00708 Mdot
.50952 .24767 Mdot
.51429 .31334 Mdot
.51905 .46626 Mdot
.52381 .01639 Mdot
.52857 .19573 Mdot
.53333 .01552 Mdot
.5381 .48298 Mdot
.54286 .04924 Mdot
.54762 .15457 Mdot
.55238 .02189 Mdot
.55714 .2729 Mdot
.5619 .08175 Mdot
.56667 .11723 Mdot
.57143 .07423 Mdot
.57619 .42147 Mdot
.58095 .15208 Mdot
.58571 .11804 Mdot
.59048 .2295 Mdot
.59524 .411 Mdot
.6 .0576 Mdot
.60476 .14145 Mdot
.60952 .0199 Mdot
.61429 .0333 Mdot
.61905 .06074 Mdot
.62381 .07846 Mdot
.62857 .12899 Mdot
.63333 .03362 Mdot
.6381 .24566 Mdot
.64286 .04352 Mdot
.64762 .1652 Mdot
.65238 .10575 Mdot
.65714 .03042 Mdot
.6619 .27831 Mdot
.66667 .12191 Mdot
.67143 .07726 Mdot
.67619 .20463 Mdot
.68095 .05496 Mdot
.68571 .1164 Mdot
.69048 .01269 Mdot
.69524 .39225 Mdot
.7 .03567 Mdot
.70476 .09479 Mdot
.70952 .02781 Mdot
.71429 .10597 Mdot
.71905 .51768 Mdot
.72381 .11219 Mdot
.72857 .17669 Mdot
.73333 .11488 Mdot
.7381 .13435 Mdot
.74286 .06545 Mdot
.74762 .27868 Mdot
.75238 .16733 Mdot
.75714 .07941 Mdot
.7619 .0707 Mdot
.76667 .13172 Mdot
.77143 .02751 Mdot
.77619 .25967 Mdot
.78095 .05767 Mdot
.78571 .00546 Mdot
.79048 .30367 Mdot
.79524 .48559 Mdot
.8 .0931 Mdot
.80476 .02457 Mdot
.80952 .01124 Mdot
.81429 .26952 Mdot
.81905 .1689 Mdot
.82381 .35439 Mdot
.82857 .09145 Mdot
.83333 .13419 Mdot
.8381 .52652 Mdot
.84286 .26004 Mdot
.84762 .1951 Mdot
.85238 .02182 Mdot
.85714 .21401 Mdot
.8619 .18626 Mdot
.86667 .02172 Mdot
.87143 .20669 Mdot
.87619 .05515 Mdot
.88095 .08083 Mdot
.88571 .05096 Mdot
.89048 .23729 Mdot
.89524 .30508 Mdot
.9 .0291 Mdot
.90476 .36145 Mdot
.91905 .12807 Mdot
.92381 .02671 Mdot
.92857 .01209 Mdot
.93333 .02061 Mdot
.9381 .05416 Mdot
.94286 .22543 Mdot
.94762 .11976 Mdot
.95238 .00994 Mdot
.95714 .05631 Mdot
.9619 .58278 Mdot
.96667 .14642 Mdot
.97143 .0347 Mdot
.97619 .34254 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`;o00003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0ol0
000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo0_l0000?ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool2o`0000Sooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool2o`0000oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000
ooooooooool07Oooool2o`0006kooooo0_l00009ooooo`;o0000FOooool2o`0003Cooooo0_l0000F
ooooo`009?ooool00ol0003oooooooooo`0Mooooo`;o00005Oooool2o`0001;ooooo0_l0002:oooo
o`;o00009Oooool2o`0002Gooooo0_l00005ooooo`;o00005_ooool002Cooooo0_l0000Zooooo`;o
00002Oooool2o`0001;ooooo0_l0001Dooooo`;o000000?oooooo`000?l00000<Oooool2o`0002Go
oooo0_l0000Uooooo`;o00007Oooool002Cooooo00?o0000ooooooooool0:Oooool2o`0005Wooooo
0_l0000Hooooo`;o000000?oooooo`000?l00000W_ooool002Cooooo00?o0000ooooooooool0;_oo
ool2o`00037ooooo0_l0000@ooooo`;o00003oooool4o`0000;ooooo0_l0000Looooo`;o00004?oo
ool2o`0004gooooo0_l00003ooooo`;o00004oooool2o`0001cooooo000Tooooo`03o`000?oooooo
oooo02kooooo0_l0000Fooooo`;o00006Oooool2o`00013ooooo0_l00003ooooo`;o00003?ooool2
o`0000;ooooo0_l0000Looooo`;o00004?ooool2o`0003gooooo0_l0000>ooooo`;o00000oooool2
o`0001?ooooo0_l0000Looooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000<Oooool2o`00
00Oooooo0_l0000Fooooo`;o00006?ooool2o`00067ooooo0_l0000Booooo`;o00002?ooool2o`00
02Gooooo0_l0000Oooooo`009?ooool2o`0000_ooooo0_l0000Yooooo`;o00001_ooool2o`0001oo
oooo0_l0001Zooooo`;o00003oooool2o`0001;ooooo0_l0000Wooooo`;o00001_ooool2o`0001oo
oooo000Tooooo`03o`000?oooooooooo03Gooooo0_l0000Uooooo`;o0000G_ooool2o`0000Cooooo
0_l00006ooooo`;o0000C?ooool2o`0001Kooooo0_l0000?ooooo`009?ooool00ol0003ooooooooo
o`09ooooo`;o00003Oooool2o`0004;ooooo0_l0001Nooooo`;o00001?ooool2o`0001Cooooo0_l0
001Fooooo`;o00003oooool002Cooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0000P
ooooo`;o00005?ooool2o`0008Kooooo0_l0001Wooooo`009?ooool00ol0003oooooooooo`0joooo
o`;o00005?ooool2o`0004;ooooo0_l0000_ooooo`;o0000N_ooool002Cooooo0_l0002Eooooo`;o
0000;oooool2o`0007[ooooo000Tooooo`03o`000?oooooooooo05oooooo0_l0000Aooooo`;o0000
<Oooool2o`0009[ooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0000oooooo`;o00004Ooo
ool2o`0001kooooo0_l0000Aooooo`;o0000KOooool2o`0002_ooooo000Tooooo`03o`000?oooooo
oooo01kooooo0_l0001booooo`;o0000?Oooool2o`0003kooooo0_l000000ooooooo0000o`00000?
ooooo`;o00001?ooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo09Gooooo0_l0000Poooo
o`;o00006?ooool2o`0001oooooo0_l0000Mooooo`;o00004_ooool2o`0000Cooooo0_l0000Doooo
o`009?ooool2o`0009Kooooo0_l0000Pooooo`;o00001?ooool2o`0003?ooooo0_l0001=ooooo`00
9?ooool00ol0003oooooooooo`0Eooooo`;o00003?ooool2o`0000Kooooo0_l0002@ooooo`;o0000
9_ooool2o`0005[ooooo000Tooooo`03o`000?oooooooooo01Gooooo0_l0000<ooooo`;o00001_oo
ool2o`0000Gooooo0_l0000Aooooo`;o0000W_ooool2o`0005[ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool04?ooool2o`0001Gooooo0_l00009ooooo`;o00004Oooool2o`0000;o
oooo0_l0002Qooooo`;o0000Doooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool04?ooool2o`0001Gooooo0_l0000Pooooo`;o0000Hoooool2o`0003cooooo0_l0001C
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool3o`000:kooooo0_l0000Nooooo`;o0000LOooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o0000AOooool2o`00
06Oooooo0_l0000=ooooo`;o00006_ooool2o`0002Kooooo0_l0000]ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`0000[ooooo0_l0000D
ooooo`;o00003?ooool2o`0001Gooooo0_l0000Sooooo`;o0000;_ooool2o`0001;ooooo0_l0000Y
ooooo`;o00009_ooool2o`0002gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01_ooooo0_l0000Dooooo`;o00003?ooool2o`0003[ooooo0_l0000^ooooo`;o0000U?ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0004oo
oooo0_l0002Xooooo`;o00001oooool2o`0003kooooo000Tooooo`03o`000?oooooooooo023ooooo
0_l0000/ooooo`;o0000>Oooool2o`0004kooooo0_l0000Mooooo`;o00001oooool2o`0003kooooo
000Tooooo`03o`000?oooooooooo023ooooo0_l0001Wooooo`;o0000C_ooool2o`0006Kooooo000T
ooooo`03o`000?oooooooooo03Oooooo0_l0001:ooooo`;o0000_?ooool002Cooooo00?o0000oooo
ooooool0=oooool2o`0000Oooooo0_l00011ooooo`;o0000@oooool2o`0007Oooooo000Tooooo`03
o`000?oooooooooo043ooooo0_l0000cooooo`;o0000DOooool2o`0001;ooooo0_l0001Sooooo`00
9?ooool2o`0002Oooooo0_l0000oooooo`;o00003?ooool2o`0006Gooooo0_l0001Sooooo`009?oo
ool00ol0003oooooooooo`0Vooooo`;o0000:Oooool2o`0001Cooooo0_l0000@ooooo`;o0000I?oo
ool2o`000003ooooool0003o000005gooooo000Tooooo`03o`000?oooooooooo057ooooo0_l0000A
ooooo`;o00004oooool2o`00037ooooo0_l00004ooooo`;o00007oooool2o`0000[ooooo0_l00000
0ooooooo0000o`00001Mooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000H?ooool2o`00
04Kooooo0_l00004ooooo`;o00007oooool2o`0005?ooooo0_l0000Gooooo`009?ooool00ol0003o
ooooooooo`02ooooo`;o0000bOooool2o`0005Wooooo0_l0000Gooooo`009?ooool2o`000<kooooo
0_l0001booooo`009?ooool00ol0003oooooooooo`30ooooo`;o0000GOooool2o`00023ooooo000T
ooooo`03o`000?oooooooooo06[ooooo0_l0001Dooooo`;o0000:oooool2o`00033ooooo0_l0000P
ooooo`009?ooool00ol0003oooooooooo`1Zooooo`;o0000N?ooool2o`0000Oooooo0_l0000Doooo
o`;o0000??ooool002Cooooo00?o0000ooooooooool0L?ooool2o`0007;ooooo0_l0000Mooooo`;o
0000??ooool002Cooooo0_l0001Jooooo`;o00005Oooool2o`0004Oooooo0_l00026ooooo`009?oo
ool00ol0003oooooooooo`1Iooooo`?o0000GOooool2o`0008Kooooo0009ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo05[ooooo0_l0000Uooooo`;o0000Zoooool2o`00017ooooo0009ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`21ooooo`;o0000Zoooool2o`00017ooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo0_l0000Eooooo`;o0000
7Oooool2o`0004;ooooo0_l00009ooooo`;o0000S_ooool000Wooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000/ooooo`;o00005Oooool2o`0001gooooo
0_l00012ooooo`;o00002Oooool2o`0008kooooo0009ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01Oooool2o`000?oo
oooo>oooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool2o`000?oooooo>oooool000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool2o`00077o
oooo0_l0000Pooooo`;o0000E_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool00ol0003oooooooooo`1Dooooo`;o0000LOooool2o`00023ooooo0_l0000Cooooo`;o
0000@Oooool002Cooooo0_l0003oooooo`;o0000@Oooool002Cooooo00?o0000ooooooooool0Sooo
ool2o`00053ooooo0_l0001Nooooo`009?ooool00ol0003oooooooooo`2?ooooo`;o0000D?ooool2
o`0005kooooo000Tooooo`03o`000?oooooooooo07Kooooo0_l00039ooooo`009?ooool00ol0003o
ooooooooo`1fooooo`;o0000bOooool002Cooooo0_l00005ooooo`;o0000R_ooool2o`0007[ooooo
0_l0000cooooo`009?ooool00ol0003oooooooooo`04ooooo`;o0000R_ooool2o`0007[ooooo0_l0
000cooooo`009?ooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000hooooo`009?ooool00ol0
003oooooooooo`2Pooooo`;o0000IOooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo08co
oooo0_l0000Booooo`;o0000Woooool002Cooooo0_l0002=ooooo`;o0000/oooool002Cooooo00?o
0000ooooooooool04_ooool2o`0000gooooo0_l0002]ooooo`;o0000?Oooool2o`00033ooooo000T
ooooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`;o0000[Oooool2o`0003gooooo0_l0000`
ooooo`009?ooool00ol0003oooooooooo`0hooooo`;o0000ooooool8ooooo`009?ooool00ol0003o
ooooooooo`0hooooo`;o00004Oooool2o`000;gooooo0_l0000eooooo`009?ooool2o`0004cooooo
0_l0002mooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooobOooooo0_l0000Iooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolWooooo`;o00006Oooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0]?ooool2o`0008_ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`?o0000Eoooool2o`0005_ooooo0_l0002;ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo05Oooooo0_l0002looooo`;o0000:_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolFooooo`;o0000:_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3ooooood;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`33ooooo`;o0000O?ooool002Co
oooo0_l00013ooooo`;o0000E_ooool2o`0002Oooooo0_l0001looooo`009?ooool00ol0003ooooo
ooooo`12ooooo`;o0000Doooool2o`000003ooooool0003o00000:Gooooo000Tooooo`03o`000?oo
oooooooo03cooooo0_l0001Iooooo`;o0000Z?ooool002Cooooo00?o0000ooooooooool0??ooool2
o`000;;ooooo0_l0001?ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000f?ooool2o`00
01Cooooo0_l0000iooooo`009?ooool2o`0001Oooooo0_l0000eooooo`;o0000]oooool2o`0003Wo
oooo000Tooooo`03o`000?oooooooooo04gooooo0_l0000Looooo`;o0000e?ooool002Cooooo00?o
0000ooooooooool0Joooool2o`00093ooooo0_l00012ooooo`009?ooool00ol0003oooooooooo`2Y
ooooo`;o0000D_ooool2o`0004;ooooo000Tooooo`03o`000?oooooooooo0:Wooooo0_l0000Poooo
o`;o0000M?ooool002Cooooo0_l0001mooooo`;o0000COooool2o`0001[ooooo0_l0001Hooooo`00
9?ooool00ol0003oooooooooo`1Uooooo`;o00005Oooool2o`0006Wooooo0_l0001Hooooo`009?oo
ool00ol0003oooooooooo`1Uooooo`;o0000f_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0mOooool2o`00023ooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?Gooooo0_l0000Pooooo`;o0000:?ooool001cooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000J_ooool2o`000:Cooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;oooool2o`0006[ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo0_l0003ooooooc?ooooo000Jooooo`03oeEEEOmVIVKo0000
00Oooooo00?o0000ooooooooool03Oooool2o`000?oooooo<oooool002Cooooo0_l0000Dooooo`;o
0000ooooool]ooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o0000ooooool]ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo<oooool2o`0000ko
oooo000Tooooo`03o`000?oooooooooo0?oooooo<_ooool2o`0000kooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3oooooo`7ooooo0_l0000oooooo`009?ooool2o`000?oooooo0_ooool2o`0003oo
oooo000Tooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002Gooooo000Tooooo`03o`000?oo
oooooooo0?oooooo6oooool2o`0002Gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004oooo
o`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0K_ooool2o`0006Kooooo0_l0001Yooooo`001?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1^ooooo`;o00003_ooool2o`0005Kooooo0_l0001Yooooo`001?ooool00ol0003o
ooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07kooooo0_l00031ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool01?l0003oooooo`000?l0002eooooo`;o0000ROooool002Cooooo00Co0000ooooool0003o0000
]Oooool2o`0008Wooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003o
oooood?ooooo000Tooooo`03o`000?oooooooooo0:oooooo0_l0002@ooooo`009?ooool00ol0003o
ooooooooo`2_ooooo`;o0000T?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo
000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`0009gooooo0_l0
002Rooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Tooooo`;o0000Moooool2o`000:;ooooo000<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`;o0000oooooolL
ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`2Sooooo`;o0000W?ooool002Cooooo00?o0000ooooooooool0Xoooool2o`00057ooooo0_l00019
ooooo`009?ooool00ol0003oooooooooo`3fooooo`;o0000BOooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0006kooooo
0_l0003Booooo`009?ooool00ol0003oooooooooo`1]ooooo`;o0000d_ooool002Cooooo00?o0000
ooooooooool0g_ooool2o`00067ooooo000Tooooo`03o`000?oooooooooo0=kooooo0_l0001Qoooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000ooooool6ooooo`;o0000
>oooool002Cooooo00?o0000ooooooooool0ooooool5ooooo`;o0000>oooool000;ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Co
oooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03?ooool2o`0007Wo
oooo0_l0002hooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o0000NOooool2o`000;Sooooo
0004ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Doooool2o`000>cooooo0002ooooo`03oeEEEOmV
IVKo000000cooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`1Cooooo`;o0000k?oo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3oooooobgooooo0_l0000Cooooo`009?ooool00ol0003ooooooooo
o`3oooooobgooooo0_l0000Cooooo`009?ooool3o`000?oooooo@_ooool002Cooooo0ol0003ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1oooooo`;o0000`?ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1oooooo`;o0000`?ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo@_oo
ool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3ooooo
odWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .57312 Mdot
.03333 .36136 Mdot
.0381 .08009 Mdot
.04286 .31486 Mdot
.04762 .1689 Mdot
.05238 .16804 Mdot
.05714 .43994 Mdot
.0619 .00236 Mdot
.06667 .15766 Mdot
.07143 .54572 Mdot
.07619 .1508 Mdot
.08095 .07977 Mdot
.08571 .07014 Mdot
.09048 .20518 Mdot
.09524 .21214 Mdot
.1 .03291 Mdot
.10476 .13862 Mdot
.10952 .21436 Mdot
.11429 .10188 Mdot
.11905 .00016 Mdot
.12381 .00914 Mdot
.12857 .02842 Mdot
.13333 .01446 Mdot
.1381 .38178 Mdot
.14286 .17993 Mdot
.14762 .27115 Mdot
.15238 .11049 Mdot
.15714 .06919 Mdot
.1619 .01483 Mdot
.16667 .11538 Mdot
.17143 .1529 Mdot
.17619 .02224 Mdot
.18095 .12597 Mdot
.18571 .26971 Mdot
.19048 .0925 Mdot
.19524 .0985 Mdot
.2 .10846 Mdot
.20476 .15264 Mdot
.20952 .08472 Mdot
.21429 .11696 Mdot
.21905 .07124 Mdot
.22381 .0266 Mdot
.22857 .08207 Mdot
.23333 .08173 Mdot
.2381 .20878 Mdot
.24286 .05175 Mdot
.24762 .01817 Mdot
.25238 .0242 Mdot
.25714 .10346 Mdot
.2619 .02913 Mdot
.26667 .26704 Mdot
.27143 .09512 Mdot
.27619 .08871 Mdot
.28095 .03801 Mdot
.28571 .02073 Mdot
.29048 .33159 Mdot
.29524 .0135 Mdot
.3 .16836 Mdot
.30476 .42211 Mdot
.30952 .05157 Mdot
.31429 .14324 Mdot
.31905 .0335 Mdot
.32381 .02762 Mdot
.32857 .02422 Mdot
.33333 .02005 Mdot
.3381 .36371 Mdot
.34286 .11814 Mdot
.34762 .28408 Mdot
.35238 .25601 Mdot
.35714 .0637 Mdot
.3619 .30777 Mdot
.36667 .35999 Mdot
.37143 .32433 Mdot
.37619 .45854 Mdot
.38095 .10113 Mdot
.38571 .04936 Mdot
.39048 .01968 Mdot
.39524 .10774 Mdot
.4 .15284 Mdot
.40476 .02412 Mdot
.40952 .02381 Mdot
.41429 .12137 Mdot
.41905 .16141 Mdot
.42381 .40759 Mdot
.42857 .48892 Mdot
.43333 .14672 Mdot
.4381 .10009 Mdot
.44286 .02672 Mdot
.44762 .26012 Mdot
.45238 .44533 Mdot
.45714 .22085 Mdot
.4619 .03523 Mdot
.46667 .32706 Mdot
.47143 .00552 Mdot
.47619 .25868 Mdot
.48095 .16311 Mdot
.48571 .05236 Mdot
.49048 .19042 Mdot
.49524 .06147 Mdot
.5 .03222 Mdot
.50476 .09967 Mdot
.50952 .45086 Mdot
.51429 .29147 Mdot
.51905 .27181 Mdot
.52381 .01639 Mdot
.52857 .08271 Mdot
.53333 .01552 Mdot
.5381 .50484 Mdot
.54286 .04924 Mdot
.54762 .15457 Mdot
.55238 .27387 Mdot
.55714 .33247 Mdot
.5619 .0032 Mdot
.56667 .05479 Mdot
.57143 .03141 Mdot
.57619 .24638 Mdot
.58095 .15208 Mdot
.58571 .11804 Mdot
.59048 .09946 Mdot
.59524 .24761 Mdot
.6 .0676 Mdot
.60476 .08887 Mdot
.60952 .02686 Mdot
.61429 .0333 Mdot
.61905 .11948 Mdot
.62381 .07846 Mdot
.62857 .03646 Mdot
.63333 .03362 Mdot
.6381 .14324 Mdot
.64286 .00088 Mdot
.64762 .09676 Mdot
.65238 .07272 Mdot
.65714 .03042 Mdot
.6619 .05821 Mdot
.66667 .00742 Mdot
.67143 .07726 Mdot
.67619 .02523 Mdot
.68095 .00292 Mdot
.68571 .1164 Mdot
.69048 .07725 Mdot
.69524 .26022 Mdot
.7 .00987 Mdot
.70476 .00779 Mdot
.70952 .02781 Mdot
.71429 .16618 Mdot
.71905 .60275 Mdot
.72381 .14166 Mdot
.72857 .17669 Mdot
.73333 .11488 Mdot
.7381 .16838 Mdot
.74286 .02948 Mdot
.74762 .2005 Mdot
.75238 .16733 Mdot
.75714 .02679 Mdot
.7619 .121 Mdot
.76667 .03345 Mdot
.77143 .02751 Mdot
.77619 .40727 Mdot
.78095 .12276 Mdot
.78571 .10423 Mdot
.79048 .20432 Mdot
.79524 .16229 Mdot
.8 .00972 Mdot
.80476 .10579 Mdot
.80952 .01124 Mdot
.81429 .04796 Mdot
.81905 .1689 Mdot
.82381 .48781 Mdot
.82857 .09145 Mdot
.83333 .03725 Mdot
.8381 .44266 Mdot
.84286 .38981 Mdot
.84762 .39557 Mdot
.85238 .02182 Mdot
.85714 .03923 Mdot
.8619 .09768 Mdot
.86667 .07648 Mdot
.87143 .03981 Mdot
.87619 .06462 Mdot
.88095 .08083 Mdot
.88571 .05096 Mdot
.89048 .19236 Mdot
.89524 .45056 Mdot
.9 .0291 Mdot
.90476 .23289 Mdot
.90952 .32534 Mdot
.91905 .00507 Mdot
.92381 .06293 Mdot
.92857 .01209 Mdot
.93333 .14743 Mdot
.9381 .20297 Mdot
.94286 .09433 Mdot
.94762 .11856 Mdot
.95238 .00994 Mdot
.95714 .05631 Mdot
.9619 .53742 Mdot
.96667 .37961 Mdot
.97143 .20524 Mdot
.97619 .42196 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00gooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00Wooooo
0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0_ooool2o`0000Sooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000ooooo`0>ooooo`03
o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo01gooooo0_l0001^ooooo`;o0000
?_ooool2o`0000Wooooo0ol0000Mooooo`;o00009Oooool2o`0000Sooooo0_l0000Fooooo`009?oo
ool00ol0003oooooooooo`0Mooooo`;o0000[_ooool2o`0000Wooooo0ol0000Mooooo`;o000000?o
ooooo`000?l000009Oooool2o`0000Gooooo0_l0000Fooooo`009?ooool2o`00027ooooo0_l00007
ooooo`;o0000:Oooool2o`0004Sooooo0_l000000ooooooo0000o`00001Hooooo`;o00009Oooool2
o`0001gooooo000Tooooo`03o`000?oooooooooo023ooooo0_l00007ooooo`;o00006_ooool2o`00
00gooooo0_l00018ooooo`;o000000?oooooo`000?l00000W_ooool002Cooooo00?o0000oooooooo
ool0;_ooool2o`0001Gooooo0_l0000:ooooo`;o00003_ooool2o`00013ooooo0_l0002Dooooo`;o
0000=_ooool002Cooooo00?o0000ooooooooool0;_ooool2o`0001Kooooo0_l00009ooooo`;o0000
3?ooool4o`00013ooooo0_l00003ooooo`?o0000EOooool2o`0003Oooooo0_l0000fooooo`009?oo
ool00ol0003oooooooooo`0Nooooo`;o00007Oooool2o`0000Oooooo0_l0000Fooooo`?o00005ooo
ool3o`0000Wooooo0_l0000dooooo`;o00005?ooool2o`0000Wooooo0_l0000=ooooo`;o00000ooo
ool2o`00053ooooo000Tooooo`;o00007oooool2o`0001gooooo0_l0000:ooooo`;o00004oooool2
o`0002Cooooo0_l0000Xooooo`;o00002_ooool2o`0000kooooo0_l0000?ooooo`;o00002?ooool2
o`0000?ooooo0_l00003ooooo`;o00009oooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo
01Gooooo0_l0000booooo`;o00004Oooool2o`0003Wooooo0_l0000Eooooo`;o00003?ooool2o`00
00Cooooo0_l00006ooooo`;o00006Oooool2o`0000Kooooo0_l0000Yooooo`;o00009oooool002Co
oooo00?o0000ooooooooool05Oooool2o`0004Gooooo0_l0000/ooooo`;o00002oooool2o`0002?o
oooo0_l00002ooooo`Co0000:Oooool2o`0001Cooooo0_l0000looooo`009?ooool00ol0003ooooo
ooooo`1@ooooo`;o0000>?ooool2o`0003Cooooo0_l00011ooooo`;o00001Oooool2o`0000?ooooo
0_l0000`ooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000^?ooool2o`0000?ooooo0_l0
000`ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0L_ooool2o`00
037ooooo0_l0001Fooooo`;o0000@_ooool002Cooooo00?o0000ooooooooool0@oooool2o`0001Co
oooo0_l0000Gooooo`;o00007_ooool2o`00017ooooo0_l0001Fooooo`;o00005Oooool2o`0002_o
oooo000Tooooo`03o`000?oooooooooo04?ooooo0_l0000Dooooo`;o0000=oooool2o`0001Sooooo
0_l0001Vooooo`;o00005Oooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo0:cooooo0_l0
000Mooooo`;o0000G_ooool2o`0001Cooooo000Tooooo`;o0000U_ooool2o`0003Cooooo0_l0001d
ooooo`009?ooool00ol0003oooooooooo`1Xooooo`;o0000:oooool2o`0007[ooooo0_l0000=oooo
o`;o00007oooool002Cooooo00?o0000ooooooooool0J?ooool2o`0004gooooo0_l0001Hooooo`;o
00003Oooool2o`0001oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04?ooool2
o`0001Gooooo0_l0000Cooooo`;o0000NOooool2o`0008Sooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo013ooooo0_l0000Eooooo`;o00004oooool2o`0008[ooooo
0_l0001gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000<Sooooo0_l00004ooooo`;o00001?oo
ool2o`0003Sooooo0_l0000aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooooooooooo
ool2o`0000cooooo0_l0002^ooooo`;o00003Oooool2o`0000Cooooo0_l0000hooooo`;o00000_oo
ool2o`0002gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooooooooooooooo
0_l0000<ooooo`;o0000;_ooool3o`0005kooooo0_l0000Mooooo`;o0000DOooool2o`0002gooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`?o0000G_oo
ool2o`0009oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool2o`0001Co
oooo0_l0001Yooooo`;o0000Q_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000<oooool2o`0001[ooooo0_l0001Y
ooooo`;o0000A_ooool2o`0003kooooo000Tooooo`03o`000?oooooooooo03;ooooo0_l0000Ioooo
o`;o0000/_ooool2o`0002?ooooo0_l0000Iooooo`009?ooool00ol0003oooooooooo`0dooooo`;o
00005oooool2o`0006Gooooo0_l0000Aooooo`;o0000@oooool2o`0001Sooooo0_l0000Iooooo`00
9?ooool00ol0003oooooooooo`0Jooooo`;o00006?ooool2o`0003[ooooo0_l0000Aooooo`;o0000
4oooool2o`0001[ooooo0_l0000Aooooo`;o0000@oooool2o`0003?ooooo000Tooooo`03o`000?oo
oooooooo01[ooooo0_l0000/ooooo`;o00009_ooool2o`00017ooooo0_l0000Cooooo`;o0000FOoo
ool2o`0000Cooooo0_l00016ooooo`009?ooool00ol0003oooooooooo`0eooooo`;o00004Oooool2
o`0002_ooooo0_l0001looooo`;o00001?ooool2o`0004Kooooo000Tooooo`;o00009oooool2o`00
00gooooo0_l0000nooooo`;o0000b_ooool002Cooooo00?o0000ooooooooool09_ooool2o`000;[o
oooo0_l0001Mooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o00003Oooool2o`0002Sooooo
0_l0001<ooooo`;o00007oooool2o`0000gooooo0_l0001Mooooo`009?ooool00ol0003ooooooooo
o`0[ooooo`;o00003Oooool2o`0002Sooooo0_l0001<ooooo`;o00002Oooool2o`0001Cooooo0_l0
000Gooooo`;o0000>_ooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo07_ooooo0_l00010
ooooo`;o0000;Oooool2o`0000Cooooo0_l0000dooooo`;o00005oooool002Cooooo0_l0000`oooo
o`;o0000B_ooool2o`0007Gooooo0_l0001=ooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o
0000oooooolAooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool05_ooool2o`000?oooooo:_ooool0
02Cooooo0_l0000Gooooo`;o0000aoooool2o`00063ooooo000Tooooo`03o`000?oooooooooo05[o
oooo0_l0001Wooooo`;o00006_ooool2o`00063ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
05[ooooo0_l0000Uooooo`;o0000@?ooool2o`0005kooooo0_l0000Looooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool03Oooool2o`0007;ooooo0_l0002Pooooo`;o00007?ooool000Wooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool2o`00
01gooooo0_l00009ooooo`;o0000?Oooool2o`0002kooooo0_l00009ooooo`;o0000S_ooool000Wo
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000:oooo
o`;o00008?ooool2o`0000Wooooo0_l0000mooooo`;o0000;_ooool2o`0000Wooooo0_l0002>oooo
o`002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo00[ooooo0_l0003oooooocKooooo0009ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo0_l0000B
ooooo`;o0000I?ooool2o`0004Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo0_l0000Booooo`;o0000B_ooool2
o`0000_ooooo0_l0000;ooooo`;o0000BOooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`?o0000Coooool2o`0008Cooooo0_l00006
ooooo`;o00000oooool2o`0001?ooooo0_l00011ooooo`009?ooool2o`0000Gooooo0ol0001?oooo
o`;o0000S?ooool2o`0001Sooooo0_l00011ooooo`009?ooool00ol0003oooooooooo`3Qooooo`;o
0000G_ooool002Cooooo00?o0000ooooooooool0hOooool2o`0005kooooo000Tooooo`03o`000?oo
oooooooo02?ooooo0_l0003ooooooagooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0003o
oooooagooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`2Dooooo`;o
0000Zoooool002Cooooo00?o0000ooooooooool0U?ooool2o`0007oooooo0_l0000Zooooo`009?oo
ool00ol0003oooooooooo`3ooooooaKooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`3W
ooooo`;o0000F?ooool002Cooooo0_l0003Xooooo`;o00003?ooool2o`0002kooooo0_l0000Joooo
o`009?ooool00ol0003oooooooooo`0Booooo`;o0000hOooool2o`0002kooooo0_l00009ooooo`;o
00003oooool002Cooooo00?o0000ooooooooool04_ooool2o`0002kooooo0_l0003/ooooo`;o0000
3oooool002Cooooo00?o0000ooooooooool04oooool2o`0002gooooo0_l0003mooooo`009?ooool0
0ol0003oooooooooo`0Cooooo`;o00000oooool2o`000?oooooo:?ooool002Cooooo0_l0000Ioooo
o`;o0000oooooolXooooo`009?ooool00ol0003oooooooooo`29ooooo`;o0000]_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ROooool2o`000;Kooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo@_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooo
oa_ooooo0_l0000Uooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?oooooo6oooool2o`0002Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00co
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooooooo
o`2_ooooo`;o00001Oooool2o`0008Wooooo000Tooooo`;o0000/?ooool2o`0000Gooooo0_l00029
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo06Oo
oooo0_l0003Hooooo`009?ooool00ol0003oooooooooo`1Wooooo`;o00009_ooool2o`000;3ooooo
000Tooooo`03o`000?oooooooooo08Kooooo0_l00007ooooo`;o0000AOooool2o`0006Wooooo000T
ooooo`;o0000Qoooool2o`0004kooooo0_l0001Yooooo`009?ooool00ol0003oooooooooo`1;oooo
o`;o0000m?ooool002Cooooo00?o0000ooooooooool09?ooool2o`0000_ooooo0_l0000Hooooo`;o
0000D?ooool2o`000:;ooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l0000;ooooo`;o0000
J_ooool2o`0000Wooooo0_l0002Gooooo`009?ooool00ol0003oooooooooo`2Xooooo`;o0000Uooo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo06Gooooo0_l0003Joooo
o`009?ooool00ol0003oooooooooo`1Uooooo`;o0000f_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`2Kooooo`;o0000Y?ooool002Cooooo0_l0002L
ooooo`;o0000Y?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Zooooo`;o0000eOooool001cooooo00?o0000ooooooooool01Oooool3
o`0006[ooooo0_l0003Eooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_l0003oooooockooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2o`000?oooooo?_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood;ooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0KOoo
ool2o`000=;ooooo000Tooooo`;o0000K_ooool2o`0001gooooo0_l0002=ooooo`;o00009?ooool0
02Cooooo00?o0000ooooooooool0S?ooool2o`0008gooooo0_l0000Tooooo`009?ooool00ol0003o
ooooooooo`1Cooooo`;o0000E?ooool2o`0009Kooooo000Tooooo`03o`000?oooooooooo05?ooooo
0_l0001Dooooo`;o0000U_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00Co0000oooo
ool0003o0000J_ooool2o`000=Cooooo000Tooooo`04o`000?oooooo0000o`00067ooooo0_l00007
ooooo`;o0000e?ooool002Cooooo00?o0000ooooooooool0H_ooool2o`000=gooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo;ooo
ool2o`00017ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo0_l0
003oooooo`cooooo0_l0000Aooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`;o0000oooooolO
ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
o`Oooooo0_l0000iooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooo`Oooooo0ol0000hooooo`00
1?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Sooooo0002ooooo`03oeEE
EOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`1nooooo`;o0000L?ooool2o`0004oooooo000Tooooo`03o`000?oooooooooo07kooooo0_l0001`
ooooo`;o0000Coooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`1Gooooo`;o0000f?ooool2o`0000kooooo000Tooooo`03o`000?oooooooooo05Oooooo0_l0003H
ooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocWooooo000Toooo
o`03o`000?oooooooooo00Oooooo0_l0003kooooo`;o0000>oooool002Cooooo00?o0000oooooooo
ool0Qoooool2o`0007_ooooo0_l0000kooooo`009?ooool2o`0008Sooooo0_l0000Aooooo`;o0000
Noooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo09[ooooo0_l0001kooooo`;o0000:?oo
ool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06kooooo0_l0003A
ooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0K_ooool2o`000=7ooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003oooooo000Tooooo`03o`000?oo
oooooooo07oooooo0_l0001oooooo`;o0000?oooool002Cooooo00?o0000ooooooooool0Ooooool2
o`000<3ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Xooo
ool2o`0009cooooo000Tooooo`03o`000?oooooooooo0:?ooooo0_l0002Looooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo;Oooool2o`0001?ooooo
0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo;Oooool2o`0001?ooooo0004ooooo`03o`000?oooooo
oooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2
ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00cooooo0_l0003oooooocCooooo0004oooo
o`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo0_l0003oooooocCooooo0004ooooo`03o`000?oooooooooo00[o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool3o`000?oooooo@_ooool002Cooooo0ol0003ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
goooool2o`00067ooooo000Tooooo`03o`000?oooooooooo0=kooooo0_l0001Qooooo`006Oooool5
o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oo
oooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003ooooooooo
o`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .553 Mdot
.03333 .26011 Mdot
.0381 .24477 Mdot
.04286 .50242 Mdot
.04762 .11266 Mdot
.05238 .16804 Mdot
.05714 .23397 Mdot
.0619 .00236 Mdot
.06667 .25299 Mdot
.07619 .08745 Mdot
.08095 .15012 Mdot
.08571 .06192 Mdot
.09048 .07843 Mdot
.09524 .0482 Mdot
.1 .04959 Mdot
.10476 .20632 Mdot
.10952 .40901 Mdot
.11429 .05114 Mdot
.11905 .00016 Mdot
.12381 .04804 Mdot
.12857 .24153 Mdot
.13333 .0578 Mdot
.1381 .33121 Mdot
.14286 .37387 Mdot
.14762 .00584 Mdot
.15238 .03732 Mdot
.15714 .06919 Mdot
.1619 .05948 Mdot
.16667 .1015 Mdot
.17143 .1529 Mdot
.17619 .19228 Mdot
.18095 .29869 Mdot
.18571 .12426 Mdot
.19048 .0296 Mdot
.19524 .14977 Mdot
.2 .14154 Mdot
.20476 .08077 Mdot
.20952 .07736 Mdot
.21429 .35145 Mdot
.21905 .07195 Mdot
.22381 .0266 Mdot
.22857 .05722 Mdot
.23333 .21219 Mdot
.2381 .10065 Mdot
.24286 .07307 Mdot
.24762 .01093 Mdot
.25238 .08485 Mdot
.25714 .04001 Mdot
.2619 .02913 Mdot
.26667 .31003 Mdot
.27143 .20068 Mdot
.27619 .08871 Mdot
.28095 .03469 Mdot
.28571 .03258 Mdot
.29048 .06289 Mdot
.29524 .0135 Mdot
.3 .16836 Mdot
.30476 .42752 Mdot
.30952 .05157 Mdot
.31429 .01308 Mdot
.31905 .25187 Mdot
.32381 .02762 Mdot
.32857 .12795 Mdot
.33333 .20068 Mdot
.3381 .36371 Mdot
.34286 .13082 Mdot
.34762 .11303 Mdot
.35238 .12062 Mdot
.35714 .26649 Mdot
.3619 .17143 Mdot
.36667 .36801 Mdot
.37143 .34395 Mdot
.37619 .3605 Mdot
.38095 .10113 Mdot
.38571 .08155 Mdot
.39048 .01968 Mdot
.39524 .03106 Mdot
.4 .09888 Mdot
.40476 .02412 Mdot
.40952 .02381 Mdot
.41429 .15863 Mdot
.41905 .11874 Mdot
.42381 .58232 Mdot
.42857 .46252 Mdot
.43333 .14672 Mdot
.4381 .27526 Mdot
.44286 .05687 Mdot
.44762 .22039 Mdot
.45238 .23957 Mdot
.45714 .13639 Mdot
.4619 .0763 Mdot
.46667 .14546 Mdot
.47143 .05699 Mdot
.47619 .1965 Mdot
.48095 .22393 Mdot
.48571 .03191 Mdot
.49048 .17963 Mdot
.49524 .06147 Mdot
.5 .03222 Mdot
.50476 .1045 Mdot
.50952 .50445 Mdot
.51429 .2231 Mdot
.51905 .13548 Mdot
.52381 .01639 Mdot
.52857 .08271 Mdot
.53333 .01135 Mdot
.54286 .04924 Mdot
.54762 .05902 Mdot
.55238 .37534 Mdot
.55714 .16027 Mdot
.5619 .0032 Mdot
.56667 .05479 Mdot
.57143 .03141 Mdot
.57619 .36451 Mdot
.58095 .22328 Mdot
.58571 .25941 Mdot
.59048 .17167 Mdot
.59524 .04142 Mdot
.6 .0676 Mdot
.60476 .19882 Mdot
.60952 .13692 Mdot
.61429 .42057 Mdot
.61905 .11948 Mdot
.62381 .04776 Mdot
.62857 .03646 Mdot
.63333 .03238 Mdot
.6381 .14324 Mdot
.64286 .00088 Mdot
.64762 .03648 Mdot
.65238 .07272 Mdot
.65714 .03042 Mdot
.6619 .04029 Mdot
.66667 .00742 Mdot
.67143 .07726 Mdot
.67619 .02523 Mdot
.68095 .00292 Mdot
.68571 .11666 Mdot
.69048 .01373 Mdot
.69524 .23265 Mdot
.7 .11643 Mdot
.70476 .00779 Mdot
.70952 .01515 Mdot
.71429 .0034 Mdot
.71905 .35517 Mdot
.72381 .14166 Mdot
.72857 .08321 Mdot
.73333 .12353 Mdot
.7381 .28964 Mdot
.74286 .02948 Mdot
.74762 .25189 Mdot
.75238 .47479 Mdot
.75714 .12047 Mdot
.7619 .05915 Mdot
.76667 .03345 Mdot
.77143 .17681 Mdot
.77619 .52267 Mdot
.78095 .12276 Mdot
.78571 .0175 Mdot
.79048 .08955 Mdot
.79524 .08573 Mdot
.8 .0559 Mdot
.80476 .10579 Mdot
.80952 .38913 Mdot
.81429 .20228 Mdot
.81905 .27472 Mdot
.82381 .31579 Mdot
.82857 .00212 Mdot
.83333 .03725 Mdot
.8381 .23959 Mdot
.84286 .16053 Mdot
.84762 .43559 Mdot
.85238 .02182 Mdot
.85714 .03923 Mdot
.8619 .32881 Mdot
.86667 .00859 Mdot
.87143 .03981 Mdot
.87619 .06462 Mdot
.88095 .22364 Mdot
.88571 .05096 Mdot
.89048 .13291 Mdot
.89524 .23171 Mdot
.9 .0291 Mdot
.90476 .3551 Mdot
.90952 .36321 Mdot
.91905 .0104 Mdot
.92381 .06293 Mdot
.92857 .00404 Mdot
.93333 .05176 Mdot
.9381 .18619 Mdot
.94286 .08005 Mdot
.94762 .11856 Mdot
.95238 .13184 Mdot
.95714 .05631 Mdot
.9619 .49296 Mdot
.96667 .175 Mdot
.97143 .02928 Mdot
.97619 .2095 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00gooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00gooooo00?o0000oooooooo
ool03?ooool2o`0000kooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool0
2Oooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o
00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03
o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool2o`000003ooooool0003ooooo00gooooo00?o0000ooooooooool03?ooool2o`0000ko
oooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool09?ooool2o`000:Oooooo
0_l0000:ooooo`;o0000<oooool2o`00037ooooo000Tooooo`03o`000?oooooooooo04Gooooo0_l0
000Cooooo`;o0000AOooool2o`0002[ooooo0_l0000:ooooo`;o0000<oooool2o`0000oooooo0_l0
000Pooooo`009?ooool2o`0004Kooooo0_l0000=ooooo`;o00001?ooool2o`0004;ooooo0_l00000
0ooooooo0000o`00000aooooo`;o00001Oooool2o`0004;ooooo0_l0000Pooooo`009?ooool00ol0
003oooooooooo`1Dooooo`;o0000B?ooool2o`0003Cooooo0_l00005ooooo`;o00005_ooool2o`00
04cooooo000Tooooo`03o`000?oooooooooo07?ooooo0_l0001nooooo`;o00005?ooool2o`0003Ko
oooo000Tooooo`03o`000?oooooooooo07?ooooo0_l00003ooooo`?o0000EOooool2o`0003Oooooo
0_l0000fooooo`009?ooool00ol0003oooooooooo`0mooooo`;o00007oooool2o`0001Sooooo0ol0
001Eooooo`;o0000Koooool002Cooooo0_l0000cooooo`;o00002Oooool2o`0000[ooooo0_l0000C
ooooo`;o00005Oooool2o`0003Oooooo0_l0000Jooooo`;o00006Oooool2o`00037ooooo0_l0000F
ooooo`;o00003oooool002Cooooo00?o0000ooooooooool0<_ooool2o`0001Gooooo0_l00005oooo
o`?o00008_ooool2o`0001_ooooo0_l00003ooooo`;o00005Oooool2o`0001;ooooo0_l00006oooo
o`;o00006Oooool2o`0000Kooooo0_l0000Yooooo`;o00005_ooool2o`0000oooooo000Tooooo`03
o`000?oooooooooo02Kooooo0_l0000Xooooo`?o0000?oooool2o`0000?ooooo0_l0000Wooooo`Co
00000oooool2o`0002Cooooo0_l0000Dooooo`;o0000??ooool002Cooooo00?o0000ooooooooool0
9_ooool2o`00023ooooo0_l0001fooooo`;o00001Oooool2o`0000;ooooo0_l0000fooooo`;o0000
1Oooool2o`0000?ooooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`18ooooo`;o0000K?oo
ool2o`0001?ooooo0_l0000mooooo`;o00000oooool2o`00033ooooo000Tooooo`;o0000]oooool2
o`0008Wooooo000Tooooo`03o`000?oooooooooo01?ooooo1?l00006ooooo`;o0000Q_ooool2o`00
01Sooooo0_l00020ooooo`009?ooool00ol0003oooooooooo`0Cooooo`Co00000oooool2o`000003
ooooool0003o000003[ooooo0_l0001:ooooo`;o00006?ooool2o`0005?ooooo0_l0000=ooooo`;o
00007?ooool002Cooooo00?o0000ooooooooool06_ooool2o`0003gooooo0_l0001Aooooo`;o0000
B_ooool2o`0001[ooooo0_l0000=ooooo`;o00001_ooool2o`0001Cooooo000Tooooo`03o`000?oo
oooooooo023ooooo0_l00007ooooo`;o00005?ooool2o`0004?ooooo0_l00007ooooo`;o00005ooo
ool2o`0000Cooooo0_l0000nooooo`;o00002_ooool2o`00037ooooo0_l0000Dooooo`009?ooool2
o`00017ooooo0_l0000>ooooo`;o00001oooool2o`0001Cooooo0_l00013ooooo`;o00001oooool2
o`0000Kooooo0_l0000?ooooo`;o0000A?ooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo
013ooooo0_l00011ooooo`;o0000@?ooool2o`0007[ooooo0_l0000=ooooo`;o00007oooool002Co
oooo00?o0000ooooooooool0Doooool2o`0006;ooooo0_l0001Hooooo`;o00003Oooool2o`0001oo
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09oooool2o`0008kooooo0_l00028
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Wooooo`;o0000
4oooool2o`0000Gooooo0_l00023ooooo`;o0000Moooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
000hooooo`;o00000_ooool2o`0000Gooooo0_l00015ooooo`;o0000??ooool2o`0000Cooooo0_l0
001aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`;o00008oooool3
o`00053ooooo0_l00012ooooo`;o0000E_ooool2o`0001Wooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool04_ooool2o`0002?ooooo0_l0000iooooo`;o0000;?ooool2
o`0003oooooo0_l00013ooooo`;o00006Oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0A_ooool2o`0002[ooooo0_l0000/ooooo`;o0000?oooool2o`0001?ooooo0_l00019oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0000gooooo`;o00001_oo
ool2o`000:Gooooo0ol00019ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000>ooooo`;o0000?oooool2o`000:Go
oooo0_l0001:ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo07Kooooo0_l00039ooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o00005Oooool2
o`0002cooooo0_l00004ooooo`;o0000bOooool002Cooooo00?o0000ooooooooool0:oooool2o`00
01Gooooo0_l0000/ooooo`;o00009_ooool2o`0005oooooo0_l00016ooooo`009?ooool00ol0003o
ooooooooo`2Hooooo`;o0000Goooool2o`0004Kooooo000Tooooo`;o0000oooooom3ooooo`009?oo
ool00ol0003oooooooooo`04ooooo`;o0000Goooool2o`000=[ooooo000Tooooo`03o`000?oooooo
oooo00Cooooo0_l0001Oooooo`;o0000K?ooool2o`0000?ooooo0_l0001Wooooo`009?ooool00ol0
003oooooooooo`1Wooooo`;o00004oooool2o`0003oooooo0_l0000Dooooo`;o00000oooool2o`00
013ooooo0_l0000looooo`;o00005oooool002Cooooo00?o0000ooooooooool0<Oooool2o`0003Co
oooo0_l0000Cooooo`;o0000?oooool2o`0002?ooooo0_l00006ooooo`;o00001_ooool2o`0003Co
oooo0_l0000Gooooo`009?ooool2o`0003;ooooo0_l0002_ooooo`;o00003_ooool2o`0004gooooo
000Tooooo`03o`000?oooooooooo05oooooo0_l0003Pooooo`009?ooool00ol0003oooooooooo`1O
ooooo`;o00000oooool2o`000:oooooo0_l0000Booooo`;o00005_ooool002Cooooo00?o0000oooo
ooooool0I?ooool2o`0002?ooooo0_l0000Booooo`;o0000M_ooool2o`0001;ooooo0_l0000Foooo
o`009?ooool00ol0003oooooooooo`29ooooo`;o00004_ooool2o`0001_ooooo0_l00025ooooo`00
9?ooool2o`0003Kooooo0_l00023ooooo`;o00008oooool2o`00063ooooo000Tooooo`03o`000?oo
oooooooo03Gooooo0_l0001Eooooo`;o0000=Oooool2o`0001[ooooo0_l0001Pooooo`002Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`21ooooo`;o00002Oooool2o`0003Gooooo0_l0001looooo`002Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool03oooool2o`0002?ooooo0_l0001;ooooo`;o0000__ooool000Wooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3oooool2o`0001_ooooo0_l00006ooooo`;o0000ooooool<ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002cooooo0_l0003ooooooaCooooo
0009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0Noooool2o`0002cooooo0_l0001Kooooo`;o0000>Oooool000Wooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Noooool2o`0002cooooo0_l0001Kooooo`;o0000>Oooool000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`00
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00Go
oooo0_l0001?ooooo`;o0000jOooool002Cooooo0_l00006ooooo`;o0000Coooool2o`0001;ooooo
0_l00018ooooo`;o0000Roooool002Cooooo00?o0000ooooooooool0J_ooool2o`0004Sooooo0_l0
001hooooo`;o00004Oooool002Cooooo00?o0000ooooooooool0U?ooool2o`0005Wooooo0_l0000m
ooooo`;o00004Oooool002Cooooo00?o0000ooooooooool0U?ooool2o`0005Wooooo0_l0001@oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooolWooooo`;o0000
6_ooool002Cooooo00?o0000ooooooooool0oooooolVooooo`;o00006_ooool002Cooooo00?o0000
ooooooooool0;_ooool2o`000?oooooo4_ooool002Cooooo00?o0000ooooooooool0;_ooool2o`00
05oooooo0_l0002`ooooo`009?ooool00ol0003oooooooooo`1=ooooo`;o00004_ooool2o`0002co
oooo0_l0000Xooooo`;o0000Q_ooool002Cooooo0_l0001>ooooo`;o00004_ooool2o`0005Kooooo
0_l00012ooooo`;o0000@_ooool002Cooooo00?o0000ooooooooool05_ooool2o`000>Gooooo0_l0
0012ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000oooooolJooooo`;o00003_ooool0
02Cooooo00?o0000ooooooooool0@?ooool2o`000>oooooo0_l0000>ooooo`009?ooool00ol0003o
ooooooooo`10ooooo`;o0000ooooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo08Kooooo0_l0002iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`26ooooo`;o00002?ooool2o`0000Wooooo0_l0000Dooooo`;o0000Goooool2o`0002go
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2@ooooo`;o00002Oooool2o`00
01Cooooo0_l0001Oooooo`;o0000;Oooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolHooooo`;o0000:?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00007ooooo`;o0000
cOooool2o`0003oooooo0_l0000Xooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Oooooo0_l0003=ooooo`;o0000JOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Qoooool2o`0007_ooooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01kooooo0_l0001Wooooo`;o0000Noooool2o`0003_ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool01?l0003oooooooooooooool2
o`0001_ooooo0_l0003oooooob;ooooo000Tooooo`;o00000_ooool2o`000?oooooo?oooool002Co
oooo00?o0000ooooooooool02_ooool2o`00053ooooo0_l00029ooooo`;o0000F?ooool002Cooooo
00?o0000ooooooooool02_ooool2o`00053ooooo0_l00029ooooo`;o0000F?ooool002Cooooo00?o
0000ooooooooool0/_ooool2o`0008gooooo000Tooooo`04o`000?oooooo0000o`000;7ooooo0_l0
002=ooooo`009?ooool4o`000?oooooo@Oooool002Cooooo00?o0000ooooooooool0J?ooool2o`00
0=Oooooo000Tooooo`03o`000?oooooooooo06Sooooo0_l0003Gooooo`009?ooool00ol0003ooooo
ooooo`23ooooo`;o0000NOooool2o`00047ooooo000Tooooo`03o`000?oooooooooo08?ooooo0_l0
001iooooo`;o0000@Oooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3Tooooo`;o0000Foooool002Cooooo00?o0000ooooooooool0i?ooool2o`0005_ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000oooooolAoooo
o`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;oooool2o`000?oo
oooo4Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`?o0000Boooool2o`000?Cooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool2o`000?Cooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000oooooo`006_ooool00omEEEGoIVIVo`00
0007ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo3Oooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo027o
oooo0_l0003Yooooo`;o0000<oooool002Cooooo00?o0000ooooooooool08Oooool2o`000?oooooo
7oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool0KOooool2o`000=;ooooo000Tooooo`03o`000?oooooooooo06go
oooo0_l0003Booooo`009?ooool00ol0003oooooooooo`0jooooo`;o0000ooooool6ooooo`009?oo
ool00ol0003oooooooooo`0jooooo`;o0000X_ooool2o`0003[ooooo0_l0000Uooooo`009?ooool2
o`000=oooooo0_l0000jooooo`;o00009Oooool002Cooooo00?o0000ooooooooool0K_ooool2o`00
0=7ooooo000Tooooo`03o`000?oooooooooo06;ooooo0_l0000:ooooo`;o0000?oooool2o`0006[o
oooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`1Rooooo`;o0000Boooool2o`0006[ooooo
0_l0000Tooooo`009?ooool00ol0003oooooooooo`1[ooooo`;o0000e?ooool002Cooooo0_l0000T
ooooo`;o0000A_ooool2o`000=Cooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l00023oooo
o`;o0000Uoooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0:Sooooo0_l0002Goooo
o`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003kooooo`;o0000A?ooool000Cooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3kooooo`;o0000A?ooool000Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool06?ooool2o`000?oooooo:?ooool002Cooooo
00?o0000ooooooooool06?ooool2o`000?oooooo:?ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0_?ooool2o`00
08?ooooo000Tooooo`03o`000?oooooooooo0;cooooo0_l00023ooooo`009?ooool00ol0003ooooo
ooooo`1Gooooo`;o0000j?ooool002Cooooo00?o0000ooooooooool0Eoooool2o`000>Sooooo000T
ooooo`;o0000ooooool9ooooo`;o0000>?ooool002Cooooo00?o0000ooooooooool0ooooool8oooo
o`;o0000>?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003o
oooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000[ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`003?oo
ool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001oooooo`;o0000`?oo
ool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0jOooool2o`0005Kooooo000:ooooo`03
oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0>Wooooo0_l0001Fooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0ooooool]ooooo`;o00004oooool002Cooooo0_l0003oooooobkooooo
0_l0000Cooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo00;ooooo0_l0003oooooockooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0002Foooo
o`;o0000YOooool002Cooooo00?o0000ooooooooool0V_ooool2o`000:Gooooo000Tooooo`;o0000
oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3`ooooo`;o0000Coooool002Cooooo0_l0003aooooo`;o0000Coooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo
00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmV
IVKo000000cooooo1Ol00004ooooo`Co00001_ooool3o`000?oooooo@_ooool002Cooooo0ol0003o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`1nooooo`;o0000`Oooool002Cooooo00?o0000ooooooooool0O_ooool2o`000<7ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`3ooooood;o
oooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood;o
oooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooom2ooooo`006ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?ooool00omgMgOoIVIVooooo`3o
oooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wooooo00Go0000okZj^_oo
ooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;oooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .33421 Mdot
.0381 .11688 Mdot
.04286 .48756 Mdot
.04762 .05532 Mdot
.05238 .13308 Mdot
.05714 .09383 Mdot
.0619 .00236 Mdot
.06667 .41975 Mdot
.07143 .5538 Mdot
.07619 .02252 Mdot
.08095 .0998 Mdot
.08571 .06192 Mdot
.09048 .07843 Mdot
.09524 .0482 Mdot
.1 .04959 Mdot
.10476 .10774 Mdot
.10952 .21885 Mdot
.11429 .05114 Mdot
.11905 .00016 Mdot
.12381 .04804 Mdot
.12857 .12846 Mdot
.13333 .0578 Mdot
.1381 .3303 Mdot
.14286 .27183 Mdot
.14762 .00584 Mdot
.15238 .03732 Mdot
.15714 .19924 Mdot
.1619 .05948 Mdot
.16667 .1015 Mdot
.17143 .06787 Mdot
.17619 .12479 Mdot
.18095 .23703 Mdot
.18571 .12426 Mdot
.19048 .0296 Mdot
.19524 .02975 Mdot
.2 .11411 Mdot
.20476 .08077 Mdot
.20952 .0601 Mdot
.21429 .44597 Mdot
.21905 .06764 Mdot
.22381 .1522 Mdot
.22857 .05722 Mdot
.23333 .21219 Mdot
.2381 .07906 Mdot
.24286 .21332 Mdot
.24762 .06328 Mdot
.25238 .10555 Mdot
.25714 .02678 Mdot
.2619 .02913 Mdot
.26667 .32849 Mdot
.27143 .05389 Mdot
.27619 .04036 Mdot
.28095 .12901 Mdot
.28571 .18151 Mdot
.29048 .0895 Mdot
.29524 .1344 Mdot
.3 .19877 Mdot
.30476 .45024 Mdot
.30952 .24008 Mdot
.31429 .12693 Mdot
.31905 .0294 Mdot
.32381 .05304 Mdot
.32857 .18849 Mdot
.33333 .36862 Mdot
.3381 .12325 Mdot
.34286 .18241 Mdot
.34762 .00251 Mdot
.35238 .21888 Mdot
.35714 .25933 Mdot
.3619 .17143 Mdot
.36667 .2508 Mdot
.37143 .40527 Mdot
.37619 .43694 Mdot
.38095 .10113 Mdot
.38571 .13302 Mdot
.39048 .01968 Mdot
.39524 .00607 Mdot
.4 .19302 Mdot
.40476 .02412 Mdot
.40952 .02381 Mdot
.41429 .12339 Mdot
.41905 .14969 Mdot
.42857 .58862 Mdot
.43333 .23672 Mdot
.4381 .0268 Mdot
.44286 .05687 Mdot
.44762 .17683 Mdot
.45238 .01082 Mdot
.45714 .29612 Mdot
.4619 .0763 Mdot
.46667 .11442 Mdot
.47143 .02414 Mdot
.47619 .38615 Mdot
.48095 .18797 Mdot
.48571 .03191 Mdot
.49048 .22927 Mdot
.49524 .26946 Mdot
.5 .03222 Mdot
.50476 .02151 Mdot
.50952 .1378 Mdot
.51429 .31579 Mdot
.51905 .13548 Mdot
.52381 .0302 Mdot
.52857 .08271 Mdot
.53333 .01135 Mdot
.54286 .04924 Mdot
.54762 .06062 Mdot
.55238 .46216 Mdot
.55714 .08985 Mdot
.5619 .03162 Mdot
.56667 .05479 Mdot
.57143 .03141 Mdot
.57619 .21741 Mdot
.58095 .12922 Mdot
.58571 .21276 Mdot
.59048 .01971 Mdot
.59524 .04142 Mdot
.6 .0676 Mdot
.60476 .04764 Mdot
.60952 .01871 Mdot
.61429 .49139 Mdot
.61905 .33491 Mdot
.62381 .04776 Mdot
.62857 .00261 Mdot
.63333 .06618 Mdot
.6381 .0922 Mdot
.64286 .00088 Mdot
.64762 .4356 Mdot
.65238 .15754 Mdot
.65714 .03042 Mdot
.6619 .04029 Mdot
.66667 .18719 Mdot
.67143 .03001 Mdot
.67619 8e-05 Mdot
.68095 .15492 Mdot
.68571 .11666 Mdot
.69048 .12103 Mdot
.69524 .04996 Mdot
.7 .11643 Mdot
.70476 .11307 Mdot
.70952 .01515 Mdot
.71429 .0034 Mdot
.71905 .20453 Mdot
.72381 .31423 Mdot
.72857 .04477 Mdot
.73333 .13856 Mdot
.7381 .29068 Mdot
.74286 .02948 Mdot
.74762 .17225 Mdot
.75238 .14502 Mdot
.75714 .08062 Mdot
.7619 .01359 Mdot
.76667 .24095 Mdot
.77143 .24199 Mdot
.77619 .40444 Mdot
.78095 .14649 Mdot
.78571 .11025 Mdot
.79048 .26218 Mdot
.79524 .0724 Mdot
.8 .29665 Mdot
.80476 .10579 Mdot
.80952 .24753 Mdot
.81429 .01671 Mdot
.81905 .0738 Mdot
.82381 .15538 Mdot
.82857 .06249 Mdot
.83333 .03725 Mdot
.8381 .36348 Mdot
.84286 .00914 Mdot
.84762 .18751 Mdot
.85238 .02182 Mdot
.85714 .04157 Mdot
.8619 .41229 Mdot
.86667 .01038 Mdot
.87143 .19698 Mdot
.87619 .06462 Mdot
.88095 .31816 Mdot
.88571 .05096 Mdot
.89048 .44782 Mdot
.89524 .19521 Mdot
.9 .05811 Mdot
.90476 .52376 Mdot
.90952 .2311 Mdot
.91905 .10958 Mdot
.92381 .09978 Mdot
.92857 .10177 Mdot
.93333 .06079 Mdot
.9381 .26627 Mdot
.94286 .17114 Mdot
.94762 .11856 Mdot
.95238 .13792 Mdot
.95714 .05631 Mdot
.9619 .60291 Mdot
.96667 .10578 Mdot
.97143 .00174 Mdot
.97619 .22806 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00gooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool3o`0000kooooo000Tooooo`03o`000?oo
oooooooo00Wooooo0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00Gooooo0_l0
0005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo0_l0
0002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`009?ooool00ol0003oooooooooo`0T
ooooo`;o0000Coooool2o`0008oooooo0_l0000iooooo`009?ooool00ol0003oooooooooo`27oooo
o`;o00006?ooool2o`0006?ooooo0_l00006ooooo`;o0000<Oooool002Cooooo0_l00028ooooo`;o
00006?ooool2o`0003Sooooo0_l0000?ooooo`;o00008?ooool2o`00037ooooo000Tooooo`03o`00
0?oooooooooo0;[ooooo0_l0000Oooooo`;o00003oooool2o`0000oooooo0_l00012ooooo`009?oo
ool00ol0003oooooooooo`0=ooooo`;o0000I?ooool2o`0002?ooooo0_l0000Jooooo`;o00001?oo
ool2o`00047ooooo0_l0000:ooooo`;o0000=_ooool002Cooooo00?o0000ooooooooool03Oooool2
o`0006Cooooo0_l00003ooooo`?o00004_ooool2o`0000Wooooo0_l0000Jooooo`;o0000Doooool2
o`0003Kooooo000Tooooo`03o`000?oooooooooo04Sooooo0_l0000^ooooo`?o00002?ooool2o`00
00Sooooo0_l0002booooo`009?ooool2o`0003?ooooo1?l0000Booooo`?o00004Oooool2o`0002Go
oooo0_l0000Iooooo`;o00002oooool2o`000003ooooool0003o000001[ooooo0_l00002ooooo`;o
00005Oooool2o`0005[ooooo000Tooooo`03o`000?oooooooooo03;ooooo1?l0000Cooooo`;o0000
4Oooool2o`0003Cooooo0_l00003ooooo`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000
o`00000Jooooo`;o00000_ooool2o`0001Gooooo0_l0001Jooooo`009?ooool00ol0003ooooooooo
o`0Vooooo`;o0000J_ooool2o`0000?ooooo0_l0001Zooooo`;o0000??ooool002Cooooo00?o0000
ooooooooool09_ooool2o`0002Kooooo0_l0001kooooo`;o0000=_ooool2o`0003cooooo000Toooo
o`03o`000?oooooooooo04kooooo0_l0001Vooooo`;o00004oooool2o`0003gooooo0_l0000eoooo
o`009?ooool2o`000;Oooooo0_l0000Yooooo`;o00009oooool2o`0003Gooooo000Tooooo`03o`00
0?oooooooooo01?ooooo1?l00006ooooo`;o0000Q_ooool2o`0001;ooooo0_l00004ooooo`;o0000
5Oooool2o`0000Wooooo0_l0001Nooooo`009?ooool00ol0003oooooooooo`0Cooooo`Co00000ooo
ool2o`000003ooooool0003o000003oooooo0_l00015ooooo`;o00004_ooool2o`0000Cooooo0_l0
000Eooooo`;o0000??ooool2o`0002_ooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000D
ooooo`;o0000<Oooool2o`0000oooooo0_l0001<ooooo`;o0000I_ooool2o`0001Gooooo0_l0000D
ooooo`009?ooool00ol0003oooooooooo`04ooooo`;o00006_ooool2o`0000Oooooo0_l0000Doooo
o`;o00003?ooool2o`0003Gooooo0_l0000Vooooo`;o0000J_ooool2o`00017ooooo0_l0000Doooo
o`009?ooool2o`00017ooooo0_l0000>ooooo`;o00001oooool2o`0000gooooo0_l00005ooooo`;o
0000@oooool2o`00023ooooo0_l0001Iooooo`;o00005Oooool2o`0000Wooooo0_l0000Looooo`00
9?ooool00ol0003oooooooooo`0@ooooo`;o00009_ooool2o`0000_ooooo0_l0001Oooooo`;o0000
FOooool2o`0000kooooo0_l0000@ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0;?oo
ool2o`0000kooooo0_l00007ooooo`;o0000L?ooool2o`0000Wooooo0_l0001=ooooo`;o0000;_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0/ooooo`;o00003_ooool2o`0007Wo
oooo0_l00009ooooo`;o0000OOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0m_ooool2o`0000Kooooo0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
08[ooooo0_l0001Zooooo`;o00001_ooool2o`00047ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01;ooooo0_l0000Sooooo`;o00002Oooool2o`0004Kooooo0_l0001Nooooo`;o
0000EOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Booooo`;o
00008oooool2o`0000Wooooo0_l0001Looooo`;o0000B?ooool2o`0005Gooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0:3ooooo0_l0002Oooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05?ooooo0_l0001Dooooo`;o0000U_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000E?oo
ool2o`0005Cooooo0_l0000Hooooo`;o0000O?ooool002Cooooo00?o0000ooooooooool01oooool2
o`000;[ooooo0_l0001looooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000oooooolioooo
o`009?ooool00ol0003oooooooooo`0?ooooo`;o00006_ooool2o`0004?ooooo0_l0002^ooooo`Co
00007Oooool002Cooooo00?o0000ooooooooool03oooool2o`0001[ooooo0_l0000Iooooo`;o0000
:?ooool2o`0008Oooooo0_l0000Uooooo`Co00002_ooool2o`00017ooooo000Tooooo`03o`000?oo
oooooooo01Kooooo0_l0000^ooooo`;o0000/Oooool2o`0003?ooooo0_l0000Aooooo`009?ooool2
o`0001Oooooo0_l0003Kooooo`;o0000:_ooool2o`00023ooooo000Tooooo`03o`000?oooooooooo
03Gooooo0_l0001Eooooo`;o0000Boooool2o`0001Sooooo0_l0000Zooooo`;o00008?ooool002Co
oooo00Co0000oooooooooooooooo0_l0000booooo`;o0000EOooool2o`0004Gooooo0_l00003oooo
o`?o0000I_ooool002Cooooo00Co0000oooooooooooooooo0_l0003@ooooo`?o00000_ooool2o`00
04kooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`0aooooo`;o0000;oooool2o`0001Oo
oooo0_l0001Gooooo`;o0000D_ooool2o`0001Oooooo000Tooooo`;o0000;oooool2o`000003oooo
ool0003o000002Oooooo0_l00006ooooo`;o00005oooool2o`000<Cooooo000Tooooo`03o`000?oo
oooooooo01kooooo0_l0000>ooooo`;o00008?ooool2o`0000Sooooo0_l0001Eooooo`;o0000S_oo
ool002Cooooo00?o0000ooooooooool01Oooool2o`0001Oooooo0_l0000`ooooo`;o00008?ooool2
o`0003gooooo0_l0002>ooooo`009?ooool00ol0003oooooooooo`05ooooo`;o0000COooool2o`00
01cooooo0_l0000Yooooo`;o0000X_ooool002Cooooo00?o0000ooooooooool0E?ooool2o`0004Co
oooo0_l000000ooooooo0000o`000013ooooo`;o0000AOooool2o`0001Kooooo000Tooooo`;o0000
Voooool2o`0004Kooooo0_l00015ooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0jOoo
ool2o`0005Kooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0>Wooooo0_l00007ooooo`;o0000
COooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo07cooooo0_l0001dooooo`;o0000COooool000Wooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool2o`0003gooooo0_l0001Cooooo`;o0000K_ooool000Wooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000mooooo`;o0000ROooool2o`0000Oooooo
0_l0000]ooooo`;o0000?oooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`38ooooo`;o0000=_ooool2o`0003oo
oooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@_ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
0_l0001[ooooo`;o0000Noooool2o`0003gooooo0_l0000Iooooo`009?ooool00ol0003ooooooooo
o`1Zooooo`;o0000Noooool2o`0003gooooo0_l0000Iooooo`009?ooool00ol0003oooooooooo`26
ooooo`;o0000^Oooool002Cooooo00?o0000ooooooooool0DOooool2o`00017ooooo0_l0000Poooo
o`;o0000^Oooool002Cooooo00?o0000ooooooooool0DOooool2o`00017ooooo0_l0003Kooooo`00
9?ooool2o`00063ooooo0_l0000_ooooo`;o0000>oooool2o`0003Sooooo0_l0000hooooo`009?oo
ool00ol0003oooooooooo`1Oooooo`;o0000;oooool2o`0003_ooooo0_l0000hooooo`;o0000>?oo
ool002Cooooo00?o0000ooooooooool0M_ooool2o`0009oooooo0_l0000Xooooo`009?ooool00ol0
003oooooooooo`1fooooo`;o0000Uoooool2o`0000Kooooo0_l0000Xooooo`009?ooool00ol0003o
ooooooooo`0Wooooo`;o0000;Oooool2o`000;Oooooo0_l0000`ooooo`009?ooool2o`0002Sooooo
0_l0000]ooooo`;o0000jOooool002Cooooo00?o0000ooooooooool0g_ooool2o`00067ooooo000T
ooooo`03o`000?oooooooooo0=kooooo0_l0001Qooooo`009?ooool00ol0003oooooooooo`10oooo
o`;o000000?oooooo`000?l00000KOooool2o`0008gooooo000Tooooo`03o`000?oooooooooo043o
oooo0_l000000ooooooo0000o`00001]ooooo`;o0000SOooool002Cooooo0_l0000Iooooo`;o0000
COooool2o`0004Kooooo0_l0002@ooooo`009?ooool00ol0003oooooooooo`0Hooooo`;o0000COoo
ool2o`0004Kooooo0_l0002@ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3ooooood;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
oc;ooooo0_l0000>ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Dooooo`;o
0000QOooool2o`0001Cooooo0_l0000>ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0009Cooooo
0_l00025ooooo`;o00009?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000D?ooool2o`000;kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02oooooo0_l0000Xooooo`;o00009_ooool2o`0006[ooooo0_l0001Booooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Wooooo0_l0002Booooo`Co0000D?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0>oooooo0_l0000:ooooo`;o0000A?ooool002Cooooo0_l0003looooo`;o0000A?ooool002Cooooo
00?o0000ooooooooool0Joooool2o`000=Cooooo000Tooooo`03o`000?oooooooooo06_ooooo0_l0
003Dooooo`009?ooool00ol0003oooooooooo`1Xooooo`;o0000eoooool002Cooooo00?o0000oooo
ooooool0J?ooool2o`0008_ooooo0_l0001:ooooo`009?ooool2o`000?Kooooo0_l0001:ooooo`00
9?ooool00ol0003oooooooooo`3oooooobKooooo0_l0000Jooooo`009?ooool00ol0003ooooooooo
o`0Sooooo`;o0000L?ooool2o`0008kooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`0S
ooooo`;o0000L?ooool2o`000:[ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3Tooooo`;o0000Foooool0
02Cooooo00?o0000ooooooooool0i?ooool2o`0005_ooooo000Tooooo`;o0000R_ooool2o`0006go
oooo0_l00017ooooo`009?ooool00ol0003oooooooooo`29ooooo`;o0000KOooool2o`0004Oooooo
000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3Oooooo`;o0000H?ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Kooooo`;o0000@_ooool2o`00037ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09_ooooo0_l0001eooooo`;o0000;Oooool001[ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`0Qooooo`;o0000:?ooool2o`000?Cooooo000Tooooo`03o`000?oo
oooooooo027ooooo0_l0000Xooooo`;o0000m?ooool002Cooooo00Co0000ooooool0003o0000_?oo
ool2o`0008;ooooo000Tooooo`04o`000?oooooo0000o`000;cooooo0_l00022ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3oooooo`Gooooo0_l0000kooooo`00
9?ooool00ol0003oooooooooo`3oooooo`Gooooo0_l0000kooooo`009?ooool00ol0003ooooooooo
o`1Qooooo`;o0000g_ooool002Cooooo0_l0001Rooooo`;o0000g_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2oooo
o`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo08oooooo0_l0002`ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0008oooooo0_l0002`ooooo`001?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo0_l0003aooooo`;o0000Coooool002Cooooo00?o0000oooo
ooooool0KOooool2o`00087ooooo0_l0001?ooooo`009?ooool00ol0003oooooooooo`1]ooooo`;o
0000d_ooool002Cooooo00?o0000ooooooooool0ooooool=ooooo`;o0000<oooool002Cooooo00?o
0000ooooooooool0ooooool=ooooo`;o0000<oooool002Cooooo0_l0000;ooooo`;o0000oooooolf
ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000oooooolfooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000<Sooooo0_l0001hooooo`009?ooool00ol0
003oooooooooo`1^ooooo`;o0000Eoooool2o`0007Sooooo000Tooooo`03o`000?oooooooooo06ko
oooo0_l0003Aooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo03[ooooo0_l0003Iooooo`;o0000:_ooool002Cooooo0_l0000kooooo`;o00006oooool2
o`000;cooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`1Gooooo`;o0000j?ooool000[o
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:Sooooo
0_l0002Gooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002Xooooo`;o0000Uoooool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2oooo
o`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo00;ooooo0_l0003oooooockooooo000Tooooo`03o`000?oooooooooo
00;ooooo0_l0003oooooockooooo000Tooooo`03o`000?oooooooooo0;cooooo0_l00023ooooo`00
9?ooool2o`000;gooooo0_l00023ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooooa_o
oooo0_l0000Uooooo`009?ooool2o`000?oooooo7?ooool2o`0002Gooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004oooo
o`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00
000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool03?ooool2o`000?oooooo=?oo
ool002Cooooo0_l0000=ooooo`;o0000ooooooldooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000P?ooool2o`000<3ooooo000Tooooo`03o`000?oooooooooo
07oooooo0_l00030ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2
o`000?oooooo;_ooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo0?oooooo;Oooool2o`00
01?ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000oooooom2ooooo`007?ooool00omgMgOoIVIVooooo`3ooooood[ooooo000Moooo
o`03o`000?oooooooooo0?ooooooBOooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooo
od_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .21575 Mdot
.0381 .2605 Mdot
.04286 .52042 Mdot
.04762 .06308 Mdot
.05238 .13308 Mdot
.05714 .01155 Mdot
.0619 .09772 Mdot
.06667 .26068 Mdot
.07143 .43983 Mdot
.07619 .02252 Mdot
.08095 .11097 Mdot
.08571 .06192 Mdot
.09048 .07843 Mdot
.09524 .05427 Mdot
.1 .08628 Mdot
.10476 .05786 Mdot
.10952 .39306 Mdot
.11429 .05114 Mdot
.11905 .00016 Mdot
.12381 .2957 Mdot
.12857 .12846 Mdot
.13333 .06548 Mdot
.1381 .21798 Mdot
.14286 .32602 Mdot
.14762 .00584 Mdot
.15238 .25418 Mdot
.15714 .08683 Mdot
.1619 .05948 Mdot
.16667 .25882 Mdot
.17143 .06787 Mdot
.17619 .09642 Mdot
.18095 .0526 Mdot
.18571 .13321 Mdot
.19048 .0296 Mdot
.19524 .12317 Mdot
.2 .12473 Mdot
.20476 .12742 Mdot
.20952 .0601 Mdot
.21429 .35313 Mdot
.21905 .06764 Mdot
.22381 .1522 Mdot
.22857 .08348 Mdot
.23333 .46725 Mdot
.2381 .15917 Mdot
.24286 .08612 Mdot
.24762 .06549 Mdot
.25238 .10555 Mdot
.25714 .06717 Mdot
.2619 .02913 Mdot
.26667 .1882 Mdot
.27143 .12777 Mdot
.27619 .02186 Mdot
.28095 .12901 Mdot
.28571 .11225 Mdot
.29048 .0895 Mdot
.29524 .13913 Mdot
.3 .0563 Mdot
.30476 .42305 Mdot
.30952 .11761 Mdot
.31429 .00307 Mdot
.31905 .07373 Mdot
.32381 .05304 Mdot
.32857 .18849 Mdot
.33333 .51364 Mdot
.3381 .20723 Mdot
.34286 .14892 Mdot
.34762 .00251 Mdot
.35238 .21888 Mdot
.35714 .38915 Mdot
.3619 .38242 Mdot
.36667 .14378 Mdot
.37143 .20851 Mdot
.37619 .26784 Mdot
.38095 .10113 Mdot
.38571 .13302 Mdot
.39048 .16006 Mdot
.39524 .11794 Mdot
.4 .14749 Mdot
.40476 .15322 Mdot
.40952 .21068 Mdot
.41429 .12339 Mdot
.41905 .06074 Mdot
.42857 .15994 Mdot
.43333 .17703 Mdot
.4381 .10275 Mdot
.44286 .09311 Mdot
.44762 .16083 Mdot
.45238 .01082 Mdot
.45714 .28899 Mdot
.4619 .0882 Mdot
.46667 .11442 Mdot
.47143 .02414 Mdot
.47619 .56196 Mdot
.48095 .31548 Mdot
.48571 .40171 Mdot
.49048 .22927 Mdot
.49524 .49147 Mdot
.5 .03222 Mdot
.50476 .03571 Mdot
.50952 .12173 Mdot
.51429 .21266 Mdot
.51905 .22575 Mdot
.52381 .09109 Mdot
.52857 .11905 Mdot
.53333 .01135 Mdot
.54286 .1662 Mdot
.54762 .21951 Mdot
.55238 .28524 Mdot
.55714 .05476 Mdot
.5619 .00734 Mdot
.56667 .18182 Mdot
.57143 .03141 Mdot
.57619 .21741 Mdot
.58095 .13756 Mdot
.58571 .2764 Mdot
.59048 .03762 Mdot
.59524 .17721 Mdot
.6 .0676 Mdot
.60476 .04764 Mdot
.60952 .02728 Mdot
.61429 .46912 Mdot
.61905 .30347 Mdot
.62381 .04776 Mdot
.62857 .09263 Mdot
.63333 .26418 Mdot
.6381 .32071 Mdot
.64286 .00088 Mdot
.64762 .43162 Mdot
.65238 .19135 Mdot
.65714 .03042 Mdot
.6619 .04029 Mdot
.66667 .17965 Mdot
.67143 .0351 Mdot
.67619 8e-05 Mdot
.68095 .07895 Mdot
.68571 .11666 Mdot
.69048 .02428 Mdot
.69524 .06798 Mdot
.7 .11643 Mdot
.70476 .10525 Mdot
.70952 .04471 Mdot
.71429 .0034 Mdot
.71905 .16516 Mdot
.72381 .10112 Mdot
.72857 .04477 Mdot
.73333 .21805 Mdot
.7381 .13363 Mdot
.74286 .02948 Mdot
.74762 .17225 Mdot
.75238 .02339 Mdot
.75714 .19023 Mdot
.7619 .04984 Mdot
.76667 .01641 Mdot
.77143 .02555 Mdot
.77619 .23602 Mdot
.78095 .08525 Mdot
.78571 .07094 Mdot
.79048 .05512 Mdot
.79524 .0724 Mdot
.8 .29665 Mdot
.80476 .10579 Mdot
.80952 .34897 Mdot
.81429 .01671 Mdot
.81905 .14674 Mdot
.82381 .12294 Mdot
.82857 .15674 Mdot
.83333 .12505 Mdot
.8381 .20366 Mdot
.84286 .19693 Mdot
.84762 .21835 Mdot
.85238 .02182 Mdot
.85714 .1014 Mdot
.8619 .39811 Mdot
.86667 .07568 Mdot
.87143 .27715 Mdot
.87619 .06462 Mdot
.88095 .38942 Mdot
.88571 .03021 Mdot
.89048 .43939 Mdot
.89524 .13348 Mdot
.9 .06387 Mdot
.90476 .46642 Mdot
.90952 .06193 Mdot
.91905 .26759 Mdot
.92381 .09978 Mdot
.92857 .21623 Mdot
.93333 .00155 Mdot
.9381 .25638 Mdot
.94286 .34509 Mdot
.94762 .0217 Mdot
.95238 .13792 Mdot
.95714 .0851 Mdot
.9619 .60291 Mdot
.96667 .02638 Mdot
.97143 .00174 Mdot
.97619 .41853 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool2o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o00002Oooool2o`0000?ooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`0000_ooooo
0ol0000>ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo0_l00009ooooo`;o00000_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0ol0
000;ooooo`?o00003_ooool002Cooooo00?o0000ooooooooool09?ooool2o`0008Gooooo0_l0002D
ooooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000O_ooool2o`0001Sooooo0_l00008oooo
o`;o0000U?ooool002Cooooo0_l00008ooooo`;o0000O_ooool2o`0001Sooooo0_l0002Nooooo`00
9?ooool00ol0003oooooooooo`3]ooooo`;o00003_ooool2o`0004;ooooo000Tooooo`03o`000?oo
oooooooo00gooooo0_l0000oooooo`;o0000WOooool2o`0000kooooo0_l0000:ooooo`;o00007Ooo
ool2o`0001Oooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0000oooooo`;o0000?Oooool2
o`0004Gooooo0_l0000Cooooo`;o00001?ooool2o`0001Sooooo0_l0000Mooooo`;o00005oooool0
02Cooooo00?o0000ooooooooool0SOooool2o`0002_ooooo0_l0000Hooooo`;o00004oooool2o`00
00Cooooo0_l0000mooooo`;o00004Oooool002Cooooo0_l0000cooooo`;o00005Oooool2o`0006?o
oooo0_l0000:ooooo`;o00003_ooool2o`0001Wooooo0_l0000]ooooo`;o00006?ooool2o`00017o
oooo000Tooooo`03o`000?oooooooooo03;ooooo0_l0000Eooooo`;o0000C?ooool2o`0001Gooooo
0_l0000Jooooo`;o00006Oooool2o`0002gooooo0_l0000[ooooo`009?ooool00ol0003ooooooooo
o`2Gooooo`?o00006_ooool2o`0001Sooooo0_l0001aooooo`009?ooool00ol0003oooooooooo`2H
ooooo`;o00006_ooool2o`0001Gooooo0_l000000ooooooo0000o`00001aooooo`009?ooool00ol0
003oooooooooo`3;ooooo`;o0000M?ooool002Cooooo0_l0003Looooo`;o00001?ooool2o`0005ko
oooo000Tooooo`03o`000?oooooooooo0;Wooooo0_l00004ooooo`;o00006_ooool2o`0000Cooooo
0_l00009ooooo`;o0000Doooool002Cooooo00?o0000ooooooooool06_ooool2o`0001?ooooo0_l0
000]ooooo`;o0000FOooool2o`0000Cooooo0_l0000[ooooo`;o0000Doooool002Cooooo00?o0000
ooooooooool04oooool2o`0000Gooooo0_l0000Cooooo`;o00009Oooool2o`0000Kooooo0_l00019
ooooo`;o0000B_ooool2o`0004[ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o0000:oooool2o`00057ooooo0_l0001:ooooo`;o0000B_ooool002Co
oooo0_l0000Aooooo`;o00001?ooool2o`00017ooooo0_l0000=ooooo`;o0000@_ooool2o`0009go
oooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0000kooooo
0_l0000Fooooo`;o00002oooool2o`0003Gooooo0_l0002Cooooo`;o00001Oooool2o`000003oooo
ool0003o000002Cooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000Jooooo`;o00002_oo
ool2o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l00000KOooool2o`0001gooooo0_l0
000iooooo`;o00001Oooool2o`0002Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0;?ooool2o`0000kooooo0_l0000:ooooo`;o0000KOooool2o`0001gooooo0_l0000Kooooo`;o
0000C?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0G?ooool2
o`0009Gooooo0_l000000ooooooo0000o`000019ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
05cooooo0_l0002Hooooo`;o00005_ooool2o`00037ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01;ooooo0_l0002mooooo`;o0000>oooool2o`00037ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`0002_ooooo0_l0002@ooooo`;o
0000K_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool2o`00013ooooo
0_l0000Fooooo`;o00000_ooool2o`000:gooooo0_l0000gooooo`;o00005?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool2o`0001[ooooo0_l0000>oooo
o`;o0000=Oooool2o`0006Kooooo0_l0000gooooo`;o00005?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000E?oo
ool2o`0002oooooo0_l00004ooooo`;o00004_ooool2o`00023ooooo0_l0001oooooo`009?ooool0
0ol0003oooooooooo`0^ooooo`;o0000E?ooool2o`0001Sooooo0_l0000Pooooo`;o0000Ooooool0
02Cooooo00?o0000ooooooooool02Oooool2o`0002?ooooo0_l0003ooooooa;ooooo000Tooooo`03
o`000?oooooooooo00Wooooo0_l0001Uooooo`;o0000KOooool2o`0002Wooooo0_l0000Dooooo`;o
00007oooool002Cooooo00?o0000ooooooooool0A_ooool2o`0002Sooooo0_l0000Aooooo`;o0000
E?ooool2o`0000Cooooo0_l0000Hooooo`;o00003oooool2o`0001Cooooo0_l0000Oooooo`009?oo
ool00ol0003oooooooooo`16ooooo`;o0000>oooool2o`0005Cooooo0_l0000Nooooo`;o0000A_oo
ool002Cooooo0_l0000@ooooo`;o0000oooooolaooooo`009?ooool00ol0003oooooooooo`0?oooo
o`;o0000@?ooool2o`0003Wooooo0_l0002cooooo`009?ooool00ol0003oooooooooo`1Aooooo`;o
00001_ooool2o`0001[ooooo0_l0000Eooooo`;o0000AOooool2o`0000?ooooo0_l0001Wooooo`00
9?ooool00ol0003oooooooooo`1Iooooo`;o00006_ooool2o`0002Wooooo0_l0000aooooo`;o0000
0oooool2o`0006Oooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l00015ooooo`;o00007Ooo
ool2o`0000Cooooo0_l0001Nooooo`;o0000?oooool002Cooooo0_l0000eooooo`?o0000A?ooool2
o`0001gooooo0_l0001Tooooo`;o000000?oooooo`000?l00000??ooool002Cooooo00?o0000oooo
ooooool07_ooool2o`0001Gooooo1?l0000Dooooo`;o000000?oooooo`000?l00000/Oooool2o`00
03cooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0000Gooooo`;o00004Oooool2o`0000Co
oooo0_l0000Dooooo`;o000000?oooooo`000?l000008?ooool2o`000:?ooooo0_l0000Xooooo`00
9?ooool00ol0003oooooooooo`05ooooo`;o0000:_ooool2o`0003oooooo0_l0001`ooooo`;o0000
<Oooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo05Cooooo0_l0001Kooooo`;o0000<Ooo
ool2o`0004?ooooo0_l0000Fooooo`009?ooool2o`0005Gooooo0_l0001Kooooo`;o0000M_ooool2
o`0001Kooooo000Tooooo`03o`000?oooooooooo06_ooooo0_l0003Dooooo`002Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1Tooooo`;o00001Oooool2o`0000Wooooo0_l00026ooooo`;o0000@Oooool0
00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo06Cooooo0_l0000@ooooo`;o0000Q_ooool2o`00047ooooo0009oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03gooooo0_l0000iooooo`;o0000aoooool000Wooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000mooooo`;o0000>Oooool2o`0008Oooooo0_l0000n
ooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo04;ooooo0_l0000_ooooo`;o00002_ooool2o`0000Gooooo0_l0
001iooooo`;o0000?_ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0@_ooool2o`0002oooooo0_l0000:ooooo`;o00001Ooo
ool2o`000;Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0:Gooooo0_l0000gooooo`;o0000HOooool000Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2Uooooo`;o0000=ooo
ool2o`00067ooooo000Tooooo`;o0000j?ooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo
0>Oooooo0_l0001Hooooo`009?ooool00ol0003oooooooooo`21ooooo`;o0000<oooool2o`0001Go
oooo0_l0001booooo`009?ooool00ol0003oooooooooo`21ooooo`;o0000:Oooool2o`0000Sooooo
0_l0000Eooooo`;o0000L_ooool002Cooooo00?o0000ooooooooool0[?ooool2o`0009?ooooo000T
ooooo`;o0000C?ooool2o`0001;ooooo0_l0003Pooooo`009?ooool00ol0003oooooooooo`1;oooo
o`;o00004_ooool2o`0006Oooooo0_l0000Pooooo`;o0000EOooool002Cooooo00?o0000oooooooo
ool0b?ooool2o`00023ooooo0_l0001Eooooo`009?ooool00ol0003oooooooooo`3oooooo`Oooooo
0_l0000iooooo`009?ooool00ol0003oooooooooo`3oooooo`Oooooo0_l0000iooooo`009?ooool2
o`000?oooooo1_ooool2o`0003_ooooo000Tooooo`03o`000?oooooooooo06;ooooo0_l0002Poooo
o`;o0000>oooool002Cooooo00?o0000ooooooooool0H_ooool2o`0000Wooooo0_l0003Booooo`00
9?ooool00ol0003oooooooooo`1]ooooo`;o00002_ooool2o`00023ooooo0_l0002Tooooo`009?oo
ool01?l0003oooooo`000?l0001hooooo`;o00008?ooool2o`0008Gooooo0_l0000Mooooo`009?oo
ool4o`00023ooooo0_l00014ooooo`;o0000?Oooool2o`0000Oooooo0_l0000aooooo`;o00008ooo
ool2o`0001Wooooo0_l0000Mooooo`009?ooool00ol0003oooooooooo`0Qooooo`;o0000A?ooool2
o`0003gooooo0_l00007ooooo`;o0000<Oooool2o`0002?ooooo0_l0000hooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Mooooo`;o0000X_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo09gooooo0_l0002Rooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2Dooooo`;o0000Zoooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002Dooooo`;o0000Zoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3`ooooo`;o0000Coooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0l?ooool2
o`0004oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`0Vooooo`;o0000oOooool2o`0001[ooooo000Toooo
o`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o0000n?ooool2o`0001[ooooo000Tooooo`04
o`000?ooooooooooooooo`;o00001oooool2o`0001oooooo0_l0003ooooooaGooooo000Tooooo`;o
00000_ooool2o`0000Oooooo0_l0002fooooo`;o0000OOooool002Cooooo00?o0000ooooooooool0
K_ooool2o`0005;ooooo0_l0001Kooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0K_oo
ool2o`000:oooooo0_l0000Pooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0;;ooooo0_l0001Kooooo`;o0000<?ooool002Cooooo0_l0002cooooo`;o
0000Foooool2o`00033ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0Z?ooool2o`0009Oooooo000Tooooo`03o`000?oooooooooo08Wooooo0_l0000M
ooooo`;o0000Uoooool002Cooooo00?o0000ooooooooool0ROooool2o`000;Kooooo000Tooooo`;o
00007_ooool2o`000=Wooooo0_l00017ooooo`009?ooool00ol0003oooooooooo`0Mooooo`;o0000
fOooool2o`0004Oooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0_Oooool2
o`0008;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0_Oooool2o`00
08;ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0003ooooood;ooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0T?ooool2o`000:oooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0T?ooool2o`000:oooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0`oooool2o`0007cooooo000Jooooo`03oeEEEOmVIVKo0000
00Oooooo00?o0000ooooooooool0`oooool2o`0007cooooo000Tooooo`;o00009?ooool2o`000?oo
oooo7Oooool002Cooooo00?o0000ooooooooool08oooool2o`000?oooooo7Oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo9oooool2o`0001Wooooo000Tooooo`03o`000?oooooooooo0?_ooooo0_l0
000Yooooo`;o00006Oooool002Cooooo00?o0000ooooooooool0noooool2o`0004Cooooo000Toooo
o`03o`000?oooooooooo03[ooooo0_l0003oooooo`Kooooo000Tooooo`;o0000>oooool2o`000?oo
oooo1_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Zooooo`;o0000eOooool000Cooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0J_ooool2o`000=Gooooo0004ooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000J?ooool2o`000:Sooooo0_l0000]
ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06Sooooo0_l0002Xooooo`;o0000;Oooool0
00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06?ooool2o`000?oooooo:?ooool000Cooooo00?o0000oooooooo
ool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Hooooo`;o0000l_ooool2o`0003?ooooo0002ooooo`03oeEEEOmVIVKo000000co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`2Boooo
o`;o0000N?ooool2o`0003?ooooo000Tooooo`;o0000Toooool2o`000:gooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooooc?ooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`1Gooooo`;o0000
f?ooool2o`0000kooooo000Tooooo`03o`000?oooooooooo05Oooooo0_l0003Xooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0<Oooooo0_l0001hoooo
o`009?ooool2o`000<Sooooo0_l0001hooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo00cooooo0_l0003oooooo`Sooooo0_l0000Zooooo`009?ooool0
0ol0003oooooooooo`0<ooooo`;o0000ooooool8ooooo`;o0000:_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom2ooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0003ooooooa_ooooo0_l0000Uooooo`003?ooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`10ooooo`;o0000N_ooool2o`00
05cooooo0_l0000Uooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@?ooool2o`0007[ooooo0_l00023ooooo`003?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`002_oo
ool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`2Eooooo`;o0000Z_ooool002Cooooo0_l0002Fooooo`;o0000Z_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0HOooool2o`00
0=kooooo000Tooooo`03o`000?oooooooooo067ooooo0_l0003Nooooo`009?ooool00ol0003ooooo
ooooo`02ooooo`;o0000oooooolnooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000oooo
oolnooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000Co
oooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004oooo
o`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`2?ooooo`;o0000/?ooool002Cooooo00?o0000ooooooooool0Sooo
ool2o`000;3ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo;_ooool2o`0001?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo;Oooool2o`0001?ooooo000Iooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooom2
ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?ooool00omgMgOo
IVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wooooo00Go
0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .51793 Mdot
.03333 .31098 Mdot
.0381 .22596 Mdot
.04286 .42041 Mdot
.04762 .03672 Mdot
.05238 .13308 Mdot
.05714 .22223 Mdot
.0619 .01708 Mdot
.06667 .05535 Mdot
.07143 .26679 Mdot
.07619 .17225 Mdot
.08095 .11097 Mdot
.08571 .05784 Mdot
.09048 .07843 Mdot
.09524 .05427 Mdot
.1 .05348 Mdot
.10476 .05786 Mdot
.10952 .10941 Mdot
.11429 .00345 Mdot
.11905 .00016 Mdot
.12381 .05928 Mdot
.12857 .04106 Mdot
.13333 .06548 Mdot
.1381 .26508 Mdot
.14286 .28637 Mdot
.14762 .00662 Mdot
.15238 .31802 Mdot
.15714 .03189 Mdot
.1619 .05948 Mdot
.16667 .15465 Mdot
.17143 .06787 Mdot
.17619 .09642 Mdot
.18095 .0526 Mdot
.18571 .05209 Mdot
.19048 .0296 Mdot
.19524 .12317 Mdot
.2 .12473 Mdot
.20476 .02476 Mdot
.20952 .16423 Mdot
.21429 .34376 Mdot
.21905 .01184 Mdot
.22381 .20404 Mdot
.22857 .07487 Mdot
.23333 .22697 Mdot
.2381 .12697 Mdot
.24286 .12613 Mdot
.24762 .24174 Mdot
.25238 .31508 Mdot
.25714 .06717 Mdot
.2619 .06733 Mdot
.26667 .39132 Mdot
.27143 .11999 Mdot
.27619 .02186 Mdot
.28095 .13821 Mdot
.28571 .11225 Mdot
.29048 .1013 Mdot
.29524 .13913 Mdot
.3 .08649 Mdot
.30476 .42305 Mdot
.30952 .11761 Mdot
.31429 .0758 Mdot
.31905 .16795 Mdot
.32381 .05174 Mdot
.32857 .35804 Mdot
.33333 .47875 Mdot
.3381 .02282 Mdot
.34286 .06973 Mdot
.34762 .00251 Mdot
.35238 .0707 Mdot
.35714 .31606 Mdot
.3619 .37212 Mdot
.36667 .22485 Mdot
.37143 .33679 Mdot
.37619 .26784 Mdot
.38095 .08022 Mdot
.38571 .0949 Mdot
.39048 .10298 Mdot
.39524 .14057 Mdot
.4 .06037 Mdot
.40476 .15034 Mdot
.40952 .27811 Mdot
.41429 .12339 Mdot
.41905 .03822 Mdot
.42857 .19668 Mdot
.43333 .17703 Mdot
.4381 .34132 Mdot
.44286 .19355 Mdot
.44762 .1005 Mdot
.45238 .01082 Mdot
.45714 .06387 Mdot
.4619 .0882 Mdot
.46667 .10467 Mdot
.47143 .03881 Mdot
.47619 .56517 Mdot
.48095 .31548 Mdot
.48571 .3154 Mdot
.49048 .25568 Mdot
.49524 .30702 Mdot
.5 .05509 Mdot
.50476 .03571 Mdot
.50952 .09416 Mdot
.51429 .29418 Mdot
.51905 .03038 Mdot
.52381 .09109 Mdot
.52857 .11905 Mdot
.53333 .01135 Mdot
.5381 .49146 Mdot
.54286 .06801 Mdot
.54762 .05686 Mdot
.55238 .21156 Mdot
.55714 .05476 Mdot
.5619 .00734 Mdot
.56667 .31978 Mdot
.57143 .03141 Mdot
.57619 .06248 Mdot
.58095 .15602 Mdot
.58571 .34625 Mdot
.59048 .03762 Mdot
.59524 .20315 Mdot
.6 .25244 Mdot
.60476 .11019 Mdot
.60952 .02728 Mdot
.61429 .51222 Mdot
.61905 .10458 Mdot
.62381 .04776 Mdot
.62857 .09263 Mdot
.63333 .52141 Mdot
.6381 .22298 Mdot
.64286 .00088 Mdot
.64762 .29643 Mdot
.65238 .19908 Mdot
.65714 .03248 Mdot
.6619 .04029 Mdot
.66667 .02836 Mdot
.67143 .0351 Mdot
.67619 .04851 Mdot
.68095 .07937 Mdot
.68571 .0273 Mdot
.69048 .02428 Mdot
.69524 .17638 Mdot
.7 .11643 Mdot
.70476 .10525 Mdot
.70952 .08163 Mdot
.71429 .02217 Mdot
.71905 .03189 Mdot
.72381 .10112 Mdot
.72857 .04477 Mdot
.73333 .13859 Mdot
.7381 .13363 Mdot
.74286 .0663 Mdot
.74762 .21778 Mdot
.75238 .12555 Mdot
.75714 .13938 Mdot
.7619 .19326 Mdot
.76667 .02945 Mdot
.77143 .02555 Mdot
.77619 .23602 Mdot
.78095 .0078 Mdot
.78571 .07094 Mdot
.79048 .05512 Mdot
.79524 .21935 Mdot
.8 .15113 Mdot
.80476 .2295 Mdot
.80952 .33408 Mdot
.81429 .01671 Mdot
.81905 .0537 Mdot
.82381 .12294 Mdot
.82857 .19732 Mdot
.83333 .21074 Mdot
.8381 .05464 Mdot
.84286 .18224 Mdot
.84762 .41619 Mdot
.85238 .02182 Mdot
.85714 .03236 Mdot
.8619 .3084 Mdot
.86667 .11722 Mdot
.87143 .12758 Mdot
.87619 .08421 Mdot
.88095 .40219 Mdot
.88571 .06818 Mdot
.89048 .43939 Mdot
.89524 .13348 Mdot
.9 .06387 Mdot
.90476 .34204 Mdot
.90952 .19014 Mdot
.91429 .57735 Mdot
.91905 .21565 Mdot
.92381 .09978 Mdot
.92857 .25926 Mdot
.93333 .00155 Mdot
.9381 .29704 Mdot
.94286 .4503 Mdot
.94762 .03479 Mdot
.95238 .00598 Mdot
.95714 .12781 Mdot
.9619 .48956 Mdot
.96667 .18418 Mdot
.97143 .11231 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool2o`0000kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`?o00003Oooool00ol0003ooooo
ooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0ol0
0007ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l00025
ooooo`;o0000AOooool2o`0003Gooooo0_l0000Fooooo`009?ooool00ol0003oooooooooo`0loooo
o`;o0000BOooool2o`0001Sooooo0_l00008ooooo`;o0000AOooool2o`0004gooooo000Tooooo`;o
0000?Oooool2o`0004Wooooo0_l0000Hooooo`;o0000W_ooool002Cooooo00?o0000ooooooooool0
2Oooool2o`000?;ooooo0_l00012ooooo`009?ooool00ol0003oooooooooo`09ooooo`;o0000@ooo
ool2o`0008cooooo0_l0000Oooooo`;o00002_ooool2o`0003Kooooo000Tooooo`03o`000?oooooo
oooo03Oooooo0_l0000Eooooo`;o00004_ooool2o`00073ooooo0_l00006ooooo`;o00004Oooool2
o`0001Sooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`0gooooo`;o0000:Oooool2o`00
05Kooooo0_l0000Aooooo`;o00001?ooool3o`0001Wooooo0_l0001@ooooo`009?ooool2o`0003?o
oooo0_l0001Yooooo`;o00003oooool2o`0000[ooooo0_l0000Aooooo`;o00001?ooool2o`0001So
oooo0_l0001Booooo`009?ooool00ol0003oooooooooo`0Wooooo`;o00002Oooool2o`0006Wooooo
0_l0000?ooooo`;o00006_ooool2o`0001;ooooo0_l0000=ooooo`;o00006oooool2o`0001cooooo
0_l0000Gooooo`009?ooool00ol0003oooooooooo`04ooooo`;o00008Oooool2o`0006oooooo0_l0
000Jooooo`;o00005?ooool2o`0000;ooooo0_l0000>ooooo`;o0000:_ooool2o`0001cooooo0_l0
000Gooooo`009?ooool00ol0003oooooooooo`04ooooo`;o00006?ooool2o`0005cooooo0_l0000?
ooooo`;o00002Oooool2o`0001[ooooo0_l0000Eooooo`;o000000?oooooo`000?l00000LOooool0
02Cooooo00?o0000ooooooooool07_ooool2o`0005cooooo0_l0000?ooooo`;o0000??ooool2o`00
07Cooooo000Tooooo`;o0000h_ooool2o`0005kooooo000Tooooo`03o`000?oooooooooo0;oooooo
0_l0000?ooooo`;o00003oooool2o`0005kooooo000Tooooo`03o`000?oooooooooo02oooooo1?l0
000[ooooo`;o0000Goooool2o`0000oooooo0_l0001_ooooo`009?ooool00ol0003oooooooooo`0:
ooooo`;o00001oooool4o`0001Sooooo1?l0000[ooooo`;o0000=oooool2o`00013ooooo0_l0001:
ooooo`;o00001oooool2o`0000Cooooo0_l0000kooooo`009?ooool00ol0003oooooooooo`0:oooo
o`;o00001?ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000[ooooo0_l0001/oooo
o`;o00003Oooool2o`000003ooooool0003o000004[ooooo0_l00007ooooo`;o00001?ooool2o`00
03_ooooo000Tooooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool2o`0004_o
oooo0_l0000^ooooo`;o00001oooool2o`00093ooooo000Tooooo`03o`000?oooooooooo023ooooo
0_l0001Dooooo`;o00004Oooool2o`0002Cooooo0_l0001Wooooo`;o00009oooool002Cooooo00?o
0000ooooooooool08?ooool2o`0000[ooooo0_l0000Jooooo`?o0000?_ooool2o`0001[ooooo0_l0
000nooooo`;o0000;Oooool2o`0000;ooooo0_l0000Wooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo02cooooo0_l0000Jooooo`?o00006Oooool2o`000003ooooool0003o000003co
oooo0_l0000nooooo`;o00003?ooool2o`0001oooooo0_l0000[ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0oooooo`;o00008oooool2o`000003ooooool0003o
000008[ooooo0_l0001<ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0003oooooo0_l0000Ioooo
o`;o0000iOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04_ooool2o`0004Ko
oooo0_l0000Dooooo`;o0000Goooool2o`0006kooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool04_ooool2o`0005cooooo0_l0001Oooooo`;o00002?ooool2o`0003Co
oooo0_l0000^ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`;o0000
Poooool2o`0003Cooooo0_l0000^ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Kooooo0_l0000booooo`;o0000]Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Roooool2o`0001;ooooo0_l0
000Pooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0;_ooool2o`0004;ooooo0_l0000V
ooooo`;o00000_ooool2o`00023ooooo0_l0001oooooo`009?ooool00ol0003oooooooooo`0^oooo
o`;o0000@_ooool2o`0002Kooooo0_l0002Uooooo`009?ooool00ol0003oooooooooo`1Cooooo`;o
0000<Oooool2o`0005Oooooo0_l0000oooooo`;o00007oooool002Cooooo00?o0000ooooooooool0
Doooool2o`0001kooooo0_l0000Aooooo`;o00001?ooool2o`0002oooooo0_l0000Jooooo`;o0000
1?ooool2o`0003oooooo0_l0000Oooooo`009?ooool00ol0003oooooooooo`1cooooo`;o00005ooo
ool2o`0002oooooo0_l0000Jooooo`;o0000I_ooool002Cooooo0_l0000@ooooo`;o00001oooool2
o`0009oooooo0_l00026ooooo`009?ooool00ol0003oooooooooo`0?ooooo`;o00001oooool2o`00
03Oooooo0_l0001Vooooo`;o0000MOooool2o`0000oooooo000Tooooo`03o`000?oooooooooo057o
oooo0_l00006ooooo`;o0000OOooool2o`0003Cooooo0_l0000Pooooo`;o00003oooool002Cooooo
00?o0000ooooooooool0COooool2o`0000[ooooo0_l00015ooooo`;o0000=_ooool2o`0003Cooooo
0_l0000aooooo`009?ooool00ol0003oooooooooo`0dooooo`;o00005oooool2o`0002cooooo0_l0
000Sooooo`;o0000G_ooool2o`0003oooooo000Tooooo`;o0000=Oooool3o`0000_ooooo0ol0000f
ooooo`;o0000K?ooool2o`0001Gooooo0_l0000oooooo`009?ooool00ol0003oooooooooo`0eoooo
o`;o00002oooool3o`000:Cooooo0_l0000Tooooo`;o00006_ooool2o`0001Cooooo000Tooooo`03
o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo0_l00006ooooo`;o00004_ooool2o`0001Co
oooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0003Mooooo`;o0000<Oooool2o`0002Sooooo
000Tooooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o0000S?ooool4o`0000Cooooo0_l0
001Eooooo`009?ooool2o`00057ooooo0_l00002ooooo`;o00007oooool2o`0006_ooooo0_l00006
ooooo`;o0000EOooool002Cooooo00?o0000ooooooooool0MOooool2o`000<[ooooo0009ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo@_ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Sooooo0_l0001n
ooooo`;o0000Aoooool000Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:oooool2o`0004_ooooo0_l0001nooooo`;o0000Aoooool0
00Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000[
ooooo`;o0000Q?ooool2o`0008kooooo0009ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/Oooool2o`0008kooooo0009
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Sooooo0_l0003oooooo`Sooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Sooooo0009
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0G?oo
ool2o`000>?ooooo000Tooooo`;o00003_ooool2o`0004gooooo0_l0003Sooooo`009?ooool00ol0
003oooooooooo`0=ooooo`;o0000aoooool2o`0006Wooooo000Tooooo`03o`000?oooooooooo087o
oooo0_l0001Cooooo`;o0000JOooool002Cooooo00?o0000ooooooooool0POooool2o`0008?ooooo
0_l0000iooooo`009?ooool00ol0003oooooooooo`3oooooo`Oooooo0_l0000Vooooo`;o00004Ooo
ool002Cooooo0_l0003ooooooc3ooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`3ooooo
oacooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`24ooooo`;o0000I_ooool2o`0002go
oooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`1oooooo`;o00000oooool2o`0006Kooooo
0_l0000Cooooo`;o0000?_ooool002Cooooo00?o0000ooooooooool0Ooooool2o`0004Oooooo0_l0
000gooooo`;o0000?_ooool002Cooooo0_l0000nooooo`;o0000Moooool2o`00013ooooo0_l0001g
ooooo`009?ooool00ol0003oooooooooo`0mooooo`;o0000Moooool2o`0008Wooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Z?ooool2o`0005Wooooo
0_l0000looooo`009?ooool00ol0003oooooooooo`2Xooooo`;o0000FOooool2o`0001[ooooo0_l0
000Pooooo`009?ooool2o`000>Sooooo0_l0000=ooooo`;o00009oooool2o`00023ooooo000Toooo
o`03o`000?oooooooooo00Oooooo0_l0002jooooo`;o00008_ooool2o`0000gooooo0_l00019oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2o`0000Cooooo
0_l0001Rooooo`;o0000E_ooool2o`0007cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003o
ooooooooooooool2o`0003gooooo0_l0000Yooooo`;o0000e?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0@?ooool2o`000;Oooooo0_l00016ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000?Wooooo0_l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?3ooooo0_l0001?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3`ooooo`;o0000Coooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`15ooooo`;o
0000n_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo04Gooooo0_l0003jooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0]oooool2o`0008Sooooo000Tooooo`03o`000?oooooooooo09Cooooo0_l0
000Qooooo`;o0000R?ooool002Cooooo00?o0000ooooooooool0U?ooool2o`0008cooooo0_l0000M
ooooo`009?ooool00ol0003oooooooooo`3oooooob?ooooo0_l0000Mooooo`009?ooool2o`0002;o
oooo0_l0003ooooooaoooooo000Tooooo`03o`000?oooooooooo00cooooo0_l0000Cooooo`;o0000
Boooool2o`000=7ooooo000Tooooo`03o`000?oooooooooo00cooooo0_l0001Pooooo`;o0000dOoo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1ioooo
o`;o0000a_ooool002Cooooo0_l0001jooooo`;o0000a_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`0Sooooo`;o0000oooooolMooooo`009?ooool0
0ol0003oooooooooo`0Sooooo`;o0000oooooolMooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000W?ooool2o`0002[ooooo0_l0001hooooo`009?ooool00ol0003ooooo
ooooo`2Kooooo`;o0000:_ooool2o`0005cooooo0_l0000Jooooo`006_ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolVooooo`;o00006_ooool001cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0UOooool2o`0007Gooooo0_l0000cooooo`007?ooool00ol0003o
ooooooooo`05ooooo`Co0000U?ooool2o`0007Gooooo0_l0000cooooo`007?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?oooooo0000o`0004Gooooo0_l00018ooooo`Co0000[Oooool001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`;o00007_ooool2o`00023ooooo
0_l0000Vooooo`Co0000[Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Vooooo`;o0000@?ooool2o`0004;ooooo0_l0002Cooooo`006_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0:cooooo0_l0002Cooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo06gooooo0_l0002<ooooo`;o0000A?ooool002Cooooo00?o0000
ooooooooool0KOooool2o`0008cooooo0_l00014ooooo`009?ooool2o`0008Cooooo0_l0002Eoooo
o`;o00009Oooool002Cooooo00?o0000ooooooooool0>_ooool2o`0004Oooooo0_l0000]ooooo`;o
0000I_ooool2o`0002Gooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0001fooooo`;o0000
SOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000H?ooool2o`000>3ooooo000Tooooo`03o`000?oooooooooo05oo
oooo0_l0003Pooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
06_ooooo0_l0003Eooooo`009?ooool00ol0003oooooooooo`1Zooooo`;o0000eOooool000;ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04_ooooo0_l0
003dooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1;ooooo`;o0000m?ooool000Cooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooolDooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool0oooooolCooooo`;o
0000;Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Sooooo000Toooo
o`;o0000ooooool9ooooo`;o0000>?ooool002Cooooo00?o0000ooooooooool00_ooool2o`0005?o
oooo0_l0003Xooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000Doooool2o`000>Sooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooooaKooooo0_l0000Zooooo`009?ooool00ol0003ooooooooo
o`3ooooooaKooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooolXooooo`;o00006Oooool002Cooooo00?o0000ooooooooool0oooooolWooooo`;o
00006Oooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04
ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;o
oooo000:ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo067ooooo
0_l0003Nooooo`009?ooool2o`0006;ooooo0_l0003Nooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0ooooool]ooooo`;o00004oooool002Cooooo00?o0000ooooooooool0Xoooool2o`0008Oooooo
0_l0000Cooooo`009?ooool2o`000:Cooooo0_l0002Looooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000_Ooo
ool2o`0008?ooooo000Tooooo`03o`000?oooooooooo0;cooooo0_l00023ooooo`009?ooool3o`00
0?oooooo@_ooool002Cooooo0ol00032ooooo`;o0000OOooool002Cooooo00?o0000ooooooooool0
`_ooool2o`0007gooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003o
ooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003ooooooooo
o`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
Soooool2o`000;3ooooo000Tooooo`03o`000?oooooooooo08oooooo0_l0002`ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003o
ooooooooo`3ooooooakooooo0_l0000Rooooo`009?ooool00ol0003oooooooooo`3ooooooakooooo
0_l0000Rooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`00
0?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Loooo
o`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`00
6Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .10485 Mdot
.03333 .21464 Mdot
.0381 .2779 Mdot
.04286 .27674 Mdot
.04762 .03672 Mdot
.05238 .13308 Mdot
.05714 .1058 Mdot
.0619 .01708 Mdot
.06667 .05535 Mdot
.07143 .13838 Mdot
.07619 .00518 Mdot
.08095 .25488 Mdot
.08571 .05784 Mdot
.09048 .17372 Mdot
.09524 .05427 Mdot
.1 .05348 Mdot
.10476 .05786 Mdot
.10952 .10941 Mdot
.11429 .00305 Mdot
.11905 .00016 Mdot
.12381 .09995 Mdot
.12857 .04106 Mdot
.13333 .15937 Mdot
.1381 .15916 Mdot
.14286 .30262 Mdot
.14762 .11155 Mdot
.15238 .21281 Mdot
.15714 .03189 Mdot
.1619 .01322 Mdot
.16667 .05234 Mdot
.17143 .1397 Mdot
.17619 .06424 Mdot
.18095 .01498 Mdot
.18571 .05209 Mdot
.19048 .0296 Mdot
.19524 .05771 Mdot
.2 .12473 Mdot
.20476 .02335 Mdot
.20952 .07568 Mdot
.21429 .09375 Mdot
.21905 .01184 Mdot
.22381 .15958 Mdot
.22857 .07487 Mdot
.23333 .20842 Mdot
.2381 .18869 Mdot
.24286 .12613 Mdot
.24762 .24174 Mdot
.25238 .1208 Mdot
.25714 .06717 Mdot
.2619 .27674 Mdot
.26667 .33454 Mdot
.27143 .11999 Mdot
.27619 .00629 Mdot
.28095 .31464 Mdot
.28571 .11225 Mdot
.29048 .02472 Mdot
.29524 .22927 Mdot
.3 .15431 Mdot
.30476 .34522 Mdot
.30952 .0481 Mdot
.31429 .03222 Mdot
.31905 .16795 Mdot
.32381 .00395 Mdot
.32857 .3528 Mdot
.33333 .09177 Mdot
.3381 .02282 Mdot
.34286 .05012 Mdot
.34762 .24539 Mdot
.35238 .0707 Mdot
.35714 .07684 Mdot
.3619 .40058 Mdot
.36667 .27352 Mdot
.37143 .43499 Mdot
.37619 .08675 Mdot
.38095 .26086 Mdot
.38571 .21037 Mdot
.39048 .16423 Mdot
.39524 .14057 Mdot
.4 .06037 Mdot
.40476 .24129 Mdot
.40952 .40914 Mdot
.41429 .0467 Mdot
.41905 .03822 Mdot
.42857 .06022 Mdot
.43333 .08241 Mdot
.4381 .19509 Mdot
.44286 .1185 Mdot
.44762 .1005 Mdot
.45238 .01082 Mdot
.45714 .01287 Mdot
.4619 .13485 Mdot
.46667 .067 Mdot
.47143 .04792 Mdot
.47619 .55447 Mdot
.48095 .14262 Mdot
.48571 .08396 Mdot
.49048 .09779 Mdot
.49524 .35657 Mdot
.5 .05509 Mdot
.50476 .03571 Mdot
.50952 .16958 Mdot
.51429 .04989 Mdot
.51905 .01451 Mdot
.52381 .30744 Mdot
.52857 .21552 Mdot
.53333 .01135 Mdot
.5381 .49266 Mdot
.54286 .00819 Mdot
.54762 .17895 Mdot
.55238 .15171 Mdot
.55714 .05476 Mdot
.5619 .17547 Mdot
.56667 .31493 Mdot
.57143 .03141 Mdot
.57619 .10146 Mdot
.58095 .15602 Mdot
.58571 .14366 Mdot
.59048 .01661 Mdot
.59524 .18374 Mdot
.6 .31781 Mdot
.60476 .01986 Mdot
.60952 .02728 Mdot
.61429 .4785 Mdot
.61905 .14375 Mdot
.62381 .04501 Mdot
.62857 .09263 Mdot
.63333 .34479 Mdot
.6381 .10535 Mdot
.64286 .06687 Mdot
.64762 .29643 Mdot
.65238 .26714 Mdot
.65714 .03248 Mdot
.6619 .04029 Mdot
.66667 .02836 Mdot
.67143 .1155 Mdot
.67619 .09517 Mdot
.68095 .07937 Mdot
.68571 .00623 Mdot
.69048 .11872 Mdot
.69524 .22306 Mdot
.7 .11643 Mdot
.70476 .10525 Mdot
.70952 .11728 Mdot
.71429 .06539 Mdot
.71905 .07794 Mdot
.72381 .12115 Mdot
.72857 .10807 Mdot
.73333 .2393 Mdot
.7381 .13363 Mdot
.74286 .04433 Mdot
.74762 .16903 Mdot
.75238 .34517 Mdot
.75714 .12763 Mdot
.7619 .15648 Mdot
.76667 .02945 Mdot
.77143 .02555 Mdot
.77619 .04572 Mdot
.78095 .0078 Mdot
.78571 .2129 Mdot
.79048 .06864 Mdot
.79524 .03101 Mdot
.8 .07604 Mdot
.80476 .2295 Mdot
.80952 .38388 Mdot
.81429 .01671 Mdot
.81905 .08179 Mdot
.82381 .12294 Mdot
.82857 .02575 Mdot
.83333 .21074 Mdot
.8381 .05464 Mdot
.84286 .07528 Mdot
.84762 .31769 Mdot
.85238 .02182 Mdot
.85714 .03236 Mdot
.8619 .06185 Mdot
.86667 .05525 Mdot
.87143 .12758 Mdot
.87619 .06746 Mdot
.88095 .18152 Mdot
.88571 .06818 Mdot
.89048 .43939 Mdot
.89524 .30723 Mdot
.9 .0768 Mdot
.90476 .34204 Mdot
.90952 .06553 Mdot
.91429 .46561 Mdot
.91905 .18448 Mdot
.92381 .03096 Mdot
.92857 .28354 Mdot
.93333 .09278 Mdot
.9381 .25959 Mdot
.94286 .55587 Mdot
.94762 .03479 Mdot
.95238 .00598 Mdot
.95714 .04418 Mdot
.9619 .55308 Mdot
.96667 .29315 Mdot
.97143 .03156 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`?o0000
2oooool3o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`04o`00
0?ooooooooooooooo`;o00002_ooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool3o`0000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o
0000?oooool2o`0005Gooooo0_l0000/ooooo`;o00007Oooool2o`0003Gooooo0_l0000Fooooo`00
9?ooool00ol0003oooooooooo`0Yooooo`;o00004Oooool2o`0004Wooooo1?l0000Fooooo`;o0000
0_ooool2o`0004_ooooo0_l0001=ooooo`009?ooool2o`0002[ooooo0_l00004ooooo`;o00002ooo
ool2o`0004Wooooo1?l0000Booooo`;o00000_ooool2o`0009kooooo000Tooooo`03o`000?oooooo
oooo00Wooooo0_l0000Tooooo`;o0000K?ooool2o`0001Gooooo0_l00017ooooo`;o0000@_ooool0
02Cooooo00?o0000ooooooooool02Oooool2o`000:Wooooo0_l00003ooooo`;o0000@_ooool2o`00
00[ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`0gooooo`;o00006_ooool2o`0000go
oooo0_l0001Eooooo`;o0000=?ooool2o`0001Sooooo0_l0000fooooo`009?ooool00ol0003ooooo
ooooo`0gooooo`;o00006_ooool2o`0000gooooo0_l0001Fooooo`;o00004Oooool2o`00023ooooo
0_l0000@ooooo`;o0000?_ooool002Cooooo0_l0000cooooo`;o0000N_ooool2o`0000[ooooo0_l0
000Aooooo`;o00007_ooool2o`0000Oooooo0_l00009ooooo`;o00007Oooool2o`0000kooooo0_l0
000?ooooo`009?ooool00ol0003oooooooooo`0Wooooo`;o00002Oooool2o`0002Kooooo0_l0001B
ooooo`;o00006_ooool2o`00027ooooo0_l00007ooooo`;o00004_ooool2o`0001Cooooo0_l00006
ooooo`;o00001_ooool2o`0000oooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000Qoooo
o`;o0000<Oooool2o`0003cooooo0_l0000`ooooo`;o0000?_ooool2o`0001cooooo0_l0000Goooo
o`009?ooool00ol0003oooooooooo`04ooooo`;o00006?ooool2o`0005cooooo0_l0000Jooooo`;o
0000<Oooool2o`0007Cooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0001Looooo`;o0000
COooool2o`0007Cooooo000Tooooo`;o0000O?ooool2o`0004;ooooo0_l0000Tooooo`;o00002Ooo
ool2o`0003Wooooo0_l0000Dooooo`009?ooool00ol0003oooooooooo`1Iooooo`;o00002Oooool2
o`0001Gooooo0_l0000@ooooo`;o00003?ooool2o`0002;ooooo0_l0000Tooooo`;o00002Oooool2
o`0003Wooooo0_l0000Dooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o00001?ooool2o`00
02Kooooo0_l00009ooooo`;o00009oooool2o`0000cooooo0_l0002Tooooo`009?ooool00ol0003o
ooooooooo`0:ooooo`;o00001oooool4o`0001Cooooo0_l00004ooooo`;o0000I?ooool2o`00013o
oooo0_l0001Iooooo`;o00002?ooool2o`00037ooooo000Tooooo`03o`000?oooooooooo00[ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Looooo`;o0000HOooool2o`00013ooooo
0_l0001Iooooo`;o00002?ooool2o`00037ooooo000Tooooo`;o00004Oooool2o`0000Cooooo0_l0
000Looooo`;o0000@?ooool2o`0000Oooooo0_l0002;ooooo`;o0000<oooool002Cooooo00?o0000
ooooooooool0;_ooool2o`0004Kooooo0_l00007ooooo`;o0000Foooool2o`0002kooooo0_l0000=
ooooo`;o00009?ooool002Cooooo00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l00012oooo
o`;o0000=oooool2o`0001Gooooo0_l0000Gooooo`;o00006_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Tooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Sooooo0_l0
000Mooooo`;o00008oooool2o`0003Oooooo0_l0000^ooooo`;o00006_ooool2o`000003ooooool0
003o000002_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03oo
oooo0_l0000Vooooo`;o0000f?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000hooooo`;o0000
1Oooool2o`0002Oooooo0_l0001dooooo`;o00006?ooool2o`0000cooooo0_l0000@ooooo`;o0000
9oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>?ooool2o`0002kooooo0_l0
001Wooooo`;o00002oooool2o`0001Sooooo0_l0000<ooooo`;o00004?ooool2o`0002Oooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0POooool2o`0000oooooo0_l0
000mooooo`;o0000:oooool2o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06kooooo0_l0000Aooooo`;o00003oooool2o`0006[ooooo0_l00011ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06kooooo0_l0003Aooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001Roooo
o`;o0000GOooool2o`00067ooooo0_l0000Looooo`009?ooool00ol0003oooooooooo`0jooooo`;o
00009Oooool2o`0005gooooo0_l0000>ooooo`;o0000DOooool2o`0001cooooo000Tooooo`03o`00
0?oooooooooo03[ooooo0_l0001Hooooo`;o0000>_ooool2o`0006oooooo000Tooooo`03o`000?oo
oooooooo01gooooo0_l0001Wooooo`;o00003?ooool2o`0001Wooooo0_l0002@ooooo`009?ooool3
o`0000Oooooo0_l0000Dooooo`;o0000Ioooool2o`0002Oooooo0_l0000Booooo`;o00005?ooool2
o`0006Kooooo000Tooooo`?o00001oooool2o`000;[ooooo0_l0000Dooooo`;o00001_ooool2o`00
05kooooo000Tooooo`;o00006Oooool2o`0000[ooooo0_l0002kooooo`;o0000G_ooool002Cooooo
00?o0000ooooooooool06?ooool2o`0000[ooooo0_l0000[ooooo`;o0000k_ooool002Cooooo00?o
0000ooooooooool0DOooool2o`0007_ooooo0_l00008ooooo`;o000000?oooooo`000?l00000I?oo
ool002Cooooo00?o0000ooooooooool0A_ooool2o`0000Gooooo0_l0000eooooo`;o0000B?ooool2
o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00063ooooo000Toooo
o`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o0000=Oooool2o`0004kooooo0_l00009oooo
o`;o00007oooool2o`0003oooooo000Tooooo`;o0000=_ooool2o`0000cooooo0_l0002kooooo`;o
0000?oooool002Cooooo00?o0000ooooooooool0=Oooool2o`0000cooooo0_l0002Uooooo`;o0000
8oooool2o`00033ooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0003Sooooo`;o00008ooo
ool2o`00033ooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l00023ooooo`;o0000F?ooool2
o`0005_ooooo000Tooooo`03o`000?oooooooooo00cooooo0_l0000Nooooo`;o0000G?ooool2o`00
05Sooooo0_l0001Kooooo`009?ooool2o`0000gooooo0_l0000Nooooo`;o0000Aoooool2o`0001Wo
oooo0_l0002_ooooo`009?ooool00ol0003oooooooooo`1eooooo`;o00006Oooool2o`00023ooooo
0_l00009ooooo`;o0000P_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool2o`0000Wo
oooo0_l00022ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Z?ooool2o`0009Oooooo0009ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Ko
oooo0_l0001@ooooo`;o0000Uoooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0001Fooooo`;o0000FOooool2o`0003Wooooo0_l0001Cooooo`00
2Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo023ooooo0ol0000Jooooo`;o0000L_ooool2o`0003Wooooo0_l0001Coooo
o`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Pooooo`?o00006_ooool2o`0003Cooooo0_l0003<ooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1coooo
o`;o0000c?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0
003oooooooooo`1Looooo`;o0000??ooool2o`0004_ooooo0_l0001Hooooo`009?ooool2o`0005go
oooo0_l0000looooo`;o0000Boooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo01;ooooo
0_l0002Gooooo`;o0000U?ooool002Cooooo00?o0000ooooooooool04_ooool2o`0009;ooooo0_l0
0003ooooo`;o0000U?ooool002Cooooo00?o0000ooooooooool0Y_ooool2o`0006[ooooo0_l0000]
ooooo`009?ooool00ol0003oooooooooo`2fooooo`;o0000F_ooool2o`0000_ooooo0_l0000Poooo
o`009?ooool2o`0004?ooooo0_l0001booooo`;o0000Ioooool2o`00023ooooo000Tooooo`03o`00
0?oooooooooo04;ooooo0_l0003mooooo`009?ooool00ol0003oooooooooo`23ooooo`;o0000_?oo
ool002Cooooo00?o0000ooooooooool0Poooool2o`000;cooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0@?ooool2o`00033ooooo0_l0003=ooooo`009?ooool0
0ol0003oooooooooo`0Vooooo`;o00006?ooool2o`00033ooooo0_l0001oooooo`;o00003_ooool2
o`0003cooooo000Tooooo`04o`000?oooooo0000o`0002Gooooo0_l0001hooooo`;o0000DOooool2
o`0000kooooo0_l0000looooo`009?ooool4o`0009oooooo0_l0002Oooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0=Kooooo0_l0001Yooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0e_oo
ool2o`0006Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo0_l0002S
ooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001Dooooo`;o0000Xoooool2o`00
04Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1hooooo`;o0000J?ooool2o`0005go
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0AOooool2o`00037ooooo0_l0001X
ooooo`;o0000GOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l0
0006ooooo`03o`000?oooooooooo04Gooooo0_l0000Nooooo`;o0000f_ooool002Cooooo0_l0001V
ooooo`;o0000f_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`0?ooooo`;o0000oooooolaooooo`009?ooool00ol0003oooooooooo`0?ooooo`;o0000
oooooolEooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0L?ooool2o`000;?ooooo0_l0
000Jooooo`009?ooool2o`00077ooooo0_l0003?ooooo`009?ooool00ol0003oooooooooo`38oooo
o`;o0000Moooool002Cooooo00?o0000ooooooooool0b?ooool2o`0007Oooooo000Tooooo`03o`00
0?oooooooooo06_ooooo0_l0003Dooooo`009?ooool01?l0003oooooooooooooool3o`0004Gooooo
0_l0000Pooooo`;o0000e?ooool002Cooooo0_l00002ooooo`?o0000AOooool2o`000?Kooooo000T
ooooo`03o`000?oooooooooo0?oooooo8oooool2o`0001gooooo000Tooooo`03o`000?oooooooooo
0?oooooo8oooool2o`0001gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0ooooool_ooooo`;o00004Oooool002Cooooo0_l00038ooooo`;o0000IOoo
ool2o`00017ooooo000Tooooo`03o`000?oooooooooo0<Oooooo0_l0001hooooo`006_ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool08oooool2o`000?oooooo7Oooool001co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`;o0000oooooolMooooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09kooooo0_l0001gooooo`;o0000
:?ooool001cooooo00?o0000ooooooooool01Oooool3o`0009kooooo0_l0001gooooo`;o0000:?oo
ool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`;o0000F_ooool2
o`0009?ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D?ooool2o`00
05[ooooo0_l00009ooooo`;o0000C_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0]oooool2o`0004kooooo0_l0000hooooo`006_ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`1;ooooo`;o0000m?ooool002Cooooo00?o0000ooooooooool0
Boooool2o`000?Cooooo000Tooooo`;o0000oooooolLooooo`;o00009Oooool002Cooooo00?o0000
ooooooooool0Eoooool2o`0006Wooooo0_l0000Uooooo`;o0000;oooool2o`0002Gooooo000Toooo
o`03o`000?oooooooooo05Oooooo0_l0001Yooooo`;o00009Oooool2o`0005Kooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Goooool2o`000>3ooooo
000Tooooo`;o0000H?ooool2o`0003Cooooo0_l0002Zooooo`009?ooool00ol0003oooooooooo`2E
ooooo`;o0000Z_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3kooooo`;o0000A?ooool000Co
oooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003kooooo`;o0000A?ooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;o
oooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool00ol0003oooooooooo`1Zooooo`;o0000eOooool002Cooooo0_l0
001[ooooo`;o0000eOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`1iooooo`;o0000a_ooool002Cooooo00?o0000ooooooooool0NOooool2o`000<Ko
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0001^ooooo`;o0000d_ooool002Cooooo00?o0000ooooooooool0KOooool2
o`000=;ooooo000Tooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002[ooooo000Tooooo`03
o`000?oooooooooo0?oooooo5_ooool2o`0002[ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`04oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000
oooooolNooooo`;o00008_ooool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolNooooo`;o00008_ooool000cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000oooo
ooooool0_?ooool2o`0008?ooooo000Tooooo`;o0000_Oooool2o`0008?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0:?ooooo0_l0002Loooo
o`009?ooool2o`000:Cooooo0_l0002Looooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
oooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooo
ooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo
1?l00006ooooo`03o`000?oooooooooo08oooooo0_l0002Eooooo`;o00001?ooool2o`0001?ooooo
000Tooooo`;o0000T?ooool2o`0009Gooooo0_l00004ooooo`;o00004oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool5o`00
00Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo
@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3o
ooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnH
V9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .23041 Mdot
.03333 .55361 Mdot
.0381 .2779 Mdot
.04286 .03256 Mdot
.04762 .03672 Mdot
.05238 .04185 Mdot
.05714 .1058 Mdot
.0619 .19927 Mdot
.06667 .11348 Mdot
.07143 .0484 Mdot
.07619 .00518 Mdot
.08095 .39077 Mdot
.08571 .07377 Mdot
.09048 .17372 Mdot
.09524 .14442 Mdot
.1 .09806 Mdot
.10476 .05786 Mdot
.10952 .06345 Mdot
.11429 .00305 Mdot
.11905 .1987 Mdot
.12381 .09995 Mdot
.12857 .04106 Mdot
.13333 .08601 Mdot
.1381 .31349 Mdot
.14286 .24006 Mdot
.14762 .04283 Mdot
.15238 .21281 Mdot
.15714 .08714 Mdot
.1619 .01322 Mdot
.16667 .11529 Mdot
.17143 .16892 Mdot
.17619 .06424 Mdot
.18095 .05212 Mdot
.18571 .05286 Mdot
.19048 .0296 Mdot
.19524 .00046 Mdot
.2 .08911 Mdot
.20476 .02335 Mdot
.20952 .07568 Mdot
.21429 .06152 Mdot
.21905 .01184 Mdot
.22381 .23258 Mdot
.22857 .03209 Mdot
.23333 .22164 Mdot
.2381 .20662 Mdot
.24286 .09516 Mdot
.24762 .39179 Mdot
.25238 .0825 Mdot
.25714 .06905 Mdot
.2619 .07339 Mdot
.26667 .24799 Mdot
.27143 .11999 Mdot
.27619 .00629 Mdot
.28095 .38179 Mdot
.28571 .11225 Mdot
.29048 .06077 Mdot
.29524 .2021 Mdot
.3 .07863 Mdot
.30476 .52212 Mdot
.30952 .07095 Mdot
.31429 .03222 Mdot
.31905 .15965 Mdot
.32381 .00395 Mdot
.32857 .24478 Mdot
.33333 .08849 Mdot
.3381 .02282 Mdot
.34286 .20899 Mdot
.34762 .04296 Mdot
.35238 .43231 Mdot
.35714 .25449 Mdot
.3619 .44623 Mdot
.36667 .03757 Mdot
.37143 .01982 Mdot
.37619 .36652 Mdot
.38095 .34578 Mdot
.38571 .20383 Mdot
.39048 .16423 Mdot
.39524 .01341 Mdot
.4 .15817 Mdot
.40476 .26654 Mdot
.40952 .23645 Mdot
.41429 .0467 Mdot
.41905 .03607 Mdot
.42857 .06044 Mdot
.43333 .08241 Mdot
.4381 .2314 Mdot
.44286 .08366 Mdot
.44762 .26961 Mdot
.45238 .01082 Mdot
.45714 .06975 Mdot
.4619 .50922 Mdot
.46667 .067 Mdot
.47143 .04792 Mdot
.47619 .28971 Mdot
.48095 .00887 Mdot
.48571 .08396 Mdot
.49048 .06542 Mdot
.49524 .35657 Mdot
.5 .05509 Mdot
.50476 .02146 Mdot
.50952 .10561 Mdot
.51429 .03417 Mdot
.51905 .01451 Mdot
.52381 .3204 Mdot
.52857 .0891 Mdot
.53333 .01135 Mdot
.5381 .25657 Mdot
.54286 .00819 Mdot
.54762 .17895 Mdot
.55238 .02157 Mdot
.55714 .05476 Mdot
.5619 .23357 Mdot
.56667 .11182 Mdot
.57143 .15628 Mdot
.57619 .23842 Mdot
.58095 .0825 Mdot
.58571 .08462 Mdot
.59048 .04996 Mdot
.59524 .00551 Mdot
.6 .12598 Mdot
.60476 .06884 Mdot
.60952 .02728 Mdot
.61429 .4785 Mdot
.61905 .26574 Mdot
.62381 .04501 Mdot
.62857 .01785 Mdot
.63333 .43799 Mdot
.6381 .04123 Mdot
.64286 .06687 Mdot
.64762 .2304 Mdot
.65238 .26714 Mdot
.65714 .03248 Mdot
.6619 .04029 Mdot
.66667 .02836 Mdot
.67143 .1155 Mdot
.67619 .01067 Mdot
.68095 .19463 Mdot
.68571 .06782 Mdot
.69048 .11872 Mdot
.69524 .18705 Mdot
.7 .11643 Mdot
.70476 .06037 Mdot
.70952 .26734 Mdot
.71429 .11384 Mdot
.71905 .10936 Mdot
.72381 .12115 Mdot
.72857 .10461 Mdot
.73333 .1375 Mdot
.7381 .15746 Mdot
.74286 .04433 Mdot
.74762 .12984 Mdot
.75238 .19902 Mdot
.75714 .10002 Mdot
.7619 .02549 Mdot
.76667 .06025 Mdot
.77143 .02555 Mdot
.77619 .04572 Mdot
.78095 .05701 Mdot
.78571 .0401 Mdot
.79048 .03492 Mdot
.79524 .23076 Mdot
.8 .39624 Mdot
.80476 .1497 Mdot
.80952 .32099 Mdot
.81429 .01671 Mdot
.81905 .08179 Mdot
.82381 .12294 Mdot
.82857 .05754 Mdot
.83333 .21074 Mdot
.8381 .09833 Mdot
.84286 .07528 Mdot
.84762 .13804 Mdot
.85238 .03358 Mdot
.85714 .0354 Mdot
.8619 .02912 Mdot
.86667 .06491 Mdot
.87143 .18575 Mdot
.87619 .06746 Mdot
.88095 .10351 Mdot
.88571 .17576 Mdot
.89524 .5061 Mdot
.9 .0768 Mdot
.90476 .39761 Mdot
.90952 .06553 Mdot
.91905 .18448 Mdot
.92381 .15706 Mdot
.92857 .09881 Mdot
.93333 .09278 Mdot
.9381 .42125 Mdot
.94286 .53772 Mdot
.94762 .02547 Mdot
.95238 .00598 Mdot
.95714 .00272 Mdot
.9619 .35082 Mdot
.96667 .14893 Mdot
.97143 .04359 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00009ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`00
0?oooooooooo00cooooo0ol0000;ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooooooo0_l0000:ooooo`04o`000?oooooooooooooo
o`;o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Cooooo1?l00005ooooo`03o`000?oooooooooo00cooooo000Tooooo`03
o`000?oooooooooo00gooooo0_l0000oooooo`;o0000@?ooool2o`0001?ooooo0_l0000?ooooo`;o
0000LOooool2o`0001Kooooo000Tooooo`03o`000?oooooooooo02Wooooo0_l0000Aooooo`;o0000
BOooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`0002Wooooo0_l0001_ooooo`009?oo
ool2o`0002[ooooo0_l0000Aooooo`;o0000=oooool2o`00013ooooo0_l0000Dooooo`;o00000_oo
ool2o`0002gooooo0_l0001_ooooo`009?ooool00ol0003oooooooooo`1eooooo`;o00009_ooool2
o`00027ooooo0_l0000kooooo`;o0000@_ooool002Cooooo00?o0000ooooooooool0KOooool2o`00
02Wooooo0_l0000>ooooo`;o00005_ooool2o`0003_ooooo0_l00012ooooo`009?ooool00ol0003o
ooooooooo`0gooooo`;o0000:Oooool2o`0000Wooooo0_l0000Yooooo`;o00003_ooool2o`0004;o
oooo0_l000000ooooooo0000o`00000gooooo`;o00005oooool002Cooooo00?o0000ooooooooool0
=oooool2o`0002Wooooo0_l0001Fooooo`;o00004Oooool2o`0001gooooo0_l000000ooooooo0000
o`00000gooooo`;o00005oooool002Cooooo0_l0000cooooo`;o0000Q_ooool2o`00017ooooo0_l0
000mooooo`;o0000<oooool002Cooooo00?o0000ooooooooool00_ooool2o`0002kooooo0_l0000;
ooooo`;o00006Oooool2o`0003oooooo0_l0000]ooooo`;o0000?Oooool2o`000003ooooool0003o
000003?ooooo000Tooooo`03o`000?oooooooooo00;ooooo1?l0000iooooo`;o00006Oooool2o`00
00oooooo0_l0000?ooooo`;o00007Oooool2o`0002gooooo0_l0000Yooooo`;o00004_ooool3o`00
03Gooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000Hooooo`;o0000Boooool2o`0000oo
oooo0_l0001=ooooo`;o00009_ooool4o`0001?ooooo0_l0000eooooo`009?ooool00ol0003ooooo
ooooo`05ooooo`;o00005oooool2o`0000Cooooo0_l0000oooooo`;o0000G?ooool2o`0000Kooooo
0_l0000Vooooo`;o0000>oooool2o`0000oooooo000Tooooo`;o00001_ooool2o`0001gooooo0_l0
000oooooo`;o00005?ooool2o`0004;ooooo0_l00002ooooo`;o00008?ooool2o`0000Wooooo0_l0
000nooooo`;o00003oooool002Cooooo00?o0000ooooooooool03?ooool2o`0006gooooo0_l0000@
ooooo`;o00009Oooool2o`0000Wooooo0_l0000Tooooo`;o00002Oooool2o`0004oooooo000Toooo
o`03o`000?oooooooooo00cooooo0_l0000Qooooo`Co0000F_ooool2o`0002Gooooo0_l0002;oooo
o`009?ooool00ol0003oooooooooo`0_ooooo`Co0000I?ooool2o`00013ooooo0_l0002Fooooo`00
9?ooool00ol0003oooooooooo`0Fooooo`;o0000Ooooool2o`00013ooooo0_l00017ooooo`;o0000
3Oooool2o`0003kooooo000Tooooo`;o00005oooool2o`0002;ooooo0_l0000Gooooo`;o0000:_oo
ool2o`0005Sooooo0_l0000Booooo`;o00000oooool2o`0000gooooo0_l0000nooooo`009?ooool0
0ol0003oooooooooo`0Hooooo`;o00005?ooool2o`0000[ooooo0_l0000Gooooo`;o0000:_ooool2
o`0001?ooooo0_l00013ooooo`;o00004_ooool2o`0001oooooo0_l0000;ooooo`;o00009?ooool0
02Cooooo00?o0000ooooooooool06?ooool2o`0001Cooooo0_l0001Looooo`;o00001_ooool2o`00
02oooooo0_l0000<ooooo`;o0000>Oooool2o`000003ooooool0003o000000Sooooo0_l0000Toooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Sooooo0_l0000?ooooo`;o0000;_oo
ool2o`000003ooooool0003o000002_ooooo0_l0000:ooooo`;o00003?ooool2o`0003cooooo0_l0
000^ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`;o
0000=_ooool3o`0000kooooo0_l0000^ooooo`;o0000;_ooool2o`0008Kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`?o00004?ooool2o`0002Kooooo0_l0000?ooooo`;o0000^oooool2o`00013ooooo
0_l0000Wooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0hooooo`;o00007?oo
ool2o`000:kooooo0_l0000@ooooo`;o00009oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`16ooooo`;o00003_ooool2o`0002Wooooo0_l000000ooooooo0000o`00
000<ooooo`;o00007Oooool2o`0004_ooooo0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Pooooo`;o00001Oooool2o`0001gooooo0_l0000iooooo`;o000000?ooooo
o`000?l000003?ooool2o`0001gooooo0ol0001:ooooo`;o0000@Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Pooooo`;o00001Oooool2o`0000cooooo0_l0000Zooooo`;o0000
?Oooool2o`00013ooooo0_l0002=ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000fooooo`;o0000:_ooool2o`00
03gooooo0_l00021ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0@oooool2o`000=ko
oooo0_l0000Looooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000;?ooool2o`000;oooooo
0_l0000Looooo`;o00007Oooool002Cooooo00?o0000ooooooooool05Oooool2o`0000Kooooo0_l0
003;ooooo`;o00006?ooool2o`0001cooooo0_l0000Mooooo`009?ooool00ol0003oooooooooo`07
ooooo`;o00005?ooool2o`0007_ooooo0_l00015ooooo`;o00001oooool2o`0002Kooooo0_l0000]
ooooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000TOooool2o`0004Gooooo0_l0000_oooo
o`;o0000;Oooool002Cooooo0_l0002]ooooo`;o0000<?ooool2o`00067ooooo000Tooooo`03o`00
0?oooooooooo00[ooooo0_l00015ooooo`;o0000FOooool2o`0002kooooo1?l0001Qooooo`009?oo
ool00ol0003oooooooooo`0:ooooo`;o00007oooool2o`0002Cooooo0_l0001kooooo`;o00002?oo
ool2o`0000;ooooo0_l0001Sooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o00008?ooool2
o`0007oooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0001Pooooo`009?ooool00ol0
003oooooooooo`1=ooooo`;o0000QOooool2o`0000Wooooo0_l0000Oooooo`;o0000?oooool002Co
oooo0_l0002hooooo`;o0000Aoooool2o`0003oooooo000Tooooo`03o`000?oooooooooo0;Oooooo
0_l0000^ooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool0ioooool2o`0005Sooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0h_ooool2o`00
02?ooooo0_l0000hooooo`009?ooool2o`000>?ooooo0_l0000Sooooo`;o0000>?ooool002Cooooo
00?o0000ooooooooool04oooool2o`000?oooooo;Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool04oooool2o`000?oooooo6_ooool2o`00017ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3iooooo`;o
0000<oooool2o`00017ooooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?Wooooo0_l00016ooooo`002Oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0007Kooooo0_l0000fooooo`;o
0000=?ooool2o`0003[ooooo0_l0000Oooooo`002Oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05cooooo0_l0000Hoooo
o`;o0000=_ooool2o`0003Cooooo0_l0000jooooo`;o00007oooool000Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0G?ooool2o`00
01Gooooo0_l0003<ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1cooooo`;o0000c?ooool000Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolDoooo
o`009?ooool2o`0002gooooo0_l0003ooooooaCooooo000Tooooo`03o`000?oooooooooo01;ooooo
0_l0003oooooo`7ooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`0Booooo`;o0000T_oo
ool2o`0006cooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`2Vooooo`;o0000VOooool0
02Cooooo00?o0000ooooooooool0ooooool@ooooo`;o00003_ooool2o`00023ooooo000Tooooo`;o
0000eoooool2o`0003Oooooo0_l0000>ooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0
e_ooool2o`0006Wooooo000Tooooo`03o`000?oooooooooo0=7ooooo0_l0001^ooooo`009?ooool0
0ol0003oooooooooo`3Aooooo`;o0000K_ooool002Cooooo00?o0000ooooooooool02Oooool2o`00
013ooooo0_l0003<ooooo`;o0000E_ooool002Cooooo0_l0000:ooooo`;o00004?ooool2o`0003Oo
oooo0_l0000Looooo`;o0000MOooool2o`0005Kooooo000Tooooo`03o`000?oooooooooo04;ooooo
0_l0000@ooooo`;o00007?ooool2o`000<gooooo000Tooooo`03o`000?oooooooooo04;ooooo0_l0
000Pooooo`;o0000foooool002Cooooo00?o0000ooooooooool09_ooool2o`0003cooooo0_l0002M
ooooo`;o0000??ooool002Cooooo00?o0000ooooooooool09_ooool2o`000=_ooooo0_l0000loooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0@?ooool2o`000?oooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo043ooooo0_l0003ooooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool3o`0008?ooooo0_l00012ooooo`;o0000;Oooool2o`0004Wooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`04ooooo`?o0000?Oooool2o`0004Cooooo0_l0000Vooooo`;o00006_ooool2o`0002go
oooo0_l00019ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03go
oooo0_l0000jooooo`;o0000<?ooool2o`0009Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02?ooooo0_l0001Dooooo`;o0000=?ooool2o`00093ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08oooool2o`0008[ooooo0_l0002@ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0Goooool2
o`000>3ooooo000Tooooo`;o0000C?ooool2o`0001;ooooo0_l0003Pooooo`009?ooool00ol0003o
ooooooooo`1;ooooo`;o0000m?ooool002Cooooo00?o0000ooooooooool0J?ooool2o`0003Wooooo
0_l0002Looooo`009?ooool00ol0003oooooooooo`1Xooooo`;o0000>Oooool2o`0009cooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0002nooooo`;o0000P_ooool002Co
oooo00?o0000ooooooooool0N?ooool2o`0004?ooooo0_l00009ooooo`;o00004Oooool2o`0006Co
oooo000Tooooo`03o`000?oooooooooo07Sooooo0_l0000<ooooo`;o0000@?ooool2o`00017ooooo
0_l0001Tooooo`009?ooool00ol0003oooooooooo`26ooooo`;o0000^Oooool002Cooooo00Co0000
oooooooooooooooo0_l0003oooooocoooooo000Tooooo`;o00000_ooool2o`000?oooooo?oooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo08oooooo0_l0002`ooooo`009?ooool00ol0003ooooooooo
o`2?ooooo`;o0000/?ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
oooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom2ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo0_l0003ooooooaoooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08Oooool2o`000?oooooo7oooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2Nooooo`;o0000Foooool2o`0004Cooooo000Jooooo`03oeEEEOmV
IVKo000000Oooooo00?o0000ooooooooool0W_ooool2o`0005_ooooo0_l00014ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0L?ooool2o`000<oooooo000Tooooo`03o`000?oooooooooo073ooooo0_l0003?ooooo`00
9?ooool00ol0003oooooooooo`3oooooobgooooo0_l0000Cooooo`009?ooool00ol0003ooooooooo
o`3oooooobgooooo0_l0000Cooooo`009?ooool2o`0009Kooooo0_l0002Zooooo`009?ooool00ol0
003oooooooooo`2Eooooo`;o0000Z_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`1^ooooo`;o0000dOooool002Cooooo00?o0000ooooooooool0K_oo
ool2o`000=7ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo053ooooo0_l0003_ooooo`001?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1@ooooo`;o0000koooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool03oooool2o`0003Cooooo0_l0003jooooo`001?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`;o0000=?ooool2o`000?[ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0n?oo
ool2o`00023ooooo0_l0000Uooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0n?ooool2o`00023ooooo0_l0
000Uooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool0oooooolVooooo`;o00006_ooool002Cooooo00?o0000oooooooo
ool0oooooolVooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`1Wooooo`;o0000f?ooool002Cooooo0_l0001Xooooo`;o0000f?ooool0
02Cooooo00?o0000ooooooooool0`_ooool2o`0007gooooo000Tooooo`03o`000?oooooooooo0<;o
oooo0_l0001mooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo06[ooooo0_l0003Eooooo`009?ooool2o`0006_ooooo0_l0003Eooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000co
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2
ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003o
ooooooooo`2looooo`;o0000Poooool002Cooooo0_l0002mooooo`;o0000Poooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo6?ooool2o`00
02Sooooo000Tooooo`03o`000?oooooooooo08[ooooo0_l0002;ooooo`;o0000:?ooool002Cooooo
0_l0002;ooooo`;o0000]Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0Eoooool2o`000>Sooooo000Tooooo`;o0000F?ooool2o`000>Sooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
oooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo9oooool2o`0001Wooooo0004ooooo`03
o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolWooooo`;o00006Oooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;o
oooo0004ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_oo
ool01?l0003oooooo`000?l0003ooooood7ooooo000Tooooo`Co0000oooooom1ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Ioooo
o`Go00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000
oooooom2ooooo`007?ooool00omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooo
oooo0?ooooooBOooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Ioooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .17696 Mdot
.03333 .26524 Mdot
.0381 .34726 Mdot
.04286 .03256 Mdot
.04762 .05693 Mdot
.05238 .02149 Mdot
.05714 .1058 Mdot
.0619 .01144 Mdot
.06667 .24512 Mdot
.07143 .2368 Mdot
.07619 .00518 Mdot
.08095 .07066 Mdot
.08571 .21583 Mdot
.09048 .33499 Mdot
.09524 .15128 Mdot
.1 .13934 Mdot
.10476 .09054 Mdot
.10952 .06345 Mdot
.11429 .00305 Mdot
.11905 .15075 Mdot
.12381 .02691 Mdot
.12857 .02818 Mdot
.13333 .21834 Mdot
.1381 .11766 Mdot
.14286 .10005 Mdot
.14762 .08281 Mdot
.15238 .02466 Mdot
.15714 .12764 Mdot
.1619 .01322 Mdot
.16667 .07529 Mdot
.17143 .14328 Mdot
.17619 .27898 Mdot
.18095 .23561 Mdot
.18571 .05286 Mdot
.19048 .08137 Mdot
.19524 .00046 Mdot
.2 .10546 Mdot
.20476 .02335 Mdot
.20952 .07568 Mdot
.21429 .01689 Mdot
.21905 .01184 Mdot
.22381 .20463 Mdot
.22857 .02822 Mdot
.23333 .22164 Mdot
.2381 .18955 Mdot
.24286 .09516 Mdot
.24762 .06949 Mdot
.25238 .0825 Mdot
.25714 .30775 Mdot
.2619 .12169 Mdot
.26667 .04701 Mdot
.27143 .11999 Mdot
.27619 .00629 Mdot
.28095 .21632 Mdot
.28571 .16417 Mdot
.29048 .06077 Mdot
.29524 .29105 Mdot
.3 .19996 Mdot
.30952 .06896 Mdot
.31429 .03222 Mdot
.31905 .06361 Mdot
.32381 .00395 Mdot
.32857 .02412 Mdot
.33333 .08849 Mdot
.3381 .00125 Mdot
.34286 .20832 Mdot
.34762 .02764 Mdot
.35238 .30999 Mdot
.35714 .25647 Mdot
.3619 .54528 Mdot
.36667 .03342 Mdot
.37143 .1699 Mdot
.37619 .1682 Mdot
.38095 .22093 Mdot
.38571 .06342 Mdot
.39048 .05853 Mdot
.39524 .01341 Mdot
.4 .39495 Mdot
.40476 .38222 Mdot
.40952 .0733 Mdot
.41429 .0467 Mdot
.41905 .25469 Mdot
.42857 .06044 Mdot
.43333 .0891 Mdot
.4381 .23235 Mdot
.44286 .00317 Mdot
.44762 .39292 Mdot
.45238 .01082 Mdot
.45714 .16552 Mdot
.4619 .34568 Mdot
.46667 .067 Mdot
.47143 .04792 Mdot
.47619 .5067 Mdot
.48095 .00887 Mdot
.48571 .24761 Mdot
.49048 .06093 Mdot
.49524 .28527 Mdot
.5 .006 Mdot
.50476 .12461 Mdot
.50952 .08154 Mdot
.51429 .03159 Mdot
.51905 .0406 Mdot
.52381 .13088 Mdot
.52857 .19411 Mdot
.53333 .06809 Mdot
.5381 .18108 Mdot
.54286 .06685 Mdot
.54762 .34512 Mdot
.55238 .02157 Mdot
.55714 .02368 Mdot
.5619 .13258 Mdot
.56667 .17223 Mdot
.57143 .17726 Mdot
.57619 .23842 Mdot
.58095 .05621 Mdot
.58571 .01247 Mdot
.59048 .03878 Mdot
.59524 .11769 Mdot
.6 .12598 Mdot
.60476 .18507 Mdot
.60952 .08994 Mdot
.61429 .3871 Mdot
.61905 .14736 Mdot
.62381 .04501 Mdot
.62857 .01785 Mdot
.63333 .13824 Mdot
.6381 .04123 Mdot
.64286 .06687 Mdot
.64762 .397 Mdot
.65238 .05844 Mdot
.65714 .03248 Mdot
.6619 .24453 Mdot
.66667 .02836 Mdot
.67143 .02039 Mdot
.67619 .01067 Mdot
.68095 .16098 Mdot
.68571 .11135 Mdot
.69048 .11872 Mdot
.69524 .18431 Mdot
.7 .04052 Mdot
.70476 .23319 Mdot
.70952 .11762 Mdot
.71429 .02385 Mdot
.71905 .16479 Mdot
.72381 .02932 Mdot
.72857 .10461 Mdot
.73333 .01388 Mdot
.7381 .12395 Mdot
.74286 .22924 Mdot
.74762 .12984 Mdot
.75238 .0194 Mdot
.75714 .0673 Mdot
.7619 .02236 Mdot
.76667 .06025 Mdot
.77143 .02555 Mdot
.77619 .08501 Mdot
.78095 .02877 Mdot
.78571 .0401 Mdot
.79048 .03776 Mdot
.79524 .27897 Mdot
.8 .34278 Mdot
.80476 .1497 Mdot
.80952 .45114 Mdot
.81429 .16314 Mdot
.81905 .08179 Mdot
.82381 .05617 Mdot
.82857 .05754 Mdot
.83333 .34739 Mdot
.8381 .23972 Mdot
.84286 .07528 Mdot
.84762 .15738 Mdot
.85238 .16121 Mdot
.85714 .14878 Mdot
.8619 .11475 Mdot
.86667 .21602 Mdot
.87143 .18429 Mdot
.87619 .19937 Mdot
.88095 .15081 Mdot
.88571 .05636 Mdot
.89048 .39762 Mdot
.89524 .29268 Mdot
.9 .08502 Mdot
.90476 .35178 Mdot
.90952 .04391 Mdot
.91429 .56258 Mdot
.91905 .42439 Mdot
.92381 .08621 Mdot
.92857 .09881 Mdot
.93333 .0763 Mdot
.9381 .32664 Mdot
.94286 .53772 Mdot
.94762 .01697 Mdot
.95238 .00598 Mdot
.95714 .00272 Mdot
.9619 .24003 Mdot
.96667 .09196 Mdot
.97143 .04488 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000oooooooo
ool03?ooool002Cooooo00?o0000ooooooooool03?ooool3o`0000_ooooo0ol0000>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2o`0000[o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00cooooo0_l0000>oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`Co00001Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o
0000?oooool2o`00043ooooo0_l00005ooooo`;o0000T?ooool2o`0001Kooooo000Tooooo`03o`00
0?oooooooooo00Wooooo0_l0000Nooooo`;o00004Oooool2o`0004Wooooo0_l00007ooooo`;o0000
8?ooool2o`0001cooooo0_l0001_ooooo`009?ooool2o`0000[ooooo0_l0000Nooooo`;o00004Ooo
ool2o`0003Oooooo0_l0000@ooooo`;o0000:Oooool2o`0001cooooo0_l0000@ooooo`;o0000GOoo
ool002Cooooo00?o0000ooooooooool0>_ooool2o`0003Wooooo0_l00019ooooo`;o00008?ooool2
o`0000Gooooo0_l0000mooooo`;o00005oooool002Cooooo00?o0000ooooooooool01Oooool2o`00
03?ooooo0_l0001/ooooo`;o00005_ooool2o`0000cooooo0_l0000Iooooo`;o000000?oooooo`00
0?l00000>_ooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0000Oooooo`;o
00003oooool2o`0002Kooooo0_l00017ooooo`?o00008oooool2o`0000cooooo0_l0000>ooooo`;o
000000?oooooo`000?l00000D?ooool002Cooooo00?o0000ooooooooool07Oooool3o`0000Kooooo
0_l0000?ooooo`;o00001_ooool2o`0001kooooo0_l00004ooooo`;o0000@_ooool2o`0002;ooooo
0_l0000=ooooo`;o00004Oooool2o`00053ooooo000Tooooo`;o00007_ooool3o`0001oooooo0_l0
000Tooooo`;o0000=?ooool2o`00033ooooo0_l0000@ooooo`;o00004Oooool2o`0004gooooo000T
ooooo`03o`000?oooooooooo00;ooooo0_l0001Fooooo`;o00003oooool2o`0002kooooo0_l0000]
ooooo`;o00004oooool2o`00017ooooo0_l0001=ooooo`009?ooool00ol0003oooooooooo`02oooo
o`;o0000E_ooool2o`0000oooooo0_l0001Mooooo`;o0000:Oooool2o`0004[ooooo000Tooooo`03
o`000?oooooooooo09gooooo0_l0000Eooooo`;o00008_ooool2o`0001Wooooo1?l0001:ooooo`00
9?ooool00ol0003oooooooooo`2Mooooo`;o00005Oooool2o`0000gooooo0_l0000Cooooo`;o0000
6Oooool2o`0002Kooooo0_l0000Tooooo`009?ooool2o`0004cooooo0_l0000^ooooo`;o0000@_oo
ool2o`0000;ooooo0_l0001Fooooo`;o00004oooool2o`0000oooooo000Tooooo`03o`000?oooooo
oooo04_ooooo0_l0000^ooooo`;o00004?ooool2o`00033ooooo0_l0001_ooooo`;o00003oooool0
02Cooooo00?o0000ooooooooool0<Oooool2o`0005[ooooo0_l0002booooo`009?ooool00ol0003o
ooooooooo`0aooooo`;o0000O_ooool2o`0004gooooo0_l0000Booooo`;o0000:oooool002Cooooo
00?o0000ooooooooool01?ooool2o`0006gooooo0_l0000looooo`;o00005Oooool2o`0003Kooooo
0ol0000Aooooo`;o0000:oooool002Cooooo0_l00005ooooo`;o0000COooool2o`0001kooooo0_l0
000:ooooo`;o00004oooool2o`0003;ooooo0_l0000Sooooo`;o00004_ooool2o`0003kooooo000T
ooooo`03o`000?oooooooooo01Sooooo0_l0000iooooo`;o00001oooool2o`0001Cooooo0_l0000;
ooooo`;o00004oooool2o`0005Oooooo0_l0001Booooo`009?ooool00ol0003oooooooooo`0Hoooo
o`;o0000@_ooool2o`0001Cooooo0_l0000Hooooo`;o00004oooool2o`0000;ooooo0_l0000Noooo
o`;o00008oooool2o`0005Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03ooo
ool2o`0003Cooooo0_l0000Booooo`;o0000<Oooool2o`0001?ooooo0_l00002ooooo`;o00007_oo
ool2o`0002?ooooo0_l0001Eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0?ooooo`;o0000=?ooool2o`0001;ooooo0_l0000Nooooo`;o0000a_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo0ol0000[ooooo`;o00002oooool2o`0003oooooo0_l0002;ooooo`;o0000
6oooool2o`0001cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02_ooooo0_l0
000;ooooo`;o0000c?ooool2o`0001_ooooo0_l0000Looooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo02Cooooo0_l0000<ooooo`;o00004_ooool2o`0005;ooooo0_l0
001Rooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool2
o`0000cooooo0_l0000Booooo`;o0000D_ooool2o`0005Cooooo0_l0000<ooooo`;o00006?ooool2
o`0000Kooooo0_l0000Oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo
0_l0000Nooooo`;o0000=oooool2o`0003Cooooo0_l0000Vooooo`;o00001_ooool2o`0001oooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool2o`0001Oooooo0_l00019ooooo`;o00007_ooool2o`0003Oooooo0_l0001boooo
o`;o00004Oooool002Cooooo00?o0000ooooooooool05_ooool2o`0002_ooooo0_l0003Yooooo`;o
00004Oooool002Cooooo00?o0000ooooooooool0@oooool2o`000=gooooo0_l0000Mooooo`009?oo
ool00ol0003oooooooooo`0Sooooo`;o0000oOooool2o`0001gooooo000Tooooo`03o`000?oooooo
oooo00Oooooo0_l0000Jooooo`;o00004?ooool2o`000:[ooooo0_l0001Nooooo`009?ooool00ol0
003oooooooooo`07ooooo`;o0000;?ooool2o`000:[ooooo0_l0001Nooooo`009?ooool2o`000=Co
oooo0_l0001/ooooo`009?ooool00ol0003oooooooooo`3Cooooo`;o0000=oooool2o`0003?ooooo
000Tooooo`03o`000?oooooooooo027ooooo0_l0002Cooooo`;o00008oooool2o`0002oooooo0_l0
000cooooo`009?ooool00ol0003oooooooooo`0Qooooo`;o0000:_ooool2o`0006Oooooo0_l0000L
ooooo`;o00001Oooool2o`0006Cooooo000Tooooo`03o`000?oooooooooo04Wooooo0_l00002oooo
o`;o0000QOooool2o`0000kooooo0_l0001Kooooo`009?ooool2o`0004[ooooo0_l0001=ooooo`;o
00007Oooool2o`0002_ooooo0_l0001Kooooo`009?ooool00ol0003oooooooooo`0Wooooo`;o0000
Koooool2o`0001gooooo0_l0000^ooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool09ooo
ool2o`0007Gooooo0_l0000;ooooo`;o0000>_ooool2o`0005Sooooo000Tooooo`03o`000?oooooo
oooo09kooooo0_l0000;ooooo`;o0000U?ooool002Cooooo00?o0000ooooooooool05Oooool2o`00
0:_ooooo0_l0001mooooo`009?ooool2o`0001Kooooo0_l0002[ooooo`;o0000OOooool002Cooooo
00?o0000ooooooooool0;?ooool2o`000?oooooo5?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0;?ooool2o`0008oooooo0_l0001;ooooo`;o0000=Oooool000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?o
oooo0_l00006ooooo`;o0000X?ooool2o`0003[ooooo0_l0000?ooooo`;o00001_ooool2o`0002go
oooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo0_l00006ooooo`;o0000g?ooool2o`0001Oooooo0_l0000]ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo2?ooool2o`0003Sooooo0009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0dOooool2o`0003Cooooo1?l0000foooo
o`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Aooooo`;o0000O_ooool2o`0002[ooooo0_l0000:ooooo`;o0000=_ooool000Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0DOooool2o`0003Kooooo0_l0001Cooooo`;o00007Oooool2o`0004;ooooo0009ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0KOooool3o`00
01Wooooo0_l0001Cooooo`;o0000HOooool002Cooooo0_l0001^ooooo`?o0000??ooool2o`0009?o
oooo000Tooooo`03o`000?oooooooooo0:cooooo0_l0002Cooooo`009?ooool3o`000:kooooo0_l0
002Aooooo`009?ooool3o`000:?ooooo0_l00009ooooo`;o0000TOooool002Cooooo00?o0000oooo
ooooool0Xoooool2o`0001Cooooo0_l0000Kooooo`;o0000=oooool2o`00033ooooo000Tooooo`;o
0000^_ooool2o`0001_ooooo0_l0000gooooo`;o0000<?ooool002Cooooo00?o0000ooooooooool0
@_ooool2o`000?gooooo000Tooooo`03o`000?oooooooooo04;ooooo0_l0001Looooo`;o0000Wooo
ool002Cooooo00?o0000ooooooooool0X?ooool2o`0009oooooo000Tooooo`03o`000?oooooooooo
05Kooooo0_l0002iooooo`;o0000;_ooool002Cooooo0_l0001Gooooo`;o0000^Oooool2o`0002ko
oooo000Tooooo`03o`000?oooooooooo03gooooo0_l0003oooooo`?ooooo000Tooooo`03o`000?oo
oooooooo03gooooo0_l0000Uooooo`;o0000foooool002Cooooo00?o0000ooooooooool0I?ooool2
o`000=_ooooo000Tooooo`03o`000?oooooooooo013ooooo0_l0000nooooo`;o0000_?ooool2o`00
037ooooo000Tooooo`;o00004Oooool2o`0000kooooo0_l0000^ooooo`;o0000_?ooool2o`00037o
oooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000Nooooo`;o0000;_ooool2o`000<oooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo043ooooo0_l0000^oooo
o`;o0000coooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0iOooool2o`0005[ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`04ooooo`?o0000Poooool2o`0005Cooooo0_l0000:ooooo`;o0000F_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool2o`0005;o
oooo0_l0001Dooooo`;o0000I_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
3?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3?ooool2o`00027ooooo0_l0001nooooo`;o0000Doooool2o`0002Kooooo0_l0000Cooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0:oooooo0_l0000Jooooo`;o0000=oooool2o`00
02Kooooo0_l0000Cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4
o`0000Kooooo00?o0000ooooooooool02_ooool2o`0008Kooooo0_l0000gooooo`;o0000M?ooool0
02Cooooo0_l0000;ooooo`;o0000Q_ooool2o`000:gooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0J?ooool2o`0001;ooooo0_l00033ooooo`009?oo
ool00ol0003oooooooooo`1Xooooo`;o00004_ooool2o`000<?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo1?l0003ooooood7ooooo000Tooooo`04o`000?oooooo0000o`00
0?oooooo@Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0000_
ooooo`;o0000a_ooool2o`0004Wooooo000Tooooo`03o`000?oooooooooo02kooooo0_l00036oooo
o`;o0000BOooool002Cooooo00?o0000ooooooooool0UOooool2o`000:[ooooo000Tooooo`03o`00
0?oooooooooo09Gooooo0_l0002Zooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o0000`Ooo
ool2o`0002Sooooo000Tooooo`;o0000EOooool2o`000<7ooooo0_l0000Xooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo0_l0
003gooooo`007?ooool00ol0003oooooooooo`05ooooo`?o0000B?ooool2o`0001gooooo0_l0003H
ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo0_l0003Hoooo
o`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oeEEEOmV
IVKo000000Oooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo9oooool2
o`0001[ooooo000Tooooo`03o`000?oooooooooo0?oooooo9_ooool2o`0001[ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool04_ooool2o`000?oooooo
;_ooool002Cooooo00?o0000ooooooooool04_ooool2o`000?oooooo;_ooool002Cooooo0_l0003i
ooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0R_ooool2o`0001[ooooo0_l0001@oooo
o`;o0000Aoooool002Cooooo00Co0000oooooooooooooooo0_l00027ooooo`;o00006_ooool2o`00
05_ooooo0_l0000looooo`009?ooool01?l0003oooooooooooooool2o`000?oooooo0Oooool2o`00
01Gooooo0_l0000Uooooo`009?ooool00ol0003oooooooooo`3ooooooa_ooooo0_l0000Uooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1hooooo`;o0000aooo
ool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0N?ooool2o`000<Oooooo0004ooooo`03o`000?oooooooooo
00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000_?ooool2o`00
08?ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0_?ooool2o`0008?ooooo0004ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07Kooooo0_l0000>ooooo`;o0000^Oooool000Cooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1fooooo`;o00003_ooool2o`0003oooooo0_l0001<ooooo`;o0000:_ooool000;ooooo
00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo0<Oooooo0_l0001<ooooo`;o0000:_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooolPooooo`;o00008?ooool002Cooooo00?o0000oooo
ooooool0oooooolPooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?cooooo0_l00014ooooo`009?oo
ool00ol0003oooooooooo`3kooooo`;o0000A?ooool000[ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;o
oooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo08oooooo0_l0002`ooooo`009?ooool2o`00093ooooo0_l0002`oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`00
1?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooooooo
o`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3oooooobOooooo0_l0000Iooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo9oooool2o`0001Wooooo0004oooo
o`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0J_ooool2o`000=Gooooo0004ooooo`03o`000?oooooooooo
00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06[ooooo0_l0003Eooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;o
oooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooolNooooo`;o00008_ooool002Cooooo00?o0000oooo
ooooool0oooooolNooooo`;o00008_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool5
o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oo
oooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003ooooooooo
o`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .20635 Mdot
.03333 .10505 Mdot
.0381 .37654 Mdot
.04286 .03256 Mdot
.04762 .05693 Mdot
.05238 .01574 Mdot
.05714 .34822 Mdot
.0619 .00089 Mdot
.06667 .21639 Mdot
.07143 .08112 Mdot
.07619 .09372 Mdot
.08095 .03796 Mdot
.08571 .09566 Mdot
.09048 .19908 Mdot
.09524 .01606 Mdot
.1 .06466 Mdot
.10476 .17071 Mdot
.10952 .06345 Mdot
.11429 .05443 Mdot
.11905 .40968 Mdot
.12381 .02691 Mdot
.12857 .02818 Mdot
.13333 .21834 Mdot
.1381 .22437 Mdot
.14286 .05384 Mdot
.14762 .08281 Mdot
.15238 .02583 Mdot
.15714 .14283 Mdot
.1619 .01322 Mdot
.16667 .10205 Mdot
.17143 .14328 Mdot
.17619 .28548 Mdot
.18095 .22177 Mdot
.18571 .05286 Mdot
.19048 .08462 Mdot
.19524 .00046 Mdot
.2 .0451 Mdot
.20476 .00427 Mdot
.20952 .25527 Mdot
.21429 .01689 Mdot
.21905 .01184 Mdot
.22381 .02835 Mdot
.22857 .13439 Mdot
.23333 .13368 Mdot
.2381 .02265 Mdot
.24286 .47393 Mdot
.24762 .20256 Mdot
.25238 .11712 Mdot
.25714 .44346 Mdot
.2619 .01228 Mdot
.26667 .05183 Mdot
.27143 .11999 Mdot
.27619 .05374 Mdot
.28095 .27637 Mdot
.28571 .0703 Mdot
.29048 .06077 Mdot
.29524 .31129 Mdot
.3 .18001 Mdot
.30952 .06896 Mdot
.31429 .03222 Mdot
.31905 .09972 Mdot
.32381 .00395 Mdot
.32857 .07464 Mdot
.33333 .03982 Mdot
.3381 .13159 Mdot
.34286 .08159 Mdot
.34762 .02764 Mdot
.35238 .13469 Mdot
.35714 .01619 Mdot
.3619 .15824 Mdot
.36667 .03342 Mdot
.37143 .30758 Mdot
.37619 .32243 Mdot
.38095 .15851 Mdot
.38571 .1336 Mdot
.39048 .04294 Mdot
.39524 .01341 Mdot
.4 .37239 Mdot
.40476 .22263 Mdot
.40952 .12519 Mdot
.41429 .0467 Mdot
.41905 .14818 Mdot
.42381 .49063 Mdot
.42857 .06044 Mdot
.43333 .03177 Mdot
.4381 .01077 Mdot
.44286 .01118 Mdot
.45238 .01082 Mdot
.45714 .16552 Mdot
.4619 .25476 Mdot
.46667 .15771 Mdot
.47143 .04792 Mdot
.47619 .50675 Mdot
.48095 .05401 Mdot
.48571 .24761 Mdot
.49048 .02276 Mdot
.49524 .22839 Mdot
.5 .0556 Mdot
.50476 .06353 Mdot
.50952 .02398 Mdot
.51429 .0042 Mdot
.51905 .05423 Mdot
.52381 .20414 Mdot
.52857 .19411 Mdot
.53333 .13161 Mdot
.5381 .17034 Mdot
.54286 .06685 Mdot
.54762 .17012 Mdot
.55238 .02157 Mdot
.55714 .02368 Mdot
.5619 .06354 Mdot
.56667 .05613 Mdot
.57143 .2154 Mdot
.57619 .02251 Mdot
.58095 .05621 Mdot
.58571 .00679 Mdot
.59048 .05486 Mdot
.59524 .11769 Mdot
.6 .12598 Mdot
.60476 .04299 Mdot
.60952 .26233 Mdot
.61429 .24054 Mdot
.61905 .374 Mdot
.62381 .08138 Mdot
.62857 .09997 Mdot
.63333 .13824 Mdot
.6381 .04123 Mdot
.64286 .06687 Mdot
.64762 .42752 Mdot
.65238 .05844 Mdot
.65714 .03248 Mdot
.6619 .01867 Mdot
.66667 .02836 Mdot
.67143 .02039 Mdot
.67619 .04627 Mdot
.68095 .16098 Mdot
.68571 .11135 Mdot
.69048 .12311 Mdot
.69524 .25092 Mdot
.7 .04052 Mdot
.70476 .19083 Mdot
.70952 .11762 Mdot
.71429 .13074 Mdot
.71905 .18276 Mdot
.72381 .02932 Mdot
.72857 .10461 Mdot
.73333 .13222 Mdot
.7381 .03829 Mdot
.74286 .45131 Mdot
.74762 .12984 Mdot
.75238 .0323 Mdot
.75714 .05478 Mdot
.7619 .2475 Mdot
.76667 .06025 Mdot
.77143 .04858 Mdot
.77619 .17602 Mdot
.78095 .02877 Mdot
.78571 .27723 Mdot
.79048 .03776 Mdot
.79524 .14478 Mdot
.8 .26604 Mdot
.80476 .05253 Mdot
.80952 .41152 Mdot
.81429 .20478 Mdot
.81905 .08179 Mdot
.82381 .00387 Mdot
.82857 .04253 Mdot
.83333 .23429 Mdot
.8381 .20354 Mdot
.84286 .07528 Mdot
.84762 .13309 Mdot
.85238 .20006 Mdot
.85714 .01542 Mdot
.8619 .15429 Mdot
.86667 .18781 Mdot
.87143 .05269 Mdot
.87619 .19937 Mdot
.88095 .09295 Mdot
.88571 .05636 Mdot
.89048 .39762 Mdot
.89524 .12033 Mdot
.9 .31144 Mdot
.90476 .18217 Mdot
.90952 .05199 Mdot
.91429 .33314 Mdot
.91905 .4245 Mdot
.92381 .0046 Mdot
.92857 .16317 Mdot
.93333 .04977 Mdot
.9381 .37668 Mdot
.94286 .54076 Mdot
.94762 .06039 Mdot
.95238 .02033 Mdot
.95714 .00272 Mdot
.9619 .06834 Mdot
.96667 .06756 Mdot
.97143 .08193 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o0000
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
oooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003o
ooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00009ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool3o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo
00cooooo000Tooooo`03o`000?oooooooooo03Oooooo0_l0001Rooooo`;o00005Oooool2o`0006co
oooo0_l0000Oooooo`009?ooool00ol0003oooooooooo`0Yooooo`;o00004Oooool2o`0000_ooooo
0_l0000hooooo`?o000000?oooooo`000?l00000^?ooool002Cooooo0_l00006ooooo`;o00003?oo
ool2o`0001Cooooo0_l0000Aooooo`;o00002oooool2o`0001gooooo0_l0000;ooooo`;o00003?oo
ool3o`000003ooooool0003o0000087ooooo0_l0000eooooo`009?ooool00ol0003oooooooooo`05
ooooo`;o00003?ooool2o`0002Gooooo0_l0000/ooooo`;o00002oooool2o`0005Cooooo0_l0000m
ooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool0>_ooool2o`0006cooooo0_l00005oooo
o`;o00006_ooool2o`000003ooooool0003o000005Wooooo0_l0000Fooooo`009?ooool00ol0003o
ooooooooo`12ooooo`;o0000D?ooool2o`0000Cooooo0_l0000<ooooo`?o00001?ooool2o`0001go
oooo0_l0001Iooooo`;o00005_ooool002Cooooo00?o0000ooooooooool07Oooool3o`0000Kooooo
0_l0000Eooooo`;o00000oooool2o`00027ooooo0_l0000]ooooo`;o00001?ooool2o`0000gooooo
0_l0000Rooooo`;o0000L_ooool002Cooooo0_l0000Nooooo`?o00001_ooool2o`0001Gooooo0_l0
000Vooooo`;o00006_ooool2o`0004[ooooo0_l0000@ooooo`;o00004Oooool2o`0004gooooo000T
ooooo`03o`000?oooooooooo00;ooooo0_l0001Fooooo`;o00003oooool2o`0001Cooooo0_l00017
ooooo`;o00004oooool2o`0000Sooooo0_l00007ooooo`;o0000COooool002Cooooo00?o0000oooo
ooooool00_ooool2o`0000_ooooo0_l00019ooooo`;o00003oooool2o`0005gooooo0_l0000Moooo
o`;o00002_ooool2o`0004[ooooo000Tooooo`03o`000?oooooooooo00oooooo0_l0001@ooooo`;o
0000MOooool2o`0000[ooooo0_l0000?ooooo`;o0000B_ooool002Cooooo00?o0000ooooooooool0
HOooool2o`00013ooooo0_l00014ooooo`;o00002?ooool2o`0001?ooooo0_l0000:ooooo`;o0000
6oooool2o`0003kooooo000Tooooo`;o0000=_ooool2o`0003cooooo0_l00006ooooo`;o0000??oo
ool2o`0000Sooooo0_l0000;ooooo`;o0000;oooool2o`0003kooooo000Tooooo`03o`000?oooooo
oooo03Gooooo0_l00014ooooo`;o00004?ooool2o`00047ooooo0_l0000Mooooo`;o0000<_ooool2
o`0001cooooo000Tooooo`03o`000?oooooooooo037ooooo0_l0000Hooooo`;o0000@?ooool2o`00
063ooooo0_l00008ooooo`;o00005?ooool2o`0000[ooooo0_l00006ooooo`;o00007?ooool002Co
oooo00?o0000ooooooooool06_ooool2o`0000Oooooo0_l0000<ooooo`;o00006?ooool2o`000003
ooooool0003o0000043ooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l00003ooooo`;o
000000?oooooo`000?l00000=?ooool2o`0000gooooo0_l0000Dooooo`;o00000oooool2o`0000Go
oooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`04ooooo`;o00005?ooool2o`0000Oooooo
0_l0000Yooooo`;o0000@?ooool2o`0000Gooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Booooo`;o00008?ooool2o`0002Sooooo0_l0000[ooooo`009?oo
ool2o`0000Gooooo0_l0001=ooooo`;o0000:_ooool2o`0004Oooooo0_l0000Sooooo`;o0000>Ooo
ool2o`0001Oooooo000Tooooo`03o`000?oooooooooo01Gooooo0_l000000ooooooo0000o`00000i
ooooo`;o0000:_ooool2o`0001Oooooo0_l0000Aooooo`;o0000@?ooool2o`0003Wooooo0_l0000G
ooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l00000O_ooool2o`00
00_ooooo0_l00004ooooo`;o00006?ooool2o`0006Gooooo1?l0000Aooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo057ooooo0_l00006ooooo`;o0000B_ooool2o`0001kooooo0_l0
001Uooooo`Co00004Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0DOooool2o`0000Kooooo0_l00004ooooo`;o0000h?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol0001Oooooo`;o0000YOooool2o`0003Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00cooooo0_l0003hooooo`;o0000>Oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0<ooooo`;o00005_ooool2o`0003kooooo0_l0001Iooooo`;o0000?Ooo
ool2o`00033ooooo0_l0000?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0T
ooooo`;o00003?ooool2o`00033ooooo0_l0001Iooooo`;o0000?Oooool2o`00033ooooo0_l0000?
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`kooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool2o`000?oooooo5?ooool2o`0002gooooo000Tooooo`03o`000?oooooooooo00go
oooo0_l000000ooooooo0000o`00003oooooo`7ooooo0_l0000]ooooo`009?ooool00ol0003ooooo
ooooo`0=ooooo`;o000000?oooooo`000?l00000ooooool`ooooo`009?ooool00ol0003ooooooooo
o`0[ooooo`;o0000;oooool2o`0006;ooooo0_l0001oooooo`009?ooool01?l0003oooooo`000?l0
000Zooooo`;o0000;oooool2o`0006;ooooo0_l0000Oooooo`;o0000G_ooool002Cooooo00Co0000
ooooool0003o0000h?ooool2o`0005kooooo000Tooooo`;o0000e?ooool2o`0006cooooo000Toooo
o`03o`000?oooooooooo0=?ooooo0_l0001/ooooo`009?ooool00ol0003oooooooooo`16ooooo`;o
0000K_ooool2o`0002?ooooo0_l0001Tooooo`009?ooool00ol0003oooooooooo`16ooooo`;o0000
1Oooool2o`0006Oooooo0_l0000Sooooo`;o0000>_ooool2o`0002Sooooo000Tooooo`03o`000?oo
oooooooo04gooooo0_l00025ooooo`;o0000@Oooool2o`0002Sooooo000Tooooo`;o0000N_ooool2
o`0003cooooo0_l0000Kooooo`;o0000Joooool002Cooooo00?o0000ooooooooool0NOooool2o`00
03cooooo0_l0000^ooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool0H_ooool2o`0003go
oooo0_l0000iooooo`;o00001?ooool2o`0000?ooooo0_l0000Nooooo`;o0000>?ooool002Cooooo
00?o0000ooooooooool0?oooool3o`00023ooooo0_l00003ooooo`;o00002Oooool2o`0002gooooo
0_l0000iooooo`;o00001?ooool2o`0002?ooooo0_l0000hooooo`009?ooool00ol0003ooooooooo
o`0oooooo`?o00009Oooool2o`0000Wooooo0_l0001>ooooo`;o0000OOooool002Cooooo0_l00033
ooooo`;o0000OOooool002Cooooo00?o0000ooooooooool09oooool2o`0000?ooooo0_l00038oooo
o`;o0000BOooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09oooool2o`0000?ooooo0_l0001>
ooooo`;o0000N?ooool2o`0004Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1looooo`;o0000`oooool0
00Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0ooooool=ooooo`;o0000<oooool000Wooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001Zooooo`;o00008?ooool2o`0007kooooo0_l0000c
ooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo06[ooooo0_l00004ooooo`;o00006_ooool2o`0004?ooooo0_l0
001^ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1`ooooo`;o0000Goooool2o`0004oooooo0_l0000Mooooo`002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`29ooooo`;o0000Uoooool2o`0001gooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo00?o0000ooooooooool0ROooool2o`0001Sooooo0_l000000ooooooo0000o`00
002Iooooo`009?ooool2o`0001Oooooo0_l0002;ooooo`;o000000?oooooo`000?l00000VOooool0
02Cooooo00?o0000ooooooooool05_ooool2o`000=Sooooo0_l0001?ooooo`009?ooool00ol0003o
ooooooooo`3`ooooo`;o0000Coooool002Cooooo00?o0000ooooooooool0E_ooool2o`0008Kooooo
0_l0000jooooo`;o00009Oooool002Cooooo00?o0000ooooooooool0E_ooool2o`0008Kooooo0_l0
000jooooo`;o00009Oooool002Cooooo0_l0003ooooooa3ooooo0_l0000aooooo`009?ooool00ol0
003oooooooooo`3Iooooo`;o0000<oooool2o`00037ooooo000Tooooo`03o`000?oooooooooo0:3o
oooo0_l0000gooooo`;o0000I_ooool002Cooooo00?o0000ooooooooool0X?ooool2o`0009oooooo
000Tooooo`03o`000?oooooooooo01;ooooo0_l0003eooooo`;o00001_ooool2o`0002kooooo000T
ooooo`;o00004oooool2o`00037ooooo0_l0001Gooooo`;o0000I?ooool2o`0000?ooooo0_l00006
ooooo`;o0000;_ooool002Cooooo0ol00015ooooo`;o0000Eoooool2o`0005gooooo0_l00005oooo
o`;o0000>oooool002Cooooo0ol0003mooooo`;o0000@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000X_ooool2o`00097ooooo000T
ooooo`;o00002oooool2o`0001Cooooo0_l0002<ooooo`;o0000TOooool002Cooooo00?o0000oooo
ooooool08?ooool2o`0000gooooo0_l00017ooooo`;o0000aoooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool08Oooool2o`0000cooooo0_l00017ooooo`;o0000aooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo0_l0001booooo`;o0000
Z_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0UOooool2o`000:[ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`?o0000ooooool4ooooo`;o0000??ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooo`Cooooo0_l0000looooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2looooo`;o0000Poooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2looooo`;o0000Poooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo09;ooooo0_l0001Hooooo`;o0000
Doooool002Cooooo0_l0002Cooooo`;o0000F?ooool2o`0005?ooooo000Tooooo`03o`000?oooooo
oooo0=Kooooo0_l0001Yooooo`009?ooool00ol0003oooooooooo`0hooooo`;o0000D?ooool2o`00
04[ooooo0_l0001Yooooo`009?ooool00ol0003oooooooooo`0hooooo`;o0000D?ooool2o`000;Go
oooo000Tooooo`03o`000?oooooooooo0;[ooooo0_l00025ooooo`009?ooool2o`000;_ooooo0_l0
000looooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0n?ooool2o`0004Oooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`1@ooooo`;o0000XOooool2o`0004cooooo000Tooooo`;o0000DOoo
ool2o`000:7ooooo0_l0001<ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo02kooooo0_l0003ooooooa;ooooo000Tooooo`03o`000?oooooooooo02ko
oooo0_l0003ooooooa;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0KOooool2o`000=;ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0
001Dooooo`;o00005oooool2o`000:Wooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Cooooo0_l00032ooooo`;o00009oooool001cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo06kooooo0_l0003Aooooo`009?ooool2o`0006oooooo0_l0003Aooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo7_ooool2o`00
02;ooooo000Tooooo`03o`000?oooooooooo0?oooooo7_ooool2o`0002;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool01oooool2o`000?oooooo>Oooool002Co
oooo00?o0000ooooooooool01oooool2o`000?oooooo>Oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0007Oooooo0_l0
0015ooooo`;o0000P_ooool002Cooooo00Co0000oooooooooooooooo0_l0001cooooo`;o0000AOoo
ool2o`0006Kooooo0_l0000Jooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooooooo
0_l0003oooooob?ooooo0_l0000Jooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000
ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003o
oooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolFoooo
o`;o0000:_ooool000;ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002[ooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo01_ooooo0_l0003oooooobGooooo000Tooooo`03o`000?oooooooooo01_ooooo0_l0003N
ooooo`;o0000A?ooool002Cooooo00?o0000ooooooooool0noooool2o`0004Cooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo8?ooool2o`00023ooooo000Tooooo`03o`000?oooooooooo0<Oooooo0_l0001F
ooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0aoooool2o`0007Sooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0B?ooool2o`000?Oooooo000Toooo
o`03o`000?oooooooooo04Sooooo0_l0003gooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0iOooool2o`0005[ooooo000:ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0>Gooooo
0_l0001Jooooo`003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003o
ooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
od;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`13ooooo`;o0000o?ooool000[ooooo00?oEEEEofIVI_l000003Ooo
ool4o`0000Kooooo00?o0000ooooooooool0@oooool2o`000?cooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0O_ooool2o`000<7ooooo000Tooooo`03o`000?oo
oooooooo07kooooo0_l00031ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Soooool2o`000;3ooooo000T
ooooo`;o0000T?ooool2o`000;3ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;o
oooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooobOooooo0_l0
000Iooooo`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo9oooool2o`0001Wooooo0004
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
oooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`Go00001_oo
ool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2oooo
o`007?ooool00omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?oooooo
BOooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .18918 Mdot
.03333 .03628 Mdot
.0381 .37654 Mdot
.04286 .03256 Mdot
.04762 .05693 Mdot
.05238 .01574 Mdot
.05714 .25978 Mdot
.0619 .00089 Mdot
.06667 .01168 Mdot
.07143 .08457 Mdot
.07619 .07671 Mdot
.08095 .03796 Mdot
.08571 .09566 Mdot
.09048 .26865 Mdot
.09524 .09943 Mdot
.1 .29673 Mdot
.10476 .09381 Mdot
.10952 .10803 Mdot
.11429 .28626 Mdot
.11905 .53493 Mdot
.12381 .0436 Mdot
.12857 .02818 Mdot
.13333 .18233 Mdot
.1381 .14397 Mdot
.14286 .02717 Mdot
.14762 .00223 Mdot
.15238 .02583 Mdot
.15714 .14283 Mdot
.1619 .01322 Mdot
.16667 .10205 Mdot
.17143 .07905 Mdot
.17619 .42276 Mdot
.18095 .08786 Mdot
.18571 .18378 Mdot
.19048 .05491 Mdot
.19524 .00046 Mdot
.2 .14014 Mdot
.20476 .00427 Mdot
.20952 .39541 Mdot
.21429 .13635 Mdot
.21905 .04438 Mdot
.22381 .02835 Mdot
.22857 .13439 Mdot
.23333 .15876 Mdot
.2381 .02907 Mdot
.24286 .48569 Mdot
.24762 .05165 Mdot
.25238 .11712 Mdot
.25714 .40754 Mdot
.2619 .04316 Mdot
.26667 .05183 Mdot
.27143 .13686 Mdot
.27619 .05374 Mdot
.28095 .37818 Mdot
.28571 .29451 Mdot
.29048 .06077 Mdot
.29524 .11285 Mdot
.3 .18001 Mdot
.30476 .60507 Mdot
.30952 .0414 Mdot
.31429 .03222 Mdot
.31905 .09972 Mdot
.32381 .00395 Mdot
.32857 .07464 Mdot
.33333 .10965 Mdot
.3381 .12586 Mdot
.34286 .10984 Mdot
.34762 .02764 Mdot
.35238 .20537 Mdot
.35714 .0519 Mdot
.3619 .02376 Mdot
.36667 .03342 Mdot
.37143 .30758 Mdot
.37619 .04798 Mdot
.38095 .15487 Mdot
.38571 .15231 Mdot
.39048 .23708 Mdot
.39524 .3095 Mdot
.4 .34978 Mdot
.40476 .02403 Mdot
.40952 .1709 Mdot
.41429 .03729 Mdot
.41905 .09512 Mdot
.42857 .03158 Mdot
.43333 .00381 Mdot
.4381 .01077 Mdot
.44286 .35625 Mdot
.44762 .58592 Mdot
.45238 .11871 Mdot
.45714 .21887 Mdot
.4619 .50596 Mdot
.46667 .14866 Mdot
.47143 .04792 Mdot
.48095 .05401 Mdot
.48571 .09769 Mdot
.49048 .02276 Mdot
.49524 .13455 Mdot
.5 .01416 Mdot
.50476 .06353 Mdot
.50952 .02398 Mdot
.51429 .0042 Mdot
.51905 .09547 Mdot
.52381 .14647 Mdot
.52857 .09516 Mdot
.53333 .13161 Mdot
.5381 .17034 Mdot
.54286 .06685 Mdot
.54762 .16859 Mdot
.55238 .05694 Mdot
.55714 .0425 Mdot
.5619 .06354 Mdot
.56667 .05613 Mdot
.57143 .33213 Mdot
.57619 .02138 Mdot
.58095 .05621 Mdot
.58571 .25893 Mdot
.59048 .05486 Mdot
.59524 .21099 Mdot
.6 .12598 Mdot
.60476 .1213 Mdot
.60952 .12007 Mdot
.61429 .18707 Mdot
.61905 .1827 Mdot
.62381 .08138 Mdot
.62857 .09997 Mdot
.63333 .13824 Mdot
.6381 .04123 Mdot
.64286 .06687 Mdot
.64762 .46616 Mdot
.65238 .05844 Mdot
.65714 .03248 Mdot
.6619 .07277 Mdot
.66667 .02836 Mdot
.67143 .08554 Mdot
.67619 .0442 Mdot
.68095 .16098 Mdot
.68571 .14324 Mdot
.69048 .12311 Mdot
.69524 .02483 Mdot
.7 .18625 Mdot
.70476 .20044 Mdot
.70952 .28931 Mdot
.71429 .25612 Mdot
.71905 .13266 Mdot
.72381 .02932 Mdot
.72857 .14946 Mdot
.73333 .03635 Mdot
.7381 .03829 Mdot
.74286 .31937 Mdot
.74762 .12984 Mdot
.75238 .0323 Mdot
.75714 .05478 Mdot
.7619 .15892 Mdot
.76667 .06025 Mdot
.77143 .04862 Mdot
.77619 .17602 Mdot
.78095 .02877 Mdot
.78571 .0893 Mdot
.79048 .03776 Mdot
.79524 .10799 Mdot
.8 .17287 Mdot
.80476 .00734 Mdot
.80952 .16897 Mdot
.81429 .28535 Mdot
.81905 .02179 Mdot
.82381 .00387 Mdot
.82857 .06025 Mdot
.83333 .23429 Mdot
.8381 .05352 Mdot
.84286 .10399 Mdot
.84762 .00445 Mdot
.85238 .25467 Mdot
.85714 .01542 Mdot
.8619 .08478 Mdot
.86667 .08511 Mdot
.87143 .07339 Mdot
.87619 .16964 Mdot
.88095 .09295 Mdot
.88571 .02861 Mdot
.89048 .48689 Mdot
.89524 .12033 Mdot
.9 .19065 Mdot
.90476 .10499 Mdot
.90952 .05199 Mdot
.91429 .26334 Mdot
.91905 .31852 Mdot
.92381 .0046 Mdot
.92857 .16317 Mdot
.93333 .22896 Mdot
.9381 .0173 Mdot
.94286 .188 Mdot
.94762 .06039 Mdot
.95238 .01637 Mdot
.95714 .00272 Mdot
.9619 .03188 Mdot
.96667 .08024 Mdot
.97143 .0435 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003oooo
ool0003ooooo00kooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool0
1_ooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`00
0?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Go
oooo0_l00005ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooo
ooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01Oooool2o`0000Gooooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2o`00
00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo0_l00002ooooo`03o`000?oooooooooo00;o00002_ooool00ol0003oooooooooo`0:oooo
o`?o00002?ooool2o`0000Gooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000oooooooo
ool0=oooool2o`0006;ooooo0_l0001Looooo`;o00003?ooool2o`0001Oooooo0_l0000Oooooo`00
9?ooool00ol0003oooooooooo`0:ooooo`;o00007Oooool2o`0005Sooooo0_l0001dooooo`;o0000
A_ooool002Cooooo0_l00006ooooo`;o00000oooool2o`0001gooooo0_l0001Hooooo`;o00004_oo
ool2o`00077ooooo0_l0000Mooooo`;o00005_ooool002Cooooo00?o0000ooooooooool01Oooool2
o`00093ooooo0_l0001aooooo`;o00006Oooool2o`0000;ooooo0_l0000Fooooo`009?ooool00ol0
003oooooooooo`2_ooooo`;o0000COooool2o`0002Gooooo0_l0000Jooooo`009?ooool00ol0003o
ooooooooo`1Zooooo`;o00003?ooool2o`0001[ooooo0_l00004ooooo`;o00004oooool2o`0002Go
oooo0_l0000Vooooo`;o0000@Oooool002Cooooo00?o0000ooooooooool07_ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Eooooo`;o00009_ooool2o`0000?ooooo0_l0000<ooooo`;o0000
6_ooool2o`0000Cooooo0_l0000aooooo`;o00001oooool2o`0003cooooo0_l0000[ooooo`009?oo
ool2o`0001oooooo0_l00003ooooo`;o000000?oooooo`000?l000005Oooool2o`0000?ooooo0_l0
000Qooooo`;o00006?ooool2o`0004cooooo0_l0000@ooooo`;o00004Oooool2o`00023ooooo0_l0
000[ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000?_ooool2o`0001Kooooo0_l0000?
ooooo`;o00004_ooool2o`0004Wooooo0_l0000Cooooo`;o00002?ooool2o`0000Oooooo0_l0000h
ooooo`;o00004oooool002Cooooo00Go0000ooooool0003o0000ooooo`02o`0000_ooooo0_l00019
ooooo`;o00003oooool2o`0000kooooo0_l0001=ooooo`;o00005_ooool2o`0000Gooooo0_l0000:
ooooo`;o0000=Oooool2o`0001?ooooo000Tooooo`04o`000?oooooo0000o`0000kooooo0_l0001Z
ooooo`;o0000IOooool4o`0000oooooo0_l0001:ooooo`009?ooool00ol0003oooooooooo`0Moooo
o`;o0000:_ooool2o`0000kooooo0_l0001>ooooo`;o00006?ooool2o`0001oooooo0_l0001:oooo
o`;o00003oooool002Cooooo0_l0000Nooooo`;o00007Oooool2o`0000_ooooo0_l0000>ooooo`;o
0000C_ooool2o`0001Sooooo0_l0000;ooooo`;o0000G_ooool2o`0000oooooo000Tooooo`03o`00
0?oooooooooo03cooooo0_l0000`ooooo`;o00007Oooool2o`00047ooooo0_l0000Mooooo`;o0000
D?ooool002Cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l0000Kooooo`;o00001?oo
ool2o`0001gooooo0_l0001Pooooo`;o0000:_ooool2o`0002Cooooo000Tooooo`03o`000?oooooo
oooo03;ooooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o000001Sooooo0_l0000V
ooooo`;o00006_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000dooooo`;o00006?ooool2
o`0001Gooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`04ooooo`;o0000;?ooool2o`00
01[ooooo0_l00010ooooo`;o00005_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000004_ooool2o`00023ooooo0_l0000Hooooo`;o0000>oooool002Cooooo0_l00005ooooo`;o
0000COooool2o`0005?ooooo0_l0000Nooooo`;o00008oooool2o`0001;ooooo0_l0000Uooooo`;o
00005oooool002Cooooo00?o0000ooooooooool0Doooool2o`0004?ooooo0_l0000Aooooo`;o0000
@?ooool2o`0001;ooooo0_l0000Uooooo`;o00005oooool002Cooooo00?o0000ooooooooool0V?oo
ool2o`0000_ooooo0_l00004ooooo`;o00006?ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0YOooool2o`0001kooooo0_l0001jooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`1Oooooo`;o0000J_ooool2o`0004;ooooo0_l0000`
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool3o`0000gooooo0_l0001@ooooo`;o0000J_ooool2o`00
04;ooooo0_l0000`ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o
00007Oooool2o`000?oooooo0Oooool2o`00017ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0;?ooool2o`00097ooooo0_l0001]ooooo`;o00004Oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`000;7ooooo0_l0000=ooooo`;o0000
??ooool4o`00037ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`00
027ooooo0_l0002Mooooo`;o00008oooool2o`0001Oooooo1?l0000aooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
000`ooooo`;o0000`_ooool2o`0001gooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`0@
ooooo`;o00001?ooool2o`0006Cooooo0_l0000Oooooo`;o000000?oooooo`000?l00000L?ooool2
o`0002gooooo000Tooooo`03o`000?oooooooooo013ooooo0_l000001?oooooo0000o`000?ooool2
o`0006Cooooo0_l0000Dooooo`;o00002Oooool2o`000003ooooool0003o000009oooooo000Toooo
o`03o`000?oooooooooo01?ooooo0_l0000Fooooo`;o0000;oooool2o`0003Cooooo0_l0000/oooo
o`;o0000Ooooool002Cooooo00?o0000ooooooooool0:oooool2o`0002oooooo0_l0001Rooooo`;o
0000A?ooool2o`0001;ooooo0_l0000Uooooo`009?ooool00ol0003oooooooooo`0Hooooo`;o0000
g?ooool2o`0000kooooo0_l0000Booooo`;o00009Oooool002Cooooo0_l0000Iooooo`;o0000Aooo
ool2o`000003ooooool0003o0000093ooooo0_l00019ooooo`009?ooool00ol0003oooooooooo`1D
ooooo`;o00002oooool2o`000003ooooool0003o00000=_ooooo000Tooooo`03o`000?oooooooooo
04Kooooo0_l0000<ooooo`;o0000joooool002Cooooo00?o0000ooooooooool0A_ooool2o`0003oo
oooo0_l0000aooooo`;o0000Foooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo08Oooooo
0_l0000`ooooo`?o00006?ooool2o`00047ooooo0_l0000Xooooo`009?ooool2o`0006?ooooo0_l0
001Cooooo`Co00006Oooool2o`0006_ooooo000Tooooo`03o`000?oooooooooo06;ooooo0_l0001C
ooooo`;o0000;_ooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo0:7ooooo0_l0000koooo
o`;o00001oooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o
0000E?ooool2o`0000[ooooo0_l0000kooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0
>_ooool2o`0000?ooooo0_l0000<ooooo`;o0000A_ooool2o`0002_ooooo0_l0001mooooo`009?oo
ool2o`0003Kooooo0_l0000Fooooo`;o0000Loooool2o`0007gooooo000Tooooo`03o`000?oooooo
oooo027ooooo0_l00004ooooo`;o00003?ooool2o`0009cooooo0_l0001/ooooo`002Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Qooooo`;o00001?ooool2o`0006?ooooo0_l0000@ooooo`;o0000<ooo
ool2o`0006cooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2<ooooo`;o00004?ooool2o`00047ooooo0_l0
001Nooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1`ooooo`Co0000KOooool2o`0005kooooo0009ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000L?ooool4o`000<gooooo0009
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0@?ooool2o`0008oooooo0_l0000Iooooo`;o0000Doooool000Wooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@?ooool2o`0008oooooo0_l0000Iooooo`;o0000=?ooool2o`0001gooooo0009ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
8oooool2o`0001gooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0Xoooool2o`000003ooooool0003o000005?ooooo0_l0000Dooooo`;o0000
;_ooool002Cooooo0_l0001jooooo`;o0000:?ooool2o`000003ooooool0003o0000053ooooo0_l0
00000ooooooo0000o`00000Dooooo`;o0000;_ooool002Cooooo00?o0000ooooooooool0NOooool2
o`0007Gooooo0_l00006ooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool0l?ooool2o`00
04oooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000dooooo`;o0000IOooool2o`0008;o
oooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000?ooooo`;o00008oooool2o`0006Gooooo
0_l00022ooooo`009?ooool2o`0003;ooooo0_l00029ooooo`;o00006_ooool2o`0004cooooo0_l0
000Iooooo`009?ooool3o`000;cooooo0_l0000Jooooo`;o0000?_ooool2o`0000cooooo0_l0000I
ooooo`009?ooool3o`000?oooooo6Oooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0fOooool2o`0006Kooooo000Tooooo`;o0000f_oo
ool2o`0006Kooooo000Tooooo`03o`000?oooooooooo06Oooooo0_l0003Hooooo`009?ooool00ol0
003oooooooooo`1Wooooo`;o0000f?ooool002Cooooo00?o0000ooooooooool0]_ooool2o`0008Wo
oooo000Tooooo`03o`000?oooooooooo0;Kooooo0_l00029ooooo`009?ooool2o`0008[ooooo0_l0
002fooooo`009?ooool00ol0003oooooooooo`29ooooo`;o0000]_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolTooooo`;o00007?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolTooooo`;o00007?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
003oooooo`Cooooo0_l0000looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo07?ooooo0_l0002>ooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Loooool2o`000<cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3Looooo`;o0000:oooool2
o`0003Kooooo000Tooooo`03o`000?oooooooooo00Oooooo0_l0002Yooooo`;o0000:?ooool2o`00
02_ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000ZOooool2o`0008go
oooo000Tooooo`;o0000oooooolOooooo`;o00008_ooool002Cooooo00?o0000ooooooooool04_oo
ool2o`000?oooooo2_ooool2o`0002;ooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0003o
ooooobkooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`0Jooooo`;o0000hOooool2o`0004;ooooo000Toooo
o`03o`000?oooooooooo01[ooooo0_l0002oooooo`;o00008?ooool2o`0004;ooooo000Tooooo`03
o`000?oooooooooo0=_ooooo0_l0001Tooooo`009?ooool2o`0001Kooooo0_l0000jooooo`;o0000
k_ooool002Cooooo00?o0000ooooooooool05Oooool2o`0003[ooooo0_l0003^ooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1]ooooo`;o0000d_ooool001cooooo00?o0000ooooooooool0
1Oooool3o`0006gooooo0_l00006ooooo`;o0000b_ooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1eooooo`;o0000b_ooool001cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooob3ooooo0_l0000Pooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0>Gooooo0_l0000hooooo`;o00008?ooool001[ooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`3Uooooo`;o0000F_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0[_ooool2
o`00097ooooo000Tooooo`03o`000?oooooooooo0:kooooo0_l0002Aooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0M_ooool2o`000<Wooooo000Tooooo`03o`000?oooooooooo07Kooooo0_l00039ooooo`00
9?ooool2o`0008Gooooo0_l0002kooooo`009?ooool00ol0003oooooooooo`24ooooo`;o0000^ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`04o`000?ooooooooooooooo`;o0000ooooooloooooo`000_ooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00Co0000oooooooooooooooo0_l0001=ooooo`;o0000koooool000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0D?ooool2o`000>oooooo0004ooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0hooooo`;o0000ooooool8ooooo`001?ooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Sooooo0002ooooo`03oeEEEOmVIVKo0000
00cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`18ooooo`;o
0000moooool002Cooooo00?o0000ooooooooool0B?ooool2o`000?Oooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0;_ooool2o`000?oooooo4_ooool002Cooooo
00?o0000ooooooooool0;_ooool2o`000?oooooo4_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo
000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000<Oooooo0_l0001hooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`37ooooo`;o0000N?ooool000cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`13ooooo`;o0000d?ooool2o`0002[ooooo000Tooooo`03
o`000?oooooooooo04?ooooo0_l0003@ooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo08[o
oooo0_l0002eooooo`009?ooool00ol0003oooooooooo`2:ooooo`;o0000]Oooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3o
oooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Kooooo`;o0000oooooolUoooo
o`001?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Kooooo`;o0000oooooolUooooo`001?ooool00ol0003ooooo
ooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo
@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oo
oooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0002
ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`26
ooooo`;o0000^Oooool002Cooooo0_l00027ooooo`;o0000^Oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
05Sooooo0_l0003Xooooo`009?ooool00ol0003oooooooooo`1Gooooo`;o0000j?ooool001Wooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003o
oooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000oooooooo
ool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .16175 Mdot
.03333 .14826 Mdot
.0381 .32396 Mdot
.04286 .03256 Mdot
.04762 .04887 Mdot
.05238 .18512 Mdot
.05714 .11843 Mdot
.0619 .00465 Mdot
.06667 .06301 Mdot
.07143 .14141 Mdot
.07619 .03367 Mdot
.08095 .03796 Mdot
.08571 .14178 Mdot
.09048 .18816 Mdot
.09524 .09943 Mdot
.1 .22195 Mdot
.10476 .09381 Mdot
.10952 .10803 Mdot
.11429 .32171 Mdot
.11905 .0708 Mdot
.12381 .0436 Mdot
.12857 .07327 Mdot
.13333 .1005 Mdot
.1381 .11427 Mdot
.14286 .07491 Mdot
.14762 .10594 Mdot
.15238 .00644 Mdot
.15714 .14211 Mdot
.1619 .01322 Mdot
.16667 .30852 Mdot
.17143 .07905 Mdot
.17619 .42276 Mdot
.18095 .08786 Mdot
.18571 .10531 Mdot
.19048 .05491 Mdot
.19524 .00046 Mdot
.2 .27316 Mdot
.20476 .09772 Mdot
.20952 .30744 Mdot
.21429 .13635 Mdot
.21905 .04438 Mdot
.22381 .02835 Mdot
.22857 .13439 Mdot
.23333 .15876 Mdot
.2381 .02907 Mdot
.24286 .48569 Mdot
.24762 .22729 Mdot
.25238 .07606 Mdot
.25714 .30502 Mdot
.2619 .04316 Mdot
.26667 .08849 Mdot
.27143 .11787 Mdot
.27619 .05374 Mdot
.28095 .12374 Mdot
.28571 .40052 Mdot
.29048 .06077 Mdot
.29524 .25635 Mdot
.3 .0946 Mdot
.30476 .53873 Mdot
.30952 .01934 Mdot
.31429 .17929 Mdot
.31905 .32002 Mdot
.32381 .00395 Mdot
.32857 .22785 Mdot
.33333 .22977 Mdot
.3381 .10393 Mdot
.34286 .10984 Mdot
.34762 .20283 Mdot
.35238 .00951 Mdot
.35714 .07389 Mdot
.3619 .07202 Mdot
.36667 .24338 Mdot
.37143 .08336 Mdot
.37619 .04798 Mdot
.38095 .22089 Mdot
.38571 .11459 Mdot
.39048 .04504 Mdot
.39524 .07469 Mdot
.4 .27863 Mdot
.40476 .0254 Mdot
.40952 .3158 Mdot
.41429 .03729 Mdot
.41905 .03655 Mdot
.42381 .59138 Mdot
.42857 .1073 Mdot
.43333 .00381 Mdot
.4381 .01077 Mdot
.44286 .37788 Mdot
.44762 .55196 Mdot
.45238 .00667 Mdot
.45714 .12603 Mdot
.4619 .32798 Mdot
.46667 .1168 Mdot
.47143 .04356 Mdot
.47619 .33805 Mdot
.48095 .23982 Mdot
.48571 .13288 Mdot
.49048 .18586 Mdot
.49524 .22315 Mdot
.5 .01416 Mdot
.50476 .06353 Mdot
.50952 .0665 Mdot
.51429 .14491 Mdot
.51905 .09547 Mdot
.52381 .09824 Mdot
.52857 .28174 Mdot
.53333 .0766 Mdot
.5381 .24547 Mdot
.54286 .13888 Mdot
.54762 .15144 Mdot
.55238 .05694 Mdot
.55714 .02247 Mdot
.5619 .06798 Mdot
.56667 .05613 Mdot
.57143 .19118 Mdot
.57619 .02138 Mdot
.58095 .18659 Mdot
.58571 .15001 Mdot
.59048 .25477 Mdot
.59524 .22205 Mdot
.6 .13326 Mdot
.60476 .11073 Mdot
.60952 .15439 Mdot
.61429 .00938 Mdot
.61905 .1827 Mdot
.62381 .08138 Mdot
.62857 .21695 Mdot
.63333 .39732 Mdot
.6381 .04833 Mdot
.64286 .0485 Mdot
.64762 .32244 Mdot
.65238 .05844 Mdot
.65714 .03248 Mdot
.6619 .07277 Mdot
.66667 .02836 Mdot
.67143 .02094 Mdot
.67619 .0442 Mdot
.68095 .07352 Mdot
.68571 .01727 Mdot
.69048 .32 Mdot
.69524 .12704 Mdot
.7 .07084 Mdot
.70476 .20044 Mdot
.70952 .46643 Mdot
.71429 .11553 Mdot
.71905 .15419 Mdot
.72381 .06509 Mdot
.72857 .02596 Mdot
.73333 .03635 Mdot
.7381 .03829 Mdot
.74286 .19916 Mdot
.74762 .12984 Mdot
.75238 .0323 Mdot
.75714 .01029 Mdot
.7619 .28233 Mdot
.76667 .16194 Mdot
.77143 .04862 Mdot
.77619 .21332 Mdot
.78095 .07928 Mdot
.78571 .0893 Mdot
.79048 .25926 Mdot
.79524 .10799 Mdot
.8 .23122 Mdot
.80476 .00734 Mdot
.80952 .07404 Mdot
.81429 .49553 Mdot
.81905 .1671 Mdot
.82381 .0534 Mdot
.82857 .06025 Mdot
.83333 .31809 Mdot
.8381 .05896 Mdot
.84286 .21419 Mdot
.84762 .00445 Mdot
.85238 .33971 Mdot
.85714 .01542 Mdot
.8619 .093 Mdot
.86667 .08511 Mdot
.87143 .09513 Mdot
.87619 .25175 Mdot
.88095 .18149 Mdot
.88571 .02861 Mdot
.89048 .3575 Mdot
.89524 .12033 Mdot
.9 .04767 Mdot
.90476 .16548 Mdot
.90952 .1548 Mdot
.91429 .10079 Mdot
.91905 .31875 Mdot
.92381 .0046 Mdot
.92857 .16317 Mdot
.93333 .29519 Mdot
.9381 .09401 Mdot
.94286 .01812 Mdot
.94762 .06039 Mdot
.95238 .01637 Mdot
.95714 .00977 Mdot
.9619 .03188 Mdot
.96667 .1841 Mdot
.97143 .1012 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool2o`0000Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o
00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
9?ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003ooooo
ooooo`07ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`0000kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02o`0000[ooooo00?o0000ooooooooool02_ooool3o`0000oo
oooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool02Oooool2o`0001_ooooo
0_l0000oooooo`;o00007_ooool2o`0003?ooooo0_l0000kooooo`;o00003?ooool2o`0001Oooooo
0_l00009ooooo`;o00005?ooool002Cooooo00?o0000ooooooooool0:Oooool2o`0003cooooo0_l0
000Jooooo`;o0000=oooool2o`0002cooooo0_l0000=ooooo`;o0000<?ooool2o`0001Cooooo000T
ooooo`;o0000:_ooool2o`0005Sooooo0_l0000Booooo`;o0000DOooool2o`0001kooooo0_l0000M
ooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0FOooool2o`0003cooooo0_l0000joooo
o`;o0000=Oooool2o`0001[ooooo0_l000000ooooooo0000o`00000Fooooo`009?ooool00ol0003o
ooooooooo`1Iooooo`;o0000C_ooool2o`0000Cooooo0_l0000Mooooo`;o00000oooool2o`00057o
oooo0_l0000Iooooo`009?ooool00ol0003oooooooooo`1hooooo`;o0000;oooool2o`0000Cooooo
0_l0000Mooooo`;o0000LOooool002Cooooo00?o0000ooooooooool0?Oooool2o`0003Wooooo0_l0
001Cooooo`;o00004_ooool2o`00037ooooo0_l0000[ooooo`009?ooool2o`0003kooooo0_l00003
ooooo`;o0000ROooool2o`0001;ooooo0_l0000aooooo`;o0000:oooool002Cooooo00?o0000oooo
ooooool00_ooool2o`0000Wooooo0_l0000cooooo`;o0000Q_ooool2o`0001gooooo0_l00011oooo
o`;o00004oooool002Cooooo00?o0000ooooooooool00_ooool2o`0000Wooooo1?l0001Zooooo`?o
0000C?ooool2o`0001Kooooo0_l00005ooooo`;o0000@Oooool2o`0001?ooooo000Tooooo`03o`00
0?oooooooooo00oooooo0_l0001Zooooo`?o0000I?ooool4o`0005_ooooo000Tooooo`03o`000?oo
oooooooo01gooooo0_l0000Zooooo`;o0000@_ooool2o`0005Gooooo0_l0001Kooooo`009?ooool2
o`0001kooooo0_l0000Mooooo`;o00002oooool2o`0002Sooooo0_l0000Hooooo`;o0000@Oooool2
o`0006oooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000fooooo`;o0000<?ooool2o`00
00?ooooo0_l0001>ooooo`Co00002Oooool2o`0001gooooo0_l0000Wooooo`;o00009oooool002Co
oooo00?o0000ooooooooool01?ooool2o`0006Sooooo0_l0001Cooooo`Co0000:?ooool2o`0000oo
oooo0_l0000Fooooo`;o00009oooool002Cooooo00?o0000ooooooooool0<_ooool2o`0001[ooooo
0_l0001Looooo`;o0000D_ooool2o`0003oooooo000Tooooo`03o`000?oooooooooo03;ooooo0_l0
000Jooooo`;o0000F?ooool2o`0000;ooooo0_l0000Jooooo`;o0000>_ooool2o`0003_ooooo000T
ooooo`;o0000E?ooool2o`0005?ooooo0_l0000Nooooo`;o0000=oooool2o`000003ooooool0003o
000002;ooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000Aoooool2o`00
04?ooooo0_l00015ooooo`;o00008?ooool2o`0002Gooooo0_l0000Gooooo`009?ooool00ol0003o
ooooooooo`0:ooooo`;o0000S?ooool4o`0000oooooo0_l0000booooo`;o0000H?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Kooooo`;o0000OOooool2o`0000oooooo0_l0000[
ooooo`;o0000Ioooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
6oooool2o`000003ooooool0003o000000?ooooo0_l00013ooooo`Co00002Oooool2o`0005Cooooo
0_l00004ooooo`;o00001Oooool2o`00027ooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0001kooooo0_l00003ooooo`;o00008Oooool2o`00023ooooo1?l00009ooooo`;o0000:_oo
ool2o`0002Sooooo0_l00004ooooo`;o0000:?ooool2o`0004Cooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo02cooooo0_l0000Hooooo`;o0000FOooool2o`0004oooooo0_l0001=
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02cooooo0_l0000o
ooooo`;o0000D?ooool2o`00037ooooo0_l0001=ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1]ooooo`;o0000D?ooool2o`0004gooooo0_l0000aooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02oooooo0_l0000Jooooo`;o0000Y_ooool2o`0001Wooooo0_l0
000aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0000`ooooo`;o00006_ooool2o`000:Kooooo0_l0000Gooooo`;o
0000<oooool002Cooooo00?o0000ooooooooool05_ooool2o`0003kooooo0_l00015ooooo`;o0000
KOooool2o`000003ooooool0003o000001Cooooo0_l0000Jooooo`009?ooool00ol0003ooooooooo
o`0Cooooo`;o000000?oooooo`000?l000007oooool2o`0001gooooo0_l00015ooooo`?o0000Kooo
ool2o`0001Cooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o00002oooool2
o`0001Gooooo0_l0001Uooooo`;o0000OOooool2o`00017ooooo0_l0000?ooooo`009?ooool00ol0
003oooooooooo`0Pooooo`;o00003oooool2o`0002oooooo0_l0002iooooo`;o00004Oooool2o`00
00oooooo000Tooooo`03o`000?oooooooooo01Sooooo0_l0000:ooooo`;o00002oooool2o`0002oo
oooo0_l0000Kooooo`;o0000MOooool2o`0004Wooooo000Tooooo`;o00006Oooool2o`0000[ooooo
0_l0000nooooo`;o00006Oooool2o`0003Sooooo0_l0000kooooo`;o0000BOooool002Cooooo00?o
0000ooooooooool08Oooool2o`00047ooooo0_l0000<ooooo`;o0000AOooool2o`0008Kooooo000T
ooooo`03o`000?oooooooooo027ooooo0_l0000Zooooo`;o00008oooool2o`0001Sooooo0_l0001>
ooooo`;o0000Hoooool002Cooooo00?o0000ooooooooool01oooool2o`0004Cooooo0_l0000moooo
o`;o0000C_ooool2o`0003Wooooo0_l0000Xooooo`009?ooool00ol0003oooooooooo`07ooooo`;o
0000Aoooool2o`000<Gooooo0_l0000Xooooo`009?ooool2o`00057ooooo0_l0000gooooo`;o0000
Boooool2o`0006Wooooo000Tooooo`03o`000?oooooooooo08Wooooo0_l0001;ooooo`;o00003ooo
ool2o`0005Sooooo000Tooooo`03o`000?oooooooooo09;ooooo0_l0000Sooooo`;o0000;_ooool2
o`0005Sooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o0000DOooool2o`00
02?ooooo0_l00028ooooo`009?ooool00ol0003oooooooooo`0jooooo`;o00000oooool2o`0006Co
oooo0_l0002Jooooo`009?ooool2o`0000gooooo0_l00002ooooo`;o00005Oooool2o`0007cooooo
0_l0002Jooooo`009?ooool00ol0003oooooooooo`0<ooooo`;o00000_ooool2o`0001Gooooo0_l0
001booooo`;o0000Y?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000ooooool0003o0000V_ooool2o`000:Co
oooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool01?l0003oooooo`000?l0002Uooooo`;o00002_ooool2o`0008gooooo0009ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0:Kooooo0_l0000:ooooo`;o00001_ooool2o`0002;ooooo0_l0000kooooo`;o00009?ooool000Wo
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002joooo
o`;o00008_ooool2o`0003_ooooo0_l0000Tooooo`002Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo0_l0003o
ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool3
o`00043ooooo0_l0002[ooooo`;o0000<oooool2o`0001gooooo0009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`?o0000kOooool2o`0000oooooo0_l0000J
ooooo`;o00001_ooool2o`0001gooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo00?o0000ooooooooool0o_ooool2o`0001[ooooo0_l0000Uooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`1Jooooo`;o0000iOooool002Cooooo00?o0000ooooooooool0F_ooool2o`00067ooooo0_l0
001Cooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool01Oooool2o`0008gooooo0_l0000W
ooooo`;o0000Doooool2o`0001[ooooo0_l0000Aooooo`009?ooool2o`0000Kooooo0_l0000;oooo
o`;o0000P?ooool2o`0001_ooooo0_l0001kooooo`;o00004Oooool002Cooooo00?o0000oooooooo
ool04_ooool2o`0009[ooooo0_l000000ooooooo0000o`00002>ooooo`009?ooool00ol0003ooooo
ooooo`2^ooooo`;o0000TOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3Iooooo`;o00002_ooool2o`0005[ooooo000Tooooo`;o0000I_ooool2o`00
07;ooooo0_l0000:ooooo`;o0000F_ooool002Cooooo00?o0000ooooooooool0IOooool2o`000=[o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0l?oo
ool2o`0004oooooo000Tooooo`03o`000?oooooooooo0?3ooooo0_l0000Dooooo`;o0000>Oooool0
02Cooooo0_l00031ooooo`;o0000A?ooool2o`0003Wooooo000Tooooo`03o`000?oooooooooo01Go
oooo0_l0001Iooooo`;o0000A?ooool2o`0000Sooooo0_l0001oooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000FOooool2o`0002?ooooo0_l0000O
ooooo`;o0000ROooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Gooooo0_l0
000Hooooo`;o0000=?ooool2o`000:[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04Gooooo0_l0000Hooooo`Co0000UOooool2o`0004Oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`?o0000HOooool2o`0009Gooooo0_l00017ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0?oooooo@_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0T?ooool2o`000:oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Joooool2
o`0002?ooooo0_l0002_ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool0Joooool2o`0003Kooooo0_l0002Looooo`009?ooool2
o`000:Cooooo0_l0002Looooo`009?ooool00ol0003oooooooooo`3ooooooa;ooooo0_l0000^oooo
o`009?ooool00ol0003oooooooooo`1Dooooo`;o0000G_ooool2o`0005_ooooo0_l0000^ooooo`00
9?ooool00ol0003oooooooooo`1Dooooo`;o0000G_ooool2o`0003oooooo0_l0001:ooooo`009?oo
ool00ol0003oooooooooo`3eooooo`;o0000B_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`0eooooo`;o0000ooooool;ooooo`009?ooool00ol0003ooooooooo
o`0eooooo`;o0000ooooool;ooooo`009?ooool2o`0007Oooooo0_l00039ooooo`009?ooool00ol0
003oooooooooo`1fooooo`;o0000:?ooool2o`0004[ooooo0_l0001Cooooo`009?ooool00ol0003o
ooooooooo`2Pooooo`;o0000B_ooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo9Oooool2
o`0001cooooo000Tooooo`03o`000?oooooooooo0?oooooo9?ooool2o`0001cooooo000Jooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool2o`000?Oooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:oooool2o`0000_ooooo0_l0000>ooooo`;o0000mooo
ool001cooooo00?o0000ooooooooool01Oooool3o`0002_ooooo0_l0000;ooooo`;o0000ooooool8
ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1iooooo`;o0000R?ooool2o`0003co
oooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool2o`0001_ooooo
0_l0001Iooooo`;o0000;Oooool2o`0001[ooooo0_l0000Pooooo`006_ooool00omEEEGoIVIVo`00
0007ooooo`04o`000?ooooooooooooooo`;o00005oooool2o`00043ooooo0_l0001Yooooo`;o0000
2oooool2o`0004Wooooo0_l0000Pooooo`009?ooool2o`0000;ooooo0_l0000Gooooo`;o0000Zooo
ool2o`0007Sooooo000Tooooo`03o`000?oooooooooo08[ooooo0_l0002eooooo`009?ooool00ol0
003oooooooooo`2:ooooo`;o0000]Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`2?ooooo`;o0000N?ooool2o`0003Kooooo000Tooooo`;o0000T?oo
ool2o`0007Sooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooolGooooo`;o0000:_oo
ool002Cooooo00?o0000ooooooooool0oooooolFooooo`;o0000:_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo08Cooooo0_l0002k
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`24ooooo`;o0000^oooool0
00Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`32ooooo`;o0000OOooool000;ooooo00?o
EEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo057ooooo0_l0001_ooooo`;o0000OOooool002Cooooo0_l0001Booooo`;o0000k_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0;_ooool2
o`000?oooooo4_ooool002Cooooo00?o0000ooooooooool0;_ooool2o`000?oooooo4_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000=_ooooo0_l0001Tooooo`003?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Kooooo`;o0000
I?ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`00
00Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`13ooooo`;o0000o?oo
ool002Cooooo00?o0000ooooooooool0@oooool2o`000?cooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003nooooo`;o0000@_ooool002Cooooo00?o0000ooooooooool0
oOooool2o`0004;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Gooooo`;o0000j?ooool000Cooooo00?o0000ooooooooool03Oooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001Gooooo`;o0000j?ooool000Co
oooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`26ooooo`;o0000^Oooool000;ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo08Kooooo
0_l0002iooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0O_ooool2
o`000<7ooooo000Tooooo`03o`000?oooooooooo07kooooo0_l00031ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol00006oooo
o`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo
000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9
ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .21308 Mdot
.03333 .07651 Mdot
.0381 .08674 Mdot
.04286 .11901 Mdot
.04762 .04887 Mdot
.05238 .09164 Mdot
.05714 .11843 Mdot
.0619 .00465 Mdot
.06667 .24517 Mdot
.07143 .32193 Mdot
.07619 .03367 Mdot
.08095 .26144 Mdot
.08571 .12134 Mdot
.09048 .55893 Mdot
.09524 .15661 Mdot
.1 .22195 Mdot
.10476 .09159 Mdot
.10952 .10803 Mdot
.11429 .43686 Mdot
.11905 .10126 Mdot
.12381 .0436 Mdot
.12857 .09047 Mdot
.13333 .07683 Mdot
.1381 .10576 Mdot
.14286 .39316 Mdot
.14762 .25629 Mdot
.15238 .00644 Mdot
.15714 .0998 Mdot
.1619 .08346 Mdot
.16667 .25407 Mdot
.17143 .25777 Mdot
.17619 .37575 Mdot
.18095 .08786 Mdot
.18571 .10531 Mdot
.19048 .1365 Mdot
.19524 .10192 Mdot
.2 .01748 Mdot
.20476 .0466 Mdot
.20952 .00264 Mdot
.21429 .13635 Mdot
.21905 .04438 Mdot
.22381 .08634 Mdot
.22857 .10076 Mdot
.23333 .12785 Mdot
.2381 .02907 Mdot
.24286 .28111 Mdot
.24762 .22729 Mdot
.25238 .10086 Mdot
.25714 .30548 Mdot
.2619 .04316 Mdot
.26667 .16924 Mdot
.27143 .13304 Mdot
.27619 .00896 Mdot
.28095 .22493 Mdot
.28571 .17816 Mdot
.29048 .16782 Mdot
.29524 .24863 Mdot
.3 .15284 Mdot
.30476 .29501 Mdot
.30952 .0519 Mdot
.31429 .1135 Mdot
.31905 .36221 Mdot
.32381 .00395 Mdot
.32857 .35177 Mdot
.33333 .29312 Mdot
.3381 .10864 Mdot
.34286 .10984 Mdot
.34762 .3628 Mdot
.35238 .00951 Mdot
.35714 .16276 Mdot
.3619 .13563 Mdot
.36667 .0843 Mdot
.37143 .05749 Mdot
.37619 .00759 Mdot
.38095 .00263 Mdot
.38571 .00342 Mdot
.39048 .02364 Mdot
.39524 .03776 Mdot
.4 .12307 Mdot
.40476 .0254 Mdot
.40952 .13891 Mdot
.41429 .21097 Mdot
.41905 .04943 Mdot
.42381 .60619 Mdot
.42857 .0003 Mdot
.43333 .04098 Mdot
.4381 .05812 Mdot
.44286 .17898 Mdot
.44762 .41694 Mdot
.45238 .03958 Mdot
.45714 .12603 Mdot
.4619 .41601 Mdot
.46667 .17618 Mdot
.47143 .04356 Mdot
.47619 .23866 Mdot
.48095 .04032 Mdot
.48571 .13288 Mdot
.49048 .07754 Mdot
.49524 .26611 Mdot
.5 .01416 Mdot
.50476 .06353 Mdot
.50952 .0665 Mdot
.51429 .14491 Mdot
.51905 .30905 Mdot
.52381 .09824 Mdot
.52857 .09384 Mdot
.53333 .12501 Mdot
.5381 .30268 Mdot
.54286 .10209 Mdot
.54762 .36658 Mdot
.55238 .11953 Mdot
.55714 .02247 Mdot
.5619 .06798 Mdot
.56667 .04654 Mdot
.57143 .04617 Mdot
.57619 .02138 Mdot
.58095 .20484 Mdot
.58571 .04263 Mdot
.59048 .00925 Mdot
.59524 .11287 Mdot
.6 .12614 Mdot
.60476 .11073 Mdot
.60952 .1821 Mdot
.61429 .00938 Mdot
.61905 .09613 Mdot
.62381 .13379 Mdot
.62857 .42161 Mdot
.63333 .43988 Mdot
.6381 .19309 Mdot
.64286 .08432 Mdot
.64762 .32244 Mdot
.65238 .05844 Mdot
.65714 .0126 Mdot
.6619 .1513 Mdot
.66667 .02836 Mdot
.67143 .02094 Mdot
.67619 .03288 Mdot
.68095 .07352 Mdot
.68571 .07623 Mdot
.69048 .24925 Mdot
.69524 .33804 Mdot
.7 .06331 Mdot
.70476 .51216 Mdot
.70952 .47123 Mdot
.71429 .28143 Mdot
.71905 .09119 Mdot
.72381 .05306 Mdot
.72857 .02596 Mdot
.73333 .08682 Mdot
.7381 .027 Mdot
.74286 .05592 Mdot
.74762 .14676 Mdot
.75238 .0323 Mdot
.75714 .02878 Mdot
.7619 .26025 Mdot
.76667 .22487 Mdot
.77143 .04862 Mdot
.77619 .08281 Mdot
.78095 .20445 Mdot
.78571 .08755 Mdot
.79048 .20207 Mdot
.79524 .24369 Mdot
.8 .34948 Mdot
.80476 .00734 Mdot
.80952 .02164 Mdot
.81429 .38147 Mdot
.81905 .04765 Mdot
.82381 .03027 Mdot
.82857 .33442 Mdot
.83333 .07936 Mdot
.8381 .08491 Mdot
.84286 .21419 Mdot
.84762 .35836 Mdot
.85238 .18014 Mdot
.85714 .01542 Mdot
.8619 .093 Mdot
.86667 .08511 Mdot
.87143 .09513 Mdot
.87619 .2944 Mdot
.88095 .01231 Mdot
.88571 .08047 Mdot
.89048 .16843 Mdot
.89524 .12033 Mdot
.9 .09511 Mdot
.90476 .02504 Mdot
.90952 .1106 Mdot
.91429 .05411 Mdot
.91905 .12371 Mdot
.92381 .14383 Mdot
.92857 .16317 Mdot
.93333 .12921 Mdot
.9381 .24945 Mdot
.94286 .01812 Mdot
.94762 .06039 Mdot
.95238 .20228 Mdot
.95714 .00977 Mdot
.9619 .14704 Mdot
.96667 .12016 Mdot
.97143 .15044 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool2o`000003oooo
ool0003ooooo00gooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000Wo
oooo00?o0000ooooooooool01?ooool4o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo000Tooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000ooooo`0>ooooo`03o`00
0?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00009ooooo`03
o`000?oooooooooo00Cooooo1?l00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`00
0?oooooooooo00Wooooo0_l0000Kooooo`;o00009_ooool2o`0001Oooooo0_l00005ooooo`;o0000
A?ooool2o`0000Kooooo0_l0000kooooo`;o0000<?ooool2o`0001Cooooo000Tooooo`03o`000?oo
oooooooo04kooooo0_l0000Gooooo`;o00001Oooool2o`0004Cooooo0_l00006ooooo`;o00003?oo
ool2o`0002gooooo0_l0000Gooooo`;o00005oooool2o`0001Cooooo000Tooooo`;o0000V?ooool2
o`00037ooooo0_l0000nooooo`;o00001_ooool2o`0002gooooo000Tooooo`03o`000?oooooooooo
03Gooooo0_l0001Pooooo`;o0000LOooool2o`0001[ooooo0_l0000Iooooo`009?ooool00ol0003o
ooooooooo`0eooooo`;o0000L_ooool2o`0000Cooooo0_l0000Mooooo`;o0000:oooool2o`0002Wo
oooo0_l0000Iooooo`009?ooool00ol0003oooooooooo`1cooooo`;o00000oooool2o`0002oooooo
0_l00004ooooo`;o00007Oooool2o`0002_ooooo0_l0000Mooooo`;o00009Oooool002Cooooo00?o
0000ooooooooool0Loooool2o`0000?ooooo0_l0001Cooooo`;o00004_ooool2o`000003ooooool0
003o000003Cooooo0_l0000Uooooo`009?ooool2o`0004?ooooo0_l00029ooooo`;o00004_ooool2
o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o0000?oooool002Cooooo00?o0000oooo
ooooool03Oooool2o`0003?ooooo0_l0002<ooooo`;o00005oooool3o`0001Cooooo0_l0000ooooo
o`009?ooool00ol0003oooooooooo`0=ooooo`;o0000I_ooool2o`0005Wooooo0_l0000Gooooo`;o
0000E_ooool002Cooooo00?o0000ooooooooool0MOooool2o`0000[ooooo0_l00004ooooo`;o0000
1oooool2o`000:oooooo000Tooooo`03o`000?oooooooooo01gooooo0_l0000Zooooo`;o0000=_oo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000008?ooool2o`0008gooooo000T
ooooo`;o00007_ooool2o`0001Sooooo0_l00003ooooo`;o00002oooool2o`0004;ooooo0_l0000M
ooooo`Co00000_ooool2o`0008gooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000aoooo
o`;o00000oooool2o`0003kooooo0_l0000^ooooo`Co0000?oooool2o`0000gooooo0_l00011oooo
o`009?ooool00ol0003oooooooooo`04ooooo`;o0000Doooool2o`00027ooooo0_l0001Qooooo`;o
00003_ooool2o`0000gooooo0_l00011ooooo`009?ooool00ol0003oooooooooo`1Iooooo`;o0000
Q?ooool2o`0000Cooooo0_l0000fooooo`;o00008_ooool002Cooooo00?o0000ooooooooool0KOoo
ool2o`0001Cooooo0_l00013ooooo`;o00006oooool2o`0003Kooooo0_l0000Rooooo`009?ooool2
o`0006kooooo0_l0000Dooooo`;o0000@oooool2o`0005kooooo0_l0000Gooooo`009?ooool00ol0
003oooooooooo`2Hooooo`;o0000?_ooool2o`0004kooooo0_l0000Gooooo`009?ooool00ol0003o
ooooooooo`2Hooooo`Co00003oooool2o`0002_ooooo0_l0001Wooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo09[ooooo0_l0000?ooooo`;o0000U?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0dOooool2o`0006kooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`Co00007oooool2o`0007;ooooo0_l0000kooooo`Co0000K?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo00Co0000ooooool0003o00007oooool2o`0007;ooooo0_l0000mooooo`;o0000;_oo
ool2o`0000oooooo0_l0000[ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02Wooooo0_l00035ooooo`;o00004Oooool2o`0000oooooo0_l0000[ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool01?l0003oooooooooooooool2o`0002Kooooo0_l0000Booooo`;o0000;?oo
ool2o`0005Sooooo0_l0000Kooooo`;o00003?ooool2o`0001;ooooo0_l00008ooooo`;o0000<Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`0002cooooo0_l0000<oooo
o`;o0000;?ooool2o`0005Sooooo0_l0000Kooooo`;o00003oooool2o`0000oooooo0_l00008oooo
o`;o0000<Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o00001_ooool2o`0000oooooo0_l00006ooooo`;o00003ooo
ool2o`000:gooooo0_l0000Cooooo`;o00005oooool2o`0003?ooooo000Tooooo`03o`000?oooooo
oooo00Gooooo0_l0000?ooooo`;o00001_ooool2o`00083ooooo0_l0000Kooooo`;o00007oooool2
o`0002cooooo0_l000000ooooooo0000o`000007ooooo`;o00009oooool002Cooooo00?o0000oooo
ooooool0W_ooool4o`0001_ooooo0_l0001@ooooo`;o00001oooool2o`0002Oooooo000Tooooo`03
o`000?oooooooooo01_ooooo0_l0000:ooooo`;o00002oooool2o`0000Wooooo0_l00005ooooo`;o
0000E_ooool2o`0000Gooooo0_l0002Jooooo`009?ooool00ol0003oooooooooo`0Kooooo`;o0000
1?ooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo
0_l0001Mooooo`;o0000V_ooool002Cooooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0
000>ooooo`;o0000;oooool2o`000=gooooo000Tooooo`;o00006Oooool2o`0004Sooooo1?l0001C
ooooo`;o0000H?ooool2o`0002Cooooo000Tooooo`03o`000?oooooooooo05[ooooo0_l00008oooo
o`;o0000D?ooool2o`000003ooooool0003o0000063ooooo0_l0000Tooooo`009?ooool00ol0003o
ooooooooo`1Jooooo`;o0000F_ooool2o`0008Wooooo000Tooooo`03o`000?oooooooooo00;ooooo
0_l00003ooooo`;o0000Woooool2o`0006gooooo0_l0000Eooooo`;o00004Oooool002Cooooo00?o
0000ooooooooool00_ooool2o`0000?ooooo0_l00007ooooo`;o0000I?ooool2o`00033ooooo0_l0
001]ooooo`;o00001_ooool2o`0000gooooo0_l0000Aooooo`009?ooool2o`00017ooooo0_l0001T
ooooo`;o00004Oooool2o`0001Kooooo0_l0000Dooooo`;o0000I_ooool2o`00023ooooo000Toooo
o`03o`000?oooooooooo043ooooo0_l00017ooooo`;o00005_ooool2o`0001Cooooo0_l0001Zoooo
o`;o00007?ooool002Cooooo00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l00013ooooo`;o
0000Soooool2o`0001cooooo000Tooooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o0000
4Oooool2o`0001_ooooo0_l0000Vooooo`;o0000:oooool2o`00083ooooo000Tooooo`03o`000?oo
oooooooo03;ooooo0_l00006ooooo`;o0000;_ooool2o`0000gooooo0_l00014ooooo`;o0000P?oo
ool002Cooooo0_l0001jooooo`;o0000a_ooool002Cooooo00?o0000ooooooooool0Voooool2o`00
08?ooooo0_l0000Oooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Kooooo`;o0000B_ooool2
o`0003Oooooo0_l0000:ooooo`;o00004oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0<_ooooo0_l0000J
ooooo`;o0000@oooool2o`0000;ooooo0_l0000?ooooo`002Oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`;o0000Loooool2
o`0006?ooooo0_l0000?ooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0001?ooooo0_l00011ooooo`;o0000jOooool000Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Cooooo`;o0000ooooool]ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Xooooo`;o0000^?ooool2o`0001gooooo0009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06Sooooo0_l0002hooooo`;o00007Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1;ooooo`;o00001_ooool2o`000<3ooooo0_l0
000Zooooo`009?ooool2o`0004cooooo0_l00006ooooo`;o0000`?ooool2o`0002[ooooo000Toooo
o`03o`000?oooooooooo08cooooo0_l0002cooooo`009?ooool00ol0003oooooooooo`1Aooooo`;o
0000<Oooool2o`0000Kooooo0_l0002cooooo`009?ooool00ol0003oooooooooo`1Aooooo`;o0000
<Oooool2o`0003Cooooo0_l0001=ooooo`;o0000=_ooool002Cooooo00?o0000ooooooooool0^_oo
ool2o`0004gooooo0_l0000fooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`33ooooo`;o0000O?ooool002Cooooo
00?o0000ooooooooool0`oooool2o`0007cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo0_l0003cooooo`;o000000?oooooo`000?l00000<_ooool2o`0001Kooooo000Toooo
o`03o`000?oooooooooo0;7ooooo0_l0000oooooo`;o000000?oooooo`000?l00000<_ooool2o`00
01Kooooo000Tooooo`03o`000?oooooooooo0;7ooooo0_l0002>ooooo`009?ooool3o`0007_ooooo
0_l00034ooooo`009?ooool3o`0007_ooooo0_l00029ooooo`;o0000>Oooool002Cooooo0_l0003o
ooooo`Sooooo0_l0000iooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000ooooool[oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000>Ooo
ool2o`0009_ooooo0_l0001Booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
AOooool2o`0000Wooooo0_l0002Kooooo`;o0000D_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool2o`000?[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Soooool2o`000;3ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Soooool2o`0006Gooooo0_l00019ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
2_ooool2o`000>[ooooo0_l00019ooooo`009?ooool2o`0000_ooooo0_l00018ooooo`;o0000O_oo
ool2o`0004oooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o0000O_ooool2
o`0004oooooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o00001Oooool2o`00
0?oooooo5Oooool002Cooooo00?o0000ooooooooool09?ooool2o`0000Gooooo0ol0003ooooooaCo
oooo000Tooooo`03o`000?oooooooooo00oooooo0_l0000Kooooo`;o0000__ooool2o`0005?ooooo
000Tooooo`;o00004?ooool2o`0008Cooooo0_l0001Eooooo`;o0000Doooool002Cooooo00?o0000
ooooooooool0UOooool2o`000:[ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000A?ooool2o`0009Oooooo0_l0001Sooooo`009?ooool00ol0003oooooooooo`13
ooooo`;o0000Uoooool2o`0006?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1Qooooo`;o0000
g_ooool002Cooooo0_l0001Hooooo`;o00002?ooool2o`000:kooooo0_l0000^ooooo`009?ooool0
0ol0003oooooooooo`1Gooooo`;o0000^?ooool2o`0002kooooo000Jooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`2Sooooo`;o0000W?ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`18ooooo`;o0000FOooool2o`0009cooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool2o`0005?ooooo0_l0002Rooooo`007?oo
ool00ol0003oooooooooo`05ooooo`?o0000WOooool2o`000:;ooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood;ooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
3?ooool2o`000;Wooooo0_l0001hooooo`009?ooool2o`0000gooooo0_l0002iooooo`;o0000N?oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0003kooooo000Tooooo`03o`00
0?oooooooooo0=Kooooo0_l0000Yooooo`;o0000?_ooool002Cooooo0_l0003Gooooo`;o0000JOoo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo05oooooo0_l0002Gooooo`;o0000Aoooool002Cooooo
00?o0000ooooooooool0Goooool2o`0009Oooooo0_l00017ooooo`009?ooool2o`000?oooooo2Ooo
ool2o`0003Sooooo000Tooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Sooooo000Toooo
o`03o`000?oooooooooo05cooooo0_l00007ooooo`;o0000f_ooool002Cooooo00?o0000oooooooo
ool0G?ooool2o`0000Oooooo0_l0000oooooo`;o0000VOooool002Cooooo00?o0000ooooooooool0
Y_ooool2o`0009Wooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`0^
ooooo`;o0000oooooolBooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;_ooool2
o`000?oooooo4_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oOooool2
o`0004;ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?gooooo0_l00012ooooo`001?ooool00ol0003o
ooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02?ooooo0_l0003ooooooagooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8oooool2o`000?oooooo7Oooool000;ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo08Kooooo0_l00002ooooo`;o0000]Oooool002Cooooo0_l00027ooooo`;o00000_oo
ool2o`000;Gooooo000Tooooo`03o`000?oooooooooo0<3ooooo0_l0001oooooo`009?ooool00ol0
003oooooooooo`30ooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`0Jooooo`;o0000oooooolVooooo`009?ooool00ol0003oooooooooo`0Joooo
o`;o0000Y_ooool2o`0007gooooo000Tooooo`03o`000?oooooooooo0<;ooooo0_l0001mooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000ooooooooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0fooo
ool2o`0006Cooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3Kooooo`;o0000I?ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`00
00Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000=[ooooo0_l0001Vooooo`00
9?ooool00ol0003oooooooooo`3Iooooo`;o0000I_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00go
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go0000
1?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0001?ooooo0_l0
003oooooobkooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobkooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`1nooooo`;o0000`Oooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo
07kooooo0_l00031ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo@_ooool001cooooo00?o
MgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo000Ioooo
o`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So410@o`000?lQ8B7o
c<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44566 Mdot
.03333 .23177 Mdot
.0381 .05718 Mdot
.04286 .11901 Mdot
.04762 .15185 Mdot
.05238 .03392 Mdot
.05714 .11843 Mdot
.0619 .00465 Mdot
.06667 .03381 Mdot
.07143 .08418 Mdot
.07619 .03367 Mdot
.08095 .08257 Mdot
.08571 .1806 Mdot
.09048 .58148 Mdot
.09524 .06213 Mdot
.1 .34419 Mdot
.10476 .09159 Mdot
.10952 .01468 Mdot
.11429 .56405 Mdot
.11905 .19867 Mdot
.12381 .14384 Mdot
.12857 .14848 Mdot
.13333 .10253 Mdot
.1381 .15177 Mdot
.14286 .38771 Mdot
.14762 .37043 Mdot
.15238 .12136 Mdot
.15714 .12064 Mdot
.1619 .06237 Mdot
.16667 .12842 Mdot
.17143 .15687 Mdot
.17619 .22705 Mdot
.18095 .04569 Mdot
.18571 .28699 Mdot
.19048 .32645 Mdot
.19524 .10192 Mdot
.2 .00839 Mdot
.20476 .07575 Mdot
.20952 .17648 Mdot
.21429 .13635 Mdot
.21905 .04438 Mdot
.22381 .08634 Mdot
.22857 .13224 Mdot
.23333 .12785 Mdot
.2381 .18451 Mdot
.24286 .22239 Mdot
.24762 .45888 Mdot
.25238 .08638 Mdot
.25714 .15686 Mdot
.2619 .01692 Mdot
.26667 .02208 Mdot
.27143 .11382 Mdot
.27619 .00896 Mdot
.28095 .08591 Mdot
.28571 .32521 Mdot
.29048 .126 Mdot
.29524 .07014 Mdot
.3 .15284 Mdot
.30476 .29501 Mdot
.30952 .0519 Mdot
.31429 .02012 Mdot
.31905 .16549 Mdot
.32381 .00395 Mdot
.32857 .32495 Mdot
.33333 .11888 Mdot
.3381 .32366 Mdot
.34286 .14214 Mdot
.34762 .01097 Mdot
.35238 .02631 Mdot
.35714 .04804 Mdot
.3619 .13563 Mdot
.36667 .15899 Mdot
.37143 .11538 Mdot
.37619 .00759 Mdot
.38095 .00263 Mdot
.38571 .00342 Mdot
.39048 .02364 Mdot
.39524 .03776 Mdot
.4 .12307 Mdot
.40476 .0254 Mdot
.40952 .10093 Mdot
.41429 .21412 Mdot
.41905 .04943 Mdot
.42857 .0003 Mdot
.43333 .08927 Mdot
.4381 .05812 Mdot
.44286 .1804 Mdot
.44762 .47562 Mdot
.45238 .03958 Mdot
.45714 .12603 Mdot
.4619 .55328 Mdot
.46667 .17618 Mdot
.47143 .04356 Mdot
.47619 .33514 Mdot
.48095 .24412 Mdot
.48571 .1328 Mdot
.49048 .07754 Mdot
.49524 .2839 Mdot
.5 .07909 Mdot
.50476 .06353 Mdot
.50952 .0665 Mdot
.51429 .32259 Mdot
.51905 .4609 Mdot
.52381 .22084 Mdot
.52857 .16551 Mdot
.53333 .01289 Mdot
.5381 .02912 Mdot
.54286 .42359 Mdot
.54762 .32299 Mdot
.55238 .03438 Mdot
.55714 .02247 Mdot
.5619 .06798 Mdot
.56667 .04654 Mdot
.57143 .03028 Mdot
.57619 .01511 Mdot
.58095 .18623 Mdot
.58571 .03312 Mdot
.59048 .00925 Mdot
.59524 .35307 Mdot
.6 .11407 Mdot
.60476 .20953 Mdot
.60952 .01135 Mdot
.61429 .14153 Mdot
.61905 .17859 Mdot
.62381 .11655 Mdot
.62857 .33099 Mdot
.63333 .43515 Mdot
.6381 .07487 Mdot
.64286 .06106 Mdot
.64762 .02608 Mdot
.65238 .27153 Mdot
.65714 .0126 Mdot
.6619 .08635 Mdot
.66667 .02836 Mdot
.67143 .04108 Mdot
.67619 .03288 Mdot
.68095 .06197 Mdot
.68571 .25429 Mdot
.69048 .1589 Mdot
.69524 .32431 Mdot
.7 .09295 Mdot
.70476 .33078 Mdot
.70952 .22104 Mdot
.71429 .05669 Mdot
.71905 .04146 Mdot
.72381 .05306 Mdot
.72857 .02596 Mdot
.73333 .07874 Mdot
.7381 .19265 Mdot
.74286 .05592 Mdot
.74762 .34429 Mdot
.75238 .0144 Mdot
.75714 .01964 Mdot
.7619 .26025 Mdot
.76667 .26871 Mdot
.77143 .04862 Mdot
.77619 .19057 Mdot
.78095 .51197 Mdot
.78571 .12834 Mdot
.79048 .0422 Mdot
.79524 .25009 Mdot
.8 .49494 Mdot
.80476 .00734 Mdot
.80952 .02164 Mdot
.81429 .15486 Mdot
.81905 .07313 Mdot
.82381 .03027 Mdot
.82857 .17871 Mdot
.83333 .23536 Mdot
.8381 .3231 Mdot
.84286 .37047 Mdot
.84762 .18734 Mdot
.85238 .16513 Mdot
.85714 .07941 Mdot
.8619 .00141 Mdot
.86667 .08511 Mdot
.87143 .042 Mdot
.87619 .42642 Mdot
.88095 .01231 Mdot
.88571 .12371 Mdot
.89048 .19887 Mdot
.89524 .12033 Mdot
.9 .09511 Mdot
.90476 .02504 Mdot
.90952 .1106 Mdot
.91429 .05411 Mdot
.91905 .12371 Mdot
.92381 .14383 Mdot
.92857 .16317 Mdot
.93333 .16441 Mdot
.9381 .17334 Mdot
.94286 .02175 Mdot
.94762 .23541 Mdot
.95238 .00531 Mdot
.95714 .00977 Mdot
.9619 .11812 Mdot
.96667 .1791 Mdot
.97143 .07561 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00009ooooo`03
o`000?oooooooooo00Cooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o
00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool002Cooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003ooooo00kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000oooooooo
ool01?ooool4o`0000Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0<ooooo`00
9?ooool00ol0003oooooooooo`09ooooo`;o0000:_ooool2o`0001Oooooo0_l0000Nooooo`;o0000
A?ooool2o`0004?ooooo0_l0000^ooooo`Co00005?ooool002Cooooo00?o0000ooooooooool0=Ooo
ool2o`0001Oooooo0_l0000Eooooo`;o00001oooool2o`00037ooooo0_l0000Aooooo`;o00001?oo
ool2o`0000kooooo0_l0000]ooooo`;o00005oooool2o`0001Oooooo0_l0000Dooooo`009?ooool2
o`0001Wooooo0_l0001;ooooo`;o0000>_ooool2o`0000cooooo0_l00009ooooo`;o00003_ooool2
o`0001gooooo0_l0000Wooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool06?ooool2o`00
02oooooo0_l0001Tooooo`;o0000>?ooool2o`0005Kooooo000Tooooo`03o`000?oooooooooo04Wo
oooo1?l0000=ooooo`;o0000COooool2o`0003oooooo0_l0000?ooooo`;o0000:Oooool2o`0001Wo
oooo000Tooooo`03o`000?oooooooooo04_ooooo0_l0000=ooooo`;o00005oooool2o`0000?ooooo
0_l0000_ooooo`;o0000?oooool2o`0000oooooo0_l0000Mooooo`;o00002_ooool2o`0001Wooooo
000Tooooo`03o`000?oooooooooo06Oooooo0_l0000:ooooo`;o00000oooool2o`0004gooooo0_l0
0004ooooo`;o00004_ooool2o`0003Oooooo0_l0000Uooooo`009?ooool2o`0006Sooooo0_l0000j
ooooo`;o00002Oooool2o`0001Oooooo0_l00004ooooo`;o00004_ooool2o`0001gooooo0_l0000o
ooooo`009?ooool00ol0003oooooooooo`05ooooo`;o00000oooool2o`000003ooooool0003o0000
09Cooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000Looooo`;o0000;_ooool2o`00
03oooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o000000?oooooo`000?l0
0000I_ooool2o`00037ooooo0_l00008ooooo`;o00007?ooool2o`0006oooooo000Tooooo`03o`00
0?oooooooooo07Gooooo0_l0000@ooooo`;o0000^?ooool002Cooooo00?o0000ooooooooool0Qooo
ool2o`0000Cooooo0_l0000oooooo`;o00003_ooool2o`0001Gooooo0_l0000Hooooo`;o0000<?oo
ool002Cooooo0_l0000`ooooo`;o00002oooool2o`0004oooooo0_l0000Mooooo`;o00008?ooool2
o`0000kooooo0_l0000Eooooo`;o00006?ooool2o`00033ooooo000Tooooo`03o`000?oooooooooo
02oooooo0_l0000;ooooo`;o0000:_ooool2o`0001;ooooo0_l0000^ooooo`;o0000@Oooool2o`00
053ooooo000Tooooo`03o`000?oooooooooo05Wooooo0_l0000=ooooo`;o00004_ooool2o`00067o
oooo0_l0000>ooooo`;o0000D?ooool002Cooooo00?o0000ooooooooool0FOooool2o`0008Cooooo
0_l00004ooooo`;o0000=_ooool2o`0002;ooooo000Tooooo`04o`000?ooooooooooooooo`;o0000
P?ooool2o`0005Oooooo0_l00007ooooo`;o0000=_ooool2o`0002;ooooo000Tooooo`;o00000_oo
ool2o`00013ooooo0_l0000Dooooo`;o0000F?ooool2o`00043ooooo0_l0000:ooooo`;o00002Ooo
ool2o`0006?ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l0000Dooooo`;o0000KOooool2
o`0002_ooooo0_l0000:ooooo`;o0000K_ooool002Cooooo00?o0000ooooooooool0V?ooool4o`00
00oooooo0_l0002Dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05Cooooo0_l0
0014ooooo`;o00003oooool2o`0009Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo05Cooooo0_l0001]ooooo`;o0000>Oooool2o`00047ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`?o0000=oooool2o`0005_ooooo0_l0000]ooooo`;o0000>Oooool2o`00033ooooo
0_l0000?ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0gooooo`;o0000Fooo
ool2o`000003ooooool0003o000004Wooooo0_l0000Vooooo`;o00009?ooool2o`0000oooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03?ooool2o`000003ooooool0
003o000008Kooooo0_l00019ooooo`;o00009_ooool2o`0003Gooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000o`00000/ooooo`;o00001oooool2
o`0000Sooooo0_l0001iooooo`;o0000@Oooool2o`00037ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0?Oooool2o`0000Oooooo0_l00008ooooo`;o0000;oooool2o`0004Sooooo
0_l00011ooooo`;o0000<Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00005oooool2o`0006Wooooo0_l0001Eoooo
o`;o0000Ioooool002Cooooo00?o0000ooooooooool05_ooool2o`000<3ooooo0_l0000nooooo`;o
00009oooool002Cooooo00?o0000ooooooooool0oooooolIooooo`;o00009oooool002Cooooo00?o
0000ooooooooool08?ooool2o`0001;ooooo0_l00013ooooo`;o0000a_ooool002Cooooo00?o0000
ooooooooool08?ooool2o`0001;ooooo0_l00013ooooo`;o0000a_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo7Oooool2o`0002Cooooo000Tooooo`03o`00
0?oooooooooo04gooooo0_l0001Xooooo`;o0000H_ooool2o`0002Cooooo000Tooooo`03o`000?oo
oooooooo04gooooo0_l0000Nooooo`;o0000B?ooool2o`0000Kooooo0_l0001[ooooo`;o00004ooo
ool002Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0_l0000Nooooo`;o0000>?ooool2
o`0000[ooooo0_l0001@ooooo`;o0000E_ooool2o`0001?ooooo0_l0000Cooooo`009?ooool00ol0
003oooooooooo`02ooooo`;o00000oooool2o`0001gooooo0ol0000hooooo`;o00004oooool2o`00
09cooooo0_l000000ooooooo0000o`000006ooooo`;o00008?ooool002Cooooo0_l0000Wooooo`;o
0000:oooool2o`00027ooooo0_l0000Aooooo`;o0000ROooool2o`0000Wooooo0_l0000Pooooo`00
9?ooool00ol0003oooooooooo`0[ooooo`;o00004oooool2o`00017ooooo0_l0000dooooo`;o0000
J?ooool2o`0004cooooo000Tooooo`03o`000?oooooooooo02_ooooo0_l0000Booooo`?o0000D?oo
ool2o`0005oooooo0_l0001<ooooo`009?ooool00ol0003oooooooooo`0jooooo`;o00000oooool2
o`0002Wooooo0_l0000Vooooo`;o0000[Oooool002Cooooo00?o0000ooooooooool0>_ooool2o`00
02kooooo0_l0003Eooooo`009?ooool2o`0006Gooooo0_l0001Fooooo`;o0000Poooool002Cooooo
00?o0000ooooooooool07Oooool2o`0004Gooooo0_l0001Fooooo`;o0000H_ooool2o`0001oooooo
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01gooooo0ol0003oooooo`7ooooo0_l0000Oooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool01?ooool2o`0001Sooooo0_l000000ooooooo0000o`00003ooooooaoo
oooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0_l0000Kooooo`;o0000<oooool2o`000:Gooooo0_l00012ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002co
oooo0_l0000Jooooo`;o00003?ooool2o`000:Gooooo0_l00012ooooo`002Oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
02cooooo0_l0000Jooooo`;o00008Oooool2o`0006Oooooo0_l0001[ooooo`002Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1[oooo
o`;o0000Ioooool2o`0004cooooo0_l0000Mooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Looooo`;o0000@_ooool2o`00
06Oooooo0_l0000Gooooo`?o00007?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`1Looooo`;o0000@_ooool2o`0006Oooooo0_l0000Hoooo
o`;o00007?ooool002Cooooo0_l0003oooooobOooooo0_l0000Jooooo`009?ooool00ol0003ooooo
ooooo`0hooooo`;o0000D_ooool2o`0009Oooooo0_l0000Jooooo`009?ooool00ol0003ooooooooo
o`0hooooo`;o0000D_ooool2o`0002oooooo0_l00012ooooo`;o0000:oooool2o`00017ooooo000T
ooooo`03o`000?oooooooooo013ooooo0_l0001booooo`;o0000=oooool2o`0004;ooooo0_l0000[
ooooo`;o00004Oooool002Cooooo00?o0000ooooooooool04?ooool2o`00033ooooo0_l00010oooo
o`;o0000^oooool002Cooooo0_l00013ooooo`;o0000KOooool2o`0005Cooooo0_l0000hooooo`00
9?ooool00ol0003oooooooooo`2aooooo`;o0000?Oooool2o`0001Gooooo0_l0000hooooo`009?oo
ool00ol0003oooooooooo`3Tooooo`;o00002_ooool2o`0004oooooo000Tooooo`03o`000?oooooo
oooo0>Cooooo0_l0001Kooooo`009?ooool00ol0003oooooooooo`0Kooooo`;o0000n?ooool2o`00
02[ooooo000Tooooo`;o00007?ooool2o`000?Sooooo0_l0000Zooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0;Wooooo0_l00026ooooo`009?ooool0
0ol0003oooooooooo`2iooooo`;o0000Q_ooool002Cooooo00?o0000ooooooooool0Noooool2o`00
0<Cooooo000Tooooo`;o0000O?ooool2o`000<Cooooo000Tooooo`03o`000?oooooooooo04?ooooo
0_l0001Iooooo`;o0000>oooool2o`0006Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo04?ooooo0_l0001Iooooo`;o0000>oooool2o`0006Cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0^ooooo`;o0000oooooolBooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool01?l0003oooooo`000?l0000]ooooo`;o0000oooooolBooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool4o`000?oooooo@Oooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`3oooooo`Cooooo0_l0000Sooooo`;o00005oooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooool4ooooo`;o00008oooool2o`0001Oooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0T?ooool2o`000:oooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2@ooooo`;o0000[ooo
ool002Cooooo0_l0003gooooo`;o0000BOooool002Cooooo00?o0000ooooooooool0m_ooool2o`00
04Wooooo000Tooooo`03o`000?oooooooooo0=?ooooo0_l0001/ooooo`009?ooool00ol0003ooooo
ooooo`3Cooooo`;o0000K?ooool002Cooooo00?o0000ooooooooool0k?ooool2o`0005?ooooo000T
ooooo`;o0000kOooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo0>gooooo0_l0001Boooo
o`009?ooool00ol0003oooooooooo`38ooooo`;o00008oooool2o`0005;ooooo000Tooooo`03o`00
0?oooooooooo0<Sooooo0_l0001gooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`2Eooooo`;o0000Z_ooool002Co
oooo00?o0000ooooooooool0<Oooool2o`0006;ooooo0_l0002Zooooo`009?ooool00ol0003ooooo
ooooo`0aooooo`;o0000ooooool?ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000F?ooool2o`000>Sooooo000Tooooo`03o`000?oooooooooo05Oooooo0_l0003Xoooo
o`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooo
oooo00Gooooo0ol0003ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo
000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0H_ooool2o`0003Oooooo0_l0
0009ooooo`;o0000;_ooool2o`0002cooooo0_l0000kooooo`009?ooool2o`0003?ooooo0_l0000M
ooooo`;o00003?ooool2o`000003ooooool0003o000003Oooooo0_l00009ooooo`;o0000;_ooool2
o`0002cooooo0_l0000kooooo`009?ooool00ol0003oooooooooo`0booooo`;o00007Oooool2o`00
00cooooo0_l0001hooooo`;o0000I_ooool002Cooooo00?o0000ooooooooool0`?ooool2o`0001Oo
oooo0_l0001Vooooo`009?ooool00ol0003oooooooooo`2?ooooo`;o0000;oooool2o`0007oooooo
000Tooooo`03o`000?oooooooooo08oooooo0_l0002`ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool05Oooool2o`000=3ooooo0_l0001Hooooo`009?ooool00ol0003o
ooooooooo`0Eooooo`;o0000d?ooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0]_ooool2o`0008Wooooo000Tooooo`;o0000]oooool2
o`0008Wooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo02Cooooo0_l0003Pooooo`;o0000>Oooool002Cooooo0_l0000Uooooo`;o0000h?ooool2
o`0003Wooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
8oooool2o`000?oooooo7Oooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Sooooo`;o0000
oooooolMooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2Uooooo`;o0000J_ooool2o`0002ko
oooo000Tooooo`03o`000?oooooooooo0:Gooooo0_l0001Zooooo`;o0000;_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`000<?ooooo0_l0001mooooo`009?ooool00ol0
003oooooooooo`32ooooo`;o0000OOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`?o0000oooooom2ooooo`009?ooool3
o`000?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0AOooool2o`000?[ooooo000<ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`;o0000
E_ooool2o`000:;ooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0009gooooo0_l0002Rooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`26oooo
o`;o0000^Oooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000oooooooo
ool0Q_ooool2o`000;Wooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
nOooool2o`0004Oooooo000Tooooo`03o`000?oooooooooo0?Sooooo0_l00017ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000??ooooo0_l0001=ooooo`009?oo
ool00ol0003oooooooooo`3booooo`;o0000COooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo0004
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo
00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oo
oooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool0R_ooool2o`000;Gooooo000Tooooo`;o0000Roooool2
o`000;Gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool06_ooool2o`000?oooooo9_ooool002Cooooo00?o0000ooooooooool06_ooool2o`000?oooooo
9_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobkooooo000Tooooo`03o`000?oo
oooooooo01;ooooo0_l0003oooooobkooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`Go
00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oom2ooooo`007?ooool00omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo
0?ooooooBOooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30548 Mdot
.03333 .39661 Mdot
.0381 .02762 Mdot
.04286 .11901 Mdot
.04762 .01782 Mdot
.05238 .03392 Mdot
.05714 .11843 Mdot
.0619 .00465 Mdot
.06667 .03381 Mdot
.07143 .08418 Mdot
.07619 .03367 Mdot
.08095 .05436 Mdot
.08571 .11943 Mdot
.09048 .3636 Mdot
.09524 .05642 Mdot
.1 .04214 Mdot
.10476 .02769 Mdot
.10952 .01468 Mdot
.11429 .37652 Mdot
.11905 .00043 Mdot
.12381 .03671 Mdot
.12857 .07573 Mdot
.13333 .20725 Mdot
.1381 .08828 Mdot
.14286 .55252 Mdot
.14762 .4294 Mdot
.15238 .12077 Mdot
.15714 .05254 Mdot
.1619 .13889 Mdot
.16667 .12842 Mdot
.17143 .15687 Mdot
.17619 .06073 Mdot
.18095 .04569 Mdot
.18571 .14873 Mdot
.19048 .11478 Mdot
.19524 .0818 Mdot
.2 .00839 Mdot
.20476 .06161 Mdot
.20952 .07643 Mdot
.21429 .13635 Mdot
.21905 .18075 Mdot
.22381 .08634 Mdot
.22857 .22006 Mdot
.23333 .02117 Mdot
.2381 .10378 Mdot
.24286 .09945 Mdot
.24762 .35348 Mdot
.25238 .09029 Mdot
.25714 .07421 Mdot
.2619 .01692 Mdot
.26667 .02208 Mdot
.27143 .0161 Mdot
.27619 .10558 Mdot
.28095 .10953 Mdot
.28571 .09184 Mdot
.29048 .44801 Mdot
.29524 .07014 Mdot
.3 .08905 Mdot
.30476 .21065 Mdot
.30952 .25299 Mdot
.31429 .02012 Mdot
.31905 .16549 Mdot
.32381 .18035 Mdot
.32857 .36804 Mdot
.33333 .06576 Mdot
.3381 .22569 Mdot
.34286 .14214 Mdot
.34762 .01097 Mdot
.35238 .09642 Mdot
.35714 .07035 Mdot
.3619 .02184 Mdot
.36667 .21953 Mdot
.37143 .14631 Mdot
.37619 .0374 Mdot
.38095 .13169 Mdot
.38571 .03129 Mdot
.39048 .04575 Mdot
.39524 .03776 Mdot
.4 .26534 Mdot
.40476 .0254 Mdot
.40952 .14316 Mdot
.41429 .40154 Mdot
.41905 .05245 Mdot
.42857 .20134 Mdot
.43333 .08927 Mdot
.4381 .07142 Mdot
.44286 .0813 Mdot
.44762 .10098 Mdot
.45238 .03958 Mdot
.45714 .15546 Mdot
.4619 .10198 Mdot
.46667 .25906 Mdot
.47143 .00502 Mdot
.47619 .06704 Mdot
.48095 .18847 Mdot
.48571 .02421 Mdot
.49048 .07754 Mdot
.49524 .30978 Mdot
.5 .03001 Mdot
.50476 .00932 Mdot
.50952 .0665 Mdot
.51429 .12765 Mdot
.51905 .30267 Mdot
.52381 .15505 Mdot
.52857 .09094 Mdot
.53333 .01289 Mdot
.5381 .02912 Mdot
.54286 .48929 Mdot
.54762 .38914 Mdot
.55238 .2125 Mdot
.55714 .26698 Mdot
.5619 .18114 Mdot
.56667 .12547 Mdot
.57143 .00761 Mdot
.57619 .19692 Mdot
.58095 .16928 Mdot
.58571 .0003 Mdot
.59048 .22389 Mdot
.59524 .41526 Mdot
.6 .17766 Mdot
.60476 .3336 Mdot
.60952 .00599 Mdot
.61429 .22312 Mdot
.61905 .22577 Mdot
.62381 .20687 Mdot
.62857 .40578 Mdot
.63333 .3924 Mdot
.6381 .07487 Mdot
.64286 .06106 Mdot
.64762 .02608 Mdot
.65238 .27153 Mdot
.65714 .09064 Mdot
.6619 .08635 Mdot
.66667 .0285 Mdot
.67143 .04108 Mdot
.67619 .15417 Mdot
.68095 .06197 Mdot
.68571 .11338 Mdot
.69048 .21757 Mdot
.69524 .03965 Mdot
.7 .09295 Mdot
.70476 .60565 Mdot
.70952 .08605 Mdot
.71429 .05669 Mdot
.71905 .23479 Mdot
.72381 .05306 Mdot
.72857 .02055 Mdot
.73333 .07874 Mdot
.7381 .27816 Mdot
.74286 .05592 Mdot
.74762 .12455 Mdot
.75238 .0144 Mdot
.75714 .01964 Mdot
.7619 .05923 Mdot
.76667 .17218 Mdot
.77143 .04862 Mdot
.77619 .26211 Mdot
.78095 .27116 Mdot
.78571 .01194 Mdot
.79048 .0422 Mdot
.79524 .45504 Mdot
.80476 .00734 Mdot
.80952 .08973 Mdot
.81429 .15486 Mdot
.81905 .0214 Mdot
.82381 .03027 Mdot
.82857 .17871 Mdot
.83333 .1467 Mdot
.8381 .23751 Mdot
.84286 .37961 Mdot
.84762 .17 Mdot
.85238 .16072 Mdot
.85714 .05587 Mdot
.8619 .15548 Mdot
.86667 .09771 Mdot
.87143 .042 Mdot
.87619 .23174 Mdot
.88095 .07788 Mdot
.88571 .07741 Mdot
.89048 .10699 Mdot
.89524 .02753 Mdot
.9 .24776 Mdot
.90476 .02504 Mdot
.90952 .1106 Mdot
.91429 .22829 Mdot
.91905 .348 Mdot
.92381 .21072 Mdot
.92857 .35337 Mdot
.93333 .28003 Mdot
.9381 .17482 Mdot
.94286 .02175 Mdot
.94762 .17253 Mdot
.95238 .23748 Mdot
.95714 .00977 Mdot
.9619 .11812 Mdot
.96667 .05987 Mdot
.97143 .08753 Mdot
.97619 .44276 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02?ooool2o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00Wooooo0_l0
00000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`04o`000?oo
ooooooooooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
000Tooooo`03o`000?oooooooooo00Wooooo0_l0000Zooooo`;o0000E_ooool2o`0000Wooooo0_l0
000Dooooo`;o00002_ooool2o`0003gooooo0_l0000`ooooo`;o00005?ooool002Cooooo00?o0000
ooooooooool0=Oooool2o`0002kooooo0_l0000aooooo`;o00001oooool2o`0000_ooooo0_l00013
ooooo`;o00001?ooool2o`00033ooooo0_l0000Dooooo`009?ooool2o`0001Wooooo0_l0000coooo
o`;o00005_ooool2o`0003[ooooo0_l00016ooooo`;o00002?ooool2o`0004cooooo000Tooooo`03
o`000?oooooooooo00Cooooo0_l0000Booooo`;o0000;oooool2o`0000;ooooo0_l0002Jooooo`;o
0000E_ooool002Cooooo00?o0000ooooooooool01?ooool2o`0003[ooooo0_l00007ooooo`Co0000
3Oooool2o`0000kooooo0_l0001eooooo`;o00001oooool2o`0001;ooooo0_l0000Vooooo`;o0000
6Oooool002Cooooo00?o0000ooooooooool0@?ooool2o`0000Wooooo0_l0000=ooooo`;o00003_oo
ool2o`0000cooooo0_l0000Hooooo`;o0000COooool2o`0000Oooooo0_l0000Booooo`;o00006_oo
ool2o`0000[ooooo0_l0000Iooooo`009?ooool01?l0003oooooooooooooool2o`0001?ooooo0_l0
001Pooooo`;o00006?ooool2o`0003?ooooo0_l00004ooooo`;o0000B?ooool2o`000003ooooool0
003o000002Gooooo000Tooooo`;o00000_ooool2o`0001?ooooo0_l0001Jooooo`;o00008oooool2
o`0000[ooooo0_l0000Rooooo`;o00001?ooool2o`00037ooooo0_l0000Eooooo`;o0000:?ooool0
02Cooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l000000ooooooo0000o`00001Soooo
o`;o00008oooool2o`0000[ooooo0_l0001Kooooo`;o0000?oooool002Cooooo00?o0000oooooooo
ool01Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000Coooool2o`0000Go
oooo0_l0003:ooooo`009?ooool00ol0003oooooooooo`0Mooooo`;o0000Coooool2o`0000Gooooo
0_l0000@ooooo`;o0000COooool2o`0006Wooooo000Tooooo`03o`000?oooooooooo01Gooooo0_l0
001`ooooo`;o0000AOooool2o`0000Kooooo0_l0000Mooooo`;o00006?ooool2o`00033ooooo000T
ooooo`;o00005_ooool2o`0001Sooooo0_l00012ooooo`;o0000FOooool2o`0002Gooooo0_l0000H
ooooo`;o0000<?ooool002Cooooo00?o0000ooooooooool0;oooool2o`0004;ooooo0_l0001joooo
o`;o0000D?ooool002Cooooo00?o0000ooooooooool09oooool2o`0005?ooooo0_l0001Qooooo`;o
00003_ooool2o`00053ooooo000Tooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`;o0000
4_ooool2o`0005?ooooo0_l0001Qooooo`;o00001?ooool2o`0002?ooooo0_l0000eooooo`009?oo
ool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`000<Oooooo0_l00007ooooo`;o00001Ooo
ool2o`0001cooooo0_l0000eooooo`009?ooool2o`0002oooooo0_l00007ooooo`;o0000S?ooool2
o`0000[ooooo0_l00009ooooo`;o00003_ooool2o`00043ooooo0_l0000Aooooo`009?ooool00ol0
003oooooooooo`0^ooooo`;o00001oooool2o`0008cooooo0_l0000:ooooo`;o0000Foooool2o`00
017ooooo000Tooooo`03o`000?oooooooooo067ooooo0_l0000/ooooo`;o00002Oooool2o`000:Go
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0E?ooool2o`0000_ooooo0_l00005
ooooo`;o00006Oooool2o`0000[ooooo0_l00009ooooo`;o0000YOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo0_l0000Booooo`;o0000
6Oooool2o`0003kooooo0_l0001looooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001kooooo0_l0
000Hooooo`;o00003_ooool2o`0004[ooooo0_l0000]ooooo`;o0000COooool4o`0002_ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01kooooo0_l0000Hooooo`;o0000F_ooool2
o`0004cooooo0_l0000^ooooo`Co0000:oooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0<ooooo`;o00009_ooool2o`0004kooooo0_l0001Looooo`;o0000GOooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`0002Kooooo0_l00007oooo
o`;o0000AOooool2o`0004Gooooo0_l0000>ooooo`;o0000I?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Qooooo`;o00006_ooool2o`0000Oooooo0_l0000>ooooo`;o0000:Ooo
ool2o`0004Sooooo0_l0000>ooooo`;o00007_ooool2o`0003?ooooo0_l0000?ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo0_l0000Rooooo`;o00008oooool2o`0000Wooooo0_l00003ooooo`;o0000:Oooool2o`0001go
oooo0_l0000Xooooo`;o00003?ooool2o`00027ooooo0_l0000cooooo`;o00003oooool002Cooooo
00?o0000ooooooooool0DOooool2o`0001Cooooo0_l0000gooooo`;o0000:?ooool2o`0000cooooo
0_l0001Wooooo`009?ooool00ol0003oooooooooo`13ooooo`;o00008_ooool2o`000:Gooooo0_l0
000aooooo`009?ooool00ol0003oooooooooo`13ooooo`;o0000@Oooool2o`0000;ooooo0_l00022
ooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool0@_ooool2o`0000[ooooo0_l0000foooo
o`;o00000_ooool2o`000;Gooooo000Tooooo`03o`000?oooooooooo04;ooooo0_l0000:ooooo`;o
0000aOooool2o`0002[ooooo000Tooooo`;o0000DOooool2o`000<?ooooo0_l00004ooooo`;o0000
9?ooool002Cooooo00?o0000ooooooooool0<_ooool2o`0001cooooo0_l00021ooooo`;o0000A_oo
ool2o`0002Cooooo000Tooooo`03o`000?oooooooooo03;ooooo0_l0002Oooooo`;o0000Eoooool2
o`0001?ooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00001oooool2o`00
01Cooooo0_l0003oooooo`Gooooo0_l0000Cooooo`009?ooool00ol0003oooooooooo`02ooooo`;o
00000oooool2o`0000Oooooo0_l0000Dooooo`;o0000oooooolJooooo`009?ooool2o`000:gooooo
0_l0000iooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool0:oooool2o`0006kooooo0_l0
000?ooooo`;o0000>Oooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo02_ooooo0_l00013
ooooo`;o0000:Oooool2o`000:Cooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0000doooo
o`;o0000coooool002Cooooo00?o0000ooooooooool0:Oooool2o`0000oooooo0_l0003oooooo`Ko
oooo000Tooooo`;o0000:_ooool2o`0003Wooooo0_l0003Kooooo`009?ooool00ol0003ooooooooo
o`1Tooooo`;o00004oooool2o`000<Kooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo
0_l0000jooooo`;o00002_ooool2o`0008Sooooo0_l0000looooo`002Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
<Oooool2o`0003[ooooo0_l0002Dooooo`;o0000??ooool000Wooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0W_ooool2o`00033ooooo
0_l0000[ooooo`;o0000@_ooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0000/ooooo`;o0000Foooool2o`0001?ooooo0_l0000`ooooo`;o0000
:oooool2o`0000gooooo0_l0000cooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02cooooo0_l0001Kooooo`;o
0000O_ooool2o`000003ooooool0003o000003?ooooo0009ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0003Ko
oooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05cooooo0_l0003Sooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`03o`000?oooooooooo05cooooo0_l0001Cooooo`;o0000E?ooool2o`0003So
oooo000Tooooo`;o0000/_ooool2o`0003[ooooo0_l0000Hooooo`;o00007oooool2o`0001Oooooo
000Tooooo`03o`000?oooooooooo0>gooooo0_l0000fooooo`;o000000?oooooo`000?l000005ooo
ool002Cooooo00?o0000ooooooooool0]oooool2o`0004Sooooo0_l0000Rooooo`;o00006_ooool0
02Cooooo00?o0000ooooooooool0??ooool2o`00023ooooo0_l0001;ooooo`;o00002_ooool2o`00
04Sooooo0_l0000nooooo`009?ooool00ol0003oooooooooo`0looooo`;o00008?ooool2o`0004_o
oooo0_l0002Dooooo`009?ooool2o`00097ooooo0_l0002_ooooo`009?ooool00ol0003ooooooooo
o`2@ooooo`;o0000[oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`2_ooooo`;o0000T?ooool002Cooooo00?o0000ooooooooool0Ooooool2o`0002ko
oooo0_l0002@ooooo`009?ooool2o`00083ooooo0_l00030ooooo`009?ooool00ol0003ooooooooo
o`0Pooooo`;o0000WOooool2o`00083ooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000e
ooooo`;o0000I_ooool2o`00083ooooo000Tooooo`03o`000?oooooooooo05Oooooo0_l0001?oooo
o`;o0000M_ooool2o`0001oooooo000Tooooo`03o`000?oooooooooo0:Sooooo0_l0001fooooo`;o
00007oooool002Cooooo0_l0001/ooooo`;o0000Ioooool2o`0006_ooooo000Tooooo`03o`000?oo
oooooooo03oooooo0_l0000Zooooo`;o0000Ioooool2o`0006_ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo03oooooo0_l0000Qooooo`;o0000D?ooool2o`0000Ko
oooo0ol00022ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0H_ooool2o`00
053ooooo0_l00006ooooo`?o0000G_ooool2o`0002;ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo4_ooool2o`0000[ooooo0_l0000Rooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000=kooooo0_l0000aooooo`;o0000;_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3Nooooo`;o00009?ooool2o`0002?ooooo0_l0000Fooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooo`Gooooo0_l0000Sooooo`;o00005_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooolJooooo`;o00009oooool002Cooooo00?o0000ooooooooool0
FOooool2o`000;gooooo0_l0000Wooooo`009?ooool00ol0003oooooooooo`1Iooooo`;o0000i_oo
ool002Cooooo00?o0000ooooooooool0S?ooool2o`000;?ooooo000Tooooo`03o`000?oooooooooo
08cooooo0_l0001Rooooo`;o0000Coooool002Cooooo0_l0001gooooo`;o0000N?ooool2o`0004oo
oooo000Tooooo`03o`000?oooooooooo07Kooooo0_l0000aooooo`;o0000U_ooool002Cooooo00?o
0000ooooooooool0ZOooool2o`0001gooooo0_l0000Xooooo`;o0000COooool002Cooooo00?o0000
ooooooooool0b?ooool2o`0002Sooooo0_l0001=ooooo`009?ooool00ol0003oooooooooo`3Toooo
o`;o0000Foooool002Cooooo0_l0003Uooooo`;o0000?Oooool2o`0001cooooo000Tooooo`03o`00
0?oooooooooo0?oooooo9?ooool2o`0001cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2Mooooo`;o0000X_oo
ool001cooooo00?o0000ooooooooool01Oooool3o`0009gooooo0_l0002Rooooo`007?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`?o
0000UOooool2o`000:[ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
UOooool2o`000:[ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool0
01[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0;Wooooo0_l00026ooooo`009?ooool00ol0003oooooooooo`2iooooo`;o0000Q_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3oooooob3ooooo0_l0
000Pooooo`009?ooool00ol0003oooooooooo`3oooooob3ooooo0_l0000Pooooo`009?ooool00ol0
003oooooooooo`15ooooo`;o0000foooool2o`0001gooooo000Tooooo`;o0000A_ooool2o`000=_o
oooo0_l0000Mooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo01;ooooo0_l0003oooooobkooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0003o
ooooobkooooo000Tooooo`03o`000?oooooooooo05oooooo0_l0003Pooooo`009?ooool2o`00063o
oooo0_l0003Pooooo`009?ooool00ol0003oooooooooo`0Jooooo`;o0000oooooolVooooo`000_oo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool06_ooool2o`000>[ooooo0_l0000iooooo`001?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooo`Oooooo0_l0000iooooo`001?oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000Y_ooool2o`0009Wooooo0004oooo
o`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0Y_ooool2o`0001[ooooo0_l0001mooooo`001?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`32ooooo`;o0000OOooool000Cooooo00?o0000ooooooooool02_ooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l0003o
oooood7ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool01?l0003oooooo`000?l0001jooooo`;o0000a?ooool002Cooooo0_l0001l
ooooo`;o0000a?ooool002Cooooo00?o0000ooooooooool0`?ooool2o`0007oooooo000Tooooo`03
o`000?oooooooooo0<3ooooo0_l0001oooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0;Kooooo0_l00029ooooo`009?ooool2o`000;Oooooo0_l00029
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool09?ooool2o`000?oooooo7?ooool002Cooooo00?o
0000ooooooooool09?ooool2o`000?oooooo7?ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooooc;ooooo0_l0000>ooooo`009?ooool00ol0003ooooooooo
o`1Cooooo`;o0000g?ooool2o`0000kooooo000Tooooo`;o0000E?ooool2o`000>cooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0m_ooool2o`00
04Wooooo000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0m_ooool2o`0004Wooooo000<ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co
00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0YOooool2o`0009[ooooo000Tooooo`03o`000?oooooooooo0:Go
oooo0_l0002Jooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo
@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool0
3Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o
0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Sooooo`;o0000oooooolMooooo`000_ooool00omEEEGoIVIVo`00
000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool08oooool2o`000?oooooo7Ooo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0=Wooooo0_l0001Vooooo`006Oooool5o`0000Kooooo00?o0000oooooooo
ool0fOooool2o`0006Kooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?ooool0
0omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001Wo
oooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .30548 Mdot
.03333 .47989 Mdot
.0381 .02762 Mdot
.04286 .24266 Mdot
.04762 .01782 Mdot
.05238 .03392 Mdot
.05714 .05068 Mdot
.0619 .05302 Mdot
.06667 .03381 Mdot
.07143 .2648 Mdot
.07619 .15958 Mdot
.08095 .05064 Mdot
.08571 .11943 Mdot
.09048 .3636 Mdot
.09524 .00911 Mdot
.1 .04214 Mdot
.10476 .02769 Mdot
.10952 .01468 Mdot
.11429 .25486 Mdot
.11905 .00043 Mdot
.12381 .03671 Mdot
.12857 .07673 Mdot
.13333 .10211 Mdot
.1381 .06787 Mdot
.14286 .26359 Mdot
.14762 .18939 Mdot
.15238 .12083 Mdot
.15714 .2577 Mdot
.1619 .07434 Mdot
.16667 .12842 Mdot
.17143 .15687 Mdot
.17619 .22662 Mdot
.18095 .16983 Mdot
.18571 .33652 Mdot
.19048 .06008 Mdot
.19524 .0818 Mdot
.2 .00839 Mdot
.20476 .00714 Mdot
.20952 .07643 Mdot
.21429 .06519 Mdot
.21905 .18075 Mdot
.22381 .08634 Mdot
.22857 .15909 Mdot
.23333 .02117 Mdot
.2381 .05059 Mdot
.24286 .24246 Mdot
.24762 .28082 Mdot
.25238 .09029 Mdot
.25714 .04092 Mdot
.2619 .01692 Mdot
.26667 .02208 Mdot
.27143 .15524 Mdot
.27619 .10558 Mdot
.28095 .22888 Mdot
.28571 .09184 Mdot
.29048 .17625 Mdot
.29524 .03715 Mdot
.3 .04301 Mdot
.30476 .19194 Mdot
.30952 .20593 Mdot
.31429 .02012 Mdot
.31905 .15273 Mdot
.32381 .04257 Mdot
.32857 .31584 Mdot
.33333 .06576 Mdot
.3381 .26914 Mdot
.34286 .21777 Mdot
.34762 .09515 Mdot
.35238 .09642 Mdot
.35714 .07035 Mdot
.3619 .02184 Mdot
.36667 .07892 Mdot
.37143 .11311 Mdot
.37619 .0374 Mdot
.38095 .17197 Mdot
.38571 .03129 Mdot
.39048 .12343 Mdot
.39524 .03776 Mdot
.4 .02136 Mdot
.40476 .0254 Mdot
.40952 .04553 Mdot
.41429 .35693 Mdot
.41905 .15121 Mdot
.42857 .37792 Mdot
.43333 .06578 Mdot
.4381 .06109 Mdot
.44286 .0813 Mdot
.44762 .05113 Mdot
.45238 .24918 Mdot
.45714 .26142 Mdot
.4619 .13112 Mdot
.46667 .0806 Mdot
.47143 .20394 Mdot
.47619 .04557 Mdot
.48095 .08964 Mdot
.48571 .08185 Mdot
.49048 .23892 Mdot
.49524 .56261 Mdot
.5 .04076 Mdot
.50476 .00932 Mdot
.50952 .0665 Mdot
.51429 .12765 Mdot
.51905 .19706 Mdot
.52381 .13977 Mdot
.52857 .04998 Mdot
.53333 .01289 Mdot
.5381 .02912 Mdot
.54286 .22964 Mdot
.54762 .23667 Mdot
.55238 .2125 Mdot
.55714 .13465 Mdot
.5619 .28214 Mdot
.56667 .12547 Mdot
.57143 .00199 Mdot
.57619 .08291 Mdot
.58095 .32755 Mdot
.58571 .0003 Mdot
.59048 .07066 Mdot
.59524 .2987 Mdot
.6 .17766 Mdot
.60476 .39413 Mdot
.60952 .04332 Mdot
.61429 .22312 Mdot
.61905 .19429 Mdot
.62381 .08483 Mdot
.62857 .56263 Mdot
.63333 .22549 Mdot
.6381 .15078 Mdot
.64286 .06106 Mdot
.64762 .02608 Mdot
.65238 .21654 Mdot
.65714 .08043 Mdot
.6619 .08635 Mdot
.66667 .0285 Mdot
.67143 .1082 Mdot
.67619 .00562 Mdot
.68095 .19737 Mdot
.68571 .10242 Mdot
.69048 .23484 Mdot
.69524 .03965 Mdot
.7 .09295 Mdot
.70476 .49568 Mdot
.70952 .0754 Mdot
.71429 .02226 Mdot
.71905 .01787 Mdot
.72381 .05306 Mdot
.72857 .03967 Mdot
.73333 .12381 Mdot
.7381 .5077 Mdot
.74286 .03018 Mdot
.74762 .06772 Mdot
.75238 .29473 Mdot
.75714 .0085 Mdot
.7619 .05923 Mdot
.76667 .05013 Mdot
.77143 .05147 Mdot
.77619 .28155 Mdot
.78095 .14782 Mdot
.78571 .01194 Mdot
.79048 .00495 Mdot
.79524 .34055 Mdot
.80476 .00734 Mdot
.80952 .08973 Mdot
.81429 .07912 Mdot
.81905 .0214 Mdot
.82381 .13866 Mdot
.82857 .05898 Mdot
.83333 .04669 Mdot
.8381 .23751 Mdot
.84286 .33842 Mdot
.84762 .05078 Mdot
.85238 .03897 Mdot
.85714 .0261 Mdot
.8619 .28173 Mdot
.86667 .19486 Mdot
.87143 .25486 Mdot
.87619 .03979 Mdot
.88095 .09969 Mdot
.88571 .38687 Mdot
.89048 .10699 Mdot
.89524 .16267 Mdot
.9 .35058 Mdot
.90476 .02504 Mdot
.90952 .2394 Mdot
.91429 .01607 Mdot
.91905 .37983 Mdot
.92381 .13819 Mdot
.92857 .24407 Mdot
.93333 .44787 Mdot
.9381 .07762 Mdot
.94286 .0307 Mdot
.94762 .03072 Mdot
.95238 .16804 Mdot
.95714 .01064 Mdot
.9619 .13161 Mdot
.96667 .22763 Mdot
.97143 .32192 Mdot
.97619 .21953 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`09ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l0
0006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`?o00003Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o00008?ooool4o`0005oooooo0_l0000f
ooooo`;o00006?ooool2o`0000Wooooo0_l00002ooooo`;o0000A_ooool002Cooooo00?o0000oooo
ooooool04oooool2o`00023ooooo0_l0001Qooooo`;o00001oooool2o`0004Oooooo0_l00007oooo
o`;o00001?ooool2o`00033ooooo0_l0000Dooooo`009?ooool2o`0001Wooooo0_l00027ooooo`;o
0000D?ooool2o`0002Sooooo0_l0000<ooooo`;o00005?ooool002Cooooo00?o0000ooooooooool0
1?ooool2o`0001;ooooo0_l0000_ooooo`;o0000Toooool2o`0003gooooo0_l0000Rooooo`009?oo
ool00ol0003oooooooooo`04ooooo`;o0000>_ooool2o`0000Oooooo1?l0000=ooooo`;o00003_oo
ool2o`0000[ooooo0_l0001Tooooo`Co00007_ooool2o`00047ooooo000Tooooo`03o`000?oooooo
oooo043ooooo0_l00009ooooo`;o00003Oooool2o`0000kooooo0_l0000:ooooo`Co0000H_ooool2
o`00023ooooo0_l0000Jooooo`;o00009Oooool002Cooooo00Co0000oooooooooooooooo0_l0000C
ooooo`;o0000H?ooool2o`0004gooooo0_l00004ooooo`;o0000>oooool2o`0000kooooo0_l0000U
ooooo`009?ooool2o`0000;ooooo0_l0000Cooooo`;o0000F_ooool2o`0002oooooo0_l0000Roooo
o`;o00001?ooool2o`0001Kooooo0_l0000Sooooo`;o00006_ooool4o`0001Oooooo000Tooooo`03
o`000?oooooooooo00Gooooo0_l00003ooooo`;o0000I_ooool2o`0002oooooo0_l00010ooooo`;o
0000?oooool4o`0001Oooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o0000
4Oooool2o`0003Gooooo0_l0000Hooooo`;o00001Oooool2o`000<[ooooo000Tooooo`03o`000?oo
oooooooo01gooooo0_l0000Yooooo`;o00002_ooool2o`0001Sooooo0_l00005ooooo`;o00008?oo
ool2o`0003gooooo0_l00009ooooo`;o00009_ooool2o`0000Kooooo0_l0000^ooooo`009?ooool0
0ol0003oooooooooo`0Eooooo`;o0000<Oooool2o`0000cooooo0_l00006ooooo`;o0000=oooool2
o`00027ooooo0_l0000Jooooo`;o00002Oooool2o`0002Kooooo0_l00006ooooo`;o0000;_ooool0
02Cooooo0_l0000Fooooo`;o0000?oooool2o`0000Kooooo0_l0000Iooooo`;o00005?ooool2o`00
02Wooooo0_l00017ooooo`;o0000??ooool002Cooooo00?o0000ooooooooool0NOooool2o`0001Co
oooo0_l0000?ooooo`;o0000Boooool2o`0001Cooooo0_l0000looooo`009?ooool00ol0003ooooo
ooooo`07ooooo`Co00001?ooool2o`00037ooooo0_l00012ooooo`;o00006?ooool2o`0003gooooo
0_l0000<ooooo`Co00005_ooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo00Oooooo1?l0
0004ooooo`;o0000<Oooool2o`0004;ooooo0_l0001Gooooo`;o00003_ooool2o`0001Kooooo0_l0
000hooooo`009?ooool00ol0003oooooooooo`3/ooooo`;o00004oooool2o`0003kooooo000Toooo
o`;o0000<oooool2o`0004oooooo0_l00010ooooo`;o00009Oooool2o`0001?ooooo0_l0000noooo
o`009?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0004Oooooo0_l00010ooooo`;o
0000N_ooool002Cooooo00?o0000ooooooooool08Oooool2o`0001Oooooo0_l0000Uooooo`;o0000
7_ooool2o`0001Oooooo0_l0001;ooooo`;o0000F?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Qooooo`;o0000?_ooool2o`0000Gooooo0_l0000Gooooo`;o00005oooool2o`00
01Sooooo0_l0000aooooo`;o0000F?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0:Oooool2o`0003gooooo0_l0001:ooooo`;o0000Roooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo0ol0000Nooooo`;o00002Oooool2o`0000gooooo0_l0002Qooooo`;o0000B?ooool2
o`0001[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01kooooo0_l0000Hoooo
o`;o0000<Oooool2o`0001oooooo0_l0000looooo`;o00003oooool2o`00023ooooo0_l0000Voooo
o`;o00006_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0doooo
o`;o0000=Oooool2o`0001Oooooo0_l00006ooooo`;o00001?ooool2o`0001_ooooo0_l0000Ioooo
o`;o0000<Oooool2o`0004;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Co
oooo0_l00007ooooo`;o0000AOooool2o`0000cooooo0_l0000Kooooo`;o00003_ooool2o`0000[o
oooo0_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo0_l00007
ooooo`;o0000B?ooool2o`0002gooooo0_l0000:ooooo`;o0000;_ooool2o`0004Cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool2o`0004Oooooo0_l00009ooooo`;o0000?Oooool2o`0004Kooooo0_l0000Qooooo`;o0000
A?ooool002Cooooo00?o0000ooooooooool0DOooool2o`0001;ooooo1?l0001_ooooo`;o0000Iooo
ool002Cooooo00?o0000ooooooooool0IOooool4o`000=Sooooo000Tooooo`03o`000?oooooooooo
023ooooo0_l0002aooooo`;o0000?Oooool2o`0002gooooo000Tooooo`03o`000?oooooooooo023o
oooo0_l0000/ooooo`;o0000Poooool2o`0003gooooo0_l0000]ooooo`009?ooool00ol0003ooooo
ooooo`1>ooooo`;o0000O_ooool2o`0004Gooooo0_l0000Zooooo`009?ooool2o`000<oooooo0_l0
0015ooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool0KOooool2o`000=;ooooo000Toooo
o`03o`000?oooooooooo06gooooo0_l0003Booooo`009?ooool00ol0003oooooooooo`0@ooooo`;o
00005?ooool2o`000?oooooo6_ooool002Cooooo00?o0000ooooooooool04?ooool2o`0001Cooooo
0_l0001;ooooo`;o0000KOooool2o`0005gooooo000Tooooo`;o0000M?ooool2o`0003Oooooo0_l0
000dooooo`;o0000GOooool002Cooooo00?o0000ooooooooool0:oooool2o`0006kooooo0_l0000?
ooooo`;o0000Toooool002Cooooo00?o0000ooooooooool0:oooool2o`0005gooooo0_l0000?oooo
o`;o0000Soooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo08[ooooo0_l0000Mooooo`;o
0000POooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo0:Wooooo0_l0001Eooooo`;o0000
7_ooool2o`0001oooooo000Tooooo`;o0000Woooool2o`00063ooooo0_l0000Nooooo`;o00007ooo
ool002Cooooo00?o0000ooooooooool0W_ooool2o`000:7ooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?;ooooo0_l0001=ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0O?ooool2o`0004Gooooo0_l0
000]ooooo`;o0000COooool000Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0G?ooool2o`0001kooooo0_l00015ooooo`;o0000O?oo
ool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000/ooooo`;o00007oooool2o`0000gooooo0_l0003Sooooo`002Oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo
0_l0000Mooooo`;o00004Oooool2o`0000cooooo0_l0003booooo`002Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`;o0000
<?ooool2o`000=Kooooo0_l0000Xooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooaSooooo0_l0000Xooooo`002Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo02oooooo
0_l0003hooooo`;o00005_ooool002Cooooo0_l0000`ooooo`;o0000?oooool2o`000;Oooooo0_l0
000Fooooo`009?ooool00ol0003oooooooooo`1Cooooo`;o00006oooool2o`000<oooooo000Toooo
o`03o`000?oooooooooo05?ooooo0_l0001Rooooo`;o0000R?ooool002Cooooo00?o0000oooooooo
ool0??ooool2o`0007Wooooo0_l00028ooooo`009?ooool00ol0003oooooooooo`0looooo`;o0000
ooooool4ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool09?ooool2
o`00037ooooo0_l0003Xooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o0000<Oooool2o`00
06Cooooo0_l0001?ooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool0WOooool2o`0001ko
oooo0_l0000Booooo`;o0000>oooool2o`00037ooooo000Tooooo`03o`000?oooooooooo09gooooo
0_l0000booooo`;o0000K_ooool002Cooooo0_l0002>ooooo`;o0000/_ooool002Cooooo00?o0000
ooooooooool0FOooool2o`0003;ooooo0_l0002booooo`009?ooool00ol0003oooooooooo`1Ioooo
o`;o0000i_ooool002Cooooo00?o0000ooooooooool0Z?ooool2o`0009Oooooo000Tooooo`03o`00
0?oooooooooo0:Sooooo0_l0000Nooooo`;o0000Moooool002Cooooo0_l0001Uooooo`;o0000H_oo
ool2o`0006Oooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`1Tooooo`;o0000boooool2
o`0000kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;cooooo
0_l00004ooooo`;o0000OOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02ko
oooo0_l0000Pooooo`;o0000J_ooool2o`0000Cooooo0_l0001Zooooo`;o00004Oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool2o`00023ooooo0_l0001Cooooo`;o0000
Qoooool2o`00017ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000YOooool2o`0002gooooo0_l0
001[ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0:Kooooo0_l0
000/ooooo`;o0000;_ooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo09Cooooo0_l0000@ooooo`;o0000G?ooool2o`0001Gooooo0_l0000Tooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0000oooooo`;o0000Coooool2o`0008Gooooo
0_l00005ooooo`;o00007Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Co
oooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0_l0000oooooo`;o0000gOooool2o`0001go
oooo000Tooooo`;o0000R?ooool2o`000;Sooooo000Tooooo`03o`000?oooooooooo08Oooooo0_l0
002hooooo`009?ooool00ol0003oooooooooo`0Jooooo`;o0000loooool2o`00033ooooo000Toooo
o`03o`000?oooooooooo01[ooooo0_l0000;ooooo`;o0000i_ooool2o`00033ooooo000Tooooo`03
o`000?oooooooooo02Oooooo0_l0001Pooooo`;o0000]_ooool002Cooooo0_l0000=ooooo`;o0000
5Oooool2o`0006Cooooo0_l0002fooooo`009?ooool00ol0003oooooooooo`0<ooooo`;o00005Ooo
ool2o`0003gooooo0_l0003Mooooo`009?ooool00ol0003oooooooooo`1Rooooo`;o0000gOooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`;o0000A_ooool2o`000:Wooooo0_l0001?ooooo`009?ooool00ol0003ooooooooo
o`15ooooo`;o0000I?ooool2o`0004?ooooo0_l0000Jooooo`;o0000<oooool002Cooooo00?o0000
ooooooooool0Zoooool2o`0005oooooo0_l0000cooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003Zooooo`;o0000
E_ooool002Cooooo00?o0000ooooooooool0]_ooool2o`00037ooooo0_l0001Fooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0]_ooool2o`0008Wooooo000Loooo
o`03o`000?oooooooooo00Gooooo0ol0003ooooood;ooooo000Looooo`03o`000?oooooooooo00Go
oooo0ol0003ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0003ooooood;ooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05oooooo0_l0003Pooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05oooooo0_l0003Pooooo`006_ooool00omEEEGo
IVIVo`000007ooooo`03o`000?oooooooooo0?oooooo<Oooool2o`0000oooooo000Tooooo`;o0000
/_ooool2o`0007gooooo0_l0000?ooooo`009?ooool00ol0003oooooooooo`2aooooo`;o0000S_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0aoooo
o`;o0000ooooool?ooooo`009?ooool00ol0003oooooooooo`0aooooo`;o0000doooool2o`0003Wo
oooo000Tooooo`;o0000moooool2o`0000kooooo0_l0000iooooo`009?ooool00ol0003ooooooooo
o`3fooooo`;o0000BOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooooaWooooo0_l0000Wooooo`009?ooool00ol0003oooooooooo`3ooooooaWo
oooo0_l0000Wooooo`009?ooool2o`0007cooooo0_l00034ooooo`009?ooool00ol0003ooooooooo
o`1kooooo`;o0000a?ooool002Cooooo00?o0000ooooooooool04_ooool2o`000?oooooo;_ooool0
02Cooooo00?o0000ooooooooool04_ooool2o`000?oooooo;_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Ooooool2o`0009kooooo0_l0
000Pooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1oooooo`;o0000W_oo
ool2o`00023ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooo
oaGooooo0_l0000[ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo5Oooool2o`00
02_ooooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0_l00026ooooo`001?ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0_l00026ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooolTooooo`;o00007?ooool002Cooooo0_l0003oooooobGooooo
0_l0000Looooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`Co0000oooooom1oooo
o`009?ooool01?l0003oooooo`000?l0003ooooood7ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000f_ooool2o`0006Kooooo000Tooooo`03o`000?oooooooooo
0=Wooooo0_l0001Vooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0i?ooool2o`0005_ooooo000T
ooooo`;o0000iOooool2o`0005_ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;o
oooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
oooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omE
EEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`2Eooooo`;o0000:Oooool2o`0007oooooo000Tooooo`03o`000?oooooo
oooo09Gooooo0_l0000Yooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006Ooo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
0?oooooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003ooooo
ooooo`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .29846 Mdot
.03333 .38931 Mdot
.0381 .12953 Mdot
.04286 .23295 Mdot
.04762 .00229 Mdot
.05238 .03392 Mdot
.05714 .12749 Mdot
.0619 .25469 Mdot
.06667 .18611 Mdot
.07143 .10671 Mdot
.07619 .08559 Mdot
.08095 .06588 Mdot
.08571 .35144 Mdot
.09048 .3912 Mdot
.09524 .00911 Mdot
.1 .2524 Mdot
.10476 .02769 Mdot
.10952 .01468 Mdot
.11429 .10837 Mdot
.11905 .00043 Mdot
.12381 .12496 Mdot
.12857 .05162 Mdot
.13333 .10045 Mdot
.1381 .06787 Mdot
.14286 .26359 Mdot
.14762 .18939 Mdot
.15238 .0922 Mdot
.15714 .1782 Mdot
.1619 .07434 Mdot
.16667 .32464 Mdot
.17143 .18828 Mdot
.17619 .22471 Mdot
.18095 .16983 Mdot
.18571 .47981 Mdot
.19048 .06008 Mdot
.19524 .04104 Mdot
.2 .01731 Mdot
.20476 .00714 Mdot
.20952 .07643 Mdot
.21429 .19719 Mdot
.21905 .10353 Mdot
.22381 .08053 Mdot
.22857 .13038 Mdot
.23333 .02117 Mdot
.2381 .05059 Mdot
.24286 .22633 Mdot
.24762 .37608 Mdot
.25238 .30828 Mdot
.25714 .04092 Mdot
.2619 .22624 Mdot
.26667 .13622 Mdot
.27143 .34147 Mdot
.27619 .01009 Mdot
.28095 .14766 Mdot
.28571 .09184 Mdot
.29048 .17625 Mdot
.29524 .03715 Mdot
.3 .04301 Mdot
.30476 .19194 Mdot
.30952 .0616 Mdot
.31429 .02012 Mdot
.31905 .00429 Mdot
.32381 .05781 Mdot
.32857 .29594 Mdot
.33333 .06576 Mdot
.3381 .40516 Mdot
.34286 .27055 Mdot
.34762 .07394 Mdot
.35238 .08881 Mdot
.35714 .07035 Mdot
.3619 .02184 Mdot
.36667 .15075 Mdot
.37143 .11311 Mdot
.37619 .0374 Mdot
.38095 .25898 Mdot
.38571 .03129 Mdot
.39048 .27257 Mdot
.39524 .02333 Mdot
.4 .27308 Mdot
.40476 .17691 Mdot
.40952 .00756 Mdot
.41429 .20155 Mdot
.41905 .05583 Mdot
.42857 .23944 Mdot
.43333 .23481 Mdot
.4381 .16482 Mdot
.44286 .02232 Mdot
.44762 .29458 Mdot
.45238 .23301 Mdot
.45714 .22453 Mdot
.4619 .14387 Mdot
.46667 .0806 Mdot
.47143 .25486 Mdot
.47619 .04557 Mdot
.48095 .02734 Mdot
.48571 .08185 Mdot
.49048 .13227 Mdot
.49524 .61624 Mdot
.5 .04076 Mdot
.50476 .24161 Mdot
.50952 .10205 Mdot
.51429 .10657 Mdot
.51905 .20836 Mdot
.52381 .13977 Mdot
.52857 .04998 Mdot
.53333 .01289 Mdot
.5381 .14553 Mdot
.54286 .05686 Mdot
.54762 .31919 Mdot
.55238 .23296 Mdot
.55714 .13465 Mdot
.5619 .30424 Mdot
.56667 .12547 Mdot
.57143 .00199 Mdot
.57619 .08291 Mdot
.58095 .44444 Mdot
.58571 .00461 Mdot
.59048 .11539 Mdot
.59524 .25022 Mdot
.6 .39478 Mdot
.60952 .04332 Mdot
.61429 .22312 Mdot
.61905 .0447 Mdot
.62381 .00077 Mdot
.62857 .55036 Mdot
.63333 .09259 Mdot
.6381 .04992 Mdot
.64286 .06375 Mdot
.64762 .21614 Mdot
.65238 .13214 Mdot
.65714 .08043 Mdot
.6619 .08635 Mdot
.66667 .13147 Mdot
.67143 .1082 Mdot
.67619 .00562 Mdot
.68095 .16743 Mdot
.68571 .07685 Mdot
.69048 .13253 Mdot
.69524 .03965 Mdot
.7 .20596 Mdot
.70476 .37994 Mdot
.70952 .0754 Mdot
.71429 .10723 Mdot
.71905 .01787 Mdot
.72381 .05306 Mdot
.72857 .13771 Mdot
.73333 .01754 Mdot
.7381 .41019 Mdot
.74286 .24252 Mdot
.74762 .17344 Mdot
.75238 .15393 Mdot
.75714 .00208 Mdot
.7619 .05923 Mdot
.76667 .01089 Mdot
.77143 .05147 Mdot
.77619 .23569 Mdot
.78095 .05581 Mdot
.78571 .29161 Mdot
.79048 .05597 Mdot
.79524 .316 Mdot
.80476 .00734 Mdot
.80952 .13962 Mdot
.81429 .13149 Mdot
.81905 .16408 Mdot
.82381 .12365 Mdot
.82857 .06122 Mdot
.83333 .04669 Mdot
.8381 .19345 Mdot
.84286 .20493 Mdot
.84762 .05078 Mdot
.85238 .01589 Mdot
.85714 .0261 Mdot
.8619 .34588 Mdot
.86667 .04031 Mdot
.87143 .11558 Mdot
.87619 .18174 Mdot
.88095 .05645 Mdot
.88571 .19237 Mdot
.89048 .02953 Mdot
.89524 .05792 Mdot
.9 .10687 Mdot
.90476 .1054 Mdot
.90952 .04654 Mdot
.91429 .1563 Mdot
.91905 .4804 Mdot
.92381 .13819 Mdot
.92857 .07997 Mdot
.93333 .2944 Mdot
.9381 .07762 Mdot
.94286 .0307 Mdot
.94762 .17349 Mdot
.95238 .1733 Mdot
.95714 .01064 Mdot
.9619 .06958 Mdot
.96667 .28752 Mdot
.97143 .38518 Mdot
.97619 .50282 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01?ooool2o`0000Kooooo
00?o0000ooooooooool03?ooool2o`0000kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
0_l00005ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
000Tooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00002oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o00008_ooool2o`0001Gooooo0_l0
000<ooooo`;o00006oooool2o`0003Oooooo0_l0000Looooo`;o00009oooool2o`0004Kooooo000T
ooooo`03o`000?oooooooooo01?ooooo0_l0000iooooo`;o0000:Oooool2o`0002Kooooo0_l0001:
ooooo`;o00002_ooool2o`00033ooooo0_l0000Dooooo`009?ooool2o`0001Wooooo0_l00027oooo
o`;o0000B_ooool2o`0001[ooooo0_l0000Pooooo`;o00005?ooool002Cooooo00?o0000oooooooo
ool06?ooool2o`0001_ooooo0_l0002Wooooo`;o00000_ooool2o`0002Gooooo0_l0000fooooo`00
9?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2o`0001Sooooo0_l0000>ooooo`;o0000
6?ooool2o`0005Sooooo0_l00002ooooo`;o0000GOooool002Cooooo00?o0000ooooooooool0@?oo
ool2o`0001Sooooo0_l0000>ooooo`;o00002Oooool2o`0000gooooo0_l0002kooooo`009?ooool0
0ol0003oooooooooo`0Fooooo`;o0000GOooool2o`0001Wooooo0_l0001hooooo`;o0000=Oooool0
02Cooooo0_l0000Gooooo`;o0000F_ooool2o`0001cooooo0_l0001hooooo`;o00002Oooool2o`00
00oooooo0_l0000Iooooo`009?ooool00ol0003oooooooooo`05ooooo`;o0000Joooool2o`000:7o
oooo0_l0000?ooooo`;o00006Oooool002Cooooo00?o0000ooooooooool01Oooool2o`0004gooooo
0_l0000Hooooo`;o0000dOooool002Cooooo00?o0000ooooooooool0=?ooool2o`0001;ooooo0_l0
000:ooooo`;o00006?ooool2o`0002Oooooo0_l0000mooooo`;o0000=_ooool2o`00037ooooo000T
ooooo`03o`000?oooooooooo03Cooooo0_l0000Booooo`;o00003?ooool2o`0003oooooo0_l0000Q
ooooo`;o00006_ooool2o`0003Kooooo0_l0000aooooo`009?ooool2o`0005Oooooo0_l0000goooo
o`;o0000:Oooool2o`000003ooooool0003o000004Cooooo0_l0000Fooooo`;o00009?ooool002Co
oooo00?o0000ooooooooool0Soooool2o`0000oooooo0_l0000Kooooo`;o00001?ooool2o`0003ko
oooo0_l0000Fooooo`;o00009?ooool002Cooooo00?o0000ooooooooool07_ooool2o`0002;ooooo
0_l0001Looooo`;o00008Oooool2o`0001[ooooo0_l0000>ooooo`;o00005_ooool2o`0003Sooooo
000Tooooo`03o`000?oooooooooo01kooooo0_l0000Rooooo`;o0000>?ooool2o`00067ooooo0_l0
000>ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00002Oooool2o`0002gooooo
000Tooooo`03o`000?oooooooooo05kooooo0_l0000Looooo`;o00009oooool2o`0004Gooooo0_l0
0004ooooo`;o000000?oooooo`000?l000006oooool2o`0000?ooooo0_l0000Xooooo`009?ooool2
o`0003?ooooo0_l0000Uooooo`;o00000oooool2o`0004Gooooo0_l00015ooooo`;o00004oooool2
o`0001Cooooo0_l0000Xooooo`009?ooool00ol0003oooooooooo`0booooo`;o00009Oooool2o`00
06[ooooo0_l0000jooooo`;o0000?_ooool002Cooooo00?o0000ooooooooool03oooool2o`00013o
oooo0_l0000nooooo`;o0000H_ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool03oooool2o`00013ooooo0_l0000nooooo`;o00001Oooool2o`000<;ooooo0_l0000C
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Yooooo`;o0000
>_ooool2o`000003ooooool0003o00000<;ooooo0_l0000Cooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0002Wooooo0_l0000=ooooo`;o0000:oooool2o`0006cooooo0_l00006ooooo`;o0000B?oo
ool2o`0001[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Sooooo0_l00003
ooooo`;o0000COooool2o`0003cooooo0_l00007ooooo`;o00001_ooool2o`0004Gooooo0_l00000
0ooooooo0000o`00000Jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo03gooooo0_l0001=ooooo`;o00001?ooool2o`0001_ooooo0_l0000Iooooo`;o0000E_ooool2
o`0001gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l00023oooo
o`;o00006oooool2o`0001[ooooo0_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00gooooo0_l0001Hooooo`;o0000H_ooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002Oo
oooo0_l0000Yooooo`;o00005?ooool2o`0005Wooooo0_l0001mooooo`009?ooool00ol0003ooooo
ooooo`0Vooooo`;o0000:Oooool2o`0006oooooo0_l0001mooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0001hooooo`;o0000YOooool0
02Cooooo00?o0000ooooooooool08?ooool2o`0001[ooooo0_l0001Looooo`;o0000O_ooool2o`00
02Gooooo000Tooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o00008?ooool2o`0005go
oooo0_l0000aooooo`;o00003?ooool2o`0003[ooooo1?l0000Uooooo`009?ooool2o`0000gooooo
0_l0000<ooooo`;o0000Ooooool2o`00037ooooo0_l0000<ooooo`;o0000>_ooool2o`0002Oooooo
000Tooooo`03o`000?oooooooooo06gooooo0_l0003Booooo`009?ooool00ol0003oooooooooo`1]
ooooo`;o0000AOooool2o`0005Wooooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`2doooo
o`;o0000FOooool2o`00033ooooo000Tooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003oo
oooo000Tooooo`;o00007_ooool2o`0008gooooo0_l0001Booooo`;o0000?oooool002Cooooo00Co
0000oooooooooooooooo0_l00004ooooo`;o00005?ooool2o`00023ooooo0_l0001[ooooo`;o0000
Toooool002Cooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000=_ooool2o`0005?ooooo
0_l0000booooo`;o00000oooool2o`0000Gooooo0_l0000Wooooo`;o0000@_ooool002Cooooo00?o
0000ooooooooool0Boooool2o`0004Oooooo0_l0000Cooooo`;o00007Oooool2o`0000?ooooo0_l0
0005ooooo`;o00009oooool2o`0004;ooooo000Tooooo`03o`000?oooooooooo04_ooooo0_l0001L
ooooo`;o0000=_ooool2o`0001Sooooo0_l0000Sooooo`;o00007oooool002Cooooo0_l0002Ooooo
o`;o0000@Oooool2o`0001Sooooo0_l0000Sooooo`;o00007oooool002Cooooo00?o0000oooooooo
ool0R_ooool2o`0001;ooooo0_l00003ooooo`;o0000W?ooool000Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0D?ooool2o`0003Sooooo0_l0000Gooooo`;o0000W?ooool000Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
053ooooo0_l0000Iooooo`;o0000e?ooool000Wooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Joooool2o`0007cooooo0_l0001Foooo
o`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0>Wooooo0_l0000booooo`;o00008_ooool000Wooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooooakooooo0_l0000R
ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3nooooo`;o0000@Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Poooool2o`0004cooooo0_l0000[
ooooo`;o0000@Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`0_ooooo`;o0000D_ooool2o`0004cooooo0_l0001^ooooo`009?ooool2o`00
033ooooo0_l0002fooooo`;o0000?oooool3o`0001Kooooo000Tooooo`03o`000?oooooooooo05?o
oooo0_l0002Booooo`;o0000?oooool3o`0001Kooooo000Tooooo`03o`000?oooooooooo02Oooooo
0_l0000Zooooo`;o00008oooool2o`000<Oooooo000Tooooo`03o`000?oooooooooo02Oooooo0_l0
001?ooooo`;o0000Uoooool2o`0002kooooo000Tooooo`03o`000?oooooooooo0?oooooo4_ooool2
o`0002kooooo000Tooooo`;o00002oooool2o`00023ooooo0_l0003ooooooaCooooo000Tooooo`03
o`000?oooooooooo00[ooooo0_l0000Hooooo`;o00001_ooool2o`0002Wooooo0_l0003Xooooo`00
9?ooool00ol0003oooooooooo`0Tooooo`;o0000<Oooool2o`000:_ooooo0_l0000>ooooo`;o0000
:oooool002Cooooo00?o0000ooooooooool0>_ooool2o`000<Sooooo0_l0000>ooooo`;o0000:ooo
ool002Cooooo00?o0000ooooooooool0>_ooool2o`000?oooooo1_ooool002Cooooo0_l0001loooo
o`;o0000a?ooool002Cooooo00?o0000ooooooooool0Noooool2o`0005_ooooo0_l0000/ooooo`;o
0000>Oooool002Cooooo00?o0000ooooooooool0WOooool2o`0003Wooooo0_l0000/ooooo`;o0000
>Oooool002Cooooo00?o0000ooooooooool0WOooool2o`000:;ooooo000Tooooo`03o`000?oooooo
oooo0<Oooooo0_l0001hooooo`009?ooool2o`000<Sooooo0_l0001hooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo02kooooo0_l0001Iooooo`;o0000<Oooool2o`0008?ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0^ooooo`;o00004oooool2o`0000Cooooo0_l0000nooooo`;o0000<Ooo
ool2o`0008?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo0_l00004
ooooo`;o0000m_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`;o0000OOooool2o`00
00Cooooo0_l0000Oooooo`;o0000Uoooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`02ooooo`;o0000OOooool2o`0000Cooooo0_l0000Oooooo`;o0000A_ooool2o`00
04oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07oooooo0_l0001_ooooo`;o
0000Coooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1oooooo`;o00005oooool2
o`0004_ooooo0_l0001Jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool0V?ooool2o`0004_ooooo0_l0001Jooooo`009?ooool2
o`000;Oooooo0_l00029ooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000Woooool2o`00
08Wooooo000Tooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o0000M_ooool2o`000;;o
oooo000Tooooo`03o`000?oooooooooo00Wooooo0_l0001Uooooo`;o00006oooool2o`000;;ooooo
000Tooooo`03o`000?oooooooooo073ooooo0_l0003?ooooo`009?ooool2o`0002Cooooo0_l0003o
oooooagooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0003ooooooagooooo000Tooooo`03
o`000?oooooooooo06Cooooo0_l0003Kooooo`009?ooool00ol0003oooooooooo`1Tooooo`;o0000
3Oooool2o`000003ooooool0003o00000<Wooooo000Tooooo`03o`000?oooooooooo07?ooooo0_l0
00000ooooooo0000o`000039ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooooboooooo0_l0000Aooooo`00
9?ooool00ol0003oooooooooo`3ooooooboooooo0_l0000Aooooo`009?ooool00ol0003ooooooooo
o`3cooooo`;o0000C?ooool002Cooooo0_l0001Pooooo`;o00009Oooool2o`0006_ooooo0_l0000^
ooooo`;o00007?ooool002Cooooo0ol0001Oooooo`;o00009Oooool2o`0009_ooooo0_l0000Loooo
o`006_ooool4o`000003oa0@4?oooooooooo00?ooooo0ol0003ooooood;ooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Zoooool2o`0009Cooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A_ooool2o`0006?ooooo0_l0002Dooooo`007?ooool0
0ol0003oooooooooo`05ooooo`?o0000A_ooool2o`000?Wooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?Kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0:Kooooo0_l0001>ooooo`;o0000BOooool001[ooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`0[ooooo`;o0000NOooool2o`0009Wooooo000Tooooo`;o0000;?ooool2
o`000?oooooo5Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool2o`0004kooooo0_l0003booooo`009?ooool00ol0
003oooooooooo`1=ooooo`;o0000_Oooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo3Oooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo013ooooo0_l0003ooooooc3ooooo
000Tooooo`03o`000?oooooooooo013ooooo0_l0003ooooooc3ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`15oooo
o`;o0000n_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Gooooo0_l0002Boooo
o`;o0000I_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0fOooool2o`00
06Kooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo<Oooool2o`0000oooooo0004ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`Co0000
ooooool`ooooo`;o00003oooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooo`000?l0000Aooooo`;o
0000ooooool^ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`;o0000Xoooool2o`0008Sooooo
0004ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0]oooool2o`0008Sooooo0002ooooo`03oeEEEOmV
IVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`1R
ooooo`;o0000gOooool002Cooooo00?o0000ooooooooool0H_ooool2o`00083ooooo0_l0001Koooo
o`009?ooool00ol0003oooooooooo`3Tooooo`;o0000Foooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0;7ooooo0_l0002>ooooo`009?ooool00ol0003ooooo
ooooo`2aooooo`;o0000S_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo@_ooool000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8b
ooooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
oooood;ooooo000:ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0000booooo`;o0000k?ooool2o`00023ooooo000Tooooo`03o`00
0?oooooooooo037ooooo0_l0003/ooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooolbooooo`;o00003_ooool002Cooooo00?o0000
ooooooooool0oooooolbooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Co
oooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`30ooooo`;o0000Ooooool000;ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0<3ooooo
0_l0001oooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o0000oooo
ooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo09Go
oooo0_l0002Zooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000UOooool2o`000:[ooooo
000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9
ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .33198 Mdot
.03333 .17314 Mdot
.0381 .02556 Mdot
.04286 .11075 Mdot
.04762 .00229 Mdot
.05238 .03392 Mdot
.05714 .31557 Mdot
.0619 .2929 Mdot
.06667 .24395 Mdot
.07143 .10671 Mdot
.07619 .20342 Mdot
.08095 .09859 Mdot
.08571 .11419 Mdot
.09048 .48294 Mdot
.09524 .00911 Mdot
.1 .18705 Mdot
.10476 .02769 Mdot
.10952 .04853 Mdot
.11429 .10609 Mdot
.11905 .09072 Mdot
.12381 .12496 Mdot
.12857 .30245 Mdot
.13333 .11454 Mdot
.1381 .0404 Mdot
.14286 .20999 Mdot
.14762 .06684 Mdot
.15238 .00157 Mdot
.15714 .1782 Mdot
.1619 .15301 Mdot
.16667 .21709 Mdot
.17143 .03417 Mdot
.17619 .20306 Mdot
.18095 .16983 Mdot
.18571 .44596 Mdot
.19048 .06008 Mdot
.19524 .04104 Mdot
.2 .01731 Mdot
.20476 .0403 Mdot
.20952 .06962 Mdot
.21429 .19719 Mdot
.21905 .04172 Mdot
.22381 .08053 Mdot
.22857 .21327 Mdot
.23333 .02117 Mdot
.2381 .05059 Mdot
.24286 .11238 Mdot
.24762 .37608 Mdot
.25238 .26832 Mdot
.25714 .04092 Mdot
.2619 .05926 Mdot
.26667 .02608 Mdot
.27143 .01758 Mdot
.27619 .01009 Mdot
.28095 .00348 Mdot
.28571 .09184 Mdot
.29048 .16114 Mdot
.29524 .25449 Mdot
.3 .04301 Mdot
.30476 .19194 Mdot
.30952 .10115 Mdot
.31429 .02012 Mdot
.31905 .00429 Mdot
.32381 .00203 Mdot
.32857 .02429 Mdot
.33333 .04201 Mdot
.3381 .13595 Mdot
.34286 .10784 Mdot
.34762 .1535 Mdot
.35238 .3011 Mdot
.35714 .07035 Mdot
.3619 .12599 Mdot
.36667 .15075 Mdot
.37143 .03402 Mdot
.37619 .11546 Mdot
.38095 .10243 Mdot
.38571 .10162 Mdot
.39048 .20745 Mdot
.39524 .02333 Mdot
.4 .28588 Mdot
.40476 .07984 Mdot
.40952 .11143 Mdot
.41429 .32564 Mdot
.41905 .05583 Mdot
.42857 .19767 Mdot
.43333 .43983 Mdot
.4381 .16482 Mdot
.44286 .02232 Mdot
.44762 .05524 Mdot
.45238 .1101 Mdot
.45714 .22453 Mdot
.4619 .14387 Mdot
.46667 .00636 Mdot
.47143 .39602 Mdot
.47619 .04557 Mdot
.48095 .02734 Mdot
.48571 .05528 Mdot
.49048 .13227 Mdot
.49524 .47175 Mdot
.5 .04076 Mdot
.50476 .24161 Mdot
.50952 .10205 Mdot
.51429 .29645 Mdot
.51905 .25636 Mdot
.52381 .12054 Mdot
.52857 .38592 Mdot
.53333 .10926 Mdot
.5381 .00353 Mdot
.54286 .00561 Mdot
.54762 .1586 Mdot
.55238 .06603 Mdot
.55714 .10677 Mdot
.5619 .39895 Mdot
.56667 .02518 Mdot
.57143 .17036 Mdot
.57619 .05523 Mdot
.58095 .32748 Mdot
.58571 .09324 Mdot
.59048 .19857 Mdot
.59524 .34535 Mdot
.6 .48815 Mdot
.60476 .56445 Mdot
.60952 .10937 Mdot
.61429 .1386 Mdot
.61905 .0447 Mdot
.62381 .21709 Mdot
.62857 .55036 Mdot
.63333 .09259 Mdot
.6381 .17664 Mdot
.64286 .06375 Mdot
.64762 .0625 Mdot
.65238 .02073 Mdot
.65714 .08043 Mdot
.6619 .08635 Mdot
.66667 .05682 Mdot
.67143 .08116 Mdot
.67619 .07325 Mdot
.68095 .22472 Mdot
.68571 .02681 Mdot
.69048 .13253 Mdot
.69524 .11037 Mdot
.7 .20596 Mdot
.70476 .15803 Mdot
.70952 .0754 Mdot
.71429 .18928 Mdot
.71905 .01787 Mdot
.72381 .04829 Mdot
.72857 .07014 Mdot
.73333 .00902 Mdot
.7381 .47088 Mdot
.74286 .13233 Mdot
.74762 .13428 Mdot
.75238 .33034 Mdot
.75714 .11734 Mdot
.7619 .00972 Mdot
.76667 .01089 Mdot
.77143 .05147 Mdot
.77619 .13247 Mdot
.78095 .0333 Mdot
.78571 .13008 Mdot
.79048 .13794 Mdot
.79524 .23417 Mdot
.80476 .15119 Mdot
.80952 .05239 Mdot
.81429 .09131 Mdot
.81905 .13053 Mdot
.82381 .11496 Mdot
.82857 .06859 Mdot
.83333 .05239 Mdot
.8381 .19345 Mdot
.84286 .35592 Mdot
.84762 .05078 Mdot
.85238 .02881 Mdot
.85714 .30693 Mdot
.8619 .35053 Mdot
.86667 .04031 Mdot
.87143 .03726 Mdot
.87619 .26404 Mdot
.88095 .23124 Mdot
.88571 .19237 Mdot
.89048 .17436 Mdot
.89524 .05792 Mdot
.9 .10687 Mdot
.90476 .1054 Mdot
.90952 .21518 Mdot
.91429 .0106 Mdot
.91905 .27413 Mdot
.92381 .11506 Mdot
.92857 .07997 Mdot
.93333 .13565 Mdot
.9381 .07762 Mdot
.94286 .14815 Mdot
.94762 .37022 Mdot
.95238 .08964 Mdot
.95714 .08934 Mdot
.9619 .08497 Mdot
.96667 .28047 Mdot
.97143 .05882 Mdot
.97619 .3709 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01?ooool2o`0000Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00000oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Sooooo
00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`00
0?oooooo000000?o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo1Ol0000>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
9?ooool00ol0003oooooooooo`0Cooooo`;o0000>Oooool2o`0000cooooo0_l0000^ooooo`;o0000
5oooool2o`0003_ooooo0_l00008ooooo`;o0000Doooool002Cooooo00?o0000ooooooooool04ooo
ool2o`0003Wooooo0_l0002Booooo`;o00002?ooool3o`0002kooooo0_l0000Rooooo`009?ooool2
o`000>kooooo0_l0000^ooooo`;o00008_ooool002Cooooo00?o0000ooooooooool0=Oooool2o`00
01Kooooo0_l0002?ooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0=Oooool2o`0000Wo
oooo0_l0000;ooooo`;o00002oooool2o`0002Sooooo0_l00012ooooo`;o00005?ooool2o`00067o
oooo000Tooooo`04o`000?ooooooooooooooo`;o0000?Oooool2o`0001Sooooo0_l00003ooooo`;o
00005?ooool2o`0000gooooo0_l0000Vooooo`;o00006_ooool2o`0007Oooooo000Tooooo`04o`00
0?ooooooooooooooo`;o00004oooool2o`0003?ooooo0_l0000Booooo`;o00005?ooool2o`0001Wo
oooo0_l0000Jooooo`;o00009Oooool2o`0006cooooo000Tooooo`;o00005oooool2o`0003?ooooo
0_l00013ooooo`;o0000@Oooool2o`0003Cooooo0_l0000fooooo`009?ooool00ol0003ooooooooo
o`05ooooo`;o00009Oooool2o`0003oooooo0_l00023ooooo`;o00005Oooool2o`0003Kooooo000T
ooooo`03o`000?oooooooooo00Gooooo0_l0000Uooooo`;o0000?oooool2o`0008?ooooo0_l0000K
ooooo`;o0000<?ooool002Cooooo00?o0000ooooooooool08Oooool2o`00017ooooo0_l000000ooo
oooo0000o`00000?ooooo`;o0000COooool2o`0007Gooooo0ol0000`ooooo`009?ooool00ol0003o
ooooooooo`0Qooooo`;o00004Oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o
00003?ooool2o`0000Wooooo0_l0000dooooo`;o0000MOooool2o`00037ooooo000Tooooo`;o0000
?Oooool2o`0001Sooooo0_l00009ooooo`;o0000;?ooool2o`0002cooooo0_l00022ooooo`009?oo
ool00ol0003oooooooooo`0Hooooo`;o0000MOooool2o`0002cooooo0_l0000Pooooo`;o0000H?oo
ool002Cooooo00?o0000ooooooooool06?ooool2o`0002Sooooo0_l0002Kooooo`;o00003_ooool2
o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo
04;ooooo0_l0000hooooo`;o00002?ooool2o`0000[ooooo0_l0000Kooooo`;o0000?_ooool2o`00
00[ooooo0_l00006ooooo`;o00000_ooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo04Wo
oooo0_l0000aooooo`;o00002?ooool2o`0000[ooooo0_l0000Kooooo`;o00007?ooool2o`0004So
oooo0_l0000Gooooo`;o00003oooool002Cooooo0_l0000cooooo`;o00005Oooool2o`0007cooooo
0_l00004ooooo`;o0000B?ooool2o`0001Oooooo0_l0000?ooooo`009?ooool00ol0003ooooooooo
o`0booooo`;o0000TOooool4o`0007Sooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l00022
ooooo`;o00006oooool2o`0003[ooooo0_l0000nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo02Cooooo0_l0000Booooo`;o0000;_ooool2o`0003kooooo0_l0000gooooo`;o0000
7_ooool2o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Sooooo0_l0000^ooooo`;o0000I_ooool2o`0000oooooo0_l0001Nooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000=3ooooo0_l00009ooooo`;o0000B?ooool2o`0001[ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo03gooooo0_l0000iooooo`;o0000D?ooool2o`0000oooooo
0_l00015ooooo`;o000000?oooooo`000?l000006_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0mooooo`;o0000>Oooool2o`00053ooooo0_l00002ooooo`;o0000
D_ooool2o`0001gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<_ooooo0_l0
00000ooooooo0000o`00001Looooo`;o00004oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3;ooooo`;o0000G?ooool5o`0001?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0001cooooo0_l0000d
ooooo`;o0000Goooool2o`0000kooooo0_l0000iooooo`;o0000:_ooool4o`0001Cooooo000Toooo
o`03o`000?oooooooooo01_ooooo0_l0000dooooo`;o0000Goooool2o`0000kooooo0_l0000ioooo
o`;o0000@_ooool002Cooooo00?o0000ooooooooool03oooool2o`000?oooooo<Oooool002Cooooo
00?o0000ooooooooool03oooool2o`0004Sooooo0_l0000Eooooo`Co00009_ooool2o`000:Gooooo
000Tooooo`03o`000?oooooooooo05Wooooo0_l0000Eooooo`Co00009_ooool2o`0007kooooo0_l0
000Uooooo`009?ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool2o`0004Sooooo0_l00013
ooooo`;o0000KOooool4o`0002Gooooo000Tooooo`;o00000oooool2o`0000Sooooo0_l0000<oooo
o`;o0000B?ooool2o`0001?ooooo0_l0000<ooooo`;o00006?ooool2o`0000Kooooo0_l0000?oooo
o`;o00006_ooool2o`00043ooooo0_l0000Wooooo`009?ooool00ol0003oooooooooo`02ooooo`;o
00003?ooool2o`0000kooooo0_l0000Qooooo`;o0000=?ooool2o`0000cooooo0_l0000Hooooo`;o
00005oooool2o`0001[ooooo0_l0000Xooooo`;o00007_ooool2o`0001oooooo000Tooooo`03o`00
0?oooooooooo013ooooo0_l0000>ooooo`;o00008Oooool2o`0002Wooooo0_l0001jooooo`;o0000
5?ooool2o`0001kooooo0_l0000Oooooo`009?ooool00ol0003oooooooooo`1^ooooo`;o0000;_oo
ool2o`0004[ooooo0_l0001Eooooo`009?ooool00ol0003oooooooooo`2Nooooo`;o0000XOooool0
02Cooooo0_l0000Nooooo`;o0000Boooool2o`000=Gooooo000Tooooo`03o`000?oooooooooo01go
oooo0_l0001;ooooo`;o0000Qoooool2o`0004cooooo000Tooooo`03o`000?oooooooooo09Cooooo
0_l0000nooooo`;o00003oooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o0000
@Oooool002Cooooo00?o0000ooooooooool0H_ooool2o`00033ooooo0_l0000nooooo`;o00003ooo
ool4o`0000Oooooo0_l0000<ooooo`;o00008oooool2o`0001cooooo000Tooooo`03o`000?oooooo
oooo06;ooooo0_l0001Hooooo`;o0000:Oooool2o`0000cooooo0_l0000/ooooo`;o00007?ooool0
02Cooooo0_l0002mooooo`;o0000=oooool2o`0004[ooooo000Tooooo`03o`000?oooooooooo08[o
oooo0_l0002eooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2:ooooo`;o0000V_ooool2o`00
01Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`1[ooooo`;o0000S?ooool2o`0002_ooooo0_l0000Ioooo
o`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Yooooo`;o0000>_ooool2o`0000Cooooo0_l0002<ooooo`;o0000A_ooool000Wo
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Yoooo
o`;o0000>_ooool2o`0007;ooooo0_l0001Vooooo`002Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05?ooooo0_l0001A
ooooo`;o0000<Oooool2o`0006Kooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo0_l0001Aooooo`;o0000VOooool0
00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Poooool2o`000;cooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo00?o0000ooooooooool0;oooool2o`0005;ooooo0_l0000Yooooo`;o0000TOooool0
02Cooooo1?l0000^ooooo`;o0000OOooool2o`00097ooooo000Tooooo`04o`000?oooooo0000o`00
0<;ooooo0_l0001@ooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool09oooool2o`0009[o
oooo0_l0001@ooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool09oooool2o`000?oooooo
6Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0001Kooooo0_l0003o
ooooob_ooooo000Tooooo`03o`000?oooooooooo01Gooooo0_l00010ooooo`;o0000Poooool2o`00
06?ooooo000Tooooo`03o`000?oooooooooo05Oooooo0_l00023ooooo`;o00009_ooool2o`0000ko
oooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`0jooooo`;o0000@oooool2o`0008?ooooo
0_l0000>ooooo`;o0000:oooool002Cooooo00?o0000ooooooooool0>_ooool2o`0004?ooooo0_l0
000cooooo`;o0000Roooool002Cooooo0_l0000>ooooo`;o00007oooool2o`0008Cooooo0_l0002;
ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o00007oooool2o`0004?ooooo0_l0001Soooo
o`;o0000Ioooool002Cooooo00?o0000ooooooooool08oooool2o`0004kooooo0_l0001Sooooo`;o
0000Ioooool002Cooooo00?o0000ooooooooool08oooool2o`0001[ooooo0_l0003oooooo`7ooooo
000Tooooo`03o`000?oooooooooo03oooooo0_l0003Jooooo`;o00009?ooool002Cooooo0_l0000/
ooooo`;o0000T_ooool2o`0005[ooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`0[oooo
o`;o0000T_ooool2o`00083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo08Wooooo0_l00016ooooo`;o0000K_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo08Wooooo0_l00016ooooo`;o0000K_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolCooooo`;o0000;Oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003f
ooooo`;o00006_ooool2o`0002gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0m_ooool2o`0004Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o0000S?oo
ool2o`000:Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co0000
1_ooool00ol0003oooooooooo`0:ooooo`;o0000S?ooool2o`000:Oooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
05Cooooo0_l00017ooooo`;o0000X_ooool002Cooooo00?o0000ooooooooool0E?ooool2o`0004Oo
oooo0_l0002Rooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oolCooooo`;o0000;_ooool002Cooooo00?o0000ooooooooool0A_ooool2o`000<Wooooo0_l0000^
ooooo`009?ooool00ol0003oooooooooo`16ooooo`;o0000nOooool002Cooooo00?o0000oooooooo
ool0oooooolPooooo`;o00008?ooool002Cooooo00?o0000ooooooooool0oooooolPooooo`;o0000
8?ooool002Cooooo0_l0003ooooooc3ooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`3o
oooooboooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`1fooooo`;o0000bOooool002Co
oooo00?o0000ooooooooool0M_ooool2o`000<Wooooo000Tooooo`03o`000?oooooooooo00Wooooo
0_l0003oooooocOooooo000Tooooo`;o00002_ooool2o`00093ooooo0_l0002Tooooo`009?ooool0
0ol0003oooooooooo`2Kooooo`;o0000Y?ooool001[ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo01kooooo0_l00017ooooo`;o0000f?ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Nooooo`;o0000Aoooool2o`000=Sooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0ooooool;ooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool01Oooool3o`000?oooooo2oooool2o`0003Gooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo0_l0003oooooocWooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool2o`000?oooooo>Oooool001[ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000O?ooool2o`0003Cooooo0_l0
002>ooooo`009?ooool00ol0003oooooooooo`1kooooo`;o0000=?ooool2o`0003Kooooo0_l0001F
ooooo`009?ooool3o`000>Wooooo0_l0001Fooooo`009?ooool3o`000?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0]_ooool2o`0008Wooooo000Tooooo`03o`000?oooooooooo0;Kooooo0_l00029oooo
o`009?ooool00ol0003oooooooooo`3oooooo`gooooo0_l0000cooooo`009?ooool00ol0003ooooo
ooooo`3oooooo`gooooo0_l0000cooooo`009?ooool2o`000?oooooo2?ooool2o`0003Wooooo000T
ooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003Wooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3oooooobWooooo0_l00007ooooo`;o00003_ooool002Cooooo0_l0003oooooob[ooooo0_l0
0007ooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0AOooool2o`000?[ooooo0002oooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`15ooooo`;o0000n_ooool000Cooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Poooo
o`;o0000Woooool000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0002Pooooo`;o0000Woooool000Cooooo00?o0000ooooooooool0
3Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o
0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2=ooooo`;o0000/_ooool000;ooooo00?oEEEEofIVI_l000003?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo08gooooo
0_l0000Looooo`;o0000U?ooool002Cooooo0_l0002/ooooo`;o0000U?ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`21ooooo`;o0000__ooool002Co
oooo00?o0000ooooooooool0POooool2o`000;kooooo000Tooooo`03o`000?oooooooooo037ooooo
0_l0003oooooo`oooooo000Tooooo`;o0000<_ooool2o`000?oooooo3oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo000<oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0003ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Gooooo0_l0
001=ooooo`;o0000Foooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo09Gooooo0_l0001=ooooo`;o0000Foooool000[ooooo00?oEEEEofIV
I_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool04_ooool2o`000?oooooo;_ooool002Cooooo00?o
0000ooooooooool04_ooool2o`000:?ooooo0_l00028ooooo`009?ooool00ol0003oooooooooo`2g
ooooo`;o0000R?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0
003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03
o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`30ooooo`;o
0000Ooooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`00
0?oooooooooo0<3ooooo0_l0001oooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2iooooo`;o0000Q_ooool002Co
oooo00?o0000ooooooooool0^Oooool2o`0008Kooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
01Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000
ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool0
01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .47173 Mdot
.03333 .18553 Mdot
.0381 .05053 Mdot
.04286 .11075 Mdot
.04762 .03098 Mdot
.05238 .05203 Mdot
.05714 .25355 Mdot
.0619 .40086 Mdot
.06667 .0979 Mdot
.07143 .10671 Mdot
.07619 .05777 Mdot
.08095 .1277 Mdot
.08571 .11419 Mdot
.09048 .43145 Mdot
.09524 .00911 Mdot
.1 .07786 Mdot
.10476 .02769 Mdot
.10952 .04853 Mdot
.11429 .11083 Mdot
.11905 .07607 Mdot
.12381 .13334 Mdot
.12857 .39791 Mdot
.13333 .11454 Mdot
.1381 .0404 Mdot
.14286 .11276 Mdot
.14762 .06352 Mdot
.15238 .00157 Mdot
.15714 .08374 Mdot
.1619 .11074 Mdot
.16667 .10606 Mdot
.17143 .06996 Mdot
.17619 .19474 Mdot
.18095 .08837 Mdot
.18571 .14863 Mdot
.19048 .06008 Mdot
.19524 .04104 Mdot
.2 .01731 Mdot
.20476 .0403 Mdot
.20952 .06962 Mdot
.21429 .08066 Mdot
.21905 .04172 Mdot
.22381 .13631 Mdot
.22857 .01585 Mdot
.23333 .02117 Mdot
.2381 .05059 Mdot
.24286 .00381 Mdot
.24762 .11293 Mdot
.25238 .07175 Mdot
.25714 .40233 Mdot
.2619 .04902 Mdot
.26667 .02608 Mdot
.27143 .22399 Mdot
.27619 .01009 Mdot
.28095 .02729 Mdot
.28571 .01685 Mdot
.29048 .19508 Mdot
.29524 .11736 Mdot
.3 .08353 Mdot
.30476 .26803 Mdot
.30952 .10115 Mdot
.31429 .02012 Mdot
.31905 .00429 Mdot
.32381 .0007 Mdot
.32857 .02429 Mdot
.33333 .04201 Mdot
.3381 .01988 Mdot
.34286 .10784 Mdot
.34762 .1535 Mdot
.35238 .29719 Mdot
.35714 .07035 Mdot
.3619 .12599 Mdot
.36667 .27169 Mdot
.37143 .03402 Mdot
.37619 .11118 Mdot
.38095 .01906 Mdot
.38571 .10162 Mdot
.39048 .365 Mdot
.39524 .02333 Mdot
.4 .23359 Mdot
.40476 .02246 Mdot
.40952 .12778 Mdot
.41429 .17739 Mdot
.41905 .06805 Mdot
.42857 .55698 Mdot
.43333 .22507 Mdot
.4381 .11454 Mdot
.44286 .03774 Mdot
.44762 .05524 Mdot
.45238 .02592 Mdot
.45714 .12309 Mdot
.4619 .14387 Mdot
.46667 .00636 Mdot
.47143 .21471 Mdot
.47619 .04557 Mdot
.48095 .08256 Mdot
.48571 .18577 Mdot
.49048 .04163 Mdot
.5 .07074 Mdot
.50476 .13568 Mdot
.50952 .03582 Mdot
.51429 .09329 Mdot
.51905 .29139 Mdot
.52381 .08022 Mdot
.52857 .18275 Mdot
.53333 .26072 Mdot
.5381 .21719 Mdot
.54286 .00561 Mdot
.54762 .41169 Mdot
.55238 .18696 Mdot
.55714 .01268 Mdot
.5619 .20034 Mdot
.56667 .03503 Mdot
.57143 .31042 Mdot
.57619 .19503 Mdot
.58095 .38987 Mdot
.58571 .00761 Mdot
.59048 .18477 Mdot
.59524 .21393 Mdot
.6 .47822 Mdot
.60952 .10937 Mdot
.61429 .1386 Mdot
.61905 .01948 Mdot
.62381 .11588 Mdot
.62857 .34251 Mdot
.63333 .08778 Mdot
.6381 .23759 Mdot
.64286 .05992 Mdot
.64762 .0625 Mdot
.65238 .02073 Mdot
.65714 .02129 Mdot
.6619 .01453 Mdot
.66667 .12712 Mdot
.67143 .283 Mdot
.67619 .10738 Mdot
.68095 .07623 Mdot
.68571 .02681 Mdot
.69048 .06808 Mdot
.69524 .11037 Mdot
.7 .2815 Mdot
.70476 .10173 Mdot
.70952 .0754 Mdot
.71429 .00842 Mdot
.71905 .01787 Mdot
.72381 .10382 Mdot
.72857 .11139 Mdot
.73333 .00902 Mdot
.7381 .38839 Mdot
.74286 .26248 Mdot
.74762 .05522 Mdot
.75238 .15985 Mdot
.75714 .02989 Mdot
.7619 .00972 Mdot
.76667 .01089 Mdot
.77143 .05538 Mdot
.77619 .12812 Mdot
.78095 .20383 Mdot
.78571 .08676 Mdot
.79048 .12782 Mdot
.79524 .12603 Mdot
.8 .4111 Mdot
.80476 .26737 Mdot
.80952 .05239 Mdot
.81429 .19335 Mdot
.81905 .10594 Mdot
.82381 .3918 Mdot
.82857 .06859 Mdot
.83333 .05239 Mdot
.8381 .19574 Mdot
.84286 .04118 Mdot
.84762 .05078 Mdot
.85238 .15735 Mdot
.85714 .31078 Mdot
.8619 .21279 Mdot
.86667 .06137 Mdot
.87143 .03726 Mdot
.87619 .00607 Mdot
.88095 .09613 Mdot
.88571 .01313 Mdot
.89048 .40795 Mdot
.89524 .03941 Mdot
.9 .10687 Mdot
.90476 .1054 Mdot
.90952 .0442 Mdot
.91429 .07002 Mdot
.91905 .11713 Mdot
.92381 .21047 Mdot
.92857 .07997 Mdot
.93333 .06888 Mdot
.9381 .00915 Mdot
.94286 .14815 Mdot
.94762 .37022 Mdot
.95238 .11823 Mdot
.95714 .07813 Mdot
.9619 .23675 Mdot
.96667 .1713 Mdot
.97143 .17112 Mdot
.97619 .32134 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool01?l0003ooooo
ooooooooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
9?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1oooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o0000
1Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0
003oooooooooo`0;ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o0000>Oooool2o`0000co
oooo0_l0000^ooooo`;o00005oooool2o`0000_ooooo0_l0000Xooooo`;o00001?ooool2o`0000So
oooo0_l0000Sooooo`;o00004_ooool2o`0001[ooooo000Tooooo`03o`000?oooooooooo01?ooooo
0_l0000iooooo`;o0000FOooool2o`0000Oooooo0_l0000Xooooo`;o00001?ooool2o`0000Sooooo
0ol0000Uooooo`;o00003oooool2o`0001[ooooo000Tooooo`;o0000@?ooool2o`0006Sooooo0_l0
000Pooooo`;o00008?ooool2o`0002Gooooo0_l0000[ooooo`009?ooool00ol0003oooooooooo`0e
ooooo`;o00002?ooool2o`00013ooooo0_l0000Mooooo`;o0000Boooool2o`0000cooooo0_l0000A
ooooo`;o0000HOooool002Cooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l0000?oooo
o`;o00001oooool2o`0000Kooooo0_l0000<ooooo`;o00001_ooool2o`0004?ooooo0_l00009oooo
o`Co00004_ooool2o`00067ooooo000Tooooo`03o`000?oooooooooo043ooooo0_l0000Hooooo`;o
00000oooool2o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`00001>ooooo`Co
0000MOooool002Cooooo00?o0000ooooooooool05_ooool2o`0003?ooooo0_l00003ooooo`;o0000
3Oooool2o`0001Cooooo0_l0000@ooooo`;o0000B_ooool2o`0006cooooo000Tooooo`;o00001Ooo
ool2o`00013ooooo0_l0000cooooo`;o00000oooool2o`0003Gooooo0_l0001:ooooo`;o00005Ooo
ool2o`0005Gooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0001Wooooo`;o0000Noooool2
o`0005Gooooo000Tooooo`03o`000?oooooooooo06gooooo0_l0000Eooooo`;o00005?ooool2o`00
013ooooo0_l0001Qooooo`;o0000<?ooool002Cooooo00?o0000ooooooooool08Oooool2o`00017o
oooo0_l000000ooooooo0000o`00001;ooooo`;o00005?ooool2o`00013ooooo0_l0001Qooooo`;o
00001_ooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000000oooool2o`0002?ooooo0_l0000aooooo`;o0000L?ooool2o`0000oooooo
0_l0000Xooooo`009?ooool2o`0003gooooo0_l0000Sooooo`;o0000;?ooool2o`0000?ooooo0_l0
001`ooooo`;o00004oooool2o`0002Cooooo000Tooooo`03o`000?oooooooooo01Sooooo0_l0000_
ooooo`;o0000A?ooool2o`0008[ooooo0_l0000Tooooo`009?ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l0000Aooooo`;o0000:?ooool2o`0000Gooooo0_l0002`ooooo`;o00001_ooool2
o`0000;ooooo0_l0000hooooo`009?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0000k
ooooo`;o0000@_ooool2o`0005oooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l00002
ooooo`;o0000>?ooool002Cooooo00?o0000ooooooooool03Oooool2o`0007Oooooo0_l0001Ooooo
o`;o00001_ooool2o`00053ooooo000Tooooo`;o00003_ooool2o`0002?ooooo0_l0002Aooooo`Co
0000AOooool2o`00037ooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l0000<ooooo`;o0000
TOooool4o`0004Gooooo0_l0000aooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o0000E_oo
ool2o`0005Kooooo0_l0000[ooooo`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0/ooooo`;o00002_ooool2o`0000cooooo0_l0000Pooooo`;o00004_ooool2o`0001Wo
oooo0_l0000kooooo`;o0000:oooool2o`0001[ooooo0_l00004ooooo`;o00007?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;?ooool2o`0000[ooooo0_l0000<
ooooo`;o00008?ooool2o`0002gooooo0_l00024ooooo`;o00001?ooool2o`0001cooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`?o00005Oooool2o`0000Cooooo0_l0002dooooo`;o00002?ooool2o`00
06Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo0_l00004ooooo`;o
00007Oooool2o`0006;ooooo0_l0000aooooo`;o00002?ooool2o`0004Gooooo0_l00007ooooo`;o
00005?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Wooooo`;o
00004Oooool2o`0001[ooooo0_l0000hooooo`;o00003?ooool2o`0008;ooooo0_l00007ooooo`;o
00005?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool2o`0002gooooo
0_l0000hooooo`;o0000HOooool2o`0004cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;oooool2o`00097ooooo0_l0000_ooooo`;o0000C?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000<?oo
ool2o`0006[ooooo0_l0000Uooooo`;o0000OOooool002Cooooo00?o0000ooooooooool0Voooool2
o`0007Gooooo0_l0000]ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000ooooool7oooo
o`;o0000;Oooool002Cooooo00?o0000ooooooooool02_ooool2o`0004gooooo0_l0000Gooooo`;o
0000IOooool2o`0006Kooooo000Tooooo`03o`000?oooooooooo05Wooooo0_l0000Gooooo`;o0000
IOooool2o`0000Cooooo0_l0000iooooo`;o00009Oooool002Cooooo00?o0000ooooooooool03?oo
ool2o`0001gooooo0_l0000gooooo`;o0000J_ooool2o`0000gooooo0_l0000Mooooo`;o00006?oo
ool4o`0002Gooooo000Tooooo`;o00000oooool2o`0000Sooooo0_l0000<ooooo`;o00003Oooool4
o`0003Oooooo0_l00008ooooo`;o0000B_ooool2o`0001Cooooo0_l00004ooooo`;o00002Oooool2
o`0001_ooooo0_l0000Hooooo`;o00009oooool002Cooooo00?o0000ooooooooool00_ooool2o`00
00cooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000Joooo
o`;o00009oooool2o`0001?ooooo0_l0000eooooo`;o00006_ooool2o`0000Wooooo0_l0001Noooo
o`009?ooool00ol0003oooooooooo`0@ooooo`;o00003_ooool2o`000003ooooool0003o0000023o
oooo0_l0000=ooooo`;o0000;Oooool2o`0003[ooooo0_l0001Nooooo`;o00008?ooool002Cooooo
00?o0000ooooooooool0E?ooool2o`0006Wooooo0_l0001Nooooo`;o00002?ooool2o`0001Kooooo
000Tooooo`03o`000?oooooooooo08Wooooo0_l0002Nooooo`;o00005_ooool002Cooooo0_l0001[
ooooo`;o00007Oooool2o`0004;ooooo0_l0000Wooooo`;o0000BOooool002Cooooo00?o0000oooo
ooooool03oooool2o`0005Wooooo0_l0000=ooooo`;o0000D_ooool2o`00027ooooo0_l00003oooo
o`?o0000BOooool002Cooooo00?o0000ooooooooool03oooool2o`0000cooooo0_l0001Jooooo`;o
0000MOooool2o`0000?ooooo0_l0001:ooooo`009?ooool00ol0003oooooooooo`0Mooooo`;o0000
7_ooool2o`0005Wooooo0_l0002Wooooo`009?ooool00ol0003oooooooooo`0mooooo`;o0000FOoo
ool2o`0002;ooooo0_l00023ooooo`009?ooool2o`000;gooooo0_l00023ooooo`009?ooool00ol0
003oooooooooo`2:ooooo`;o0000]Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<Oooool2
o`0005Oooooo0_l0002Jooooo`;o00006Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo037ooooo0_l0003c
ooooo`;o00006Oooool000Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0IOooool2o`000=[ooooo0009ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000IOooool2o`000:;ooooo0_l0000f
ooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0>Wooooo0_l0000Nooooo`;o0000=_ooool000Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0jOoo
ool2o`0005Kooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000ooooool`
ooooo`Co00003oooool002Cooooo00?o0000ooooooooool0ooooool_ooooo`Co00003oooool002Co
oooo00?o0000ooooooooool0Noooool2o`000<Cooooo000Tooooo`03o`000?oooooooooo07_ooooo
0_l0000Sooooo`;o0000Woooool002Cooooo00Co0000ooooool0003o0000TOooool2o`0000cooooo
0_l0000Booooo`;o0000Roooool002Cooooo1?l0002Aooooo`;o00005?ooool2o`0000[ooooo0_l0
002;ooooo`009?ooool00ol0003oooooooooo`2Xooooo`;o0000Uoooool002Cooooo00?o0000oooo
ooooool0;_ooool2o`0002?ooooo0_l0001Jooooo`;o0000C?ooool2o`0004;ooooo000Tooooo`03
o`000?oooooooooo02kooooo0_l0000Sooooo`;o0000F_ooool2o`0004cooooo0_l00005ooooo`;o
0000>oooool002Cooooo00?o0000ooooooooool0Zoooool2o`0005Oooooo0_l0000kooooo`009?oo
ool2o`000:cooooo0_l00015ooooo`;o0000COooool002Cooooo00?o0000ooooooooool0l_ooool2
o`0004gooooo000Tooooo`03o`000?oooooooooo0?oooooo8Oooool2o`0001oooooo000Tooooo`03
o`000?oooooooooo0?oooooo3Oooool2o`0001;ooooo0_l0000Oooooo`009?ooool00ol0003ooooo
ooooo`2=ooooo`;o00009oooool2o`0005Cooooo0_l0000cooooo`009?ooool2o`0008kooooo0_l0
000Dooooo`;o00004Oooool2o`0008Wooooo000Tooooo`03o`000?oooooooooo0:?ooooo0_l0002L
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1=ooooo`;o0000
<_ooool2o`000;kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1=ooooo`;o
0000<_ooool2o`000;kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001fooooo`;o0000bOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1fooooo`;o0000Boooool2o`0006Oooooo0_l0
000Cooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`33ooooo`;o0000Ioooool2
o`0001?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool01ooo
ool2o`000?oooooo>Oooool002Cooooo00?o0000ooooooooool01oooool2o`000?oooooo>Oooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2Qooooo`;o
0000@_ooool2o`0005[ooooo000Tooooo`;o0000X_ooool2o`0004;ooooo0_l0001Jooooo`009?oo
ool00ol0003oooooooooo`1Gooooo`;o0000X?ooool2o`0004Kooooo000Tooooo`03o`000?oooooo
oooo05Oooooo0_l0000Booooo`;o0000S?ooool2o`0004Kooooo000Tooooo`03o`000?oooooooooo
06_ooooo0_l0003Dooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
fOooool2o`0006Oooooo000Tooooo`03o`000?oooooooooo0<kooooo0_l00008ooooo`;o0000Iooo
ool002Cooooo00?o0000ooooooooool0c_ooool2o`00077ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0WOooool2o`000:;ooooo000Tooooo`;o0000
W_ooool2o`000:;ooooo000Tooooo`03o`000?oooooooooo06Oooooo0_l0003Hooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool2o`000=Sooooo000Loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool0
1Oooool3o`000:kooooo0_l0001Jooooo`;o0000=Oooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2^ooooo`;o0000F_ooool2o`0003Gooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo<_ooool2o`0000kooooo000Jooooo`03oeEEEOmVIVKo000000Oo
oooo00?o0000ooooooooool0oooooolbooooo`;o00003_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l00031ooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0`?oo
ool2o`0007oooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Loooool2o`000<cooooo000Tooooo`03
o`000?oooooooooo07?ooooo0_l0002cooooo`;o00005oooool002Cooooo0_l0003oooooob[ooooo
0_l0000Gooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0
003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0>Cooooo0_l0001Kooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;7ooooo0_l0000aoooo
o`;o00006_ooool2o`0003oooooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;7ooooo0_l0001=ooooo`;o
0000?oooool000Cooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`;o0000oooooolRooooo`00
0_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo00?o0000ooooooooool02Oooool2o`0001?ooooo0_l0003oooooob;ooooo000Tooooo`;o0000
2_ooool2o`0003gooooo0_l0003gooooo`009?ooool00ol0003oooooooooo`18ooooo`;o0000booo
ool2o`0002[ooooo000Tooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002[ooooo000Toooo
o`03o`000?oooooooooo0:Kooooo0_l0001@ooooo`;o0000Aoooool002Cooooo00?o0000oooooooo
ool0Y_ooool2o`00053ooooo0_l00017ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool04_ooool2o`000?oo
oooo;_ooool002Cooooo0_l0000Cooooo`;o0000ooooool^ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
0ol0003ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool3o`000?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000
ooooooooool0]oooool2o`0008Sooooo000Tooooo`;o0000^?ooool2o`0008Sooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00083ooooo0_l00030ooooo`009?oo
ool00ol0003oooooooooo`1oooooo`;o0000`?ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o
0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBooo
ool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .13634 Mdot
.0381 .00458 Mdot
.04286 .11075 Mdot
.04762 .02807 Mdot
.05238 .05203 Mdot
.05714 .27359 Mdot
.0619 .44483 Mdot
.06667 .0979 Mdot
.07143 .14981 Mdot
.07619 .05777 Mdot
.08095 .22928 Mdot
.08571 .00161 Mdot
.09048 .36553 Mdot
.09524 .00911 Mdot
.1 .02453 Mdot
.10476 .07463 Mdot
.10952 .07299 Mdot
.11429 .11083 Mdot
.11905 .07607 Mdot
.12381 .12545 Mdot
.12857 .20551 Mdot
.13333 .11454 Mdot
.1381 .0404 Mdot
.14286 .22992 Mdot
.14762 .02192 Mdot
.15238 .03599 Mdot
.15714 .08374 Mdot
.1619 .18439 Mdot
.16667 .23646 Mdot
.17143 .06996 Mdot
.17619 .2152 Mdot
.18095 .08837 Mdot
.18571 .18052 Mdot
.19048 .08164 Mdot
.19524 .13992 Mdot
.2 .21161 Mdot
.20476 .03113 Mdot
.20952 .10971 Mdot
.21429 .08066 Mdot
.21905 .04172 Mdot
.22381 .11374 Mdot
.22857 .01585 Mdot
.23333 .02117 Mdot
.2381 .05059 Mdot
.24286 .00381 Mdot
.24762 .14358 Mdot
.25238 .22562 Mdot
.25714 .27043 Mdot
.2619 .04902 Mdot
.26667 .01666 Mdot
.27143 .09447 Mdot
.27619 .13587 Mdot
.28095 .19345 Mdot
.28571 .02158 Mdot
.29048 .11608 Mdot
.29524 .21434 Mdot
.3 .08667 Mdot
.30476 .18105 Mdot
.30952 .25671 Mdot
.31429 .12984 Mdot
.31905 .00429 Mdot
.32381 .1252 Mdot
.32857 .02429 Mdot
.33333 .07612 Mdot
.3381 .04182 Mdot
.34286 .10784 Mdot
.34762 .1535 Mdot
.35238 .1016 Mdot
.35714 .02726 Mdot
.3619 .13137 Mdot
.36667 .17711 Mdot
.37143 .18938 Mdot
.37619 .00083 Mdot
.38095 .01906 Mdot
.38571 .10162 Mdot
.39048 .15383 Mdot
.39524 .02333 Mdot
.4 .23359 Mdot
.40476 .02246 Mdot
.40952 .09124 Mdot
.41429 .14234 Mdot
.41905 .13201 Mdot
.42857 .56802 Mdot
.43333 .10904 Mdot
.4381 .00711 Mdot
.44286 .00485 Mdot
.44762 .23326 Mdot
.45238 .02592 Mdot
.45714 .12309 Mdot
.4619 .15754 Mdot
.46667 .00636 Mdot
.47143 .10617 Mdot
.47619 .04557 Mdot
.48095 .02565 Mdot
.48571 .06623 Mdot
.49048 .16777 Mdot
.49524 .60476 Mdot
.5 .07074 Mdot
.50476 .34379 Mdot
.50952 .05373 Mdot
.51429 .09329 Mdot
.51905 .05037 Mdot
.52381 .20203 Mdot
.52857 .34764 Mdot
.53333 .0167 Mdot
.5381 .25144 Mdot
.54286 .00561 Mdot
.54762 .25457 Mdot
.55238 .04003 Mdot
.55714 .03422 Mdot
.5619 .33184 Mdot
.56667 .07205 Mdot
.57143 .22828 Mdot
.57619 .13245 Mdot
.58095 .32278 Mdot
.58571 .06448 Mdot
.59048 .15936 Mdot
.59524 .34762 Mdot
.6 .28588 Mdot
.60476 .48078 Mdot
.60952 .08343 Mdot
.61429 .15811 Mdot
.61905 .01948 Mdot
.62381 .13455 Mdot
.62857 .40748 Mdot
.63333 .03199 Mdot
.6381 .07272 Mdot
.64286 .05992 Mdot
.64762 .40605 Mdot
.65238 .02073 Mdot
.65714 .14138 Mdot
.6619 .01453 Mdot
.66667 .1354 Mdot
.67143 .12766 Mdot
.67619 .16508 Mdot
.68095 .02891 Mdot
.68571 .02681 Mdot
.69048 .10107 Mdot
.69524 .10925 Mdot
.7 .33925 Mdot
.70476 .02219 Mdot
.70952 .17671 Mdot
.71429 .00842 Mdot
.71905 .09066 Mdot
.72381 .05242 Mdot
.72857 .29004 Mdot
.73333 .02268 Mdot
.7381 .38839 Mdot
.74286 .41231 Mdot
.74762 .05522 Mdot
.75238 .02994 Mdot
.75714 .02989 Mdot
.7619 .06668 Mdot
.76667 .03584 Mdot
.77143 .00125 Mdot
.77619 .10752 Mdot
.78095 .11019 Mdot
.78571 .05164 Mdot
.79048 .1024 Mdot
.79524 .36685 Mdot
.8 .00483 Mdot
.80476 .36673 Mdot
.80952 .09538 Mdot
.81429 .19335 Mdot
.81905 .10594 Mdot
.82381 .11553 Mdot
.82857 .06001 Mdot
.83333 .26076 Mdot
.8381 .15552 Mdot
.84286 .09767 Mdot
.84762 .0343 Mdot
.85238 .10185 Mdot
.85714 .31704 Mdot
.8619 .18269 Mdot
.86667 .06137 Mdot
.87143 .1727 Mdot
.87619 .00607 Mdot
.88095 .09613 Mdot
.88571 .12804 Mdot
.89048 .29503 Mdot
.89524 .18848 Mdot
.9 .11741 Mdot
.90476 .18114 Mdot
.90952 .0442 Mdot
.91429 .07002 Mdot
.91905 .06967 Mdot
.92381 .21718 Mdot
.92857 .1186 Mdot
.93333 .04431 Mdot
.9381 .00915 Mdot
.94286 .10934 Mdot
.94762 .12921 Mdot
.95238 .19201 Mdot
.95714 .03248 Mdot
.9619 .07483 Mdot
.96667 .18244 Mdot
.97143 .17112 Mdot
.97619 .22095 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool01?l0003ooooo
ooooooooool2o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool002Cooooo00Co0000oooooooooooooooo0_l00009ooooo`04o`000?oooooooooooooo
o`;o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0000;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool3o`0000;ooooo00Co0000
oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Oooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003ooooo
ooooo`0:ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
000Tooooo`04o`000?ooooooooooooooo`;o00004?ooool2o`0004Oooooo0_l0000Uooooo`?o0000
1_ooool2o`0001Oooooo0_l0000eooooo`;o00006_ooool2o`0001Oooooo0_l0000Booooo`;o0000
6_ooool002Cooooo00?o0000ooooooooool04oooool2o`000<Oooooo0_l00017ooooo`;o00006_oo
ool002Cooooo0_l00010ooooo`;o0000R_ooool2o`0007Cooooo000Tooooo`03o`000?oooooooooo
03oooooo0_l0000:ooooo`;o00008oooool2o`0002oooooo0_l0000Jooooo`;o00003?ooool2o`00
07Cooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l0000Jooooo`;o00002Oooool2o`0000Co
oooo0_l0000Mooooo`;o00001_ooool2o`0002Oooooo0_l0000Jooooo`;o00002Oooool2o`0000oo
oooo0_l0001Vooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o00003Oooool2o`0001[ooooo
0_l0000?ooooo`;o00003?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000Fooooo`;o0000
=_ooool2o`0000oooooo0_l00007ooooo`;o0000GOooool002Cooooo00?o0000ooooooooool01?oo
ool2o`0000oooooo0_l00018ooooo`;o00001oooool2o`0000_ooooo0_l0000@ooooo`;o00001ooo
ool2o`00047ooooo0_l0000=ooooo`;o0000GOooool002Cooooo0_l00005ooooo`;o0000<Oooool2
o`0002oooooo0_l0000Mooooo`;o0000B?ooool4o`0001Cooooo0ol0001Eooooo`009?ooool00ol0
003oooooooooo`0gooooo`;o0000L?ooool2o`0001Oooooo0_l0000=ooooo`;o00005_ooool3o`00
01_ooooo0_l0000Rooooo`;o00005?ooool002Cooooo00?o0000ooooooooool09_ooool2o`00087o
oooo0_l0000Gooooo`;o0000:Oooool2o`0001Sooooo0_l0000Rooooo`;o00005?ooool002Cooooo
00?o0000ooooooooool08Oooool2o`0000?ooooo0_l00020ooooo`;o0000@oooool2o`0005;ooooo
000Tooooo`03o`000?oooooooooo027ooooo0_l0000Iooooo`;o00009?ooool2o`0004Cooooo0_l0
002Gooooo`009?ooool2o`0003gooooo0_l0000Tooooo`;o0000:oooool2o`0008[ooooo0_l00006
ooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0BOooool2o`0004Cooooo0_l0002:oooo
o`;o00001_ooool2o`0001cooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0000kooooo`;o
00001Oooool2o`0005;ooooo0_l00010ooooo`;o00004_ooool2o`0004cooooo000Tooooo`03o`00
0?oooooooooo00Gooooo0_l0000kooooo`;o0000E_ooool2o`000003ooooool0003o0000043ooooo
0_l00006ooooo`;o00002_ooool2o`0004cooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0
002;ooooo`;o0000Boooool2o`0005Sooooo000Tooooo`;o00003_ooool2o`000;Kooooo0_l0000j
ooooo`;o00002oooool2o`00037ooooo000Tooooo`03o`000?oooooooooo0;;ooooo0_l0000Aoooo
o`;o0000>_ooool2o`0000_ooooo0_l0000aooooo`009?ooool00ol0003oooooooooo`2Booooo`;o
00007_ooool2o`0003Sooooo0_l0001Cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo02cooooo0_l0001Tooooo`;o00000oooool2o`0005?ooooo0_l0000_ooooo`Co00008?ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05_ooool4o`0001;ooooo
0_l0001Yooooo`;o00004oooool2o`0001Gooooo0_l0001Hooooo`Co00002oooool2o`0001?ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`?o00005_ooool4o`000003ooooool0003o000004Cooooo0_l0
0019ooooo`;o00005Oooool2o`0006Oooooo0_l0000Cooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0Kooooo`;o00007Oooool2o`0002Gooooo0_l0003Nooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Oooooo0_l00009ooooo`;o00001_ooool2
o`0007kooooo0_l00025ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Woooo
o`;o00002Oooool2o`0002;ooooo0_l0001Rooooo`;o0000QOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0_ooooo`;o00009Oooool2o`000>Wooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00033o
oooo0_l00018ooooo`;o00008?ooool2o`00047ooooo0_l0001Qooooo`009?ooool00ol0003ooooo
ooooo`1=ooooo`;o0000:_ooool2o`00023ooooo0_l00011ooooo`;o00006oooool2o`0001Gooooo
0_l0000]ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000@Oooool2o`000:cooooo0_l0
0009ooooo`;o00002_ooool2o`0002gooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0001K
ooooo`;o00002Oooool2o`00063ooooo0_l0000Oooooo`;o00003oooool2o`000003ooooool0003o
000003Kooooo000Tooooo`03o`000?oooooooooo06Oooooo0_l00009ooooo`;o0000H?ooool2o`00
01oooooo0_l0000Booooo`;o0000=_ooool002Cooooo00?o0000ooooooooool0I?ooool2o`0002Oo
oooo0_l0001Qooooo`;o00003?ooool2o`00047ooooo000Tooooo`;o00000oooool2o`0001Kooooo
0_l0000Looooo`;o0000:_ooool2o`0001_ooooo0_l0000:ooooo`;o0000Aoooool2o`0001Sooooo
1?l0000:ooooo`;o00009_ooool2o`0001Wooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0
000Fooooo`;o00001?ooool2o`0001Kooooo0_l00003ooooo`;o0000@_ooool2o`0005?ooooo0_l0
000Jooooo`;o0000<_ooool2o`0001Wooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000K
ooooo`;o00005?ooool2o`000:_ooooo0_l0000Fooooo`;o00009oooool002Cooooo00?o0000oooo
ooooool0Doooool2o`000:_ooooo0_l0000Fooooo`;o00002?ooool2o`0001gooooo000Tooooo`03
o`000?oooooooooo08Wooooo0_l0002Gooooo`;o00007Oooool002Cooooo0_l0000Nooooo`;o0000
?oooool2o`0002Wooooo0_l0002fooooo`009?ooool00ol0003oooooooooo`0Mooooo`;o0000>ooo
ool2o`0000;ooooo0_l0001^ooooo`;o0000A?ooool2o`0001;ooooo0_l0000Gooooo`009?ooool0
0ol0003oooooooooo`1Jooooo`;o00003_ooool2o`00013ooooo0_l0000aooooo`;o00007Oooool2
o`0004Cooooo0_l0000Booooo`;o00005oooool002Cooooo00Co0000ooooool0003o0000COooool2
o`0001[ooooo0_l0000@ooooo`;o0000<Oooool2o`0000kooooo0_l0000<ooooo`;o0000L_ooool0
02Cooooo00Co0000ooooool0003o0000COooool2o`0006oooooo0_l0000<ooooo`;o0000L_ooool0
02Cooooo0_l0000eooooo`;o0000AOooool2o`0004gooooo0_l0001eooooo`009?ooool00ol0003o
ooooooooo`0dooooo`;o00003oooool2o`0003Cooooo0_l0001=ooooo`;o0000MOooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0AOooool2o`000?[ooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0<oooo
o`;o0000ooooooldooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0<ooooo`;o0000Eoooool2o`0000cooooo0_l0003<oooo
o`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
06Gooooo0_l0000<ooooo`;o00005Oooool2o`00033ooooo0_l00016ooooo`;o0000>oooool000Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2:ooooo`;o0000:?ooool2o`0000Kooooo0_l00016ooooo`;o0000>oooool0
00Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0]?ooool2o`0008_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=3ooooo0_l0001_ooooo`002Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo09Cooooo0_l0000j
ooooo`;o0000Koooool002Cooooo0_l0002Eooooo`;o0000NOooool2o`0001oooooo0_l0000?oooo
o`009?ooool00ol0003oooooooooo`3Kooooo`;o0000<_ooool2o`0001oooooo0_l0000?ooooo`00
9?ooool00ol0003oooooooooo`1[ooooo`;o0000K_ooool2o`0006Cooooo000Tooooo`03o`000?oo
oooooooo037ooooo0_l0000Tooooo`;o00004_ooool2o`0009oooooo0_l0000<ooooo`;o00004_oo
ool2o`00017ooooo000Tooooo`03o`000?oooooooooo02Wooooo0_l00006ooooo`;o00009?ooool2
o`000;?ooooo0_l0000<ooooo`;o00004_ooool2o`00017ooooo000Tooooo`;o0000:_ooool2o`00
0>cooooo0_l0000Xooooo`009?ooool00ol0003oooooooooo`1]ooooo`;o0000Z?ooool2o`00013o
oooo0_l0000Fooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o00006oooool2o`0008kooooo
0_l0000Zooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0D?ooool2o`000:_ooooo0_l0
0012ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000Woooool2o`00
0:7ooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0001nooooo`;o0000XOooool002Cooooo
00?o0000ooooooooool07_ooool2o`000?oooooo8_ooool002Cooooo00?o0000ooooooooool0=Ooo
ool2o`000?oooooo2oooool002Cooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0_l0000M
ooooo`;o0000joooool002Cooooo0_l0000_ooooo`;o00009?ooool2o`000<[ooooo0_l0000Ooooo
o`009?ooool00ol0003oooooooooo`3oooooob7ooooo0_l0000?ooooo`;o00003_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0A_ooool2o`000>Wooooo0_l0000>
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0A_ooool2o`0006Kooooo0_l0
002Aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00004_ooool2
o`0008Wooooo0_l0002Aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000oooooo0_l0000Boooo
o`;o0000DOooool2o`0000kooooo0_l0002iooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo02_ooooo0_l00019ooooo`;o00003_ooool2o`000;Wooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0_l0003ooooooaGooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0Xoooool2o`0009cooooo000Tooooo`03
o`000?oooooooooo05Wooooo0_l00018ooooo`;o000000?oooooo`000?l00000VOooool002Cooooo
00?o0000ooooooooool0FOooool2o`0004_ooooo0_l0002Iooooo`009?ooool00ol0003ooooooooo
o`3oooooo`Cooooo0_l0000looooo`009?ooool2o`000?oooooo1Oooool2o`0003cooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0B?ooool2o`000?Oo
oooo000Tooooo`03o`000?oooooooooo00Oooooo0_l0000oooooo`;o0000moooool002Cooooo00?o
0000ooooooooool01oooool2o`000?oooooo>Oooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0]oooool2o`0008So
oooo000Tooooo`03o`000?oooooooooo0;Oooooo0_l0000Xooooo`;o0000G_ooool002Cooooo00?o
0000ooooooooool0hOooool2o`0005kooooo000Tooooo`;o0000oooooolGooooo`;o0000:_ooool0
02Cooooo00?o0000ooooooooool0oooooolFooooo`;o0000:_ooool001[ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom2
ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo2oooool2o`0003Gooooo
000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0/Oooool2o`0008kooooo000T
ooooo`;o0000/_ooool2o`0008kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0Zoooool2o`0009Cooooo000Tooooo`03o`000?oooooooooo0:_ooooo
0_l0002Dooooo`009?ooool00ol0003oooooooooo`3Hooooo`;o0000Ioooool002Cooooo0_l0003I
ooooo`;o0000Ioooool002Cooooo00?o0000ooooooooool0V?ooool2o`000:Oooooo000Tooooo`03
o`000?oooooooooo09Sooooo0_l00006ooooo`;o00005?ooool2o`0008Wooooo000Tooooo`03o`00
0?oooooooooo0:3ooooo0_l0000Dooooo`;o0000ROooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo01;ooooo
0_l0003Rooooo`;o000000?oooooo`000?l00000A_ooool002Cooooo00?o0000ooooooooool04_oo
ool2o`000>;ooooo0_l000000ooooooo0000o`000016ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
od;ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Tooooo`;o0000
Foooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Tooooo`;o0000Foooool000Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000;ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Toooo
o`03o`000?oooooooooo0<3ooooo0_l00005ooooo`;o0000N?ooool002Cooooo00?o0000oooooooo
ool0`?ooool2o`0000Gooooo0_l0001hooooo`009?ooool00ol0003oooooooooo`3Uooooo`;o0000
F_ooool002Cooooo00?o0000ooooooooool0iOooool2o`0005[ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
2Oooool2o`000?oooooo=oooool002Cooooo00?o0000ooooooooool02Oooool2o`000?oooooo=ooo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000[o
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooo
oom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`03
oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
0_l0002jooooo`;o0000Q_ooool002Cooooo00?o0000ooooooooool0^Oooool2o`0008Kooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00go
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`00
1?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool0
3Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?o
EEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1oooooo`;o0000
`?ooool002Cooooo00?o0000ooooooooool0Ooooool2o`000<3ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000U_ooool2
o`000:[ooooo000Tooooo`03o`000?oooooooooo09Gooooo0_l0002Zooooo`006Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo@_oo
ool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3ooooo
odWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .4639 Mdot
.03333 .00194 Mdot
.0381 .15394 Mdot
.04286 .01003 Mdot
.04762 .02807 Mdot
.05238 .09617 Mdot
.05714 .09527 Mdot
.0619 .17296 Mdot
.06667 .06775 Mdot
.07143 .15299 Mdot
.07619 .05777 Mdot
.08095 .07458 Mdot
.08571 .00161 Mdot
.09048 .23636 Mdot
.09524 .00881 Mdot
.1 .2429 Mdot
.10476 .21777 Mdot
.10952 .07299 Mdot
.11429 .06125 Mdot
.11905 .00253 Mdot
.12381 .15839 Mdot
.12857 .20551 Mdot
.13333 .19793 Mdot
.1381 .0404 Mdot
.14286 .12679 Mdot
.14762 .08892 Mdot
.15238 .03599 Mdot
.15714 .03193 Mdot
.1619 .17057 Mdot
.16667 .23646 Mdot
.17143 .27459 Mdot
.17619 .00845 Mdot
.18095 .10921 Mdot
.18571 .09003 Mdot
.19048 .13431 Mdot
.19524 .12546 Mdot
.2 .21161 Mdot
.20476 .11942 Mdot
.20952 .0691 Mdot
.21429 .08066 Mdot
.21905 .04172 Mdot
.22381 .02456 Mdot
.22857 .01521 Mdot
.23333 .19071 Mdot
.2381 .05059 Mdot
.24286 .00381 Mdot
.24762 .14358 Mdot
.25238 .03179 Mdot
.25714 .26895 Mdot
.2619 .10755 Mdot
.26667 .04591 Mdot
.27143 .20855 Mdot
.27619 .12205 Mdot
.28095 .08878 Mdot
.28571 .03515 Mdot
.29048 .09659 Mdot
.29524 .16375 Mdot
.3 .08667 Mdot
.30476 .03136 Mdot
.30952 .0145 Mdot
.31429 .37629 Mdot
.31905 .00429 Mdot
.32381 .11982 Mdot
.32857 .02429 Mdot
.33333 .09843 Mdot
.3381 .04182 Mdot
.34286 .07595 Mdot
.34762 .1627 Mdot
.35238 .06654 Mdot
.35714 .02726 Mdot
.3619 .1806 Mdot
.36667 .02719 Mdot
.37143 .2937 Mdot
.37619 .02566 Mdot
.38095 .01906 Mdot
.38571 .34053 Mdot
.39048 .10285 Mdot
.39524 .11174 Mdot
.4 .1218 Mdot
.40476 .00232 Mdot
.40952 .09124 Mdot
.41429 .25252 Mdot
.41905 .17144 Mdot
.42857 .58348 Mdot
.43333 .10904 Mdot
.4381 .00711 Mdot
.44286 .00485 Mdot
.44762 .14111 Mdot
.45238 .10358 Mdot
.45714 .12309 Mdot
.4619 .02089 Mdot
.46667 .00636 Mdot
.47143 .07501 Mdot
.47619 .04557 Mdot
.48095 .02565 Mdot
.48571 .06623 Mdot
.49048 .16777 Mdot
.5 .11824 Mdot
.50476 .29861 Mdot
.50952 .06331 Mdot
.51429 .11277 Mdot
.51905 .01374 Mdot
.52381 .22159 Mdot
.52857 .2638 Mdot
.53333 .03417 Mdot
.5381 .30782 Mdot
.54286 .00561 Mdot
.54762 .25457 Mdot
.55238 .04003 Mdot
.55714 .03422 Mdot
.5619 .23142 Mdot
.56667 .07205 Mdot
.57143 .4546 Mdot
.57619 .16267 Mdot
.58095 .29389 Mdot
.58571 .06448 Mdot
.59048 .11811 Mdot
.59524 .05026 Mdot
.6 .02692 Mdot
.60476 .26079 Mdot
.60952 .01681 Mdot
.61429 .15811 Mdot
.61905 .01948 Mdot
.62381 .06644 Mdot
.62857 .40748 Mdot
.63333 .05753 Mdot
.6381 .07272 Mdot
.64286 .05001 Mdot
.64762 .42383 Mdot
.65238 .01896 Mdot
.65714 .07483 Mdot
.6619 .01453 Mdot
.66667 .1354 Mdot
.67143 .10296 Mdot
.67619 .16802 Mdot
.68095 .02891 Mdot
.68571 .02681 Mdot
.69048 .04579 Mdot
.69524 .06064 Mdot
.7 .00719 Mdot
.70476 .02219 Mdot
.70952 .17559 Mdot
.71429 .00842 Mdot
.71905 .03054 Mdot
.72381 .04762 Mdot
.72857 .16711 Mdot
.73333 .03496 Mdot
.7381 .29606 Mdot
.74286 .48805 Mdot
.74762 .05522 Mdot
.75238 .02994 Mdot
.75714 .14394 Mdot
.7619 .41044 Mdot
.76667 .0115 Mdot
.77143 .00125 Mdot
.77619 .10752 Mdot
.78095 .01526 Mdot
.78571 .12743 Mdot
.79048 .06739 Mdot
.79524 .03189 Mdot
.8 .00483 Mdot
.80476 .36673 Mdot
.80952 .14255 Mdot
.81429 .19335 Mdot
.81905 .0907 Mdot
.82381 .04519 Mdot
.82857 .22556 Mdot
.83333 .18657 Mdot
.8381 .13902 Mdot
.84286 .09767 Mdot
.84762 .19022 Mdot
.85238 .09241 Mdot
.85714 .11904 Mdot
.8619 .16108 Mdot
.86667 .08291 Mdot
.87143 .1727 Mdot
.87619 .11752 Mdot
.88095 .06778 Mdot
.88571 .29852 Mdot
.89048 .0282 Mdot
.89524 .07986 Mdot
.9 .04162 Mdot
.90476 .02523 Mdot
.90952 .0442 Mdot
.91429 .07002 Mdot
.91905 .04823 Mdot
.92381 .21718 Mdot
.92857 .1186 Mdot
.93333 .08903 Mdot
.9381 .11359 Mdot
.94286 .10934 Mdot
.94762 .31045 Mdot
.95238 .39738 Mdot
.95714 .03248 Mdot
.9619 .21023 Mdot
.96667 .23663 Mdot
.97143 .23345 Mdot
.97619 .02787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00Co0000ooooool0003o00002oooool01?l0003o
ooooooooooooool2o`0000Wooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00003oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo00Co0000ooooool0
003o00002oooool01?l0003oooooooooooooool2o`0000Wooooo0_l0000>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool0
1?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo0_l00009ooooo`?o00000_oo
ool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool02oooool3o`0000kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0000:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`;o0000
6Oooool2o`0002cooooo0_l0000Uooooo`?o00001_ooool2o`0001Oooooo0_l0000aooooo`;o0000
0_ooool2o`0001[ooooo0_l00017ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o00003ooo
ool2o`0001Wooooo0_l0002Xooooo`;o00000_ooool2o`0000oooooo0_l0001Booooo`009?ooool2
o`00043ooooo0_l0000Hooooo`;o0000@_ooool2o`0002cooooo0_l0000Pooooo`;o00000oooool2
o`0004gooooo000Tooooo`03o`000?oooooooooo03oooooo0_l0000Hooooo`;o00005Oooool2o`00
02_ooooo0_l0000Kooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o0000
02Gooooo0_l0001=ooooo`009?ooool00ol0003oooooooooo`1`ooooo`;o00006?ooool2o`0002ko
oooo0_l000000ooooooo0000o`000009ooooo`;o00003oooool2o`0006Kooooo000Tooooo`03o`00
0?oooooooooo03gooooo0_l0000Pooooo`;o0000:Oooool2o`0000Cooooo0_l00017ooooo`;o0000
?oooool2o`0002Gooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0000gooooo`;o00008?oo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`00023ooooo0_l0000Uooooo`;o0000
6_ooool2o`00043ooooo0_l00003ooooo`;o00005Oooool2o`0000kooooo000Tooooo`;o00001Ooo
ool2o`00043ooooo0_l0000?ooooo`;o00003oooool2o`000004ooooool0003o0000ooooo`;o0000
Aoooool2o`0001Sooooo1?l00009ooooo`;o00002Oooool2o`0002[ooooo0_l0000Jooooo`;o0000
3_ooool002Cooooo00?o0000ooooooooool09oooool2o`0001gooooo0_l0000?ooooo`;o0000B?oo
ool2o`0000Kooooo0_l0000Vooooo`;o00002oooool2o`0000Wooooo0_l0000;ooooo`;o0000<ooo
ool2o`0001Cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0000Xooooo`;o0000C_ooool2
o`0000Kooooo0_l0000gooooo`;o00004_ooool2o`0003?ooooo0_l0000Dooooo`009?ooool00ol0
003oooooooooo`0Qooooo`;o00000oooool2o`0002Wooooo0_l0001Eooooo`;o0000>?ooool2o`00
05gooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0000Iooooo`;o00009?ooool2o`0004Co
oooo0_l0001^ooooo`;o00009oooool002Cooooo0_l0000mooooo`;o00003Oooool2o`0001Gooooo
0_l0000[ooooo`;o0000@oooool2o`0002[ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
9?ooool002Cooooo00?o0000ooooooooool0Boooool2o`0004;ooooo0_l0000Uooooo`;o00003Ooo
ool2o`0000gooooo0_l00009ooooo`;o00007oooool2o`0001Wooooo0_l00002ooooo`;o00008?oo
ool002Cooooo00?o0000ooooooooool0@_ooool2o`0007;ooooo0_l0000=ooooo`;o00006?ooool2
o`0003kooooo0_l0000Pooooo`009?ooool00ol0003oooooooooo`12ooooo`;o0000Xoooool2o`00
05Sooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0002cooooo`;o00008oooool2o`0005So
oooo000Tooooo`;o00003_ooool2o`0000_ooooo0_l0002Vooooo`;o00004_ooool2o`0006Wooooo
000Tooooo`03o`000?oooooooooo01[ooooo0_l0001nooooo`;o00005_ooool2o`0002;ooooo0_l0
001Yooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000Foooool2o`0002Wooooo0_l00006
ooooo`;o00005_ooool2o`0000_ooooo0_l0000dooooo`;o00006oooool2o`0002gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool2o`0002cooooo0_l0000]ooooo`;o0000
:Oooool2o`0002_ooooo0_l0000dooooo`;o00006oooool2o`0000Wooooo0_l0000Rooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o00001oooool2o`00
01kooooo0_l0001booooo`;o00005Oooool2o`0000Gooooo0_l0001Aooooo`;o00008_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol0000?ooooo`;o00001oooool2o`0004[ooooo0_l0000Wooooo`;o
00007Oooool2o`0001Gooooo0_l00005ooooo`;o0000MOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0>_ooool2o`0002Sooooo0_l0000Wooooo`;o0000R?ooool2o`0002Sooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>_ooool2o`000=;ooooo
0_l00007ooooo`;o0000:?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_oo
ool2o`000;Kooooo0_l0000aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Co
oooo0_l0000;ooooo`;o00007Oooool2o`0000Cooooo0_l0003;ooooo`;o00007?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o00009Oooool2o`0000_ooooo0_l0000Mooooo`;o00009oooool2o`0008?ooooo0_l00009
ooooo`;o00006?ooool2o`0001cooooo000Tooooo`03o`000?oooooooooo00Gooooo1?l0001`oooo
o`;o0000Poooool2o`0000Wooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`05ooooo`Co
0000B_ooool2o`0000cooooo0_l0002Sooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool0
Doooool2o`0000cooooo0_l0002Sooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool0Looo
ool2o`0001;ooooo0_l00015ooooo`;o0000LOooool002Cooooo00?o0000ooooooooool0BOooool2
o`0002Sooooo0_l0000Booooo`;o0000AOooool2o`00023ooooo0_l0001?ooooo`009?ooool2o`00
033ooooo0_l0000Hooooo`;o0000:_ooool2o`0000[ooooo0_l0001]ooooo`;o0000=?ooool2o`00
01Wooooo000Tooooo`03o`000?oooooooooo02oooooo0_l00014ooooo`;o00002_ooool2o`0001So
oooo0_l00028ooooo`?o00006Oooool002Cooooo00?o0000ooooooooool0Voooool2o`0001Oooooo
0_l0001Kooooo`;o00004_ooool2o`0001[ooooo000Tooooo`03o`000?oooooooooo03Oooooo0_l0
000Uooooo`;o0000=oooool2o`0001_ooooo0_l0001Dooooo`;o00001Oooool2o`0000oooooo0_l0
000Mooooo`009?ooool00ol0003oooooooooo`0gooooo`;o00005Oooool2o`0000kooooo0_l0000F
ooooo`;o00004Oooool2o`0000cooooo0_l0001aooooo`;o00005_ooool2o`0001gooooo000Toooo
o`;o00009?ooool2o`0000oooooo0_l0000Hooooo`;o00009_ooool2o`00017ooooo0_l0002foooo
o`009?ooool00ol0003oooooooooo`0Sooooo`;o00003oooool2o`000;gooooo0_l0001<ooooo`00
9?ooool00ol0003oooooooooo`3cooooo`;o0000C?ooool002Cooooo00?o0000ooooooooool0<_oo
ool2o`0009Wooooo0_l0001booooo`009?ooool00ol0003oooooooooo`0booooo`;o0000VOooool2
o`0003Gooooo0_l0000kooooo`009?ooool2o`0008Oooooo0_l0001cooooo`;o00001oooool2o`00
03_ooooo000Tooooo`03o`000?oooooooooo04Gooooo0_l0000oooooo`;o0000H_ooool2o`0000oo
oooo0_l00014ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`15ooooo`;o0000Xoooool2o`00
05Gooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0009ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00002Oooool2
o`000?oooooo=?ooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol000000ooooooo0000o`000009ooooo`;o0000[_ooool2o`0008?ooooo0009oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool07Oooool2o`0009gooooo0_l0001>ooooo`;o0000<oooool000Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Ooo
ool2o`0003Gooooo0_l0000?ooooo`;o0000B?ooool2o`0005_ooooo0_l0000cooooo`002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Dooooo`;o00003oooool2o`0004Sooooo0_l0000`ooooo`;o0000G_ooool000Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Yooooo`;o0000JOoo
ool2o`0003[ooooo0_l0000?ooooo`;o0000G_ooool002Cooooo0_l0000:ooooo`;o00007_ooool2
o`00057ooooo0_l0000Fooooo`;o0000>_ooool2o`0003gooooo0_l0000`ooooo`009?ooool00ol0
003oooooooooo`09ooooo`;o0000LOooool2o`0005gooooo0_l0000booooo`;o0000<?ooool002Co
oooo00?o0000ooooooooool0foooool2o`0006Cooooo000Tooooo`03o`000?oooooooooo06[ooooo
0_l0003Eooooo`009?ooool00ol0003oooooooooo`1Zooooo`;o0000eOooool002Cooooo0_l0003o
ooooo`Gooooo0_l0000looooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000`Oooool2o`00
00;ooooo0_l0000hooooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000^oooool2o`0000So
oooo0_l0000hooooo`009?ooool00ol0003oooooooooo`0Pooooo`;o0000foooool2o`0004;ooooo
000Tooooo`03o`000?oooooooooo023ooooo0_l0003oooooob3ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000oooooolRooooo`009?ooool00ol0003o
ooooooooo`0Nooooo`;o0000;Oooool2o`000=gooooo0_l0000Cooooo`009?ooool00ol0003ooooo
ooooo`0eooooo`;o00005_ooool2o`000=gooooo0_l0000Cooooo`009?ooool00ol0003ooooooooo
o`0eooooo`;o0000ooooool;ooooo`009?ooool2o`0001Oooooo0_l0003oooooo`Wooooo0_l0000O
ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000Q_ooool2o`00083ooooo0_l0000Ooooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Nooooo`;o0000HOoo
ool2o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooo`;ooooo
0_l0000nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2[ooooo`;o0000U?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002[ooooo`;o0000Poooool2o`0000oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`0001Oooooo0_l0003o
ooooo`;ooooo1?l0000?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`;o00005oooool2o`000?oooooo0_ooool2o`00017ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05Oooool2o`000?oooooo:oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooob_ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`1kooooo`;o0000a?ooool0
02Cooooo00?o0000ooooooooool0Noooool2o`0002Wooooo0_l0002Iooooo`009?ooool00ol0003o
ooooooooo`2Vooooo`;o0000VOooool002Cooooo00?o0000ooooooooool0^Oooool2o`0008Kooooo
000Tooooo`;o0000XOooool2o`0001Oooooo0_l00026ooooo`009?ooool00ol0003oooooooooo`18
ooooo`;o0000E_ooool2o`0009oooooo000Tooooo`03o`000?oooooooooo04Sooooo0_l0003goooo
o`009?ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolDooooo`009?ooool00ol0003ooooo
ooooo`0/ooooo`;o0000oooooolDooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0KOooool2o`0004;ooooo
0_l0002>ooooo`009?ooool2o`0006kooooo0_l00012ooooo`;o0000<Oooool2o`0005_ooooo000T
ooooo`03o`000?oooooooooo09Sooooo0_l0001:ooooo`;o0000;_ooool2o`0002_ooooo000Joooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2Hooooo`;o0000N_ooool2o`00
02_ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:?ooooo0_l0002Looooo`007?oo
ool00ol0003oooooooooo`05ooooo`?o0000Xoooool2o`0008?ooooo0_l0000Gooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo:Oooool2o`0001Oooooo000Loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000Loooool2o`000<gooooo000Tooooo`03o`000?oooooooooo07;ooooo0_l0003=
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?Wooooo0_l00016ooooo`009?ooool00ol0003ooooo
ooooo`3iooooo`;o0000A_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo05[ooooo0_l0003Uooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0F_ooool2
o`000>Gooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooob[ooooo0_l0000Fooooo`000_oo
ool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0oooooolZooooo`;o00005_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0<3ooooo0_l0001oooooo`009?ooool00ol0003oooooooooo`30oooo
o`;o0000:_ooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo0>cooooo0_l0001Cooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0<Oooooo0_l0001hoooo
o`009?ooool00ol0003oooooooooo`37ooooo`;o0000N?ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2^
ooooo`;o0000TOooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2^ooooo`;o0000TOooool000cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo
00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?oo
ool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool3o`000?oooooo
@_ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`00
00Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3Uooooo`;o0000F_oo
ool002Cooooo00?o0000ooooooooool0iOooool2o`0005[ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooo
oooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00go
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go0000
1?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo07oo
oooo0_l00030ooooo`009?ooool00ol0003oooooooooo`1oooooo`;o0000`?ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_oo
ool001gooooo00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So
410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44148 Mdot
.03333 .06077 Mdot
.0381 .1342 Mdot
.04286 .15513 Mdot
.04762 .02807 Mdot
.05238 .09902 Mdot
.05714 .16138 Mdot
.0619 .31261 Mdot
.06667 .06775 Mdot
.07143 .05905 Mdot
.07619 .06077 Mdot
.08095 .16652 Mdot
.08571 .01586 Mdot
.09048 .03629 Mdot
.09524 .18318 Mdot
.1 .12972 Mdot
.10476 .17578 Mdot
.10952 .13072 Mdot
.11429 .06125 Mdot
.11905 .06893 Mdot
.12381 .0081 Mdot
.12857 .1092 Mdot
.13333 .2018 Mdot
.1381 .22968 Mdot
.14286 .12679 Mdot
.14762 .04961 Mdot
.15238 .01251 Mdot
.15714 .11657 Mdot
.1619 .1475 Mdot
.16667 .40047 Mdot
.17143 .16157 Mdot
.17619 .0695 Mdot
.18095 .19837 Mdot
.18571 .12286 Mdot
.19048 .32165 Mdot
.19524 .33264 Mdot
.2 .32659 Mdot
.20476 .11942 Mdot
.20952 .03669 Mdot
.21429 .1499 Mdot
.21905 .02782 Mdot
.22381 .21456 Mdot
.22857 .08982 Mdot
.23333 .19071 Mdot
.2381 .05059 Mdot
.24286 .04506 Mdot
.24762 .20727 Mdot
.25238 .03179 Mdot
.25714 .04147 Mdot
.2619 .44546 Mdot
.26667 .04591 Mdot
.27143 .2147 Mdot
.27619 .12205 Mdot
.28095 .08878 Mdot
.28571 .12482 Mdot
.29048 .02706 Mdot
.29524 .03612 Mdot
.3 .08667 Mdot
.30476 .03136 Mdot
.30952 .06213 Mdot
.31429 .54963 Mdot
.31905 .02564 Mdot
.32381 .06732 Mdot
.32857 .05498 Mdot
.33333 .2258 Mdot
.3381 .04182 Mdot
.34286 .00219 Mdot
.34762 .00922 Mdot
.35238 .09488 Mdot
.35714 .02726 Mdot
.3619 .09231 Mdot
.36667 .02719 Mdot
.37143 .22393 Mdot
.37619 .00248 Mdot
.38095 .15184 Mdot
.38571 .44131 Mdot
.39048 .45147 Mdot
.39524 .246 Mdot
.4 .1218 Mdot
.40476 .05009 Mdot
.40952 .09124 Mdot
.41429 .09261 Mdot
.41905 .04943 Mdot
.43333 .1456 Mdot
.4381 .02217 Mdot
.44286 .00741 Mdot
.44762 .24845 Mdot
.45238 .23432 Mdot
.45714 .06961 Mdot
.4619 .02089 Mdot
.46667 .00636 Mdot
.47143 .20313 Mdot
.47619 .13681 Mdot
.48095 .02565 Mdot
.48571 .06623 Mdot
.49048 .02035 Mdot
.49524 .5284 Mdot
.5 .14252 Mdot
.50476 .54425 Mdot
.50952 .06017 Mdot
.51429 .11277 Mdot
.51905 .01374 Mdot
.52381 .22159 Mdot
.52857 .10061 Mdot
.53333 .06577 Mdot
.5381 .05394 Mdot
.54286 .00561 Mdot
.54762 .34421 Mdot
.55238 .04003 Mdot
.55714 .03422 Mdot
.5619 .05985 Mdot
.56667 .07205 Mdot
.57143 .41682 Mdot
.57619 .11218 Mdot
.58095 .31452 Mdot
.58571 .11905 Mdot
.59048 .04168 Mdot
.59524 .05026 Mdot
.6 .02692 Mdot
.60476 .19657 Mdot
.60952 .12428 Mdot
.61429 .05125 Mdot
.61905 .01948 Mdot
.62381 .06644 Mdot
.62857 .58201 Mdot
.63333 .05753 Mdot
.6381 .02121 Mdot
.64286 .22717 Mdot
.64762 .35008 Mdot
.65238 .01184 Mdot
.65714 .07483 Mdot
.6619 .01453 Mdot
.66667 .02031 Mdot
.67143 .16326 Mdot
.67619 .1394 Mdot
.68095 .00866 Mdot
.68571 .10947 Mdot
.69048 .09484 Mdot
.69524 .02906 Mdot
.7 .00719 Mdot
.70476 .16604 Mdot
.70952 .06735 Mdot
.71429 .03657 Mdot
.71905 .03054 Mdot
.72381 .14487 Mdot
.72857 .09297 Mdot
.73333 .03496 Mdot
.7381 .25789 Mdot
.74286 .57315 Mdot
.74762 .02026 Mdot
.75238 .02994 Mdot
.75714 .06962 Mdot
.7619 .57399 Mdot
.76667 .08537 Mdot
.77143 .17238 Mdot
.77619 .10752 Mdot
.78095 .00339 Mdot
.78571 .03216 Mdot
.79048 .31331 Mdot
.79524 .16896 Mdot
.8 .00483 Mdot
.80476 .16966 Mdot
.80952 .18467 Mdot
.81429 .04121 Mdot
.81905 .0907 Mdot
.82381 .04519 Mdot
.82857 .10005 Mdot
.83333 .23429 Mdot
.8381 .10623 Mdot
.84286 .16165 Mdot
.84762 .11626 Mdot
.85238 .347 Mdot
.85714 .45544 Mdot
.8619 .24279 Mdot
.86667 .10898 Mdot
.87143 .1727 Mdot
.87619 .12928 Mdot
.88095 .06778 Mdot
.88571 .41648 Mdot
.89048 .34475 Mdot
.89524 .07986 Mdot
.9 .04162 Mdot
.90476 .07968 Mdot
.90952 .00657 Mdot
.91429 .04151 Mdot
.91905 .05142 Mdot
.92381 .11046 Mdot
.92857 .00046 Mdot
.93333 .08903 Mdot
.9381 .00721 Mdot
.94286 .00361 Mdot
.94762 .07576 Mdot
.95238 .15069 Mdot
.95714 .03248 Mdot
.9619 .05579 Mdot
.96667 .007 Mdot
.97143 .05635 Mdot
.97619 .02787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000?ooooo
00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0:ooooo`?o00003oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`07ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003ooooooooo
o`0<ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`?o0000
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`?o00000oooool2o`0000[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`05ooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000Ko
oooo0_l00002ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo01gooooo
0_l00016ooooo`;o00007Oooool2o`0000Kooooo0_l0000Gooooo`;o0000:_ooool2o`0000Gooooo
0_l0000Nooooo`;o00008Oooool2o`0000Sooooo0_l00007ooooo`;o00004Oooool002Cooooo00?o
0000ooooooooool07Oooool2o`0000Oooooo0_l0000mooooo`;o00007Oooool2o`0004;ooooo0_l0
0007ooooo`;o00001Oooool2o`0004_ooooo0_l0000Jooooo`009?ooool2o`00017ooooo0_l0000D
ooooo`;o0000MOooool2o`0002Wooooo0_l000000ooooooo0000o`00001dooooo`009?ooool00ol0
003oooooooooo`0@ooooo`;o0000Roooool2o`0001kooooo0_l0000<ooooo`;o0000M?ooool002Co
oooo00?o0000ooooooooool0Poooool2o`0000Gooooo0_l00008ooooo`;o00009oooool2o`0000Co
oooo0_l00008ooooo`;o00006?ooool2o`0005Sooooo000Tooooo`03o`000?oooooooooo05cooooo
0_l0000Uooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000;Oooool2o`0000Sooooo
0_l0000Hooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool01?ooool2o`0003Kooooo0_l0
000Eooooo`;o00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Sooooo`;o00009Ooo
ool2o`0007Sooooo0_l0000>ooooo`009?ooool2o`0000Gooooo0_l0000fooooo`;o00002?ooool2
o`0000_ooooo0_l00002ooooo`;o00003oooool2o`000003ooooool0003o000004[ooooo0_l0000M
ooooo`;o00001_ooool2o`0000Wooooo0_l00016ooooo`;o00003_ooool002Cooooo00?o0000oooo
ooooool0A_ooool2o`0000oooooo0_l0001@ooooo`;o0000:oooool2o`0000Kooooo0_l00009oooo
o`;o00002?ooool2o`0003Kooooo0_l0000Dooooo`009?ooool00ol0003oooooooooo`0Booooo`;o
00009?ooool2o`0001[ooooo0_l0001Cooooo`;o0000<Oooool2o`0000Cooooo0_l0000?ooooo`;o
0000=_ooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo01;ooooo0_l0000Tooooo`;o0000
6_ooool2o`0005;ooooo0_l0000booooo`;o00001?ooool2o`0005gooooo000Tooooo`03o`000?oo
oooooooo04Sooooo0_l0000Hooooo`;o0000A?ooool2o`0000[ooooo0_l00017ooooo`;o00006Ooo
ool2o`0000?ooooo0_l0000Rooooo`009?ooool2o`0004Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000005Oooool2o`00053ooooo0_l00017ooooo`;o000000?oooooo`000?l000005_ooool2
o`0000?ooooo0_l0000Rooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o00007Oooool2o`00
00Kooooo0_l0000[ooooo`;o00000_ooool2o`0003Sooooo0_l00018ooooo`;o0000?oooool002Co
oooo00?o0000ooooooooool09?ooool2o`0001cooooo0_l0000dooooo`;o00000_ooool2o`0003So
oooo0_l00004ooooo`;o0000HOooool2o`00023ooooo000Tooooo`03o`000?oooooooooo04;ooooo
0_l0000Kooooo`;o0000@_ooool2o`0001Oooooo0_l0001Qooooo`;o00002oooool2o`0000;ooooo
0_l0000?ooooo`009?ooool00ol0003oooooooooo`0<ooooo`;o0000DOooool2o`0004;ooooo0_l0
000Mooooo`;o0000J?ooool2o`0000;ooooo0_l0000?ooooo`009?ooool4o`0000_ooooo0ol0000;
ooooo`;o0000?Oooool2o`0003oooooo0_l0000?ooooo`;o00005Oooool2o`0007gooooo000Toooo
o`04o`000?oooooo0000o`0000cooooo0_l0000;ooooo`;o0000?Oooool2o`0003oooooo0_l0000?
ooooo`;o0000U?ooool002Cooooo00?o0000ooooooooool02_ooool2o`0005;ooooo0_l0000boooo
o`;o00003Oooool2o`0001cooooo0_l0000Jooooo`;o0000=Oooool2o`0002gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool2o`0000oooooo0_l0000Aooooo`;o0000;_oo
ool2o`0002Wooooo0_l00007ooooo`;o00003Oooool2o`0001cooooo0_l0000Jooooo`;o00003Ooo
ool2o`0002Kooooo0_l0000]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Kooooo`;o00004Oooool2o`0005Wooooo0_l0000Qooooo`;o00007?ooool2o`0001ko
oooo0_l0001Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000:cooooo0_l0000Looooo`;o0000
G?ooool2o`0001Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo6?oo
ool2o`000003ooooool0003o000000cooooo0_l0000Gooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo6?ooool2o`000003ooooool0003o000002Gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo0_l0002Eooooo`;o0000D_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`;o00003oooool2o`0000Cooooo
0_l0002Eooooo`;o0000=?ooool2o`0001cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00043ooooo0_l0000?oooo
o`;o00006?ooool2o`0000gooooo1?l0001Tooooo`;o00006oooool2o`0002?ooooo0_l0000Loooo
o`009?ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l000003Oooool4o`0005Oo
oooo0_l0000;ooooo`;o00006oooool2o`00047ooooo000Tooooo`03o`000?oooooooooo00Gooooo
0_l0001Pooooo`;o0000Joooool2o`0006_ooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0
002Iooooo`;o0000Goooool2o`0003kooooo000Tooooo`03o`000?oooooooooo0:3ooooo0_l0001O
ooooo`;o0000?_ooool002Cooooo00?o0000ooooooooool0l?ooool2o`0001;ooooo0_l0000koooo
o`009?ooool2o`0001oooooo0_l0002cooooo`;o00006oooool2o`0001;ooooo0_l00008ooooo`;o
00004?ooool2o`0001oooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0001kooooo`;o0000
4_ooool2o`0002;ooooo0_l0000iooooo`;o00004?ooool2o`0001oooooo000Tooooo`03o`000?oo
oooooooo02Oooooo0_l0001booooo`;o00004_ooool2o`0005Kooooo0_l0000hooooo`009?ooool0
0ol0003oooooooooo`0Wooooo`;o00003_ooool2o`0007Wooooo0_l0001Cooooo`;o0000>?ooool0
02Cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l0000Eooooo`;o00009_ooool2o`00
03[ooooo0_l00006ooooo`;o0000QOooool002Cooooo0_l0000Tooooo`;o00003?ooool2o`0001_o
oooo0_l000000ooooooo0000o`00000Sooooo`;o0000@_ooool2o`0008Gooooo000Tooooo`03o`00
0?oooooooooo01Gooooo0_l0000<ooooo`;o0000;?ooool2o`000;kooooo0_l0000^ooooo`009?oo
ool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l00000moooool2o`0002kooooo000T
ooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`000?oooooo:?ooool002Cooooo00Co0000
oooooooooooooooo0_l0002<ooooo`;o0000?oooool2o`0006oooooo000Tooooo`;o0000T?ooool2
o`0000Kooooo0_l0000gooooo`;o0000Koooool002Cooooo00?o0000ooooooooool0POooool2o`00
01Cooooo0_l00016ooooo`;o0000H?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0:Oooool2
o`0005Kooooo0_l0001Looooo`;o0000H?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Wooooo0_l0000?
ooooo`;o0000=?ooool2o`000;Oooooo0_l0000Fooooo`002Oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o0000=_ooool2
o`0003Cooooo0_l0002gooooo`;o00005_ooool000Wooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`;o0000oooooolnooooo`002Oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool2o`0002?ooooo0_l0002Pooooo`;o0000=_oo
ool2o`0003Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`;o00006oooool2o`000:3ooooo0_l0
0009ooooo`;o0000:oooool2o`0003Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo00?o0000ooooooooool03oooool2o`000<Sooooo0_l0000Kooooo`;o000000?o
ooooo`000?l00000A_ooool002Cooooo0_l0003`ooooo`;o00001Oooool2o`000003ooooool0003o
000001Cooooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000eoooool2o`00
01kooooo0_l0000`ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000oooooolZooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l0
003Vooooo`;o0000A?ooool002Cooooo0_l0000Dooooo`;o0000i_ooool2o`0004Cooooo000Toooo
o`03o`000?oooooooooo043ooooo0_l0003oooooo`009?ooool00ol0003oooooooooo`10ooooo`;o
0000ooooool002Cooooo00?o0000ooooooooool0^Oooool2o`0008Kooooo000Tooooo`03o`000?oo
oooooooo02oooooo0_l00028ooooo`;o0000Q_ooool002Cooooo0_l0000Qooooo`;o00003Oooool2
o`0005cooooo0_l0002booooo`009?ooool00ol0003oooooooooo`0Pooooo`;o00008oooool2o`00
04Kooooo0_l0002booooo`009?ooool00ol0003oooooooooo`15ooooo`;o0000n_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0mooooo`;o00003_oo
ool2o`000?;ooooo000Tooooo`;o0000?_ooool2o`0000kooooo0_l0003booooo`009?ooool00ol0
003oooooooooo`2Nooooo`;o0000XOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0HOooool2o`0000[ooooo0_l0000_ooooo`;o0000XOooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo067ooooo0_l0000:ooooo`;o0000E_ooool2o`0007[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo0_l0002Rooooo`;o0000N_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Qooooo`;o0000I?ooool2o`0007[ooooo0_l0000l
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo08Oooooo0_l0001j
ooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo3Oooool2o`0003?ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`1eooooo`;o0000UOooool2o`0003?ooooo000Tooooo`;o0000M_ooool2o`0000oooooo0_l0
002iooooo`009?ooool00ol0003oooooooooo`26ooooo`;o0000^Oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3Tooooo`;o0000Foooool002Cooooo
00?o0000ooooooooool0i?ooool2o`0005_ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@_ooool001cooooo00?o0000ooooooooool01Oooool3o`000?oooooo@_ooool001cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`;o0000Y_ooool2o`0004;ooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0_l0002Voooo
o`;o0000@_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<_ooool2o`000?oooooo3_ooool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003ooooo
ooooo`0booooo`;o0000ooooool>ooooo`009?ooool2o`0003Kooooo0_l0003oooooo`_ooooo000T
ooooo`03o`000?oooooooooo03Gooooo0_l0003oooooo`_ooooo000Tooooo`03o`000?oooooooooo
03Cooooo0_l0003oooooo`cooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`co
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0:Kooooo0_l0001]ooooo`;o0000:_ooool002Cooooo00?o0000oooo
ooooool0Y_ooool2o`00067ooooo0_l0000:ooooo`;o0000:_ooool002Cooooo00?o0000oooooooo
ool0aoooool2o`00043ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`37ooooo`;o0000
N?ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00co
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`00
1?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?o
EEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo02_ooooo0_l0003ooooooaGooooo000Tooooo`;o0000;?ooool2o`000?oooooo5Ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
[_ooool2o`0006Cooooo0_l0000[ooooo`009?ooool2o`000:oooooo0_l0001Tooooo`;o0000:ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool3o`0007;ooooo0_l0003=ooooo`009?ooool3o`0007;ooooo0_l0003=ooooo`00
9?ooool00ol0003oooooooooo`19ooooo`;o0000m_ooool002Cooooo0_l0001:ooooo`;o0000m_oo
ool002Cooooo00?o0000ooooooooool0Loooool2o`000<cooooo000:ooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo07?ooooo0_l0002Eooooo`;o0000=Oooool000cooooo00?o0000ooooooooool01?ooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000eoooo
o`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0003ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0UOooool2o`000:[ooooo0002ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0UOooool2o`000:[ooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooo
od;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0V?ooool2o`000:Oooooo0004ooooo`03
o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05[ooooo0_l0000looooo`;o0000Yoooool000Cooooo00?o0000ooooooooool0
2_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Jooooo`;o0000iOooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo
1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003Vooooo`;o00001Oooool2o`0005?ooooo000Tooooo`03o`000?oooooo
oooo0>Gooooo0_l00005ooooo`;o0000Doooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`30ooooo`;o0000Ooooool002Cooooo00?o0000ooooooooool0
`?ooool2o`0007oooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool00ol0
003oooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`007?oo
ool00omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool0
01Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .44148 Mdot
.03333 .06077 Mdot
.0381 .11421 Mdot
.04286 .16855 Mdot
.04762 .00078 Mdot
.05238 .03383 Mdot
.05714 .16138 Mdot
.0619 .02487 Mdot
.06667 .02903 Mdot
.07143 .17312 Mdot
.07619 .06077 Mdot
.08095 .01495 Mdot
.08571 .04673 Mdot
.09048 .26038 Mdot
.09524 .11962 Mdot
.1 .12972 Mdot
.10476 .16206 Mdot
.10952 .27389 Mdot
.11429 .06188 Mdot
.11905 .10753 Mdot
.12381 .12499 Mdot
.12857 .11747 Mdot
.13333 .00529 Mdot
.1381 .21567 Mdot
.14286 .12457 Mdot
.14762 .04961 Mdot
.15238 .01251 Mdot
.15714 .11657 Mdot
.1619 .14036 Mdot
.16667 .1538 Mdot
.17143 .16157 Mdot
.17619 .0695 Mdot
.18095 .12438 Mdot
.18571 .04094 Mdot
.19048 .07983 Mdot
.19524 .33336 Mdot
.2 .19654 Mdot
.20476 .20266 Mdot
.20952 .07309 Mdot
.21429 .04309 Mdot
.21905 .02782 Mdot
.22381 .18004 Mdot
.22857 .11645 Mdot
.23333 .12113 Mdot
.2381 .23322 Mdot
.24286 .04506 Mdot
.24762 .42291 Mdot
.25238 .03179 Mdot
.25714 .14614 Mdot
.2619 .26047 Mdot
.26667 .00655 Mdot
.27143 .28608 Mdot
.27619 .05001 Mdot
.28095 .10482 Mdot
.28571 .02073 Mdot
.29048 .05872 Mdot
.29524 .03612 Mdot
.3 .08667 Mdot
.30476 .04494 Mdot
.30952 .07806 Mdot
.31429 .41593 Mdot
.31905 .02564 Mdot
.32381 .00018 Mdot
.32857 .05498 Mdot
.33333 .04614 Mdot
.3381 .09518 Mdot
.34286 .10578 Mdot
.34762 .00922 Mdot
.35238 .11652 Mdot
.35714 .11773 Mdot
.3619 .09231 Mdot
.36667 .02719 Mdot
.37143 .02233 Mdot
.37619 .00248 Mdot
.38095 .15184 Mdot
.38571 .43345 Mdot
.39048 .45585 Mdot
.39524 .02629 Mdot
.4 .03625 Mdot
.40476 .05009 Mdot
.40952 .09124 Mdot
.41429 .10404 Mdot
.41905 .04943 Mdot
.43333 .15586 Mdot
.4381 .02217 Mdot
.44286 .00741 Mdot
.45238 .37015 Mdot
.45714 .06961 Mdot
.4619 .02089 Mdot
.46667 .00636 Mdot
.47143 .20313 Mdot
.47619 .05775 Mdot
.48095 .00215 Mdot
.48571 .08779 Mdot
.49048 .02035 Mdot
.49524 .34469 Mdot
.5 .19511 Mdot
.50476 .39481 Mdot
.50952 .0554 Mdot
.51429 .07881 Mdot
.51905 .01374 Mdot
.52381 .10056 Mdot
.52857 .25373 Mdot
.53333 .50585 Mdot
.5381 .02914 Mdot
.54286 .00561 Mdot
.54762 .25791 Mdot
.55238 .04003 Mdot
.55714 .02379 Mdot
.5619 .05985 Mdot
.56667 .01209 Mdot
.57143 .42684 Mdot
.57619 .05637 Mdot
.58095 .0298 Mdot
.58571 .04392 Mdot
.59048 .04168 Mdot
.59524 .17004 Mdot
.6 .03583 Mdot
.60476 .31004 Mdot
.60952 .32936 Mdot
.61429 .05125 Mdot
.61905 .01948 Mdot
.62381 .06644 Mdot
.62857 .52856 Mdot
.63333 .05767 Mdot
.6381 .02121 Mdot
.64286 .15454 Mdot
.64762 .22881 Mdot
.65238 .01184 Mdot
.65714 .28082 Mdot
.6619 .01453 Mdot
.66667 .15545 Mdot
.67143 .16326 Mdot
.67619 .3547 Mdot
.68095 .00866 Mdot
.68571 .10947 Mdot
.69048 .09484 Mdot
.69524 .02148 Mdot
.7 .2372 Mdot
.70476 .03479 Mdot
.70952 .06735 Mdot
.71429 .03657 Mdot
.71905 .11495 Mdot
.72381 .3788 Mdot
.72857 .09297 Mdot
.73333 .03496 Mdot
.7381 .21578 Mdot
.74286 .23876 Mdot
.74762 .02026 Mdot
.75238 .022 Mdot
.75714 .227 Mdot
.7619 .54019 Mdot
.76667 .08537 Mdot
.77143 .13327 Mdot
.77619 .17915 Mdot
.78095 .20003 Mdot
.78571 .03216 Mdot
.79048 .21386 Mdot
.79524 .05435 Mdot
.8 .00483 Mdot
.80476 .16966 Mdot
.80952 .19534 Mdot
.81429 .04121 Mdot
.81905 .14137 Mdot
.82381 .02145 Mdot
.82857 .06929 Mdot
.83333 .23429 Mdot
.8381 .10623 Mdot
.84286 .20363 Mdot
.84762 .11626 Mdot
.85238 .06381 Mdot
.8619 .12774 Mdot
.86667 .02717 Mdot
.87143 .04177 Mdot
.87619 .09222 Mdot
.88095 .15677 Mdot
.88571 .19832 Mdot
.89048 .24879 Mdot
.89524 .02869 Mdot
.9 .04162 Mdot
.90476 .18276 Mdot
.90952 .00657 Mdot
.91429 .04151 Mdot
.91905 .05142 Mdot
.92381 .08196 Mdot
.92857 .00046 Mdot
.93333 .05548 Mdot
.9381 .24696 Mdot
.94286 .40526 Mdot
.94762 .14195 Mdot
.95238 .08564 Mdot
.95714 .00638 Mdot
.9619 .05579 Mdot
.96667 .11381 Mdot
.97143 .00426 Mdot
.97619 .02787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01?ooool2o`0000Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o
00002Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`0<ooooo`00
9?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
oooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Gooooo00?o0000oooo
ooooool02oooool3o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2
o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`;o00001Oooool0
0ol0003oooooooooo`06ooooo`;o00000oooool3o`0000kooooo000Tooooo`03o`000?oooooooooo
023ooooo0_l0000Yooooo`;o00006?ooool2o`0001gooooo0_l00006ooooo`;o00005oooool2o`00
02[ooooo0_l0000Uooooo`;o00008Oooool2o`0000kooooo0_l00003ooooo`;o00003oooool002Co
oooo00?o0000ooooooooool09_ooool2o`0003gooooo0_l0000Mooooo`;o00009_ooool2o`0001[o
oooo0_l00007ooooo`;o0000K_ooool002Cooooo0_l0000@ooooo`;o00005Oooool2o`0007Gooooo
0_l0000=ooooo`;o00006_ooool2o`000003ooooool0003o000007Cooooo000Tooooo`03o`000?oo
oooooooo00oooooo0_l0002<ooooo`;o00007_ooool2o`0000cooooo0_l0001dooooo`009?ooool0
0ol0003oooooooooo`1Aooooo`;o00006_ooool2o`0001Cooooo0_l00005ooooo`;o00002?ooool2
o`0002Oooooo0_l00004ooooo`;o00004Oooool2o`0000oooooo1?l0000Eooooo`;o0000?oooool0
02Cooooo00?o0000ooooooooool02Oooool2o`0004Kooooo0_l00009ooooo`;o00003oooool2o`00
01Cooooo0_l00005ooooo`;o00002?ooool2o`0001?ooooo0_l0000Hooooo`;o00004Oooool2o`00
00oooooo1?l0000Eooooo`;o0000?oooool002Cooooo00?o0000ooooooooool02Oooool2o`00037o
oooo0_l0000Nooooo`;o00003Oooool2o`0000Sooooo0_l0000booooo`;o0000Hoooool2o`0000Oo
oooo0_l0000Hooooo`;o00003_ooool002Cooooo0_l0000;ooooo`;o0000<?ooool2o`0000Sooooo
0_l0000Sooooo`;o00002?ooool2o`0002cooooo0_l0000<ooooo`;o0000Foooool2o`0000Oooooo
0_l0000Hooooo`;o00003_ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0
000jooooo`;o0000Foooool2o`0000cooooo0_l0000Vooooo`;o00006?ooool2o`0004cooooo000T
ooooo`03o`000?oooooooooo00Gooooo0_l0001=ooooo`;o00008?ooool2o`0003oooooo0_l0000P
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000oooooo0_l0001<ooooo`009?ooool00ol0
003oooooooooo`0aooooo`;o00008Oooool2o`00023ooooo0_l0000`ooooo`;o00003Oooool2o`00
02?ooooo0_l00004ooooo`;o0000GOooool002Cooooo00?o0000ooooooooool0<Oooool2o`0000Oo
oooo0_l0001/ooooo`;o00002?ooool4o`0004Oooooo0_l0000@ooooo`;o00001oooool2o`0000?o
oooo0_l0000Rooooo`009?ooool2o`00017ooooo0_l0000Xooooo`;o00001oooool2o`0001;ooooo
0_l00008ooooo`;o0000Coooool4o`0004Oooooo0_l0000@ooooo`;o00001oooool2o`0000?ooooo
0_l0000Rooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o00004_ooool2o`0001gooooo0_l0
0009ooooo`;o00001oooool2o`0000Sooooo0_l0000Eooooo`;o00000_ooool2o`000<?ooooo000T
ooooo`03o`000?oooooooooo02Cooooo0_l0000Xooooo`;o0000:?ooool2o`0000;ooooo0_l0000n
ooooo`;o0000HOooool2o`00023ooooo000Tooooo`03o`000?oooooooooo05oooooo0_l0000ioooo
o`;o00004oooool2o`0000_ooooo0_l0000hooooo`;o00009oooool2o`0000;ooooo0_l00007oooo
o`;o00004oooool002Cooooo00?o0000ooooooooool0Doooool2o`0000[ooooo0_l0000^ooooo`;o
00002Oooool2o`0001?ooooo0_l0000Aooooo`;o0000<_ooool2o`0002_ooooo0_l00007ooooo`;o
00004oooool002Cooooo1?l0000<ooooo`;o00002oooool2o`0003Oooooo0_l0000jooooo`;o0000
6_ooool2o`0001Gooooo0_l0001mooooo`009?ooool01?l0003oooooo`000?l0000<ooooo`;o0000
2oooool2o`0008oooooo0_l0001Looooo`;o0000=_ooool002Cooooo00?o0000ooooooooool0_ooo
ool2o`0001[ooooo0_l0000/ooooo`;o0000=_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0^ooooo`;o0000FOooool2o`0003Cooooo0_l0000Jooooo`;o00009?ooool2o`0003ko
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02kooooo0_l00008
ooooo`;o0000Coooool2o`0007Kooooo0_l0000nooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
03Sooooo0_l0000Oooooo`;o0000i_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0<_ooool2o`0002Gooooo0_l00010ooooo`;o0000Y?ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0booooo`;o0000Ioooool2o`0008?ooooo0_l0000Oooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`;o0000UOooool2o`00037ooooo
0_l00007ooooo`;o00005_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Foooo
o`;o0000>_ooool2o`0005Wooooo0_l0000jooooo`;o00005_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Jooo
ool2o`0000gooooo0_l0000Gooooo`;o0000COooool2o`0002kooooo0_l0000^ooooo`009?ooool0
0ol0003oooooooooo`1Rooooo`;o00001_ooool2o`0000gooooo0_l0001Iooooo`;o00002oooool2
o`0002kooooo0_l0000^ooooo`009?ooool00ol0003oooooooooo`1Rooooo`;o0000L?ooool2o`00
06_ooooo000Tooooo`03o`000?oooooooooo09kooooo0_l0002Qooooo`009?ooool00ol0003ooooo
ooooo`1@ooooo`;o00004_ooool2o`0001Gooooo0_l0000Qooooo`;o0000XOooool002Cooooo00?o
0000ooooooooool06oooool2o`0003?ooooo0_l0000Booooo`;o00005Oooool2o`0008Oooooo0_l0
000kooooo`009?ooool2o`0001cooooo0_l0002fooooo`;o0000;oooool2o`0003_ooooo000Toooo
o`04o`000?ooooooooooooooo`;o0000d?ooool2o`0000Wooooo0_l0001>ooooo`;o00004Oooool0
02Cooooo00Co0000oooooooooooooooo0_l0000Kooooo`;o00001oooool2o`0001Kooooo0_l0000V
ooooo`?o0000M?ooool2o`0002Oooooo0_l0000Uooooo`;o00004Oooool002Cooooo00?o0000oooo
ooooool04oooool2o`0000Wooooo0_l00007ooooo`;o00005_ooool3o`0002Gooooo0ol0002Moooo
o`;o0000>?ooool002Cooooo00?o0000ooooooooool04oooool2o`0002_ooooo0_l0003oooooo`00
9?ooool2o`0001kooooo0_l00004ooooo`;o00002_ooool2o`000?oooooo4Oooool002Cooooo00?o
0000ooooooooool05Oooool2o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`000=_ooooo0_l0
000cooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000f?ooool2o`0001_ooooo0_l0000c
ooooo`009?ooool00ol0003oooooooooo`3_ooooo`;o0000D?ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`0002[ooooo0_l0003Cooooo`;o0000:?ooool2o`0001Oooooo
000Tooooo`03o`000?oooooooooo02Wooooo0_l0003Cooooo`;o0000:?ooool2o`0001Oooooo0009
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo04Sooooo0_l0003gooooo`002Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
B?ooool2o`0002Kooooo0_l0003?ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`;o0000@oooool2o`0005?ooooo
0_l0001jooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`0002_ooooo0_l0001Dooooo`;o0000@_ooool2o`0000Kooooo0_l00013ooooo`;o0000
;Oooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`21ooooo`;o0000B_ooool2o`0004?ooooo0_l0000]ooooo`00
2Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`;o00003Oooool2o`0001Cooooo0_l0002Pooooo`;o0000LOooool000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool2o`0000gooooo0_l0000Dooooo`;o0000X?ooool2o`00077ooooo0009ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`000;;o
oooo0_l00011ooooo`;o0000A_ooool002Cooooo0_l00003ooooo`;o00002?ooool2o`000:Sooooo
0_l00011ooooo`;o0000A_ooool002Cooooo00?o0000ooooooooool03?ooool2o`000?oooooo=?oo
ool002Cooooo00?o0000ooooooooool0l?ooool2o`0004oooooo000Tooooo`03o`000?oooooooooo
03gooooo0_l0002aooooo`;o0000:?ooool2o`0002Gooooo000Tooooo`03o`000?oooooooooo03go
oooo0_l0003Kooooo`;o00009Oooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Uoooool2o`000:Sooooo000Toooo
o`03o`000?oooooooooo03Gooooo0_l0001Pooooo`;o0000H_ooool2o`0001Oooooo0_l0000[oooo
o`009?ooool00ol0003oooooooooo`0eooooo`;o0000^oooool2o`0000Oooooo0_l0000Gooooo`;o
0000:oooool002Cooooo0_l0000hooooo`;o0000E?ooool2o`0006?ooooo0_l0000Booooo`;o0000
>Oooool002Cooooo00?o0000ooooooooool0=oooool2o`0005Cooooo0_l0001gooooo`;o0000>Ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo027ooooo0_l00031ooooo`;o00003oooool2o`0004[o
oooo000Tooooo`;o00008_ooool2o`000<7ooooo0_l0000?ooooo`;o0000B_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3ooooood;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`37oooo
o`;o00008Oooool2o`0005Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_o
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Oo
oooo0_l0000Qooooo`;o0000EOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00012ooooo`;o0000
_oooool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
@_ooool2o`0009Cooooo0_l0000Yooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0f?ooool2o`0000_ooooo0_l0001Jooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0>Gooooo0_l0001Jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0oooooolVooooo`;o00006_ooool002Co
oooo0_l0003ooooooaOooooo0_l0000>ooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0
X?ooool2o`0007?ooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`2Pooooo`;o0000Wooo
ool002Cooooo00?o0000ooooooooool0Y_ooool2o`0009Wooooo000Tooooo`03o`000?oooooooooo
01;ooooo0_l0000eooooo`;o0000Foooool2o`0009Wooooo000Tooooo`;o00004oooool2o`0003Go
oooo0_l0003fooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool06?ooool2o`000?oooooo:?ooool0
02Cooooo00?o0000ooooooooool06?ooool2o`000?oooooo:?ooool002Cooooo0_l0003;ooooo`;o
0000MOooool002Cooooo00?o0000ooooooooool0b_ooool2o`0007Gooooo000Tooooo`03o`000?oo
oooooooo04gooooo0_l0003booooo`009?ooool00ol0003oooooooooo`1=ooooo`;o0000l_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od;ooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`;o0000Q_ooool001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`;o0000Q_ooool001cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0;[ooooo0_l00025ooooo`009?ooool00ol0003oooooooooo`0dooooo`;o0000Q?oo
ool2o`0008Gooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`cooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo09Gooooo0_l0002Zooooo`009?ooool00ol0003oooooooooo`2Eooooo`;o0000Z_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3@oooo
o`;o0000Koooool002Cooooo0_l0003Aooooo`;o0000Koooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Qoooool2o`000;Sooooo000Tooooo`;o
0000R?ooool2o`000;Sooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0=oooooo0_l0001Pooooo`001?ooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3Oooooo`;o0000H?ooool000Cooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3o
oooood;ooooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo09Sooooo0_l0002Wooooo`001?ooool00ol0003o
ooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo09Sooooo0_l0002Wooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooolWooooo`;o0000
6Oooool002Cooooo00?o0000ooooooooool0oooooolWooooo`;o00006Oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1Jooooo`;o0000iOooool002Co
oooo0_l0001Kooooo`;o0000iOooool002Cooooo00?o0000ooooooooool0AOooool2o`000?[ooooo
000Tooooo`03o`000?oooooooooo04Gooooo0_l0003jooooo`009?ooool00ol0003oooooooooo`2^
ooooo`;o0000TOooool002Cooooo00?o0000ooooooooool0[_ooool2o`00097ooooo000Tooooo`;o
0000Loooool2o`000<gooooo000Tooooo`03o`000?oooooooooo07;ooooo0_l0003=ooooo`009?oo
ool3o`000?oooooo@_ooool002Cooooo0ol0003ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Loooool2o`000<cooooo000<ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Looo
ool2o`000<cooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`00
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0XOooool2o`0009kooooo000Tooooo`03o`000?oo
oooooooo0:7ooooo0_l0002Nooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0`?ooool2o`0007oooooo0002ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0`?ooool2o`0007oooooo0004ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo
0_l0001Cooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000>cooooo0_l0001Cooooo`001?ooool00ol0003oooooooooo`0=
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0
003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RH
ob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^
00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo
00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo
Boooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .36962 Mdot
.03333 .25052 Mdot
.0381 .06726 Mdot
.04286 .11067 Mdot
.04762 .06105 Mdot
.05238 .03383 Mdot
.05714 .07301 Mdot
.0619 .00596 Mdot
.06667 .02903 Mdot
.07143 .06066 Mdot
.07619 .20521 Mdot
.08095 .01495 Mdot
.08571 .19491 Mdot
.09048 .08008 Mdot
.09524 .13035 Mdot
.1 .16583 Mdot
.10476 .09119 Mdot
.10952 .1317 Mdot
.11429 .06188 Mdot
.11905 .10753 Mdot
.12381 .12499 Mdot
.12857 .23063 Mdot
.13333 .00529 Mdot
.1381 .26772 Mdot
.14286 .15939 Mdot
.14762 .05029 Mdot
.15238 .18075 Mdot
.15714 .18623 Mdot
.1619 .21237 Mdot
.16667 .12488 Mdot
.17143 .03415 Mdot
.17619 .19111 Mdot
.18095 .24689 Mdot
.18571 .03065 Mdot
.19048 .28644 Mdot
.19524 .13622 Mdot
.2 .27114 Mdot
.20476 .0356 Mdot
.20952 .07309 Mdot
.21429 .04309 Mdot
.21905 .06409 Mdot
.22381 .07531 Mdot
.22857 .08191 Mdot
.23333 .22672 Mdot
.2381 .07871 Mdot
.24286 .04506 Mdot
.24762 .03502 Mdot
.25238 .03179 Mdot
.25714 .17803 Mdot
.2619 .04656 Mdot
.26667 .00655 Mdot
.27143 .28608 Mdot
.27619 .05001 Mdot
.28095 .3357 Mdot
.28571 .19095 Mdot
.29048 .05872 Mdot
.29524 .08555 Mdot
.3 .18284 Mdot
.30476 .04494 Mdot
.30952 .40778 Mdot
.31429 .24736 Mdot
.31905 .03153 Mdot
.32381 .00018 Mdot
.32857 .05498 Mdot
.33333 .04614 Mdot
.3381 .20778 Mdot
.34286 .10578 Mdot
.34762 .11615 Mdot
.35238 .24131 Mdot
.35714 .17936 Mdot
.3619 .09231 Mdot
.36667 .02719 Mdot
.37143 .1044 Mdot
.37619 .06385 Mdot
.38095 .01889 Mdot
.39048 .36958 Mdot
.39524 .02629 Mdot
.4 .03625 Mdot
.40476 .05009 Mdot
.40952 .25701 Mdot
.41429 .09654 Mdot
.41905 .04943 Mdot
.42857 .51747 Mdot
.43333 .10874 Mdot
.4381 .02217 Mdot
.44286 .07167 Mdot
.45238 .2651 Mdot
.45714 .06961 Mdot
.4619 .09159 Mdot
.46667 .06841 Mdot
.47143 .3731 Mdot
.47619 .15078 Mdot
.48095 .17213 Mdot
.48571 .0709 Mdot
.49048 .02035 Mdot
.49524 .02548 Mdot
.5 .14191 Mdot
.50476 .19538 Mdot
.50952 .0554 Mdot
.51429 .05881 Mdot
.51905 .01374 Mdot
.52381 .10056 Mdot
.52857 .17374 Mdot
.53333 .26948 Mdot
.5381 .14522 Mdot
.54286 .14039 Mdot
.54762 .35968 Mdot
.55238 .04003 Mdot
.55714 .01596 Mdot
.5619 .05985 Mdot
.56667 .10598 Mdot
.57143 .13633 Mdot
.57619 .09727 Mdot
.58095 .0298 Mdot
.58571 .04392 Mdot
.59048 .02627 Mdot
.59524 .06337 Mdot
.6 .03583 Mdot
.60476 .39924 Mdot
.60952 .19976 Mdot
.61429 .05125 Mdot
.61905 .07808 Mdot
.62381 .03908 Mdot
.62857 .51834 Mdot
.63333 .20301 Mdot
.6381 .2715 Mdot
.64286 .35776 Mdot
.64762 .22881 Mdot
.65238 .01184 Mdot
.65714 .12242 Mdot
.6619 .0532 Mdot
.66667 .16905 Mdot
.67143 .31287 Mdot
.67619 .11239 Mdot
.68095 .06518 Mdot
.68571 .19781 Mdot
.69048 .09484 Mdot
.69524 .02878 Mdot
.7 .05105 Mdot
.70476 .03479 Mdot
.70952 .08633 Mdot
.71429 .03657 Mdot
.71905 .11495 Mdot
.72381 .32043 Mdot
.72857 .03284 Mdot
.73333 .12673 Mdot
.7381 .18136 Mdot
.74286 .03561 Mdot
.74762 .1709 Mdot
.75238 .07722 Mdot
.75714 .227 Mdot
.7619 .53792 Mdot
.76667 .22362 Mdot
.77143 .13327 Mdot
.77619 .00167 Mdot
.78095 .01078 Mdot
.78571 .03216 Mdot
.79048 .15439 Mdot
.79524 .05435 Mdot
.8 .06589 Mdot
.80476 .21552 Mdot
.80952 .02827 Mdot
.81429 .05134 Mdot
.81905 .09019 Mdot
.82381 .01155 Mdot
.82857 .07188 Mdot
.83333 .15375 Mdot
.8381 .13184 Mdot
.84286 .04415 Mdot
.84762 .09194 Mdot
.85238 .04935 Mdot
.85714 .61711 Mdot
.8619 .12774 Mdot
.86667 .02718 Mdot
.87143 .16541 Mdot
.87619 .09222 Mdot
.88095 .15677 Mdot
.88571 .14264 Mdot
.89048 .13825 Mdot
.89524 .02869 Mdot
.9 .20096 Mdot
.90476 .351 Mdot
.90952 .00938 Mdot
.91429 .04151 Mdot
.91905 .19544 Mdot
.92381 .08196 Mdot
.92857 .16105 Mdot
.93333 .05548 Mdot
.9381 .33919 Mdot
.94286 .21542 Mdot
.94762 .31259 Mdot
.95238 .01261 Mdot
.95714 .00638 Mdot
.9619 .22873 Mdot
.96667 .41794 Mdot
.97143 .00426 Mdot
.97619 .02787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00009ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o
00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`00
0?oooooooooo00Wooooo0_l000000ooooooo0000ooooo`0>ooooo`04o`000?ooooooooooooooo`;o
00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`?o
00003_ooool002Cooooo00?o0000ooooooooool02Oooool2o`0001Gooooo0_l0000Yooooo`;o0000
c_ooool2o`0000kooooo0_l00003ooooo`;o00003oooool002Cooooo00?o0000ooooooooool0b?oo
ool2o`0002Sooooo0_l0000<ooooo`;o00006Oooool2o`0000cooooo0_l0000Fooooo`009?ooool2
o`00013ooooo0_l0002<ooooo`;o00002_ooool2o`0001gooooo0_l0000Xooooo`;o00003?ooool2
o`0002Oooooo0_l0000Fooooo`009?ooool00ol0003oooooooooo`0?ooooo`;o0000Goooool2o`00
02_ooooo0_l0000:ooooo`;o0000U_ooool002Cooooo00?o0000ooooooooool0L?ooool2o`00017o
oooo0_l0000?ooooo`;o0000Zoooool002Cooooo00?o0000ooooooooool0Poooool2o`0000oooooo
0ol0002Zooooo`009?ooool00ol0003oooooooooo`1[ooooo`;o00002?ooool2o`0001kooooo0_l0
000Mooooo`;o0000AOooool2o`00017ooooo0_l00007ooooo`;o00006?ooool2o`0000kooooo000T
ooooo`;o00002oooool2o`0002Gooooo0_l0000Cooooo`;o00005?ooool2o`0000gooooo0_l00008
ooooo`;o0000>_ooool2o`000003ooooool0003o0000023ooooo0_l0000Sooooo`;o00004Oooool2
o`0000Oooooo0_l0000Hooooo`;o00003_ooool002Cooooo00?o0000ooooooooool01Oooool2o`00
00?ooooo0_l0000Pooooo`;o00000oooool2o`0001?ooooo0_l0000Dooooo`;o0000Doooool2o`00
02?ooooo0_l000000ooooooo0000o`000006ooooo`;o00004?ooool2o`0004cooooo000Tooooo`03
o`000?oooooooooo00Gooooo0_l0000Uooooo`;o00002Oooool2o`0000cooooo0_l0000_ooooo`;o
0000?oooool2o`00023ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000co
oooo0_l0001<ooooo`009?ooool00ol0003oooooooooo`0gooooo`;o00003?ooool2o`0002oooooo
0_l0000`ooooo`;o00003Oooool2o`0000Kooooo0_l0000Kooooo`;o00001oooool2o`0005[ooooo
000Tooooo`03o`000?oooooooooo03[ooooo0_l0001/ooooo`;o00002?ooool2o`0000_ooooo0_l0
0015ooooo`;o00005Oooool2o`0002;ooooo000Tooooo`;o0000>oooool2o`0000Oooooo0_l00004
ooooo`;o00003?ooool2o`0000Sooooo0_l0001?ooooo`;o0000D_ooool2o`0001Gooooo0_l0000R
ooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o00007Oooool2o`0000Cooooo0_l00003oooo
o`;o00001oooool2o`0000Sooooo0_l0000Eooooo`;o00000_ooool2o`0008_ooooo0_l0000foooo
o`009?ooool00ol0003oooooooooo`0Tooooo`;o0000:?ooool2o`0002Sooooo0_l00002ooooo`;o
0000?_ooool2o`0000gooooo0_l0000;ooooo`;o00008oooool2o`0000[ooooo0_l0000fooooo`00
9?ooool00ol0003oooooooooo`1Oooooo`;o0000>Oooool2o`00023ooooo0_l0000=ooooo`;o0000
2oooool2o`0001cooooo0_l00005ooooo`;o00009?ooool2o`0001cooooo000Tooooo`03o`000?oo
oooooooo05?ooooo0_l0000:ooooo`;o0000>Oooool3o`0005Wooooo0_l0000[ooooo`;o00007?oo
ool002Cooooo0_l00005ooooo`;o00001_ooool2o`0000cooooo0_l0000gooooo`;o0000A_ooool2
o`0000kooooo0_l0002Dooooo`009?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool2o`00
00cooooo0_l0000Pooooo`;o0000<?ooool2o`0003_ooooo0_l00009ooooo`;o00006Oooool2o`00
06kooooo000Tooooo`04o`000?ooooooooooooooo`;o0000>Oooool2o`00033ooooo0_l0000Loooo
o`;o0000:?ooool2o`0001Wooooo0_l0000Uooooo`;o0000Aoooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool01?l0003oooooooooooooool2o`00087ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0006Cooooo0_l00007ooooo`;o0000?_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01oooool2o`0002oooooo0_l0001:ooooo`;o00000oooool2o`00
00Oooooo0_l0001]ooooo`;o0000?_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`;o
0000;oooool2o`0000?ooooo0_l0002Zooooo`;o0000E_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool04_ooool2o`0002Wooooo0_l00003ooooo`;o0000NOooool2o`0002[ooooo
0_l0001Fooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01;ooooo
0_l0000[ooooo`;o000000?oooooo`000?l00000NOooool2o`00067ooooo0_l0000Oooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`;o00004oooool2o`0008Gooooo0_l0
0013ooooo`;o00007oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Dooooo`;o
0000QOooool2o`00027ooooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Gooooo`;o0000D_ooool2
o`0001kooooo0_l0001booooo`;o00001oooool2o`0000Sooooo0_l0000^ooooo`009?ooool00ol0
003oooooooooo`0Fooooo`;o0000D_ooool2o`0000oooooo0_l0000=ooooo`;o0000B?ooool2o`00
037ooooo0_l00008ooooo`;o0000;_ooool002Cooooo00?o0000ooooooooool0Noooool2o`0003;o
oooo0_l0000Sooooo`;o0000Joooool002Cooooo00?o0000ooooooooool0W_ooool2o`0000oooooo
0_l0002@ooooo`009?ooool00ol0003oooooooooo`1Tooooo`;o00001oooool2o`0002oooooo0_l0
002Qooooo`009?ooool00ol0003oooooooooo`0Kooooo`;o0000Aoooool2o`0000Oooooo0_l0000B
ooooo`;o0000:Oooool2o`0009?ooooo000Tooooo`;o00000oooool2o`0001Oooooo0_l0001Toooo
o`;o0000:Oooool2o`0009?ooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0003<ooooo`;o
00003?ooool2o`00067ooooo000Tooooo`03o`000?oooooooooo06Gooooo0_l0001Yooooo`;o0000
3?ooool2o`00067ooooo000Tooooo`03o`000?oooooooooo06Gooooo0_l0003Jooooo`009?ooool0
0ol0003oooooooooo`3:ooooo`;o0000MOooool002Cooooo0_l0000Nooooo`;o00003?ooool2o`00
09gooooo0_l0000Fooooo`;o0000GOooool002Cooooo00?o0000ooooooooool04oooool2o`0000So
oooo0_l0000<ooooo`;o0000]Oooool2o`0002Sooooo0_l0000cooooo`009?ooool00ol0003ooooo
ooooo`0Cooooo`;o00000oooool2o`000=Gooooo0_l0000Cooooo`;o00001_ooool2o`0003?ooooo
000Tooooo`03o`000?oooooooooo01Sooooo0_l0000Jooooo`;o0000N?ooool2o`0003oooooo0_l0
000Cooooo`;o0000>oooool002Cooooo00?o0000ooooooooool0=?ooool2o`0007Sooooo0_l0001U
ooooo`;o0000:_ooool002Cooooo0_l0002Hooooo`;o00003?ooool2o`0006gooooo0ol0000Zoooo
o`009?ooool00ol0003oooooooooo`2Gooooo`;o00002_ooool4o`0006gooooo0_l0000[ooooo`00
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2Sooooo`;o0000W?ooool000Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08oooooo0_l0002`ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2?ooooo`;o0000I?ooool2o`0000cooooo0_l0000loooo
o`002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0?Gooooo0_l0000<ooooo`;o00003Oooool2o`0002gooooo0009ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool08oooool2
o`000>gooooo0_l0000>ooooo`;o00007Oooool000Wooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool2o`000?gooooo0_l0000M
ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Eooooo`;o0000n?ooool2o`00033ooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool05Oooool2o`000;Kooooo0_l00010
ooooo`;o0000<?ooool002Cooooo0_l0002Aooooo`;o0000>oooool2o`0001Sooooo0_l0001Hoooo
o`009?ooool00ol0003oooooooooo`2@ooooo`;o00003_ooool2o`0004Gooooo0_l0001Hooooo`00
9?ooool00ol0003oooooooooo`18ooooo`;o00007_ooool2o`0003Kooooo0_l0002Oooooo`009?oo
ool00ol0003oooooooooo`0Vooooo`;o00008?ooool2o`0000cooooo0_l0000@ooooo`;o0000N_oo
ool2o`0005_ooooo000Tooooo`03o`000?oooooooooo02Kooooo0_l0000^ooooo`;o0000S?ooool2
o`0005_ooooo000Tooooo`;o0000:?ooool2o`000?oooooo6Oooool002Cooooo00?o0000oooooooo
ool09oooool2o`0000Gooooo0_l0000Qooooo`;o0000k_ooool002Cooooo00?o0000ooooooooool0
4?ooool2o`0001cooooo0_l0000Qooooo`;o0000k_ooool002Cooooo00?o0000ooooooooool04?oo
ool2o`0008Kooooo0_l0000iooooo`;o0000B_ooool2o`00023ooooo000Tooooo`03o`000?oooooo
oooo09Sooooo0_l0000Pooooo`;o00005oooool2o`0004?ooooo0_l00005ooooo`;o00008?ooool0
02Cooooo0_l0002kooooo`;o00001_ooool2o`0005Cooooo0_l0000Wooooo`009?ooool00ol0003o
ooooooooo`0=ooooo`;o0000/oooool2o`0007gooooo000Tooooo`03o`000?oooooooooo00gooooo
0_l0001Cooooo`;o0000gOooool002Cooooo00?o0000ooooooooool0:Oooool2o`0003Oooooo0_l0
003Mooooo`009?ooool00ol0003oooooooooo`0Yooooo`;o0000c_ooool2o`0002_ooooo0_l0000I
ooooo`009?ooool2o`000?[ooooo0_l0000[ooooo`;o00006Oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3]
ooooo`;o0000D_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo043ooooo0_l0
0025ooooo`;o00008Oooool2o`000003ooooool0003o000003gooooo0_l0000Cooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o00008?ooool2o`0008Gooooo0_l0000Q
ooooo`;o0000@?ooool2o`0001?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o00007_ooool2o`00
0?oooooo8_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
od;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Oooooo0_l0003Hooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Oooooo0_l0003Hooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0;ooo
ool2o`0002Wooooo0_l0003Uooooo`009?ooool4o`0002kooooo0_l0000Yooooo`;o0000iOooool0
02Cooooo00Co0000ooooool0003o0000oooooom1ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo07Wooooo0_l00036ooooo`009?ooool00ol0003ooooo
ooooo`1iooooo`;o0000a_ooool002Cooooo0_l00028ooooo`;o0000^?ooool002Cooooo00?o0000
ooooooooool08Oooool2o`0006Cooooo0_l0002hooooo`009?ooool00ol0003oooooooooo`0Qoooo
o`;o00004_ooool2o`0006[ooooo0_l0000Pooooo`;o0000O?ooool002Cooooo00?o0000oooooooo
ool0=Oooool2o`0006[ooooo0_l0000Pooooo`;o0000O?ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`0booooo`;o00006Oooool2o`000?;ooooo000Tooooo`03
o`000?oooooooooo03;ooooo0_l0000Iooooo`;o0000l_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2oooo
o`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oo
oooooooo00Gooooo0ol0003ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0c_ooool2o`0005Sooooo0_l0000Gooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0<kooooo0_l0001Hooooo`;o00005oooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3Oooooo`;o0000H?ooool001[ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3Oooooo`;o0000H?ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`1@ooooo`;o0000koooool002Cooooo00?o0000ooooooooool0
D?ooool2o`000=?ooooo0_l0000Jooooo`009?ooool2o`000?oooooo9oooool2o`0001[ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool00ol0003oooooooooo`3ooooooa_ooooo0_l0000Uooooo`009?ooool00ol0003ooooo
ooooo`3ooooooa_ooooo0_l0000Uooooo`009?ooool2o`000<Kooooo0_l0001jooooo`009?ooool0
0ol0003oooooooooo`2Vooooo`;o00007Oooool2o`0007[ooooo000Tooooo`03o`000?oooooooooo
0:Kooooo0_l0002Iooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`?o0000
Loooool2o`000<cooooo000Tooooo`?o0000Loooool2o`0001Sooooo0_l0002booooo`009?ooool0
0ol0003oooooooooo`2=ooooo`;o0000/_ooool000;ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00co
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`00
1?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo00?o
EEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo0;Wooooo0_l00026ooooo`009?ooool2o`000;[ooooo0_l00026ooooo`009?ooool0
0ol0003oooooooooo`1Iooooo`;o0000i_ooool002Cooooo00?o0000ooooooooool0FOooool2o`00
0>Kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo<?ooool2o`00017ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo;oooool2o`00017ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000ooooooooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo07oooooo0_l0000oooooo`;o0000Oooo
ool002Cooooo00?o0000ooooooooool0Ooooool2o`0003oooooo0_l0001oooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool0
0ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3/ooooo`;o0000Doooool000Cooooo00?o0000ooooooooool03Oooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003/ooooo`;o0000Doooool000Co
oooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEE
EOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`3ooooo
od;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooo
od;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0ooooool;ooooo`;o
0000=Oooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo2oooool2o`0003Gooooo
000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9
ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .05664 Mdot
.03333 .25052 Mdot
.0381 .06726 Mdot
.04286 .3052 Mdot
.04762 .20595 Mdot
.05238 .00127 Mdot
.05714 .01988 Mdot
.0619 .00596 Mdot
.06667 .02903 Mdot
.07143 .01871 Mdot
.07619 .15548 Mdot
.08095 .01495 Mdot
.08571 .06217 Mdot
.09048 .24101 Mdot
.09524 .15078 Mdot
.1 .00839 Mdot
.10476 .1476 Mdot
.10952 .11512 Mdot
.11429 .01701 Mdot
.11905 .08272 Mdot
.12381 .01492 Mdot
.12857 .21618 Mdot
.13333 .00529 Mdot
.1381 .10482 Mdot
.14286 .09194 Mdot
.14762 .03432 Mdot
.15238 .18075 Mdot
.15714 .18623 Mdot
.1619 .2618 Mdot
.16667 .03684 Mdot
.17143 .04384 Mdot
.17619 .14581 Mdot
.18095 .24413 Mdot
.18571 .05608 Mdot
.19048 .05297 Mdot
.19524 .13622 Mdot
.2 .21193 Mdot
.20476 .01821 Mdot
.20952 .18143 Mdot
.21429 .202 Mdot
.21905 .06409 Mdot
.22381 .16445 Mdot
.22857 .22778 Mdot
.23333 .25373 Mdot
.2381 .13761 Mdot
.24286 .04506 Mdot
.24762 .03502 Mdot
.25238 .07005 Mdot
.25714 .27569 Mdot
.2619 .05944 Mdot
.26667 .03537 Mdot
.27143 .21217 Mdot
.27619 .05659 Mdot
.28095 .41334 Mdot
.28571 .41829 Mdot
.29048 .05872 Mdot
.29524 .16083 Mdot
.3 .18284 Mdot
.30476 .04494 Mdot
.30952 .37961 Mdot
.31429 .30975 Mdot
.31905 .02805 Mdot
.32381 .00018 Mdot
.32857 .06506 Mdot
.33333 .08332 Mdot
.3381 .13665 Mdot
.34286 .01649 Mdot
.34762 .11615 Mdot
.35238 .25199 Mdot
.35714 .42111 Mdot
.3619 .23253 Mdot
.36667 .02719 Mdot
.37143 .1044 Mdot
.37619 .17118 Mdot
.38095 .01889 Mdot
.39048 .3085 Mdot
.39524 .02629 Mdot
.4 .03625 Mdot
.40476 .1297 Mdot
.40952 .11128 Mdot
.41429 .08207 Mdot
.41905 .04943 Mdot
.43333 .25725 Mdot
.4381 .02217 Mdot
.44286 .06272 Mdot
.45238 .03287 Mdot
.45714 .04291 Mdot
.4619 .19747 Mdot
.46667 .06841 Mdot
.47143 .22572 Mdot
.47619 .01116 Mdot
.48095 .16191 Mdot
.48571 .10138 Mdot
.49048 .03977 Mdot
.49524 .02548 Mdot
.5 .13447 Mdot
.50476 .02201 Mdot
.50952 .0554 Mdot
.51429 .05881 Mdot
.51905 .01374 Mdot
.52381 .32204 Mdot
.52857 .42335 Mdot
.53333 .14402 Mdot
.5381 .15608 Mdot
.54286 .07384 Mdot
.54762 .13019 Mdot
.55238 .04003 Mdot
.55714 .03848 Mdot
.5619 .23889 Mdot
.56667 .00331 Mdot
.57143 .13633 Mdot
.57619 .02665 Mdot
.58095 .0298 Mdot
.58571 .00935 Mdot
.59048 .11897 Mdot
.59524 .00426 Mdot
.6 .03583 Mdot
.60476 .3796 Mdot
.60952 .39961 Mdot
.61429 .05125 Mdot
.61905 .15682 Mdot
.62381 .24552 Mdot
.62857 .5684 Mdot
.63333 .21349 Mdot
.6381 .2715 Mdot
.64286 .13577 Mdot
.64762 .0039 Mdot
.65238 .01184 Mdot
.65714 .48679 Mdot
.6619 .0532 Mdot
.66667 .16905 Mdot
.67143 .27707 Mdot
.67619 .03388 Mdot
.68095 .04623 Mdot
.68571 .25334 Mdot
.69048 .07011 Mdot
.69524 .02878 Mdot
.7 .13749 Mdot
.70476 .03479 Mdot
.70952 .08633 Mdot
.71429 .02415 Mdot
.71905 .09822 Mdot
.72381 .28332 Mdot
.72857 .00633 Mdot
.73333 .12673 Mdot
.7381 .00175 Mdot
.74286 .18926 Mdot
.74762 .2065 Mdot
.75238 .07722 Mdot
.75714 .31191 Mdot
.76667 .09709 Mdot
.77143 .05262 Mdot
.77619 .00167 Mdot
.78095 .01078 Mdot
.78571 .24958 Mdot
.79048 .06912 Mdot
.79524 .26749 Mdot
.8 .06589 Mdot
.80476 .17541 Mdot
.80952 .02827 Mdot
.81429 .0865 Mdot
.81905 .24183 Mdot
.82381 .01155 Mdot
.82857 .07188 Mdot
.83333 .15375 Mdot
.8381 .10012 Mdot
.84286 .04415 Mdot
.84762 .21887 Mdot
.85238 .34646 Mdot
.85714 .61711 Mdot
.8619 .12774 Mdot
.86667 .005 Mdot
.87143 .1305 Mdot
.87619 .00116 Mdot
.88095 .2314 Mdot
.88571 .37471 Mdot
.89048 .04744 Mdot
.89524 .02869 Mdot
.9 .20096 Mdot
.90476 .10706 Mdot
.90952 .00938 Mdot
.91429 .04151 Mdot
.91905 .15722 Mdot
.92381 .08196 Mdot
.92857 .16105 Mdot
.93333 .05548 Mdot
.9381 .11342 Mdot
.94286 .03335 Mdot
.94762 .08843 Mdot
.95238 .02898 Mdot
.95714 .00638 Mdot
.9619 .10982 Mdot
.96667 .19981 Mdot
.97143 .00426 Mdot
.97619 .02787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o
00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`03
o`000?oooooooooo00gooooo0ol0000<ooooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`;o
00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool0
1Oooool2o`0000;ooooo0_l000000ooooooo0000ooooo`0>ooooo`04o`000?ooooooooooooooo`;o
00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool2o`0000Sooooo0_l0000>ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`07ooooo`;o000000Coooooo`000?l0003o00003_ooool00ol0003oooooooooo`06oooo
o`;o00000oooool3o`0000kooooo000Tooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o
00002Oooool2o`00093ooooo0_l00002ooooo`;o0000:Oooool2o`0002_ooooo0_l0000;ooooo`;o
00003_ooool2o`0000?ooooo0_l0000?ooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000
N?ooool2o`00027ooooo0_l0000Dooooo`;o0000:?ooool2o`0000cooooo0_l0000Iooooo`;o0000
9?ooool002Cooooo0_l0000@ooooo`;o00003?ooool2o`00073ooooo0_l0000<ooooo`;o0000:Ooo
ool2o`0002Sooooo0_l0000<ooooo`;o0000?oooool002Cooooo00?o0000ooooooooool03?ooool2
o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00000Hooooo`;o0000:oooool2
o`0000[ooooo0_l0000[ooooo`;o0000X_ooool002Cooooo00?o0000ooooooooool01oooool2o`00
00?ooooo0_l0000<ooooo`;o00006oooool2o`0002_ooooo0_l0000:ooooo`;o00004Oooool2o`00
01?ooooo0_l0002Wooooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000N_ooool2o`00013o
oooo0_l000000ooooooo0000o`000012ooooo`;o0000Hoooool002Cooooo00?o0000ooooooooool0
G?ooool2o`0000gooooo0_l00008ooooo`;o00007_ooool2o`0001Sooooo0_l0000[ooooo`;o0000
7Oooool2o`0001[ooooo0_l0000Hooooo`;o00003_ooool002Cooooo0_l0000;ooooo`;o0000D?oo
ool2o`0000gooooo0_l00008ooooo`;o0000>?ooool4o`0002?ooooo0_l0000Sooooo`;o00006_oo
ool2o`00013ooooo0_l00006ooooo`;o00003_ooool002Cooooo00?o0000ooooooooool02_ooool2
o`0001Sooooo0_l0001Qooooo`;o0000:?ooool2o`0001gooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000Boooool2o`000003ooooool0003o000001Kooooo000Tooooo`03o`000?oooooooooo
02Cooooo0_l00005ooooo`;o00006?ooool2o`0000Cooooo0_l0000Yooooo`;o00003oooool2o`00
02kooooo0_l0000Gooooo`;o00001oooool2o`0004_ooooo0_l0000Iooooo`009?ooool00ol0003o
ooooooooo`0[ooooo`;o00006?ooool2o`0000Cooooo0_l0000Yooooo`;o00007?ooool2o`0001;o
oooo0ol0000<ooooo`;o0000R?ooool002Cooooo00?o0000ooooooooool0;?ooool2o`0005_ooooo
0_l00009ooooo`;o00004_ooool3o`0005_ooooo0_l0000Eooooo`;o00008_ooool002Cooooo0_l0
000]ooooo`;o00005Oooool2o`0001;ooooo0_l0000`ooooo`;o0000A_ooool2o`0003?ooooo0_l0
000Eooooo`;o00008_ooool002Cooooo00?o0000ooooooooool0@oooool2o`0001;ooooo0_l0000S
ooooo`;o0000Doooool2o`0004;ooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`0boooo
o`;o0000B?ooool2o`0003kooooo0_l0000=ooooo`;o00008_ooool2o`0002Cooooo0_l0000Zoooo
o`009?ooool00ol0003oooooooooo`0aooooo`?o0000I_ooool2o`00023ooooo0_l0000=ooooo`;o
00008_ooool2o`0003;ooooo0_l0000Looooo`009?ooool3o`00037ooooo0_l0000Fooooo`;o0000
0oooool2o`0000?ooooo0_l00015ooooo`?o0000Q_ooool2o`0001cooooo000Tooooo`?o00004?oo
ool2o`0003Oooooo0_l00003ooooo`;o00000oooool2o`0004Kooooo0_l0002Tooooo`009?ooool0
0ol0003oooooooooo`0@ooooo`;o0000:_ooool2o`00027ooooo0_l0000Sooooo`;o0000^oooool0
02Cooooo00Co0000oooooooooooooooo0_l0000iooooo`;o00008Oooool2o`0002?ooooo0_l00006
ooooo`;o0000J_ooool2o`0004Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooo
oooo0_l00013ooooo`;o0000A?ooool2o`0004Kooooo0_l0000Oooooo`;o000000?oooooo`000?l0
00001oooool2o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo04Kooooo0_l0001Mooooo`;o0000;Oooool2o`0001oooooo0_l0000:ooooo`;o0000?_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo0ol0002Uooooo`;o0000@_ooool2o`0005Kooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0>Wooooo0_l0001Fooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo01_ooooo0_l00014ooooo`;o00006?ooool2o`000:?o
oooo0_l0000Oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`;o0000
A?ooool2o`0001Sooooo0_l0001Nooooo`;o00008?ooool2o`00027ooooo0_l0000Oooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo0_l0000Pooooo`;o0000:Oooool2o`00
01Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`0002Cooooo0_l0003oooooo`Cooooo0_l0000Gooooo`009?ooool0
0ol0003oooooooooo`0Sooooo`;o0000oooooolMooooo`009?ooool00ol0003oooooooooo`3Noooo
o`;o00003Oooool2o`0005;ooooo000Tooooo`03o`000?oooooooooo09;ooooo0_l0001:ooooo`;o
00003Oooool2o`0001Gooooo0_l0000kooooo`009?ooool00ol0003oooooooooo`0Qooooo`;o0000
B_ooool2o`0002?ooooo0_l0001`ooooo`;o0000>oooool002Cooooo00?o0000ooooooooool08Ooo
ool2o`0004[ooooo0_l0002[ooooo`;o00009Oooool002Cooooo0_l0001jooooo`;o0000Woooool2
o`00013ooooo0_l0000Cooooo`009?ooool00ol0003oooooooooo`1iooooo`;o0000Z_ooool2o`00
00Gooooo0_l0000Cooooo`009?ooool00ol0003oooooooooo`0Hooooo`;o0000Boooool2o`000;ko
oooo0_l0000Jooooo`009?ooool00ol0003oooooooooo`0Hooooo`;o0000Boooool2o`0004gooooo
0_l0002;ooooo`009?ooool00ol0003oooooooooo`2dooooo`;o0000Roooool002Cooooo0_l0003S
ooooo`;o0000GOooool002Cooooo00?o0000ooooooooool0N?ooool2o`0002cooooo0_l0000joooo
o`;o0000:?ooool2o`0003?ooooo000Tooooo`03o`000?oooooooooo07Sooooo0_l0000/ooooo`;o
0000I?ooool2o`000003ooooool0003o0000033ooooo000Tooooo`03o`000?oooooooooo03Cooooo
0_l0000/ooooo`;o0000<oooool2o`0001Gooooo0_l0000Eooooo`;o0000B?ooool2o`00033ooooo
000Tooooo`03o`000?oooooooooo03Cooooo0_l0000<ooooo`;o00007_ooool2o`0003?ooooo0_l0
000Eooooo`;o00005Oooool2o`00017ooooo0_l0001Wooooo`009?ooool2o`0004?ooooo0_l0002D
ooooo`;o0000Ioooool002Cooooo00?o0000ooooooooool0;_ooool2o`00077ooooo0_l0002Noooo
o`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Fooooo`;o00005_ooool2o`00077ooooo0_l0002N
ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool04oooool2o`000003ooooool0003o00000?oooooo:_ooool0
00Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04oooool2o`000>kooooo0_l0000looooo`002Oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000gooooo0_l0002Dooooo`;o00006?ooool2
o`0004Cooooo0_l0000Jooooo`;o00008?ooool000Wooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0=ooooo`;o0000AOoo
ool2o`0004gooooo0_l0000Hooooo`;o0000H?ooool2o`000003ooooool0003o000001gooooo0009
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Cooooo0_l0000jooooo`;o0000T?ooool2o`0001gooooo0009ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo0_l0
001Aooooo`;o0000[oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_oo
ool00ol0003oooooooooo`0mooooo`;o0000S_ooool2o`0007;ooooo000Tooooo`;o0000Koooool2
o`0005gooooo0_l0001booooo`009?ooool00ol0003oooooooooo`1^ooooo`;o0000ROooool2o`00
04Kooooo000Tooooo`03o`000?oooooooooo0?Wooooo0_l00016ooooo`009?ooool00ol0003ooooo
ooooo`0Vooooo`;o00004?ooool2o`0001cooooo0_l0003Yooooo`009?ooool00ol0003ooooooooo
o`0Vooooo`;o00004?ooool2o`0001cooooo0_l0003Yooooo`009?ooool2o`0002Sooooo0_l0003o
oooooaWooooo000Tooooo`03o`000?oooooooooo02Oooooo0_l0002looooo`;o0000F_ooool002Co
oooo00?o0000ooooooooool0iOooool2o`0005[ooooo000Tooooo`03o`000?oooooooooo08[ooooo
0_l0002eooooo`009?ooool00ol0003oooooooooo`2:ooooo`;o0000S?ooool2o`0001Cooooo0_l0
000Aooooo`009?ooool2o`0003_ooooo0_l0003Looooo`;o00005?ooool2o`00017ooooo000Toooo
o`03o`000?oooooooooo00Cooooo0_l0000dooooo`;o0000Zoooool2o`0005Sooooo000Tooooo`03
o`000?oooooooooo00Cooooo0_l0003Qooooo`;o0000F?ooool002Cooooo00?o0000ooooooooool0
=Oooool2o`0001Kooooo0_l0001cooooo`;o0000OOooool002Cooooo00?o0000ooooooooool07_oo
ool2o`0001Gooooo0_l0000Fooooo`;o0000Loooool2o`0007gooooo000Tooooo`;o00007oooool2
o`000>Oooooo0_l0000hooooo`009?ooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000hoooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2=ooooo`;o0000/_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03oooooo0_l0001<ooooo`;o0000
/_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool2o`000=7ooooo0_l0
000]ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0006[ooooo0_l0002Vooooo`;o0000;Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Zooooo`;o0000eOooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool2o`0009Oooooo0_l0002Doooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0_l0000Kooooo`;o0000N_oo
ool2o`00057ooooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go0000
1?ooool4o`0000Kooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0000mooooo`;o0000
@Oooool002Cooooo1?l0002nooooo`;o0000<_ooool2o`0004cooooo000Tooooo`04o`000?oooooo
0000o`0003oooooo0_l0000Uooooo`;o0000J_ooool2o`0001kooooo0_l0001<ooooo`009?ooool0
0ol0003oooooooooo`10ooooo`;o00009Oooool2o`0006[ooooo0_l0001/ooooo`009?ooool00ol0
003oooooooooo`21ooooo`;o0000__ooool002Cooooo00?o0000ooooooooool0:Oooool2o`0005Ko
oooo0_l0002nooooo`009?ooool2o`0002[ooooo0_l0003ooooooaOooooo000Tooooo`03o`000?oo
oooooooo0?Kooooo0_l00019ooooo`009?ooool00ol0003oooooooooo`33ooooo`;o0000<Oooool2
o`0004Wooooo000Tooooo`03o`000?oooooooooo0<?ooooo0_l0001looooo`009?ooool00ol0003o
ooooooooo`18ooooo`;o0000Q?ooool2o`00077ooooo000Tooooo`;o0000BOooool2o`0008Cooooo
0_l0001aooooo`009?ooool00ol0003oooooooooo`3Oooooo`;o0000H?ooool002Cooooo00?o0000
ooooooooool0goooool2o`00063ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_l0003oooooockooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2o`0006oooooo0_l0003<ooooo`007?ooool00ol0003oooooooooo`05ooooo`?o0000
F_ooool2o`0001Oooooo0_l0001eooooo`;o0000EOooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Jooooo`;o0000S_ooool2o`0005Gooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`2Nooooo`;o0000XOooool002Cooooo0_l0002Oooooo`;o0000XOooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3oooooo`[ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`3ooooo
o`[ooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooooaGooooo0_l0000[ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0FOoo
ool2o`0005kooooo0_l0001Iooooo`;o0000:oooool000Cooooo00?o0000ooooooooool01?ooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0FOooool2o`0005kooooo0_l00026ooooo`001?ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
oooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;[ooooo0_l00025ooooo`00
9?ooool2o`000;_ooooo0_l00025ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0D?ooool2o`00
0>oooooo000Tooooo`03o`000?oooooooooo053ooooo0_l0003_ooooo`009?ooool2o`0005;ooooo
0_l0003^ooooo`009?ooool00ol0003oooooooooo`1Aooooo`;o00005Oooool2o`0003Kooooo0_l0
002Oooooo`009?ooool00ol0003oooooooooo`1Xooooo`;o0000=_ooool2o`0009oooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo000<
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3:ooooo`;o0000MOooool002Cooooo00?o
0000ooooooooool0b_ooool2o`0007Gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2
ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0`?ooool2o`0007oo
oooo000Tooooo`;o0000`Oooool2o`0007oooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool001Wooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000eooooo`006oooool00onHV9So
8B4Qonk^kP06ooooo`?o0000ooooool;ooooo`;o0000=Oooool001cooooo00?oMgMgofIVI_ooool0
oooooom:ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo000Iooooo`05o`000?nj^[[o
oooooiRHV?l@4100oooooom;ooooo`006Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBooo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .05664 Mdot
.03333 .05337 Mdot
.0381 .03724 Mdot
.04286 .30735 Mdot
.04762 .10654 Mdot
.05238 .00127 Mdot
.05714 .19398 Mdot
.0619 .06703 Mdot
.06667 .02903 Mdot
.07143 .01583 Mdot
.07619 .05784 Mdot
.08095 .18337 Mdot
.08571 .01928 Mdot
.09048 .24101 Mdot
.09524 .24304 Mdot
.1 .08344 Mdot
.10476 .09822 Mdot
.10952 .07367 Mdot
.11429 .13989 Mdot
.11905 .08272 Mdot
.12381 .01492 Mdot
.12857 .21618 Mdot
.13333 .00529 Mdot
.1381 .10257 Mdot
.14286 .23225 Mdot
.14762 .03432 Mdot
.15238 .01068 Mdot
.15714 .15605 Mdot
.1619 .2618 Mdot
.16667 .03684 Mdot
.17143 .00566 Mdot
.17619 .14581 Mdot
.18095 .24413 Mdot
.18571 .05608 Mdot
.19048 .05297 Mdot
.19524 .20134 Mdot
.2 .21193 Mdot
.20476 .0326 Mdot
.20952 .18332 Mdot
.21429 .202 Mdot
.21905 .06571 Mdot
.22381 .16445 Mdot
.22857 .00736 Mdot
.23333 .42373 Mdot
.2381 .12874 Mdot
.24286 .04506 Mdot
.24762 .03502 Mdot
.25238 .23957 Mdot
.25714 .27081 Mdot
.2619 .09474 Mdot
.26667 .03537 Mdot
.27143 .25078 Mdot
.27619 .05659 Mdot
.28095 .17095 Mdot
.28571 .19742 Mdot
.29048 .05758 Mdot
.29524 .09189 Mdot
.3 .12018 Mdot
.30476 .13135 Mdot
.30952 .39101 Mdot
.31429 .04795 Mdot
.31905 .02805 Mdot
.32381 .0417 Mdot
.32857 .23657 Mdot
.33333 .07325 Mdot
.3381 .13665 Mdot
.34286 .01649 Mdot
.34762 .02694 Mdot
.35238 .1066 Mdot
.35714 .43322 Mdot
.3619 .05078 Mdot
.36667 .02719 Mdot
.37143 .1044 Mdot
.37619 .00308 Mdot
.38095 .23271 Mdot
.39048 .59297 Mdot
.39524 .02629 Mdot
.4 .26083 Mdot
.40476 .05083 Mdot
.40952 .01683 Mdot
.41429 .30605 Mdot
.41905 .04943 Mdot
.42857 .57906 Mdot
.43333 .28878 Mdot
.4381 .12947 Mdot
.44286 .24155 Mdot
.45238 .04668 Mdot
.45714 .04291 Mdot
.4619 .2101 Mdot
.46667 .1677 Mdot
.47143 .45381 Mdot
.47619 .01116 Mdot
.48095 .15423 Mdot
.48571 .03499 Mdot
.49048 .11213 Mdot
.49524 .02548 Mdot
.5 .13447 Mdot
.50476 .02201 Mdot
.50952 .0554 Mdot
.51429 .05881 Mdot
.51905 .12352 Mdot
.52381 .17297 Mdot
.52857 .32876 Mdot
.53333 .00901 Mdot
.5381 .27083 Mdot
.54286 .15172 Mdot
.54762 .05882 Mdot
.55238 .09475 Mdot
.55714 .03848 Mdot
.5619 .23889 Mdot
.56667 .18045 Mdot
.57143 .13633 Mdot
.57619 .00625 Mdot
.58095 .0298 Mdot
.58571 .04935 Mdot
.59048 .11897 Mdot
.59524 .24414 Mdot
.6 .14837 Mdot
.60476 .23591 Mdot
.60952 .34552 Mdot
.61429 .16309 Mdot
.61905 .10278 Mdot
.62381 .02807 Mdot
.62857 .52709 Mdot
.63333 .14271 Mdot
.6381 .3829 Mdot
.64286 .08088 Mdot
.64762 .00472 Mdot
.65238 .22308 Mdot
.65714 .274 Mdot
.6619 .02587 Mdot
.66667 .16905 Mdot
.67143 .23788 Mdot
.67619 .02501 Mdot
.68095 .04623 Mdot
.68571 .02709 Mdot
.69048 .18817 Mdot
.69524 .02878 Mdot
.7 .02701 Mdot
.70476 .03479 Mdot
.70952 .00157 Mdot
.71429 .05967 Mdot
.71905 .04047 Mdot
.72381 .00587 Mdot
.72857 .01682 Mdot
.73333 .29304 Mdot
.7381 .00175 Mdot
.74286 .08324 Mdot
.74762 .3076 Mdot
.75238 .02364 Mdot
.75714 .12949 Mdot
.7619 .57674 Mdot
.76667 .16824 Mdot
.77143 .05262 Mdot
.77619 .07486 Mdot
.78095 .01078 Mdot
.78571 .29033 Mdot
.79048 .18508 Mdot
.79524 .03002 Mdot
.8 .06589 Mdot
.80476 .06845 Mdot
.80952 .12424 Mdot
.81429 .0865 Mdot
.81905 .13041 Mdot
.82381 .18203 Mdot
.82857 .11445 Mdot
.83333 .19959 Mdot
.8381 .01539 Mdot
.84286 .04415 Mdot
.84762 .52874 Mdot
.85238 .32917 Mdot
.85714 .20547 Mdot
.8619 .12774 Mdot
.86667 .24038 Mdot
.87143 .02302 Mdot
.87619 .00116 Mdot
.88095 .06918 Mdot
.88571 .16335 Mdot
.89048 .18635 Mdot
.89524 .09251 Mdot
.9 .39094 Mdot
.90476 .24449 Mdot
.90952 .00938 Mdot
.91429 .02819 Mdot
.91905 .00758 Mdot
.92381 .11488 Mdot
.92857 .19764 Mdot
.93333 .1285 Mdot
.9381 .16203 Mdot
.94286 .03335 Mdot
.94762 .01174 Mdot
.95238 .03918 Mdot
.95714 .00638 Mdot
.9619 .23079 Mdot
.96667 .23962 Mdot
.97143 .03371 Mdot
.97619 .02787 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Oooooo
0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o0000
2Oooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool3o`0000cooooo00?o0000ooooooooool0
0oooool2o`0000;ooooo0_l00003ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo0ol0000>ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`00
0?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo023ooooo0_l0000:ooooo`;o00004Ooo
ool2o`00063ooooo0_l0000<ooooo`;o00005_ooool2o`0001Kooooo0_l0000jooooo`;o00000_oo
ool2o`0000[ooooo0_l0000Dooooo`009?ooool00ol0003oooooooooo`0Vooooo`;o00005oooool2
o`0004kooooo0_l0000@ooooo`;o0000Coooool2o`0002Oooooo0_l00002ooooo`;o00001oooool2
o`0001Oooooo000Tooooo`;o00003Oooool2o`0000oooooo0_l00007ooooo`;o0000Ioooool2o`00
067ooooo0_l0000@ooooo`;o00008_ooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo00co
oooo0_l00002ooooo`;o00002oooool2o`0004Gooooo0_l0000Cooooo`;o0000I_ooool2o`00027o
oooo0_l0000kooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o0000D_ooool2o`0001?ooooo
0_l0000Mooooo`;o0000Aoooool2o`0005kooooo000Tooooo`03o`000?oooooooooo09Gooooo0_l0
00000ooooooo0000o`00000fooooo`;o00005oooool2o`0002Cooooo0_l0000`ooooo`009?ooool0
0ol0003oooooooooo`1Looooo`;o00001oooool2o`0000Cooooo0_l00008ooooo`;o00007_ooool2
o`0002Sooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000?
ooooo`;o00009?ooool2o`0000cooooo0_l0000Booooo`;o00003_ooool002Cooooo0_l0000;oooo
o`;o0000D?ooool2o`0000Oooooo0_l00004ooooo`;o00002?ooool2o`0003[ooooo0_l0000<oooo
o`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0001cooooo0_l0000Uoooo
o`;o00004_ooool2o`0000kooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0000Hooooo`;o
00004Oooool2o`0007Sooooo0_l0000Sooooo`;o000000?oooooo`000?l000006oooool2o`0002ko
oooo0_l00008ooooo`;o00003oooool002Cooooo00Co0000oooooooooooooooo0_l0000Qooooo`;o
00001Oooool2o`0000[ooooo0_l0000<ooooo`;o00001?ooool2o`0004Gooooo0_l00015ooooo`;o
0000Boooool2o`0000Sooooo0_l0000?ooooo`009?ooool01?l0003oooooooooooooool2o`0002So
oooo0_l0000Hooooo`;o00001?ooool2o`0004Gooooo0_l0000Eooooo`;o0000<oooool2o`0004Wo
oooo0_l0000Fooooo`009?ooool00ol0003oooooooooo`1Nooooo`;o0000:Oooool2o`0001kooooo
0_l0000cooooo`;o00009_ooool2o`00027ooooo0_l0000Fooooo`009?ooool2o`0004Cooooo0_l0
000Iooooo`;o00009oooool4o`0004Kooooo0_l0000cooooo`;o0000>Oooool002Cooooo00?o0000
ooooooooool0@oooool2o`0001Gooooo0_l0000Pooooo`;o00002Oooool2o`0002Wooooo0_l0000M
ooooo`;o0000K_ooool002Cooooo00Co0000ooooool0003o0000<Oooool2o`0002Kooooo0_l0000>
ooooo`;o00003?ooool2o`0000;ooooo0_l0000dooooo`;o0000>oooool2o`00053ooooo000Toooo
o`04o`000?oooooo0000o`00033ooooo0ol0000fooooo`;o00003?ooool2o`00023ooooo0_l0001C
ooooo`;o0000D?ooool002Cooooo0ol0000=ooooo`;o00008_ooool2o`0001_ooooo0_l00003oooo
o`;o0000AOooool3o`0000Wooooo0_l0002Iooooo`009?ooool3o`0000gooooo0_l0000oooooo`;o
00000oooool2o`0004Kooooo0_l00009ooooo`;o0000=?ooool2o`0006?ooooo000Tooooo`03o`00
0?oooooooooo03cooooo0_l0002Nooooo`;o0000Hoooool002Cooooo00?o0000ooooooooool02Ooo
ool2o`00037ooooo0_l0002jooooo`?o0000A_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`09ooooo`;o0000kOooool3o`0001Oooooo0_l0000]ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Hooooo`;o0000Aoooool2o`0008gooooo0_l0000P
ooooo`;o0000;Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o0000Aoooool2o`00
08gooooo0_l0001?ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`35ooooo`;o
0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Eooooo`;o
00001?ooool2o`000:Sooooo0_l0000Nooooo`;o0000F_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05Oooool2o`0000Cooooo0_l00038ooooo`;o00005_ooool2o`0004;ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oOooool2o`0004;ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`0005Gooooo0_l00031ooooo`;o0000:?ooool002Cooooo00?o0000ooooooooool0BOooool2
o`0000Wooooo0_l0001Booooo`;o0000KOooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo
01Kooooo0_l0000aooooo`;o0000GOooool2o`0009Oooooo000Tooooo`03o`000?oooooooooo01Ko
oooo0_l00009ooooo`;o0000oooooolOooooo`009?ooool00ol0003oooooooooo`0Qooooo`;o0000
B_ooool2o`0004kooooo0_l00022ooooo`009?ooool00ol0003oooooooooo`04ooooo`;o0000HOoo
ool2o`0000Cooooo0_l0001>ooooo`;o0000P_ooool002Cooooo0_l00005ooooo`;o0000HOooool2
o`000=Sooooo000Tooooo`03o`000?oooooooooo09Cooooo0_l0001[ooooo`;o00007Oooool2o`00
01oooooo000Tooooo`03o`000?oooooooooo09Cooooo0_l0001[ooooo`;o00007Oooool2o`0001oo
oooo000Tooooo`03o`000?oooooooooo05Kooooo0_l0001Looooo`;o0000Roooool002Cooooo00?o
0000ooooooooool0E_ooool2o`0004Gooooo0_l0000Eooooo`;o0000AOooool2o`0004Cooooo000T
ooooo`;o0000W_ooool2o`0005cooooo0_l00014ooooo`009?ooool00ol0003oooooooooo`12oooo
o`;o0000?oooool2o`0006Gooooo0_l0000Booooo`;o00003?ooool2o`0001Gooooo0_l0000Loooo
o`009?ooool00ol0003oooooooooo`12ooooo`;o00004oooool2o`0002[ooooo0_l0001Uooooo`;o
00004_ooool2o`0000cooooo0_l0000Eooooo`;o00007?ooool002Cooooo00?o0000ooooooooool0
Eoooool2o`0000Wooooo0_l0000cooooo`;o00005Oooool2o`00097ooooo000Tooooo`03o`000?oo
oooooooo06;ooooo0_l0000cooooo`;o00005Oooool2o`00097ooooo000Tooooo`;o00006oooool2
o`000:Kooooo0_l0001mooooo`009?ooool00ol0003oooooooooo`0Jooooo`;o00004_ooool2o`00
09;ooooo0_l0001mooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0^ooooo`;o0000Qoooool2
o`0008Sooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2Uooooo`;o00004?ooool2o`0008Sooooo0009oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo093ooooo0_l0000Cooooo`;o0000V_ooool000Wooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Wooooo`;o0000Ioooool2o`000:oooooo0009oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool09oooool2o`000?oooooo6Oooool000Wooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0_?ooool2o`0005Kooooo0_l0
000?ooooo`;o00006_ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0007gooooo0_l0001Fooooo`;o00003ooo
ool2o`0001[ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o
0000ooooooooool0?Oooool2o`0004gooooo0_l0000oooooo`;o00007_ooool2o`0005;ooooo000T
ooooo`;o0000DOooool2o`0003[ooooo0_l0000@ooooo`;o0000;Oooool2o`0001kooooo0_l0001B
ooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000C?ooool2o`000:7ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0[?ooool2o`0005;ooooo
0_l0000oooooo`009?ooool00ol0003oooooooooo`0?ooooo`;o00009oooool2o`0007;ooooo0_l0
0017ooooo`;o00002Oooool2o`0003oooooo000Tooooo`;o00004?ooool2o`0002Oooooo0_l0002J
ooooo`;o00007oooool2o`0001kooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`3Doooo
o`;o0000?oooool2o`0002[ooooo000Tooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocWo
oooo000Tooooo`03o`000?oooooooooo00Oooooo0_l00018ooooo`;o0000coooool2o`0001gooooo
000Tooooo`03o`000?oooooooooo03Cooooo0_l0000Kooooo`;o0000/?ooool2o`0001gooooo0_l0
000Mooooo`009?ooool2o`0003Gooooo0_l00004ooooo`;o0000aoooool2o`0003cooooo000Toooo
o`03o`000?oooooooooo03[ooooo0_l0003>ooooo`;o0000=Oooool002Cooooo00?o0000oooooooo
ool0R_ooool2o`0007kooooo0_l0000eooooo`009?ooool00ol0003oooooooooo`0eooooo`;o0000
Doooool2o`000;Gooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0000Eooooo`;o0000oooo
ool;ooooo`009?ooool2o`0001oooooo0_l0003oooooob;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?oo
ool2o`0007Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`;o0000
Moooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooool]ooooo`;o00004ooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Sooooo`;o0000Boooool2o`000;[ooooo0_l0000C
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02?ooooo0_l0000j
ooooo`;o00003oooool2o`0004Oooooo0_l0000Cooooo`;o0000LOooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04_ooool2o`0003;ooooo0_l0000Gooooo`;o0000B_ooool2o`00
00cooooo0_l0000Cooooo`;o0000?_ooool2o`0001kooooo0_l0000Aooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo0ol0000Jooooo`;o00005Oooool2o`0003cooooo0_l0
000Uooooo`;o00002Oooool2o`0005Kooooo0_l0000:ooooo`;o00004_ooool2o`00017ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`0Cooooo`;o00006_ooool2o`0005?ooooo0_l0000`ooooo`;o0000H_ooool2o`0002Gooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`1=ooooo`;o0000l_ooool0
02Cooooo00?o0000ooooooooool0COooool2o`000?;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0:Oooool2o`0004_ooooo0_l00039ooooo`009?oo
ool2o`0002[ooooo0_l0001;ooooo`;o0000bOooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`18ooooo`;o0000FOooool2o`0009cooooo000Tooooo`03
o`000?oooooooooo04Sooooo0_l0001Iooooo`;o00009Oooool2o`0007Gooooo000Tooooo`03o`00
0?oooooooooo0<[ooooo0_l0001eooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo087ooooo0_l0001`ooooo`;o0000C?ooool002Cooooo00?o0000ooooooooool0
POooool2o`0005oooooo0_l0000?ooooo`;o0000C?ooool002Cooooo0_l0003Sooooo`;o0000GOoo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo07_ooooo0_l00034ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo0_l0001gooooo`;o0000J_ooool2o`0005Sooooo000Looooo`03o`000?oo
oooooooo00Gooooo0ol00002ooooo`;o0000hoooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood;ooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0X?ooool2
o`0006Oooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`2Pooooo`;o0000Ioooool2o`00
03Kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0^_ooool2
o`0008Gooooo000Tooooo`03o`000?oooooooooo0;[ooooo0_l00025ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0`oooool2o`0007cooooo0004oooo
o`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0<?ooooo0_l0001looooo`001?ooool00ol0003oooooooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Iooooo`;o0000_Oooool2o`0002Oooooo0004ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Wooooo0_l0002mooooo`;o00009oooool000Cooooo00?o0000ooooooooool02_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood;ooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`009?ooool00ol0003o
ooooooooo`10ooooo`;o0000ooooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`0006Wooooo0_l0003Gooooo`009?ooool00ol0003oooooooooo`1Xooooo`;o0000eoooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo08gooooo0_l0002booooo`002_ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2=
ooooo`;o0000/_ooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=oooo
o`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000`Oooool2o`0007oooooo000Tooooo`03o`000?oooooooooo0<3ooooo
0_l00015ooooo`;o0000>?ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0_l0000hooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo
00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2oooo
o`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooooooo
ool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000T
ooooo`03o`000?oooooooooo0>cooooo0_l0001Cooooo`009?ooool00ol0003oooooooooo`1ooooo
o`;o0000Joooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`1cooooo`;o0000c?ooool002Cooooo00?o0000ooooooooool0Loooool2o`00
0<cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h0
1_ooool3o`000?oooooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool0
0ol0003oooooooooo`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;
ooooo`006Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .01492 Mdot
.03333 .05337 Mdot
.0381 .03724 Mdot
.04286 .11332 Mdot
.04762 .10654 Mdot
.05238 .00127 Mdot
.05714 .24886 Mdot
.0619 .1671 Mdot
.06667 .02213 Mdot
.07143 .02006 Mdot
.07619 .19146 Mdot
.08095 .0127 Mdot
.08571 .06608 Mdot
.09048 .0393 Mdot
.09524 .2783 Mdot
.1 .08344 Mdot
.10476 .09822 Mdot
.10952 .07367 Mdot
.11429 .13989 Mdot
.11905 .10386 Mdot
.12381 .01492 Mdot
.12857 .4161 Mdot
.13333 .07822 Mdot
.1381 .10257 Mdot
.14286 .18696 Mdot
.14762 .03432 Mdot
.15238 .01068 Mdot
.15714 .37999 Mdot
.1619 .28525 Mdot
.16667 .03684 Mdot
.17143 .00566 Mdot
.17619 .18915 Mdot
.18095 .11796 Mdot
.18571 .1365 Mdot
.19048 .13416 Mdot
.19524 .04989 Mdot
.2 .07013 Mdot
.20476 .0326 Mdot
.20952 .09475 Mdot
.21429 .23525 Mdot
.21905 .11183 Mdot
.22381 .05093 Mdot
.22857 .00736 Mdot
.23333 .20081 Mdot
.2381 .13357 Mdot
.24286 .20928 Mdot
.24762 .03502 Mdot
.25238 .04398 Mdot
.25714 .3852 Mdot
.2619 .09821 Mdot
.26667 .07664 Mdot
.27143 .0116 Mdot
.27619 .05659 Mdot
.28095 .24025 Mdot
.28571 .28521 Mdot
.29048 .01768 Mdot
.29524 .09189 Mdot
.3 .06405 Mdot
.30476 .12024 Mdot
.30952 .40378 Mdot
.31429 .04795 Mdot
.31905 .02805 Mdot
.32381 .00171 Mdot
.32857 .28604 Mdot
.33333 .16531 Mdot
.3381 .03567 Mdot
.34286 .14691 Mdot
.34762 .0448 Mdot
.35238 .0355 Mdot
.35714 .51073 Mdot
.3619 .00193 Mdot
.36667 .02719 Mdot
.37143 .15846 Mdot
.37619 .13746 Mdot
.38095 .23271 Mdot
.39048 .32748 Mdot
.39524 .3873 Mdot
.4 .33067 Mdot
.40476 .13354 Mdot
.40952 .01683 Mdot
.41429 .12106 Mdot
.41905 .02577 Mdot
.42857 .56968 Mdot
.43333 .18914 Mdot
.4381 .12947 Mdot
.44286 .33503 Mdot
.45238 .05943 Mdot
.45714 .04291 Mdot
.4619 .27082 Mdot
.46667 .09568 Mdot
.47143 .41475 Mdot
.47619 .01769 Mdot
.48095 .00607 Mdot
.48571 .03499 Mdot
.49048 .04963 Mdot
.49524 .02548 Mdot
.5 .37224 Mdot
.50476 .03801 Mdot
.50952 .28184 Mdot
.51429 .02492 Mdot
.51905 .01881 Mdot
.52381 .03577 Mdot
.52857 .11956 Mdot
.53333 .14938 Mdot
.5381 .1653 Mdot
.54286 .12624 Mdot
.54762 .08865 Mdot
.55238 .09475 Mdot
.55714 .03848 Mdot
.5619 .07247 Mdot
.56667 .07335 Mdot
.57143 .13633 Mdot
.57619 .01789 Mdot
.58095 .20279 Mdot
.58571 .05994 Mdot
.59048 .0034 Mdot
.59524 .10313 Mdot
.6 .14837 Mdot
.60476 .23591 Mdot
.60952 .22056 Mdot
.61429 .09758 Mdot
.61905 .10278 Mdot
.62381 .07062 Mdot
.63333 .14271 Mdot
.6381 .47653 Mdot
.64286 .07017 Mdot
.64762 .00472 Mdot
.65238 .16936 Mdot
.65714 .34202 Mdot
.6619 .02587 Mdot
.66667 .16905 Mdot
.67143 .36809 Mdot
.67619 .02501 Mdot
.68095 .10462 Mdot
.68571 .02219 Mdot
.69048 .19325 Mdot
.69524 .02878 Mdot
.7 .16403 Mdot
.70476 .03479 Mdot
.70952 .06254 Mdot
.71429 .03297 Mdot
.71905 .04047 Mdot
.72381 .04729 Mdot
.72857 .03889 Mdot
.73333 .3609 Mdot
.7381 .09713 Mdot
.74286 .04989 Mdot
.74762 .26672 Mdot
.75238 .02364 Mdot
.75714 .36648 Mdot
.7619 .33107 Mdot
.76667 .03384 Mdot
.77143 .08895 Mdot
.77619 .15785 Mdot
.78095 .01078 Mdot
.78571 .11665 Mdot
.79048 .11149 Mdot
.79524 .03002 Mdot
.8 .18053 Mdot
.80476 .07381 Mdot
.80952 .03778 Mdot
.81429 .0865 Mdot
.81905 .27925 Mdot
.82381 .1205 Mdot
.82857 .00272 Mdot
.83333 .21217 Mdot
.8381 .01539 Mdot
.84286 .09467 Mdot
.84762 .36113 Mdot
.85238 .34533 Mdot
.85714 .09739 Mdot
.8619 .12774 Mdot
.86667 .01991 Mdot
.87143 .31071 Mdot
.87619 .18676 Mdot
.88095 .06918 Mdot
.88571 .01015 Mdot
.89048 .08524 Mdot
.89524 .04535 Mdot
.9 .23594 Mdot
.90476 .24449 Mdot
.90952 .00938 Mdot
.91429 .02819 Mdot
.91905 .00758 Mdot
.92381 .1971 Mdot
.92857 .15703 Mdot
.93333 .1285 Mdot
.9381 .00991 Mdot
.94286 .17522 Mdot
.94762 .01174 Mdot
.95238 .03918 Mdot
.95714 .00638 Mdot
.9619 .20595 Mdot
.96667 .41379 Mdot
.97143 .03371 Mdot
.97619 .01388 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o
00002Oooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool2o`000003ooooool0003ooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo00Gooooo
0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o
00002Oooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`;o
00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000?ooooo`?o
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool2o`000003ooooool0003ooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`009?ooool00ol0003ooooo
ooooo`0/ooooo`;o00004Oooool2o`0004oooooo0_l0000eooooo`;o0000Boooool2o`0000Gooooo
0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000Dooooo`009?ooool00ol0003ooooooooo
o`0?ooooo`;o00005Oooool2o`0001Oooooo0_l0000<ooooo`;o0000Xoooool2o`00023ooooo0_l0
0005ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`009?ooool3
o`0000oooooo0_l0000<ooooo`;o00001oooool2o`0002Gooooo0_l0002Sooooo`;o00004?ooool2
o`0002;ooooo0_l00007ooooo`;o00003_ooool002Cooooo0ol0000Mooooo`;o0000=?ooool2o`00
02Cooooo0_l0000Dooooo`;o00003?ooool2o`00013ooooo0_l0001Cooooo`;o0000:oooool2o`00
00kooooo000Tooooo`03o`000?oooooooooo00[ooooo1?l00015ooooo`;o00009?ooool2o`0001Co
oooo0_l0000<ooooo`;o00004?ooool2o`0002;ooooo0_l0000iooooo`;o0000<Oooool002Cooooo
00?o0000ooooooooool02_ooool4o`0008Oooooo0_l00004ooooo`;o0000<oooool2o`000003oooo
ool0003o000001Cooooo0_l0000Sooooo`;o0000<Oooool002Cooooo00?o0000ooooooooool0G?oo
ool2o`0000gooooo0_l0000?ooooo`;o00005oooool2o`0000Cooooo0_l0000^ooooo`;o00000ooo
ool2o`0001Oooooo0_l0000booooo`;o00008_ooool002Cooooo0_l0001Mooooo`;o00003Oooool2
o`0000oooooo0_l0001=ooooo`;o00002Oooool2o`0001kooooo0_l0000Uooooo`;o00008_ooool0
02Cooooo00?o0000ooooooooool09?ooool2o`00017ooooo0_l0002Mooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000?ooooo`;o00001oooool2o`0003Sooooo0_l0000?ooooo`009?ooool01?l0
003oooooooooooooool2o`00027ooooo0_l00005ooooo`;o00002_ooool2o`0000cooooo0_l0000K
ooooo`;o00000oooool2o`0002Wooooo0_l0000:ooooo`;o0000>Oooool2o`000003ooooool0003o
000000oooooo0_l0000<ooooo`;o0000<oooool2o`0000oooooo000Tooooo`04o`000?oooooooooo
ooooo`;o00003oooool2o`0001Oooooo0_l0000Hooooo`;o00006oooool2o`0000?ooooo0_l0000Y
ooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`;o0000<oooool2o`000003ooooool0003o
000001Sooooo0_l0000/ooooo`;o00005_ooool002Cooooo00?o0000ooooooooool04_ooool2o`00
03;ooooo0_l00011ooooo`;o00003Oooool2o`0000oooooo0_l0000cooooo`;o000000?oooooo`00
0?l00000A_ooool2o`0001Kooooo000Tooooo`;o0000Aoooool2o`0001gooooo0_l0000Rooooo`;o
0000S?ooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l0000Tooooo`;o0000
2Oooool2o`0002gooooo0_l00019ooooo`;o00001?ooool2o`00033ooooo0_l0000Xooooo`009?oo
ool01?l0003oooooo`000?l0000cooooo`;o00001oooool2o`0001_ooooo0_l0000hooooo`;o0000
BOooool2o`0000Cooooo0_l0001Jooooo`009?ooool01?l0003oooooo`000?l0000looooo`;o0000
ooooool3ooooo`009?ooool00ol0003oooooooooo`1>ooooo`;o0000=oooool2o`000;Sooooo000T
ooooo`;o0000Coooool2o`0003Oooooo0_l0000Yooooo`;o00009oooool2o`0006Cooooo000Toooo
o`03o`000?oooooooooo05Kooooo0_l0001Jooooo`;o00009oooool2o`0006Cooooo000Tooooo`03
o`000?oooooooooo013ooooo0_l00014ooooo`;o0000jOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0@ooooo`;o00008oooool2o`0008Sooooo0_l00004ooooo`;o0000Boooool2
o`0002gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Sooooo
0_l0000Kooooo`;o0000M?ooool3o`00017ooooo0_l00004ooooo`;o0000<_ooool2o`0001Oooooo
0_l0000]ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Sooooo0_l0000aooooo`;o0000G_oo
ool3o`0004_ooooo0_l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0P
ooooo`;o0000:Oooool2o`000?Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool05Oooool2o`0000Wooooo0_l0003oooooob3ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Gooooo0_l0003Vooooo`;o00005_ooool2o`0002[ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Y_ooool2o`0004Oooooo0_l0000<ooooo`;o00005_oo
ool2o`0002[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool2o`0005Gooooo0_l0001@ooooo`;o0000Aoooool2o`00053o
oooo000Tooooo`03o`000?oooooooooo03Sooooo0_l0000Jooooo`;o0000=_ooool2o`0001[ooooo
0_l0001Looooo`;o0000>Oooool002Cooooo00?o0000ooooooooool05_ooool2o`00023ooooo0_l0
000?ooooo`;o0000@Oooool2o`0001[ooooo0_l0000Booooo`;o00009_ooool2o`00023ooooo0_l0
0002ooooo`;o0000=Oooool002Cooooo00?o0000ooooooooool05_ooool2o`0000Wooooo0_l0000V
ooooo`;o0000LOooool2o`0002Kooooo0_l0000Tooooo`;o0000=Oooool002Cooooo00?o0000oooo
ooooool06oooool2o`0000Cooooo0_l0002Cooooo`;o00001Oooool2o`0001;ooooo0_l0001^oooo
o`009?ooool00ol0003oooooooooo`04ooooo`;o00005Oooool2o`0009Wooooo0_l00005ooooo`;o
00004_ooool2o`0006kooooo000Tooooo`;o00001Oooool2o`0003Kooooo0_l0002gooooo`;o0000
B_ooool002Cooooo00?o0000ooooooooool00_ooool2o`0003Sooooo0_l0002gooooo`;o0000B_oo
ool002Cooooo00?o0000ooooooooool00_ooool2o`0002_ooooo0_l00032ooooo`;o0000C?ooool0
02Cooooo00?o0000ooooooooool0;oooool2o`0002Kooooo0_l0000Rooooo`;o00008oooool2o`00
057ooooo0_l0000;ooooo`;o0000?oooool002Cooooo00?o0000ooooooooool0Eoooool2o`0002;o
oooo0_l0000Sooooo`;o0000G_ooool2o`0003oooooo000Tooooo`;o0000Y_ooool2o`0009[ooooo
000Tooooo`03o`000?oooooooooo08?ooooo0_l0000Pooooo`;o0000IOooool2o`0001Gooooo0_l0
000Looooo`009?ooool00ol0003oooooooooo`12ooooo`;o0000=?ooool2o`0000Wooooo0_l00027
ooooo`;o00005Oooool2o`0001cooooo000Tooooo`03o`000?oooooooooo037ooooo0ol0000>oooo
o`;o0000=?ooool2o`0003Cooooo0_l0002Aooooo`009?ooool00ol0003oooooooooo`0aooooo`?o
0000>_ooool2o`0003kooooo0_l0002Aooooo`009?ooool2o`0001_ooooo0_l0001Booooo`;o0000
D_ooool2o`0007gooooo000Tooooo`03o`000?oooooooooo01[ooooo0_l0002Vooooo`;o0000OOoo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0I?ooool2o`00057ooooo0_l00028ooooo`002Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0I?ooool2o`0003_ooooo0_l0000Dooooo`;o0000R?ooool000Wooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
XOooool2o`0009kooooo0009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`?o0000l?ooool2o`00033ooooo0_l0000Mooooo`002Oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06go
oooo0_l00021ooooo`;o0000<?ooool2o`0001gooooo0009ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06gooooo0_l0001Yooooo`;o
0000Ioooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02Oooool2o`0005Kooooo0_l00010ooooo`;o0000<oooool2o`0006Oo
oooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooooooo
ool02Oooool2o`0005Kooooo0_l00010ooooo`;o00008oooool2o`0000?ooooo0_l0001booooo`00
9?ooool2o`000<Wooooo0_l00003ooooo`;o0000L_ooool002Cooooo00?o0000ooooooooool0oooo
oolWooooo`;o00006Oooool002Cooooo00?o0000ooooooooool0oooooolWooooo`;o00006Oooool0
02Cooooo00?o0000ooooooooool0n?ooool2o`0004Oooooo000Tooooo`03o`000?oooooooooo0?So
oooo0_l00017ooooo`009?ooool2o`0002Cooooo0_l0003/ooooo`;o0000;_ooool002Cooooo00?o
0000ooooooooool03Oooool2o`0001Cooooo0_l00009ooooo`;o0000DOooool2o`0008kooooo0_l0
000^ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o00007oooool2o`00057ooooo0_l0001A
ooooo`;o0000Joooool002Cooooo00?o0000ooooooooool0e?ooool2o`0004[ooooo0_l0000Ooooo
o`009?ooool00ol0003oooooooooo`10ooooo`;o0000g_ooool2o`0001oooooo000Tooooo`;o0000
@Oooool2o`0006oooooo0_l0002>ooooo`009?ooool00ol0003oooooooooo`2aooooo`;o0000NOoo
ool2o`0001?ooooo000Tooooo`03o`000?oooooooooo04?ooooo0_l0003Wooooo`;o00004oooool0
02Cooooo00?o0000ooooooooool0@oooool2o`000;kooooo0_l0000looooo`009?ooool00ol0003o
ooooooooo`3oooooo`Cooooo0_l0000looooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o
0000ooooooooool0^_ooool2o`0008Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;[ooooo0_l00025ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooom2ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`?o0000>_ooool2o`0003Cooooo0_l0003?ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03[ooooo0_l0000dooooo`;o0000
Aoooool2o`0005gooooo0_l0000Wooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1@ooooo`;o0000Ioooool2o`0005gooooo0_l0000Wooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo053ooooo0_l00038ooooo`;o00009Oooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo6oooool2o`00
02Gooooo000Tooooo`;o00002?ooool2o`000?oooooo>Oooool002Cooooo00?o0000ooooooooool0
1oooool2o`000?oooooo>Oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0>Oooooo0_l0001Hooooo`009?oo
ool00ol0003oooooooooo`2:ooooo`;o0000Foooool2o`0005Sooooo000Tooooo`03o`000?oooooo
oooo08[ooooo0_l0002eooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o0000ooooool]oooo
o`009?ooool2o`0001Cooooo0_l0003Yooooo`;o0000@Oooool002Cooooo00?o0000ooooooooool0
V_ooool2o`0006;ooooo0_l00011ooooo`009?ooool00ol0003oooooooooo`0Yooooo`;o00009_oo
ool2o`0000cooooo0_l0000iooooo`;o0000YOooool002Cooooo00?o0000ooooooooool0:Oooool2
o`0002Kooooo0_l0000<ooooo`;o0000h?ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Go
oooo0ol0003ooooooa3ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo4?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@_ooool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000M?ooool2o`000<cooooo000Tooooo`03o`000?oooooooooo07?ooooo
0_l000000ooooooo0000o`000039ooooo`009?ooool00ol0003oooooooooo`1fooooo`;o0000M?oo
ool2o`0005?ooooo000Tooooo`03o`000?oooooooooo08Cooooo0_l0001Vooooo`;o0000Doooool0
02Cooooo00?o0000ooooooooool0Q?ooool2o`000;_ooooo000Tooooo`;o0000boooool2o`0007Go
oooo000Tooooo`03o`000?oooooooooo0<[ooooo0_l0000mooooo`;o0000=_ooool002Cooooo00?o
0000ooooooooool0ooooool:ooooo`;o0000=_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3Rooooo`;o00008oooool2o`0003Sooooo000Tooooo`03o`000?oo
oooooooo0>;ooooo0_l0000Sooooo`;o0000>?ooool002Cooooo00?o0000ooooooooool0j_ooool2
o`0005Gooooo000Tooooo`03o`000?oooooooooo0<kooooo0_l0000Jooooo`;o0000EOooool002Co
oooo0_l0002Hooooo`;o0000=Oooool2o`00077ooooo000Tooooo`03o`000?oooooooooo09Oooooo
0_l0002Xooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09oooool2o`000?oooooo
6Oooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2o`000?oooooo
6Oooool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0B?ooool2o`000?Oooooo0004ooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000B?ooool2
o`0002_ooooo0_l0003:ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Gooooo0_l0003:
ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0005[o
oooo0_l0003Vooooo`009?ooool00ol0003oooooooooo`1Iooooo`;o0000i_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooooboooooo0_l0000A
ooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000KOooool2o`0009oooooo0_l0000Aoooo
o`009?ooool2o`0001oooooo0_l0001]ooooo`;o0000/_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom2ooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0003ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0`ooo
ool2o`0007cooooo000Tooooo`;o0000a?ooool2o`0007cooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003o
oooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo0_l0001Yooooo`;o0000eoooool002Cooooo00?o0000oooo
ooooool0J?ooool2o`000=Oooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo
0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo07oooooo0_l00030oooo
o`009?ooool2o`00083ooooo0_l00030ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Iooooo`Go00001_ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06oooo
o`?o0000oooooom2ooooo`007?ooool00omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`00
0?oooooooooo0?ooooooBOooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo
000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .008 Mdot
.03333 .06262 Mdot
.0381 .03724 Mdot
.04286 .25386 Mdot
.04762 .21752 Mdot
.05238 .16199 Mdot
.05714 .27326 Mdot
.0619 .54585 Mdot
.06667 .02436 Mdot
.07143 .2154 Mdot
.07619 .02155 Mdot
.08095 .0127 Mdot
.08571 .06608 Mdot
.09048 .0393 Mdot
.09524 .04043 Mdot
.1 .05418 Mdot
.10476 .09822 Mdot
.10952 .07367 Mdot
.11429 .13989 Mdot
.11905 .06525 Mdot
.12381 .0294 Mdot
.12857 .21175 Mdot
.13333 .1023 Mdot
.1381 .22843 Mdot
.14286 .34833 Mdot
.14762 .00633 Mdot
.15238 .01068 Mdot
.15714 .45019 Mdot
.1619 .26303 Mdot
.16667 .03684 Mdot
.17143 .04388 Mdot
.17619 .30419 Mdot
.18095 .20061 Mdot
.18571 .1365 Mdot
.19048 .19957 Mdot
.19524 .04989 Mdot
.2 .17502 Mdot
.20476 .0326 Mdot
.20952 .0498 Mdot
.21429 .10863 Mdot
.21905 .04446 Mdot
.22381 .21237 Mdot
.22857 .00768 Mdot
.23333 .40892 Mdot
.2381 .12229 Mdot
.24286 .21258 Mdot
.24762 .00446 Mdot
.25238 .00546 Mdot
.25714 .42932 Mdot
.2619 .04919 Mdot
.26667 .24156 Mdot
.27143 .07911 Mdot
.27619 .05659 Mdot
.28095 .11673 Mdot
.28571 .22314 Mdot
.29048 .0007 Mdot
.29524 .37501 Mdot
.3 .17791 Mdot
.30476 .10888 Mdot
.30952 .36347 Mdot
.31429 .04795 Mdot
.31905 .02805 Mdot
.32381 .1648 Mdot
.32857 .14126 Mdot
.33333 .16531 Mdot
.3381 .02366 Mdot
.34286 .06105 Mdot
.34762 .0448 Mdot
.35238 .22185 Mdot
.3619 .00193 Mdot
.36667 .01306 Mdot
.37143 .14652 Mdot
.37619 .15214 Mdot
.38095 .30531 Mdot
.38571 .52156 Mdot
.39048 .28236 Mdot
.39524 .51658 Mdot
.4 .37963 Mdot
.40476 .15992 Mdot
.40952 .01683 Mdot
.41429 .12106 Mdot
.41905 .02577 Mdot
.42857 .58147 Mdot
.43333 .08227 Mdot
.4381 .0351 Mdot
.44286 .15544 Mdot
.45238 .14108 Mdot
.45714 .04291 Mdot
.4619 .12778 Mdot
.46667 .05032 Mdot
.47143 .58607 Mdot
.47619 .07167 Mdot
.48095 .00607 Mdot
.48571 .04741 Mdot
.49048 .03768 Mdot
.49524 .02548 Mdot
.5 .21995 Mdot
.50476 .04749 Mdot
.50952 .13597 Mdot
.51429 .21484 Mdot
.51905 .01881 Mdot
.52381 .11292 Mdot
.52857 .04893 Mdot
.53333 .02507 Mdot
.5381 .0427 Mdot
.54286 .20053 Mdot
.54762 .22719 Mdot
.55238 .28303 Mdot
.55714 .08895 Mdot
.5619 .0384 Mdot
.56667 .07241 Mdot
.57143 .13633 Mdot
.57619 .01789 Mdot
.58095 .20279 Mdot
.58571 .18603 Mdot
.59048 .0034 Mdot
.59524 .05426 Mdot
.6 .55942 Mdot
.60476 .10865 Mdot
.60952 .16975 Mdot
.61429 .18897 Mdot
.61905 .1487 Mdot
.62381 .07062 Mdot
.63333 .14271 Mdot
.6381 .50692 Mdot
.64286 .01706 Mdot
.64762 .00472 Mdot
.65238 .09736 Mdot
.65714 .30058 Mdot
.6619 .02587 Mdot
.66667 .07108 Mdot
.67143 .17165 Mdot
.67619 .02501 Mdot
.68095 .10462 Mdot
.68571 .02219 Mdot
.69048 .15161 Mdot
.69524 .02878 Mdot
.7 .11207 Mdot
.70476 .07178 Mdot
.70952 .06385 Mdot
.71429 .03297 Mdot
.71905 .04047 Mdot
.72381 .07966 Mdot
.72857 .03889 Mdot
.73333 .38426 Mdot
.7381 .21893 Mdot
.74286 .04989 Mdot
.74762 .26672 Mdot
.75238 .02364 Mdot
.75714 .18231 Mdot
.7619 .03893 Mdot
.76667 .06707 Mdot
.77143 .08831 Mdot
.77619 .01839 Mdot
.78095 .01646 Mdot
.78571 .19438 Mdot
.79048 .11149 Mdot
.79524 .08546 Mdot
.8 .20846 Mdot
.80476 .01907 Mdot
.80952 .01266 Mdot
.81429 .0865 Mdot
.81905 .19613 Mdot
.82381 .01014 Mdot
.82857 .0811 Mdot
.83333 .21217 Mdot
.8381 .16977 Mdot
.84286 .02283 Mdot
.84762 .01579 Mdot
.85238 .16977 Mdot
.85714 .23122 Mdot
.8619 .18859 Mdot
.86667 .01991 Mdot
.87143 .03508 Mdot
.87619 .39717 Mdot
.88095 .06918 Mdot
.88571 .00398 Mdot
.89048 .08524 Mdot
.89524 .04535 Mdot
.9 .21222 Mdot
.90476 .19735 Mdot
.90952 .06476 Mdot
.91429 .02819 Mdot
.91905 .00758 Mdot
.92381 .00663 Mdot
.92857 .32319 Mdot
.93333 .1285 Mdot
.9381 .13746 Mdot
.94286 .115 Mdot
.94762 .05643 Mdot
.95238 .03918 Mdot
.95714 .00638 Mdot
.9619 .30347 Mdot
.96667 .38787 Mdot
.97143 .03371 Mdot
.97619 .06719 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00cooooo
0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000?ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`07ooooo`?o00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0
000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`?o00003oooool3o`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool3o`0000[ooooo0ol00008ooooo`;o00001Oooool00ol0003ooooooooo
o`0<ooooo`009?ooool3o`0002Cooooo0_l0000Iooooo`;o00001?ooool3o`0004Sooooo0_l0000e
ooooo`;o0000=oooool2o`0001gooooo0ol00009ooooo`;o00005?ooool002Cooooo0ol0000?oooo
o`;o00005Oooool2o`0001Oooooo0_l0000Zooooo`;o0000S_ooool2o`0000?ooooo0_l0000Moooo
o`;o00008?ooool002Cooooo0_l0000@ooooo`;o00005Oooool2o`0004?ooooo0_l0002>ooooo`;o
00002_ooool2o`0003Sooooo000Tooooo`03o`000?oooooooooo07Wooooo0_l0000Rooooo`;o0000
4?ooool2o`0001Cooooo0_l0000Yooooo`Co00001Oooool2o`0000cooooo0_l0000hooooo`009?oo
ool00ol0003oooooooooo`0=ooooo`;o0000J_ooool2o`0002;ooooo0_l0000@ooooo`;o00005?oo
ool2o`0000cooooo0_l0000Kooooo`Co00001Oooool2o`0001?ooooo0_l0000aooooo`009?ooool0
0ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l00000Doooool2o`00037ooooo0_l0000:
ooooo`;o0000;Oooool2o`000003ooooool0003o000001Cooooo0_l0000Kooooo`;o00001_ooool2
o`00037ooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0001@ooooo`;o00001?ooool2o`00
01Sooooo0_l0000Gooooo`;o00002_ooool2o`0002Sooooo0_l00003ooooo`;o00005oooool2o`00
01_ooooo0_l0000Eooooo`;o00008_ooool002Cooooo0_l0000Nooooo`;o0000?Oooool2o`0001ko
oooo0_l0001=ooooo`;o00002Oooool2o`0004Gooooo0_l0000Rooooo`009?ooool00ol0003ooooo
ooooo`0Mooooo`;o00006?ooool2o`0009gooooo0_l00004ooooo`;o0000D_ooool2o`0000oooooo
000Tooooo`04o`000?ooooooooooooooo`;o0000:?ooool2o`0000[ooooo0_l0001:ooooo`;o0000
3oooool2o`0004Kooooo0_l0000aooooo`;o00007oooool2o`0000oooooo000Tooooo`04o`000?oo
ooooooooooooo`;o00003oooool3o`0001Kooooo0_l0001Fooooo`;o00003oooool2o`0001Gooooo
0_l0000aooooo`;o000000?oooooo`000?l000002Oooool2o`00027ooooo0_l0000Hooooo`;o0000
5_ooool002Cooooo00?o0000ooooooooool04_ooool3o`0001Oooooo0_l0001Kooooo`;o00006?oo
ool2o`0000Kooooo0_l0000aooooo`;o000000?oooooo`000?l000002Oooool2o`0003_ooooo0_l0
000Fooooo`009?ooool2o`0002gooooo0_l0000>ooooo`;o00009oooool2o`0002;ooooo0_l0000H
ooooo`;o0000L_ooool2o`0002Sooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l00002oooo
o`;o00000_ooool2o`0000_ooooo0_l0000?ooooo`;o00002Oooool2o`0002Gooooo0_l00004oooo
o`;o00001?ooool2o`0000Kooooo0_l00013ooooo`;o0000<?ooool2o`0002Sooooo000Tooooo`03
o`000?oooooooooo03Cooooo0_l00002ooooo`;o00003oooool2o`0000oooooo0_l0000`ooooo`;o
00001?ooool2o`0000Cooooo0_l00006ooooo`;o0000@oooool2o`0005[ooooo000Tooooo`03o`00
0?oooooooooo01Gooooo0_l0002Oooooo`;o0000L?ooool2o`0001Oooooo000Tooooo`03o`000?oo
oooooooo01Gooooo0_l0000gooooo`;o0000I_ooool2o`00073ooooo0_l0000Gooooo`009?ooool4
o`0004gooooo0_l0000Dooooo`;o0000foooool002Cooooo00Co0000ooooool0003o00006_ooool2
o`0004Oooooo0_l0001eooooo`;o0000?_ooool2o`0002Cooooo000Tooooo`03o`000?oooooooooo
013ooooo0_l00009ooooo`;o0000__ooool2o`00013ooooo0_l0000/ooooo`;o00005?ooool2o`00
00kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04?ooool2o`0007gooooo0_l0
000^ooooo`;o00003?ooool2o`0000[ooooo0_l0000Booooo`;o00008oooool2o`0001gooooo0_l0
000>ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Hooooo`;o
0000MOooool2o`0001_ooooo0_l0000Aooooo`;o00003?ooool2o`0000[ooooo0_l0000gooooo`;o
0000;Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o0000T_ooool2o`0009?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04gooooo0_l0002@ooooo`;o00008?oo
ool2o`0003kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0COoo
ool2o`0003;ooooo0_l0001Looooo`;o00008?ooool2o`0003kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo087ooooo0_l0001cooooo`;o00001Oooool2o`0001Kooooo0_l0000Z
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Wooooo0_l00014ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000Fooooo`;o0000:_ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Z_ooool2o`00
04Cooooo0_l0001@ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo01Kooooo0_l0002`ooooo`;o0000Moooool002Cooooo00?o0000ooooooooool05_oo
ool2o`0000Sooooo0_l0002Vooooo`;o0000Moooool002Cooooo00?o0000ooooooooool08?ooool2
o`000:oooooo0_l0001^ooooo`009?ooool00ol0003oooooooooo`0jooooo`;o00006oooool2o`00
063ooooo0_l0000Fooooo`;o0000K_ooool002Cooooo0_l0000kooooo`;o00006oooool2o`00063o
oooo0_l0000jooooo`;o0000B_ooool002Cooooo00?o0000ooooooooool0W_ooool2o`0003Sooooo
0_l0000Kooooo`;o0000;oooool2o`0001Wooooo000Tooooo`03o`000?oooooooooo053ooooo0_l0
001<ooooo`;o0000>?ooool2o`0004cooooo0_l0000Iooooo`009?ooool00ol0003oooooooooo`1@
ooooo`;o0000:Oooool2o`000<Cooooo000Tooooo`03o`000?oooooooooo04;ooooo0_l0000goooo
o`;o0000a?ooool002Cooooo0_l00013ooooo`;o0000oOooool002Cooooo00?o0000ooooooooool0
R_ooool2o`0009Oooooo0_l0000Looooo`009?ooool00ol0003oooooooooo`2:ooooo`;o0000Uooo
ool2o`0001cooooo000Tooooo`03o`000?oooooooooo037ooooo0_l0001Wooooo`;o00004_ooool2
o`00097ooooo000Tooooo`03o`000?oooooooooo037ooooo0_l0001Wooooo`;o00004_ooool2o`00
07Gooooo0_l0000Jooooo`009?ooool2o`0001_ooooo0_l00013ooooo`;o00009_ooool2o`0003Wo
oooo0_l0001Qooooo`;o00006_ooool002Cooooo00?o0000ooooooooool06_ooool2o`0004?ooooo
0_l0000Vooooo`;o0000>Oooool2o`0007gooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06go
oooo0_l0001>ooooo`;o0000P_ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06gooooo0_l0001>ooooo`;o
00005Oooool2o`0006_ooooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06kooooo0_l0001Tooooo`;o0000Joooool000Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001^ooooo`;o
00005?ooool2o`000;_ooooo0009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0N?ooool2o`0000[ooooo0_l0002koooo
o`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`;o0000LOooool2o`000<Oooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l0001Goooo
o`;o000000?oooooo`000?l00000g_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l00000Eoooool2o`00
04Sooooo0_l00003ooooo`;o0000=_ooool002Cooooo0_l0002kooooo`;o00004_ooool2o`0003Co
oooo0_l00003ooooo`;o0000=_ooool002Cooooo00?o0000ooooooooool0=Oooool2o`0009Oooooo
0_l0001aooooo`009?ooool00ol0003oooooooooo`0eooooo`;o00007oooool2o`000>Wooooo000T
ooooo`03o`000?oooooooooo05Kooooo0_l0002Booooo`;o0000EOooool002Cooooo00?o0000oooo
ooooool0j_ooool2o`0005Gooooo000Tooooo`;o0000/oooool2o`0000Sooooo0_l0001>ooooo`;o
0000<oooool002Cooooo00?o0000ooooooooool0/_ooool2o`0000Sooooo0_l0001>ooooo`;o0000
<oooool002Cooooo00?o0000ooooooooool0loooool2o`0004cooooo000Tooooo`03o`000?oooooo
oooo0??ooooo0_l00009ooooo`;o00006_ooool2o`0002Gooooo000Tooooo`03o`000?oooooooooo
02oooooo0_l000000ooooooo0000o`00001aooooo`;o0000Eoooool2o`0001[ooooo0_l0000Uoooo
o`009?ooool2o`00033ooooo0_l000000ooooooo0000o`00001aooooo`;o00002_ooool2o`0008ko
oooo000Tooooo`03o`000?oooooooooo0;7ooooo0_l0002>ooooo`009?ooool00ol0003ooooooooo
o`3hooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool07_ooool2o`0001gooooo0_l00004
ooooo`;o0000/oooool2o`0000Wooooo0_l0000Cooooo`;o00009oooool002Cooooo00?o0000oooo
ooooool03?ooool2o`00013ooooo0_l0000Mooooo`;o00001?ooool2o`0005Kooooo0_l0001Voooo
o`;o00004oooool2o`0002Oooooo000Tooooo`;o00001Oooool2o`0000Kooooo0_l0002=ooooo`;o
0000Aoooool2o`0005_ooooo000Tooooo`03o`000?oooooooooo00Cooooo0_l0001Qooooo`;o0000
;_ooool2o`0004_ooooo0_l0001Kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`1Aooooo`;o00005?ooool2o`0002kooooo0_l0002Xooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool08Oooool2o`0002kooooo0_l0001Cooooo`;o0000VOooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool2o`0008?ooooo0_l0001Roooo
o`;o0000=Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooo`_ooooo0_l0000eooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04_ooooo0_l0003dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0Boooool2o`000?Cooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo00;ooooo0_l0003oooooockooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0
003oooooockooooo000Tooooo`03o`000?oooooooooo02Wooooo0_l0003ooooooaOooooo000Toooo
o`;o0000:_ooool2o`000?oooooo5oooool002Cooooo00?o0000ooooooooool0ioooool2o`0005So
oooo000Tooooo`03o`000?oooooooooo0>Oooooo0_l0001Hooooo`009?ooool00ol0003ooooooooo
o`07ooooo`;o0000ooooooliooooo`009?ooool00ol0003oooooooooo`07ooooo`;o0000ooooooli
ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0Loooool2o`0003?o
oooo0_l0002Gooooo`009?ooool00ol0003oooooooooo`1cooooo`;o0000<oooool2o`0009Oooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
6_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0b_ooool2o`0007Gooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool2o`00043ooooo0_l0
001Hooooo`;o0000H?ooool2o`0001?ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;_ooool2o`00043ooooo0_l0002jooooo`;o00004oooool001cooooo00?o0000oooo
ooooool01Oooool3o`000?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_oo
ool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooob?ooooo0_l0000M
ooooo`009?ooool2o`000?oooooo9?ooool2o`0001gooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
8oooool2o`000?oooooo7Oooool002Cooooo00?o0000ooooooooool08oooool2o`000?oooooo7Ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1Iooooo`;o0000
i_ooool002Cooooo00?o0000ooooooooool0FOooool2o`000>Kooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo05Co
oooo0_l0003[ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0E?ooool2o`00023o
oooo0_l00039ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1fooooo`;o
0000bOooool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0h_ooool2o`0005gooooo0004ooooo`03o`000?oo
oooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000h_oo
ool2o`0004[ooooo0_l0000Aooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo;ooo
ool2o`00017ooooo0004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooooa;ooooo0_l0000^ooooo`000_ooool00omEEEGoIVIVo`00000<oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooolB
ooooo`;o0000;_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0@?ooool2o`000?oooooo000Tooooo`03o`000?oo
oooooooo043ooooo0_l0003oooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0B?ooool2o`000?Oooooo000T
ooooo`03o`000?oooooooooo04Sooooo0_l0003gooooo`009?ooool2o`000?oooooo@oooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`0002Sooooo0_l0003ooooooaWooooo000Tooooo`03o`000?oooooooooo02Oo
oooo0_l0003ooooooaWooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo
00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMg
oc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2oooo
o`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`33ooooo`;o0000O?ooool002Cooooo0_l00034ooooo`;o0000O?ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1eooooo`;o0000b_ooool002Co
oooo00?o0000ooooooooool0L_ooool2o`000003ooooool0003o00000<[ooooo000Tooooo`03o`00
0?oooooooooo07;ooooo0_l0003=ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000Co
oooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo00?o
0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`09ooooo`;o0000oooooolgooooo`001?ooool00ol0003ooooooooo
o`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`;o0000oooooolgooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0;Oo
oooo0_l00028ooooo`009?ooool00ol0003oooooooooo`2gooooo`;o0000R?ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0Ooooool2o`000<3ooooo000T
ooooo`03o`000?oooooooooo07oooooo0_l0000<ooooo`;o0000/_ooool002Cooooo0_l0002>oooo
o`;o0000/_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`000?oooooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:oooo
o`007Oooool00ol0003oooooooooo`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@
4100oooooom;ooooo`006Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .15569 Mdot
.03333 .06262 Mdot
.0381 .03724 Mdot
.04286 .06965 Mdot
.04762 .10719 Mdot
.05238 .17488 Mdot
.05714 .05951 Mdot
.06667 .00936 Mdot
.07143 .12457 Mdot
.07619 .02382 Mdot
.08095 .09392 Mdot
.08571 .04589 Mdot
.09048 .00207 Mdot
.09524 .04043 Mdot
.1 .0555 Mdot
.10476 .17948 Mdot
.10952 .07367 Mdot
.11429 .01867 Mdot
.11905 .04662 Mdot
.12381 .0294 Mdot
.12857 .17628 Mdot
.13333 .0787 Mdot
.1381 .50789 Mdot
.14286 .10505 Mdot
.14762 .09514 Mdot
.15238 .01068 Mdot
.1619 .23485 Mdot
.16667 .02984 Mdot
.17143 .12674 Mdot
.17619 .2083 Mdot
.18095 .03167 Mdot
.18571 .04258 Mdot
.19048 .37428 Mdot
.19524 .04989 Mdot
.2 .01972 Mdot
.20476 .0326 Mdot
.20952 .0498 Mdot
.21429 .01302 Mdot
.21905 .08346 Mdot
.22381 .08294 Mdot
.22857 .19653 Mdot
.23333 .48749 Mdot
.2381 .0249 Mdot
.24286 .06088 Mdot
.24762 .00446 Mdot
.25238 .00546 Mdot
.2619 .04919 Mdot
.26667 .08018 Mdot
.27143 .07911 Mdot
.27619 .03099 Mdot
.28095 .15925 Mdot
.28571 .14869 Mdot
.29048 .0007 Mdot
.29524 .45035 Mdot
.3 .11336 Mdot
.30476 .1276 Mdot
.30952 .5093 Mdot
.31429 .04795 Mdot
.31905 .02805 Mdot
.32381 .32176 Mdot
.32857 .08085 Mdot
.33333 .16531 Mdot
.3381 .18113 Mdot
.34286 .04225 Mdot
.34762 .07498 Mdot
.35238 .55941 Mdot
.35714 .34364 Mdot
.3619 .00193 Mdot
.36667 .03228 Mdot
.37143 .19299 Mdot
.37619 .30624 Mdot
.38095 .0998 Mdot
.38571 .45424 Mdot
.39048 .1787 Mdot
.39524 .41689 Mdot
.4 .52947 Mdot
.40476 .14341 Mdot
.40952 .03737 Mdot
.41429 .26731 Mdot
.41905 .02577 Mdot
.42857 .36173 Mdot
.43333 .08227 Mdot
.4381 .24037 Mdot
.44286 .15544 Mdot
.45238 .08312 Mdot
.45714 .04291 Mdot
.4619 .20775 Mdot
.46667 .05032 Mdot
.47619 .07973 Mdot
.48095 .05973 Mdot
.48571 .04741 Mdot
.49048 .00491 Mdot
.49524 .2114 Mdot
.5 .14554 Mdot
.50476 .04749 Mdot
.50952 .26558 Mdot
.51429 .00048 Mdot
.51905 .01881 Mdot
.52381 .11292 Mdot
.52857 .04893 Mdot
.53333 .02507 Mdot
.5381 .0427 Mdot
.54286 .00617 Mdot
.54762 .10787 Mdot
.55238 .31235 Mdot
.55714 .06905 Mdot
.5619 .01425 Mdot
.56667 .09867 Mdot
.57143 .13633 Mdot
.57619 .16798 Mdot
.58095 .01611 Mdot
.58571 .18603 Mdot
.59048 .07959 Mdot
.59524 .05426 Mdot
.6 .51403 Mdot
.60476 .11525 Mdot
.60952 .06712 Mdot
.61429 .34748 Mdot
.61905 .24754 Mdot
.62381 .1775 Mdot
.62857 .5437 Mdot
.63333 .01175 Mdot
.6381 .39337 Mdot
.64286 .01706 Mdot
.64762 .01534 Mdot
.65238 .15227 Mdot
.65714 .05042 Mdot
.6619 .02587 Mdot
.66667 .07108 Mdot
.67143 .13029 Mdot
.67619 .16159 Mdot
.68095 .04539 Mdot
.68571 .02219 Mdot
.69048 .11639 Mdot
.69524 .09671 Mdot
.7 .02149 Mdot
.70476 .07178 Mdot
.70952 .06385 Mdot
.71429 .03297 Mdot
.71905 .05516 Mdot
.72381 .09362 Mdot
.72857 .07875 Mdot
.73333 .46947 Mdot
.7381 .08112 Mdot
.74286 .30425 Mdot
.74762 .33555 Mdot
.75238 .02364 Mdot
.75714 .04016 Mdot
.7619 .03893 Mdot
.76667 .14109 Mdot
.77143 .08831 Mdot
.77619 .01839 Mdot
.78095 .01646 Mdot
.78571 .12076 Mdot
.79048 .1803 Mdot
.79524 .06994 Mdot
.8 .20846 Mdot
.80476 .01584 Mdot
.80952 .01266 Mdot
.81429 .0865 Mdot
.81905 .14533 Mdot
.82381 .01014 Mdot
.82857 .32169 Mdot
.83333 .12341 Mdot
.8381 .1449 Mdot
.84286 .04467 Mdot
.84762 .0046 Mdot
.85238 .07766 Mdot
.85714 .00986 Mdot
.8619 .04162 Mdot
.86667 .01571 Mdot
.87143 .03508 Mdot
.87619 .31087 Mdot
.88095 .06918 Mdot
.88571 .02336 Mdot
.89048 .0724 Mdot
.89524 .04535 Mdot
.9 .34443 Mdot
.90476 .05734 Mdot
.90952 .06476 Mdot
.91429 .02819 Mdot
.91905 .01159 Mdot
.92381 .00663 Mdot
.92857 .55967 Mdot
.93333 .13146 Mdot
.9381 .13746 Mdot
.94286 .00148 Mdot
.94762 .16709 Mdot
.95238 .12739 Mdot
.95714 .00638 Mdot
.9619 .38746 Mdot
.96667 .30693 Mdot
.97143 .1628 Mdot
.97619 .17987 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0<ooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool03?ooool002Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool3o`0000;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`?o00003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000ooooo`0<ooooo`?o
00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_l0000:ooooo`03o`000?oooooooooo00[ooooo0ol00003ooooo`;o00000oooool2o`0000Go
oooo00?o0000ooooooooool03?ooool002Cooooo00?o0000ooooooooool02_ooool2o`0003Wooooo
0ol0001<ooooo`;o00003oooool2o`0005Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000Wooooo0_l0000Dooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o00006_oo
ool2o`0001;ooooo0_l00026ooooo`;o0000=oooool2o`0000?ooooo0_l00008ooooo`;o00004ooo
ool2o`00023ooooo000Tooooo`;o00009oooool2o`0001;ooooo0_l0001_ooooo`;o00001?ooool2
o`0000oooooo0_l00003ooooo`;o0000<?ooool4o`00017ooooo0_l0000?ooooo`;o00008?ooool0
02Cooooo00?o0000ooooooooool06_ooool2o`00087ooooo0_l0000<ooooo`;o00001?ooool2o`00
01;ooooo1?l0000Wooooo`Co00001Oooool2o`0001?ooooo0_l0000aooooo`009?ooool00ol0003o
ooooooooo`0Jooooo`;o00006Oooool2o`0006Kooooo0_l0000Vooooo`;o00003?ooool2o`0000?o
oooo0_l0000Fooooo`Co0000COooool002Cooooo00?o0000ooooooooool03Oooool2o`0002Kooooo
0_l0000;ooooo`;o0000GOooool2o`00033ooooo0_l00003ooooo`;o00003oooool2o`0002Wooooo
0_l0000[ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o0000<oooool2o`0001Sooooo0_l0
000Nooooo`;o00008oooool2o`0002Sooooo0_l0000Looooo`;o0000:Oooool2o`0000Oooooo0_l0
000Rooooo`009?ooool2o`0001kooooo0_l0000<ooooo`;o00000_ooool2o`0001gooooo0_l0000<
ooooo`;o00007_ooool2o`0004gooooo0_l0001@ooooo`;o00008_ooool002Cooooo00?o0000oooo
ooooool07Oooool2o`0000cooooo0_l00002ooooo`;o00001_ooool2o`0001Gooooo0_l0000Koooo
o`;o0000Koooool2o`0006?ooooo000Tooooo`04o`000?ooooooooooooooo`;o0000=?ooool2o`00
03;ooooo0_l0000<ooooo`;o0000HOooool2o`00037ooooo0_l0000`ooooo`009?ooool01?l0003o
ooooooooooooool2o`00013ooooo0_l0001Tooooo`;o0000Koooool4o`00027ooooo0_l0000`oooo
o`009?ooool00ol0003oooooooooo`0Cooooo`;o00007?ooool2o`00037ooooo0_l0000Sooooo`;o
00006?ooool2o`0004Gooooo1?l0000Nooooo`;o0000<oooool002Cooooo0_l0000Aooooo`;o0000
2Oooool2o`0001Cooooo0_l0000aooooo`;o00008oooool2o`0001Sooooo0_l0000/ooooo`;o0000
<oooool2o`0000Cooooo0_l00009ooooo`;o0000:?ooool002Cooooo00?o0000ooooooooool04?oo
ool2o`0000Wooooo0_l0000Gooooo`;o00000_ooool2o`0000oooooo0_l0000?ooooo`;o0000<?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0002oooooo0_l0000cooooo`;o00003ooo
ool2o`0002Sooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00003oooool2
o`0000oooooo0_l0000`ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o0000:?ooool2
o`0007Gooooo000Tooooo`03o`000?oooooooooo01Gooooo0_l0002Oooooo`;o00004_ooool2o`00
01;ooooo0_l0001Qooooo`009?ooool00ol0003oooooooooo`07ooooo`;o00003?ooool2o`0009oo
oooo0_l0000Vooooo`;o0000>_ooool2o`0002Gooooo000Tooooo`Co00001_ooool2o`0003[ooooo
0_l0001;ooooo`;o0000R?ooool2o`0002Gooooo000Tooooo`04o`000?oooooo0000o`0004;ooooo
0_l0001;ooooo`;o0000BOooool2o`0003kooooo0_l0000Tooooo`009?ooool00ol0003ooooooooo
o`2jooooo`;o00007oooool2o`0003kooooo0_l0000Tooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo00;ooooo0_l0002Uooooo`;o00003oooool2o`00017ooooo0_l0000:ooooo`;o
00006oooool2o`0001[ooooo0_l0000]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`02ooooo`;o00005?ooool2o`0004_ooooo0_l00012ooooo`;o00008_ooool2
o`0000[ooooo0_l0000Kooooo`;o00006_ooool2o`000003ooooool0003o000002[ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`?o00006?ooool2o`0004_ooooo0_l0002Rooooo`;o00002_ooool2o`00
02[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo023ooooo0_l0000Yooooo`Co
00004?ooool2o`0002kooooo0_l0000Sooooo`;o0000:oooool2o`000003ooooool0003o000002?o
oooo0_l0000fooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo023o
oooo0_l0000Jooooo`?o00003?ooool4o`00013ooooo0_l0000Pooooo`;o00001?ooool2o`0000Ko
oooo0_l0000Sooooo`;o0000:oooool2o`000003ooooool0003o000005_ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03cooooo0ol00012ooooo`;o00001?ooool2o`0007Cooooo
0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>oooooo0_l0000<oooo
o`;o0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000l?ooool2o`00053ooooo000Tooooo`03o`000?oooooo
oooo00oooooo0_l0000Cooooo`;o0000^Oooool2o`00063ooooo000Tooooo`03o`000?oooooooooo
00oooooo0_l0000Cooooo`;o0000Q_ooool2o`0002Sooooo0_l00007ooooo`;o0000H?ooool002Co
oooo00?o0000ooooooooool0L?ooool2o`0003[ooooo0_l0000Xooooo`;o0000JOooool002Cooooo
00?o0000ooooooooool08oooool2o`0004_ooooo0_l0003?ooooo`009?ooool00ol0003ooooooooo
o`04ooooo`;o00007Oooool2o`00087ooooo0_l0002Iooooo`009?ooool2o`0000Gooooo0_l0002P
ooooo`;o0000VOooool002Cooooo00?o0000ooooooooool0E_ooool2o`0004Kooooo0_l0002Qoooo
o`009?ooool00ol0003oooooooooo`1Fooooo`;o0000A_ooool2o`0001Wooooo0_l0000Iooooo`;o
0000Joooool002Cooooo00?o0000ooooooooool0^Oooool2o`0001Wooooo0_l0000Mooooo`;o0000
C?ooool002Cooooo00?o0000ooooooooool0loooool2o`0000kooooo0_l0000looooo`009?ooool2
o`0000gooooo0_l0000Nooooo`;o0000eOooool2o`0002Cooooo0_l0000Fooooo`009?ooool00ol0
003oooooooooo`0<ooooo`;o00007_ooool2o`0002Wooooo0_l0001eooooo`;o0000FOooool2o`00
01Kooooo000Tooooo`03o`000?oooooooooo05Oooooo0_l0001eooooo`;o0000Doooool2o`0001co
oooo000Tooooo`03o`000?oooooooooo0:kooooo0_l0001cooooo`;o00007?ooool002Cooooo00?o
0000ooooooooool0[_ooool2o`0007Gooooo0_l0000Jooooo`009?ooool2o`000>kooooo0_l0000f
ooooo`;o00006_ooool002Cooooo00?o0000ooooooooool0N?ooool2o`0001gooooo0_l0001Doooo
o`;o00003oooool2o`0000Cooooo0_l0000kooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1A
ooooo`;o00009Oooool2o`0001gooooo0_l0001Uooooo`;o00001?ooool2o`0003_ooooo0009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Aooooo`;o0000k_ooool000Wooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool2o`0007Oooooo0009oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000Q?ooool2
o`0004;ooooo0_l0001gooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`?o0000D?ooool2o`0003;ooooo0_l0002kooooo`002Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1@ooooo`;o0000O_ooool2o`0005kooooo0_l0000?ooooo`002Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`;o0000KOoo
ool2o`0005Kooooo0_l00006ooooo`;o00003oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1Qooooo`;o0000C?ooool2o`0007Oooooo0_l0
000Gooooo`009?ooool2o`000;3ooooo0_l0002@ooooo`009?ooool00ol0003oooooooooo`05oooo
o`;o00005oooool2o`000?oooooo8_ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000oo
oooo0_l00006ooooo`;o0000Doooool2o`0004[ooooo0_l00020ooooo`009?ooool00ol0003ooooo
ooooo`0Fooooo`;o0000B_ooool2o`0000oooooo0_l0001:ooooo`;o0000=?ooool2o`0003[ooooo
0_l0000>ooooo`009?ooool00ol0003oooooooooo`1Rooooo`;o0000TOooool2o`0003[ooooo0_l0
000>ooooo`009?ooool2o`000;?ooooo0_l0002=ooooo`009?ooool00ol0003oooooooooo`2boooo
o`;o0000SOooool002Cooooo00?o0000ooooooooool0KOooool2o`000=;ooooo000Tooooo`03o`00
0?oooooooooo03oooooo0_l0000/ooooo`;o0000d_ooool002Cooooo00?o0000ooooooooool0?ooo
ool2o`000?oooooo0Oooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0;_ooool2o`0005[ooooo0_l0001/ooooo`;o
0000Aoooool002Cooooo00?o0000ooooooooool0;_ooool2o`0005[ooooo0_l00009ooooo`;o0000
HOooool2o`0004Oooooo000Tooooo`03o`000?oooooooooo09Gooooo0_l0002Zooooo`009?ooool2
o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood;ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3ooooood;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Yooooo`;o0000oooooolG
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Wooooo0_l0003o
oooooaOooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08?ooooo0_l0002loooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08?ooooo0_l0002looooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
_Oooool2o`0008;ooooo000Tooooo`;o0000__ooool2o`0008;ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
002Kooooo`;o0000YOooool002Cooooo00?o0000ooooooooool0Noooool2o`0001gooooo0_l0002U
ooooo`009?ooool00ol0003oooooooooo`1kooooo`;o0000a?ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0iOooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K_ooool2o`0007Gooooo
0_l00017ooooo`;o00004Oooool001cooooo00?o0000ooooooooool01Oooool3o`0006kooooo0_l0
000hooooo`;o0000Ioooool2o`0001_ooooo0_l0000Aooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:Sooooo0_l0001Wooooo`;o0000;_ooool001cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo05kooooo0_l0002Qooooo`;o0000?_ooool002Cooooo0_l0001Oooooo`;o0000XOoo
ool2o`0003kooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3Wooooo`;o0000F?ooool002Cooooo
00?o0000ooooooooool0ioooool2o`0005Sooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`1Xooooo`;o0000[_ooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo
06Sooooo0_l0001Booooo`;o0000F_ooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo0;co
oooo0_l00023ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`1oooooo`;o0000`?ooool002Cooooo00?o0000oooo
ooooool0Ooooool2o`000<3ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0<_ooool2o`000?oooooo3_ooool000;ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo03;ooooo0_l0003oooooo`kooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003o
ooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo;Oooool2o`0001?ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0ooooool]ooooo`;o
00004oooool000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0`oooool2o`0007cooooo0004ooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0`oooool2o`0007cooooo0002ooooo`03oeEEEOmVIVKo000000cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool00ol0003oooooooooo`1eooooo`;o0000b_ooool002Cooooo0_l0001fooooo`;o0000b_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`0005Gooooo0_l0
003[ooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o0000joooool000[ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0L_ooool2o`000<gooooo000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0L_ooool2o`000<gooooo000<ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;o
oooo000<ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo
@_ooool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0h_ooool2o`0005gooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3Rooooo`;o0000GOooool000cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`10ooooo`;o0000ooooool002Cooooo00?o0000ooooooooool0@?ooool2
o`000?oooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
027ooooo0_l0000fooooo`;o0000i_ooool002Cooooo0_l0000Rooooo`;o0000=_ooool2o`000>Ko
oooo000Tooooo`03o`000?oooooooooo0;Oooooo0_l00028ooooo`009?ooool00ol0003ooooooooo
o`2gooooo`;o0000R?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooo
ooooo`1fooooo`;o0000bOooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`1fooooo`;o0000bOooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0=oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Co
oooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`30ooooo`;o0000Ooooool000Cooooo00?o0000oooooooo
ool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0`?ooool2o`0007oooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`00
0_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0Ioooool2
o`000;Wooooo0_l0000Mooooo`009?ooool00ol0003oooooooooo`1Wooooo`;o0000^Oooool2o`00
01gooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h0
1_ooool3o`000?oooooo@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool0
0ol0003oooooooooo`3oooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;
ooooo`006Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .15569 Mdot
.03333 .06262 Mdot
.0381 .03724 Mdot
.04286 .12524 Mdot
.04762 .07473 Mdot
.05238 .0178 Mdot
.05714 .05951 Mdot
.0619 .54952 Mdot
.06667 .09546 Mdot
.07143 .34866 Mdot
.07619 .02382 Mdot
.08095 .10848 Mdot
.08571 .04589 Mdot
.09048 .00207 Mdot
.09524 .04043 Mdot
.1 .0555 Mdot
.10476 .08439 Mdot
.10952 .04495 Mdot
.11429 .01867 Mdot
.11905 .04585 Mdot
.12381 .0294 Mdot
.12857 .38131 Mdot
.13333 .28025 Mdot
.1381 .44801 Mdot
.14286 .20769 Mdot
.14762 .07302 Mdot
.15238 .01068 Mdot
.15714 .42783 Mdot
.1619 .32187 Mdot
.16667 .02984 Mdot
.17143 .27166 Mdot
.17619 .25086 Mdot
.18095 .03167 Mdot
.18571 .04258 Mdot
.19048 .30706 Mdot
.19524 .05514 Mdot
.2 .01253 Mdot
.20476 .0326 Mdot
.20952 .0498 Mdot
.21429 .01302 Mdot
.21905 .02298 Mdot
.22381 .08294 Mdot
.22857 .08756 Mdot
.23333 .28724 Mdot
.2381 .09075 Mdot
.24286 .06088 Mdot
.24762 .10372 Mdot
.25238 .00546 Mdot
.25714 .4659 Mdot
.2619 .21725 Mdot
.26667 .32986 Mdot
.27143 .07911 Mdot
.27619 .02748 Mdot
.28095 .03422 Mdot
.28571 .28723 Mdot
.29048 .0007 Mdot
.29524 .51013 Mdot
.3 .20881 Mdot
.30476 .1707 Mdot
.30952 .40516 Mdot
.31429 .01138 Mdot
.31905 .20382 Mdot
.32381 .46206 Mdot
.32857 .08085 Mdot
.33333 .40325 Mdot
.3381 .1455 Mdot
.34286 .04225 Mdot
.34762 .04356 Mdot
.35238 .11428 Mdot
.35714 .3213 Mdot
.3619 .00193 Mdot
.36667 .03228 Mdot
.37143 .19299 Mdot
.37619 .35951 Mdot
.38095 .0998 Mdot
.38571 .5353 Mdot
.39048 .01341 Mdot
.39524 .49037 Mdot
.4 .57717 Mdot
.40476 .10976 Mdot
.40952 .03737 Mdot
.41429 .12365 Mdot
.41905 .20787 Mdot
.42857 .3804 Mdot
.43333 .08227 Mdot
.4381 .14031 Mdot
.44286 .24032 Mdot
.45238 .08312 Mdot
.45714 .04291 Mdot
.4619 .0934 Mdot
.46667 .07346 Mdot
.47619 .01099 Mdot
.48095 .08733 Mdot
.48571 .15118 Mdot
.49048 .09176 Mdot
.49524 .36175 Mdot
.5 .07471 Mdot
.50476 .04749 Mdot
.50952 .07265 Mdot
.51429 .00048 Mdot
.51905 .07016 Mdot
.52381 .01956 Mdot
.52857 .00302 Mdot
.53333 .02507 Mdot
.5381 .0427 Mdot
.54286 .00617 Mdot
.54762 .16081 Mdot
.55238 .20161 Mdot
.55714 .06905 Mdot
.5619 .00234 Mdot
.56667 .13769 Mdot
.57143 .00499 Mdot
.57619 .11863 Mdot
.58095 .01015 Mdot
.58571 .16412 Mdot
.59048 .07959 Mdot
.59524 .10261 Mdot
.6 .45726 Mdot
.60476 .06006 Mdot
.60952 .24371 Mdot
.61429 .34728 Mdot
.61905 .0399 Mdot
.62381 .1775 Mdot
.62857 .29897 Mdot
.63333 .01175 Mdot
.6381 .4947 Mdot
.64286 .01706 Mdot
.64762 .01534 Mdot
.65238 .00787 Mdot
.65714 .11588 Mdot
.6619 .12114 Mdot
.66667 .07129 Mdot
.67143 .07433 Mdot
.67619 .13012 Mdot
.68095 .05697 Mdot
.68571 .02219 Mdot
.69048 .03492 Mdot
.69524 .05081 Mdot
.7 .01231 Mdot
.70476 .03918 Mdot
.70952 .06385 Mdot
.71429 .03297 Mdot
.71905 .04643 Mdot
.72381 .03072 Mdot
.72857 .04127 Mdot
.73333 .37634 Mdot
.7381 .14197 Mdot
.74286 .52144 Mdot
.74762 .25959 Mdot
.75238 .02364 Mdot
.75714 .13601 Mdot
.7619 .22263 Mdot
.76667 .17615 Mdot
.77143 .14801 Mdot
.77619 .02589 Mdot
.78095 .0066 Mdot
.78571 .12076 Mdot
.79048 .06682 Mdot
.79524 .11873 Mdot
.8 .04359 Mdot
.80476 .00992 Mdot
.80952 .19203 Mdot
.81429 .18856 Mdot
.81905 .14533 Mdot
.82381 .12289 Mdot
.82857 .27303 Mdot
.83333 .12341 Mdot
.8381 .05978 Mdot
.84286 .05023 Mdot
.84762 .10099 Mdot
.85238 .07766 Mdot
.85714 .13503 Mdot
.8619 .05381 Mdot
.86667 .01571 Mdot
.87143 .03508 Mdot
.87619 .2963 Mdot
.88095 .1191 Mdot
.88571 .02336 Mdot
.89048 .0724 Mdot
.89524 .076 Mdot
.9 .12523 Mdot
.90476 .05734 Mdot
.90952 .25657 Mdot
.91429 .00532 Mdot
.91905 .01159 Mdot
.92381 .16351 Mdot
.92857 .20875 Mdot
.93333 .16656 Mdot
.9381 .13746 Mdot
.94286 .02994 Mdot
.94762 .18209 Mdot
.95238 .14208 Mdot
.95714 .00247 Mdot
.9619 .38746 Mdot
.96667 .19584 Mdot
.97143 .11507 Mdot
.97619 .10422 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0<ooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00Co0000oooooooooooooooo0_l00003ooooo`;o00001Oooool01?l0003oooooooooooooool2o`00
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0
003oooooooooo`0<ooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo0_l00008ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`06ooooo`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo0ol0000?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool2o`0000?ooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000oooooooo
ool03?ooool002Cooooo00?o0000ooooooooool0A_ooool2o`0005gooooo0_l00007ooooo`;o0000
00?oooooo`000?l000005Oooool2o`0002Sooooo0_l00005ooooo`;o00008_ooool2o`0002;ooooo
000Tooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`;o00000oooool2o`0001kooooo0_l0
000cooooo`;o00008?ooool2o`0000oooooo0_l00004ooooo`;o00003_ooool2o`0001oooooo0_l0
000Tooooo`;o00008?ooool002Cooooo0_l0000Wooooo`;o00003Oooool2o`0000?ooooo0_l0000N
ooooo`;o00005oooool2o`0001[ooooo0_l0000aooooo`;o00000oooool2o`0000oooooo0_l0000d
ooooo`;o00003oooool2o`00023ooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0000Coooo
o`;o0000Eoooool2o`00053ooooo1?l00015ooooo`;o0000<Oooool002Cooooo00?o0000oooooooo
ool01Oooool2o`0001?ooooo0_l00022ooooo`;o00009Oooool2o`0000cooooo0_l0001/ooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`;o0000;Oooool2o`00063ooooo0_l000000ooooooo0000
o`00000`ooooo`;o00005?ooool2o`0002Wooooo0_l0000[ooooo`009?ooool00ol0003ooooooooo
o`0=ooooo`;o0000;Oooool2o`00013ooooo0_l0001Aooooo`;o0000A_ooool2o`0000Gooooo0_l0
000Rooooo`;o0000:oooool002Cooooo0_l0000Nooooo`;o00003?ooool2o`0000;ooooo0_l0000M
ooooo`;o0000Soooool2o`0000oooooo0_l0000dooooo`;o00006Oooool002Cooooo00?o0000oooo
ooooool07Oooool2o`0000cooooo0_l00002ooooo`;o00001_ooool2o`0001Oooooo0_l0000Ioooo
o`;o0000Koooool2o`000003ooooool0003o000004Gooooo0_l0000Iooooo`009?ooool01?l0003o
ooooooooooooool2o`0003Cooooo0_l0000Gooooo`;o00006Oooool2o`0000cooooo0_l0001Ioooo
o`;o00001_ooool2o`00037ooooo0_l0000`ooooo`009?ooool01?l0003oooooooooooooool2o`00
013ooooo0_l0001Tooooo`;o0000@_ooool2o`0001Gooooo0_l00003ooooo`;o0000=?ooool2o`00
033ooooo000Tooooo`03o`000?oooooooooo01?ooooo0_l0000Looooo`;o0000<Oooool3o`0002;o
oooo0_l0000Hooooo`;o00006?ooool2o`0001[ooooo0_l00006ooooo`;o00005Oooool2o`0004Oo
oooo000Tooooo`;o00004Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
<Oooool3o`0002;ooooo0_l0000Hooooo`;o0000>Oooool2o`000003ooooool0003o000001Gooooo
0_l00017ooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o00001_ooool2o`000003ooooool0
003o000001_ooooo0_l0001Nooooo`;o0000A?ooool2o`0002Kooooo0_l0000iooooo`009?ooool0
0ol0003oooooooooo`0hooooo`;o0000G_ooool2o`0003cooooo0_l0000^ooooo`;o0000>Oooool0
02Cooooo00?o0000ooooooooool05Oooool2o`0001gooooo0_l0002Pooooo`;o0000=?ooool2o`00
03?ooooo000Tooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o00007Oooool2o`0009_o
oooo0_l0000iooooo`;o00003?ooool2o`0002Gooooo000Tooooo`Co00001_ooool2o`0003[ooooo
0_l0001dooooo`;o00005_ooool2o`00037ooooo0_l0000Dooooo`;o00009Oooool002Cooooo00Co
0000ooooool0003o0000@_ooool2o`0007Cooooo0_l0000Pooooo`;o00009oooool2o`0003_ooooo
000Tooooo`03o`000?oooooooooo0=_ooooo0_l0000Hooooo`;o0000B_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2Mooooo`;o00002_ooool2o`0002;ooooo0_l0000Vooooo`;o
0000B_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool2
o`0001kooooo0_l0001Vooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00002_oo
ool2o`0002;ooooo0ol00015ooooo`;o0000:_ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00004
ooooo`;o00007_ooool2o`0006Kooooo0_l00009ooooo`;o000000?oooooo`000?l00000<_ooool2
o`0003Wooooo0_l0000:ooooo`Co0000:?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0COooool2o`00013ooooo0_l0001Cooooo`;o0000Doooool2o`0000cooooo0_l0000Xoooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03gooooo0_l0000>oooo
o`;o00004?ooool2o`00023ooooo0_l00004ooooo`;o0000:oooool2o`0008_ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Kooooo0_l0000Uooooo`;o0000@_ooool2o`0000Co
oooo0_l0002hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo0_l0000W
ooooo`;o0000Coooool2o`000:oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00043ooooo0_l000000ooooooo0000
o`000016ooooo`;o00001?ooool2o`0000;ooooo0_l0002[ooooo`009?ooool00ol0003ooooooooo
o`0:ooooo`;o0000=_ooool2o`0004Kooooo0_l00008ooooo`;o0000Zoooool002Cooooo00?o0000
ooooooooool02_ooool2o`000?oooooo=_ooool002Cooooo00?o0000ooooooooool0L?ooool2o`00
04Cooooo0_l0001?ooooo`;o0000>?ooool002Cooooo00?o0000ooooooooool0AOooool2o`0002Wo
oooo0_l00014ooooo`;o0000Coooool2o`0002Sooooo0_l0000>ooooo`009?ooool00ol0003ooooo
ooooo`0?ooooo`;o0000=?ooool2o`000>[ooooo0_l0000>ooooo`009?ooool2o`00013ooooo0_l0
001Wooooo`;o0000aoooool002Cooooo00?o0000ooooooooool0Ioooool2o`0000oooooo0_l0002f
ooooo`;o00003oooool002Cooooo00?o0000ooooooooool0Ioooool2o`00067ooooo0_l0001Toooo
o`;o00003oooool002Cooooo00?o0000ooooooooool0[oooool2o`0001Wooooo0ol0000Vooooo`;o
000000?oooooo`000?l000006_ooool2o`0002gooooo000Tooooo`03o`000?oooooooooo07_ooooo
0_l0000booooo`;o00006_ooool2o`0002Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0002gooooo000Tooooo`;o00000oooool2o`0007Oooooo0_l0
0023ooooo`;o000000?oooooo`000?l000004oooool2o`0002Oooooo000Tooooo`03o`000?oooooo
oooo00;ooooo0_l0003<ooooo`;o0000A_ooool2o`0002Oooooo000Tooooo`03o`000?oooooooooo
0=3ooooo0_l0001_ooooo`009?ooool00ol0003oooooooooo`3Zooooo`;o00007_ooool2o`0003Go
oooo000Tooooo`03o`000?oooooooooo0:cooooo0_l0000looooo`;o00007_ooool2o`0001Wooooo
0_l0000Jooooo`009?ooool2o`0008Cooooo0_l0000Wooooo`;o0000=_ooool2o`0003oooooo0_l0
0002ooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0H_ooool2o`0001oooooo0_l0001O
ooooo`;o00006?ooool2o`0002Wooooo0_l0000Fooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`1Rooooo`;o0000Roooool2o`0000gooooo0_l00011ooooo`002Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0T_oo
ool2o`0005_ooooo0_l0001@ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Booooo`;o0000[Oooool000Wooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo0009
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
0ol0002Vooooo`;o0000VOooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Y_ooool2o`0000[ooooo0_l0001/ooooo`;o0000
7oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool2o`0006cooooo0_l000000ooooooo0000o`00000Looooo`002Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo
9?ooool2o`0001cooooo000Tooooo`;o0000F?ooool2o`000>Sooooo000Tooooo`03o`000?oooooo
oooo05Oooooo0_l0002Dooooo`;o0000D_ooool002Cooooo00?o0000ooooooooool0_oooool2o`00
02cooooo0_l0001Booooo`009?ooool00ol0003oooooooooo`2oooooo`;o0000Ioooool2o`0001Oo
oooo000Tooooo`03o`000?oooooooooo0?oooooo:Oooool2o`0001Oooooo000Tooooo`;o0000o_oo
ool2o`0004;ooooo000Tooooo`03o`000?oooooooooo0?_ooooo1?l00012ooooo`009?ooool00ol0
003oooooooooo`1]ooooo`;o0000S?ooool2o`0004Cooooo000Tooooo`03o`000?oooooooooo06go
oooo0_l0002oooooo`;o00004Oooool002Cooooo00?o0000ooooooooool0ooooool_ooooo`;o0000
4Oooool002Cooooo0_l0001Mooooo`;o0000B_ooool2o`0009Oooooo000Tooooo`03o`000?oooooo
oooo05cooooo0_l0001:ooooo`;o0000Uoooool002Cooooo00?o0000ooooooooool08oooool2o`00
037ooooo0_l0000Tooooo`;o0000Y?ooool2o`0001gooooo000Tooooo`03o`000?oooooooooo02?o
oooo0_l0000aooooo`;o00009?ooool2o`000:Cooooo0_l0000Mooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000B_ooool2o`000?Kooooo000Tooooo`03o`000?oooooo
oooo04Wooooo0_l0002Qooooo`;o0000Doooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0k?ooool2o`0005?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`24ooooo`;o0000^oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`24ooooo`;o0000=?ooool2o`0008Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2jooooo`;o0000QOooool002Cooooo
0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa;ooooo000T
ooooo`03o`000?oooooooooo02kooooo0_l0003[ooooo`;o00009?ooool002Cooooo00?o0000oooo
ooooool0ioooool2o`0003;ooooo0_l0000Tooooo`009?ooool00ol0003oooooooooo`3Wooooo`;o
0000F?ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0;?ooool2o`000?oooooo5?ooool002Cooooo00?o0000oooo
ooooool0;?ooool2o`000=?ooooo0_l0000nooooo`009?ooool00ol0003oooooooooo`3oooooo`;o
oooo0_l0000nooooo`009?ooool2o`00027ooooo0_l0003oooooob3ooooo000Tooooo`03o`000?oo
oooooooo023ooooo0_l0003oooooob3ooooo000Tooooo`03o`000?oooooooooo043ooooo0_l0000?
ooooo`;o0000k_ooool002Cooooo00?o0000ooooooooool0@?ooool2o`0000oooooo0_l0003^oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooolCooooo`;o0000
;_ooool002Cooooo00?o0000ooooooooool0`?ooool2o`0004oooooo0_l0000^ooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0`?ooool2o`0007oooooo000Loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`kooooo000Looooo`03o`00
0?oooooooooo00Gooooo0ol0000booooo`;o0000ooooool>ooooo`007?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0J?ooool2o`000=Oooooo000Jooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0:Oooool2o`0003gooooo0_l0003Gooooo`009?ooool2o`0002[ooooo0_l0003ooooooaOooooo
000Tooooo`03o`000?oooooooooo04_ooooo0_l0003dooooo`009?ooool00ol0003oooooooooo`1;
ooooo`;o0000m?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo00cooooo0_l0002^ooooo`;o0000Poooool0
02Cooooo00?o0000ooooooooool03?ooool2o`000:kooooo0_l00023ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`1^ooooo`;o0000dOooool002Cooooo00?o0000ooooooooool0K_ooool2o`0002Gooooo0_l0002Z
ooooo`009?ooool00ol0003oooooooooo`2Eooooo`;o0000Z_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0h_oo
ool2o`0005gooooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3Rooooo`;o0000GOoo
ool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07_ooool2o`0005oooooo0_l0
0030ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o0000Goooool2o`000<3ooooo0004oooo
o`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o0000ooooool]ooooo`;o00004oooool000Cooooo00?o0000ooooooooool03Oooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
obgooooo0_l0000Cooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`00
0?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`00
9?ooool2o`0006;ooooo0_l0003Nooooo`009?ooool00ol0003oooooooooo`1Iooooo`;o00001_oo
ool2o`000=kooooo000Tooooo`03o`000?oooooooooo05Wooooo0_l0003Vooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolIoooo
o`009?ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolIooooo`009?ooool2o`000?oooooo
@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool08Oooool2o`000?oooooo7oooool002Cooooo0_l0000Rooooo`;o0000oooooolOooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Oooooo0_l0
0028ooooo`003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;Oooooo0_l00028ooooo`003?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool2o`000>7ooooo000<ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`0004Sooooo0_l0000Dooooo`;o
0000hOooool000cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0B?ooool2o`000?Oooooo000<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000:
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1eooooo`;o0000b_oo
ool002Cooooo00?o0000ooooooooool0MOooool2o`000<[ooooo000Tooooo`;o0000a?ooool2o`00
07cooooo000Tooooo`03o`000?oooooooooo0<?ooooo0_l0001looooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`0005Gooooo0_l0003[ooooo`009?ooool00ol0003o
ooooooooo`1Dooooo`;o0000joooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3Uooooo`;o0000F_ooool002Cooooo00?o0000ooooooooool0iOooool2
o`0005[ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom2ooooo`00
1?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0L_ooool2o`000<gooooo0004ooooo`03o`000?oo
oooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo0_l0003=ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo00?o0000oooo
ooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l0003ooooo
ocOooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`000?oooooo=oooool000;o
oooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo
000Tooooo`03o`000?oooooooooo07Kooooo0_l00039ooooo`009?ooool00ol0003oooooooooo`1f
ooooo`;o0000bOooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000
oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Iooooo`Go00001_ooool0
0ol0003oooooooooo`3ooooood;ooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`3ooooood;ooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom2ooooo`00
7?ooool00omgMgOoIVIVooooo`3ooooood[ooooo000Mooooo`03o`000?oooooooooo0?ooooooBOoo
ool001Wooooo00Go0000okZj^_ooooooV9RHoa0@403ooooood_ooooo000Iooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .26874 Mdot
.03333 .06262 Mdot
.0381 .08797 Mdot
.04286 .10387 Mdot
.04762 .02964 Mdot
.05238 .0178 Mdot
.05714 .05951 Mdot
.0619 .54323 Mdot
.06667 .23836 Mdot
.07143 .39282 Mdot
.07619 .25024 Mdot
.08095 .32877 Mdot
.08571 .04589 Mdot
.09048 .00207 Mdot
.09524 .02376 Mdot
.1 .0555 Mdot
.10476 .11674 Mdot
.10952 .14156 Mdot
.11429 .09595 Mdot
.11905 .04585 Mdot
.12381 .0294 Mdot
.12857 .33309 Mdot
.13333 .25101 Mdot
.1381 .46672 Mdot
.14286 .19845 Mdot
.14762 .07302 Mdot
.15238 .02328 Mdot
.15714 .22547 Mdot
.1619 .17653 Mdot
.16667 .17304 Mdot
.17143 .44036 Mdot
.17619 .24744 Mdot
.18095 .03167 Mdot
.18571 .21223 Mdot
.19048 .06381 Mdot
.19524 .12107 Mdot
.2 .26897 Mdot
.20476 .01273 Mdot
.20952 .09183 Mdot
.21429 .01302 Mdot
.21905 .04843 Mdot
.22381 .13244 Mdot
.22857 .01244 Mdot
.23333 .3674 Mdot
.2381 .26951 Mdot
.24286 .1079 Mdot
.24762 .25803 Mdot
.25238 .00546 Mdot
.25714 .27693 Mdot
.2619 .06307 Mdot
.26667 .3682 Mdot
.27143 .16151 Mdot
.27619 .02748 Mdot
.28095 .17677 Mdot
.28571 .04552 Mdot
.29048 .06659 Mdot
.29524 .33127 Mdot
.3 .07971 Mdot
.30476 .28216 Mdot
.30952 .39152 Mdot
.31429 .01138 Mdot
.31905 .45143 Mdot
.32381 .22078 Mdot
.32857 .08085 Mdot
.33333 .21954 Mdot
.3381 .06778 Mdot
.34286 .09476 Mdot
.34762 .04356 Mdot
.35238 .11428 Mdot
.3619 .13805 Mdot
.36667 .03228 Mdot
.37143 .40206 Mdot
.37619 .18452 Mdot
.38095 .18568 Mdot
.38571 .43379 Mdot
.39048 .01341 Mdot
.4 .33923 Mdot
.40476 .27382 Mdot
.40952 .03737 Mdot
.41429 .02158 Mdot
.41905 .11052 Mdot
.42857 .289 Mdot
.43333 .04543 Mdot
.4381 .14031 Mdot
.44286 .14953 Mdot
.45238 .08312 Mdot
.45714 .23551 Mdot
.4619 .0934 Mdot
.46667 .2466 Mdot
.47143 .40198 Mdot
.47619 .22032 Mdot
.48095 .00327 Mdot
.48571 .07587 Mdot
.49048 .09176 Mdot
.49524 .45989 Mdot
.5 .07471 Mdot
.50476 .04749 Mdot
.50952 .2245 Mdot
.51429 .00873 Mdot
.51905 .07016 Mdot
.52381 .01956 Mdot
.52857 .00302 Mdot
.53333 .05761 Mdot
.5381 .0427 Mdot
.54286 .00617 Mdot
.54762 .03985 Mdot
.55238 .32659 Mdot
.55714 .00297 Mdot
.5619 .00234 Mdot
.56667 .13234 Mdot
.57143 .00499 Mdot
.57619 .11863 Mdot
.58095 .03559 Mdot
.58571 .06429 Mdot
.59048 .0021 Mdot
.59524 .01042 Mdot
.6 .48022 Mdot
.60476 .02161 Mdot
.60952 .24371 Mdot
.61429 .07416 Mdot
.61905 .0399 Mdot
.62381 .0217 Mdot
.62857 .26406 Mdot
.63333 .01175 Mdot
.6381 .48524 Mdot
.64286 .01706 Mdot
.64762 .08125 Mdot
.65238 .10911 Mdot
.65714 .06349 Mdot
.6619 .08495 Mdot
.66667 .06059 Mdot
.67143 .07433 Mdot
.67619 .13154 Mdot
.68095 .13238 Mdot
.68571 .02219 Mdot
.69048 .10899 Mdot
.69524 .11294 Mdot
.7 .01231 Mdot
.70476 .03918 Mdot
.70952 .06385 Mdot
.71429 .12761 Mdot
.71905 .07337 Mdot
.72381 .03072 Mdot
.72857 .2238 Mdot
.73333 .51412 Mdot
.7381 .14741 Mdot
.74286 .16082 Mdot
.74762 .18476 Mdot
.75238 .02364 Mdot
.75714 .27077 Mdot
.7619 .25767 Mdot
.76667 .41493 Mdot
.77143 .1521 Mdot
.77619 .02589 Mdot
.78095 .0066 Mdot
.78571 .24379 Mdot
.79048 .0559 Mdot
.79524 .11873 Mdot
.8 .04359 Mdot
.80476 .05907 Mdot
.80952 .02712 Mdot
.81429 .00824 Mdot
.81905 .05778 Mdot
.82381 .0716 Mdot
.82857 .17132 Mdot
.83333 .24892 Mdot
.8381 .26349 Mdot
.84286 .05023 Mdot
.84762 .05069 Mdot
.85238 .12321 Mdot
.85714 .13503 Mdot
.8619 .05947 Mdot
.86667 .13331 Mdot
.87143 .00794 Mdot
.87619 .18354 Mdot
.88095 .1191 Mdot
.88571 .02336 Mdot
.89048 .12689 Mdot
.89524 .076 Mdot
.9 .13483 Mdot
.90476 .21166 Mdot
.90952 .30151 Mdot
.91429 .04919 Mdot
.91905 .01159 Mdot
.92381 .16351 Mdot
.92857 .17992 Mdot
.93333 .43583 Mdot
.9381 .12389 Mdot
.94286 .073 Mdot
.94762 .28365 Mdot
.95238 .25502 Mdot
.95714 .00247 Mdot
.9619 .12114 Mdot
.96667 .11041 Mdot
.97143 .06343 Mdot
.97619 .10422 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo
0_l00005ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooo000000?o0000
1oooool3o`0000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool0
3?ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`;o00002?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?oo
ool2o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`;o00001Ooo
ool00ol0003oooooooooo`06ooooo`;o00000oooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001?ooool3o`0000oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000?ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooooooo
o`0<ooooo`009?ooool00ol0003oooooooooo`16ooooo`;o0000Doooool2o`0000Sooooo0_l00007
ooooo`;o0000@_ooool2o`0000Wooooo0_l0000@ooooo`;o0000<?ooool002Cooooo00?o0000oooo
ooooool0=oooool2o`000003ooooool0003o000000?ooooo0_l0000Iooooo`;o0000?oooool2o`00
01Wooooo0_l0000:ooooo`;o00005?ooool2o`0002?ooooo0_l0000@ooooo`;o00003_ooool2o`00
023ooooo000Tooooo`;o0000>?ooool2o`000003ooooool0003o000000?ooooo0_l0000Iooooo`;o
00005oooool2o`00047ooooo0_l0000:ooooo`;o00005?ooool2o`0004Gooooo0_l0000Pooooo`00
9?ooool00ol0003oooooooooo`05ooooo`;o0000K?ooool2o`00053ooooo0_l0001jooooo`009?oo
ool00ol0003oooooooooo`05ooooo`;o0000M?ooool2o`00027ooooo0_l0000Iooooo`;o00001?oo
ool2o`0000Cooooo0_l0000<ooooo`;o0000K?ooool002Cooooo00?o0000ooooooooool04oooool2
o`00017ooooo0_l0001Cooooo`;o00008Oooool2o`0001Wooooo0_l00004ooooo`;o00004_ooool2
o`0001Cooooo0_l0000Yooooo`;o0000:oooool002Cooooo00?o0000ooooooooool04oooool2o`00
017ooooo0_l0000Vooooo`;o0000VOooool2o`0000Gooooo0_l00009ooooo`;o00005oooool2o`00
02_ooooo000Tooooo`;o00001Oooool2o`0001Oooooo0_l0000@ooooo`;o00007Oooool2o`0008oo
oooo0_l0000?ooooo`;o00002Oooool2o`0004Cooooo000Tooooo`03o`000?oooooooooo00Cooooo
0_l0000Gooooo`;o00004?ooool2o`0003[ooooo0_l0001booooo`;o0000H?ooool002Cooooo00?o
0000ooooooooool0Joooool2o`0000cooooo0_l0000fooooo`;o0000S_ooool002Cooooo00?o0000
ooooooooool0NOooool2o`0002_ooooo0_l00009ooooo`;o00002_ooool2o`0001[ooooo0_l0001V
ooooo`009?ooool00ol0003oooooooooo`1Uooooo`;o0000??ooool2o`000003ooooool0003o0000
01Gooooo0_l0000Jooooo`;o00007Oooool2o`0004Oooooo000Tooooo`;o00004Oooool2o`0000Wo
oooo0_l0000dooooo`;o00004_ooool2o`0001[ooooo0_l0000Pooooo`;o0000Doooool2o`0004Oo
oooo000Tooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`;o00007oooool2o`0001?ooooo
0_l0000^ooooo`;o00005Oooool2o`0006cooooo0_l0000Eooooo`;o00008_ooool002Cooooo00?o
0000ooooooooool0??ooool2o`0005[ooooo0_l0001/ooooo`?o00005?ooool2o`0002;ooooo000T
ooooo`03o`000?oooooooooo01Gooooo0_l0003Nooooo`;o00004?ooool2o`0003Sooooo000Toooo
o`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o0000R_ooool2o`0005;ooooo0_l00002oooo
o`;o00000oooool2o`0000cooooo0_l0000cooooo`009?ooool4o`0000Kooooo0_l0002Hooooo`;o
0000:_ooool2o`0002[ooooo0_l00003ooooo`;o00003?ooool2o`0003?ooooo000Tooooo`04o`00
0?oooooo0000o`00037ooooo0_l0000Eooooo`;o0000Ioooool2o`0001Kooooo0_l000000ooooooo
0000o`00000<ooooo`;o0000Doooool2o`0000oooooo000Tooooo`03o`000?oooooooooo03;ooooo
0_l0000Eooooo`;o00002?ooool2o`0000gooooo0_l0001>ooooo`;o00005_ooool2o`0000oooooo
0_l0001Cooooo`;o00003oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Coooo
o`;o00003Oooool2o`0003Wooooo0_l0001Qooooo`;o0000?oooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool09?ooool2o`00077ooooo0_l00004ooooo`;o00007Ooo
ool2o`00013ooooo0_l0000>ooooo`;o00008?ooool2o`0002Cooooo0_l0000Iooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`0002Cooooo0_l0001/ooooo`;o00000oooool2o`0002?ooooo0_l0000@
ooooo`;o00003_ooool2o`0003Oooooo0_l0000=ooooo`;o00006Oooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0E_ooool2o`0000Oooooo0_l0000aooooo`;o0000Poooool2o`00
02Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0E_ooool2o`00
00Oooooo0_l0000Vooooo`;o0000?_ooool2o`0007Sooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08Oooooo0_l0000nooooo`;o00000_ooool2o`0007Cooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooooooo0_l00038ooooo`;o0000M?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o
00000_ooool2o`0003Gooooo0_l0001@ooooo`;o00002?ooool2o`000:_ooooo000Tooooo`03o`00
0?oooooooooo01[ooooo0_l0000Looooo`;o0000:_ooool2o`0002Cooooo0_l00008ooooo`;o0000
Zoooool002Cooooo00?o0000ooooooooool06_ooool2o`0004Sooooo0_l0003Kooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0003ooooo
obkooooo0_l0000>ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000?oooool2o`000>co
oooo0_l0000>ooooo`009?ooool2o`0004Cooooo0_l0000gooooo`;o0000B_ooool2o`0000[ooooo
0_l0001Hooooo`;o00004Oooool002Cooooo00?o0000ooooooooool0Ioooool2o`0001?ooooo0_l0
001:ooooo`;o00002_ooool4o`0005Kooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`0F
ooooo`;o0000Coooool2o`0006gooooo0_l0001Yooooo`009?ooool00ol0003oooooooooo`0Foooo
o`;o00007?ooool2o`0007Wooooo0_l00015ooooo`;o00006_ooool2o`0001Sooooo0_l0000Coooo
o`009?ooool00ol0003oooooooooo`0dooooo`;o0000NOooool2o`0004Gooooo0_l0000Aooooo`;o
00001oooool2o`00017ooooo0_l00005ooooo`;o00004oooool002Cooooo0_l0003oooooo`_ooooo
0_l0000:ooooo`;o00003_ooool2o`0001[ooooo000Tooooo`03o`000?oooooooooo0=cooooo0_l0
000gooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool0?Oooool2o`0006gooooo0_l0000R
ooooo`?o00002Oooool2o`00033ooooo0_l0000aooooo`009?ooool00ol0003oooooooooo`0moooo
o`;o0000KOooool2o`0002;ooooo0ol0000gooooo`;o00000_ooool2o`0000Sooooo0_l0000Woooo
o`009?ooool00ol0003oooooooooo`1Zooooo`;o0000W_ooool2o`0000cooooo0_l0000Wooooo`00
9?ooool2o`0001Wooooo0_l0001@ooooo`;o00005oooool2o`000;cooooo000Tooooo`03o`000?oo
oooooooo01Sooooo0_l0001Yooooo`;o0000_?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
i?ooool2o`0005_ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`24ooooo`;o0000G_ooool2o`0005_ooooo
0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo08Cooooo0_l0001Yooooo`;o0000D?ooool000Wooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003_ooooo`;o0000D?ooool000Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3Uooooo`;o0000F_ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0COooool2o`0009Kooooo0_l0000iooooo`;o
00007oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0COooool2o`000=7ooooo0_l0000Oooooo`002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
0_l0000/ooooo`;o0000e?ooool2o`0003kooooo000Tooooo`03o`000?oooooooooo02Wooooo1?l0
003Dooooo`;o0000?_ooool002Cooooo00?o0000ooooooooool0:Oooool2o`0002Gooooo0_l0003_
ooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000d?ooool2o`0001gooooo000Tooooo`03
o`000?oooooooooo06kooooo1?l0001eooooo`;o0000:?ooool2o`0000oooooo0_l0000Mooooo`00
9?ooool2o`0006oooooo1?l0001eooooo`;o0000:?ooool2o`0002kooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l0003ooooooago
oooo000Tooooo`;o00009?ooool2o`000?oooooo7Oooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
037ooooo0_l0003Wooooo`;o00009Oooool002Cooooo00?o0000ooooooooool0<Oooool2o`000>Oo
oooo0_l0000Uooooo`009?ooool2o`0006;ooooo0_l0003Nooooo`009?ooool00ol0003ooooooooo
o`1Nooooo`;o000000?oooooo`000?l00000;?ooool2o`000;3ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo02Oooooo0_l0000eooooo`;o0000;oooool2o`0000Wo
oooo0_l00015ooooo`;o0000G_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02Oooooo0_l0001aooooo`;o0000AOooool2o`0005kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood;ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02_ooool2o`0007gooooo
0_l0002fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o0000OOoo
ool2o`000;Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^_ooool2o`0003Oo
oooo0_l0001<ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`00
00Kooooo00?o0000ooooooooool0;_ooool2o`0005cooooo0_l0000/ooooo`;o0000=oooool2o`00
04cooooo000Tooooo`;o00003_ooool2o`0001oooooo0_l0001Looooo`;o0000MOooool2o`0003co
oooo000Tooooo`03o`000?oooooooooo00gooooo0_l0000Aooooo`;o0000hOooool2o`0003cooooo
000Tooooo`03o`000?oooooooooo023ooooo0_l0003oooooo`Sooooo0_l0000Fooooo`009?ooool0
0ol0003oooooooooo`15ooooo`;o0000YOooool2o`0003_ooooo0_l0000Fooooo`009?ooool00ol0
003oooooooooo`15ooooo`;o0000YOooool2o`0005?ooooo000Tooooo`;o0000`Oooool2o`0004;o
oooo0_l0000kooooo`009?ooool3o`0003Gooooo0_l00029ooooo`;o0000@_ooool2o`0003_ooooo
000Tooooo`?o0000=Oooool2o`0000_ooooo0_l0002Vooooo`;o0000EOooool002Cooooo00?o0000
ooooooooool0@_ooool2o`0003Cooooo0_l0001`ooooo`;o0000EOooool002Cooooo00?o0000oooo
ooooool0B?ooool2o`0002kooooo0_l00037ooooo`009?ooool2o`0004Wooooo0_l0003gooooo`00
9?ooool00ol0003oooooooooo`1Gooooo`;o0000coooool2o`0001Oooooo000Tooooo`03o`000?oo
oooooooo05Oooooo0_l0003?ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0Ooooool2
o`000<3ooooo000Tooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolLooooo`;o00009?ooool001cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooooacooooo0_l0000Tooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo@_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool0
01[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000ZOooool2o`0009Oooooo000Tooooo`03o`000?oooooooooo00oooooo0_l0002Gooooo`;o0000
Uoooool002Cooooo00?o0000ooooooooool03oooool2o`0000gooooo0_l0000dooooo`;o0000jooo
ool002Cooooo00?o0000ooooooooool07_ooool2o`0003Cooooo0_l0003[ooooo`009?ooool00ol0
003oooooooooo`1fooooo`;o0000bOooool002Cooooo0_l0001gooooo`;o0000bOooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2oooo
o`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo043ooooo0_l0003o
ooooo`009?ooool00ol0003oooooooooo`10ooooo`;o00002Oooool2o`000?Cooooo000Tooooo`;o
0000C?ooool2o`000?Cooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`?o0000oooooom2ooooo`001?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05Wooooo0_l0003V
ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0<ooooo`;o0000Boooool2o`000>Kooooo0004ooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool2o`000?oooooo=?ooool000;ooooo00?oEEEEofIVI_l0
00003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo0_l0001^ooooo`;o00007_ooool2o`000;;ooooo000Tooooo`03o`00
0?oooooooooo06gooooo0_l0000Nooooo`;o0000/_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
0>gooooo0_l0001Booooo`009?ooool2o`000>kooooo0_l0001Booooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o
0000Loooool2o`000<gooooo000Tooooo`03o`000?oooooooooo07;ooooo0_l0002_ooooo`;o0000
7?ooool002Cooooo00?o0000ooooooooool0;?ooool2o`000?Gooooo0_l0000Looooo`009?ooool0
0ol0003oooooooooo`0/ooooo`;o0000oooooolDooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`1Looooo`;o0000
hoooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0G?ooool2o`000>?ooooo000<ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0UOoo
ool2o`000:[ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2Eooooo`;o0000Z_ooool000cooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`;o0000oooooolOoooo
o`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08Oooool2o`000?oooooo7oooool000cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Ooo
ool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000;Sooooo0_l00028
ooooo`009?ooool00ol0003oooooooooo`2gooooo`;o0000R?ooool002Cooooo00?o0000oooooooo
ool0`oooool2o`0007cooooo000Tooooo`03o`000?oooooooooo0<?ooooo0_l0001looooo`009?oo
ool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000T
ooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3Rooooo`;o0000GOooool002Co
oooo00?o0000ooooooooool0h_ooool2o`0005gooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Wooooo0_l0
003oooooocOooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02Oooool2o`000?oooooo=ooo
ool000Cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000;ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo1Ol0
0006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
od;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0
oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .10857 Mdot
.03333 .21542 Mdot
.0381 .11287 Mdot
.04286 .05048 Mdot
.04762 .02964 Mdot
.05238 .0178 Mdot
.05714 .03137 Mdot
.0619 .51844 Mdot
.06667 .20368 Mdot
.07143 .30075 Mdot
.07619 .05345 Mdot
.08095 .01785 Mdot
.08571 .04589 Mdot
.09048 .00207 Mdot
.09524 .02376 Mdot
.1 .03562 Mdot
.10476 .11503 Mdot
.10952 .12491 Mdot
.11429 .00365 Mdot
.11905 .1249 Mdot
.12381 .0294 Mdot
.12857 .38639 Mdot
.13333 .25101 Mdot
.1381 .41736 Mdot
.14286 .20929 Mdot
.14762 .18654 Mdot
.15238 .00252 Mdot
.15714 .04086 Mdot
.1619 .02464 Mdot
.16667 .27683 Mdot
.17143 .48584 Mdot
.17619 .11664 Mdot
.18095 .08362 Mdot
.18571 .06547 Mdot
.19048 .0642 Mdot
.19524 .12107 Mdot
.2 .28705 Mdot
.20476 .02746 Mdot
.20952 .09183 Mdot
.21429 .13266 Mdot
.21905 .04843 Mdot
.22381 .1434 Mdot
.22857 .27316 Mdot
.23333 .17224 Mdot
.2381 .26085 Mdot
.24286 .1079 Mdot
.24762 .20239 Mdot
.25238 .08922 Mdot
.25714 .245 Mdot
.2619 .01398 Mdot
.26667 .24834 Mdot
.27143 .16151 Mdot
.27619 .02748 Mdot
.28095 .26498 Mdot
.28571 .08059 Mdot
.29048 .02564 Mdot
.29524 .41588 Mdot
.3 .04383 Mdot
.30476 .2229 Mdot
.30952 .2857 Mdot
.31429 .11355 Mdot
.32381 .30196 Mdot
.32857 .34267 Mdot
.33333 .21954 Mdot
.3381 .06778 Mdot
.34286 .01767 Mdot
.34762 .04356 Mdot
.35238 .11428 Mdot
.35714 .4104 Mdot
.3619 .28109 Mdot
.36667 .12799 Mdot
.37143 .20668 Mdot
.37619 .14857 Mdot
.38095 .18568 Mdot
.38571 .31045 Mdot
.39048 .01341 Mdot
.39524 .59931 Mdot
.4 .09488 Mdot
.40476 .08432 Mdot
.40952 .04342 Mdot
.41429 .02158 Mdot
.41905 .11052 Mdot
.42857 .30603 Mdot
.43333 .04543 Mdot
.4381 .07706 Mdot
.44286 .1141 Mdot
.45238 .08312 Mdot
.45714 .20922 Mdot
.4619 .0934 Mdot
.46667 .07323 Mdot
.47143 .16837 Mdot
.47619 .28155 Mdot
.48095 .00327 Mdot
.48571 .09592 Mdot
.49048 .09176 Mdot
.49524 .39303 Mdot
.5 .07471 Mdot
.50476 .04749 Mdot
.50952 .2245 Mdot
.51429 .03457 Mdot
.51905 .07016 Mdot
.52381 .04527 Mdot
.52857 .00958 Mdot
.53333 .05761 Mdot
.5381 .0427 Mdot
.54286 .01621 Mdot
.54762 .03985 Mdot
.55238 .44706 Mdot
.55714 .00297 Mdot
.5619 .00234 Mdot
.56667 .15633 Mdot
.57143 .02031 Mdot
.57619 .11863 Mdot
.58095 .03827 Mdot
.58571 .03441 Mdot
.59048 .03963 Mdot
.59524 .08071 Mdot
.6 .54508 Mdot
.60476 .32339 Mdot
.60952 .01771 Mdot
.61429 .07416 Mdot
.61905 .18929 Mdot
.62381 .11842 Mdot
.62857 .06491 Mdot
.63333 .01175 Mdot
.6381 .35669 Mdot
.64286 .01706 Mdot
.64762 .08125 Mdot
.65238 .04265 Mdot
.65714 .25174 Mdot
.6619 .08495 Mdot
.66667 .25455 Mdot
.67143 .07067 Mdot
.67619 .13154 Mdot
.68095 .30229 Mdot
.68571 .04546 Mdot
.69048 .10899 Mdot
.69524 .33098 Mdot
.7 .01231 Mdot
.70476 .0117 Mdot
.70952 .06385 Mdot
.71429 .12761 Mdot
.71905 .01585 Mdot
.72381 .03072 Mdot
.72857 .25015 Mdot
.73333 .44771 Mdot
.7381 .19804 Mdot
.74286 .11112 Mdot
.74762 .18476 Mdot
.75238 .11541 Mdot
.75714 .03417 Mdot
.7619 .21309 Mdot
.76667 .34146 Mdot
.77143 .2109 Mdot
.77619 .02589 Mdot
.78095 .0066 Mdot
.78571 .0701 Mdot
.79048 .0559 Mdot
.79524 .26867 Mdot
.8 .04359 Mdot
.80476 .01128 Mdot
.80952 .02712 Mdot
.81429 .06212 Mdot
.81905 .06287 Mdot
.82381 .0716 Mdot
.82857 .31438 Mdot
.83333 .20899 Mdot
.8381 .06965 Mdot
.84286 .05023 Mdot
.84762 .22895 Mdot
.85238 .03496 Mdot
.85714 .13503 Mdot
.8619 .05947 Mdot
.86667 .10127 Mdot
.87143 .00794 Mdot
.87619 .05827 Mdot
.88095 .22273 Mdot
.88571 .00046 Mdot
.89048 .09806 Mdot
.89524 .15377 Mdot
.9 .13483 Mdot
.90476 .19137 Mdot
.90952 .27558 Mdot
.91429 .04919 Mdot
.91905 .01159 Mdot
.92381 .16351 Mdot
.92857 .26797 Mdot
.93333 .24738 Mdot
.9381 .12389 Mdot
.94286 .16062 Mdot
.94762 .02233 Mdot
.95238 .17512 Mdot
.95714 .06142 Mdot
.9619 .18728 Mdot
.96667 .25538 Mdot
.97143 .06343 Mdot
.97619 .26004 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`;o00001_ooool3o`0000Wooooo0_l00003ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo
0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000000ol00009ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`?o0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Kooooo0ol00009ooooo`;o00000ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooo000000?o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`?o00003oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`009?ooool00ol0003oooooooooo`2Pooooo`;o0000D?ooool2o`0001_ooooo0_l0000`
ooooo`009?ooool00ol0003oooooooooo`2Pooooo`;o00008?ooool2o`0001Cooooo0ol0000Noooo
o`;o00005?ooool2o`0000kooooo0_l0000Pooooo`009?ooool2o`0004[ooooo0_l0000Xooooo`;o
0000<?ooool2o`0001_ooooo0_l0000Dooooo`?o00000oooool2o`0001Wooooo0_l0000Tooooo`;o
00008?ooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l0000hooooo`;o0000
6Oooool2o`0000gooooo0_l0000`ooooo`;o00004oooool2o`0000Wooooo0_l0000Gooooo`;o0000
HOooool002Cooooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l0001Cooooo`;o00005Ooo
ool2o`00037ooooo0_l0000:ooooo`;o00002Oooool2o`00067ooooo0_l0000Gooooo`009?ooool0
0ol0003oooooooooo`0Cooooo`;o00005?ooool2o`0002Sooooo0_l0000Vooooo`;o0000<Oooool2
o`0007Sooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`0Cooooo`;o00005?ooool2o`00
00cooooo0_l0000Eooooo`;o00000oooool2o`0009_ooooo0_l00009ooooo`;o0000A?ooool002Co
oooo0_l00005ooooo`;o000000?oooooo`000?l000005?ooool2o`0001Sooooo0_l0000Eooooo`;o
0000Soooool2o`0000oooooo0_l00009ooooo`;o0000A?ooool002Cooooo00?o0000ooooooooool0
1?ooool2o`000003ooooool0003o000001Cooooo0_l0001looooo`;o00005Oooool2o`0002_ooooo
0_l00009ooooo`;o0000EOooool002Cooooo00?o0000ooooooooool05Oooool2o`0008Cooooo0_l0
000Eooooo`;o0000=_ooool2o`0001gooooo0_l0000fooooo`009?ooool00ol0003oooooooooo`0E
ooooo`;o00004?ooool2o`0007gooooo0_l00009ooooo`;o000000?oooooo`000?l00000Doooool2
o`0003Kooooo000Tooooo`03o`000?oooooooooo02Oooooo0_l0000]ooooo`;o00003Oooool2o`00
01;ooooo0_l0000Xooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o0000
01;ooooo0_l0000^ooooo`;o0000Aoooool002Cooooo0_l0000Aooooo`;o0000A?ooool2o`0000go
oooo0_l0000Booooo`;o00001_ooool2o`0001_ooooo0_l00003ooooo`;o00008oooool2o`0000Wo
oooo0_l0000Sooooo`;o0000Aoooool002Cooooo00?o0000ooooooooool04?ooool2o`0002[ooooo
0_l00013ooooo`;o00005Oooool2o`0000Cooooo0_l0000cooooo`;o0000<Oooool2o`0001Gooooo
0_l0000Rooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000>?ooool2o`0005[ooooo0_l0
001/ooooo`;o00005Oooool2o`0002;ooooo000Tooooo`03o`000?oooooooooo00;ooooo0_l00009
ooooo`;o0000i_ooool2o`0004[ooooo000Tooooo`03o`000?oooooooooo00gooooo0_l0002Boooo
o`;o0000D_ooool2o`0001Gooooo0_l00003ooooo`;o0000;_ooool002Cooooo0_l0002Rooooo`;o
0000F_ooool2o`0000gooooo0_l00003ooooo`;o00006?ooool2o`0001Cooooo000Tooooo`03o`00
0?oooooooooo037ooooo0ol0002<ooooo`;o00006Oooool2o`00023ooooo0ol0000[ooooo`;o0000
0oooool2o`0000oooooo000Tooooo`03o`000?oooooooooo037ooooo0ol0000^ooooo`;o0000G?oo
ool2o`0001Wooooo0_l0000Qooooo`;o0000<?ooool2o`0000oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0H_ooool2o`0003Wooooo0_l0000_ooooo`;o00008oooool2o`0000_o
oooo0_l00002ooooo`;o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0S?ooool2o`0000Wooooo0_l00004ooooo`;o00007Oooool2o`00013ooooo0_l0000S
ooooo`;o00002oooool2o`0000;ooooo0_l0000kooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
08?ooooo0_l00007ooooo`;o00002Oooool2o`0002?ooooo0_l00023ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`1Aooooo`;o0000<?ooool2o`00037ooooo0_l00029ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02oooooo0_l0000Pooooo`;o
0000=?ooool2o`0002gooooo0_l0000?ooooo`;o0000N?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0;oooool2o`0004Oooooo0_l0000=ooooo`;o0000?_ooool2o`0000;ooooo
0_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo0_l0000`oooo
o`;o0000DOooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0003Wooooo0_l0000<ooooo`;o0000@_oo
ool2o`0000Sooooo0_l0002[ooooo`009?ooool00ol0003oooooooooo`0hooooo`;o0000??ooool2
o`0001;ooooo0_l00006ooooo`Co0000Zoooool002Cooooo00?o0000ooooooooool0M_ooool2o`00
01[ooooo0_l00021ooooo`;o0000:_ooool002Cooooo00?o0000ooooooooool0ooooool?ooooo`;o
00001Oooool2o`0002[ooooo000Tooooo`03o`000?oooooooooo0?oooooo3oooool2o`00037ooooo
000Tooooo`?o0000@oooool2o`000?cooooo000Tooooo`?o0000@oooool2o`0003Oooooo0_l0001F
ooooo`;o00003oooool2o`0005[ooooo000Tooooo`04o`000?ooooooooooooooo`;o00004oooool2
o`0004;ooooo0_l0000;ooooo`;o00004oooool2o`0000Kooooo0_l0001>ooooo`;o00003oooool2
o`0005[ooooo000Tooooo`04o`000?ooooooooooooooo`;o00004oooool2o`0001Kooooo0_l0000Z
ooooo`;o00002oooool2o`0001_ooooo0_l0001Sooooo`;o0000E_ooool002Cooooo00?o0000oooo
ooooool0;_ooool2o`0000Cooooo0_l0001iooooo`;o00003_ooool2o`0002Sooooo0_l0001Foooo
o`009?ooool00ol0003oooooooooo`0dooooo`;o0000NOooool2o`0000kooooo0_l0001Tooooo`;o
00006_ooool002Cooooo0_l0000Iooooo`;o000000?oooooo`000?l00000ooooool9ooooo`;o0000
6_ooool002Cooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000004kooooo0_l0
001_ooooo`;o0000Hoooool002Cooooo00?o0000ooooooooool0>_ooool2o`0002oooooo0_l0001S
ooooo`;o00002_ooool2o`0006?ooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0002Doooo
o`;o0000>?ooool2o`0000cooooo0_l0000Wooooo`009?ooool00ol0003oooooooooo`3oooooo`_o
oooo0_l0000<ooooo`;o00009oooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oo
oooooooo03gooooo0_l0003oooooo`?ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03gooooo
0_l0000_ooooo`;o0000dOooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06kooooo0_l0003Aooooo`002Ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooooaSooooo0_l0000Xooooo`002Oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool3o`000:cooooo0_l0001Yooooo`;o0000:?ooool000Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2/ooooo`;o0000N?ooool2o`0001Wooooo0009ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04gooooo0_l0003Aooooo`;o
00001?ooool2o`0001Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04gooooo0_l0003Aooooo`;o00007oooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2=ooooo`;o
0000/_ooool002Cooooo0_l00011ooooo`;o0000Boooool2o`000;;ooooo000Tooooo`03o`000?oo
oooooooo043ooooo0_l0003Wooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0oooooolZ
ooooo`;o00005_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`1`ooooo`;o0000MOooool2o`0005Sooooo000Tooooo`;o00009Oooool2o`0004[ooooo
0_l0001eooooo`;o0000@oooool2o`0001?ooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l0
002Gooooo`;o0000Foooool2o`00013ooooo0_l0000Cooooo`009?ooool00ol0003oooooooooo`2m
ooooo`;o0000Foooool2o`0002Gooooo000Tooooo`03o`000?oooooooooo0>Cooooo0_l0001Koooo
o`009?ooool00ol0003oooooooooo`3Tooooo`;o0000Foooool002Cooooo0_l0000;ooooo`;o0000
>Oooool2o`000?[ooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0000iooooo`;o00009_oo
ool2o`000=;ooooo000Tooooo`03o`000?oooooooooo02?ooooo0_l00018ooooo`;o00006_ooool2
o`0007Sooooo0_l0000looooo`009?ooool00ol0003oooooooooo`0Sooooo`;o0000I?ooool2o`00
067ooooo0_l000000ooooooo0000o`00000Booooo`;o0000??ooool002Cooooo00Co0000ooooool0
003o0000joooool2o`000003ooooool0003o0000053ooooo000Tooooo`Co0000H?ooool2o`000=ko
oooo000Tooooo`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o0000[oooool2o`0002gooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05Oooooo0_l00011oooo
o`;o0000M_ooool2o`0002gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2J
ooooo`;o0000Joooool2o`0003Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo2?ooool2o`0003Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom2ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo04Sooooo0_l0003Iooooo`;o00007?ooool0
02Cooooo0_l00019ooooo`;o000000?oooooo`000?l00000U?ooool2o`00043ooooo0_l0000Loooo
o`009?ooool00ol0003oooooooooo`0Pooooo`;o0000:Oooool2o`0007gooooo0_l0000Eooooo`;o
0000G_ooool002Cooooo00?o0000ooooooooool08?ooool2o`000:Sooooo0_l000000ooooooo0000
o`00001Oooooo`;o00004Oooool002Cooooo00?o0000ooooooooool0cOooool2o`0005oooooo0_l0
000Aooooo`009?ooool00ol0003oooooooooo`12ooooo`;o0000kOooool2o`0000kooooo000Toooo
o`;o0000@oooool2o`0000cooooo0_l0003Oooooo`;o00003_ooool002Cooooo00?o0000oooooooo
ool0D?ooool2o`000:Cooooo0_l0000Zooooo`;o00007Oooool002Cooooo00?o0000ooooooooool0
m_ooool2o`0002[ooooo0_l0000Mooooo`009?ooool00ol0003oooooooooo`0oooooo`;o0000oooo
ool1ooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o00004_ooool2o`000=[ooooo0_l0000T
ooooo`009?ooool2o`0002cooooo0_l0000mooooo`;o00008oooool2o`0008[ooooo0_l0000Toooo
o`009?ooool00ol0003oooooooooo`1Zooooo`;o00008oooool2o`000;3ooooo000Tooooo`03o`00
0?oooooooooo03Gooooo0_l0000Rooooo`;o0000i_ooool002Cooooo00?o0000ooooooooool0=Ooo
ool2o`0002;ooooo0_l0003Vooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Toooo
o`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Jooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o0000D?ooool2o`00077ooooo
0_l0001^ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo0_l0
001@ooooo`;o00007oooool2o`00053ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07oooooo0_l00030ooooo`007?ooool00ol0003oooooooooo`05oooo
o`?o0000L_ooool2o`000<gooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0L_ooool2o`0008gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo0_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom2ooooo`006_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo0;Wooooo0_l00026ooooo`009?ooool2o`000;[ooooo0_l00026ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0=Kooooo0_l0001Yooooo`009?oo
ool00ol0003oooooooooo`3Fooooo`;o0000JOooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`00063ooooo0_l0002<ooooo`;o0000D_ooool002Cooooo00?o0000oooooooo
ool0Goooool2o`0008cooooo0_l0001Booooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool2o`000<Cooooo0_l0001looooo`009?ooool00ol0003oooooooooo`33ooooo`;o
0000O?ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooo
od?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o0000oooooolRooooo`001?oo
ool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0001kooooo0_l0003oooooob;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Eooooo`;o0000Z_ooool000Cooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Eooooo`;o0000Z_ooool000;ooooo00?oEEEEofIVI_l000003?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0J?ooool2o`000=Oooooo000Tooooo`03o`000?oooooooooo06Sooooo0_l0
003Gooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o0000joooool002Cooooo0_l0000Roooo
o`;o0000<Oooool2o`000>_ooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0003ooooooaoo
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooo
oom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3oooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2X
ooooo`;o0000>?ooool2o`0005gooooo000Tooooo`;o0000ZOooool2o`0003Sooooo0_l0001Moooo
o`009?ooool00ol0003oooooooooo`3ooooood;ooooo000:ooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000cooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2
ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom2ooooo`002_ooool00omEEEGoIVIVo`00000=ooooo`Co0000
1_ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo02cooooo0_l0003ooooo
oaCooooo000Tooooo`03o`000?oooooooooo02cooooo0_l0003ooooooaCooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003o
ooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0
003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooo
ooooool02Oooool2o`000?oooooo=oooool002Cooooo00?o0000ooooooooool02Oooool2o`000?oo
oooo=oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`000_ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo@_ooool000Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003ooooo
ooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo
@_ooool000Cooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2gooooo`;o0000R?ooool000Cooooo00?o
0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0]oooool2o`0008Sooooo0004ooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`00
0?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oo
oooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0MOooool2o`000<[ooooo000Toooo
o`;o0000M_ooool2o`000<[ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`3ooooood;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003o
oooood;ooooo000Looooo`03ogMgMomVIVKooooo0?ooooooB_ooool001gooooo00?o0000oooooooo
ool0oooooom9ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .10857 Mdot
.03333 .21542 Mdot
.0381 .17528 Mdot
.04286 .05048 Mdot
.04762 .04284 Mdot
.05238 .21123 Mdot
.05714 .12864 Mdot
.0619 .48948 Mdot
.06667 .20368 Mdot
.07143 .02315 Mdot
.07619 .03664 Mdot
.08095 .01785 Mdot
.08571 .01344 Mdot
.09048 .00207 Mdot
.09524 .02376 Mdot
.1 .11874 Mdot
.10476 .03366 Mdot
.10952 .12491 Mdot
.11429 .11118 Mdot
.11905 .09374 Mdot
.12381 .06694 Mdot
.12857 .56407 Mdot
.13333 .29575 Mdot
.1381 .14513 Mdot
.14286 .0203 Mdot
.14762 .03647 Mdot
.15238 .00252 Mdot
.15714 .03742 Mdot
.1619 .02464 Mdot
.16667 .28146 Mdot
.17143 .48509 Mdot
.17619 .11664 Mdot
.18095 .08275 Mdot
.18571 .06547 Mdot
.19048 .0642 Mdot
.19524 .08682 Mdot
.2 .09653 Mdot
.20476 .18486 Mdot
.20952 .09284 Mdot
.21429 .13266 Mdot
.21905 .04843 Mdot
.22381 .13166 Mdot
.22857 .18702 Mdot
.23333 .20785 Mdot
.2381 .26085 Mdot
.24286 .0847 Mdot
.24762 .10509 Mdot
.25238 .08922 Mdot
.25714 .31072 Mdot
.2619 .1021 Mdot
.26667 .03074 Mdot
.27143 .16151 Mdot
.27619 .02691 Mdot
.28095 .26498 Mdot
.28571 .08059 Mdot
.29048 .04526 Mdot
.29524 .42149 Mdot
.3 .06614 Mdot
.30476 .08594 Mdot
.30952 .25889 Mdot
.31429 .07995 Mdot
.32381 .14706 Mdot
.32857 .2785 Mdot
.33333 .23756 Mdot
.3381 .25173 Mdot
.34286 .04126 Mdot
.34762 .12632 Mdot
.35238 .25165 Mdot
.35714 .16933 Mdot
.3619 .49879 Mdot
.36667 .05139 Mdot
.37143 .19141 Mdot
.37619 .05976 Mdot
.38095 .1238 Mdot
.38571 .29867 Mdot
.39048 .04727 Mdot
.39524 .37859 Mdot
.4 .09488 Mdot
.40476 .04323 Mdot
.40952 .07496 Mdot
.41429 .23759 Mdot
.41905 .32291 Mdot
.42857 .2111 Mdot
.43333 .00451 Mdot
.4381 .05449 Mdot
.44286 .04021 Mdot
.45238 .1149 Mdot
.45714 .02705 Mdot
.4619 .09231 Mdot
.46667 .06647 Mdot
.47143 .13867 Mdot
.47619 .32191 Mdot
.48095 .17267 Mdot
.48571 .06036 Mdot
.49048 .09176 Mdot
.49524 .51809 Mdot
.5 .52876 Mdot
.50476 .32959 Mdot
.50952 .2245 Mdot
.51429 .03457 Mdot
.51905 .02784 Mdot
.52381 .04527 Mdot
.52857 .00958 Mdot
.53333 .05761 Mdot
.5381 .12622 Mdot
.54286 .01621 Mdot
.54762 .03985 Mdot
.55238 .26559 Mdot
.55714 .00297 Mdot
.5619 .20259 Mdot
.56667 .07309 Mdot
.57143 .02031 Mdot
.57619 .10097 Mdot
.58095 .03827 Mdot
.58571 .03441 Mdot
.59048 .03963 Mdot
.59524 .08071 Mdot
.6 .57624 Mdot
.60476 .33959 Mdot
.60952 .01771 Mdot
.61429 .13366 Mdot
.61905 .29745 Mdot
.62381 .11842 Mdot
.62857 .06491 Mdot
.63333 .1867 Mdot
.6381 .60337 Mdot
.64286 .06855 Mdot
.64762 .07093 Mdot
.65238 .09337 Mdot
.65714 .25174 Mdot
.6619 .13857 Mdot
.66667 .04975 Mdot
.67143 .11807 Mdot
.67619 .04463 Mdot
.68095 .19289 Mdot
.68571 .03066 Mdot
.69048 .10899 Mdot
.69524 .22345 Mdot
.7 .01231 Mdot
.70476 .0117 Mdot
.70952 .03178 Mdot
.71429 .00556 Mdot
.71905 .01585 Mdot
.72381 .01111 Mdot
.72857 .0111 Mdot
.73333 .43374 Mdot
.7381 .25112 Mdot
.74286 .31104 Mdot
.74762 .38811 Mdot
.75238 .02307 Mdot
.75714 .19231 Mdot
.7619 .03781 Mdot
.76667 .42933 Mdot
.77143 .2109 Mdot
.77619 .01089 Mdot
.78095 .00384 Mdot
.78571 .04295 Mdot
.79048 .19063 Mdot
.79524 .45353 Mdot
.8 .04359 Mdot
.80476 .03398 Mdot
.80952 .0061 Mdot
.81429 .03133 Mdot
.81905 .00333 Mdot
.82381 .0716 Mdot
.82857 .23396 Mdot
.83333 .02716 Mdot
.8381 .13448 Mdot
.84286 .05023 Mdot
.84762 .22048 Mdot
.85238 .06794 Mdot
.85714 .13503 Mdot
.8619 .05947 Mdot
.86667 .06748 Mdot
.87143 .00794 Mdot
.87619 .05827 Mdot
.88095 .21609 Mdot
.88571 .06266 Mdot
.89048 .18034 Mdot
.89524 .01419 Mdot
.9 .1195 Mdot
.90476 .15834 Mdot
.90952 .09126 Mdot
.91429 .01586 Mdot
.91905 .22841 Mdot
.92381 .05143 Mdot
.92857 .05802 Mdot
.93333 .25484 Mdot
.9381 .12389 Mdot
.94286 .20696 Mdot
.94762 .1508 Mdot
.95238 .17512 Mdot
.95714 .06142 Mdot
.9619 .22234 Mdot
.96667 .20504 Mdot
.97143 .14129 Mdot
.97619 .2057 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`;o00000oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`?o00002Oooool2o`0000Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003ooooo
ooooo`07ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00[o
oooo0ol00006ooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
9?ooool00ol0003oooooooooo`21ooooo`;o00007Oooool2o`0003[ooooo0_l0000Mooooo`;o0000
4_ooool2o`00033ooooo000Tooooo`03o`000?oooooooooo0:3ooooo0_l0000fooooo`?o00001?oo
ool4o`0000gooooo0_l0000Mooooo`;o0000<?ooool002Cooooo0_l0000Aooooo`;o0000Toooool2
o`00037ooooo0ol00003ooooo`Go00003Oooool2o`0002Gooooo0_l00004ooooo`;o00008_ooool0
02Cooooo00?o0000ooooooooool03oooool3o`0009?ooooo0_l0000Cooooo`;o00008_ooool2o`00
03Oooooo0_l00004ooooo`;o00008_ooool002Cooooo00?o0000ooooooooool03oooool2o`0001;o
oooo0_l00029ooooo`;o00002_ooool2o`0008Gooooo000Tooooo`03o`000?oooooooooo00cooooo
0_l00005ooooo`;o00003_ooool2o`0000Cooooo0_l00023ooooo`;o0000>Oooool2o`0005Kooooo
000Tooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`;o00005?ooool2o`0002?ooooo0_l0
000iooooo`;o00004_ooool2o`0004[ooooo0_l0000Hooooo`;o0000??ooool002Cooooo0_l0001<
ooooo`;o000000?oooooo`000?l00000>Oooool2o`0001;ooooo0_l0000dooooo`;o00001_ooool2
o`00023ooooo0_l00004ooooo`;o0000??ooool002Cooooo00?o0000ooooooooool05_ooool2o`00
03?ooooo0_l0001>ooooo`;o00005Oooool2o`0001oooooo0_l00006ooooo`;o00007?ooool2o`00
00;ooooo0_l00012ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o00001oooool2o`0000co
oooo0_l000000ooooooo0000o`00001booooo`;o00005Oooool2o`0003Sooooo0_l0000;ooooo`;o
0000A_ooool002Cooooo00?o0000ooooooooool03Oooool2o`0001Gooooo0_l000000ooooooo0000
o`00001Kooooo`;o00008?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000fooooo`;o0000
Doooool002Cooooo00?o0000ooooooooool01?ooool2o`0005kooooo0_l0000Booooo`;o00002_oo
ool2o`00023ooooo0_l00009ooooo`;o000000?oooooo`000?l00000?Oooool2o`0000?ooooo0_l0
0017ooooo`009?ooool2o`0000Gooooo0_l0001=ooooo`;o00003oooool2o`0001;ooooo0_l0000T
ooooo`;o0000<?ooool2o`00027ooooo0_l00003ooooo`;o0000Aoooool002Cooooo00?o0000oooo
ooooool0??ooool2o`0001Gooooo0_l0000Nooooo`;o0000:Oooool2o`0002gooooo0_l000000ooo
oooo0000o`00000dooooo`;o0000>Oooool002Cooooo00?o0000ooooooooool00_ooool2o`0003So
oooo0_l0000]ooooo`;o00001_ooool2o`0005Sooooo0_l0000gooooo`;o00006?ooool2o`0001oo
oooo000Tooooo`03o`000?oooooooooo00;ooooo0_l0001Wooooo`;o00005_ooool2o`0009_ooooo
0_l0000Oooooo`009?ooool00ol0003oooooooooo`23ooooo`;o00007?ooool2o`0006Wooooo0_l0
0003ooooo`;o00003oooool2o`0001gooooo000Tooooo`;o0000Koooool2o`0002;ooooo0_l0000=
ooooo`;o0000JOooool2o`0000?ooooo0_l0000?ooooo`;o00001oooool2o`0001Cooooo000Toooo
o`03o`000?oooooooooo037ooooo0ol0000jooooo`;o00008_ooool2o`0002cooooo0_l0001Boooo
o`;o00005Oooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo01gooooo0_l0000Booooo`?o
00008_ooool2o`0003Cooooo0_l0000booooo`;o00000oooool2o`0004;ooooo0_l00003ooooo`;o
00001?ooool2o`0002_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Oooool2
o`0003Oooooo0_l0000dooooo`;o0000=oooool4o`0003Oooooo0_l00007ooooo`;o00000oooool2
o`00037ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Wooooo
0_l0000aooooo`;o00006Oooool2o`0003Oooooo0_l0000oooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0007Wooooo0_l0000aooooo`;o0000Toooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0DOooool2o`0000Oooooo0_l0001Jooooo`;o0000ROooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0_ooooo`;o00008?ooool2o`0000Oooooo0_l0001J
ooooo`;o0000ROooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool2o`00
00?ooooo0_l0000=ooooo`;o00004_ooool2o`000>Sooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0=?ooool2o`0000gooooo0_l000000ooooooo0000o`00000?ooooo`;o0000j?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`;o0000>Oooool2o`0000cooooo0_l00012ooooo`;o00002?ooool2o`0003;o
oooo0_l0001Aooooo`;o00009?ooool002Cooooo00?o0000ooooooooool06oooool2o`0001Sooooo
0_l000000ooooooo0000o`00000looooo`;o00004_ooool2o`0000Sooooo0_l0000booooo`;o0000
DOooool2o`0002Cooooo000Tooooo`03o`000?oooooooooo01_ooooo0_l0000Hooooo`;o0000?ooo
ool2o`000<Wooooo000Tooooo`03o`000?oooooooooo04Wooooo0_l0001Tooooo`;o0000T?ooool0
02Cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l0001Tooooo`;o0000T?ooool002Co
oooo0ol00015ooooo`;o0000n_ooool002Cooooo0ol0000Jooooo`;o0000^?ooool2o`0006_ooooo
000Tooooo`03o`000?oooooooooo01[ooooo0_l0001[ooooo`;o0000Boooool2o`0006_ooooo000T
ooooo`03o`000?oooooooooo02kooooo0_l0001Gooooo`;o0000AOooool2o`00077ooooo000Toooo
o`03o`000?oooooooooo01Gooooo0_l0000Gooooo`;o0000Soooool2o`0000gooooo0_l00018oooo
o`;o00009oooool002Cooooo00?o0000ooooooooool05Oooool2o`0005Wooooo0_l0001=ooooo`;o
0000Eoooool2o`0000_ooooo0_l0000Jooooo`009?ooool2o`0001Wooooo0_l0001;ooooo`;o0000
2Oooool2o`00037ooooo0_l00020ooooo`;o00006_ooool002Cooooo00?o0000ooooooooool01ooo
ool2o`0000oooooo0_l0001;ooooo`;o0000??ooool2o`0009cooooo000Tooooo`03o`000?oooooo
oooo00Oooooo0_l0000aooooo`;o000000?oooooo`000?l00000ooooool3ooooo`009?ooool00ol0
003oooooooooo`0jooooo`;o000000?oooooo`000?l00000OOooool2o`0004Kooooo0_l00004oooo
o`;o0000=Oooool002Cooooo00?o0000ooooooooool0SOooool2o`0002gooooo0_l0000=ooooo`;o
0000=oooool2o`0000Cooooo0_l0000eooooo`009?ooool2o`0008kooooo0_l0000looooo`;o0000
Hoooool2o`0000oooooo000Tooooo`03o`000?oooooooooo027ooooo0_l0003oooooo`kooooo0_l0
000?ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Qooooo`;o0000>oooool2o`000>7ooooo
0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`1Nooooo`;o0000b?ooool2o`0001Oooooo0009ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
:Oooool2o`0001Oooooo0009ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`?o0000oooooom2ooooo`002Oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002Go
oooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04gooooo0_l0003;ooooo`;o00009Oooool000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0COooool2o`000?;o
oooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooooooo
ool0J?ooool2o`000=Oooooo000Tooooo`;o0000JOooool2o`0002Kooooo0_l0002_ooooo`009?oo
ool01?l0003oooooooooooooool2o`0008gooooo0_l0002Gooooo`;o00005_ooool002Cooooo00Co
0000oooooooooooooooo0_l0003oooooobOooooo0_l0000Fooooo`009?ooool00ol0003ooooooooo
o`3ooooooaKooooo0_l0000Zooooo`009?ooool00ol0003oooooooooo`0gooooo`;o0000g?ooool2
o`0002[ooooo000Tooooo`;o0000>?ooool2o`0000Kooooo0_l00021ooooo`;o0000OOooool002Co
oooo00?o0000ooooooooool0?oooool2o`0002cooooo0_l0001Cooooo`;o0000<Oooool2o`0004[o
oooo000Tooooo`03o`000?oooooooooo06gooooo0_l0001Rooooo`;o00005oooool2o`0000Wooooo
0_l0001:ooooo`009?ooool00ol0003oooooooooo`3Aooooo`;o00005oooool2o`0005Gooooo000T
ooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo0_l0000;ooooo`;o0000Woooool2o`00
09Cooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0002Oooooo`;o0000NOooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000
i?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000>ooooo`009?ooool00ol0003ooooooooo
o`05ooooo`;o0000>Oooool2o`0003gooooo0_l0001^ooooo`;o0000D?ooool002Cooooo00Co0000
ooooool0003o00001?ooool2o`0007Sooooo0_l0001^ooooo`;o00008Oooool2o`0002gooooo000T
ooooo`Co0000oooooolBooooo`;o0000;Oooool002Cooooo00?o0000ooooooooool0ooooool8oooo
o`;o00008oooool2o`0001?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo09[ooooo0_l0000jooooo`;o0000;oooool2o`0002?ooooo0_l0000Cooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0V_ooool2o`0003[ooooo0_l00017ooooo`;o0000
8?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolPooooo`;o00008?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooo`;ooooo0_l0000nooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo067ooooo0_l0000Hooooo`;o0000Q?ooool2
o`0003kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo0_l0000Hoooo
o`;o0000a?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`1R
ooooo`;o00000oooool2o`00067ooooo0_l0000Hooooo`;o0000Foooool002Cooooo00?o0000oooo
ooooool0H_ooool2o`0000?ooooo0_l0001Qooooo`;o00006?ooool2o`0003gooooo0_l0000Loooo
o`009?ooool00ol0003oooooooooo`1Iooooo`;o0000b?ooool2o`0001cooooo000Tooooo`03o`00
0?oooooooooo04;ooooo0_l0000Eooooo`;o0000i_ooool002Cooooo0_l00013ooooo`;o00003?oo
ool2o`0005Kooooo0_l0002Gooooo`009?ooool00ol0003oooooooooo`1@ooooo`;o0000E_ooool2
o`0009Oooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000;?oo
ool2o`0003;ooooo0_l0003Pooooo`009?ooool00ol0003oooooooooo`0[ooooo`;o0000<_ooool2
o`000>3ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o00008Ooo
ool2o`000?oooooo8?ooool002Cooooo00?o0000ooooooooool08?ooool2o`00053ooooo0_l00019
ooooo`;o0000P_ooool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
07;ooooo0_l00019ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom2ooooo`007?ooool00ol0003oooooooooo`05ooooo`?o0000B?ooool2o`0009_ooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo0_l0002K
ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2ooooo`00
6_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo07cooooo0_l0000Aooooo`;o0000
/?ooool002Cooooo0_l0001mooooo`;o00004Oooool2o`000;3ooooo000Tooooo`03o`000?oooooo
oooo09Sooooo0_l0002Wooooo`009?ooool00ol0003oooooooooo`2Hooooo`;o0000Yoooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`2iooooo`;o0000
Q_ooool002Cooooo0_l0002jooooo`;o0000Q_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0MOooool2o`000<[ooooo0004oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Gooooo0_l0003:ooooo`001?ooool00ol0
003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000ioooool2o`0005Sooooo0004ooooo`03o`00
0?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0ioooool2o`0005Sooooo0004ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmV
IVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`1Dooooo`;o0000joooool002Cooooo00?o0000oooo
ooooool0E?ooool2o`000>_ooooo000Tooooo`03o`000?oooooooooo0>gooooo0_l0001Booooo`00
9?ooool00ol0003oooooooooo`3]ooooo`;o0000D_ooool002Cooooo0_l0003Sooooo`;o0000GOoo
ool002Cooooo00?o0000ooooooooool0h_ooool2o`0005gooooo000Tooooo`03o`000?oooooooooo
0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3f
ooooo`;o0000BOooool000[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0m_ooool2o`0004Wooooo000<oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom2ooooo`003?ooool00ol0003oooooooooo`0>ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0003ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_oo
ool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo@_ooool000[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000oooo
ooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolDooooo`009?ooool0
0ol0003oooooooooo`09ooooo`;o00008Oooool2o`000?oooooo5?ooool002Cooooo00?o0000oooo
ooooool02Oooool2o`000?oooooo=oooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`00
0?oooooooooo06[ooooo0_l0003Eooooo`009?ooool00ol0003oooooooooo`1Zooooo`;o0000eOoo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo09Gooooo0_l0002Zooooo`009?ooool00ol0003oooooooooo`2E
ooooo`;o0000Z_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oo
oooo@oooool002Cooooo00?o0000ooooooooool0Uoooool2o`000:Sooooo0002ooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Uoooool2o`000:Sooooo0004ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00cooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@_ooool0
00Cooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0003ooooood;ooooo0004ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom2oooo
o`001?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`000_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`0Nooooo`;o0000oooooolRoooo
o`009?ooool00ol0003oooooooooo`0Nooooo`;o0000oooooolRooooo`009?ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`2g
ooooo`;o0000R?ooool002Cooooo00?o0000ooooooooool0]oooool2o`0008Sooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000<Cooooo0_l0001looooo`009?ooool0
0ol0003oooooooooo`33ooooo`;o0000O?ooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo
0?oooooo@_ooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0?oooooo@_ooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3ooooood;o
oooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood;ooooo000Looooo`03ogMgMomV
IVKooooo0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`006Oooool01Ol0
003o^[ZjoooooonHV9So410@0?ooooooBoooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03o
oooood_ooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0 0.309017 [
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .07167 Mdot
.03333 .20709 Mdot
.0381 .14327 Mdot
.04286 .26313 Mdot
.04762 .25735 Mdot
.05238 .01066 Mdot
.05714 .14221 Mdot
.0619 .2345 Mdot
.06667 .24232 Mdot
.07143 .05938 Mdot
.07619 .03664 Mdot
.08095 .01785 Mdot
.08571 .03324 Mdot
.09048 .07926 Mdot
.09524 .26287 Mdot
.1 .127 Mdot
.10476 .03366 Mdot
.10952 .12491 Mdot
.11429 .20909 Mdot
.11905 .00244 Mdot
.12381 .06694 Mdot
.13333 .18543 Mdot
.1381 .14513 Mdot
.14286 .0203 Mdot
.14762 .00461 Mdot
.15238 .00252 Mdot
.15714 .07046 Mdot
.1619 .02464 Mdot
.16667 .1611 Mdot
.17143 .23319 Mdot
.17619 .11664 Mdot
.18095 .18183 Mdot
.18571 .20965 Mdot
.19048 .19894 Mdot
.19524 .13421 Mdot
.2 .10159 Mdot
.20476 .21294 Mdot
.20952 .11259 Mdot
.21429 .13266 Mdot
.21905 .11102 Mdot
.22381 .05758 Mdot
.22857 .22623 Mdot
.23333 .0899 Mdot
.2381 .22961 Mdot
.24286 .08238 Mdot
.24762 .18392 Mdot
.25238 .29398 Mdot
.25714 .07869 Mdot
.2619 .1021 Mdot
.26667 .05096 Mdot
.27143 .01636 Mdot
.27619 .02691 Mdot
.28095 .09299 Mdot
.28571 .08059 Mdot
.29048 .0654 Mdot
.29524 .31022 Mdot
.3 .06614 Mdot
.30476 .07471 Mdot
.30952 .25889 Mdot
.31429 .00498 Mdot
.31905 .42029 Mdot
.32381 .14706 Mdot
.32857 .06719 Mdot
.33333 .32173 Mdot
.3381 .07242 Mdot
.34286 .13126 Mdot
.34762 .12632 Mdot
.35238 .47518 Mdot
.35714 .16933 Mdot
.3619 .22401 Mdot
.36667 .19883 Mdot
.37143 .37801 Mdot
.37619 .05976 Mdot
.38095 .28418 Mdot
.38571 .1055 Mdot
.39048 .0116 Mdot
.39524 .56767 Mdot
.4 .00533 Mdot
.40476 .0277 Mdot
.40952 .00312 Mdot
.41429 .26006 Mdot
.41905 .25051 Mdot
.42857 .11092 Mdot
.43333 .03578 Mdot
.4381 .05449 Mdot
.44286 .04021 Mdot
.45238 .08824 Mdot
.45714 .01382 Mdot
.4619 .14251 Mdot
.46667 .21233 Mdot
.47143 .13867 Mdot
.47619 .00117 Mdot
.48095 .21194 Mdot
.48571 .06036 Mdot
.49048 .14608 Mdot
.49524 .5789 Mdot
.5 .17943 Mdot
.50952 .13639 Mdot
.51429 .03457 Mdot
.51905 .02784 Mdot
.52381 .09192 Mdot
.52857 .00958 Mdot
.53333 .05761 Mdot
.5381 .07787 Mdot
.54286 .11412 Mdot
.54762 .24436 Mdot
.55238 .29361 Mdot
.55714 .11854 Mdot
.5619 .34169 Mdot
.56667 .07309 Mdot
.57143 .02031 Mdot
.57619 .10097 Mdot
.58095 .03827 Mdot
.58571 .15903 Mdot
.59048 .13767 Mdot
.59524 .08071 Mdot
.6 .35982 Mdot
.60476 .11845 Mdot
.60952 .20548 Mdot
.61429 .19237 Mdot
.61905 .28554 Mdot
.62381 .08443 Mdot
.62857 .04747 Mdot
.63333 .06286 Mdot
.6381 .17567 Mdot
.64286 .12861 Mdot
.64762 .08866 Mdot
.65238 .18684 Mdot
.65714 .17525 Mdot
.6619 .13857 Mdot
.66667 .03029 Mdot
.67143 .28248 Mdot
.67619 .04463 Mdot
.68095 .25858 Mdot
.68571 .2088 Mdot
.69048 .10899 Mdot
.69524 .13337 Mdot
.7 .01231 Mdot
.70476 .0117 Mdot
.70952 .03178 Mdot
.71429 .00556 Mdot
.71905 .01585 Mdot
.72381 .01111 Mdot
.72857 .0111 Mdot
.73333 .34011 Mdot
.7381 .13058 Mdot
.74286 .11045 Mdot
.75238 .24879 Mdot
.75714 .08562 Mdot
.7619 .03781 Mdot
.76667 .21222 Mdot
.77143 .04012 Mdot
.77619 .01089 Mdot
.78095 .00553 Mdot
.78571 .04295 Mdot
.79048 .28641 Mdot
.79524 .45353 Mdot
.8 .04359 Mdot
.80476 .00017 Mdot
.80952 .0061 Mdot
.81429 .03133 Mdot
.81905 .00333 Mdot
.82381 .0716 Mdot
.82857 .08573 Mdot
.83333 .02244 Mdot
.8381 .13448 Mdot
.84286 .34597 Mdot
.84762 .20314 Mdot
.85238 .06794 Mdot
.85714 .19822 Mdot
.8619 .04744 Mdot
.86667 .08428 Mdot
.87143 .00794 Mdot
.87619 .08187 Mdot
.88095 .11221 Mdot
.88571 .30659 Mdot
.89048 .0054 Mdot
.89524 .01419 Mdot
.9 .1195 Mdot
.90476 .15834 Mdot
.90952 .09126 Mdot
.91429 .01586 Mdot
.91905 .30993 Mdot
.92381 .19811 Mdot
.92857 .05236 Mdot
.93333 .25484 Mdot
.9381 .22575 Mdot
.94286 .04914 Mdot
.94762 .01361 Mdot
.95238 .24208 Mdot
.95714 .06142 Mdot
.9619 .00809 Mdot
.96667 .20504 Mdot
.97143 .03246 Mdot
.97619 .10262 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0jooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^03Sooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo001^oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg03oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0=oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo001^oooo
o`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
??ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0hooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool006_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool006_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@03oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@03cooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`00Jooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0>?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool006_ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0?Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03[ooooo00?oEEEEofIVI_l000001Oooool4
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`007?ooooooo`0004Oo00001_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`;o00002Oooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`;o00003Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o00001oooool4o`0000?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo0_l0
000=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00000=ooooo`03o`000?oo
oooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo00?o0000ooooooooool02_ooool3o`0000Kooooo0_l000000ooooooo0000o`00
0004ooooo`03o`000?oooooooooo00cooooo00Co0000ooooool0003o00002oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo02Cooooo0_l0
000dooooo`;o00006_ooool2o`0002Sooooo0_l0000jooooo`;o00005?ooool2o`0000Oooooo0_l0
000Booooo`;o00001?ooool2o`0001Gooooo0_l0000Cooooo`009?ooool00ol0003oooooooooo`05
ooooo`;o0000K?ooool2o`0002_ooooo0_l0000fooooo`?o00001?ooool4o`0000gooooo0_l0000M
ooooo`;o00006oooool2o`0001?ooooo000Tooooo`;o00001_ooool2o`0004Kooooo0_l0000Toooo
o`;o00005?ooool2o`0004gooooo0ol00003ooooo`Go00003Oooool2o`0002Gooooo0_l00004oooo
o`;o00002Oooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo00oooooo0_l0000looooo`;o
0000>_ooool2o`0005?ooooo0_l0000gooooo`;o00001?ooool2o`0000Wooooo0_l0000Gooooo`00
9?ooool00ol0003oooooooooo`0?ooooo`;o00004_ooool2o`0008Wooooo0_l0001Cooooo`;o0000
??ooool002Cooooo00?o0000ooooooooool08oooool2o`0000Cooooo0_l00023ooooo`;o0000Dooo
ool2o`0003cooooo000Tooooo`03o`000?oooooooooo02Wooooo0_l0000Sooooo`;o0000:?ooool2
o`0002?ooooo0_l0002Rooooo`009?ooool2o`0004oooooo0_l0000Xooooo`;o00008oooool2o`00
02kooooo0_l0000<ooooo`;o00008?ooool2o`0004;ooooo000Tooooo`03o`000?oooooooooo013o
oooo0_l00004ooooo`;o0000Poooool2o`00033ooooo0_l0000<ooooo`;o00008?ooool2o`00037o
oooo0_l0000?ooooo`009?ooool00ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0006Wooooo0_l0000Hooooo`;o0000Coooool2o`0004;ooooo0_l0000?ooooo`009?oo
ool00ol0003oooooooooo`0=ooooo`;o0000L_ooool2o`000003ooooool0003o000002_ooooo0_l0
000iooooo`;o000000?oooooo`000?l00000D?ooool002Cooooo00?o0000ooooooooool0Q?ooool2
o`0002_ooooo0_l0000looooo`;o00000_ooool2o`0000?ooooo0_l00017ooooo`009?ooool2o`00
0=7ooooo0_l0000Qooooo`;o00000oooool2o`0004Oooooo000Tooooo`03o`000?oooooooooo0<3o
oooo0_l0000>ooooo`;o0000>_ooool2o`0001Sooooo0_l0000Iooooo`009?ooool00ol0003ooooo
ooooo`1;ooooo`;o0000Loooool2o`0004[ooooo0_l0000Dooooo`;o00000_ooool2o`0001Wooooo
000Tooooo`03o`000?oooooooooo04_ooooo0_l0000fooooo`;o0000WOooool2o`0001gooooo000T
ooooo`03o`000?oooooooooo00cooooo0_l0000_ooooo`;o0000A?ooool2o`0001cooooo0_l0002N
ooooo`009?ooool2o`0000gooooo0_l0000_ooooo`;o0000;oooool2o`0002;ooooo0_l0000=oooo
o`;o0000R?ooool2o`0001Cooooo000Tooooo`03o`000?oooooooooo05?ooooo0_l0000Iooooo`;o
00008_ooool2o`0002kooooo0_l0001Wooooo`;o00005?ooool002Cooooo00?o0000ooooooooool0
7Oooool2o`0003Cooooo0_l000000ooooooo0000o`000007ooooo`;o0000HOooool2o`0004Gooooo
0_l0000fooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`?o00007Oooool2o`0000Sooooo0_l0000]oooo
o`;o00001oooool2o`0009oooooo0_l00007ooooo`;o0000=_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Wooooo`;o0000;_ooool2o`0000Wooooo0_l00018ooooo`;o0000D_oo
ool2o`0003oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000Eoooool2o`0000Wooooo0_l0000o
ooooo`;o00001oooool2o`0009?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01;ooooo0_l0000dooooo`;o00001oooool2o`00053ooooo0_l0000Aooooo`;o0000ROooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Booooo`;o0000;oooool2o`00
00?ooooo0_l00007ooooo`;o0000Hoooool2o`0005Wooooo0_l0000^ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`13ooooo`;o0000N_ooool2o`0002Wooooo0_l0000Eooooo`;o
00002oooool2o`000003ooooool0003o000002kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0@?ooool2o`0004Gooooo0_l0000fooooo`;o00001_ooool2o`00027ooooo0_l0000E
ooooo`;o00002oooool2o`00037ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00047ooooo0_l0000>ooooo`;o0000
=Oooool2o`0001Gooooo0_l0000Wooooo`;o0000D_ooool2o`0002Cooooo000Tooooo`03o`000?oo
oooooooo053ooooo0_l0001<ooooo`;o0000Noooool2o`0002Cooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0=Oooool2o`0001;ooooo0_l0001Toooo
o`;o0000P?ooool2o`0000kooooo000Tooooo`03o`000?oooooooooo03Gooooo0_l0000Booooo`;o
00009oooool2o`0003_ooooo0_l00020ooooo`;o00003_ooool002Cooooo00?o0000ooooooooool0
L_ooool2o`000<gooooo000Tooooo`;o0000?Oooool2o`00047ooooo0_l0001Cooooo`;o00003ooo
ool2o`0005[ooooo000Tooooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o0000@Oooool2
o`0002Cooooo0_l0000]ooooo`;o00003oooool2o`0002_ooooo0_l0000]ooooo`009?ooool00ol0
003oooooooooo`0^ooooo`;o00002?ooool2o`0006_ooooo0_l0001[ooooo`;o0000;Oooool002Co
oooo00?o0000ooooooooool0;_ooool2o`0007Wooooo0_l0000>ooooo`;o0000GOooool2o`0002Oo
oooo000Tooooo`03o`000?oooooooooo0:Wooooo0_l0000>ooooo`;o0000GOooool2o`0002Oooooo
000Tooooo`;o00005_ooool2o`000003ooooool0003o000004_ooooo0_l0003Jooooo`009?ooool0
0ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l00000Boooool2o`0005kooooo0_l0001j
ooooo`009?ooool00ol0003oooooooooo`0jooooo`;o0000:?ooool2o`0005oooooo0_l0000?oooo
o`;o00003?ooool2o`0005_ooooo000Tooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`;o
0000:?ooool2o`0003Cooooo0_l0000jooooo`;o00003?ooool2o`0001kooooo0_l0000kooooo`00
9?ooool00ol0003oooooooooo`0dooooo`;o0000Eoooool2o`0000_ooooo0_l0000Hooooo`;o0000
5Oooool2o`0003Oooooo0_l0000kooooo`009?ooool2o`0000Sooooo0_l00021ooooo`;o000000?o
ooooo`000?l000009Oooool2o`0001Gooooo0_l0001dooooo`009?ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l0000Hooooo`;o0000Ioooool2o`000;Gooooo0009ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`00
0?ooooooooooooooo`;o00007_ooool2o`0003_ooooo0_l0000dooooo`;o0000Zoooool000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo05kooooo0_l0000dooooo`;o0000Zoooool000Wooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo@_ooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0[ooooo`;o0000QOooool2o`0006Kooooo0_l0000Uoooo
o`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0[ooooo`;o0000QOooool2o`0006Kooooo0_l0000Uooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
od;ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool0J?ooool2o`000=Oooooo000Tooooo`;o0000JOooool2o`000=Oooooo000Tooooo`03o`00
0?oooooooooo0<?ooooo0_l00005ooooo`;o0000MOooool002Cooooo00?o0000ooooooooool0Uooo
ool2o`0002[ooooo0_l00005ooooo`;o0000MOooool002Cooooo00?o0000ooooooooool0;oooool2
o`0006Kooooo0_l0002Xooooo`009?ooool00ol0003oooooooooo`0Pooooo`;o00003Oooool2o`00
01Cooooo0_l0003jooooo`009?ooool2o`00027ooooo0_l0000Sooooo`;o0000POooool2o`0007Oo
oooo000Tooooo`03o`000?oooooooooo0<Sooooo0_l0001gooooo`009?ooool00ol0003ooooooooo
o`2looooo`;o0000Poooool002Cooooo00?o0000ooooooooool0_?ooool2o`0004cooooo0_l0000D
ooooo`;o00007oooool002Cooooo00?o0000ooooooooool0<_ooool2o`0003Oooooo0_l0002Moooo
o`;o00005?ooool2o`0001oooooo000Tooooo`;o0000<oooool2o`0003Oooooo0_l0002Jooooo`;o
0000>?ooool002Cooooo00Co0000ooooool0003o0000^Oooool2o`0004_ooooo0_l0000Uooooo`;o
00004Oooool002Cooooo00Co0000ooooool0003o00006Oooool2o`0001Gooooo0_l00027ooooo`;o
00005oooool2o`0005Wooooo0_l0000Aooooo`009?ooool00ol0003oooooooooo`0Jooooo`;o0000
5Oooool2o`0000Cooooo0_l0001Cooooo`;o00000_ooool2o`00047ooooo0_l0000Hooooo`;o0000
D_ooool002Cooooo00?o0000ooooooooool0=oooool2o`0005?ooooo0_l00002ooooo`;o0000Fooo
ool2o`0005;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06[ooooo0_l0
002iooooo`;o00006_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03oooooo
0_l0000Yooooo`;o0000^Oooool2o`0001[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03oooooo0_l000000ooooooo0000o`00003mooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3
o`0000Wooooo0_l0000Qooooo`;o00005?ooool2o`000?gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool02Oooool2o`00027ooooo0_l0003ooooooaCooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`;o0000V_ooool2o`00087ooooo0_l0000Fooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
2_ooool2o`0009[ooooo0_l00021ooooo`;o00005_ooool002Cooooo0_l0001mooooo`;o0000Jooo
ool2o`0005Kooooo000Tooooo`03o`000?oooooooooo07cooooo0_l0001[ooooo`;o0000E_ooool0
02Cooooo00?o0000ooooooooool0oooooolTooooo`;o00007?ooool002Cooooo00?o0000oooooooo
ool01?ooool2o`0005?ooooo0_l0001fooooo`;o0000D?ooool2o`0001cooooo000Tooooo`03o`00
0?oooooooooo00Cooooo0_l0000=ooooo`;o0000A?ooool2o`00023ooooo0_l0001Dooooo`;o0000
K_ooool002Cooooo0_l00003ooooo`;o00003oooool2o`0006Kooooo0_l00034ooooo`009?ooool0
0ol0003oooooooooo`02ooooo`;o0000oooooolnooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0
oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0L?ooool2
o`0005cooooo0_l0001aooooo`009?ooool00ol0003oooooooooo`1`ooooo`;o0000Boooool2o`00
00oooooo0_l0000Uooooo`;o0000B_ooool002Cooooo00?o0000ooooooooool0_Oooool2o`0003Ko
oooo0_l0001:ooooo`009?ooool00ol0003oooooooooo`2Xooooo`;o0000Uoooool002Cooooo0_l0
0017ooooo`;o0000H?ooool2o`0009Oooooo000Tooooo`03o`000?oooooooooo04Kooooo0_l0003i
ooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom2oooo
o`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaGooooo0_l0000[ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`?o0000E?ooool2o`000;kooooo0_l00009ooooo`;o00008?oo
ool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`;o0000bOooool2
o`00023ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom2oooo
o`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@_ooool001[ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1Qooooo`;o0000g_ooool002Cooooo0_l0
001Rooooo`;o0000g_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0h_ooool2o`0005gooooo000Tooooo`;o0000[?ooool2o`0003Gooooo0_l0
001Mooooo`009?ooool00ol0003oooooooooo`2[ooooo`;o0000FOooool2o`0003Wooooo000Toooo
o`03o`000?oooooooooo0?oooooo1oooool2o`0003Wooooo000Tooooo`03o`000?oooooooooo0?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@ooo
ool002Cooooo00?o0000ooooooooool0]oooool2o`0008Sooooo000Tooooo`03o`000?oooooooooo
0;Oooooo0_l00028ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`00
0?oooooooooo0?oooooo@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooo
oooo0?oooooo@_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06gooooo0_l0003B
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1]ooooo`;o0000d_ooool0
00Cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo@_ooool000Cooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@_ooool000Cooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`03oeEEEOmV
IVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000oooooooo
ool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000GOoo
ool2o`000>?ooooo000Tooooo`03o`000?oooooooooo05cooooo0_l0003Sooooo`009?ooool00ol0
003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0m_ooool2o`0004Wooooo000:oooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?Kooooo0_l00019ooooo`003?ooool00ol0003oooooooooo`04oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@_ooool000co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oo
oooo@_ooool000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000
oooooom2ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Wooooo`;o0000f?ooool0
00[ooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0Ioooool2o`00
0=Sooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_oo
ool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooo
od;ooooo000Tooooo`;o0000oooooom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2
ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`;o0000oooooom3ooooo`00
9?ooool00ol0003oooooooooo`3ooooood;ooooo0002ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0oooooom2ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom2ooooo`001?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3ooooood;ooooo0004ooooo`03o`000?oooooooooo
00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom2oooo
o`001?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@_ooool000Cooooo00?o0000oooooooo
ool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom2ooooo`001?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@_ooool000;ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo
@_ooool002Cooooo0_l0003ooooood?ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool0
02Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`1eooooo`;o
0000b_ooool002Cooooo00?o0000ooooooooool0MOooool2o`000<[ooooo000Tooooo`;o0000oooo
oom3ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo
09Gooooo0_l0002Zooooo`009?ooool00ol0003oooooooooo`2Eooooo`;o0000Z_ooool002Cooooo
00?o0000ooooooooool0oooooom2ooooo`009?ooool2o`000?oooooo@oooool002Cooooo00?o0000
ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo000Tooooo`03
o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?oo
ool2o`000?oooooo@oooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool5o`00
00Kooooo00?o0000ooooooooool0oooooom2ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0oooooom2ooooo`006_ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo0?oooooo@_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo
@_ooool001cooooo00?oMgMgofIVI_ooool0oooooom:ooooo`007Oooool00ol0003oooooooooo`3o
ooooodWooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@4100oooooom;ooooo`006Oooool01OnH
V9So410@o`000?lQ8B7oc<c<0?ooooooBoooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.608, -0.152711, \
0.809369, 0.0124722}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tThe system rapidly approaches equilibrium. This can also be seen by \
evaluating the potential energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  " of the system as a function of time, as seen in Cell ",
  ButtonBox["8.31",
    ButtonData:>"Cell 8.31",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(U[
          n_]\  := \(U[
            n]\  = \ \ Sum[\ \[Phi][x[j, n]], {j, 1, 200}]\);\)\), "\n", 
    \(\(ListPlot[Table[U[n], {n, 0, 300}], 
        AxesLabel \[Rule] {"\<n\>", "\<potential energy\>"}, 
        PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.36"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0206349 0.0031746 -0.39729 0.00500305 [
[.17937 -0.00955 -6 -9 ]
[.17937 -0.00955 6 0 ]
[.3381 -0.00955 -9 -9 ]
[.3381 -0.00955 9 0 ]
[.49683 -0.00955 -9 -9 ]
[.49683 -0.00955 9 0 ]
[.65556 -0.00955 -9 -9 ]
[.65556 -0.00955 9 0 ]
[.81429 -0.00955 -9 -9 ]
[.81429 -0.00955 9 0 ]
[.97302 -0.00955 -9 -9 ]
[.97302 -0.00955 9 0 ]
[1.025 .00295 0 -6 ]
[1.025 .00295 10 6 ]
[.00813 .10301 -18 -4.5 ]
[.00813 .10301 0 4.5 ]
[.00813 .20308 -18 -4.5 ]
[.00813 .20308 0 4.5 ]
[.00813 .30314 -18 -4.5 ]
[.00813 .30314 0 4.5 ]
[.00813 .4032 -18 -4.5 ]
[.00813 .4032 0 4.5 ]
[.00813 .50326 -18 -4.5 ]
[.00813 .50326 0 4.5 ]
[.00813 .60332 -18 -4.5 ]
[.00813 .60332 0 4.5 ]
[.02063 .64303 -50 0 ]
[.02063 .64303 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17937 .00295 m
.17937 .0092 L
s
[(50)] .17937 -0.00955 0 1 Mshowa
.3381 .00295 m
.3381 .0092 L
s
[(100)] .3381 -0.00955 0 1 Mshowa
.49683 .00295 m
.49683 .0092 L
s
[(150)] .49683 -0.00955 0 1 Mshowa
.65556 .00295 m
.65556 .0092 L
s
[(200)] .65556 -0.00955 0 1 Mshowa
.81429 .00295 m
.81429 .0092 L
s
[(250)] .81429 -0.00955 0 1 Mshowa
.97302 .00295 m
.97302 .0092 L
s
[(300)] .97302 -0.00955 0 1 Mshowa
.125 Mabswid
.05238 .00295 m
.05238 .0067 L
s
.08413 .00295 m
.08413 .0067 L
s
.11587 .00295 m
.11587 .0067 L
s
.14762 .00295 m
.14762 .0067 L
s
.21111 .00295 m
.21111 .0067 L
s
.24286 .00295 m
.24286 .0067 L
s
.2746 .00295 m
.2746 .0067 L
s
.30635 .00295 m
.30635 .0067 L
s
.36984 .00295 m
.36984 .0067 L
s
.40159 .00295 m
.40159 .0067 L
s
.43333 .00295 m
.43333 .0067 L
s
.46508 .00295 m
.46508 .0067 L
s
.52857 .00295 m
.52857 .0067 L
s
.56032 .00295 m
.56032 .0067 L
s
.59206 .00295 m
.59206 .0067 L
s
.62381 .00295 m
.62381 .0067 L
s
.6873 .00295 m
.6873 .0067 L
s
.71905 .00295 m
.71905 .0067 L
s
.75079 .00295 m
.75079 .0067 L
s
.78254 .00295 m
.78254 .0067 L
s
.84603 .00295 m
.84603 .0067 L
s
.87778 .00295 m
.87778 .0067 L
s
.90952 .00295 m
.90952 .0067 L
s
.94127 .00295 m
.94127 .0067 L
s
.25 Mabswid
0 .00295 m
1 .00295 L
s
gsave
1.025 .00295 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02063 .10301 m
.02688 .10301 L
s
[(100)] .00813 .10301 1 0 Mshowa
.02063 .20308 m
.02688 .20308 L
s
[(120)] .00813 .20308 1 0 Mshowa
.02063 .30314 m
.02688 .30314 L
s
[(140)] .00813 .30314 1 0 Mshowa
.02063 .4032 m
.02688 .4032 L
s
[(160)] .00813 .4032 1 0 Mshowa
.02063 .50326 m
.02688 .50326 L
s
[(180)] .00813 .50326 1 0 Mshowa
.02063 .60332 m
.02688 .60332 L
s
[(200)] .00813 .60332 1 0 Mshowa
.125 Mabswid
.02063 .02797 m
.02438 .02797 L
s
.02063 .05298 m
.02438 .05298 L
s
.02063 .078 m
.02438 .078 L
s
.02063 .12803 m
.02438 .12803 L
s
.02063 .15304 m
.02438 .15304 L
s
.02063 .17806 m
.02438 .17806 L
s
.02063 .22809 m
.02438 .22809 L
s
.02063 .25311 m
.02438 .25311 L
s
.02063 .27812 m
.02438 .27812 L
s
.02063 .32815 m
.02438 .32815 L
s
.02063 .35317 m
.02438 .35317 L
s
.02063 .37818 m
.02438 .37818 L
s
.02063 .42821 m
.02438 .42821 L
s
.02063 .45323 m
.02438 .45323 L
s
.02063 .47824 m
.02438 .47824 L
s
.02063 .52827 m
.02438 .52827 L
s
.02063 .55329 m
.02438 .55329 L
s
.02063 .5783 m
.02438 .5783 L
s
.25 Mabswid
.02063 0 m
.02063 .61803 L
s
gsave
.02063 .64303 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(potential) show
123.000 13.000 moveto
(energy) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.02381 .60332 Mdot
.02698 .52924 Mdot
.03016 .49644 Mdot
.03333 .46 Mdot
.03651 .4251 Mdot
.03968 .4004 Mdot
.04286 .36184 Mdot
.04603 .34759 Mdot
.04921 .3243 Mdot
.05238 .27486 Mdot
.05556 .27224 Mdot
.05873 .28483 Mdot
.0619 .26959 Mdot
.06508 .2417 Mdot
.06825 .26735 Mdot
.07143 .25573 Mdot
.0746 .24805 Mdot
.07778 .2438 Mdot
.08095 .25574 Mdot
.08413 .22773 Mdot
.0873 .19573 Mdot
.09048 .21565 Mdot
.09365 .20183 Mdot
.09683 .18922 Mdot
.1 .19113 Mdot
.10317 .16396 Mdot
.10635 .13978 Mdot
.10952 .12856 Mdot
.1127 .10735 Mdot
.11587 .13933 Mdot
.11905 .13529 Mdot
.12222 .11917 Mdot
.1254 .1269 Mdot
.12857 .142 Mdot
.13175 .12625 Mdot
.13492 .11757 Mdot
.1381 .09583 Mdot
.14127 .10469 Mdot
.14444 .10604 Mdot
.14762 .10612 Mdot
.15079 .11816 Mdot
.15397 .14653 Mdot
.15714 .14073 Mdot
.16032 .12187 Mdot
.16349 .12009 Mdot
.16667 .10411 Mdot
.16984 .0728 Mdot
.17302 .08893 Mdot
.17619 .08294 Mdot
.17937 .06767 Mdot
.18254 .07082 Mdot
.18571 .05334 Mdot
.18889 .05413 Mdot
.19206 .06021 Mdot
.19524 .04794 Mdot
.19841 .04194 Mdot
.20159 .06513 Mdot
.20476 .07898 Mdot
.20794 .07746 Mdot
.21111 .07603 Mdot
.21429 .09134 Mdot
.21746 .07064 Mdot
.22063 .0787 Mdot
.22381 .07777 Mdot
.22698 .06595 Mdot
.23016 .09098 Mdot
.23333 .10611 Mdot
.23651 .11481 Mdot
.23968 .08185 Mdot
.24286 .04438 Mdot
.24603 .04224 Mdot
.24921 .02693 Mdot
.25238 .04771 Mdot
.25556 .03576 Mdot
.25873 .01472 Mdot
.2619 .02933 Mdot
.26508 .04621 Mdot
.26825 .02949 Mdot
.27143 .04162 Mdot
.2746 .05295 Mdot
.27778 .0569 Mdot
.28095 .06621 Mdot
.28413 .06228 Mdot
.2873 .05966 Mdot
.29048 .06732 Mdot
.29365 .06428 Mdot
.29683 .06313 Mdot
.3 .06989 Mdot
.30317 .07757 Mdot
.30635 .07921 Mdot
.30952 .07891 Mdot
.3127 .10593 Mdot
.31587 .07499 Mdot
.31905 .10558 Mdot
.32222 .10447 Mdot
.3254 .12296 Mdot
.32857 .0799 Mdot
.33175 .07123 Mdot
.33492 .08194 Mdot
.3381 .06946 Mdot
.34127 .06737 Mdot
.34444 .07001 Mdot
.34762 .06439 Mdot
.35079 .08081 Mdot
.35397 .09282 Mdot
.35714 .12432 Mdot
.36032 .10635 Mdot
.36349 .11868 Mdot
.36667 .13429 Mdot
.36984 .13047 Mdot
.37302 .14566 Mdot
.37619 .12725 Mdot
.37937 .13319 Mdot
.38254 .14689 Mdot
.38571 .1257 Mdot
.38889 .12001 Mdot
.39206 .12363 Mdot
.39524 .10806 Mdot
.39841 .07983 Mdot
.40159 .07721 Mdot
.40476 .07328 Mdot
.40794 .08198 Mdot
.41111 .101 Mdot
.41429 .09309 Mdot
.41746 .09362 Mdot
.42063 .12087 Mdot
.42381 .11595 Mdot
.42698 .12283 Mdot
.43016 .13565 Mdot
.43333 .13497 Mdot
.43651 .14349 Mdot
.43968 .16705 Mdot
.44286 .14751 Mdot
.44603 .13046 Mdot
.44921 .11975 Mdot
.45238 .12714 Mdot
.45556 .12377 Mdot
.45873 .12949 Mdot
.4619 .10081 Mdot
.46508 .09297 Mdot
.46825 .07117 Mdot
.47143 .08796 Mdot
.4746 .09484 Mdot
.47778 .08672 Mdot
.48095 .09236 Mdot
.48413 .0923 Mdot
.4873 .07496 Mdot
.49048 .07077 Mdot
.49365 .07425 Mdot
.49683 .08857 Mdot
.5 .10672 Mdot
.50317 .12464 Mdot
.50635 .11089 Mdot
.50952 .12018 Mdot
.5127 .12027 Mdot
.51587 .12562 Mdot
.51905 .15073 Mdot
.52222 .13609 Mdot
.5254 .14639 Mdot
.52857 .15492 Mdot
.53175 .16472 Mdot
.53492 .16162 Mdot
.5381 .16027 Mdot
.54127 .17022 Mdot
.54444 .1458 Mdot
.54762 .13248 Mdot
.55079 .13244 Mdot
.55397 .11253 Mdot
.55714 .0708 Mdot
.56032 .09721 Mdot
.56349 .09375 Mdot
.56667 .10345 Mdot
.56984 .07021 Mdot
.57302 .08333 Mdot
.57619 .11446 Mdot
.57937 .09801 Mdot
.58254 .0935 Mdot
.58571 .0567 Mdot
.58889 .05017 Mdot
.59206 .05746 Mdot
.59524 .06796 Mdot
.59841 .10604 Mdot
.60159 .09422 Mdot
.60476 .118 Mdot
.60794 .10971 Mdot
.61111 .10521 Mdot
.61429 .11811 Mdot
.61746 .11234 Mdot
.62063 .11605 Mdot
.62381 .14987 Mdot
.62698 .16793 Mdot
.63016 .12941 Mdot
.63333 .11687 Mdot
.63651 .07533 Mdot
.63968 .07405 Mdot
.64286 .07466 Mdot
.64603 .09769 Mdot
.64921 .07514 Mdot
.65238 .08633 Mdot
.65556 .06316 Mdot
.65873 .06568 Mdot
.6619 .04873 Mdot
.66508 .05693 Mdot
.66825 .05418 Mdot
.67143 .06302 Mdot
.6746 .06856 Mdot
.67778 .03972 Mdot
.68095 .04985 Mdot
.68413 .07685 Mdot
.6873 .05472 Mdot
.69048 .04241 Mdot
.69365 .03951 Mdot
.69683 .04614 Mdot
.7 .06462 Mdot
.70317 .05599 Mdot
.70635 .08257 Mdot
.70952 .06578 Mdot
.7127 .07863 Mdot
.71587 .09385 Mdot
.71905 .10759 Mdot
.72222 .07885 Mdot
.7254 .07911 Mdot
.72857 .10656 Mdot
.73175 .09817 Mdot
.73492 .08501 Mdot
.7381 .087 Mdot
.74127 .07515 Mdot
.74444 .10157 Mdot
.74762 .07496 Mdot
.75079 .09367 Mdot
.75397 .07477 Mdot
.75714 .09715 Mdot
.76032 .11025 Mdot
.76349 .08486 Mdot
.76667 .1091 Mdot
.76984 .0997 Mdot
.77302 .08673 Mdot
.77619 .06667 Mdot
.77937 .06382 Mdot
.78254 .05965 Mdot
.78571 .1021 Mdot
.78889 .115 Mdot
.79206 .12232 Mdot
.79524 .12817 Mdot
.79841 .12406 Mdot
.80159 .12459 Mdot
.80476 .12281 Mdot
.80794 .11547 Mdot
.81111 .11434 Mdot
.81429 .11072 Mdot
.81746 .12185 Mdot
.82063 .10682 Mdot
.82381 .11518 Mdot
.82698 .11898 Mdot
.83016 .08549 Mdot
.83333 .10197 Mdot
.83651 .11693 Mdot
.83968 .08538 Mdot
.84286 .08148 Mdot
.84603 .07192 Mdot
.84921 .12137 Mdot
.85238 .12183 Mdot
.85556 .11497 Mdot
.85873 .10283 Mdot
.8619 .0683 Mdot
.86508 .07667 Mdot
.86825 .07979 Mdot
.87143 .09547 Mdot
.8746 .07921 Mdot
.87778 .09496 Mdot
.88095 .1216 Mdot
.88413 .11035 Mdot
.8873 .1282 Mdot
.89048 .11295 Mdot
.89365 .0689 Mdot
.89683 .03699 Mdot
.9 .06719 Mdot
.90317 .04833 Mdot
.90635 .04261 Mdot
.90952 .03664 Mdot
.9127 .01496 Mdot
.91587 .04275 Mdot
.91905 .06276 Mdot
.92222 .05791 Mdot
.9254 .03374 Mdot
.92857 .05951 Mdot
.93175 .05816 Mdot
.93492 .05003 Mdot
.9381 .06366 Mdot
.94127 .05931 Mdot
.94444 .0709 Mdot
.94762 .07854 Mdot
.95079 .09674 Mdot
.95397 .08117 Mdot
.95714 .11081 Mdot
.96032 .11364 Mdot
.96349 .11214 Mdot
.96667 .09336 Mdot
.96984 .09261 Mdot
.97302 .09911 Mdot
.97619 .12061 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00I@3oool01@14A4@000000000000c<c<0gMgM0080
oooo00D0k^k^03<c<`000000<c<c0>k^kP0M0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`00
0000<c<c0>k^kP<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0I0?ooo`@0000000D04A4A0?ooo`3o
ool0oooo04A4A0020000000903<c<`3MgMd0oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^01P0oooo
1@0000030?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^
01L0oooo1@0000040?ooo`0504A4A0000000000003<c<`3MgMd00P3oool01@3^k^h0<c<c0000000c
<c<0k^k^01P0oooo00D0VIVI014A4@000000<c<c0<c<c0030?ooo`050>k^kP0c<c<0000003<c<`3^
k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^01<0oooo001X0?ooo`0907MgM`0c<c<0oooo0?oo
o`1gMgL0VIVI0?ooo`2IVIT0MgMg01l0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0K0?ooo`030000003oool0oooo00H0
oooo00T0MgMg03<c<`3oool0oooo07MgM`2IVIT0oooo09VIV@1gMgL0603oool01@2IVIT08R8R0>k^
kP3oool0A4A400<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL05`3oool01@2IVIT08R8R0>k^kP3oool0A4A400L0oooo00T0MgMg03<c<`3oool0oooo07Mg
M`2IVIT0oooo09VIV@1gMgL0603oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00<0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL04`3oool006T0oooo00@00000
0?ooo`3oool04A4A0`3oool00`0A4A40oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00D0
4A4A0?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A406`3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo014A4@<0oooo00<04A4A0?ooo`3oool05`3oool00`2I
VIT08R8R0>k^kP040?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3o
ool04A4A01P0oooo00<0VIVI028R8P3^k^h02@3oool010000000oooo0?ooo`0A4A430?ooo`03014A
4@3oool0oooo01X0oooo00D000000?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?oo
o`0A4A400`3oool00`0A4A40oooo0?ooo`0A0?ooo`00J03oool01@1gMgL0<c<c0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool01P3o
ool01@1gMgL0<c<c0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0603oool00`2IVIT08R8R
0>k^kP030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
01T0oooo00<0VIVI028R8P3^k^h01`3oool01@1gMgL0<c<c0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool06@3oool00`2ZZZX04A4A0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000001<0oooo001U0?ooo`050000000R8R80000003<c<`3<c<`0
0P3oool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0
oooo00<0oooo00D00000028R8P000000<c<c0<c<c0020?ooo`050000003oool0oooo0?ooo`000000
6`3oool00`1gMgL0IVIV0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000001X0oooo00<0MgMg06IVIP3oool00`3oool01@0000008R8R0000000c<c<0
c<c<0080oooo00D000000?ooo`3oool0oooo0000000J0?ooo`03014A4@000000^k^k00<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000004`3oool006D0oooo
00<000000?ooo`3oool0103oool01@0A4A40oooo0?ooo`3oool04A4A01l0oooo00<000000?ooo`3o
ool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@0K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@0A4A40oooo0?ooo`3o
ool04A4A01`0oooo00D000000?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A
4A400`3oool00`0A4A40oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool01@0A4A40oooo0?ooo`3oool04A4A01/0oooo00<0^k^k028R8P3oool00P3oool01@0A
4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@0C0?ooo`00I@3oool0
0`000000oooo0?ooo`040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL07`3oool00`000000oooo0?oo
o`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg01/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL0603oool01@000000^k^k0?ooo`2IVIT04A4A00<0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL05`3oool01@000000^k^k0?ooo`2IVIT04A4A00@0
oooo00<000000?ooo`3oool0103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg01P0oooo00D04A4A09VI
V@3oool0^k^k000000030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg01<0oooo001U0?ooo`@000000`3oool01@3^k^h0<c<c0000000c<c<0k^k^01d0oooo
0P1EEED00`000000oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0
<c<c0000000c<c<0k^k^01T0oooo0P1EEED00`000000oooo0?ooo`030?ooo`@000000`3oool01@3^
k^h0<c<c0000000c<c<0k^k^01P0oooo00D0VIVI014A4@0000008R8R0<c<c0030?ooo`050>k^kP0c
<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^01L0oooo00D0VIVI014A4@00
00008R8R0<c<c0040?ooo`@000000`3oool01@3^k^h0<c<c0000000c<c<0k^k^01P0oooo00D0ZZZZ
014A4@0000004A4A0:ZZZP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c
0000000c<c<0k^k^01<0oooo003o0?ooofT0oooo003o0?oooel0oooo00@04A4A000000000000oooo
0P0000000`0A4A40oooo0?ooo`010?ooo`00o`3ooomP0?ooo`050000003oool0oooo0?ooo`000000
103oool003h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`050000003oool0oooo0?ooo`000000
103oool003P0ooooo`00000M000000/0oooo00D000000?ooo`3oool0oooo000000040?ooo`00?P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`0500000028R8P0oooo0:ZZZP000000103oool003h0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0403oool00`0A4A40000007MgM`020000000309VIV@3oool0oooo0080oooo000n
0?ooo`030000003oool0oooo0400oooo0P00002g0?ooo`800000;03oool003h0oooo00<000000?oo
o`3oool0@03oool200000;L0oooo0P00000/0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0
oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo0P00000n0?ooo`8000000P3o
ool300000><0oooo000n0?ooo`030000003oool0oooo03d0oooo0P0000020?ooo`<00000h`3oool0
03h0oooo00<000000?ooo`3oool0?`3oool200000;<0oooo0P0000020?ooo`8000000P3oool20000
02T0oooo000n0?ooo`030000003oool0oooo03l0oooo0P00001e0?ooo`8000000`3oool2000003L0
oooo0P0000020?ooo`8000000P3oool2000002T0oooo000n0?ooo`030000003oool0oooo02l0oooo
0P00000;0?ooo`8000001@3oool200000740oooo0P0000020?ooo`<00000>P3oool2000000030?oo
o`000000000002/0oooo000n0?ooo`030000003oool0oooo02l0oooo0P00000:0?ooo`D0000000<0
oooo0000000000000P00001e0?ooo`@00000>@3oool2000000030?ooo`000000000002/0oooo000n
0?ooo`030000003oool0oooo02h0oooo0P00000;0?ooo`80000000@0oooo000000000000oooo0P00
001J0?ooo`8000004`3oool2000000<0oooo0P0000030?ooo`800000>03oool2000000L0oooo0P00
000V0?ooo`00?P3oool2000002`0oooo1@00000D0?ooo`800000E`3oool2000001<0oooo10000000
0`3oool0000000000002000003/0oooo0P0000070?ooo`8000009P3oool003h0oooo00<000000?oo
o`3oool0:`3oool3000001H0oooo0`00001E0?ooo`@000004`3oool3000000<0oooo0P0000020?oo
o`800000?03oool2000000030?ooo`000000000002L0oooo000n0?ooo`030000003oool0oooo02d0
oooo0P00000F0?ooo`80000000<0oooo000000000000DP3oool4000001<0oooo0P0000080?ooo`80
00005@3oool2000002D0oooo1@0000000`3oool000000000000T0?ooo`00?P3oool00`000000oooo
0?ooo`0]0?ooo`80000000<0oooo0000000000005@3oool5000000d0oooo0P00001E0?ooo`800000
0P3oool2000000H0oooo0P00000E0?ooo`<00000903oool2000000040?ooo`00000000000?ooo`<0
0000903oool003h0oooo00<000000?ooo`3oool0:@3oool2000000D0oooo0P0000050?ooo`800000
3@3oool6000000/0oooo100000140?ooo`8000003`3oool3000000040?ooo`0000000000000000D0
oooo0P0000000`3oool000000000000A0?ooo`<000005@3oool2000000L0oooo100000030?ooo`80
0000103oool2000002D0oooo000n0?ooo`030000003oool0oooo02T0oooo0`0000080?ooo`800000
00<0oooo0000000000003@3oool2000000030?ooo`0000000000008000001`3oool600000240oooo
0P0000040?ooo`8000004@3oool200000080oooo0P0000050?ooo`800000403oool200000080oooo
0P0000080?ooo`8000004@3oool200000180oooo0P0000020?ooo`8000001`3oool4000000/0oooo
0P00000S0?ooo`00?P3oool00`000000oooo0?ooo`0W0?ooo`80000000<0oooo0000000000001P3o
ool4000001D0oooo0P0000030?ooo`8000000P3oool6000000l0oooo0P00000@0?ooo`8000000`3o
ool400000100oooo0P0000020?ooo`8000004@3oool5000001P0oooo1P00000H0?ooo`8000006P3o
ool2000002<0oooo000n0?ooo`800000:03oool2000000L0oooo10000000103oool0000000000000
000D0?ooo`H000005P3oool3000001D0oooo1000000W0?ooo`D00000203oool2000000H0oooo0P00
0000103oool000000000000000020?ooo`H000007@3oool2000000030?ooo`00000000000180oooo
0P00000S0?ooo`00?P3oool00`000000oooo0?ooo`0X0?ooo`8000001P3oool300000080oooo0`00
00020?ooo`800000403oool4000000<0oooo100000030?ooo`8000002`3oool5000004`0oooo0P00
00040?ooo`@0000000@0oooo00000000000000007`3oool2000000@0oooo1@00000B0?ooo`@00000
8@3oool003h0oooo00<000000?ooo`3oool0:03oool200000100oooo0P00000G0?ooo`@000000`3o
ool2000000/0oooo0P0000000`3oool000000000000]0?ooo`800000503oool2000000d0oooo0P00
00060?ooo`8000001P3oool200000140oooo0P000000103oool000000000000000050?ooo`800000
5P3oool200000240oooo000n0?ooo`030000003oool0oooo02L0oooo0P00001C0?ooo`@000000`3o
ool2000001@0oooo0P00000D0?ooo`8000005@3oool3000000D0oooo0P0000000`3oool000000000
000>0?ooo`80000000<0oooo000000000000@@3oool003h0oooo00<000000?ooo`3oool09`3oool2
000000X0oooo0P0000030?ooo`8000008@3oool2000000l0oooo0`00000;0?ooo`L000000P3oool2
000001H0oooo0P00000Z0?ooo`8000000P3oool2000000@0oooo0P00000e0?ooo`<00000703oool0
02@0oooo10000000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^0`3oool01@3^k^h0<c<c
0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool07P3oool2000001<0oooo0P0000030?ooo`80
00008@3oool2000000l0oooo0`00000;0?ooo`80000000<0oooo0000000000000P00000D0?ooo`<0
00000`3oool2000000@0oooo0P00000N0?ooo`800000203oool4000001h0oooo1000000B0?ooo`80
00000`3oool3000001`0oooo000V0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`0N0?oo
o`800000G@3oool2000001H0oooo0`0000020?ooo`8000001@3oool2000000X0oooo0P00000B0?oo
o`8000000P3oool2000000H0oooo0P0000000`3oool000000000000K0?ooo`@000004P3oool20000
00D0oooo0P00000K0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool09P3oool2
000004<0oooo0P00000<0?ooo`800000703oool2000000030?ooo`00000000000140oooo0P00000F
0?ooo`8000000P3oool2000000D0oooo0P0000030?ooo`8000002`3oool2000000D0oooo0P00000O
0?ooo`8000006`3oool002H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`<000005P3oool2000000H0oooo1000
00040?ooo`8000004@3oool2000001@0oooo1@0000080?ooo`8000003@3oool2000000`0oooo0P00
00090?ooo`8000004@3oool2000000L0oooo0P0000000`3oool000000000000M0?ooo`80000000<0
oooo0000000000000P3oool2000000X0oooo0P0000080?ooo`80000000<0oooo0000000000001@3o
ool2000003`0oooo000V0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0F0?ooo`800000
1P3oool4000001L0oooo0P00000D0?ooo`D00000203oool2000000P0oooo0P00000L0?ooo`@00000
603oool5000001d0oooo0P0000000`3oool00000000000070?ooo`<00000303oool400000100oooo
0P00000B0?ooo`800000803oool002H0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?oo
o`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo03T0
oooo0P00000[0?ooo`8000007P3oool2000000/0oooo0P0000040?ooo`8000001`3oool200000003
0?ooo`000000000002L0oooo0`00000;0?ooo`<000004P3oool300000140oooo1000000N0?ooo`00
9P3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool07@3oool200000080oooo0P00000F0?oo
o`800000<`3oool2000002<0oooo0P0000040?ooo`8000001`3oool600000080oooo0P00000Z0?oo
o`8000000`3oool3000000030?ooo`00000000000080oooo0P0000030?ooo`800000203oool20000
0180oooo0`00000N0?ooo`00903oool205EEE@030000003oool0oooo0080oooo00D0k^k^03<c<`00
0000<c<c0>k^kP030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0I
0?ooo`8000000P3oool200000080oooo0P000000103oool0000000000000000f0?ooo`8000001P3o
ool2000000H0oooo0`0000060?ooo`8000003`3oool3000001P0oooo1P0000020?ooo`800000:P3o
ool2000000<0oooo0P0000000`3oool0000000000002000000030?ooo`00000000000080oooo0`00
00060?ooo`8000006@3oool2000001X0oooo000n0?ooo`030000003oool0oooo01T0oooo0P000009
0?ooo`<00000;03oool2000000L0oooo0`0000060?ooo`8000001P3oool4000000D0oooo0`00000<
0?ooo`D00000C@3oool500000080oooo100000050?ooo`<000001P3oool2000001T0oooo0P00000J
0?ooo`00?P3oool00`000000oooo0?ooo`0F0?ooo`8000000P3oool4000003D0oooo0P0000070?oo
o`8000000`3oool2000000040?ooo`0000000000000000P0oooo0P0000050?ooo`<00000303oool2
000000030?ooo`000000000004d0oooo1@00000E0?ooo`800000=03oool003h0oooo0P00000G0?oo
o`8000000P3oool400000440oooo100000000`3oool000000000000?0?ooo`D000003P3oool20000
00L0oooo0`00000E0?ooo`800000;03oool2000001P0oooo0P00000d0?ooo`00?P3oool00`000000
oooo0?ooo`0H0?ooo`800000A03oool3000000030?ooo`000000000000`0oooo0`0000020?ooo`80
000000<0oooo000000000000403oool2000000D0oooo0`00000E0?ooo`800000O03oool003h0oooo
00<000000?ooo`3oool05`3oool3000004@0oooo0P0000020?ooo`800000303oool3000001L0oooo
0P00002K0?ooo`00?P3oool00`000000oooo0?ooo`0E0?ooo`@000000P3oool2000000H0oooo0P00
003o0?ooo`<0oooo000n0?ooo`030000003oool0oooo01D0oooo0P0000040?ooo`8000001@3oool3
000003/0oooo0P00000@0?ooo`8000005`3oool2000000<0oooo0P00002E0?ooo`00?P3oool00`00
0000oooo0?ooo`0R0?ooo`800000?03oool2000000030?ooo`000000000000d0oooo1000000E0?oo
o`8000000`3oool2000001D0oooo0P00001n0?ooo`00?P3oool00`000000oooo0?ooo`1S0?ooo`80
00003`3oool2000001<0oooo0P00000L0?ooo`800000OP3oool003h0oooo0P00002:0?ooo`800000
00<0oooo000000000000V@3oool003h0oooo00<000000?ooo`3oool0S03oool2000000030?ooo`00
0000000009H0oooo000n0?ooo`030000003oool0oooo01@0oooo0P00001h0?ooo`<00000UP3oool0
03h0oooo00<000000?ooo`3oool0503oool2000005d0oooo0P00000H0?ooo`<00000603oool20000
07d0oooo000n0?ooo`030000003oool0oooo07<0oooo0P00000H0?ooo`80000000<0oooo00000000
00005P3oool2000007d0oooo000n0?ooo`030000003oool0oooo0900oooo0P00002E0?ooo`00?P3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`800000o`3ooolY0?ooo`00?P3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo
00<000000?ooo`3oool04P3oool300000?l0oooo4`3oool002@0oooo100000000`0A4A40oooo0?oo
o`05000000<0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo00l0oooo
0P000000103oool0000000000000003o0?oooa<0oooo000V0?ooo`030000003oool0oooo0080oooo
00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`00
0000oooo0?ooo`0?0?ooo`800000o`3ooolG0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`03
09VIV@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo
0140oooo0P00003o0?oooaD0oooo000V0?ooo`030000003oool0oooo00@0oooo00<0VIVI028R8P3^
k^h00`3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00000A0?ooo`800000o`3ooolE0?oo
o`009P3oool00`000000oooo0?ooo`050?ooo`0307MgM`1VIVH0oooo0080oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo0?l0oooo:03oool002H0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool04A4A00<0oooo00<04A4A0?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooobP0oooo000V0?ooo`030000003oool0oooo0080oooo00D000000;^k^`3o
ool0VIVI014A4@030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`0@
0?ooo`800000o`3ooolF0?ooo`00903oool205EEE@030000003oool0oooo0080oooo00D0VIVI014A
4@0000008R8R0<c<c0030?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?oo
o`0@0?ooo`800000o`3ooolF0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?oo
o`030000003oool0oooo00h0oooo0P00003o0?oooaP0oooo000n0?ooo`8000003`3oool200000?l0
oooo603oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?oo
o`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo00T0oooo0P00003o0?oooad0oooo000n0?oo
o`030000003oool0oooo00T0oooo0P0000020?ooo`800000o`3ooolI0?ooo`00?P3oool00`000000
oooo0?ooo`0<0?ooo`<00000o`3ooolI0?ooo`00?P3oool00`000000oooo0?ooo`0<0?ooo`800000
o`3ooolJ0?ooo`00?P3oool2000000`0oooo1000003o0?oooaT0oooo000n0?ooo`030000003oool0
oooo00/0oooo1000003o0?oooaT0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0
oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`080?ooo`@00000
o`3ooolL0?ooo`00?P3oool00`000000oooo0?ooo`060?ooo`H00000o`3ooolL0?ooo`00?P3oool0
0`000000oooo0?ooo`050?ooo`<00000o`3ooolP0?ooo`00?P3oool2000000H0oooo0P00003o0?oo
ob40oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3oool0
1`3oool200000?l0oooo7`3oool003h0oooo00<000000?ooo`3oool01`3oool200000?l0oooo7`3o
ool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00903oool400000003014A4@3oool0oooo
0080oooo0P0000002@0A4A40oooo0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000
003oool0oooo0?l0oooo:03oool002H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`3o0?ooobP0oooo
000V0?ooo`030000003oool0oooo0080oooo1@0000030?ooo`05014A4@3oool0oooo0?ooo`0A4A40
1P3oool300000?l0oooo:03oool002H0oooo00<000000?ooo`3oool00P3oool01014A4@0gMgM0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`3o0?ooobP0
oooo000V0?ooo`030000003oool0oooo0080oooo00@0gMgM05EEE@3oool00000103oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`009P3oool00`000000
oooo0?ooo`030?ooo`0307MgM`3<c<`0000000@0oooo00D04A4A0?ooo`3oool0oooo014A4@060?oo
o`030000003oool0oooo0?l0oooo:03oool002H0oooo00<000000?ooo`3oool00`3oool00`3^k^h0
A4A4000000040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`3o0?oo
obP0oooo000T0?ooo`80EEEE00<000000?ooo`3oool0103oool00`1gMgL000000?ooo`030?ooo`05
0>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`03
0000003oool0oooo00@0oooo0P00003o0?ooob80oooo000n0?ooo`8000001@3oool200000?l0oooo
8P3oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o
0?ooobP0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`040?ooo`800000o`3ooolR0?ooo`00?P3o
ool00`000000oooo0?ooo`040?ooo`800000o`3ooolR0?ooo`00?P3oool200000?l0oooo:@3oool0
03h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`030?ooo`80
0000o`3ooolS0?ooo`00?P3oool00`000000oooo0?ooo`030?ooo`800000o`3ooolS0?ooo`00?P3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool0
03h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool200000?l0oooo:@3oool003h0oooo
00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n
0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?oo
o`00903oool400000008014A4@3oool0oooo0>k^kP0c<c<00000014A4@3<c<`30?ooo`050>k^kP0c
<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000V0?ooo`030000003o
ool0oooo0080oooo00D0EEEE07MgM`3oool0VIVI028R8P030?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL01P3oool00`000000oooo0?ooo`020?ooo`800000o`3ooolT0?ooo`009P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@0A4A40oooo0?ooo`3oool04A4A
00H0oooo0`0000020?ooo`800000o`3ooolT0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`05
0000002IVIT0oooo09VIV@0R8R800`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0o`3ooolX0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`050000001EEED00000
014A4@3<c<`00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0o`3o
oolX0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`0305EEE@28R8P0oooo00D0oooo00D04A4A
0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo0?l0oooo:03oool002H0oooo00<00000
0?ooo`3oool00P3oool00`3MgMd04A4A09VIV@050?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo000T0?ooo`80EEEE00<000000?ooo`3oool00`3oool0
103<c<`0A4A40000000A4A430?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo
0?ooo`3o0?ooobP0oooo000n0?ooo`040000003oool0oooo0?ooo`800000o`3ooolU0?ooo`00?P3o
ool200000080oooo0P00003o0?ooobD0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool0
03h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0
oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3oool0o`3o
oolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo
0?l0oooo:03oool003h0oooo0P00003o0?ooobT0oooo000n0?ooo`030000003oool0oooo00800000
o`3ooolV0?ooo`00?P3oool00`000000oooo0?ooo`0200000?l0oooo9P3oool003h0oooo00<00000
0?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`03
0000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3o
ool200000?l0oooo:@3oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool002@0oooo
10000000200A4A40oooo0?ooo`3<c<`08R8R0000000R8R80c<c<0`3oool01@3^k^h0<c<c0000000c
<c<0k^k^00H0oooo00@000000?ooo`0000000000o`3ooolW0?ooo`009P3oool00`000000oooo0?oo
o`020?ooo`05028R8P2IVIT0oooo09VIV@0R8R800`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0
oooo00@000000?ooo`0000000000o`3ooolW0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<00000
0?ooo`3oool0o`3ooolX0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`0503<c<`2IVIT0oooo
09VIV@0c<c<00`3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00003o0?ooobP0oooo000V
0?ooo`030000003oool0oooo0080oooo00D0c<c<00000000000000000<c<c0030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000V0?ooo`030000003o
ool0oooo0080oooo00D04A4A0;^k^`3oool0^k^k014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A
4A401P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000V0?ooo`030000003oool0oooo0080oooo
00D000000;^k^`3oool0^k^k000000030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo000T0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@2ZZZX0
4A4A0000000A4A40ZZZZ00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0
oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000
oooo0?ooo`3o0?ooobP0oooo000n0?ooo`<00000o`3ooolX0?ooo`00?P3oool300000?l0oooo:03o
ool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?oo
obP0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?ooo`3oool0
o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`800000o`3ooolY
0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo0?l0
oooo:03oool003h0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00?P3oool00`000000oooo0?oo
o`3o0?ooobP0oooo000n0?ooo`030000003oool0oooo0?l0oooo:03oool003h0oooo00<000000?oo
o`3oool0o`3ooolX0?ooo`00?P3oool200000?l0oooo:@3oool003h0oooo00<000000?ooo`3oool0
o`3ooolX0?ooo`00?P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000n0?ooo`030000003oool0
oooo0?l0oooo:03oool002<0oooo1@0000030?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`008`3oool0
1@2IVIT08R8R0>k^kP3oool0A4A400<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000T0?ooo`0309VI
V@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?oo
o`0A4A401P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000U0?ooo`0309VIV@0R8R80k^k^00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool3
00000?l0oooo:03oool002H0oooo00<0MgMg06IVIP3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`800000o`3ooolY0?ooo`009`3oool0
1@000000oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`03014A
4@3oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`008`3oool01@000000^k^k0?oo
o`2IVIT04A4A00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL01P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000S0?ooo`0509VIV@0A4A400000028R
8P3<c<`00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^
kP060?ooo`030000003oool0oooo0?l0oooo:03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0
ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0
ooooJ@3oool000<0oooo00@04A4A0000000000000000J03oool01P0R8R80000000000014A4@0gMgM
0?ooo`<0000000<04A4A0?ooo`3oool0k@3oool000@0oooo00<000000?ooo`3oool0J`3oool00`1g
MgL0<c<c0?ooo`020?ooo`03028R8P2k^k/0oooo0>h0oooo00040?ooo`030000003oool0oooo06`0
oooo00H000000?ooo`3oool0oooo09VIV@0c<c?_0?ooo`00103oool02@000000MgMg000000000000
EEEE0>k^kP3oool0k^k^05EEE@020000000305EEE@3^k^h0oooo0080oooo00D0VIVI000000000000
A4A40;^k^`020?ooo`060>k^kP1EEED0000000000014A4@0^k^k0P3oool0100A4A4000000000003o
ool200000004014A4@3oool0oooo09VIV@80000000<0A4A40;^k^`3oool00P3oool500000080oooo
00H0VIVI000000000000MgMg014A4@0000020?ooo`D000001P3oool01P3^k^h0EEEE000000000000
A4A40;^k^`80oooo00@04A4A000000000000oooo0P000000100A4A40oooo0>k^kP1EEED200000004
04A4A02k^k/0oooo014A4@D000000`3oool01P3^k^h0EEEE0000000A4A40c<c<000000<0oooo00<0
gMgM0000002k^k/0kP3oool000@0oooo00T0000005EEE@3^k^h0oooo07MgM`1EEED0oooo05EEE@1g
MgL00P3oool00`1gMgL0EEEE0?ooo`020?ooo`05014A4@2k^k/0k^k^07MgM`0A4A400P3oool01P1E
EED0MgMg0?ooo`3^k^h0MgMg014A4@<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05014A
4@2k^k/0k^k^07MgM`0A4A401@3oool00`000000oooo0?ooo`020?ooo`050000003<c<`0k^k^08R8
R00000001@3oool00`000000oooo0?ooo`060?ooo`0605EEE@1gMgL0oooo0>k^kP1gMgL04A4A0`3o
ool01@000000oooo0?ooo`3oool000000080oooo00H0EEEE07MgM`3oool0k^k^07MgM`0A4A430?oo
o`030000003oool0oooo00@0oooo00H0EEEE07MgM`3oool0k^k^05EEE@0000030?ooo`0305EEE@1g
MgL0<c<c0>h0oooo00040?ooo`030000003^k^h0oooo0080oooo00<000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`05014A
4@28R8P0oooo0>k^kP0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool01P000000oooo0?ooo`3oool0k^k^00000080oooo00D0gMgM014A4@3oool08R8R
0<c<c03]0?ooo`00103oool00`000000k^k^0?ooo`020?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`H000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030;^k^`0A4A4000000080
00001@3oool00`000000oooo0?ooo`060?ooo`H000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo1P0000030?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool0oooo0>k^kP00
00020?ooo`0506IVIP28R8P0oooo09VIV@1EEED0k@3oool000@0oooo00T0000005EEE@3^k^h0oooo
07MgM`1VIVH0oooo05EEE@1gMgL00P3oool00`1gMgL0EEEE0?ooo`020?ooo`030000003oool0oooo
00@0oooo00H0EEEE08R8R03^k^h0oooo08R8R00c<c<30?ooo`0500000028R8P0oooo0:ZZZP000000
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0c<c<0000003oool0
103oool00`000000oooo0?ooo`060?ooo`0605EEE@28R8P0k^k^0?ooo`28R8P0<c<c0`3oool01@00
0000R8R80?ooo`2ZZZX000000080oooo00H0EEEE08R8R03^k^h0oooo08R8R00c<c<30?ooo`030000
000c<c<0gMgM00@0oooo00X0EEEE07MgM`3oool0k^k^05EEE@000000oooo0>k^kP000000k^k^0P3o
ool00`000000gMgM0?ooo`3[0?ooo`000`3oool00`0A4A40000007MgM`020000000506IVIP3^k^h0
oooo0>k^kP1EEED00P000000101EEED0k^k^0?ooo`0A4A45000000<0oooo00H0k^k^05EEE@000000
000004A4A03^k^h20?ooo`03014A4@000000MgMg0080000000<0VIVI0?ooo`0A4A401@0000040?oo
o`03014A4@000000000000D0oooo00@0<c<c000000000000VIVI1@3oool00`000000oooo0?ooo`06
0?ooo`060>k^kP1EEED0000000000014A4@0k^k^0P3oool00`0A4A40000007MgM`020000000509VI
V@3oool0oooo0>k^kP1EEED00P0000001014A4@0k^k^0?ooo`3oool2000000040:ZZZP0R8R800000
028R8P80oooo00H0k^k^05EEE@0000008R8R0:ZZZP000002014A4@80000000@0oooo000000000000
4A4Ak03oool001@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0?l0oooo8@3oool001@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`00=P3oool0
0`0A4A40oooo0?ooo`0:0?ooo`<00000o`3ooolS0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-69.629, 65.8017, 1.39252, \
0.883598}}]
}, Open  ]],

Cell[TextData[{
  "After a rapid period of equilibration, the potential settles down and \
fluctuates about some average level. This average value can be determined \
numerically by averaging over the portion of the data that avoids the initial \
equilibration process, say ",
  Cell[BoxData[
      \(TraditionalForm\`n > 60\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Uav\  = \ Mean[Table[U[n], {n, 61, 300}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.37"],

Cell[BoxData[
    \(97.75257929148479`\)], "Output"]
}, Open  ]],

Cell["\<\
The value is close to that expected from the Boltzmann \
distribution, \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], " ", 
        "=", \(N \(\[Integral]m\ g\ x\ \(\[ExponentialE]\^\(\(-m\)\ g\ x/k\_B 
                       T\)\) \[DifferentialD]x/\(\[Integral]\(\[ExponentialE]\
\^\(\(-m\)\ g\ x/k\_B  T\)\) \[DifferentialD]x\)\) = 
          N\ \(k\_B\) \(\(T\)\(.\)\)\)}], TraditionalForm]]]], "NE3",
  CellTags->"(8.3.15)"],

Cell[TextData[{
  "For our parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_B\) T\  = \ 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N = 200\)]],
  ", the expected value is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "U", "\[RightAngleBracket]"}], " ", "=", 
          "100"}], TraditionalForm]]],
  ", in close agreement with the simulation.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Error Estimates: The Fluctuation Away from the Mean, Correlation \
Functions, and the Correlation Time\
\>", "Subsubsection",
  CellTags->"i:70"],

Cell[TextData[{
  "\tThe error in our simulation result for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " can also be estimated from the rms size of the fluctuations around the \
average value, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SqrtBox[
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "2"], 
              "\[RightAngleBracket]"}]], " ", "=", " ", 
          SqrtBox[
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"U", "-", 
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], "U", "\[RightAngleBracket]"}]}], 
                  ")"}], "2"], "\[RightAngleBracket]"}]]}], 
        TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:90"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(\[Delta]Uav = \ 
      Sqrt[Mean[Table[\((U[n] - Uav)\)^2, {n, 61, 300}]]]\)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.38"],

Cell[BoxData[
    \(6.284130029369781`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe size of these fluctuations does not change over time, but the longer \
we perform the averaging, the better will be our estimate of the average \
value. Roughly speaking, the error ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  " in our estimate of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " decreases with increasing number of steps kept in the average, ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  ", as "
}], "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            SqrtBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]], "2"], 
                "\[RightAngleBracket]"}]], \(\@\(m\_c/N\_step\)\)}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(8.3.16)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  " is a dimensionless constant that is larger than 1, but less than ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " . This scaling is a simple consequence of random-walk statistics. For a \
moment, think of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " as the exact value that we might obtain from an infinitely long time \
average, or a theoretical calculation. When we evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " approximately in a finite random walk, we sum ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " values of ",
  Cell[BoxData[
      \(TraditionalForm\`U\_n\)]],
  ", each of which differs from ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " by a random amount  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["U",
                  FontSlant->"Italic"]}]], "n"], "=", 
          RowBox[{\(U\_n\), "-", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "U", "\[RightAngleBracket]"}]}]}], 
        TraditionalForm]]],
  ". The sum is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(N\_\(\(step\)\(\ \)\)\), 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "U", "\[RightAngleBracket]"}]}], " ", "+",
           " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontSlant->"Italic"]}]], "=", 
          RowBox[{\(\[Sum]\+n\), 
            SubscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["U",
                    FontSlant->"Italic"]}]], "n"]}]}], TraditionalForm]]],
  " is the error. On average, over many experiments, we expect that the mean \
squared error ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["E",
                  FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " in the overall sum will be caused by the diffusion due to these ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " random steps, and be given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(N\_step\), " ", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["U",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}]}],
         TraditionalForm]]],
  " (assuming uncorrelated steps). Thus,  the error in the sum is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\@N\_step\), " ", 
          SqrtBox[
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "2"], 
              "\[RightAngleBracket]"}]]}], TraditionalForm]]],
  "; but  the mean value of the sum is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(N\_step\), " ", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "U", "\[RightAngleBracket]"}]}], 
        TraditionalForm]]],
  ". The error in our approximate evaluation of  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " itself is therefore  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SqrtBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]], "2"], 
                "\[RightAngleBracket]"}]], "/", \(\@N\_step\)}], " "}], 
        TraditionalForm]]],
  ". Note that this error estimate applies not just to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", but to any average quantity that we measure in the simulation."
}], "Text"],

Cell[TextData[{
  "\tHowever, the random steps ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "n"], TraditionalForm]]],
  " are not necessarily uncorrelated. This is the origin of the constant ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  " in Eq. ",
  ButtonBox["(8.3.16)",
    ButtonData:>{"Chapter8.nb", "(8.3.16)"},
    ButtonStyle->"Hyperlink"],
  ". For instance, the steps could all be in the same direction for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " steps over which the average is taken.  A little thought leads to the \
conclusion that the error would then be larger than the estimate based on \
uncorrelated steps,  because we have not really taken ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  StyleBox[" uncorrelated",
    FontSlant->"Italic"],
  " steps; we have taken effectively fewer steps. The ratio ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step/m\_c\)]],
  " is the effective number of uncorrelated steps that have been taken.  In \
fact, the largest error one might expect is when the entire process was \
equivalent to one big step, so we would then take the statistical error \
associated with a single step, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "=", 
          SqrtBox[
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "2"], 
              "\[RightAngleBracket]"}]]}], TraditionalForm]]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\  = N\_step\)]],
  " in Eq. ",
  ButtonBox["(8.3.16)",
    ButtonData:>{"Chapter8.nb", "(8.3.16)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"],

Cell[TextData[{
  "\tWe can estimate the value of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  " by determining the number of steps ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\ \)\)\)]],
  "required before ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], \(n + m\)], TraditionalForm]]],
  " becomes uncorrelated with a previous value ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "n"], TraditionalForm]]],
  ". A measure of the correlation between ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], \(n + m\)], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "n"], TraditionalForm]]],
  " is given by the correlation function"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c(m)\), " ", "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              RowBox[{
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]], \(n + m\)], " ", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]], "n"]}], 
              "\[RightAngleBracket]"}], "/", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "2"], 
              "\[RightAngleBracket]"}]}]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->{"i:71", "(8.3.17)"}],

Cell[TextData[{
  "[see Eq. ",
  ButtonBox["(8.2.12)",
    ButtonData:>{"Chapter8.nb", "(8.2.12)"},
    ButtonStyle->"Hyperlink"],
  "]. If ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], \(n + m\)], TraditionalForm]]],
  "is uncorrelated with ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], "n"], TraditionalForm]]],
  ", then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], \(n + m\)], " ", 
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "n"]}], 
            "\[RightAngleBracket]"}], " ", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]], \(n + m\)], " ", 
                "\[RightAngleBracket]"}], 
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["U",
                        FontSlant->"Italic"]}]], "n"], 
                "\[RightAngleBracket]"}]}], " ", "=", "0"}]}], 
        TraditionalForm]]],
  ". However, for correlated processes, ",
  Cell[BoxData[
      \(TraditionalForm\`c(m)\)]],
  " is nonzero for ",
  Cell[BoxData[
      \(TraditionalForm\`m > 0\)]],
  ". Of course, at ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "n"], " ", 
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]], "n"]}], 
            "\[RightAngleBracket]"}], " ", "=", 
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["U",
                    FontSlant->"Italic"]}]], "2"], "\[RightAngleBracket]"}], 
          " "}], TraditionalForm]]],
  "so ",
  Cell[BoxData[
      \(TraditionalForm\`c(0) = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe correlation function for our random walk can be easily evaluated \
from the numerical data, as shown in Cell ",
  ButtonBox["8.34",
    ButtonData:>"Cell 8.34",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:88"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(c[
          m_]\ \  := \ \(c[
            m]\  = \ \ \((Sum[\((U[n] - Uav)\)\ \((U[n + m] - Uav)\), {n, 61, 
                    300 - m}]/\((240 - m)\))\)/\[Delta]Uav^2\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[{m, c[m]}, {m, 0, 80}], PlotRange \[Rule] All, 
        AxesLabel \[Rule] {"\<m\>", "\<c(m)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.39"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0119048 0.139881 0.461515 [
[.2619 .12738 -6 -9 ]
[.2619 .12738 6 0 ]
[.5 .12738 -6 -9 ]
[.5 .12738 6 0 ]
[.7381 .12738 -6 -9 ]
[.7381 .12738 6 0 ]
[.97619 .12738 -6 -9 ]
[.97619 .12738 6 0 ]
[1.025 .13988 0 -6 ]
[1.025 .13988 10.125 6 ]
[.01131 .04758 -24 -4.5 ]
[.01131 .04758 0 4.5 ]
[.01131 .23218 -18 -4.5 ]
[.01131 .23218 0 4.5 ]
[.01131 .32449 -18 -4.5 ]
[.01131 .32449 0 4.5 ]
[.01131 .41679 -18 -4.5 ]
[.01131 .41679 0 4.5 ]
[.01131 .50909 -18 -4.5 ]
[.01131 .50909 0 4.5 ]
[.01131 .6014 -6 -4.5 ]
[.01131 .6014 0 4.5 ]
[.02381 .64303 -14.0625 0 ]
[.02381 .64303 14.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .13988 m
.2619 .14613 L
s
[(20)] .2619 .12738 0 1 Mshowa
.5 .13988 m
.5 .14613 L
s
[(40)] .5 .12738 0 1 Mshowa
.7381 .13988 m
.7381 .14613 L
s
[(60)] .7381 .12738 0 1 Mshowa
.97619 .13988 m
.97619 .14613 L
s
[(80)] .97619 .12738 0 1 Mshowa
.125 Mabswid
.08333 .13988 m
.08333 .14363 L
s
.14286 .13988 m
.14286 .14363 L
s
.20238 .13988 m
.20238 .14363 L
s
.32143 .13988 m
.32143 .14363 L
s
.38095 .13988 m
.38095 .14363 L
s
.44048 .13988 m
.44048 .14363 L
s
.55952 .13988 m
.55952 .14363 L
s
.61905 .13988 m
.61905 .14363 L
s
.67857 .13988 m
.67857 .14363 L
s
.79762 .13988 m
.79762 .14363 L
s
.85714 .13988 m
.85714 .14363 L
s
.91667 .13988 m
.91667 .14363 L
s
.25 Mabswid
0 .13988 m
1 .13988 L
s
gsave
1.025 .13988 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .04758 m
.03006 .04758 L
s
[(-0.2)] .01131 .04758 1 0 Mshowa
.02381 .23218 m
.03006 .23218 L
s
[(0.2)] .01131 .23218 1 0 Mshowa
.02381 .32449 m
.03006 .32449 L
s
[(0.4)] .01131 .32449 1 0 Mshowa
.02381 .41679 m
.03006 .41679 L
s
[(0.6)] .01131 .41679 1 0 Mshowa
.02381 .50909 m
.03006 .50909 L
s
[(0.8)] .01131 .50909 1 0 Mshowa
.02381 .6014 m
.03006 .6014 L
s
[(1)] .01131 .6014 1 0 Mshowa
.125 Mabswid
.02381 .07065 m
.02756 .07065 L
s
.02381 .09373 m
.02756 .09373 L
s
.02381 .1168 m
.02756 .1168 L
s
.02381 .16296 m
.02756 .16296 L
s
.02381 .18603 m
.02756 .18603 L
s
.02381 .20911 m
.02756 .20911 L
s
.02381 .25526 m
.02756 .25526 L
s
.02381 .27834 m
.02756 .27834 L
s
.02381 .30141 m
.02756 .30141 L
s
.02381 .34756 m
.02756 .34756 L
s
.02381 .37064 m
.02756 .37064 L
s
.02381 .39371 m
.02756 .39371 L
s
.02381 .43987 m
.02756 .43987 L
s
.02381 .46294 m
.02756 .46294 L
s
.02381 .48602 m
.02756 .48602 L
s
.02381 .53217 m
.02756 .53217 L
s
.02381 .55524 m
.02756 .55524 L
s
.02381 .57832 m
.02756 .57832 L
s
.02381 .0245 m
.02756 .0245 L
s
.02381 .00143 m
.02756 .00143 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.125 13.000 moveto
(L) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.02381 .60332 Mdot
.03571 .53263 Mdot
.04762 .48214 Mdot
.05952 .43582 Mdot
.07143 .39867 Mdot
.08333 .36509 Mdot
.09524 .3284 Mdot
.10714 .29277 Mdot
.11905 .25685 Mdot
.13095 .23934 Mdot
.14286 .21381 Mdot
.15476 .17556 Mdot
.16667 .1574 Mdot
.17857 .14315 Mdot
.19048 .14095 Mdot
.20238 .14092 Mdot
.21429 .13541 Mdot
.22619 .13495 Mdot
.2381 .14535 Mdot
.25 .15872 Mdot
.2619 .16671 Mdot
.27381 .18216 Mdot
.28571 .18958 Mdot
.29762 .1999 Mdot
.30952 .20473 Mdot
.32143 .21605 Mdot
.33333 .22519 Mdot
.34524 .22802 Mdot
.35714 .21772 Mdot
.36905 .20751 Mdot
.38095 .1756 Mdot
.39286 .15238 Mdot
.40476 .13236 Mdot
.41667 .11188 Mdot
.42857 .0857 Mdot
.44048 .0615 Mdot
.45238 .05015 Mdot
.46429 .04566 Mdot
.47619 .05154 Mdot
.4881 .03339 Mdot
.5 .02025 Mdot
.5119 .01472 Mdot
.52381 .0196 Mdot
.53571 .02214 Mdot
.54762 .0371 Mdot
.55952 .04256 Mdot
.57143 .04517 Mdot
.58333 .04938 Mdot
.59524 .06235 Mdot
.60714 .06011 Mdot
.61905 .06933 Mdot
.63095 .07973 Mdot
.64286 .08798 Mdot
.65476 .09884 Mdot
.66667 .10059 Mdot
.67857 .09545 Mdot
.69048 .09321 Mdot
.70238 .09953 Mdot
.71429 .11617 Mdot
.72619 .11997 Mdot
.7381 .11864 Mdot
.75 .11023 Mdot
.7619 .10088 Mdot
.77381 .10475 Mdot
.78571 .11003 Mdot
.79762 .1155 Mdot
.80952 .11361 Mdot
.82143 .10833 Mdot
.83333 .11402 Mdot
.84524 .12354 Mdot
.85714 .12222 Mdot
.86905 .13243 Mdot
.88095 .12157 Mdot
.89286 .11836 Mdot
.90476 .11265 Mdot
.91667 .10906 Mdot
.92857 .12045 Mdot
.94048 .12083 Mdot
.95238 .11673 Mdot
.96429 .10934 Mdot
.97619 .11313 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`008@3oool300000?l0ooooA@3oool00240oooo00<0
00000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?oo
o`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0U@3oool200000:d0
oooo000Q0?ooo`030000003oool0oooo09D0oooo0P00002]0?ooo`008@3oool00`000000oooo0?oo
o`2A0?ooo`8000001P3oool200000:T0oooo000Q0?ooo`030000003oool0oooo0940oooo0P000006
0?ooo`80000000<0oooo000000000000YP3oool00240oooo0`00002L0?ooo`800000YP3oool00240
oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`2>0?ooo`800000
]03oool00240oooo00<000000?ooo`3oool0SP3oool200000100oooo0P00002R0?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D000001@3oool00`000000oooo0?oo
o`2P0?ooo`800000XP3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103o
ool01@2IVIT08R8R0>k^kP3oool0A4A400D0oooo00<000000?ooo`3oool0Y03oool2000009h0oooo
000500000080oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00H0oooo
00<000000?ooo`3oool0QP3oool2000001`0oooo0P0000020?ooo`800000VP3oool000L0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`0309VIV@0R8R80k^k^00D0oooo0`0000220?ooo`800000
0P3oool200000200oooo0P0000000`3oool000000000002G0?ooo`001`3oool01@000000oooo0?oo
o`3oool0000000h0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`220?ooo`800000
1P3oool2000001l0oooo0P00002G0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2:0?ooo`800000^03oool000L0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo09VIV@0A4A401@3oool00`000000
oooo0?ooo`2c0?ooo`800000S`3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`05
09VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`1o0?ooo`800000;P3oool20000
0080oooo0P00002?0?ooo`008@3oool00`000000oooo0?ooo`1o0?ooo`800000;P3oool2000009<0
oooo000Q0?ooo`030000003oool0oooo0;H0oooo0P00002<0?ooo`008@3oool300000;H0oooo0P00
002<0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo
0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0^P3oool2000008P0oooo000Q0?ooo`030000
003oool0oooo07/0oooo0P00000m0?ooo`800000R03oool00240oooo00<000000?ooo`3oool0N`3o
ool200000440oooo0P0000240?ooo`008@3oool00`000000oooo0?ooo`2n0?ooo`800000Q03oool0
0240oooo0`0000390?ooo`8000000P3oool2000007D0oooo000Q0?ooo`030000003oool0oooo0<T0
oooo0P0000020?ooo`800000M@3oool00240oooo00<000000?ooo`3oool0@@3oool5000000<0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0o0?ooo`80000000T04A4A0?ooo`3oool0oooo0>k^kP0c<c<0
000003<c<`3^k^h0:P3oool2000000030?ooo`000000000000T0oooo0P0000030?ooo`050>k^kP0c
<c<00000014A4@3<c<`00`3oool01P3^k^h0<c<c0000000c<c<0k^k^0?ooo`800000>`3oool01@3<
c<`08R8R0000000R8R80c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0G0?ooo`008@3oool0
0`000000oooo0?ooo`110?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@00`3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg0400oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02X0
oooo0P0000000`3oool00000000000090?ooo`8000000`3oool01@1EEED0MgMg0?ooo`2IVIT08R8R
00<0oooo00H0MgMg09VIV@3oool0VIVI07MgM`3oool200000080oooo0P00000g0?ooo`05028R8P2I
VIT0oooo09VIV@0R8R800`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg01L0oooo000Q0?ooo`030000
003oool0oooo0480oooo00<0VIVI028R8P3^k^h0103oool01@0A4A40oooo0?ooo`3oool04A4A03d0
oooo1@0000030?ooo`05014A4@3oool0oooo0?ooo`0A4A40?@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D04A4A0?ooo`3oool0oooo014A4@050?ooo`8000003@3oool2000002P0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`05014A4@3oool0oooo0?ooo`0A4A405`3oool00240oooo
00<000000?ooo`3oool0@`3oool00`2IVIT08R8R0>k^kP030?ooo`050000003oool0oooo0?ooo`00
0000?@3oool01014A4@0gMgM0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000?@3oool0
1@000000VIVI0?ooo`2IVIT08R8R00<0oooo00<000000?ooo`0000000P0000080?ooo`8000002P3o
ool2000001/0oooo0P00000;0?ooo`0503<c<`2IVIT000000000000c<c<00`3oool01@000000oooo
0?ooo`3oool0000001L0oooo000Q0?ooo`030000003oool0oooo04@0oooo00<0MgMg06IVIP3oool0
0P3oool01@000000oooo0?ooo`3oool0000002T0oooo0P00000B0?ooo`040=gMg@1EEED0oooo0000
00@0oooo00D000000?ooo`3oool0oooo0000000m0?ooo`050000001EEED00000014A4@3<c<`00`3o
ool00`000000oooo00000002000000P0oooo0P0000060?ooo`8000001@3oool2000001D0oooo0P00
00000`3oool000000000000;0?ooo`060<c<c000000000000000003<c<`0oooo0`0000030?ooo`03
0000003oool0oooo01D0oooo000Q0?ooo`<00000A@3oool01@000000oooo0?ooo`3oool04A4A00<0
oooo00<04A4A0?ooo`3oool09`3oool2000001<0oooo00<0MgMg0<c<c0000000103oool01@0A4A40
oooo0?ooo`3oool04A4A03`0oooo0P0000000`28R8P0oooo0?ooo`040?ooo`05014A4@3oool0oooo
0?ooo`0A4A40303oool200000080oooo0P0000050?ooo`8000005@3oool2000000`0oooo0P000000
1P0A4A40^k^k0?ooo`2k^k/04A4A0?ooo`80000000D04A4A0?ooo`3oool0oooo014A4@0G0?ooo`00
8@3oool00`000000oooo0?ooo`110?ooo`050000002k^k/0oooo09VIV@0A4A400`3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg03h0oooo00<0k^k^04A4A0000000103oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg03`0oooo0P000000100A4A40VIVI0000000000020?ooo`80000000@0VIVI0?ooo`2IVIT0MgMg
303oool2000001`0oooo0P0000090?ooo`8000000P3oool2000000080?ooo`00000000000000002k
^k/0oooo0;^k^`0000030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL05`3oool00240oooo00<00000
0?ooo`3oool0@@3oool01@2IVIT04A4A0000000R8R80c<c<00<0oooo00D0k^k^03<c<`000000<c<c
0>k^kP0o0?ooo`0307MgM`000000oooo00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0n0?ooo`04
0<c<c014A4@0000000000080oooo0P000000100c<c<0000003<c<`3^k^hK0?ooo`8000000P3oool2
000000D0oooo0P0000020?ooo`8000002@3oool200000080oooo0P0000030?ooo`050:ZZZP0A4A40
0000014A4@2ZZZX00`3oool01@3^k^h0<c<c0000000c<c<0k^k^01L0oooo000Q0?ooo`030000003o
ool0oooo0?d0oooo0P0000020?ooo`8000001@3oool2000003X0oooo000Q0?ooo`030000003oool0
oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0M03oool2000008h0oooo0P00000b0?oo
o`8000000P3oool01@000000oooo0?ooo`0000004A4A00<0oooo000Q0?ooo`030000003oool0oooo
03P0oooo0P0000020?ooo`800000=P3oool2000008h0oooo0P00000c0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool00240oooo00<000000?ooo`3oool0>03oool20000
0080oooo0P00003k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0
01X0ooooo`00000j000000X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01`3oool200000080oooo0P0000000`3oool000000000000:0?ooo`8000001P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`070000003<c<`0c<c<0000002ZZZX0gMgM028R8P040?ooo`008@3oool0
0`000000oooo0?ooo`100?ooo`8000001P3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0>0?ooo`08014A4@000000
8R8R0000001gMgL04A4A0000002ZZZX40?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`800000
dP3oool00240oooo00<000000?ooo`3oool0L03oool200000=80oooo000Q0?ooo`030000003oool0
oooo02T0oooo0P00000H0?ooo`800000o`3oool00240oooo00<000000?ooo`3oool0:@3oool20000
01P0oooo0P00003o0?ooo`008@3oool300000?l0ooooA@3oool00240oooo00<000000?ooo`3oool0
A`3oool200000?/0oooo000Q0?ooo`030000003oool0oooo04L0oooo0P00003k0?ooo`008@3oool0
0`000000oooo0?ooo`0V0?ooo`800000A03oool200000=H0oooo000Q0?ooo`030000003oool0oooo
02H0oooo0P0000140?ooo`800000eP3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`00
8@3oool00`000000oooo0?ooo`1;0?ooo`800000m`3oool00240oooo0`00001;0?ooo`800000m`3o
ool00240oooo00<000000?ooo`3oool0CP3oool200000?@0oooo000Q0?ooo`030000003oool0oooo
04h0oooo0P00003d0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000
003oool0oooo0580oooo0P00003`0?ooo`008@3oool00`000000oooo0?ooo`1B0?ooo`800000l03o
ool00240oooo00<000000?ooo`3oool0EP3oool200000100oooo0P00003J0?ooo`008@3oool30000
05H0oooo0P00000@0?ooo`800000fP3oool00240oooo00<000000?ooo`3oool08P3oool200000?l0
oooo8@3oool00240oooo00<000000?ooo`3oool08P3oool2000003H0oooo0P00003X0?ooo`008@3o
ool00`000000oooo0?ooo`1J0?ooo`8000002@3oool200000=d0oooo000Q0?ooo`030000003oool0
oooo06D0oooo0P00003M0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R84
0?ooo`D000001@3oool00`000000oooo0?ooo`1M0?ooo`800000i@3oool000L0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2IVIT08R8R0>k^kP3oool0A4A400D0oooo00<0
00000?ooo`3oool0G@3oool200000080oooo0P00003Q0?ooo`001`3oool01@0A4A40oooo0?ooo`3o
ool04A4A00`0oooo00<0VIVI028R8P3^k^h01P3oool300000640oooo0P00003Q0?ooo`001`3oool0
1@000000oooo0?ooo`3oool0000000d0oooo00<0VIVI028R8P3^k^h01@3oool00`000000oooo0?oo
o`3o0?ooodD0oooo00070?ooo`050000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?oo
o`040?ooo`030000003oool0oooo01h0oooo0P00003o0?ooobD0oooo00070?ooo`05014A4@3oool0
oooo0?ooo`0A4A403`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo0P00
003o0?ooobD0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?oo
o`2IVIT04A4A00D0oooo00<000000?ooo`3oool0o`3ooom50?ooo`001`3oool01@3^k^h0<c<c0000
000c<c<0k^k^00/0oooo00D0VIVI014A4@0000008R8R0<c<c0050?ooo`030000003oool0oooo0?l0
ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooodD0oooo000Q0?ooo`<000006P3oool200000?l0oooo:@3oool00240oooo00<000000?oo
o`3oool06P3oool200000?l0oooo:@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3o
ool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
odD0oooo000Q0?ooo`<00000o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo
000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`008@3oool00`000000oooo0?ooo`0G0?ooo`800000o`3oool/0?ooo`008@3oool00`000000
oooo0?ooo`0G0?ooo`800000o`3oool/0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo
000Q0?ooo`<00000o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?oo
o`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
1@3oool2028R8PH0oooo0P0000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
A@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooA@3oool000L0oooo00D04A4A0?ooo`3oool0oooo
014A4@0;0?ooo`D000001@3oool300000?l0ooooA@3oool000L0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`0404A4A03MgMd0oooo000000H0oooo00<000000?ooo`3oool04`3oool200000?l0
oooo<03oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo0000
00H0oooo00<000000?ooo`3oool04`3oool200000?l0oooo<03oool000L0oooo00D04A4A0?ooo`3o
ool0oooo014A4@0<0?ooo`0307MgM`3<c<`0000000H0oooo00<000000?ooo`3oool0o`3ooom50?oo
o`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<0k^k^04A4A00000001P3oool00`00
0000oooo0?ooo`3o0?ooodD0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1g
MgL000000?ooo`050?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3o
ool0o`3ooom50?ooo`008@3oool300000?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3o
oom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo
0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo00l0oooo0P00003o0?oooc@0oooo000Q
0?ooo`030000003oool0oooo00l0oooo0P00003o0?oooc@0oooo000Q0?ooo`<00000o`3ooom50?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
A@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o
0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3o
ool0o`3ooom50?ooo`008@3oool300000?l0ooooA@3oool00240oooo00<000000?ooo`3oool0303o
ool200000?l0oooo=`3oool00240oooo00<000000?ooo`3oool0303oool200000?l0oooo=`3oool0
0240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0
oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^03<c<`00
00004A4A0<c<c0050?ooo`030000003oool0oooo0?l0ooooA@3oool000L0oooo00D0MgMg09VIV@3o
ool0VIVI07MgM`050?ooo`808R8R103oool01@1EEED0MgMg0?ooo`2IVIT08R8R00D0oooo00<00000
0?ooo`3oool0o`3ooom50?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`<00000o`3ooom50?ooo`001`3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P050?ooo`030000003oool0oooo0?l0oooo
A@3oool000L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000014A4@3<
c<`01@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool00`1EEED0R8R80?ooo`070?ooo`030000003oool0oooo0?l0ooooA@3oool000L0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A4A40VIVI00L0oooo00<000000?ooo`3o
ool0o`3ooom50?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0c<c<04A4A000
00004A4A1@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo00P0
oooo0P00003o0?oooc/0oooo000Q0?ooo`<00000203oool200000?l0oooo>`3oool00240oooo00<0
00000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?oo
o`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3o
ool00240oooo0`00003o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool00240
oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo
000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`800000o`3ooolo0?ooo`008@3oool00`000000
oooo0?ooo`040?ooo`800000o`3ooolo0?ooo`008@3oool300000?l0ooooA@3oool00240oooo00<0
00000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?oo
o`030000003oool0oooo0?l0ooooA@3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?oo
o`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00D0oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0
oooo09VIV@0R8R801@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00070?ooo`05014A4@3oool0
oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
o`3ooom50?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3oool0
VIVI03<c<`050?ooo`<00000o`3ooom50?ooo`001`3oool01@000000oooo0?ooo`3oool0000000/0
oooo00D0c<c<00000000000000000<c<c0050?ooo`030000003oool0oooo0?l0ooooA@3oool000L0
oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k^`0A4A401@3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo00070?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool0
1@000000^k^k0?ooo`2k^k/0000000D0oooo00<000000?ooo`3oool0o`3ooom50?ooo`001`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP050?ooo`030000
003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`D00000o`3ooom30?ooo`008@3oool00`000000
oooo0?ooo`0200000?l0oooo@`3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3o
ool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool0
0240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0
oooo000Q0?ooo`<00000o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0oooo
A@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool300000?l0ooooA@3oool0
0240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0
oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3o
oom50?ooo`00603oool400000003014A4@3oool0oooo0080oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooA@3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooodD0oooo000J0?ooo`030000
003oool0oooo00@0oooo0`00003o0?ooodD0oooo000J0?ooo`030000003oool0oooo00@0oooo0P00
003o0?ooodH0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooA@3oool001P0
oooo0P1EEED00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo
00<000000?ooo`3oool0o`3ooom50?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`007`3oool00`1gMgL0IVIV0?ooo`080?ooo`0306IVIP1gMgL0oooo0?l0oooo
?03oool001h0oooo00<0gMgM014A4@3^k^h02@3oool00`3^k^h04A4A0=gMg@3o0?oooc`0oooo000D
0?ooo`0506IVIP000000000004A4A03<c<`01@3oool00`1EEED0VIVI0?ooo`0200000080oooo00P0
00000?ooo`3oool00000014A4@3oool0R8R806IVI_l0oooo?03oool001<0oooo00H0IVIV07MgM`3o
ool0oooo08R8R00A4A450?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030>k^kP000000oooo0?l0oooo>`3oool001<0oooo00<000000?ooo`3oool0203o
ool01@0c<c<0oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`3o0?ooocX0oooo000C0?ooo`030000003oool0oooo00P0oooo00D0<c<c0?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0o`3ooolj0?oo
o`004`3oool01P1VIVH0MgMg0?ooo`3oool0R8R8000000D0oooo00D000000>k^kP3oool0oooo0000
00020<c<c0040000002ZZZX0gMgM028R8P80oooo00<0k^k^0000003oool0o`3ooolk0?ooo`004`3o
ool01P3^k^h0IVIV000000000000A4A4000000D0oooo00/0EEEE07MgM`3oool04A4A0000000R8R80
000007MgM`0A4A4000000:ZZZP020?ooo`0307MgM`1EEED0oooo0?l0oooo>`3oool001h0oooo00<0
gMgM014A4@3^k^h02@3oool00`3^k^h04A4A0=gMg@3o0?oooc`0oooo000O0?ooo`0307MgM`1VIVH0
oooo00P0oooo00<0IVIV07MgM`3oool0o`3oooll0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.12551, -0.322899, \
0.336464, 0.0086791}}]
}, Open  ]],

Cell[TextData[{
  "The correlation function exhibits a reasonably clear falloff in the first \
10-20 steps, after which it fluctuates around zero. This allows us to define \
the ",
  StyleBox["correlation time",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  ", the number of timesteps required for ",
  Cell[BoxData[
      \(TraditionalForm\`c(m)\)]],
  " to approach zero. More precisely, one can define ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  " by fitting an exponential function to ",
  Cell[BoxData[
      \(TraditionalForm\`c(m)\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`c(m)\  = \ \[ExponentialE]\^\(\(-m\)/m\_c\)\)]],
  ". We won't bother with this fitting here, but instead will simply estimate \
the correlation time as ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\  \[TildeTilde] 10\)]],
  ".  Then the ",
  StyleBox["effective number of uncorrelated steps that is taken",
    FontSlant->"Italic"],
  " in an average over ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " timesteps is  ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step/m\_c \[TildeTilde] N\_step/10\)]],
  ".  "
}], "Text",
  CellTags->"i:87"],

Cell[TextData[{
  "\tUsing our estimate of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\  = \ 10\)]],
  " yields the following error estimate",
  ",",
  " given that we averaged over ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step = 240\)]],
  " steps:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]E\  = \ \[Delta]Uav/Sqrt[240/10]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.40"],

Cell[BoxData[
    \(1.2827426707714193`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since we already know that the value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " is supposed to be 100, and we obtained a value of 97.8, we can see that \
our error estimate did a reasonable job of predicting the magnitude of the \
error. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mean Density Compared with the Boltzmann Distribution", "Subsubsection"],

Cell[TextData[{
  "\tWe can also compare the mean density of particles with the Boltzmann \
distribution. We do so in Cell ",
  ButtonBox["8.36",
    ButtonData:>"Cell 8.36",
    ButtonStyle->"Hyperlink"],
  ",  making a histogram ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " of the particle positions in bins of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", "0.1"}], TraditionalForm]]],
  ",  over  70 steps of the process."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(\(p1\  = \ 
        Histogram[Flatten[Table[pos[n], {n, 31, 100}]], 
          HistogramRange \[Rule] {0, 2}, HistogramCategories \[Rule] 20, \ 
          DisplayFunction \[Rule] Identity];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Rho]B[x_]\  = 
      m\ g/\ T\ \ Exp[\(-m\)\ g\ x/T]; \ \[CapitalDelta]x\  = \ 0.1; \ 
    M = 200;\n\), "\[IndentingNewLine]", 
    \(\(p2\  = \ 
        Plot[70  \[CapitalDelta]x\ M\ \[Rho]B[x], {x, 0, 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[\ p1, p2, AxesLabel \[Rule] {"\<x\>", "\<H(x)\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.41"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.47619 0.0147151 0.000210216 [
[.2381 .00222 -9 -9 ]
[.2381 .00222 9 0 ]
[.47619 .00222 -3 -9 ]
[.47619 .00222 3 0 ]
[.71429 .00222 -9 -9 ]
[.71429 .00222 9 0 ]
[.95238 .00222 -3 -9 ]
[.95238 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[-0.0125 .11982 -18 -4.5 ]
[-0.0125 .11982 0 4.5 ]
[-0.0125 .22493 -24 -4.5 ]
[-0.0125 .22493 0 4.5 ]
[-0.0125 .33004 -24 -4.5 ]
[-0.0125 .33004 0 4.5 ]
[-0.0125 .43515 -24 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .54025 -24 -4.5 ]
[-0.0125 .54025 0 4.5 ]
[0 .64303 -14 0 ]
[0 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2381 .01472 m
.2381 .02097 L
s
[(0.5)] .2381 .00222 0 1 Mshowa
.47619 .01472 m
.47619 .02097 L
s
[(1)] .47619 .00222 0 1 Mshowa
.71429 .01472 m
.71429 .02097 L
s
[(1.5)] .71429 .00222 0 1 Mshowa
.95238 .01472 m
.95238 .02097 L
s
[(2)] .95238 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11982 m
.00625 .11982 L
s
[(500)] -0.0125 .11982 1 0 Mshowa
0 .22493 m
.00625 .22493 L
s
[(1000)] -0.0125 .22493 1 0 Mshowa
0 .33004 m
.00625 .33004 L
s
[(1500)] -0.0125 .33004 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(2000)] -0.0125 .43515 1 0 Mshowa
0 .54025 m
.00625 .54025 L
s
[(2500)] -0.0125 .54025 1 0 Mshowa
.125 Mabswid
0 .03574 m
.00375 .03574 L
s
0 .05676 m
.00375 .05676 L
s
0 .07778 m
.00375 .07778 L
s
0 .0988 m
.00375 .0988 L
s
0 .14084 m
.00375 .14084 L
s
0 .16187 m
.00375 .16187 L
s
0 .18289 m
.00375 .18289 L
s
0 .20391 m
.00375 .20391 L
s
0 .24595 m
.00375 .24595 L
s
0 .26697 m
.00375 .26697 L
s
0 .288 m
.00375 .288 L
s
0 .30902 m
.00375 .30902 L
s
0 .35106 m
.00375 .35106 L
s
0 .37208 m
.00375 .37208 L
s
0 .3931 m
.00375 .3931 L
s
0 .41412 m
.00375 .41412 L
s
0 .45617 m
.00375 .45617 L
s
0 .47719 m
.00375 .47719 L
s
0 .49821 m
.00375 .49821 L
s
0 .51923 m
.00375 .51923 L
s
0 .56128 m
.00375 .56128 L
s
0 .5823 m
.00375 .5823 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .5556 L
.04762 .5556 L
.04762 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .5556 L
.04762 .5556 L
.04762 .01472 L
0 .01472 L
s
1 0 0 r
.04762 .01472 m
.04762 .44776 L
.09524 .44776 L
.09524 .01472 L
F
0 g
.04762 .01472 m
.04762 .44776 L
.09524 .44776 L
.09524 .01472 L
.04762 .01472 L
s
1 0 0 r
.09524 .01472 m
.09524 .35274 L
.14286 .35274 L
.14286 .01472 L
F
0 g
.09524 .01472 m
.09524 .35274 L
.14286 .35274 L
.14286 .01472 L
.09524 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .3231 L
.19048 .3231 L
.19048 .01472 L
F
0 g
.14286 .01472 m
.14286 .3231 L
.19048 .3231 L
.19048 .01472 L
.14286 .01472 L
s
1 0 0 r
.19048 .01472 m
.19048 .24763 L
.2381 .24763 L
.2381 .01472 L
F
0 g
.19048 .01472 m
.19048 .24763 L
.2381 .24763 L
.2381 .01472 L
.19048 .01472 L
s
1 0 0 r
.2381 .01472 m
.2381 .21841 L
.28571 .21841 L
.28571 .01472 L
F
0 g
.2381 .01472 m
.2381 .21841 L
.28571 .21841 L
.28571 .01472 L
.2381 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .17805 L
.33333 .17805 L
.33333 .01472 L
F
0 g
.28571 .01472 m
.28571 .17805 L
.33333 .17805 L
.33333 .01472 L
.28571 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .1337 L
.38095 .1337 L
.38095 .01472 L
F
0 g
.33333 .01472 m
.33333 .1337 L
.38095 .1337 L
.38095 .01472 L
.33333 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .12382 L
.42857 .12382 L
.42857 .01472 L
F
0 g
.38095 .01472 m
.38095 .12382 L
.42857 .12382 L
.42857 .01472 L
.38095 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .1131 L
.47619 .1131 L
.47619 .01472 L
F
0 g
.42857 .01472 m
.42857 .1131 L
.47619 .1131 L
.47619 .01472 L
.42857 .01472 L
s
1 0 0 r
.47619 .01472 m
.47619 .08114 L
.52381 .08114 L
.52381 .01472 L
F
0 g
.47619 .01472 m
.47619 .08114 L
.52381 .08114 L
.52381 .01472 L
.47619 .01472 L
s
1 0 0 r
.52381 .01472 m
.52381 .07337 L
.57143 .07337 L
.57143 .01472 L
F
0 g
.52381 .01472 m
.52381 .07337 L
.57143 .07337 L
.57143 .01472 L
.52381 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .07063 L
.61905 .07063 L
.61905 .01472 L
F
0 g
.57143 .01472 m
.57143 .07063 L
.61905 .07063 L
.61905 .01472 L
.57143 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .05045 L
.66667 .05045 L
.66667 .01472 L
F
0 g
.61905 .01472 m
.61905 .05045 L
.66667 .05045 L
.66667 .01472 L
.61905 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .04919 L
.71429 .04919 L
.71429 .01472 L
F
0 g
.66667 .01472 m
.66667 .04919 L
.71429 .04919 L
.71429 .01472 L
.66667 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .04057 L
.7619 .04057 L
.7619 .01472 L
F
0 g
.71429 .01472 m
.71429 .04057 L
.7619 .04057 L
.7619 .01472 L
.71429 .01472 L
s
1 0 0 r
.7619 .01472 m
.7619 .03574 L
.80952 .03574 L
.80952 .01472 L
F
0 g
.7619 .01472 m
.7619 .03574 L
.80952 .03574 L
.80952 .01472 L
.7619 .01472 L
s
1 0 0 r
.80952 .01472 m
.80952 .0309 L
.85714 .0309 L
.85714 .01472 L
F
0 g
.80952 .01472 m
.80952 .0309 L
.85714 .0309 L
.85714 .01472 L
.80952 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .02838 L
.90476 .02838 L
.90476 .01472 L
F
0 g
.85714 .01472 m
.85714 .02838 L
.90476 .02838 L
.90476 .01472 L
.85714 .01472 L
s
1 0 0 r
.90476 .01472 m
.90476 .02375 L
.95238 .02375 L
.95238 .01472 L
F
0 g
.90476 .01472 m
.90476 .02375 L
.95238 .02375 L
.95238 .01472 L
.90476 .01472 L
s
1 0 0 r
.95238 .01472 m
.95238 .03153 L
1 .03153 L
1 .01472 L
F
0 g
.95238 .01472 m
.95238 .03153 L
1 .03153 L
1 .01472 L
.95238 .01472 L
s
0 .60332 m
.03864 .51515 L
.08077 .43399 L
.12034 .36979 L
.1584 .31734 L
.19891 .26999 L
.2379 .23143 L
.27935 .19681 L
.31928 .16869 L
.35769 .14575 L
.39856 .12508 L
.43791 .10827 L
.47574 .09452 L
.51603 .0821 L
.5548 .07197 L
.59603 .06287 L
.63573 .05547 L
.67393 .04943 L
.71457 .04398 L
.7537 .03955 L
.79528 .03557 L
.83535 .03234 L
.8739 .0297 L
.91491 .02733 L
.95238 .0255 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Goooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0??ooool4o`000003oa0@4?oooooooooo03Wooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03_ooooo1Ol0
000Rooooo`00Goooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08_ooool005oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?oV9RHob4Q8Oo^k^h0
8oooool005oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03gooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03cooooo
00?oV9RHob4Q8Oo^k^h08_ooool005oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0?_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00nooooo`03ogMgMomVIVKooooo027ooooo001Oooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
023ooooo001Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0moooo
o`05o`000?nj^[[ooooooiRHV?l@41008_ooool005oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000?Oooool00omEEEGoIVIVo`00000mooooo`03oeEEEOmVIVKo000000gooooo1?l0000l
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08_ooool00?ooooooJOooool002;ooooo00?o0000oooo
ooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooocWooooo0_l00002ooooo`;o
00001Oooool002;ooooo00?o0000ooooooooool0ooooooliooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1Oooool002;ooooo00?o0000ooooooooool0ooooooljooooo`04omgMgOl0003o410@olc<
c0Kooooo000Roooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kPKooooo000Rooooo`03
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1_ooool002;ooooo00?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000oooooooo
ool02?ooool2o`0000;ooooo0_l00005ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0013o0000
3Ooo00000ol0003oooooooooo`0Cooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000_oo`0000?o0000ool00?oo00003?oo000Go`0000Kooooo00?o0000ool00?oo00002ooo
00000ol0003oooooooooo`0Cooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003o
o`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003o
o`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003o
o`0000_oo`006_l0000Booooo`oo00005Oooool002;ooooo00?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oooooo000000_o0000@_ooool002;ooooo00?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo000@o`0004kooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
2ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
2ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000;ool001?o0000F_ooool002;ooooo00?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000Soo`002Ol0001Wooooo`008_ooool0
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00000_oo0006
o`0000?oo`0000?o0000ooooooooool0J_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo000No`00
06cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ooooooooool01Oooool6o`0007co
oooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ooooool000001Ol00022ooooo`008_oo
ool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool00007ool000Ko0000R?ooool002;ooooo00?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00000_oo0005
o`0000Coo`0000?o0000ooooooooool0Qoooool002;ooooo00?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`001Ol00009ool00003o`000?oooooooooo
08Oooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool00009ool001;o0000ROooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool0013o0000Uoooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000;ool00004o`000?ooooooooooooooo`Co0000Woooool002;ooooo00?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
000Bo`000:?ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool01oooool4
o`000:Oooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool00_ooool5o`00
0:_ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`001Ol0002`ooooo`008_ooool00ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000:ool000?o0000]?ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00002?oo0002o`0000;oo`0000?o
0000ooooooooool0/_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<
ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<
ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00001Ooo0003o`0000Coo`0000?o0000
ooooooooool0/_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00000ooo0002o`0000Ooo`0000?o0000oooo
ooooool0/_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000_oo`0000Co0000ool00?oo003oo`000_l00009ool00003o`000?oooooooooo
0;;ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00004o`000?oo003o0000o`0000_oo`0000?o0000ooooooooool0/_ooool000So
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000[oo`004Ol0002dooooo`002oooool02OmgMgOo<S8boooooooo
ooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002?oo0002o`00
0003ool00?l0003ooooo0<;ooooo000<ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000Koo`000_l00003ool00003o`000?oooooo
oooo0<7ooooo000;ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`003ol00033ooooo`002?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000Co0000oooooooooooooooo0_l0003<oooo
o`002?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<
ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<
ool00004o`000?oooooo0000o`000<kooooo0008ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool0017o0000d?ooool000Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
ooooooooo`0:ooooo`;o0000d_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003ooooo
ooooo`08ooooo`;o0000e?ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003ooooooooo
o`06ooooo`;o0000e_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<
ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oooooooooo`04
ooooo`;o0000f?ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oooooooooo`02oooo
o`;o0000f_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00001Ol0003ooooooooooooooooo0000
0=cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000_oo`0000Co0000ooooool0003o0000gOooool002;o
oooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_o
o`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000co
o`0000?o0000ool00?oo00002ooo0002o`000=oooooo000Rooooo`03o`000?oo003oo`0000_oo`00
00?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`00
00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000[oo`00
0_l0003Pooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o
0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o
0000ool00?oo00003?oo00000ol0003oo`00ool00008ool000;o000000?oo`00o`000?ooool0gooo
ool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003o
o`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00001_oo0002o`0000?oo`0000?o0000ooooooooool0g_ooool0
02;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
0=kooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003o
ooooooooo`3Nooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`00
00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`00
00?o0000ool00?oo00003?oo000?o`000>3ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o
0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o
0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00005o`000?ooooooooooooooool00000
j_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000Co0000oooooooooooo0000joooool002;ooooo00?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`000ol0003/ooooo`008_ooool0
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oooooooooo`3/ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00_oo`0000?o0000ool00?oo00002ooo0002o`000>kooooo000Rooooo`03o`000?oo003oo`0000_o
o`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000co
o`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool00009ool000;o000000?oo`00o`000?oo
ool0kOooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000Soo`0000Go0000ool00?oo003oo`00o`00003^ooooo`008_ooool00ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00
ool00002ool00003o`000?oooooooooo0>cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o
0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o
0000ool00?oo00002ooo00000ol0003oo`00ool00005ool000;o00001Ooo00000ol0003ooooooooo
o`3/ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000
ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00005ool00003o`000?oooooooooo0>cooooo000Roooo
o`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Koo`0000?o0000ooooooooool0k?ooool000Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000co
o`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_o
o`004?l0003^ooooo`000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oooooooooo`02
o`000?Wooooo0002ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`00
00?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oooooo00000?_ooooo
0002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ool0
0?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool0
0?oo00003?oo00000ol0003oo`00ool0000;ool000;o0000o?ooool000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000_oo`0000?o0000ooooooooool0noooool000;ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000co
o`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000[o
o`000_l0003mooooo`000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002Ooo00000ol0003oo`00o`00003m
ooooo`0000?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000Soo`0000Co0000ool00?oo003o0000oOooool002;ooooo
00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`00
00?o0000ool00?oo00003?oo00000ol0003oo`00ool00007ool00005o`000?oo003oo`00ool00?l0
0000oOooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo000?o`000?gooooo000Rooooo`03o`000?oo
003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo
003oo`0000coo`0000?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`;ooooo000R
ooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`?ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool00oooool00ol0
003oooooooooo`3oooooo`Cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooo`Gooooo000Rooooo`03o`000?oo003oo`0000_oo`00
00?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`00
00Go0000ooooooooooooooooo`00003oooooo`Sooooo000Rooooo`03o`000?oo003oo`0000_oo`00
00?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`00
00Co0000oooooooooooo0000ooooool9ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oooooo00000?oooooo2_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oooooo`00
003oooooo`[ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`000_l0003oooooo`_ooooo000Roooo
o`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0
0003o`000?oo003oo`0000coo`0000?o0000ooooooooool0ooooool:ooooo`008_ooool00ol0003o
o`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000;ool000;o0000ooooool<ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0003oo`00ool0000:ool00003o`00
0?oo003o00000?oooooo3?ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo00002Ooo00001?l0003oo`00ool0
0?l0003oooooo`cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000Soo`0000Go0000ool00?oo003oo`00
o`00003oooooo`cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000Soo`0000Go0000ool00?oo003oo`00
o`00003oooooo`cooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000Ooo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`3oooooo`[ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000
ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000Koo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`3oooooo`[ooooo000Rooooo`03o`000?oo003oo`00
00_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`00
00Goo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`3oooooo`[ooooo000Rooooo`03
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001Ooo00000ol0003oooooooooo`3oooooo`[o
oooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001_oo00000ol0003ooooo
ooooo`3oooooo`[ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo
00000ol0003oooooooooo`3oooooo`[ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000
ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00001ooo00000ol0003oooooooooo`3oooooo`[ooooo0004o`000005oa0@4?oooooooooo
oooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00002ooo000@o`000?oooooo3?ooool000;ooooo00?o0000oooooooo
ool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`00
00?o0000ool00?oo00002ooo00001?l0003oooooooooool0003ooooooaSooooo0002ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01?ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00002ooo00000ol0003oooooo`00003ooooooaWooooo0002ooooo`03
o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000_oo`0000?o0000
ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oooooo00000?oooooo6Oooool0
00;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oo`00
ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo0002o`000?oooooo
6_ooool000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ool00?oo
00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000oooooooo
ool0oooooolIooooo`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002_oo0002o`00
0?oooooo6oooool00003oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000[oo`000_l0003ooooooa_ooooo000Roooo
o`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool00009ool0
0003o`000?oo003o00000?oooooo6oooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003o
o`00ool0000<ool000oo0000oooooolKooooo`008_ooool00ol0003oo`00ool0000;ool00003o`00
0?oo003oo`0000coo`0000?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooagooooo
000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo00000ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo7Oooool002;ooooo00?o0000ool00?oo00002ooo0000
0ol0003oo`00ool0000<ool00003o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolN
ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000coo`0000?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooooaoooooo000Rooooo`03o`000?oo003oo`0000_o
o`0000?o0000ool00?oo00003?oo00000ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo8?ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooolPooooo`008_ooool00ol0003oo`00ool0
000;ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool00oooool00ol0003ooooooooo
o`3oooooob7ooooo000Rooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00003?oo0000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo8_ooool002;ooooo00?o0000ool0
0?oo00002ooo00000ol0003oo`00ool0000<ool00003o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolRooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000co
o`0000Go0000ooooooooooooooooo`00003oooooobGooooo000Rooooo`03o`000?oo003oo`0000_o
o`0000?o0000ool00?oo00003?oo00001Ol0003ooooooooooooooooo00000?oooooo9Oooool002;o
oooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00004o`000?ooooooooooo`00
0?oooooo9_ooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000<ool00003
o`000?oooooo00000?oooooo9oooool002;ooooo00?o0000ool00?oo00002ooo00000ol0003oo`00
ool0000<ool00003o`000?oooooo00000?oooooo9oooool002;ooooo00?o0000ool00?oo00002ooo
00000ol0003oo`00ool0000<ool000;o0000oooooolXooooo`008_ooool00ol0003oo`00ool0000;
ool00003o`000?oo003oo`0000coo`000_l0003oooooobSooooo000Rooooo`03o`000?oo003oo`00
00_oo`0000?o0000ool00?oo00003?oo00000ol0003oooooooooo`3oooooobOooooo000Rooooo`03
o`000?oo003oo`0000_oo`0000?o0000ool00?oo00002ooo0002o`000?oooooo:Oooool002;ooooo
00?o0000ool00?oo00002ooo00000ol0003oo`00ool0000;ool000;o0000oooooolYooooo`008_oo
ool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000[oo`0000?o0000ool00?l00000oooo
oolYooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000[oo`0000?o0000
ool00?l00000oooooolYooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`00
00Woo`0000Co0000ool00?oo003o0000oooooolYooooo`001?l00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo00002?oo00001Ol0003oo`00
ool00?oo003o00000?oooooo:Oooool00004ob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ool00?oo00002ooo00000ol0003oo`00ool00008ool00005o`000?oo
003oo`00ool00?l00000oooooolYooooo`0000?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oo`00ool0000;ool00003o`000?oo003oo`0000Ooo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`3oooooobOooooo00001?ooooooV9RHob4Q8Oo^k^h3oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oo003oo`0000_oo`0000?o0000ool00?oo0000
1ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo0?oooooo9oooool000;ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oo`00ool0000;ool0
0003o`000?oo003oo`0000Koo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`3ooooo
obOooooo0003ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ool00?oo00002ooo00000ol0003oo`00ool00006ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0oooooolWooooo`0000Co^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oo`00ool0000;ool0013o0000oooooolYooooo`0000Co410@o`000?lQ
8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oo`00ool0000;ool00003o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0ooooool^ooooo`008_ooool00ol0003oo`00ool0
000;ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool_ooooo`008_ooool0
0ol0003oo`00ool0000;ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool_
ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0ooooool`ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`000?oooooooooo00?o
oooo00?o0000ooooooooool0ooooool`ooooo`008_ooool00ol0003oo`00ool0000;ool00003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0oooooolaooooo`008_ooool00ol0003oo`00ool0
000;ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolaooooo`008_ooool0
0ol0003oo`00ool0000;ool00005o`000?ooooooooooooooool00000ooooooldooooo`008_ooool0
0ol0003oo`00ool0000;ool00004o`000?ooooooooooo`000?oooooo=Oooool002;ooooo00?o0000
ool00?oo00002ooo00001?l0003oooooooooool0003oooooocGooooo000Rooooo`03o`000?oo003o
o`0000_oo`0000?o0000ooooool00000oooooolfooooo`008_ooool00ol0003oo`00ool0000;ool0
0003o`000?oooooo00000?oooooo=_ooool002;ooooo00?o0000ool00?oo00002ooo0002o`000?oo
oooo=oooool002;ooooo00?o0000ool00?oo00002ooo0002o`000?oooooo=oooool002;ooooo00?o
0000ool00?oo00002ooo00000ol0003oooooooooo`3oooooocKooooo000Rooooo`03o`000?oo003o
o`0000_oo`0000?o0000ooooooooool0oooooolfooooo`008_ooool00ol0003oo`00ool0000:ool0
00;o0000oooooolhooooo`008_ooool00ol0003oo`00ool0000:ool000;o0000oooooolhooooo`00
8_ooool00ol0003oo`00ool00009ool00003o`000?oo003o00000?oooooo>?ooool002;ooooo00?o
0000ool00?oo00002Ooo00000ol0003oo`00o`00003oooooocSooooo000Rooooo`03o`000?oo003o
o`0000Soo`0000Co0000ool00?oo003o0000oooooolhooooo`008_ooool00ol0003oo`00ool00008
ool00004o`000?oo003oo`00o`000?oooooo>?ooool002;ooooo00?o0000ool00?oo00001ooo0000
1Ol0003oo`00ool00?oo003o00000?oooooo>?ooool002;ooooo00?o0000ool00?oo00001ooo0000
1Ol0003oo`00ool00?oo003o00000?oooooo>?ooool002;ooooo00?o0000ool00?oo00001ooo0000
1Ol0003oo`00ool00?oo003o00000?oooooo>?ooool000Co00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oo`00ool00006ool00003o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0oooooolfooooo`0000Co8B4Qonk^k_ooooooA4A41oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oo`00
ool00006ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0oooooolfooooo`0000?o
V9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oo003oo`0000Goo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`3oooooocKooooo00001?ooooooV9RHob4Q8Oo^k^h7ooooo`05
ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oo`00ool00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0oooooolfooooo`000_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003ooooo
ooooo`3oooooocKooooo0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`3oooooocKo
oooo00001?nj^[[ooooooiRHV?l@4104ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0oooooolfooooo`0000Co410@o`00
0?lQ8B7oc<c<1?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool?o`000?oooooo>?ooool002;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3oooooockooooo000Rooooo`;o00000oooool00ol0003oooooooooo`3o
ooooocoooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolooooo
o`008_ooool01Ol0003ooooooooooooooooo00000?oooooo@_ooool002;ooooo00Go0000oooooooo
ooooooooo`00003ooooood;ooooo000Rooooo`05o`000?ooooooooooooooool00000oooooom2oooo
o`008_ooool01?l0003oooooooooool0003ooooood?ooooo000Rooooo`;o000000?oooooo`000?oo
ool0oooooom2ooooo`008_ooool00ol0003oooooo`00003oooooodCooooo000Rooooo`03o`000?oo
oooo00000?ooooooA?ooool002;ooooo0_l0003oooooodGooooo000Rooooo`;o0000oooooom5oooo
o`008_ooool2o`000?ooooooAOooool002;ooooo0_l0003oooooodGooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`007oooool00omgMgOoIVIVooooo`08ooooo`03ofIVI_mgMgOooooo0?oooooo
??ooool001kooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@3ooooooccooooo000C
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00_ooool00omEEEGoV9RHoooo
o`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool0oooooolkooooo`005?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@;ooooo00?ok^k^o`000?ooool0oooooolkooooo`005?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o<S8booooooooool00oooool01?oMgMgo0000oa0@4?o<c<`4oooo
o`03o`000?oooooooooo0?oooooo>_ooool001Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^1?ooool00ol0003oooooooooo`3o
oooooc[ooooo000Dooooo`Go00001Oooool00ol0003ok^k^ooooo`03ooooo`04ob4Q8OmgMgOoMgMg
oc8b<P?ooooo00?ok^k^o`000?ooool0oooooolkooooo`005?ooool01Ol0003ooooooooooooooooo
000000Gooooo00?oEEEEogMgMoooool00_ooool2o`0000;ooooo0_l00002ooooo`03ogMgMomEEEGo
oooo0?oooooo>oooool001Cooooo00Go0000ooooooooooooooooo`000005ooooo`03omgMgOl@413o
k^k^00Wooooo00?ok^k^oa0@4?oMgMd0oooooollooooo`004oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`3o
oooooccooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.235175, -235.209, \
0.00862086, 19.5283}}]
}, Open  ]],

Cell[TextData[{
  "The histogram is in excellent agreement with the prediction of the \
Boltzmann distribution. Note that the maximum step size 0.8 used in this \
random process is quite large, yet the particle distribution still follows \
the thermal equilibrium theory. This is as opposed to the results displayed \
in Fig. ",
  ButtonBox["8.7",
    ButtonData:>"Fig. 8.7",
    ButtonStyle->"Hyperlink"],
  ", which were not generated using the Rosenbluth-Teller-Metropolis method. \
"
}], "Text"],

Cell[TextData[{
  "\tFluctuations in the histogram away from ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\)]],
  "can be easily understood using the same argument as was used for \
fluctuations in potential energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". In any given histogram bin centered at ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  the rms fluctuation in ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " away from its expected value will be proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(H(x)\)\)]],
  ". For large ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " this error is small compared to ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " itself, so the histogram matches ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_B\)]],
  ".  "
}], "Text",
  CellTags->"i:89"],

Cell[TextData[{
  "\tThe reason that the rms fluctuation in ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " scales as ",
  Cell[BoxData[
      \(TraditionalForm\`\@H\)]],
  " is as follows. Assume for simplicity that the histogram is made using the \
random walk of a single particle  executing ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " steps. At timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " the particle lands in the bin at position ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  ". The total number of times the particle lands in bin ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(H(x)\)\(,\)\)\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`H(
          x)\  = \ \[Sum]\+\(n = 1\)\%N \[Delta]\_\(x, x\_n\)\)]],
  ". Furthermore, the probability ",
  Cell[BoxData[
      \(TraditionalForm\`P(x)\)]],
  " of landing in this bin is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(P(x)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(H(x)\), "\[RightAngleBracket]"}], "/", 
            "N"}]}], TraditionalForm]]],
  ", where the average can be thought of as  an average over many repeated \
random walks. "
}], "Text"],

Cell[TextData[{
  "\tThe mean ",
  "squared ",
  "fluctuation in ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " for finite ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "  is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["H",
                      FontSlant->"Italic"]}]], "(", "x", ")"}], "2"], 
            "\[RightAngleBracket]"}], " ", "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(\(H(x)\)\^2\), "\[RightAngleBracket]"}],
             "-", 
            SuperscriptBox[
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], \(H(x)\), "\[RightAngleBracket]"}], 
              "2"]}]}], TraditionalForm]]],
  ".  Since we already know ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(H(x)\), "\[RightAngleBracket]"}], " ", 
          "=", \(\(N\)\(\ \)\(P(x)\)\(\ \)\)}], TraditionalForm]]],
  ", we only need ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(\(H(x)\)\^2\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ". This is given in the usual way by"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(\(H(x)\)\^2\), "\[RightAngleBracket]"}], 
          " ", "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], 
              RowBox[{
                UnderoverscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->6], \(n = 1\), "N"], 
                RowBox[{\(\[Delta]\_\(x, x\_n\)\), " ", 
                  RowBox[{
                    UnderoverscriptBox[
                      StyleBox["\[Sum]",
                        FontSize->9], \(n\&_ = 1\), 
                      "N"], \(\[Delta]\_\(x, x\_n\&_\)\)}]}]}], 
              "\[RightAngleBracket]"}], "=", 
            RowBox[{
              RowBox[{\(\[Sum]\+\(n = 1\)\%N\), 
                RowBox[{\(\[Sum]\+\(n\&_ \[NotEqual] \ n\)\%N\), 
                  RowBox[{
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], \(\[Delta]\_\(x, x\_n\)\), 
                      "\[RightAngleBracket]"}], 
                    RowBox[{
                      FormBox["\[LeftAngleBracket]",
                        "TraditionalForm"], \(\[Delta]\_\(x, x\_n\&_\)\), " ",
                       "\[RightAngleBracket]"}]}]}]}], "+", 
              RowBox[{\(\[Sum]\+\(n = 1\)\%N\), 
                RowBox[{
                  FormBox["\[LeftAngleBracket]",
                    "TraditionalForm"], \(\[Delta]\_\(x, x\_n\)\^2\), 
                  "\[RightAngleBracket]"}]}]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where we have assumed for simplicity that the particle positions at \
different timesteps are completely uncorrelated, so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              
              "TraditionalForm"], \(\(\[Delta]\_\(x, 
                  x\_n\)\) \[Delta]\_\(x, x\_n\&_\)\), " ", 
            "\[RightAngleBracket]"}], "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(\[Delta]\_\(x, x\_n\)\), 
              "\[RightAngleBracket]"}], 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(\[Delta]\_\(x, x\_n\&_\)\), " ", 
              "\[RightAngleBracket]"}]}]}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ n\&_\)]],
  ". Each of these averages simply yields ",
  Cell[BoxData[
      \(TraditionalForm\`P(x)\)]],
  ",",
  " and furthermore ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(\[Delta]\_\(x, x\_n\)\^2\), 
            "\[RightAngleBracket]"}], "=", 
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(\[Delta]\_\(x, x\_n\)\), 
              "\[RightAngleBracket]"}], " ", "=", \(P(x)\)}]}], 
        TraditionalForm]]],
  ", so "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(\(H(x)\)\^2\), "\[RightAngleBracket]"}], 
          " ", "=", 
          " ", \(N\ \((N - 1)\) \(P(x)\)\^2\  + \ \(\(N\)\(\ \)\(P(
                x)\)\(\ \)\)\)}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Therefore, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["H",
                      FontSlant->"Italic"]}]], "(", "x", ")"}], "2"], 
            "\[RightAngleBracket]"}], " ", 
          "=", \(\(N(N - 1)\)\ \(P(x)\)\^2 + 
              N\ \(P(x)\)\  - \ \(N\^2\) \(P(x)\)\^2 = \ 
            N\ \(P(x)\)[1 - P(x)]\)}], TraditionalForm]]],
  ". However, assuming there are many bins with ",
  Cell[BoxData[
      \(TraditionalForm\`\(P(x)\) << 1\)]],
  " for any one bin, we obtain "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], 
            SuperscriptBox[
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["H",
                      FontSlant->"Italic"]}]], "(", "x", ")"}], "2"], 
            "\[RightAngleBracket]"}], " ", "=", " ", 
          RowBox[{\(N\ \(P(x)\)\), "=", 
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], \(H(x)\), "\[RightAngleBracket]"}]}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.18)"],

Cell[TextData[{
  "Hence, the rms fluctuation in the distribution equals ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(H(x)\), "\[RightAngleBracket]"}]], 
        TraditionalForm]]],
  ", which is not much different than ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(H(x)\)\)]],
  "itself, obtained from any one realization of the random walk.   "
}], "Text"],

Cell[TextData[{
  "\tThis result for fluctuations in ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " assumed that the particle's positions at different times were \
uncorrelated, which  is not really true. According to our previous arguments, \
we would therefore expect that the rms fluctuation in ",
  Cell[BoxData[
      \(TraditionalForm\`H(x)\)]],
  " is increased by roughly a factor ",
  Cell[BoxData[
      \(TraditionalForm\`\@m\_c\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  " is the correlation time for the particle position.  "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Lennard-Jones Clusters", "Section",
  CellTags->{"i:72", "c:29"}],

Cell[TextData[{
  "The power of the Rosenbluth-Teller-Metropolis method is only fully \
realized when dealing with systems of interacting particles, for which no \
exact analytic theory predictions are available.  Here, we choose a system of \
",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " particles interacting via the  Lennard-Jones potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], " ", "=", 
          " ", \(r\^\(-12\) - 2\ r\^\(-6\)\)}], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:69"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\(<< Statistics`;\)\), "\n", 
    \(\(<< Graphics`;\)\), "\n", 
    \(\[Phi]int[r1_]\ \  := \ 
      1/r^12\  - \ 2/r^6\  /. r \[Rule] Sqrt[r1 . r1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.42"],

Cell[TextData[{
  "This potential is weakly attractive at long range and repulsive at short \
range. We will investigate the configuration and average energy of a cluster \
of ",
  Cell[BoxData[
      \(TraditionalForm\`six\)]],
  " particles interacting via this potential, as a function of the \
temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ".  The number of particles is chosen to be small in order to make the code \
run quickly. Since the interaction between ",
  Cell[BoxData[
      \(TraditionalForm\`\(M(M - 1)\)/2\)]],
  " pairs or particles must be calculated, the time required to run the code \
scales as ",
  Cell[BoxData[
      \(TraditionalForm\`M\^2\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t In order to keep particles from escaping to infinity (as they might do \
at large temperatures), we  confine the particles in a spherical enclosure \
with radius ",
  Cell[BoxData[
      \(TraditionalForm\`3\)]],
  " units:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi]ext[r1_]\  := \ 10^5\  /; \ r1 . r1 > 9;\)\), "\n", 
    \(\(\[Phi]ext[r1_]\  := \ 
        0\  /; \ r1 . r1\  \[LessEqual] \ 9;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.43"],

Cell["\<\
Then the potential energy is the sum over all the interparticle \
interactions, including the energy associated with the external \
potential:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"U", "(", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(i = 2\)\%M\), 
              RowBox[{\(\[Sum]\+\(j = 1\)\%\(\(\ \)\(i - 1\)\)\), 
                RowBox[{\(\[Phi]\_int\), "(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], \(\(i\)\(\ \)\)], "-", " ", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "j"]}], ")"}]}]}], " ", "+", 
            RowBox[{\(\[Sum]\+\(i = 1\)\%M\), 
              RowBox[{\(\[Phi]\_ext\), "(", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], ")"}], " "}]}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(8.3.19)"],

Cell[TextData[{
  "Our state variable in the random walk will be the vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{"{", 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "1"], ",", " ", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"], ",", "...", ",", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "M"]}], "}"}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", so we write ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  " in terms of ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(U[z_]\  := \ \(\(Sum[
          Sum[\[Phi]int[ri - rj] /. {ri \[Rule] z[\([i]\)], 
                rj \[Rule] z[\([j]\)]}, {j, 1, i - 1}], {i, 2, 
            M}]\)\(\ \)\(+\)\(Sum[\[Phi]ext[z[\([i]\)]], {i, 1, 
            M}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.44"],

Cell[TextData[{
  "An unbiased random step between states is then a vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["s",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Plain"]}]], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{"{", 
              RowBox[{
                SubscriptBox[
                  StyleBox["s",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "1"], ",", " ", 
                SubscriptBox[
                  StyleBox["s",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"], ",", "...", ",", 
                SubscriptBox[
                  StyleBox["s",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "M"]}], "}"}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", with maximum size ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[PlusMinus]", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " in each dimension:"
}], "Text"],

Cell[BoxData[
    \(s[]\  := \ 
      Table[Table[
          Random[Real, {\(-\[CapitalDelta]x\), \[CapitalDelta]x}], {3}], {M}]\
\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.45"],

Cell["\<\
In other words, we now step all of the particles at once, rather \
than one at a time as we did previously.  We could step the particles one at \
a time here as well, but the code is more elegant when all particles are \
moved simultaneously.  \
\>", "Text"],

Cell[TextData[{
  "\tThere are pros and cons to moving all the particles at once. For large \
numbers of particles,  it is more efficient to step one particle at a time, \
because this allows one to take larger steps with the same acceptance rate: \
for a given step size the energy change will on average be smaller if only \
one particle moves than if all the particles move. (If the energy change \
caused by each particle's step is random and unbiased with zero mean, how \
does the magnitude of the energy change scale with the number of \
participating particles?)  But for only six particles we needn't worry about \
this.  On the other hand,  moving all the particles at once can sample the \
configuration space more efficiently.  See the exercises for a more thorough \
discussion of these issues.\n\t The code for the method is given below, and \
is almost identical to the previous ideal gas code.  The function ",
  StyleBox["z[n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the array of positions at timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{\(z[n_]\), " ", ":=", 
      RowBox[{\(z[n]\), "=", "\[IndentingNewLine]", 
        StyleBox[\( (*\ 
            step\ all\ particles\ randomly\ to\ new\ positions\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
        RowBox[{"(", 
          
          RowBox[{\(z1\  = \ \ z[n - 1]\  + \ s[]\), ";", " ", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ test\ the\ new\ configuration\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[CapitalDelta]U\  = \ 
              U[z1] - energy[n - 1]\), ";", 
            "\[IndentingNewLine]", \(nkept[n] = \ 1\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{\(\[CapitalDelta]U > 0\), ",", " ", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(Random[] > \ \ Exp[\(-\[CapitalDelta]U\)/T]\), 
                    ",", "\[IndentingNewLine]", 
                    StyleBox[\( (*\ reject\ the\ step\ *) \),
                      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                    StyleBox["  ",
                      FontColor->RGBColor[1, 0, 0]], \(\[CapitalDelta]U = 
                      0; \[IndentingNewLine]nkept[n] = 
                      0; \[IndentingNewLine]z1 = \ z[n - 1];\)}], "]"}]}], 
              "]"}], ";", 
            "\[IndentingNewLine]", \(energy[n]\  = \ 
              energy[n - 1]\  + \ \[CapitalDelta]U\), ";", 
            "\[IndentingNewLine]", "z1"}], ")"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.46"],

Cell["\<\
The only difference from Example 1, other than moving all the \
particles at once,  is that we now keep track of the energy as we go, since \
we have to calculate it anyway at each step.  \
\>", "Text"],

Cell[TextData[{
  "\tWe run the code below for a cluster of ",
  Cell[BoxData[
      \(TraditionalForm\`M = 6\)]],
  " particles, starting at a low temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0.1\)]],
  ", and choosing a stepsize ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.03"}], 
        TraditionalForm]]],
  ". The initial positions of the particles are chosen randomly:"
}], "Text"],

Cell[BoxData[{
    \(M = 6; \ T = 0.1; \ \[CapitalDelta]x\  = \ 0.03;\), "\n", 
    \(\(z[0] = 
        Table[{Random[Real, {\(-1.5\), 1.5}], Random[Real, {\(-1.5\), 1.5}], 
            Random[Real, {\(-1.5\), 1.5}]}, {M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.47"],

Cell["\<\
We run the code forward for 2000 steps, and then check to determine \
what fraction of steps are accepted:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Do[\(z[n];\), {n, 0, 2000, 1}];\)\), "\n", 
    \(Mean[Table[nkept[n], {n, 1, 2000}]] // N\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.48"],

Cell[BoxData[
    \(0.3285`\)], "Output"]
}, Open  ]],

Cell["\<\
The fraction of accepted steps is on the low side, so we reduce the \
stepsize to 0.02 and continue the run for 12000 steps\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CapitalDelta]x\  = \ 0.02;\)\), "\n", 
    \(\(Do[\(z[n];\), {n, 0, 12000, 100}];\)\), "\n", 
    \(Mean[Table[nkept[n], {n, 2000, 12000}]] // N\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.49"],

Cell[BoxData[
    \(0.47115288471152883`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the fraction of accepted steps is much closer to 50%. In Cell ",
  ButtonBox["8.45",
    ButtonData:>"Cell 8.45",
    ButtonStyle->"Hyperlink"],
  ",  we plot the energy vs. timestep in order to observe the equilibration \
of the system."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n, energy[n]}, {n, 1, 12000}], 
        PlotJoined \[Rule] True];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.50"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 7.93651e-05 3.26162 0.257691 [
[.18254 .15683 -12 -9 ]
[.18254 .15683 12 0 ]
[.34127 .15683 -12 -9 ]
[.34127 .15683 12 0 ]
[.5 .15683 -12 -9 ]
[.5 .15683 12 0 ]
[.65873 .15683 -12 -9 ]
[.65873 .15683 12 0 ]
[.81746 .15683 -15 -9 ]
[.81746 .15683 15 0 ]
[.97619 .15683 -15 -9 ]
[.97619 .15683 15 0 ]
[.01131 .04048 -30 -4.5 ]
[.01131 .04048 0 4.5 ]
[.01131 .29817 -30 -4.5 ]
[.01131 .29817 0 4.5 ]
[.01131 .42702 -18 -4.5 ]
[.01131 .42702 0 4.5 ]
[.01131 .55586 -30 -4.5 ]
[.01131 .55586 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .16933 m
.18254 .17558 L
s
[(2000)] .18254 .15683 0 1 Mshowa
.34127 .16933 m
.34127 .17558 L
s
[(4000)] .34127 .15683 0 1 Mshowa
.5 .16933 m
.5 .17558 L
s
[(6000)] .5 .15683 0 1 Mshowa
.65873 .16933 m
.65873 .17558 L
s
[(8000)] .65873 .15683 0 1 Mshowa
.81746 .16933 m
.81746 .17558 L
s
[(10000)] .81746 .15683 0 1 Mshowa
.97619 .16933 m
.97619 .17558 L
s
[(12000)] .97619 .15683 0 1 Mshowa
.125 Mabswid
.06349 .16933 m
.06349 .17308 L
s
.10317 .16933 m
.10317 .17308 L
s
.14286 .16933 m
.14286 .17308 L
s
.22222 .16933 m
.22222 .17308 L
s
.2619 .16933 m
.2619 .17308 L
s
.30159 .16933 m
.30159 .17308 L
s
.38095 .16933 m
.38095 .17308 L
s
.42063 .16933 m
.42063 .17308 L
s
.46032 .16933 m
.46032 .17308 L
s
.53968 .16933 m
.53968 .17308 L
s
.57937 .16933 m
.57937 .17308 L
s
.61905 .16933 m
.61905 .17308 L
s
.69841 .16933 m
.69841 .17308 L
s
.7381 .16933 m
.7381 .17308 L
s
.77778 .16933 m
.77778 .17308 L
s
.85714 .16933 m
.85714 .17308 L
s
.89683 .16933 m
.89683 .17308 L
s
.93651 .16933 m
.93651 .17308 L
s
.25 Mabswid
0 .16933 m
1 .16933 L
s
.02381 .04048 m
.03006 .04048 L
s
[(-12.5)] .01131 .04048 1 0 Mshowa
.02381 .29817 m
.03006 .29817 L
s
[(-11.5)] .01131 .29817 1 0 Mshowa
.02381 .42702 m
.03006 .42702 L
s
[(-11)] .01131 .42702 1 0 Mshowa
.02381 .55586 m
.03006 .55586 L
s
[(-10.5)] .01131 .55586 1 0 Mshowa
.125 Mabswid
.02381 .06625 m
.02756 .06625 L
s
.02381 .09202 m
.02756 .09202 L
s
.02381 .11779 m
.02756 .11779 L
s
.02381 .14356 m
.02756 .14356 L
s
.02381 .1951 m
.02756 .1951 L
s
.02381 .22086 m
.02756 .22086 L
s
.02381 .24663 m
.02756 .24663 L
s
.02381 .2724 m
.02756 .2724 L
s
.02381 .32394 m
.02756 .32394 L
s
.02381 .34971 m
.02756 .34971 L
s
.02381 .37548 m
.02756 .37548 L
s
.02381 .40125 m
.02756 .40125 L
s
.02381 .45279 m
.02756 .45279 L
s
.02381 .47856 m
.02756 .47856 L
s
.02381 .50432 m
.02756 .50432 L
s
.02381 .53009 m
.02756 .53009 L
s
.02381 .01471 m
.02756 .01471 L
s
.02381 .58163 m
.02756 .58163 L
s
.02381 .6074 m
.02756 .6074 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05865 .61803 m
.05865 .61575 L
.05873 .61575 L
s
.05873 .61575 m
.05874 .61803 L
s
.05906 .61803 m
.05913 .5723 L
.05921 .58624 L
.05929 .58624 L
.05937 .58624 L
.05944 .59694 L
.05952 .59845 L
.0596 .59845 L
.05968 .59845 L
.05976 .5898 L
.05984 .54316 L
.05992 .54316 L
.06 .54316 L
.06008 .54316 L
.06016 .54316 L
.06024 .51366 L
.06032 .51366 L
.0604 .51366 L
.06048 .51366 L
.06056 .51366 L
.06063 .51608 L
.06071 .51608 L
.06079 .51608 L
.06087 .51608 L
.06095 .51608 L
.06103 .51608 L
.06111 .51608 L
.06119 .50117 L
.06127 .50117 L
.06135 .50117 L
.06143 .509 L
.06151 .509 L
.06159 .509 L
.06167 .509 L
.06175 .509 L
.06183 .509 L
.0619 .52909 L
.06198 .52909 L
.06206 .52909 L
.06214 .52909 L
.06222 .52909 L
.0623 .52909 L
.06238 .52909 L
.06246 .56978 L
.06254 .56978 L
.06262 .56978 L
.0627 .56978 L
.06278 .56978 L
.06286 .56978 L
.06294 .53152 L
Mistroke
.06302 .53152 L
.0631 .53152 L
.06317 .53152 L
.06325 .53152 L
.06333 .53454 L
.06341 .53454 L
.06349 .53454 L
.06357 .54158 L
.06365 .49069 L
.06373 .49069 L
.06381 .54376 L
.06389 .54376 L
.06397 .54376 L
.06405 .54376 L
.06413 .54376 L
.06421 .54376 L
.06429 .54376 L
.06437 .52962 L
.06444 .52962 L
.06452 .52518 L
.0646 .52518 L
.06468 .52518 L
.06476 .52518 L
.06484 .52518 L
.06492 .52673 L
.065 .5476 L
.06508 .5476 L
.06516 .5476 L
.06524 .5476 L
.06532 .5497 L
.0654 .57629 L
.06548 .57629 L
.06556 .57485 L
.06563 .57485 L
.06571 .50505 L
.06579 .50505 L
.06587 .50505 L
.06595 .43528 L
.06603 .46785 L
.06611 .46785 L
.06619 .46785 L
.06627 .46785 L
.06635 .46785 L
.06643 .46785 L
.06651 .46785 L
.06659 .46785 L
.06667 .46785 L
.06675 .46785 L
.06683 .42479 L
.0669 .49838 L
Mistroke
.06698 .49838 L
.06706 .49838 L
.06714 .49838 L
.06722 .47812 L
.0673 .47812 L
.06738 .47812 L
.06746 .47812 L
.06754 .47812 L
.06762 .47812 L
.0677 .47812 L
.06778 .47812 L
.06786 .47812 L
.06794 .47812 L
.06802 .47812 L
.0681 .47812 L
.06817 .47812 L
.06825 .47812 L
.06833 .47812 L
.06841 .47812 L
.06849 .47812 L
.06857 .47812 L
.06865 .50252 L
.06873 .50252 L
.06881 .47564 L
.06889 .47564 L
.06897 .47564 L
.06905 .47564 L
.06913 .47564 L
.06921 .47103 L
.06929 .48255 L
.06937 .48255 L
.06944 .48255 L
.06952 .48255 L
.0696 .48255 L
.06968 .48255 L
.06976 .48255 L
.06984 .48255 L
.06992 .49297 L
.07 .48603 L
.07008 .48603 L
.07016 .47641 L
.07024 .47641 L
.07032 .47641 L
.0704 .5519 L
.07048 .5519 L
.07056 .5519 L
.07063 .551 L
.07071 .4963 L
.07079 .50718 L
.07087 .50985 L
Mistroke
.07095 .50927 L
.07103 .5504 L
.07111 .5504 L
.07119 .5504 L
.07127 .5504 L
.07135 .53906 L
.07143 .53906 L
.07151 .53906 L
.07159 .53906 L
.07167 .55052 L
.07175 .55459 L
.07183 .55459 L
.0719 .55459 L
.07198 .55459 L
.07206 .55459 L
.07214 .55459 L
.07222 .56061 L
.0723 .5302 L
Mfstroke
.0723 .5302 m
.07237 .61803 L
s
.07266 .61803 m
.0727 .60021 L
.07278 .58377 L
.07286 .5621 L
.07294 .5621 L
.07302 .5621 L
.0731 .6073 L
.07317 .6073 L
s
.07317 .6073 m
.0732 .61803 L
s
.07373 .61803 m
.07381 .55926 L
.07389 .48645 L
.07397 .48645 L
.07405 .48645 L
.07413 .48645 L
.07421 .48645 L
.07429 .47536 L
.07437 .46521 L
.07444 .46521 L
.07452 .46521 L
.0746 .46521 L
.07468 .46521 L
.07476 .46521 L
.07484 .46621 L
.07492 .5123 L
.075 .5123 L
.07508 .5123 L
.07516 .5123 L
.07524 .5123 L
.07532 .5123 L
.0754 .5123 L
.07548 .5123 L
.07556 .52601 L
.07563 .52601 L
.07571 .52968 L
.07579 .53302 L
.07587 .53302 L
.07595 .53302 L
.07603 .53302 L
.07611 .53302 L
.07619 .4965 L
.07627 .4965 L
.07635 .4965 L
.07643 .48286 L
.07651 .48286 L
.07659 .48059 L
.07667 .48059 L
.07675 .48059 L
.07683 .48059 L
.0769 .48059 L
.07698 .48059 L
.07706 .48059 L
.07714 .48059 L
.07722 .48059 L
.0773 .48059 L
.07738 .48059 L
.07746 .48059 L
.07754 .48059 L
.07762 .47771 L
Mistroke
.0777 .48173 L
.07778 .48173 L
.07786 .48173 L
.07794 .49537 L
.07802 .49537 L
.0781 .49537 L
.07817 .49537 L
.07825 .50373 L
.07833 .5713 L
.07841 .5577 L
.07849 .5577 L
.07857 .5577 L
.07865 .59046 L
.07873 .59046 L
.07881 .59046 L
.07889 .59046 L
.07897 .59046 L
.07905 .57058 L
.07913 .5407 L
.07921 .5407 L
.07929 .50802 L
.07937 .50802 L
.07944 .50802 L
.07952 .50802 L
.0796 .50802 L
.07968 .54093 L
.07976 .54093 L
.07984 .54093 L
.07992 .54093 L
.08 .54093 L
.08008 .49929 L
.08016 .49929 L
.08024 .49929 L
.08032 .49929 L
.0804 .49929 L
.08048 .48184 L
.08056 .48184 L
.08063 .48184 L
.08071 .48184 L
.08079 .50864 L
.08087 .50864 L
.08095 .46418 L
.08103 .46418 L
.08111 .46418 L
.08119 .46418 L
.08127 .46418 L
.08135 .46418 L
.08143 .46418 L
.08151 .4592 L
.08159 .4592 L
Mistroke
.08167 .42361 L
.08175 .46347 L
.08183 .46347 L
.0819 .41832 L
.08198 .41832 L
.08206 .41832 L
.08214 .41832 L
.08222 .43527 L
.0823 .43527 L
.08238 .48285 L
.08246 .48285 L
.08254 .48285 L
.08262 .43535 L
.0827 .45053 L
.08278 .45053 L
.08286 .45053 L
.08294 .45053 L
.08302 .44366 L
.0831 .44366 L
.08317 .44366 L
.08325 .49416 L
.08333 .49416 L
.08341 .52443 L
.08349 .52443 L
.08357 .52443 L
.08365 .52443 L
.08373 .38922 L
.08381 .38922 L
.08389 .38833 L
.08397 .37591 L
.08405 .37591 L
.08413 .37591 L
.08421 .37591 L
.08429 .37591 L
.08437 .37591 L
.08444 .37591 L
.08452 .37591 L
.0846 .37591 L
.08468 .37591 L
.08476 .37591 L
.08484 .37591 L
.08492 .37591 L
.085 .40591 L
.08508 .45957 L
.08516 .45957 L
.08524 .45957 L
.08532 .45957 L
.0854 .45957 L
.08548 .45957 L
.08556 .44496 L
Mistroke
.08563 .44496 L
.08571 .44496 L
.08579 .44496 L
.08587 .44496 L
.08595 .44496 L
.08603 .44496 L
.08611 .44496 L
.08619 .44496 L
.08627 .44496 L
.08635 .44496 L
.08643 .44496 L
.08651 .44496 L
.08659 .4305 L
.08667 .41251 L
.08675 .41251 L
.08683 .41251 L
.0869 .41251 L
.08698 .41251 L
.08706 .41251 L
.08714 .41251 L
.08722 .41251 L
.0873 .41251 L
.08738 .41251 L
.08746 .41251 L
.08754 .41913 L
.08762 .41913 L
.0877 .377 L
.08778 .37626 L
.08786 .37626 L
.08794 .37626 L
.08802 .37626 L
.0881 .37626 L
.08817 .37626 L
.08825 .37626 L
.08833 .37385 L
.08841 .37385 L
.08849 .37385 L
.08857 .37385 L
.08865 .37385 L
.08873 .37385 L
.08881 .37385 L
.08889 .37385 L
.08897 .37385 L
.08905 .38482 L
.08913 .38482 L
.08921 .40634 L
.08929 .40634 L
.08937 .42747 L
.08944 .42747 L
.08952 .42747 L
Mistroke
.0896 .42747 L
.08968 .39077 L
.08976 .39077 L
.08984 .39077 L
.08992 .39077 L
.09 .41166 L
.09008 .41166 L
.09016 .41166 L
.09024 .41166 L
.09032 .41166 L
.0904 .41166 L
.09048 .41166 L
.09056 .4151 L
.09063 .44739 L
.09071 .46631 L
.09079 .47377 L
.09087 .47377 L
.09095 .47377 L
.09103 .47377 L
.09111 .50934 L
.09119 .50934 L
.09127 .52359 L
.09135 .52359 L
.09143 .52359 L
.09151 .52359 L
.09159 .40341 L
.09167 .40341 L
.09175 .40341 L
.09183 .45986 L
.0919 .45986 L
.09198 .45986 L
.09206 .47066 L
.09214 .4771 L
.09222 .50195 L
.0923 .42403 L
.09238 .39361 L
.09246 .34808 L
.09254 .3673 L
.09262 .3673 L
.0927 .3673 L
.09278 .3673 L
.09286 .37336 L
.09294 .37336 L
.09302 .37336 L
.0931 .37336 L
.09317 .37336 L
.09325 .37336 L
.09333 .37336 L
.09341 .37336 L
.09349 .37336 L
Mistroke
.09357 .3968 L
.09365 .3968 L
.09373 .35583 L
.09381 .35583 L
.09389 .35583 L
.09397 .35583 L
.09405 .35583 L
.09413 .39755 L
.09421 .39755 L
.09429 .40424 L
.09437 .43174 L
.09444 .43174 L
.09452 .43174 L
.0946 .43174 L
.09468 .43174 L
.09476 .43174 L
.09484 .43664 L
.09492 .42089 L
.095 .42089 L
.09508 .42089 L
.09516 .42089 L
.09524 .43686 L
.09532 .41682 L
.0954 .41682 L
.09548 .41682 L
.09556 .41682 L
.09563 .41682 L
.09571 .41682 L
.09579 .43297 L
.09587 .43297 L
.09595 .46591 L
.09603 .46591 L
.09611 .49405 L
.09619 .49405 L
.09627 .49405 L
.09635 .49405 L
.09643 .48845 L
.09651 .48845 L
.09659 .48845 L
.09667 .52417 L
.09675 .52417 L
.09683 .52952 L
.0969 .52952 L
.09698 .52528 L
.09706 .52528 L
.09714 .52528 L
.09722 .52528 L
.0973 .52528 L
.09738 .42333 L
.09746 .42333 L
Mistroke
.09754 .42333 L
.09762 .42333 L
.0977 .42333 L
.09778 .42333 L
.09786 .42333 L
.09794 .42333 L
.09802 .40311 L
.0981 .42108 L
.09817 .42108 L
.09825 .42108 L
.09833 .41254 L
.09841 .41254 L
.09849 .42364 L
.09857 .42364 L
.09865 .42364 L
.09873 .41427 L
.09881 .37553 L
.09889 .37553 L
.09897 .34625 L
.09905 .34625 L
.09913 .34625 L
.09921 .29184 L
.09929 .29184 L
.09937 .28566 L
.09944 .28566 L
.09952 .31059 L
.0996 .28724 L
.09968 .28724 L
.09976 .28724 L
.09984 .28724 L
.09992 .23309 L
.1 .23304 L
.10008 .23304 L
.10016 .21292 L
.10024 .21292 L
.10032 .21292 L
.1004 .21292 L
.10048 .21292 L
.10056 .21292 L
.10063 .21292 L
.10071 .21292 L
.10079 .21292 L
.10087 .21292 L
.10095 .21292 L
.10103 .21292 L
.10111 .21292 L
.10119 .21292 L
.10127 .21292 L
.10135 .21292 L
.10143 .21292 L
Mistroke
.10151 .21292 L
.10159 .21292 L
.10167 .21292 L
.10175 .21292 L
.10183 .21292 L
.1019 .21292 L
.10198 .21292 L
.10206 .21292 L
.10214 .21292 L
.10222 .21292 L
.1023 .21292 L
.10238 .21292 L
.10246 .21292 L
.10254 .21292 L
.10262 .25631 L
.1027 .25631 L
.10278 .2382 L
.10286 .2482 L
.10294 .2482 L
.10302 .2663 L
.1031 .2663 L
.10317 .27831 L
.10325 .27831 L
.10333 .26353 L
.10341 .26353 L
.10349 .34437 L
.10357 .34437 L
.10365 .34522 L
.10373 .34522 L
.10381 .34522 L
.10389 .34522 L
.10397 .34522 L
.10405 .34522 L
.10413 .34522 L
.10421 .34522 L
.10429 .37729 L
.10437 .37729 L
.10444 .37729 L
.10452 .37729 L
.1046 .37729 L
.10468 .37729 L
.10476 .37729 L
.10484 .37729 L
.10492 .37729 L
.105 .40459 L
.10508 .40459 L
.10516 .35876 L
.10524 .35876 L
.10532 .35876 L
.1054 .36447 L
Mistroke
.10548 .33094 L
.10556 .33094 L
.10563 .33094 L
.10571 .33094 L
.10579 .33094 L
.10587 .33094 L
.10595 .33094 L
.10603 .33094 L
.10611 .33094 L
.10619 .33094 L
.10627 .29234 L
.10635 .29234 L
.10643 .29234 L
.10651 .29234 L
.10659 .29234 L
.10667 .25801 L
.10675 .25801 L
.10683 .25801 L
.1069 .25801 L
.10698 .25801 L
.10706 .25801 L
.10714 .25801 L
.10722 .25801 L
.1073 .25801 L
.10738 .25801 L
.10746 .25801 L
.10754 .24793 L
.10762 .27045 L
.1077 .27138 L
.10778 .27138 L
.10786 .27138 L
.10794 .27138 L
.10802 .27138 L
.1081 .27138 L
.10817 .27138 L
.10825 .27138 L
.10833 .27138 L
.10841 .27138 L
.10849 .27138 L
.10857 .27138 L
.10865 .27138 L
.10873 .27138 L
.10881 .27138 L
.10889 .29577 L
.10897 .29577 L
.10905 .29577 L
.10913 .29577 L
.10921 .29577 L
.10929 .30837 L
.10937 .30837 L
Mistroke
.10944 .30837 L
.10952 .30837 L
.1096 .27571 L
.10968 .27571 L
.10976 .27571 L
.10984 .27571 L
.10992 .27571 L
.11 .27571 L
.11008 .27571 L
.11016 .27571 L
.11024 .27571 L
.11032 .32223 L
.1104 .26863 L
.11048 .26863 L
.11056 .32878 L
.11063 .32878 L
.11071 .32878 L
.11079 .36234 L
.11087 .36234 L
.11095 .36234 L
.11103 .33618 L
.11111 .33618 L
.11119 .33618 L
.11127 .33618 L
.11135 .33618 L
.11143 .41015 L
.11151 .41015 L
.11159 .41015 L
.11167 .40774 L
.11175 .40774 L
.11183 .40774 L
.1119 .40774 L
.11198 .38754 L
.11206 .43071 L
.11214 .44238 L
.11222 .44238 L
.1123 .37846 L
.11238 .37846 L
.11246 .37846 L
.11254 .37846 L
.11262 .37846 L
.1127 .37846 L
.11278 .34406 L
.11286 .29333 L
.11294 .31215 L
.11302 .31215 L
.1131 .31215 L
.11317 .31215 L
.11325 .31215 L
.11333 .31215 L
Mistroke
.11341 .31215 L
.11349 .31215 L
.11357 .31215 L
.11365 .31215 L
.11373 .25017 L
.11381 .25017 L
.11389 .25017 L
.11397 .25017 L
.11405 .25017 L
.11413 .23986 L
.11421 .23986 L
.11429 .24537 L
.11437 .2775 L
.11444 .27631 L
.11452 .27631 L
.1146 .27631 L
.11468 .27631 L
.11476 .27631 L
.11484 .27631 L
.11492 .27631 L
.115 .27631 L
.11508 .27631 L
.11516 .27631 L
.11524 .30954 L
.11532 .27154 L
.1154 .27154 L
.11548 .27154 L
.11556 .27154 L
.11563 .27154 L
.11571 .27154 L
.11579 .27154 L
.11587 .27154 L
.11595 .27154 L
.11603 .27154 L
.11611 .27154 L
.11619 .24667 L
.11627 .24667 L
.11635 .24667 L
.11643 .25431 L
.11651 .25289 L
.11659 .2565 L
.11667 .2565 L
.11675 .2565 L
.11683 .2565 L
.1169 .2565 L
.11698 .2565 L
.11706 .31749 L
.11714 .31741 L
.11722 .31741 L
.1173 .31741 L
Mistroke
.11738 .31741 L
.11746 .26391 L
.11754 .26391 L
.11762 .26391 L
.1177 .30267 L
.11778 .30267 L
.11786 .30267 L
.11794 .29401 L
.11802 .29401 L
.1181 .29401 L
.11817 .29401 L
.11825 .29401 L
.11833 .29401 L
.11841 .31374 L
.11849 .31374 L
.11857 .31374 L
.11865 .31374 L
.11873 .31374 L
.11881 .30495 L
.11889 .30495 L
.11897 .30495 L
.11905 .3049 L
.11913 .29624 L
.11921 .29624 L
.11929 .28459 L
.11937 .28459 L
.11944 .19602 L
.11952 .19602 L
.1196 .20681 L
.11968 .20681 L
.11976 .20681 L
.11984 .20681 L
.11992 .20681 L
.12 .20681 L
.12008 .20681 L
.12016 .18123 L
.12024 .18123 L
.12032 .18123 L
.1204 .15995 L
.12048 .15995 L
.12056 .15995 L
.12063 .15995 L
.12071 .15995 L
.12079 .15995 L
.12087 .15995 L
.12095 .16961 L
.12103 .16961 L
.12111 .16961 L
.12119 .16961 L
.12127 .16961 L
Mistroke
.12135 .16961 L
.12143 .16961 L
.12151 .16961 L
.12159 .16961 L
.12167 .16961 L
.12175 .16961 L
.12183 .16961 L
.1219 .16961 L
.12198 .1851 L
.12206 .1851 L
.12214 .1851 L
.12222 .1851 L
.1223 .1851 L
.12238 .1851 L
.12246 .1851 L
.12254 .1851 L
.12262 .20592 L
.1227 .20592 L
.12278 .20592 L
.12286 .20592 L
.12294 .20592 L
.12302 .20592 L
.1231 .21598 L
.12317 .24304 L
.12325 .24304 L
.12333 .27115 L
.12341 .27115 L
.12349 .27115 L
.12357 .21124 L
.12365 .21124 L
.12373 .21124 L
.12381 .21124 L
.12389 .21124 L
.12397 .21124 L
.12405 .21124 L
.12413 .20507 L
.12421 .20507 L
.12429 .20507 L
.12437 .20507 L
.12444 .20507 L
.12452 .21613 L
.1246 .21613 L
.12468 .21613 L
.12476 .26519 L
.12484 .26519 L
.12492 .26519 L
.125 .25257 L
.12508 .25257 L
.12516 .25257 L
.12524 .25257 L
Mistroke
.12532 .25257 L
.1254 .25257 L
.12548 .25257 L
.12556 .22049 L
.12563 .22049 L
.12571 .22049 L
.12579 .21767 L
.12587 .21767 L
.12595 .21767 L
.12603 .21767 L
.12611 .21767 L
.12619 .18385 L
.12627 .18696 L
.12635 .18696 L
.12643 .19693 L
.12651 .19693 L
.12659 .19841 L
.12667 .19841 L
.12675 .19841 L
.12683 .19841 L
.1269 .19841 L
.12698 .19914 L
.12706 .19914 L
.12714 .19914 L
.12722 .19914 L
.1273 .19914 L
.12738 .19566 L
.12746 .20029 L
.12754 .20029 L
.12762 .20029 L
.1277 .20029 L
.12778 .15884 L
.12786 .15884 L
.12794 .19046 L
.12802 .1815 L
.1281 .23315 L
.12817 .23315 L
.12825 .29538 L
.12833 .28949 L
.12841 .28949 L
.12849 .28949 L
.12857 .28949 L
.12865 .28949 L
.12873 .32882 L
.12881 .32882 L
.12889 .391 L
.12897 .3787 L
.12905 .34359 L
.12913 .34359 L
.12921 .31554 L
Mistroke
.12929 .31554 L
.12937 .31554 L
.12944 .31554 L
.12952 .31554 L
.1296 .31554 L
.12968 .31554 L
.12976 .31323 L
.12984 .31323 L
.12992 .30194 L
.13 .30194 L
.13008 .30194 L
.13016 .30194 L
.13024 .30194 L
.13032 .24821 L
.1304 .24821 L
.13048 .25283 L
.13056 .25283 L
.13063 .25283 L
.13071 .25283 L
.13079 .25283 L
.13087 .25283 L
.13095 .25283 L
.13103 .25283 L
.13111 .25283 L
.13119 .25283 L
.13127 .25283 L
.13135 .24739 L
.13143 .24739 L
.13151 .24739 L
.13159 .24739 L
.13167 .24739 L
.13175 .24739 L
.13183 .30666 L
.1319 .29426 L
.13198 .29426 L
.13206 .29426 L
.13214 .29426 L
.13222 .29426 L
.1323 .28986 L
.13238 .26965 L
.13246 .26965 L
.13254 .30185 L
.13262 .2682 L
.1327 .2682 L
.13278 .25613 L
.13286 .25613 L
.13294 .25613 L
.13302 .25613 L
.1331 .25188 L
.13317 .25188 L
Mistroke
.13325 .25188 L
.13333 .24982 L
.13341 .24982 L
.13349 .24982 L
.13357 .25318 L
.13365 .25318 L
.13373 .25318 L
.13381 .25318 L
.13389 .25318 L
.13397 .26647 L
.13405 .26647 L
.13413 .26647 L
.13421 .26647 L
.13429 .26647 L
.13437 .26482 L
.13444 .26092 L
.13452 .26092 L
.1346 .26092 L
.13468 .26092 L
.13476 .26092 L
.13484 .26092 L
.13492 .26092 L
.135 .26092 L
.13508 .26455 L
.13516 .26455 L
.13524 .25494 L
.13532 .25494 L
.1354 .25494 L
.13548 .25494 L
.13556 .25494 L
.13563 .25494 L
.13571 .25494 L
.13579 .25494 L
.13587 .25494 L
.13595 .25494 L
.13603 .30783 L
.13611 .30783 L
.13619 .30783 L
.13627 .30783 L
.13635 .34009 L
.13643 .36411 L
.13651 .36411 L
.13659 .35783 L
.13667 .35783 L
.13675 .35783 L
.13683 .35783 L
.1369 .34038 L
.13698 .35276 L
.13706 .36288 L
.13714 .41154 L
Mistroke
.13722 .40117 L
.1373 .40117 L
.13738 .40117 L
.13746 .40117 L
.13754 .40117 L
.13762 .40117 L
.1377 .40117 L
.13778 .40117 L
.13786 .40117 L
.13794 .38694 L
.13802 .38694 L
.1381 .38694 L
.13817 .38694 L
.13825 .38694 L
.13833 .35557 L
.13841 .36338 L
.13849 .36338 L
.13857 .36338 L
.13865 .31802 L
.13873 .31802 L
.13881 .32254 L
.13889 .32254 L
.13897 .32254 L
.13905 .32254 L
.13913 .31578 L
.13921 .31578 L
.13929 .31093 L
.13937 .31093 L
.13944 .31093 L
.13952 .3095 L
.1396 .29683 L
.13968 .29683 L
.13976 .29683 L
.13984 .29683 L
.13992 .29683 L
.14 .29683 L
.14008 .29683 L
.14016 .30886 L
.14024 .32112 L
.14032 .32112 L
.1404 .32112 L
.14048 .32112 L
.14056 .33365 L
.14063 .30218 L
.14071 .30218 L
.14079 .30218 L
.14087 .30218 L
.14095 .30218 L
.14103 .30218 L
.14111 .30218 L
Mistroke
.14119 .30943 L
.14127 .30943 L
.14135 .30943 L
.14143 .36165 L
.14151 .30792 L
.14159 .30549 L
.14167 .30549 L
.14175 .30549 L
.14183 .30549 L
.1419 .30549 L
.14198 .30549 L
.14206 .30549 L
.14214 .30549 L
.14222 .30549 L
.1423 .30398 L
.14238 .28072 L
.14246 .27307 L
.14254 .27307 L
.14262 .27307 L
.1427 .1828 L
.14278 .1828 L
.14286 .1828 L
.14294 .25815 L
.14302 .25815 L
.1431 .25815 L
.14317 .25815 L
.14325 .25815 L
.14333 .28386 L
.14341 .28386 L
.14349 .28386 L
.14357 .28386 L
.14365 .28386 L
.14373 .28386 L
.14381 .27632 L
.14389 .27632 L
.14397 .25048 L
.14405 .27363 L
.14413 .33609 L
.14421 .33609 L
.14429 .33609 L
.14437 .33609 L
.14444 .35953 L
.14452 .37796 L
.1446 .35015 L
.14468 .36535 L
.14476 .37754 L
.14484 .38757 L
.14492 .38757 L
.145 .38757 L
.14508 .38757 L
Mistroke
.14516 .38757 L
.14524 .32474 L
.14532 .32474 L
.1454 .32474 L
.14548 .32474 L
.14556 .29107 L
.14563 .29107 L
.14571 .29107 L
.14579 .31019 L
.14587 .31019 L
.14595 .31056 L
.14603 .28219 L
.14611 .28219 L
.14619 .27453 L
.14627 .26843 L
.14635 .26843 L
.14643 .26843 L
.14651 .24853 L
.14659 .21708 L
.14667 .21708 L
.14675 .22693 L
.14683 .22693 L
.1469 .22693 L
.14698 .22693 L
.14706 .25141 L
.14714 .18654 L
.14722 .18654 L
.1473 .18654 L
.14738 .18654 L
.14746 .18654 L
.14754 .18654 L
.14762 .18654 L
.1477 .18654 L
.14778 .18654 L
.14786 .18654 L
.14794 .22955 L
.14802 .22955 L
.1481 .22955 L
.14817 .22955 L
.14825 .22955 L
.14833 .20149 L
.14841 .18074 L
.14849 .15463 L
.14857 .15463 L
.14865 .15463 L
.14873 .16333 L
.14881 .16333 L
.14889 .16333 L
.14897 .20436 L
.14905 .21031 L
Mistroke
.14913 .21031 L
.14921 .25265 L
.14929 .25265 L
.14937 .25265 L
.14944 .25265 L
.14952 .29412 L
.1496 .31495 L
.14968 .30428 L
.14976 .17602 L
.14984 .17602 L
.14992 .19635 L
.15 .19635 L
.15008 .20585 L
.15016 .20585 L
.15024 .20585 L
.15032 .22886 L
.1504 .21784 L
.15048 .21784 L
.15056 .24441 L
.15063 .24441 L
.15071 .24441 L
.15079 .24441 L
.15087 .24441 L
.15095 .24441 L
.15103 .24441 L
.15111 .24441 L
.15119 .24441 L
.15127 .26148 L
.15135 .26148 L
.15143 .26148 L
.15151 .26148 L
.15159 .26148 L
.15167 .26148 L
.15175 .26148 L
.15183 .26148 L
.1519 .26148 L
.15198 .25911 L
.15206 .23572 L
.15214 .23286 L
.15222 .2267 L
.1523 .2267 L
.15238 .19692 L
.15246 .23246 L
.15254 .23246 L
.15262 .23246 L
.1527 .23246 L
.15278 .23246 L
.15286 .23246 L
.15294 .23246 L
.15302 .23246 L
Mistroke
.1531 .27209 L
.15317 .27209 L
.15325 .27209 L
.15333 .27209 L
.15341 .27209 L
.15349 .27853 L
.15357 .27853 L
.15365 .27181 L
.15373 .27181 L
.15381 .27181 L
.15389 .27181 L
.15397 .27181 L
.15405 .26873 L
.15413 .26873 L
.15421 .24712 L
.15429 .24712 L
.15437 .24712 L
.15444 .24712 L
.15452 .24712 L
.1546 .24712 L
.15468 .24712 L
.15476 .22191 L
.15484 .21251 L
.15492 .21251 L
.155 .21251 L
.15508 .21251 L
.15516 .19496 L
.15524 .19496 L
.15532 .19496 L
.1554 .19467 L
.15548 .19467 L
.15556 .18477 L
.15563 .18477 L
.15571 .18477 L
.15579 .18477 L
.15587 .18477 L
.15595 .18477 L
.15603 .19968 L
.15611 .19968 L
.15619 .19968 L
.15627 .19968 L
.15635 .19968 L
.15643 .19864 L
.15651 .19864 L
.15659 .19864 L
.15667 .19864 L
.15675 .19864 L
.15683 .19864 L
.1569 .19864 L
.15698 .19864 L
Mistroke
.15706 .19864 L
.15714 .19864 L
.15722 .19864 L
.1573 .21366 L
.15738 .21366 L
.15746 .21366 L
.15754 .21366 L
.15762 .21366 L
.1577 .21366 L
.15778 .21366 L
.15786 .21366 L
.15794 .21366 L
.15802 .21366 L
.1581 .21366 L
.15817 .21366 L
.15825 .21366 L
.15833 .21366 L
.15841 .21366 L
.15849 .21366 L
.15857 .21366 L
.15865 .21366 L
.15873 .21366 L
.15881 .21366 L
.15889 .21366 L
.15897 .21366 L
.15905 .24324 L
.15913 .34069 L
.15921 .34069 L
.15929 .34069 L
.15937 .34069 L
.15944 .34069 L
.15952 .34069 L
.1596 .40931 L
.15968 .40931 L
.15976 .40931 L
.15984 .40931 L
.15992 .40645 L
.16 .40645 L
.16008 .40645 L
.16016 .40645 L
.16024 .40645 L
.16032 .40645 L
.1604 .38248 L
.16048 .41937 L
.16056 .38517 L
.16063 .38517 L
.16071 .38517 L
.16079 .38517 L
.16087 .38517 L
.16095 .40961 L
Mistroke
.16103 .40961 L
.16111 .40961 L
.16119 .40424 L
.16127 .40424 L
.16135 .4348 L
.16143 .47243 L
.16151 .47243 L
.16159 .47243 L
.16167 .41302 L
.16175 .41302 L
.16183 .41302 L
.1619 .41302 L
.16198 .42433 L
.16206 .42433 L
.16214 .42433 L
.16222 .42433 L
.1623 .42433 L
.16238 .42433 L
.16246 .42433 L
.16254 .36475 L
.16262 .38076 L
.1627 .38076 L
.16278 .38151 L
.16286 .35029 L
.16294 .35029 L
.16302 .38336 L
.1631 .38336 L
.16317 .37388 L
.16325 .40469 L
.16333 .36661 L
.16341 .35112 L
.16349 .35112 L
.16357 .35112 L
.16365 .37636 L
.16373 .37636 L
.16381 .37636 L
.16389 .34018 L
.16397 .34018 L
.16405 .34018 L
.16413 .35379 L
.16421 .35379 L
.16429 .35379 L
.16437 .33461 L
.16444 .33461 L
.16452 .33461 L
.1646 .29464 L
.16468 .29464 L
.16476 .27123 L
.16484 .27249 L
.16492 .26178 L
Mistroke
.165 .26178 L
.16508 .26178 L
.16516 .26178 L
.16524 .26178 L
.16532 .26318 L
.1654 .26318 L
.16548 .26318 L
.16556 .24429 L
.16563 .24429 L
.16571 .24429 L
.16579 .24429 L
.16587 .24429 L
.16595 .24429 L
.16603 .24429 L
.16611 .24429 L
.16619 .24429 L
.16627 .26425 L
.16635 .26425 L
.16643 .24851 L
.16651 .24851 L
.16659 .24851 L
.16667 .24851 L
.16675 .24729 L
.16683 .26821 L
.1669 .27225 L
.16698 .27225 L
.16706 .22888 L
.16714 .22888 L
.16722 .2875 L
.1673 .27276 L
.16738 .27276 L
.16746 .25932 L
.16754 .25932 L
.16762 .25932 L
.1677 .25932 L
.16778 .2338 L
.16786 .2338 L
.16794 .2338 L
.16802 .2338 L
.1681 .2338 L
.16817 .2395 L
.16825 .2395 L
.16833 .2395 L
.16841 .2395 L
.16849 .2395 L
.16857 .30223 L
.16865 .30223 L
.16873 .30223 L
.16881 .26296 L
.16889 .26296 L
Mistroke
.16897 .26296 L
.16905 .26296 L
.16913 .26296 L
.16921 .26296 L
.16929 .26296 L
.16937 .26296 L
.16944 .26296 L
.16952 .26296 L
.1696 .26296 L
.16968 .26296 L
.16976 .32774 L
.16984 .31297 L
.16992 .26644 L
.17 .2733 L
.17008 .26896 L
.17016 .25656 L
.17024 .23336 L
.17032 .23336 L
.1704 .23336 L
.17048 .2539 L
.17056 .2539 L
.17063 .2539 L
.17071 .24722 L
.17079 .23651 L
.17087 .23651 L
.17095 .2495 L
.17103 .25096 L
.17111 .2366 L
.17119 .2366 L
.17127 .21883 L
.17135 .31587 L
.17143 .28061 L
.17151 .26983 L
.17159 .26983 L
.17167 .26983 L
.17175 .25026 L
.17183 .2443 L
.1719 .2443 L
.17198 .2443 L
.17206 .2443 L
.17214 .2443 L
.17222 .27402 L
.1723 .27739 L
.17238 .27739 L
.17246 .33232 L
.17254 .30945 L
.17262 .30945 L
.1727 .2501 L
.17278 .2501 L
.17286 .2501 L
Mistroke
.17294 .23809 L
.17302 .23809 L
.1731 .23809 L
.17317 .21408 L
.17325 .21408 L
.17333 .21408 L
.17341 .21408 L
.17349 .21408 L
.17357 .25686 L
.17365 .25686 L
.17373 .25686 L
.17381 .25678 L
.17389 .25678 L
.17397 .25678 L
.17405 .25678 L
.17413 .27937 L
.17421 .27937 L
.17429 .24136 L
.17437 .24544 L
.17444 .24544 L
.17452 .24544 L
.1746 .24544 L
.17468 .26632 L
.17476 .23608 L
.17484 .23608 L
.17492 .23608 L
.175 .23608 L
.17508 .23729 L
.17516 .23729 L
.17524 .24551 L
.17532 .28595 L
.1754 .28595 L
.17548 .28595 L
.17556 .28595 L
.17563 .28595 L
.17571 .28595 L
.17579 .28595 L
.17587 .28595 L
.17595 .28595 L
.17603 .28595 L
.17611 .24799 L
.17619 .24799 L
.17627 .20062 L
.17635 .20062 L
.17643 .20062 L
.17651 .20062 L
.17659 .20062 L
.17667 .20062 L
.17675 .20062 L
.17683 .23621 L
Mistroke
.1769 .23621 L
.17698 .23621 L
.17706 .23621 L
.17714 .23621 L
.17722 .23621 L
.1773 .23621 L
.17738 .23621 L
.17746 .23621 L
.17754 .23621 L
.17762 .23621 L
.1777 .23621 L
.17778 .23621 L
.17786 .23621 L
.17794 .19966 L
.17802 .19966 L
.1781 .19966 L
.17817 .19966 L
.17825 .19966 L
.17833 .19966 L
.17841 .19966 L
.17849 .19966 L
.17857 .19966 L
.17865 .19966 L
.17873 .19966 L
.17881 .19966 L
.17889 .19966 L
.17897 .19966 L
.17905 .19966 L
.17913 .21536 L
.17921 .21536 L
.17929 .17076 L
.17937 .17076 L
.17944 .17076 L
.17952 .17076 L
.1796 .17076 L
.17968 .17076 L
.17976 .17076 L
.17984 .17076 L
.17992 .17076 L
.18 .17076 L
.18008 .17076 L
.18016 .17076 L
.18024 .173 L
.18032 .173 L
.1804 .173 L
.18048 .17081 L
.18056 .14777 L
.18063 .1667 L
.18071 .1667 L
.18079 .1667 L
Mistroke
.18087 .1667 L
.18095 .1667 L
.18103 .1667 L
.18111 .16132 L
.18119 .16132 L
.18127 .16132 L
.18135 .16132 L
.18143 .16132 L
.18151 .16132 L
.18159 .23644 L
.18167 .23644 L
.18175 .23644 L
.18183 .23644 L
.1819 .23644 L
.18198 .23644 L
.18206 .23644 L
.18214 .23644 L
.18222 .23644 L
.1823 .26515 L
.18238 .26515 L
.18246 .26515 L
.18254 .2706 L
.18262 .2706 L
.1827 .26859 L
.18278 .23927 L
.18286 .23927 L
.18294 .23927 L
.18302 .27939 L
.1831 .27939 L
.18317 .30994 L
.18325 .30994 L
.18333 .30994 L
.18341 .28797 L
.18349 .28797 L
.18357 .28797 L
.18365 .28797 L
.18373 .31913 L
.18381 .31913 L
.18389 .31913 L
.18397 .31913 L
.18405 .31913 L
.18413 .31913 L
.18421 .31913 L
.18429 .31913 L
.18437 .31913 L
.18444 .29757 L
.18452 .31015 L
.1846 .31607 L
.18468 .31607 L
.18476 .31607 L
Mistroke
.18484 .29356 L
.18492 .29356 L
.185 .29739 L
.18508 .29739 L
.18516 .29739 L
.18524 .29739 L
.18532 .32012 L
.1854 .32012 L
.18548 .37773 L
.18556 .37773 L
.18563 .36723 L
.18571 .35687 L
.18579 .38217 L
.18587 .39906 L
.18595 .39906 L
.18603 .39906 L
.18611 .39906 L
.18619 .39906 L
.18627 .39906 L
.18635 .35442 L
.18643 .35442 L
.18651 .33571 L
.18659 .33571 L
.18667 .30528 L
.18675 .30528 L
.18683 .30528 L
.1869 .26756 L
.18698 .26756 L
.18706 .26756 L
.18714 .26756 L
.18722 .31106 L
.1873 .28571 L
.18738 .28571 L
.18746 .2745 L
.18754 .2745 L
.18762 .24524 L
.1877 .24943 L
.18778 .25032 L
.18786 .25032 L
.18794 .25032 L
.18802 .24227 L
.1881 .24227 L
.18817 .24227 L
.18825 .21572 L
.18833 .21575 L
.18841 .21575 L
.18849 .21575 L
.18857 .22364 L
.18865 .21031 L
.18873 .19453 L
Mistroke
.18881 .23167 L
.18889 .23167 L
.18897 .23167 L
.18905 .23167 L
.18913 .23167 L
.18921 .21421 L
.18929 .24787 L
.18937 .24787 L
.18944 .22816 L
.18952 .22349 L
.1896 .22309 L
.18968 .22309 L
.18976 .22711 L
.18984 .22711 L
.18992 .22711 L
.19 .22947 L
.19008 .22947 L
.19016 .22947 L
.19024 .22947 L
.19032 .22947 L
.1904 .32551 L
.19048 .27784 L
.19056 .27784 L
.19063 .27784 L
.19071 .25687 L
.19079 .25687 L
.19087 .25687 L
.19095 .25687 L
.19103 .25687 L
.19111 .31042 L
.19119 .22183 L
.19127 .22183 L
.19135 .22183 L
.19143 .22183 L
.19151 .22183 L
.19159 .20857 L
.19167 .20857 L
.19175 .20857 L
.19183 .19087 L
.1919 .18919 L
.19198 .18919 L
.19206 .18919 L
.19214 .18919 L
.19222 .20866 L
.1923 .20866 L
.19238 .21913 L
.19246 .21913 L
.19254 .21913 L
.19262 .22668 L
.1927 .21236 L
Mistroke
.19278 .19882 L
.19286 .24233 L
.19294 .24233 L
.19302 .27415 L
.1931 .29666 L
.19317 .29666 L
.19325 .29666 L
.19333 .28434 L
.19341 .28434 L
.19349 .2895 L
.19357 .2895 L
.19365 .31178 L
.19373 .29999 L
.19381 .29432 L
.19389 .29432 L
.19397 .31292 L
.19405 .31292 L
.19413 .31338 L
.19421 .29834 L
.19429 .30679 L
.19437 .30679 L
.19444 .30679 L
.19452 .28151 L
.1946 .2778 L
.19468 .2778 L
.19476 .2778 L
.19484 .2778 L
.19492 .2778 L
.195 .2778 L
.19508 .28134 L
.19516 .28134 L
.19524 .28134 L
.19532 .29207 L
.1954 .29207 L
.19548 .2913 L
.19556 .2913 L
.19563 .2913 L
.19571 .2913 L
.19579 .2913 L
.19587 .2913 L
.19595 .2735 L
.19603 .26761 L
.19611 .25873 L
.19619 .27529 L
.19627 .27529 L
.19635 .27529 L
.19643 .3268 L
.19651 .30708 L
.19659 .30708 L
.19667 .35299 L
Mistroke
.19675 .31529 L
.19683 .31529 L
.1969 .31916 L
.19698 .32085 L
.19706 .32085 L
.19714 .32527 L
.19722 .32527 L
.1973 .32527 L
.19738 .32527 L
.19746 .322 L
.19754 .3119 L
.19762 .3119 L
.1977 .34545 L
.19778 .34545 L
.19786 .34545 L
.19794 .32852 L
.19802 .32928 L
.1981 .32928 L
.19817 .32928 L
.19825 .34914 L
.19833 .36548 L
.19841 .36548 L
.19849 .35462 L
.19857 .35462 L
.19865 .39921 L
.19873 .38138 L
.19881 .3402 L
.19889 .33657 L
.19897 .32072 L
.19905 .32072 L
.19913 .31971 L
.19921 .32277 L
.19929 .32277 L
.19937 .32277 L
.19944 .32373 L
.19952 .28578 L
.1996 .2581 L
.19968 .3004 L
.19976 .36772 L
.19984 .36772 L
.19992 .36772 L
.2 .36772 L
.20008 .33157 L
.20016 .2691 L
.20024 .2691 L
.20032 .27599 L
.2004 .27599 L
.20048 .24107 L
.20056 .24689 L
.20063 .26373 L
Mistroke
.20071 .26373 L
.20079 .26373 L
.20087 .26373 L
.20095 .2831 L
.20103 .2831 L
.20111 .22671 L
.20119 .22339 L
.20127 .21565 L
.20135 .21565 L
.20143 .19782 L
.20151 .19782 L
.20159 .19782 L
.20167 .19841 L
.20175 .2046 L
.20183 .2046 L
.2019 .2046 L
.20198 .2046 L
.20206 .2046 L
.20214 .2046 L
.20222 .21428 L
.2023 .18942 L
.20238 .17549 L
.20246 .17168 L
.20254 .17168 L
.20262 .17733 L
.2027 .17733 L
.20278 .17733 L
.20286 .15541 L
.20294 .16013 L
.20302 .16856 L
.2031 .25098 L
.20317 .26868 L
.20325 .26868 L
.20333 .26868 L
.20341 .20734 L
.20349 .20734 L
.20357 .20734 L
.20365 .20734 L
.20373 .20734 L
.20381 .16508 L
.20389 .16093 L
.20397 .16093 L
.20405 .16944 L
.20413 .16944 L
.20421 .16705 L
.20429 .16705 L
.20437 .1823 L
.20444 .1823 L
.20452 .1823 L
.2046 .1823 L
Mistroke
.20468 .18956 L
.20476 .18956 L
.20484 .18203 L
.20492 .18203 L
.205 .18203 L
.20508 .18203 L
.20516 .18203 L
.20524 .18203 L
.20532 .18203 L
.2054 .21128 L
.20548 .21098 L
.20556 .21666 L
.20563 .18745 L
.20571 .23454 L
.20579 .2368 L
.20587 .21679 L
.20595 .21679 L
.20603 .21411 L
.20611 .20106 L
.20619 .19396 L
.20627 .17535 L
.20635 .21035 L
.20643 .20274 L
.20651 .16231 L
.20659 .16231 L
.20667 .16231 L
.20675 .20464 L
.20683 .20464 L
.2069 .18849 L
.20698 .18849 L
.20706 .18849 L
.20714 .18849 L
.20722 .22932 L
.2073 .22932 L
.20738 .17964 L
.20746 .17964 L
.20754 .17253 L
.20762 .17253 L
.2077 .17253 L
.20778 .18596 L
.20786 .17398 L
.20794 .16251 L
.20802 .16251 L
.2081 .1797 L
.20817 .18269 L
.20825 .23143 L
.20833 .19877 L
.20841 .19877 L
.20849 .19877 L
.20857 .23019 L
Mistroke
.20865 .23019 L
.20873 .23019 L
.20881 .20112 L
.20889 .1928 L
.20897 .1928 L
.20905 .20814 L
.20913 .20814 L
.20921 .19277 L
.20929 .1862 L
.20937 .1862 L
.20944 .1862 L
.20952 .18807 L
.2096 .21424 L
.20968 .2029 L
.20976 .2029 L
.20984 .17723 L
.20992 .17723 L
.21 .17574 L
.21008 .18894 L
.21016 .18894 L
.21024 .19492 L
.21032 .17613 L
.2104 .18886 L
.21048 .21315 L
.21056 .21315 L
.21063 .21315 L
.21071 .23478 L
.21079 .23478 L
.21087 .19549 L
.21095 .21221 L
.21103 .23282 L
.21111 .26213 L
.21119 .26984 L
.21127 .23137 L
.21135 .23137 L
.21143 .24294 L
.21151 .25961 L
.21159 .25961 L
.21167 .25961 L
.21175 .2581 L
.21183 .30153 L
.2119 .30153 L
.21198 .30153 L
.21206 .329 L
.21214 .33164 L
.21222 .33305 L
.2123 .28582 L
.21238 .28983 L
.21246 .23239 L
.21254 .22814 L
Mistroke
.21262 .21132 L
.2127 .21132 L
.21278 .21132 L
.21286 .26223 L
.21294 .26223 L
.21302 .25287 L
.2131 .27674 L
.21317 .3074 L
.21325 .3074 L
.21333 .29835 L
.21341 .26751 L
.21349 .26967 L
.21357 .26967 L
.21365 .26967 L
.21373 .23708 L
.21381 .23708 L
.21389 .23708 L
.21397 .23708 L
.21405 .22173 L
.21413 .21379 L
.21421 .23233 L
.21429 .23744 L
.21437 .22759 L
.21444 .27248 L
.21452 .27248 L
.2146 .25905 L
.21468 .25905 L
.21476 .25905 L
.21484 .26409 L
.21492 .25658 L
.215 .25658 L
.21508 .2505 L
.21516 .24931 L
.21524 .24931 L
.21532 .2261 L
.2154 .23122 L
.21548 .239 L
.21556 .239 L
.21563 .23807 L
.21571 .23807 L
.21579 .22134 L
.21587 .22134 L
.21595 .22026 L
.21603 .20702 L
.21611 .20702 L
.21619 .20582 L
.21627 .2278 L
.21635 .2013 L
.21643 .19521 L
.21651 .19521 L
Mistroke
.21659 .21235 L
.21667 .21235 L
.21675 .21235 L
.21683 .19075 L
.2169 .19075 L
.21698 .19075 L
.21706 .20577 L
.21714 .19241 L
.21722 .1908 L
.2173 .22724 L
.21738 .22724 L
.21746 .2253 L
.21754 .23252 L
.21762 .23252 L
.2177 .23252 L
.21778 .23252 L
.21786 .23252 L
.21794 .20597 L
.21802 .19454 L
.2181 .19454 L
.21817 .19454 L
.21825 .18187 L
.21833 .18187 L
.21841 .18187 L
.21849 .20466 L
.21857 .21119 L
.21865 .23392 L
.21873 .23392 L
.21881 .23392 L
.21889 .22232 L
.21897 .22668 L
.21905 .24037 L
.21913 .24037 L
.21921 .21602 L
.21929 .21602 L
.21937 .21602 L
.21944 .21602 L
.21952 .21602 L
.2196 .21602 L
.21968 .20442 L
.21976 .1686 L
.21984 .1686 L
.21992 .16753 L
.22 .16753 L
.22008 .16753 L
.22016 .16689 L
.22024 .17521 L
.22032 .18398 L
.2204 .18398 L
.22048 .21512 L
Mistroke
.22056 .21058 L
.22063 .21058 L
.22071 .19663 L
.22079 .23037 L
.22087 .23037 L
.22095 .23037 L
.22103 .21147 L
.22111 .22543 L
.22119 .22543 L
.22127 .22543 L
.22135 .22545 L
.22143 .2081 L
.22151 .21937 L
.22159 .21937 L
.22167 .21647 L
.22175 .21647 L
.22183 .21647 L
.2219 .21647 L
.22198 .21647 L
.22206 .21647 L
.22214 .21397 L
.22222 .19687 L
.2223 .17697 L
.22238 .18201 L
.22246 .21921 L
.22254 .21841 L
.22262 .21841 L
.2227 .22593 L
.22278 .22593 L
.22286 .22593 L
.22294 .23956 L
.22302 .22501 L
.2231 .22501 L
.22317 .24225 L
.22325 .2527 L
.22333 .2527 L
.22341 .2527 L
.22349 .2527 L
.22357 .2527 L
.22365 .26064 L
.22373 .24281 L
.22381 .24411 L
.22389 .24496 L
.22397 .24496 L
.22405 .23798 L
.22413 .24878 L
.22421 .24878 L
.22429 .24878 L
.22437 .24875 L
.22444 .24875 L
Mistroke
.22452 .24875 L
.2246 .24875 L
.22468 .24875 L
.22476 .21881 L
.22484 .22537 L
.22492 .22537 L
.225 .30811 L
.22508 .30811 L
.22516 .30811 L
.22524 .30811 L
.22532 .27181 L
.2254 .27181 L
.22548 .32119 L
.22556 .32119 L
.22563 .32119 L
.22571 .32119 L
.22579 .32119 L
.22587 .32119 L
.22595 .27399 L
.22603 .24899 L
.22611 .24899 L
.22619 .24899 L
.22627 .24899 L
.22635 .24899 L
.22643 .24899 L
.22651 .2556 L
.22659 .271 L
.22667 .271 L
.22675 .271 L
.22683 .271 L
.2269 .30859 L
.22698 .30859 L
.22706 .37721 L
.22714 .37721 L
.22722 .34012 L
.2273 .34012 L
.22738 .34012 L
.22746 .30967 L
.22754 .30967 L
.22762 .30967 L
.2277 .27769 L
.22778 .28816 L
.22786 .29389 L
.22794 .29389 L
.22802 .24977 L
.2281 .26388 L
.22817 .20712 L
.22825 .20712 L
.22833 .20712 L
.22841 .20431 L
Mistroke
.22849 .20431 L
.22857 .22157 L
.22865 .21155 L
.22873 .21155 L
.22881 .21155 L
.22889 .23376 L
.22897 .3009 L
.22905 .24698 L
.22913 .24698 L
.22921 .22097 L
.22929 .19195 L
.22937 .19195 L
.22944 .19195 L
.22952 .19195 L
.2296 .22855 L
.22968 .22855 L
.22976 .24608 L
.22984 .24608 L
.22992 .24608 L
.23 .24608 L
.23008 .24608 L
.23016 .23597 L
.23024 .23597 L
.23032 .23597 L
.2304 .23597 L
.23048 .2534 L
.23056 .2534 L
.23063 .2534 L
.23071 .27906 L
.23079 .27906 L
.23087 .27906 L
.23095 .29028 L
.23103 .29028 L
.23111 .29028 L
.23119 .25102 L
.23127 .25102 L
.23135 .25016 L
.23143 .25016 L
.23151 .25016 L
.23159 .25409 L
.23167 .25409 L
.23175 .25409 L
.23183 .25252 L
.2319 .25252 L
.23198 .25252 L
.23206 .25252 L
.23214 .25252 L
.23222 .23672 L
.2323 .23672 L
.23238 .24659 L
Mistroke
.23246 .24659 L
.23254 .25168 L
.23262 .2773 L
.2327 .29151 L
.23278 .29151 L
.23286 .29151 L
.23294 .29151 L
.23302 .28803 L
.2331 .28066 L
.23317 .28066 L
.23325 .28066 L
.23333 .28066 L
.23341 .28066 L
.23349 .28066 L
.23357 .28066 L
.23365 .28066 L
.23373 .28066 L
.23381 .28066 L
.23389 .24925 L
.23397 .24925 L
.23405 .23947 L
.23413 .23947 L
.23421 .23947 L
.23429 .23947 L
.23437 .23947 L
.23444 .23947 L
.23452 .23842 L
.2346 .2033 L
.23468 .2033 L
.23476 .2033 L
.23484 .26495 L
.23492 .2887 L
.235 .2887 L
.23508 .2887 L
.23516 .2887 L
.23524 .2887 L
.23532 .27402 L
.2354 .27402 L
.23548 .2511 L
.23556 .2511 L
.23563 .29052 L
.23571 .3095 L
.23579 .27878 L
.23587 .23295 L
.23595 .24835 L
.23603 .24703 L
.23611 .24703 L
.23619 .24703 L
.23627 .24703 L
.23635 .2616 L
Mistroke
.23643 .2616 L
.23651 .28214 L
.23659 .28214 L
.23667 .28214 L
.23675 .23686 L
.23683 .23686 L
.2369 .27304 L
.23698 .27304 L
.23706 .28284 L
.23714 .28284 L
.23722 .29485 L
.2373 .27157 L
.23738 .27655 L
.23746 .27777 L
.23754 .27777 L
.23762 .23078 L
.2377 .23078 L
.23778 .234 L
.23786 .234 L
.23794 .2245 L
.23802 .21919 L
.2381 .21919 L
.23817 .26721 L
.23825 .29815 L
.23833 .29815 L
.23841 .30907 L
.23849 .30907 L
.23857 .30907 L
.23865 .28726 L
.23873 .33056 L
.23881 .33056 L
.23889 .27241 L
.23897 .27241 L
.23905 .26218 L
.23913 .26218 L
.23921 .26218 L
.23929 .27219 L
.23937 .2873 L
.23944 .2873 L
.23952 .2873 L
.2396 .2873 L
.23968 .2873 L
.23976 .2873 L
.23984 .2085 L
.23992 .2085 L
.24 .21179 L
.24008 .22981 L
.24016 .22981 L
.24024 .21173 L
.24032 .21173 L
Mistroke
.2404 .19278 L
.24048 .19114 L
.24056 .18558 L
.24063 .18558 L
.24071 .18558 L
.24079 .18558 L
.24087 .18157 L
.24095 .18157 L
.24103 .14713 L
.24111 .18765 L
.24119 .18765 L
.24127 .18765 L
.24135 .19091 L
.24143 .21478 L
.24151 .21478 L
.24159 .21703 L
.24167 .21703 L
.24175 .17057 L
.24183 .17057 L
.2419 .16526 L
.24198 .21999 L
.24206 .19222 L
.24214 .20447 L
.24222 .20447 L
.2423 .20447 L
.24238 .20447 L
.24246 .20447 L
.24254 .19655 L
.24262 .21775 L
.2427 .25005 L
.24278 .25005 L
.24286 .24355 L
.24294 .26808 L
.24302 .26467 L
.2431 .28319 L
.24317 .28319 L
.24325 .26208 L
.24333 .28589 L
.24341 .28589 L
.24349 .28589 L
.24357 .28589 L
.24365 .28589 L
.24373 .28589 L
.24381 .25461 L
.24389 .25461 L
.24397 .21681 L
.24405 .22156 L
.24413 .22156 L
.24421 .22156 L
.24429 .22156 L
Mistroke
.24437 .22156 L
.24444 .18896 L
.24452 .18896 L
.2446 .18167 L
.24468 .18167 L
.24476 .20264 L
.24484 .20264 L
.24492 .20264 L
.245 .18863 L
.24508 .19474 L
.24516 .19474 L
.24524 .19474 L
.24532 .27112 L
.2454 .27112 L
.24548 .27112 L
.24556 .27112 L
.24563 .28773 L
.24571 .28773 L
.24579 .28773 L
.24587 .28773 L
.24595 .22073 L
.24603 .19371 L
.24611 .19371 L
.24619 .19371 L
.24627 .19371 L
.24635 .1971 L
.24643 .22319 L
.24651 .22319 L
.24659 .22319 L
.24667 .2009 L
.24675 .24728 L
.24683 .24728 L
.2469 .24728 L
.24698 .23409 L
.24706 .23602 L
.24714 .25774 L
.24722 .25099 L
.2473 .25099 L
.24738 .25099 L
.24746 .23996 L
.24754 .21597 L
.24762 .21597 L
.2477 .21597 L
.24778 .21663 L
.24786 .21663 L
.24794 .21663 L
.24802 .24307 L
.2481 .20205 L
.24817 .17754 L
.24825 .17754 L
Mistroke
.24833 .17754 L
.24841 .20534 L
.24849 .18813 L
.24857 .17074 L
.24865 .22695 L
.24873 .24161 L
.24881 .24522 L
.24889 .24522 L
.24897 .24522 L
.24905 .23972 L
.24913 .25152 L
.24921 .25152 L
.24929 .24263 L
.24937 .16544 L
.24944 .16544 L
.24952 .22383 L
.2496 .22383 L
.24968 .24621 L
.24976 .24621 L
.24984 .23964 L
.24992 .23802 L
.25 .23802 L
.25008 .23802 L
.25016 .27532 L
.25024 .26967 L
.25032 .26116 L
.2504 .26116 L
.25048 .25925 L
.25056 .23993 L
.25063 .23993 L
.25071 .23993 L
.25079 .23993 L
.25087 .25704 L
.25095 .25704 L
.25103 .25704 L
.25111 .2283 L
.25119 .27054 L
.25127 .29225 L
.25135 .33607 L
.25143 .35761 L
.25151 .33071 L
.25159 .22676 L
.25167 .23279 L
.25175 .23279 L
.25183 .23279 L
.2519 .23279 L
.25198 .24622 L
.25206 .24622 L
.25214 .24622 L
.25222 .28879 L
Mistroke
.2523 .29235 L
.25238 .34447 L
.25246 .34447 L
.25254 .35991 L
.25262 .32551 L
.2527 .32551 L
.25278 .32551 L
.25286 .34235 L
.25294 .34235 L
.25302 .34235 L
.2531 .34235 L
.25317 .34235 L
.25325 .34235 L
.25333 .34235 L
.25341 .34235 L
.25349 .34235 L
.25357 .31827 L
.25365 .31584 L
.25373 .31584 L
.25381 .34484 L
.25389 .34484 L
.25397 .34484 L
.25405 .35232 L
.25413 .32843 L
.25421 .32843 L
.25429 .32843 L
.25437 .32843 L
.25444 .32843 L
.25452 .32843 L
.2546 .32843 L
.25468 .32843 L
.25476 .32843 L
.25484 .31729 L
.25492 .31729 L
.255 .31729 L
.25508 .30433 L
.25516 .30433 L
.25524 .36045 L
.25532 .36045 L
.2554 .36045 L
.25548 .36045 L
.25556 .33894 L
.25563 .342 L
.25571 .28008 L
.25579 .26702 L
.25587 .2787 L
.25595 .2849 L
.25603 .28844 L
.25611 .3197 L
.25619 .3197 L
Mistroke
.25627 .3197 L
.25635 .31073 L
.25643 .31073 L
.25651 .30081 L
.25659 .30081 L
.25667 .31873 L
.25675 .31873 L
.25683 .30832 L
.2569 .24797 L
.25698 .25198 L
.25706 .25198 L
.25714 .27345 L
.25722 .27345 L
.2573 .31826 L
.25738 .31826 L
.25746 .31826 L
.25754 .31826 L
.25762 .31826 L
.2577 .33728 L
.25778 .30901 L
.25786 .30737 L
.25794 .30264 L
.25802 .30264 L
.2581 .30264 L
.25817 .30264 L
.25825 .30264 L
.25833 .26997 L
.25841 .25605 L
.25849 .25605 L
.25857 .27666 L
.25865 .2443 L
.25873 .2443 L
.25881 .2443 L
.25889 .2443 L
.25897 .29589 L
.25905 .31027 L
.25913 .31027 L
.25921 .27707 L
.25929 .27844 L
.25937 .27983 L
.25944 .27983 L
.25952 .2746 L
.2596 .29664 L
.25968 .29227 L
.25976 .29227 L
.25984 .29803 L
.25992 .29803 L
.26 .29803 L
.26008 .31139 L
.26016 .31012 L
Mistroke
.26024 .35125 L
.26032 .33861 L
.2604 .36843 L
.26048 .37981 L
.26056 .37981 L
.26063 .35645 L
.26071 .35645 L
.26079 .35645 L
.26087 .35645 L
.26095 .30562 L
.26103 .32601 L
.26111 .32784 L
.26119 .32784 L
.26127 .2824 L
.26135 .2824 L
.26143 .2824 L
.26151 .31839 L
.26159 .2984 L
.26167 .2984 L
.26175 .2984 L
.26183 .2705 L
.2619 .2705 L
.26198 .25665 L
.26206 .23855 L
.26214 .21855 L
.26222 .21855 L
.2623 .21855 L
.26238 .21855 L
.26246 .21907 L
.26254 .2141 L
.26262 .21184 L
.2627 .18862 L
.26278 .20812 L
.26286 .20812 L
.26294 .22775 L
.26302 .22775 L
.2631 .23122 L
.26317 .23122 L
.26325 .23122 L
.26333 .23122 L
.26341 .23122 L
.26349 .24321 L
.26357 .24321 L
.26365 .24321 L
.26373 .20322 L
.26381 .20322 L
.26389 .20322 L
.26397 .18097 L
.26405 .19346 L
.26413 .19346 L
Mistroke
.26421 .19346 L
.26429 .19346 L
.26437 .19346 L
.26444 .20297 L
.26452 .17589 L
.2646 .17589 L
.26468 .18336 L
.26476 .17267 L
.26484 .167 L
.26492 .167 L
.265 .167 L
.26508 .18934 L
.26516 .18934 L
.26524 .20635 L
.26532 .20635 L
.2654 .20635 L
.26548 .20635 L
.26556 .20635 L
.26563 .20635 L
.26571 .1741 L
.26579 .16057 L
.26587 .16057 L
.26595 .16057 L
.26603 .16057 L
.26611 .17925 L
.26619 .18085 L
.26627 .18085 L
.26635 .18085 L
.26643 .18085 L
.26651 .18085 L
.26659 .19038 L
.26667 .19038 L
.26675 .19038 L
.26683 .22044 L
.2669 .24321 L
.26698 .24321 L
.26706 .24321 L
.26714 .24321 L
.26722 .23752 L
.2673 .23752 L
.26738 .23882 L
.26746 .23882 L
.26754 .23882 L
.26762 .20457 L
.2677 .20457 L
.26778 .20644 L
.26786 .20644 L
.26794 .20644 L
.26802 .2185 L
.2681 .21612 L
Mistroke
.26817 .22923 L
.26825 .22923 L
.26833 .22923 L
.26841 .22923 L
.26849 .21995 L
.26857 .21656 L
.26865 .268 L
.26873 .268 L
.26881 .26711 L
.26889 .26711 L
.26897 .32777 L
.26905 .32777 L
.26913 .29998 L
.26921 .29998 L
.26929 .29998 L
.26937 .36896 L
.26944 .35993 L
.26952 .35993 L
.2696 .35993 L
.26968 .35993 L
.26976 .35993 L
.26984 .35993 L
.26992 .37449 L
.27 .37659 L
.27008 .35143 L
.27016 .35163 L
.27024 .35368 L
.27032 .33683 L
.2704 .31129 L
.27048 .31129 L
.27056 .2682 L
.27063 .2682 L
.27071 .2682 L
.27079 .2682 L
.27087 .2682 L
.27095 .28439 L
.27103 .28439 L
.27111 .28439 L
.27119 .28439 L
.27127 .31339 L
.27135 .31339 L
.27143 .2602 L
.27151 .2602 L
.27159 .2602 L
.27167 .26459 L
.27175 .28145 L
.27183 .295 L
.2719 .29292 L
.27198 .29292 L
.27206 .29558 L
Mistroke
.27214 .29558 L
.27222 .28703 L
.2723 .25857 L
.27238 .25857 L
.27246 .25857 L
.27254 .23686 L
.27262 .23843 L
.2727 .20689 L
.27278 .20689 L
.27286 .20689 L
.27294 .20689 L
.27302 .20689 L
.2731 .20689 L
.27317 .1936 L
.27325 .19284 L
.27333 .1564 L
.27341 .1564 L
.27349 .1564 L
.27357 .16361 L
.27365 .16361 L
.27373 .16361 L
.27381 .16361 L
.27389 .16361 L
.27397 .16361 L
.27405 .16361 L
.27413 .16853 L
.27421 .16853 L
.27429 .16853 L
.27437 .18988 L
.27444 .18988 L
.27452 .20771 L
.2746 .18053 L
.27468 .18053 L
.27476 .18053 L
.27484 .18053 L
.27492 .18053 L
.275 .16405 L
.27508 .16405 L
.27516 .16405 L
.27524 .16782 L
.27532 .16782 L
.2754 .21265 L
.27548 .2169 L
.27556 .2169 L
.27563 .2169 L
.27571 .21764 L
.27579 .21764 L
.27587 .23592 L
.27595 .23592 L
.27603 .23592 L
Mistroke
.27611 .23592 L
.27619 .28013 L
.27627 .28013 L
.27635 .28013 L
.27643 .25147 L
.27651 .1931 L
.27659 .19316 L
.27667 .19316 L
.27675 .19316 L
.27683 .16497 L
.2769 .16048 L
.27698 .16048 L
.27706 .17485 L
.27714 .22764 L
.27722 .24528 L
.2773 .2114 L
.27738 .23027 L
.27746 .23027 L
.27754 .23027 L
.27762 .25557 L
.2777 .25557 L
.27778 .25557 L
.27786 .25557 L
.27794 .25253 L
.27802 .25187 L
.2781 .25199 L
.27817 .25985 L
.27825 .24975 L
.27833 .24975 L
.27841 .24975 L
.27849 .24975 L
.27857 .23773 L
.27865 .23773 L
.27873 .23773 L
.27881 .23773 L
.27889 .23773 L
.27897 .23773 L
.27905 .22809 L
.27913 .22809 L
.27921 .22809 L
.27929 .21959 L
.27937 .21959 L
.27944 .19332 L
.27952 .22499 L
.2796 .22499 L
.27968 .20622 L
.27976 .19455 L
.27984 .19811 L
.27992 .19811 L
.28 .19811 L
Mistroke
.28008 .19811 L
.28016 .19811 L
.28024 .21892 L
.28032 .26557 L
.2804 .26284 L
.28048 .26284 L
.28056 .26284 L
.28063 .26284 L
.28071 .26284 L
.28079 .26284 L
.28087 .23292 L
.28095 .24752 L
.28103 .22522 L
.28111 .22522 L
.28119 .23681 L
.28127 .23998 L
.28135 .23998 L
.28143 .24687 L
.28151 .24687 L
.28159 .24687 L
.28167 .24603 L
.28175 .23035 L
.28183 .23035 L
.2819 .23399 L
.28198 .24103 L
.28206 .24778 L
.28214 .23968 L
.28222 .23968 L
.2823 .23968 L
.28238 .23968 L
.28246 .25638 L
.28254 .21863 L
.28262 .21863 L
.2827 .26923 L
.28278 .28582 L
.28286 .28582 L
.28294 .26494 L
.28302 .27877 L
.2831 .27877 L
.28317 .27701 L
.28325 .27701 L
.28333 .31444 L
.28341 .31444 L
.28349 .31444 L
.28357 .31309 L
.28365 .31059 L
.28373 .33496 L
.28381 .33496 L
.28389 .37922 L
.28397 .36173 L
Mistroke
.28405 .36173 L
.28413 .344 L
.28421 .344 L
.28429 .32528 L
.28437 .31463 L
.28444 .31463 L
.28452 .31463 L
.2846 .34105 L
.28468 .34105 L
.28476 .34105 L
.28484 .33315 L
.28492 .33315 L
.285 .33915 L
.28508 .35859 L
.28516 .40323 L
.28524 .40323 L
.28532 .41181 L
.2854 .41181 L
.28548 .42818 L
.28556 .42818 L
.28563 .42818 L
.28571 .42818 L
.28579 .44655 L
.28587 .39647 L
.28595 .40391 L
.28603 .3925 L
.28611 .37832 L
.28619 .36291 L
.28627 .36291 L
.28635 .36291 L
.28643 .36235 L
.28651 .36235 L
.28659 .37478 L
.28667 .37478 L
.28675 .37478 L
.28683 .3751 L
.2869 .35485 L
.28698 .37193 L
.28706 .37193 L
.28714 .35555 L
.28722 .36237 L
.2873 .35429 L
.28738 .34506 L
.28746 .34729 L
.28754 .34729 L
.28762 .38094 L
.2877 .40483 L
.28778 .40483 L
.28786 .4355 L
.28794 .47631 L
Mistroke
.28802 .47631 L
.2881 .48545 L
.28817 .48545 L
.28825 .4566 L
.28833 .4566 L
.28841 .4566 L
.28849 .40676 L
.28857 .40676 L
.28865 .40676 L
.28873 .38562 L
.28881 .3787 L
.28889 .3787 L
.28897 .3787 L
.28905 .3787 L
.28913 .3787 L
.28921 .40539 L
.28929 .35824 L
.28937 .35824 L
.28944 .35824 L
.28952 .3295 L
.2896 .3295 L
.28968 .29781 L
.28976 .29781 L
.28984 .30361 L
.28992 .30361 L
.29 .30361 L
.29008 .30361 L
.29016 .34989 L
.29024 .31422 L
.29032 .31422 L
.2904 .36546 L
.29048 .36546 L
.29056 .36546 L
.29063 .34465 L
.29071 .33836 L
.29079 .31448 L
.29087 .31448 L
.29095 .30338 L
.29103 .30338 L
.29111 .31419 L
.29119 .31419 L
.29127 .30866 L
.29135 .30866 L
.29143 .30894 L
.29151 .30894 L
.29159 .31202 L
.29167 .31202 L
.29175 .29266 L
.29183 .27272 L
.2919 .27272 L
Mistroke
.29198 .27272 L
.29206 .24245 L
.29214 .24233 L
.29222 .24233 L
.2923 .24233 L
.29238 .24233 L
.29246 .24233 L
.29254 .24233 L
.29262 .24233 L
.2927 .26715 L
.29278 .26715 L
.29286 .26715 L
.29294 .26715 L
.29302 .26715 L
.2931 .29945 L
.29317 .29945 L
.29325 .32006 L
.29333 .27219 L
.29341 .27195 L
.29349 .22732 L
.29357 .24913 L
.29365 .22806 L
.29373 .22806 L
.29381 .2134 L
.29389 .2134 L
.29397 .19158 L
.29405 .18803 L
.29413 .18803 L
.29421 .21693 L
.29429 .25923 L
.29437 .28493 L
.29444 .24919 L
.29452 .24919 L
.2946 .24919 L
.29468 .2369 L
.29476 .2369 L
.29484 .2369 L
.29492 .2369 L
.295 .17551 L
.29508 .17551 L
.29516 .1703 L
.29524 .16074 L
.29532 .16074 L
.2954 .16074 L
.29548 .17342 L
.29556 .23507 L
.29563 .23507 L
.29571 .23507 L
.29579 .23507 L
.29587 .30178 L
Mistroke
.29595 .30178 L
.29603 .30178 L
.29611 .30178 L
.29619 .30178 L
.29627 .30178 L
.29635 .30178 L
.29643 .30178 L
.29651 .25621 L
.29659 .25621 L
.29667 .25621 L
.29675 .25621 L
.29683 .24832 L
.2969 .30858 L
.29698 .30858 L
.29706 .30858 L
.29714 .28111 L
.29722 .27406 L
.2973 .23389 L
.29738 .23389 L
.29746 .23389 L
.29754 .21681 L
.29762 .21681 L
.2977 .21455 L
.29778 .21455 L
.29786 .21455 L
.29794 .21455 L
.29802 .21455 L
.2981 .21455 L
.29817 .19041 L
.29825 .18947 L
.29833 .18947 L
.29841 .18947 L
.29849 .18371 L
.29857 .1594 L
.29865 .1594 L
.29873 .16044 L
.29881 .16044 L
.29889 .16044 L
.29897 .22181 L
.29905 .22181 L
.29913 .18123 L
.29921 .18123 L
.29929 .18123 L
.29937 .18123 L
.29944 .21957 L
.29952 .21957 L
.2996 .21957 L
.29968 .21957 L
.29976 .21957 L
.29984 .2184 L
Mistroke
.29992 .27879 L
.3 .27879 L
.30008 .27879 L
.30016 .30954 L
.30024 .32973 L
.30032 .32973 L
.3004 .31815 L
.30048 .35936 L
.30056 .28764 L
.30063 .27797 L
.30071 .27763 L
.30079 .25676 L
.30087 .2765 L
.30095 .2879 L
.30103 .2879 L
.30111 .2879 L
.30119 .22998 L
.30127 .22998 L
.30135 .226 L
.30143 .18192 L
.30151 .18192 L
.30159 .19012 L
.30167 .19012 L
.30175 .2085 L
.30183 .17817 L
.3019 .17817 L
.30198 .18837 L
.30206 .18837 L
.30214 .17135 L
.30222 .17135 L
.3023 .17135 L
.30238 .17135 L
.30246 .12811 L
.30254 .1296 L
.30262 .1296 L
.3027 .15501 L
.30278 .15501 L
.30286 .15501 L
.30294 .15501 L
.30302 .15501 L
.3031 .15501 L
.30317 .15501 L
.30325 .15318 L
.30333 .17734 L
.30341 .17206 L
.30349 .17206 L
.30357 .17795 L
.30365 .17795 L
.30373 .17795 L
.30381 .18115 L
Mistroke
.30389 .18115 L
.30397 .20366 L
.30405 .20368 L
.30413 .23091 L
.30421 .23091 L
.30429 .18953 L
.30437 .18953 L
.30444 .21412 L
.30452 .20085 L
.3046 .20789 L
.30468 .2524 L
.30476 .2524 L
.30484 .2524 L
.30492 .26049 L
.305 .26049 L
.30508 .25569 L
.30516 .22773 L
.30524 .22773 L
.30532 .22773 L
.3054 .22886 L
.30548 .22886 L
.30556 .22886 L
.30563 .26104 L
.30571 .26021 L
.30579 .26917 L
.30587 .26917 L
.30595 .26917 L
.30603 .26917 L
.30611 .26917 L
.30619 .26917 L
.30627 .26917 L
.30635 .25175 L
.30643 .25175 L
.30651 .20831 L
.30659 .20831 L
.30667 .20831 L
.30675 .19238 L
.30683 .19238 L
.3069 .19812 L
.30698 .20657 L
.30706 .20657 L
.30714 .18154 L
.30722 .18154 L
.3073 .19042 L
.30738 .20787 L
.30746 .20787 L
.30754 .20787 L
.30762 .20787 L
.3077 .20787 L
.30778 .20787 L
Mistroke
.30786 .20787 L
.30794 .21286 L
.30802 .21286 L
.3081 .21286 L
.30817 .21286 L
.30825 .18831 L
.30833 .18831 L
.30841 .18831 L
.30849 .20289 L
.30857 .20072 L
.30865 .2079 L
.30873 .2079 L
.30881 .2079 L
.30889 .2079 L
.30897 .2079 L
.30905 .2252 L
.30913 .2252 L
.30921 .2252 L
.30929 .23575 L
.30937 .23575 L
.30944 .2257 L
.30952 .23643 L
.3096 .23643 L
.30968 .23643 L
.30976 .23643 L
.30984 .23643 L
.30992 .27395 L
.31 .27395 L
.31008 .26887 L
.31016 .28312 L
.31024 .28312 L
.31032 .28312 L
.3104 .28312 L
.31048 .25521 L
.31056 .25521 L
.31063 .25521 L
.31071 .25521 L
.31079 .25521 L
.31087 .25521 L
.31095 .25521 L
.31103 .25864 L
.31111 .25864 L
.31119 .25858 L
.31127 .25858 L
.31135 .26961 L
.31143 .26179 L
.31151 .27942 L
.31159 .27942 L
.31167 .27942 L
.31175 .27942 L
Mistroke
.31183 .27942 L
.3119 .28918 L
.31198 .28666 L
.31206 .28666 L
.31214 .28666 L
.31222 .2902 L
.3123 .2902 L
.31238 .29194 L
.31246 .33004 L
.31254 .33004 L
.31262 .31356 L
.3127 .31695 L
.31278 .31695 L
.31286 .33093 L
.31294 .3207 L
.31302 .28734 L
.3131 .2966 L
.31317 .30868 L
.31325 .30868 L
.31333 .27124 L
.31341 .27124 L
.31349 .26885 L
.31357 .2622 L
.31365 .29191 L
.31373 .29191 L
.31381 .27466 L
.31389 .27113 L
.31397 .29272 L
.31405 .27729 L
.31413 .28375 L
.31421 .27491 L
.31429 .27491 L
.31437 .27491 L
.31444 .27491 L
.31452 .27491 L
.3146 .27491 L
.31468 .27615 L
.31476 .27615 L
.31484 .27615 L
.31492 .27615 L
.315 .27615 L
.31508 .27615 L
.31516 .25182 L
.31524 .23914 L
.31532 .24606 L
.3154 .228 L
.31548 .228 L
.31556 .23523 L
.31563 .23795 L
.31571 .24191 L
Mistroke
.31579 .24191 L
.31587 .24713 L
.31595 .24713 L
.31603 .24713 L
.31611 .24713 L
.31619 .23083 L
.31627 .23083 L
.31635 .25261 L
.31643 .26122 L
.31651 .26122 L
.31659 .29241 L
.31667 .29241 L
.31675 .23925 L
.31683 .23925 L
.3169 .23856 L
.31698 .23856 L
.31706 .23856 L
.31714 .24936 L
.31722 .24417 L
.3173 .24417 L
.31738 .24417 L
.31746 .24417 L
.31754 .24417 L
.31762 .25739 L
.3177 .28967 L
.31778 .28967 L
.31786 .28698 L
.31794 .29727 L
.31802 .29727 L
.3181 .27477 L
.31817 .27477 L
.31825 .27477 L
.31833 .27477 L
.31841 .27717 L
.31849 .27717 L
.31857 .27717 L
.31865 .27717 L
.31873 .27108 L
.31881 .27108 L
.31889 .27108 L
.31897 .27108 L
.31905 .27108 L
.31913 .27108 L
.31921 .24179 L
.31929 .24179 L
.31937 .24179 L
.31944 .24179 L
.31952 .24179 L
.3196 .25569 L
.31968 .22517 L
Mistroke
.31976 .23087 L
.31984 .23087 L
.31992 .23087 L
.32 .23087 L
.32008 .23087 L
.32016 .23087 L
.32024 .23087 L
.32032 .22951 L
.3204 .24809 L
.32048 .24809 L
.32056 .24809 L
.32063 .24809 L
.32071 .24809 L
.32079 .25588 L
.32087 .24247 L
.32095 .24923 L
.32103 .25345 L
.32111 .25345 L
.32119 .20386 L
.32127 .20386 L
.32135 .23806 L
.32143 .2016 L
.32151 .19448 L
.32159 .19448 L
.32167 .1813 L
.32175 .1813 L
.32183 .1813 L
.3219 .1813 L
.32198 .24432 L
.32206 .19755 L
.32214 .17609 L
.32222 .19096 L
.3223 .19096 L
.32238 .19096 L
.32246 .18305 L
.32254 .20776 L
.32262 .20776 L
.3227 .20776 L
.32278 .20776 L
.32286 .18162 L
.32294 .21014 L
.32302 .21014 L
.3231 .21014 L
.32317 .21014 L
.32325 .21014 L
.32333 .21014 L
.32341 .21395 L
.32349 .21395 L
.32357 .21395 L
.32365 .19266 L
Mistroke
.32373 .19266 L
.32381 .19266 L
.32389 .19303 L
.32397 .19303 L
.32405 .17991 L
.32413 .17991 L
.32421 .18137 L
.32429 .22252 L
.32437 .29119 L
.32444 .29119 L
.32452 .29119 L
.3246 .26167 L
.32468 .24991 L
.32476 .24991 L
.32484 .24991 L
.32492 .24991 L
.325 .29533 L
.32508 .29533 L
.32516 .29533 L
.32524 .34764 L
.32532 .34764 L
.3254 .34764 L
.32548 .34764 L
.32556 .34764 L
.32563 .34764 L
.32571 .36004 L
.32579 .36004 L
.32587 .36004 L
.32595 .30956 L
.32603 .30956 L
.32611 .30956 L
.32619 .30956 L
.32627 .30936 L
.32635 .31266 L
.32643 .31266 L
.32651 .26663 L
.32659 .25796 L
.32667 .25796 L
.32675 .25796 L
.32683 .26209 L
.3269 .24914 L
.32698 .24914 L
.32706 .24914 L
.32714 .24914 L
.32722 .23955 L
.3273 .23955 L
.32738 .29056 L
.32746 .26269 L
.32754 .26077 L
.32762 .23929 L
Mistroke
.3277 .23929 L
.32778 .31016 L
.32786 .30371 L
.32794 .30371 L
.32802 .32421 L
.3281 .32421 L
.32817 .32421 L
.32825 .32421 L
.32833 .33362 L
.32841 .30664 L
.32849 .30664 L
.32857 .30664 L
.32865 .30664 L
.32873 .32218 L
.32881 .30174 L
.32889 .30174 L
.32897 .30174 L
.32905 .30174 L
.32913 .30174 L
.32921 .30174 L
.32929 .30174 L
.32937 .30174 L
.32944 .30383 L
.32952 .30666 L
.3296 .31151 L
.32968 .3344 L
.32976 .3344 L
.32984 .3344 L
.32992 .29525 L
.33 .30113 L
.33008 .30113 L
.33016 .30113 L
.33024 .33003 L
.33032 .37844 L
.3304 .35368 L
.33048 .36692 L
.33056 .36692 L
.33063 .34396 L
.33071 .34396 L
.33079 .32304 L
.33087 .32128 L
.33095 .3059 L
.33103 .3059 L
.33111 .30389 L
.33119 .30499 L
.33127 .30499 L
.33135 .30499 L
.33143 .30499 L
.33151 .3781 L
.33159 .29869 L
Mistroke
.33167 .29869 L
.33175 .27428 L
.33183 .30916 L
.3319 .31956 L
.33198 .31956 L
.33206 .31956 L
.33214 .31956 L
.33222 .31956 L
.3323 .31006 L
.33238 .31006 L
.33246 .33429 L
.33254 .33981 L
.33262 .28206 L
.3327 .28206 L
.33278 .28206 L
.33286 .28554 L
.33294 .28979 L
.33302 .28979 L
.3331 .28979 L
.33317 .27844 L
.33325 .27844 L
.33333 .27844 L
.33341 .27844 L
.33349 .27844 L
.33357 .24905 L
.33365 .24905 L
.33373 .27322 L
.33381 .29033 L
.33389 .29033 L
.33397 .29731 L
.33405 .33124 L
.33413 .33124 L
.33421 .33124 L
.33429 .33124 L
.33437 .3472 L
.33444 .40991 L
.33452 .40991 L
.3346 .40991 L
.33468 .35672 L
.33476 .36891 L
.33484 .36891 L
.33492 .36891 L
.335 .36541 L
.33508 .3754 L
.33516 .3754 L
.33524 .3754 L
.33532 .3788 L
.3354 .44444 L
.33548 .44444 L
.33556 .46277 L
Mistroke
.33563 .46277 L
.33571 .46277 L
.33579 .46277 L
.33587 .453 L
.33595 .47945 L
.33603 .47945 L
.33611 .47945 L
.33619 .47945 L
.33627 .36739 L
.33635 .31531 L
.33643 .31531 L
.33651 .30915 L
.33659 .29063 L
.33667 .29063 L
.33675 .29063 L
.33683 .29063 L
.3369 .29063 L
.33698 .29063 L
.33706 .29063 L
.33714 .29063 L
.33722 .29063 L
.3373 .29063 L
.33738 .3085 L
.33746 .3085 L
.33754 .3085 L
.33762 .3085 L
.3377 .3028 L
.33778 .28749 L
.33786 .29253 L
.33794 .27559 L
.33802 .28215 L
.3381 .30526 L
.33817 .30526 L
.33825 .27466 L
.33833 .27466 L
.33841 .27619 L
.33849 .27619 L
.33857 .31448 L
.33865 .31448 L
.33873 .31448 L
.33881 .31206 L
.33889 .31206 L
.33897 .31206 L
.33905 .31206 L
.33913 .27113 L
.33921 .37328 L
.33929 .34993 L
.33937 .34993 L
.33944 .3068 L
.33952 .3068 L
Mistroke
.3396 .3068 L
.33968 .28773 L
.33976 .28469 L
.33984 .28469 L
.33992 .28469 L
.34 .28893 L
.34008 .27262 L
.34016 .27262 L
.34024 .27262 L
.34032 .25413 L
.3404 .25413 L
.34048 .27319 L
.34056 .25959 L
.34063 .24088 L
.34071 .24088 L
.34079 .24088 L
.34087 .24088 L
.34095 .23005 L
.34103 .23005 L
.34111 .2236 L
.34119 .2236 L
.34127 .2236 L
.34135 .2236 L
.34143 .20239 L
.34151 .18363 L
.34159 .18363 L
.34167 .18363 L
.34175 .18849 L
.34183 .18849 L
.3419 .21061 L
.34198 .21061 L
.34206 .18571 L
.34214 .17525 L
.34222 .17525 L
.3423 .17837 L
.34238 .18574 L
.34246 .15363 L
.34254 .15363 L
.34262 .15363 L
.3427 .15363 L
.34278 .17488 L
.34286 .14866 L
.34294 .14866 L
.34302 .14595 L
.3431 .14595 L
.34317 .14595 L
.34325 .16378 L
.34333 .16378 L
.34341 .16378 L
.34349 .16166 L
Mistroke
.34357 .17346 L
.34365 .17346 L
.34373 .16722 L
.34381 .14689 L
.34389 .19786 L
.34397 .15427 L
.34405 .15427 L
.34413 .15427 L
.34421 .15427 L
.34429 .17662 L
.34437 .17662 L
.34444 .17325 L
.34452 .17325 L
.3446 .17325 L
.34468 .16896 L
.34476 .16896 L
.34484 .16896 L
.34492 .15957 L
.345 .16578 L
.34508 .19344 L
.34516 .19344 L
.34524 .19344 L
.34532 .18567 L
.3454 .1872 L
.34548 .1872 L
.34556 .1872 L
.34563 .17532 L
.34571 .18507 L
.34579 .14057 L
.34587 .15533 L
.34595 .15533 L
.34603 .15533 L
.34611 .15533 L
.34619 .17682 L
.34627 .17682 L
.34635 .19052 L
.34643 .19053 L
.34651 .18815 L
.34659 .18815 L
.34667 .18815 L
.34675 .18815 L
.34683 .18026 L
.3469 .19268 L
.34698 .19268 L
.34706 .16337 L
.34714 .19566 L
.34722 .19566 L
.3473 .18743 L
.34738 .19808 L
.34746 .20294 L
Mistroke
.34754 .22602 L
.34762 .22602 L
.3477 .22862 L
.34778 .22862 L
.34786 .25263 L
.34794 .27709 L
.34802 .27709 L
.3481 .27709 L
.34817 .27604 L
.34825 .26033 L
.34833 .26033 L
.34841 .26033 L
.34849 .26033 L
.34857 .28031 L
.34865 .28031 L
.34873 .28031 L
.34881 .28031 L
.34889 .27705 L
.34897 .27705 L
.34905 .30185 L
.34913 .27526 L
.34921 .27526 L
.34929 .28625 L
.34937 .28584 L
.34944 .28584 L
.34952 .22303 L
.3496 .22303 L
.34968 .22303 L
.34976 .22303 L
.34984 .26081 L
.34992 .27142 L
.35 .27142 L
.35008 .28464 L
.35016 .28464 L
.35024 .29027 L
.35032 .29027 L
.3504 .30476 L
.35048 .28291 L
.35056 .28291 L
.35063 .28291 L
.35071 .28291 L
.35079 .28291 L
.35087 .34587 L
.35095 .34152 L
.35103 .34152 L
.35111 .34152 L
.35119 .30555 L
.35127 .29107 L
.35135 .29107 L
.35143 .3131 L
Mistroke
.35151 .31035 L
.35159 .31035 L
.35167 .31035 L
.35175 .25447 L
.35183 .25447 L
.3519 .25447 L
.35198 .25447 L
.35206 .31725 L
.35214 .31725 L
.35222 .31725 L
.3523 .31725 L
.35238 .26821 L
.35246 .29172 L
.35254 .33094 L
.35262 .33094 L
.3527 .3858 L
.35278 .35185 L
.35286 .35185 L
.35294 .35185 L
.35302 .35185 L
.3531 .35185 L
.35317 .3237 L
.35325 .3237 L
.35333 .3237 L
.35341 .3237 L
.35349 .3373 L
.35357 .3373 L
.35365 .3373 L
.35373 .3373 L
.35381 .3373 L
.35389 .3373 L
.35397 .34174 L
.35405 .34174 L
.35413 .34174 L
.35421 .31421 L
.35429 .27019 L
.35437 .27019 L
.35444 .27019 L
.35452 .27019 L
.3546 .27019 L
.35468 .27019 L
.35476 .27554 L
.35484 .26719 L
.35492 .26719 L
.355 .26719 L
.35508 .26719 L
.35516 .26719 L
.35524 .26719 L
.35532 .26719 L
.3554 .26719 L
Mistroke
.35548 .2539 L
.35556 .25048 L
.35563 .27945 L
.35571 .31291 L
.35579 .33257 L
.35587 .33257 L
.35595 .39353 L
.35603 .44388 L
.35611 .44388 L
.35619 .44388 L
.35627 .44388 L
.35635 .39044 L
.35643 .35987 L
.35651 .33579 L
.35659 .32953 L
.35667 .30069 L
.35675 .30069 L
.35683 .24883 L
.3569 .24883 L
.35698 .25226 L
.35706 .26225 L
.35714 .22812 L
.35722 .26438 L
.3573 .24529 L
.35738 .24529 L
.35746 .22645 L
.35754 .22645 L
.35762 .21412 L
.3577 .21412 L
.35778 .21979 L
.35786 .21979 L
.35794 .25788 L
.35802 .25788 L
.3581 .25788 L
.35817 .28246 L
.35825 .28246 L
.35833 .28246 L
.35841 .28246 L
.35849 .28246 L
.35857 .25627 L
.35865 .25627 L
.35873 .33121 L
.35881 .33121 L
.35889 .35708 L
.35897 .35708 L
.35905 .35708 L
.35913 .3427 L
.35921 .31634 L
.35929 .31634 L
.35937 .35072 L
Mistroke
.35944 .35072 L
.35952 .35072 L
.3596 .33579 L
.35968 .35196 L
.35976 .34044 L
.35984 .31855 L
.35992 .31855 L
.36 .25902 L
.36008 .25902 L
.36016 .25902 L
.36024 .23171 L
.36032 .23171 L
.3604 .23171 L
.36048 .23171 L
.36056 .23171 L
.36063 .23171 L
.36071 .23171 L
.36079 .23171 L
.36087 .23171 L
.36095 .23758 L
.36103 .23758 L
.36111 .23758 L
.36119 .26136 L
.36127 .26136 L
.36135 .25922 L
.36143 .25922 L
.36151 .25922 L
.36159 .25922 L
.36167 .25922 L
.36175 .25922 L
.36183 .24503 L
.3619 .2587 L
.36198 .27762 L
.36206 .28008 L
.36214 .27014 L
.36222 .26566 L
.3623 .26566 L
.36238 .26566 L
.36246 .26566 L
.36254 .21647 L
.36262 .18929 L
.3627 .24587 L
.36278 .24587 L
.36286 .25227 L
.36294 .25227 L
.36302 .25227 L
.3631 .25227 L
.36317 .25227 L
.36325 .2191 L
.36333 .2191 L
Mistroke
.36341 .21915 L
.36349 .21915 L
.36357 .21915 L
.36365 .20616 L
.36373 .18574 L
.36381 .17382 L
.36389 .17382 L
.36397 .19901 L
.36405 .19901 L
.36413 .18629 L
.36421 .18629 L
.36429 .20185 L
.36437 .20185 L
.36444 .20185 L
.36452 .22247 L
.3646 .21082 L
.36468 .17427 L
.36476 .17427 L
.36484 .21436 L
.36492 .21436 L
.365 .21436 L
.36508 .21436 L
.36516 .2027 L
.36524 .2027 L
.36532 .2027 L
.3654 .21188 L
.36548 .21188 L
.36556 .21188 L
.36563 .21188 L
.36571 .2345 L
.36579 .2099 L
.36587 .23781 L
.36595 .23781 L
.36603 .21124 L
.36611 .21124 L
.36619 .19562 L
.36627 .19562 L
.36635 .19562 L
.36643 .19562 L
.36651 .19562 L
.36659 .20652 L
.36667 .22915 L
.36675 .32625 L
.36683 .2435 L
.3669 .22495 L
.36698 .22727 L
.36706 .22727 L
.36714 .22727 L
.36722 .22727 L
.3673 .26782 L
Mistroke
.36738 .26782 L
.36746 .26782 L
.36754 .26782 L
.36762 .26782 L
.3677 .26782 L
.36778 .32114 L
.36786 .28075 L
.36794 .28075 L
.36802 .24008 L
.3681 .21562 L
.36817 .21125 L
.36825 .20315 L
.36833 .20315 L
.36841 .20315 L
.36849 .17958 L
.36857 .15485 L
.36865 .15485 L
.36873 .15485 L
.36881 .15485 L
.36889 .15485 L
.36897 .15485 L
.36905 .15485 L
.36913 .15485 L
.36921 .15485 L
.36929 .15485 L
.36937 .15485 L
.36944 .15485 L
.36952 .15901 L
.3696 .17051 L
.36968 .17051 L
.36976 .21921 L
.36984 .20254 L
.36992 .24026 L
.37 .23255 L
.37008 .23522 L
.37016 .23522 L
.37024 .23665 L
.37032 .22019 L
.3704 .22019 L
.37048 .2152 L
.37056 .23251 L
.37063 .23251 L
.37071 .22492 L
.37079 .22492 L
.37087 .22492 L
.37095 .26899 L
.37103 .26899 L
.37111 .2442 L
.37119 .2442 L
.37127 .2442 L
Mistroke
.37135 .2442 L
.37143 .22867 L
.37151 .22954 L
.37159 .23013 L
.37167 .20628 L
.37175 .20628 L
.37183 .20628 L
.3719 .1984 L
.37198 .1984 L
.37206 .1984 L
.37214 .2116 L
.37222 .212 L
.3723 .212 L
.37238 .27512 L
.37246 .24661 L
.37254 .25076 L
.37262 .2533 L
.3727 .23121 L
.37278 .23061 L
.37286 .23061 L
.37294 .25983 L
.37302 .26684 L
.3731 .26684 L
.37317 .26684 L
.37325 .26684 L
.37333 .23658 L
.37341 .23658 L
.37349 .21524 L
.37357 .25488 L
.37365 .25691 L
.37373 .28864 L
.37381 .25036 L
.37389 .24852 L
.37397 .24852 L
.37405 .2534 L
.37413 .26043 L
.37421 .26043 L
.37429 .26043 L
.37437 .26043 L
.37444 .26043 L
.37452 .25802 L
.3746 .25802 L
.37468 .26534 L
.37476 .27068 L
.37484 .28386 L
.37492 .26379 L
.375 .26379 L
.37508 .23477 L
.37516 .23477 L
.37524 .23477 L
Mistroke
.37532 .26415 L
.3754 .24341 L
.37548 .22183 L
.37556 .23327 L
.37563 .25971 L
.37571 .25971 L
.37579 .24004 L
.37587 .25044 L
.37595 .2559 L
.37603 .2559 L
.37611 .21453 L
.37619 .21453 L
.37627 .21453 L
.37635 .23156 L
.37643 .26841 L
.37651 .26841 L
.37659 .26841 L
.37667 .29039 L
.37675 .29039 L
.37683 .21929 L
.3769 .24594 L
.37698 .27336 L
.37706 .32732 L
.37714 .32732 L
.37722 .32732 L
.3773 .32911 L
.37738 .32911 L
.37746 .32911 L
.37754 .32911 L
.37762 .3679 L
.3777 .35608 L
.37778 .35608 L
.37786 .394 L
.37794 .394 L
.37802 .394 L
.3781 .394 L
.37817 .394 L
.37825 .35662 L
.37833 .35662 L
.37841 .3399 L
.37849 .34455 L
.37857 .34455 L
.37865 .34455 L
.37873 .35601 L
.37881 .3594 L
.37889 .28204 L
.37897 .27871 L
.37905 .27871 L
.37913 .28513 L
.37921 .31292 L
Mistroke
.37929 .27502 L
.37937 .27502 L
.37944 .24157 L
.37952 .23652 L
.3796 .2215 L
.37968 .2215 L
.37976 .2215 L
.37984 .2215 L
.37992 .2018 L
.38 .19525 L
.38008 .20513 L
.38016 .20513 L
.38024 .24605 L
.38032 .24605 L
.3804 .24605 L
.38048 .23869 L
.38056 .25415 L
.38063 .25415 L
.38071 .25415 L
.38079 .27176 L
.38087 .27176 L
.38095 .27176 L
.38103 .27176 L
.38111 .24296 L
.38119 .24296 L
.38127 .29276 L
.38135 .2831 L
.38143 .32889 L
.38151 .33651 L
.38159 .33651 L
.38167 .29103 L
.38175 .29103 L
.38183 .29103 L
.3819 .24344 L
.38198 .24344 L
.38206 .24344 L
.38214 .24344 L
.38222 .24344 L
.3823 .24344 L
.38238 .24469 L
.38246 .25209 L
.38254 .25209 L
.38262 .26085 L
.3827 .25662 L
.38278 .25783 L
.38286 .24027 L
.38294 .24027 L
.38302 .24027 L
.3831 .24553 L
.38317 .28642 L
Mistroke
.38325 .28642 L
.38333 .28642 L
.38341 .28642 L
.38349 .28642 L
.38357 .28863 L
.38365 .28863 L
.38373 .27164 L
.38381 .30727 L
.38389 .30727 L
.38397 .30727 L
.38405 .30727 L
.38413 .32916 L
.38421 .32916 L
.38429 .33113 L
.38437 .3545 L
.38444 .29072 L
.38452 .29072 L
.3846 .24396 L
.38468 .24396 L
.38476 .24059 L
.38484 .23487 L
.38492 .2344 L
.385 .2344 L
.38508 .24985 L
.38516 .28055 L
.38524 .30357 L
.38532 .30357 L
.3854 .30357 L
.38548 .26418 L
.38556 .26418 L
.38563 .26418 L
.38571 .26418 L
.38579 .26418 L
.38587 .28214 L
.38595 .2909 L
.38603 .2909 L
.38611 .2909 L
.38619 .28285 L
.38627 .27429 L
.38635 .25528 L
.38643 .25528 L
.38651 .25528 L
.38659 .30495 L
.38667 .30495 L
.38675 .27723 L
.38683 .27723 L
.3869 .27723 L
.38698 .27723 L
.38706 .27723 L
.38714 .24928 L
Mistroke
.38722 .24928 L
.3873 .27559 L
.38738 .27559 L
.38746 .26329 L
.38754 .2358 L
.38762 .2358 L
.3877 .268 L
.38778 .268 L
.38786 .27345 L
.38794 .24013 L
.38802 .25307 L
.3881 .25307 L
.38817 .26466 L
.38825 .28433 L
.38833 .28433 L
.38841 .28433 L
.38849 .27187 L
.38857 .27187 L
.38865 .27215 L
.38873 .26788 L
.38881 .2428 L
.38889 .2428 L
.38897 .26082 L
.38905 .25267 L
.38913 .25267 L
.38921 .29775 L
.38929 .29775 L
.38937 .29775 L
.38944 .29775 L
.38952 .29775 L
.3896 .29775 L
.38968 .29775 L
.38976 .2461 L
.38984 .26563 L
.38992 .26563 L
.39 .26563 L
.39008 .27137 L
.39016 .26118 L
.39024 .26118 L
.39032 .26118 L
.3904 .26118 L
.39048 .31107 L
.39056 .31107 L
.39063 .31861 L
.39071 .3125 L
.39079 .3125 L
.39087 .31052 L
.39095 .31052 L
.39103 .31052 L
.39111 .33356 L
Mistroke
.39119 .33652 L
.39127 .33652 L
.39135 .31045 L
.39143 .31045 L
.39151 .31045 L
.39159 .31045 L
.39167 .31045 L
.39175 .31045 L
.39183 .33138 L
.3919 .33138 L
.39198 .33138 L
.39206 .33155 L
.39214 .33155 L
.39222 .3186 L
.3923 .31997 L
.39238 .31597 L
.39246 .29729 L
.39254 .30451 L
.39262 .30451 L
.3927 .30451 L
.39278 .30451 L
.39286 .27886 L
.39294 .27886 L
.39302 .26702 L
.3931 .23037 L
.39317 .23037 L
.39325 .24534 L
.39333 .24534 L
.39341 .25389 L
.39349 .27979 L
.39357 .22528 L
.39365 .2553 L
.39373 .23157 L
.39381 .23157 L
.39389 .20548 L
.39397 .20548 L
.39405 .20548 L
.39413 .20764 L
.39421 .20764 L
.39429 .20764 L
.39437 .20764 L
.39444 .23515 L
.39452 .23515 L
.3946 .23515 L
.39468 .23515 L
.39476 .23515 L
.39484 .24613 L
.39492 .24613 L
.395 .24613 L
.39508 .24613 L
Mistroke
.39516 .24297 L
.39524 .21403 L
.39532 .21403 L
.3954 .21403 L
.39548 .21403 L
.39556 .23681 L
.39563 .23681 L
.39571 .23064 L
.39579 .23687 L
.39587 .23687 L
.39595 .22257 L
.39603 .22257 L
.39611 .22257 L
.39619 .22599 L
.39627 .22599 L
.39635 .21242 L
.39643 .21242 L
.39651 .21242 L
.39659 .23804 L
.39667 .23804 L
.39675 .23804 L
.39683 .23804 L
.3969 .23773 L
.39698 .19796 L
.39706 .21038 L
.39714 .21038 L
.39722 .18356 L
.3973 .19532 L
.39738 .19532 L
.39746 .19532 L
.39754 .22546 L
.39762 .23355 L
.3977 .20193 L
.39778 .19092 L
.39786 .21258 L
.39794 .21258 L
.39802 .27889 L
.3981 .29909 L
.39817 .29623 L
.39825 .3201 L
.39833 .3201 L
.39841 .36459 L
.39849 .36459 L
.39857 .36459 L
.39865 .3343 L
.39873 .3343 L
.39881 .3343 L
.39889 .3343 L
.39897 .32312 L
.39905 .32312 L
Mistroke
.39913 .32312 L
.39921 .32312 L
.39929 .32312 L
.39937 .32312 L
.39944 .40599 L
.39952 .40599 L
.3996 .40599 L
.39968 .41319 L
.39976 .41206 L
.39984 .41206 L
.39992 .41206 L
.4 .41206 L
.40008 .36025 L
.40016 .35142 L
.40024 .3555 L
.40032 .36318 L
.4004 .36318 L
.40048 .36318 L
.40056 .37363 L
.40063 .37363 L
.40071 .37363 L
.40079 .37363 L
.40087 .37303 L
.40095 .34668 L
.40103 .34668 L
.40111 .34668 L
.40119 .3037 L
.40127 .3037 L
.40135 .3037 L
.40143 .26944 L
.40151 .2763 L
.40159 .2763 L
.40167 .2763 L
.40175 .27018 L
.40183 .27018 L
.4019 .32863 L
.40198 .32863 L
.40206 .29967 L
.40214 .29967 L
.40222 .29967 L
.4023 .29967 L
.40238 .29967 L
.40246 .31404 L
.40254 .30618 L
.40262 .30618 L
.4027 .30618 L
.40278 .31547 L
.40286 .31547 L
.40294 .31547 L
.40302 .28426 L
Mistroke
.4031 .28426 L
.40317 .27895 L
.40325 .27895 L
.40333 .27895 L
.40341 .25406 L
.40349 .21738 L
.40357 .21738 L
.40365 .21738 L
.40373 .21738 L
.40381 .21738 L
.40389 .20078 L
.40397 .20078 L
.40405 .20078 L
.40413 .20612 L
.40421 .20612 L
.40429 .23179 L
.40437 .23179 L
.40444 .23179 L
.40452 .23371 L
.4046 .23375 L
.40468 .23375 L
.40476 .23375 L
.40484 .23375 L
.40492 .2854 L
.405 .2854 L
.40508 .2854 L
.40516 .2854 L
.40524 .2854 L
.40532 .25124 L
.4054 .23607 L
.40548 .25583 L
.40556 .25583 L
.40563 .25583 L
.40571 .25583 L
.40579 .221 L
.40587 .25585 L
.40595 .23307 L
.40603 .23307 L
.40611 .23307 L
.40619 .24157 L
.40627 .19186 L
.40635 .19186 L
.40643 .1962 L
.40651 .18815 L
.40659 .18815 L
.40667 .18815 L
.40675 .18815 L
.40683 .18815 L
.4069 .19593 L
.40698 .19593 L
Mistroke
.40706 .23552 L
.40714 .2635 L
.40722 .30669 L
.4073 .28225 L
.40738 .23505 L
.40746 .23505 L
.40754 .26222 L
.40762 .26222 L
.4077 .26222 L
.40778 .26222 L
.40786 .26222 L
.40794 .26222 L
.40802 .26222 L
.4081 .26222 L
.40817 .28092 L
.40825 .28092 L
.40833 .28092 L
.40841 .23849 L
.40849 .22403 L
.40857 .22403 L
.40865 .22403 L
.40873 .2346 L
.40881 .2346 L
.40889 .2346 L
.40897 .2346 L
.40905 .2346 L
.40913 .2346 L
.40921 .22485 L
.40929 .26015 L
.40937 .26015 L
.40944 .24688 L
.40952 .20694 L
.4096 .24935 L
.40968 .24935 L
.40976 .20542 L
.40984 .20542 L
.40992 .20542 L
.41 .18826 L
.41008 .18281 L
.41016 .18281 L
.41024 .18281 L
.41032 .18281 L
.4104 .18281 L
.41048 .18281 L
.41056 .18281 L
.41063 .15112 L
.41071 .14284 L
.41079 .15983 L
.41087 .1587 L
.41095 .17676 L
Mistroke
.41103 .17676 L
.41111 .17676 L
.41119 .15899 L
.41127 .15899 L
.41135 .15899 L
.41143 .15793 L
.41151 .15793 L
.41159 .15793 L
.41167 .15793 L
.41175 .15793 L
.41183 .19751 L
.4119 .19751 L
.41198 .20874 L
.41206 .20874 L
.41214 .20874 L
.41222 .21301 L
.4123 .21301 L
.41238 .19262 L
.41246 .19262 L
.41254 .20396 L
.41262 .21074 L
.4127 .20662 L
.41278 .20662 L
.41286 .23689 L
.41294 .25363 L
.41302 .25363 L
.4131 .22332 L
.41317 .21588 L
.41325 .22525 L
.41333 .22525 L
.41341 .24915 L
.41349 .24915 L
.41357 .26395 L
.41365 .26395 L
.41373 .2509 L
.41381 .22628 L
.41389 .21509 L
.41397 .21509 L
.41405 .21509 L
.41413 .21509 L
.41421 .21509 L
.41429 .21509 L
.41437 .20041 L
.41444 .20041 L
.41452 .20041 L
.4146 .20041 L
.41468 .20041 L
.41476 .20041 L
.41484 .20041 L
.41492 .188 L
Mistroke
.415 .18305 L
.41508 .18305 L
.41516 .19936 L
.41524 .20184 L
.41532 .24103 L
.4154 .23566 L
.41548 .23566 L
.41556 .23566 L
.41563 .25269 L
.41571 .25269 L
.41579 .25269 L
.41587 .25456 L
.41595 .24739 L
.41603 .22495 L
.41611 .22495 L
.41619 .26695 L
.41627 .20207 L
.41635 .20207 L
.41643 .20207 L
.41651 .20207 L
.41659 .19659 L
.41667 .19659 L
.41675 .19659 L
.41683 .222 L
.4169 .222 L
.41698 .21348 L
.41706 .19958 L
.41714 .18795 L
.41722 .18795 L
.4173 .18795 L
.41738 .18795 L
.41746 .22207 L
.41754 .22207 L
.41762 .21914 L
.4177 .21914 L
.41778 .21914 L
.41786 .21914 L
.41794 .24395 L
.41802 .26925 L
.4181 .30371 L
.41817 .30371 L
.41825 .30371 L
.41833 .30371 L
.41841 .2655 L
.41849 .2655 L
.41857 .30596 L
.41865 .30452 L
.41873 .30452 L
.41881 .30452 L
.41889 .30452 L
Mistroke
.41897 .29333 L
.41905 .29333 L
.41913 .2284 L
.41921 .2105 L
.41929 .2105 L
.41937 .2105 L
.41944 .21507 L
.41952 .21507 L
.4196 .21507 L
.41968 .21507 L
.41976 .21507 L
.41984 .23705 L
.41992 .23427 L
.42 .23427 L
.42008 .22454 L
.42016 .22454 L
.42024 .30387 L
.42032 .24844 L
.4204 .20933 L
.42048 .20933 L
.42056 .22471 L
.42063 .22471 L
.42071 .22027 L
.42079 .22027 L
.42087 .22027 L
.42095 .22027 L
.42103 .22872 L
.42111 .22872 L
.42119 .19843 L
.42127 .19843 L
.42135 .19843 L
.42143 .218 L
.42151 .218 L
.42159 .20414 L
.42167 .20414 L
.42175 .20414 L
.42183 .20414 L
.4219 .20414 L
.42198 .20414 L
.42206 .20414 L
.42214 .29158 L
.42222 .29158 L
.4223 .29158 L
.42238 .29158 L
.42246 .34815 L
.42254 .31255 L
.42262 .31255 L
.4227 .32084 L
.42278 .32084 L
.42286 .32084 L
Mistroke
.42294 .32084 L
.42302 .37097 L
.4231 .37097 L
.42317 .37097 L
.42325 .37097 L
.42333 .37097 L
.42341 .37097 L
.42349 .37097 L
.42357 .37097 L
.42365 .37097 L
.42373 .34732 L
.42381 .34732 L
.42389 .34732 L
.42397 .34732 L
.42405 .24178 L
.42413 .24036 L
.42421 .24036 L
.42429 .24036 L
.42437 .30327 L
.42444 .30327 L
.42452 .27986 L
.4246 .27986 L
.42468 .27986 L
.42476 .27986 L
.42484 .22771 L
.42492 .27419 L
.425 .19993 L
.42508 .19993 L
.42516 .19993 L
.42524 .19993 L
.42532 .19993 L
.4254 .18679 L
.42548 .20766 L
.42556 .20923 L
.42563 .20923 L
.42571 .20923 L
.42579 .18864 L
.42587 .18864 L
.42595 .18864 L
.42603 .18864 L
.42611 .18864 L
.42619 .25017 L
.42627 .25017 L
.42635 .21763 L
.42643 .2262 L
.42651 .23396 L
.42659 .21244 L
.42667 .21244 L
.42675 .21806 L
.42683 .21806 L
Mistroke
.4269 .21806 L
.42698 .21806 L
.42706 .21806 L
.42714 .23571 L
.42722 .23812 L
.4273 .23812 L
.42738 .23812 L
.42746 .23812 L
.42754 .23812 L
.42762 .23812 L
.4277 .23812 L
.42778 .23812 L
.42786 .23875 L
.42794 .23875 L
.42802 .23875 L
.4281 .23796 L
.42817 .22998 L
.42825 .22998 L
.42833 .26395 L
.42841 .27217 L
.42849 .30834 L
.42857 .30834 L
.42865 .30834 L
.42873 .30834 L
.42881 .30027 L
.42889 .30027 L
.42897 .30027 L
.42905 .30027 L
.42913 .28399 L
.42921 .31213 L
.42929 .31213 L
.42937 .32443 L
.42944 .32443 L
.42952 .32443 L
.4296 .37721 L
.42968 .37721 L
.42976 .37721 L
.42984 .37721 L
.42992 .37721 L
.43 .37131 L
.43008 .37131 L
.43016 .37131 L
.43024 .45027 L
.43032 .45642 L
.4304 .49665 L
.43048 .55577 L
.43056 .54059 L
.43063 .54059 L
.43071 .54059 L
.43079 .47264 L
Mistroke
.43087 .47264 L
.43095 .54579 L
.43103 .54579 L
.43111 .54138 L
.43119 .59164 L
.43127 .59164 L
.43135 .59045 L
.43143 .59045 L
.43151 .60053 L
.43159 .53316 L
.43167 .53173 L
.43175 .49627 L
.43183 .48947 L
.4319 .48947 L
.43198 .49566 L
.43206 .48712 L
.43214 .47044 L
.43222 .47044 L
.4323 .47044 L
.43238 .473 L
.43246 .473 L
.43254 .45425 L
.43262 .45425 L
.4327 .46436 L
.43278 .46436 L
.43286 .46436 L
.43294 .46436 L
.43302 .47274 L
.4331 .4349 L
.43317 .4349 L
.43325 .37975 L
.43333 .37975 L
.43341 .38924 L
.43349 .38924 L
.43357 .38748 L
.43365 .3978 L
.43373 .3978 L
.43381 .36728 L
.43389 .36728 L
.43397 .36728 L
.43405 .36728 L
.43413 .36728 L
.43421 .34557 L
.43429 .34557 L
.43437 .33581 L
.43444 .33581 L
.43452 .29582 L
.4346 .29582 L
.43468 .28675 L
.43476 .28675 L
Mistroke
.43484 .28675 L
.43492 .28675 L
.435 .275 L
.43508 .275 L
.43516 .2527 L
.43524 .30002 L
.43532 .32439 L
.4354 .32439 L
.43548 .29502 L
.43556 .29502 L
.43563 .30539 L
.43571 .2904 L
.43579 .2904 L
.43587 .31693 L
.43595 .33704 L
.43603 .33704 L
.43611 .29339 L
.43619 .29339 L
.43627 .29049 L
.43635 .29049 L
.43643 .25879 L
.43651 .28469 L
.43659 .24607 L
.43667 .24607 L
.43675 .24607 L
.43683 .24607 L
.4369 .27487 L
.43698 .27487 L
.43706 .27487 L
.43714 .27487 L
.43722 .27362 L
.4373 .27362 L
.43738 .27362 L
.43746 .27362 L
.43754 .27362 L
.43762 .31875 L
.4377 .31875 L
.43778 .27559 L
.43786 .27089 L
.43794 .27089 L
.43802 .27089 L
.4381 .29352 L
.43817 .25536 L
.43825 .28486 L
.43833 .28486 L
.43841 .28486 L
.43849 .28297 L
.43857 .26594 L
.43865 .26594 L
.43873 .23672 L
Mistroke
.43881 .23672 L
.43889 .23672 L
.43897 .23672 L
.43905 .25063 L
.43913 .25063 L
.43921 .23528 L
.43929 .22747 L
.43937 .22747 L
.43944 .22747 L
.43952 .27568 L
.4396 .29887 L
.43968 .31018 L
.43976 .31018 L
.43984 .2802 L
.43992 .2802 L
.44 .33869 L
.44008 .33869 L
.44016 .34871 L
.44024 .34871 L
.44032 .32628 L
.4404 .36521 L
.44048 .34913 L
.44056 .33412 L
.44063 .33412 L
.44071 .37225 L
.44079 .34778 L
.44087 .34778 L
.44095 .34778 L
.44103 .34778 L
.44111 .41811 L
.44119 .44827 L
.44127 .44827 L
.44135 .39931 L
.44143 .39931 L
.44151 .39931 L
.44159 .43762 L
.44167 .43874 L
.44175 .43874 L
.44183 .43874 L
.4419 .43874 L
.44198 .46672 L
.44206 .4597 L
.44214 .41686 L
.44222 .41686 L
.4423 .41686 L
.44238 .41686 L
.44246 .40299 L
.44254 .40299 L
.44262 .40299 L
.4427 .40299 L
Mistroke
.44278 .39411 L
.44286 .39411 L
.44294 .38007 L
.44302 .37944 L
.4431 .37944 L
.44317 .38536 L
.44325 .43496 L
.44333 .43496 L
.44341 .45578 L
.44349 .45578 L
.44357 .45161 L
.44365 .45161 L
.44373 .4327 L
.44381 .40767 L
.44389 .40767 L
.44397 .40428 L
.44405 .40428 L
.44413 .40428 L
.44421 .40428 L
.44429 .40428 L
.44437 .42608 L
.44444 .42608 L
.44452 .42608 L
.4446 .41498 L
.44468 .41932 L
.44476 .40998 L
.44484 .34538 L
.44492 .34538 L
.445 .34538 L
.44508 .34538 L
.44516 .34538 L
.44524 .35082 L
.44532 .35082 L
.4454 .35082 L
.44548 .37077 L
.44556 .37077 L
.44563 .3759 L
.44571 .36488 L
.44579 .36488 L
.44587 .36488 L
.44595 .37475 L
.44603 .37628 L
.44611 .37628 L
.44619 .42458 L
.44627 .42458 L
.44635 .39285 L
.44643 .39588 L
.44651 .39064 L
.44659 .377 L
.44667 .377 L
Mistroke
.44675 .377 L
.44683 .37521 L
.4469 .38135 L
.44698 .38135 L
.44706 .38135 L
.44714 .38135 L
.44722 .38135 L
.4473 .38135 L
.44738 .38135 L
.44746 .35348 L
.44754 .35977 L
.44762 .34849 L
.4477 .34849 L
.44778 .34081 L
.44786 .38212 L
.44794 .38212 L
.44802 .38212 L
.4481 .37121 L
.44817 .37109 L
.44825 .37109 L
.44833 .37109 L
.44841 .37109 L
.44849 .35116 L
.44857 .35116 L
.44865 .35116 L
.44873 .35116 L
.44881 .35116 L
.44889 .35116 L
.44897 .37147 L
.44905 .35911 L
.44913 .35224 L
.44921 .35224 L
.44929 .35224 L
.44937 .35224 L
.44944 .35224 L
.44952 .35224 L
.4496 .35224 L
.44968 .36921 L
.44976 .3503 L
.44984 .35095 L
.44992 .34608 L
.45 .34608 L
.45008 .34608 L
.45016 .34608 L
.45024 .36319 L
.45032 .36498 L
.4504 .36498 L
.45048 .38361 L
.45056 .36915 L
.45063 .36723 L
Mistroke
.45071 .36535 L
.45079 .37532 L
.45087 .37532 L
.45095 .37532 L
.45103 .41562 L
.45111 .41562 L
.45119 .33844 L
.45127 .33844 L
.45135 .33844 L
.45143 .33844 L
.45151 .33844 L
.45159 .3349 L
.45167 .3349 L
.45175 .3349 L
.45183 .3349 L
.4519 .34657 L
.45198 .33027 L
.45206 .32595 L
.45214 .32595 L
.45222 .32595 L
.4523 .32854 L
.45238 .34386 L
.45246 .34386 L
.45254 .30738 L
.45262 .28137 L
.4527 .28137 L
.45278 .23753 L
.45286 .23613 L
.45294 .2391 L
.45302 .23528 L
.4531 .25249 L
.45317 .25249 L
.45325 .25249 L
.45333 .25249 L
.45341 .26479 L
.45349 .31263 L
.45357 .37419 L
.45365 .37419 L
.45373 .38277 L
.45381 .38277 L
.45389 .40878 L
.45397 .40878 L
.45405 .40878 L
.45413 .40878 L
.45421 .40277 L
.45429 .38452 L
.45437 .36039 L
.45444 .36039 L
.45452 .36039 L
.4546 .36039 L
Mistroke
.45468 .36039 L
.45476 .38692 L
.45484 .27434 L
.45492 .26847 L
.455 .24253 L
.45508 .22914 L
.45516 .22914 L
.45524 .22914 L
.45532 .22914 L
.4554 .22888 L
.45548 .28933 L
.45556 .28933 L
.45563 .30245 L
.45571 .27537 L
.45579 .26162 L
.45587 .26162 L
.45595 .2667 L
.45603 .2667 L
.45611 .28568 L
.45619 .28568 L
.45627 .28568 L
.45635 .28276 L
.45643 .28276 L
.45651 .29192 L
.45659 .29192 L
.45667 .29192 L
.45675 .2579 L
.45683 .25235 L
.4569 .24987 L
.45698 .24987 L
.45706 .24987 L
.45714 .24987 L
.45722 .25459 L
.4573 .23974 L
.45738 .23114 L
.45746 .24532 L
.45754 .24532 L
.45762 .24532 L
.4577 .21748 L
.45778 .22988 L
.45786 .22988 L
.45794 .22988 L
.45802 .22062 L
.4581 .22062 L
.45817 .24786 L
.45825 .25407 L
.45833 .22992 L
.45841 .22992 L
.45849 .20604 L
.45857 .20604 L
Mistroke
.45865 .20604 L
.45873 .20604 L
.45881 .14143 L
.45889 .1312 L
.45897 .1312 L
.45905 .1312 L
.45913 .1312 L
.45921 .1312 L
.45929 .1312 L
.45937 .1312 L
.45944 .1312 L
.45952 .1312 L
.4596 .1312 L
.45968 .15339 L
.45976 .16315 L
.45984 .16427 L
.45992 .16427 L
.46 .14161 L
.46008 .14161 L
.46016 .14661 L
.46024 .15046 L
.46032 .15046 L
.4604 .15046 L
.46048 .15046 L
.46056 .15046 L
.46063 .16167 L
.46071 .16167 L
.46079 .11359 L
.46087 .14825 L
.46095 .14825 L
.46103 .14825 L
.46111 .14825 L
.46119 .14825 L
.46127 .1378 L
.46135 .11713 L
.46143 .10002 L
.46151 .09668 L
.46159 .09805 L
.46167 .09805 L
.46175 .09805 L
.46183 .09805 L
.4619 .13333 L
.46198 .14066 L
.46206 .13908 L
.46214 .13908 L
.46222 .14765 L
.4623 .18911 L
.46238 .18911 L
.46246 .18911 L
.46254 .18911 L
Mistroke
.46262 .18911 L
.4627 .14749 L
.46278 .14749 L
.46286 .12416 L
.46294 .12416 L
.46302 .12416 L
.4631 .12416 L
.46317 .1278 L
.46325 .1278 L
.46333 .1278 L
.46341 .09654 L
.46349 .09654 L
.46357 .08497 L
.46365 .08497 L
.46373 .11033 L
.46381 .09407 L
.46389 .09407 L
.46397 .09407 L
.46405 .09263 L
.46413 .09263 L
.46421 .11071 L
.46429 .11071 L
.46437 .11644 L
.46444 .1392 L
.46452 .11939 L
.4646 .08104 L
.46468 .09534 L
.46476 .08705 L
.46484 .10813 L
.46492 .10813 L
.465 .10813 L
.46508 .1218 L
.46516 .1218 L
.46524 .13771 L
.46532 .14013 L
.4654 .14013 L
.46548 .08667 L
.46556 .08667 L
.46563 .08667 L
.46571 .06469 L
.46579 .07405 L
.46587 .11785 L
.46595 .11326 L
.46603 .11326 L
.46611 .11326 L
.46619 .09455 L
.46627 .09455 L
.46635 .10974 L
.46643 .11616 L
.46651 .11616 L
Mistroke
.46659 .13404 L
.46667 .10007 L
.46675 .10007 L
.46683 .09327 L
.4669 .09327 L
.46698 .09364 L
.46706 .09364 L
.46714 .09364 L
.46722 .09364 L
.4673 .11691 L
.46738 .11775 L
.46746 .11775 L
.46754 .11775 L
.46762 .14469 L
.4677 .14469 L
.46778 .14469 L
.46786 .14469 L
.46794 .14229 L
.46802 .13355 L
.4681 .13355 L
.46817 .13355 L
.46825 .1341 L
.46833 .15617 L
.46841 .15617 L
.46849 .15617 L
.46857 .15617 L
.46865 .09353 L
.46873 .08261 L
.46881 .08102 L
.46889 .10776 L
.46897 .1683 L
.46905 .158 L
.46913 .16256 L
.46921 .12156 L
.46929 .11652 L
.46937 .11652 L
.46944 .09621 L
.46952 .09621 L
.4696 .12915 L
.46968 .17058 L
.46976 .17058 L
.46984 .17058 L
.46992 .17058 L
.47 .23568 L
.47008 .23894 L
.47016 .23894 L
.47024 .23894 L
.47032 .23894 L
.4704 .16981 L
.47048 .16981 L
Mistroke
.47056 .11329 L
.47063 .12855 L
.47071 .07911 L
.47079 .07911 L
.47087 .09722 L
.47095 .09722 L
.47103 .13759 L
.47111 .13759 L
.47119 .16837 L
.47127 .16837 L
.47135 .17069 L
.47143 .17069 L
.47151 .14648 L
.47159 .14648 L
.47167 .14648 L
.47175 .13129 L
.47183 .13129 L
.4719 .1427 L
.47198 .1427 L
.47206 .14557 L
.47214 .17694 L
.47222 .17694 L
.4723 .17694 L
.47238 .17694 L
.47246 .17694 L
.47254 .16477 L
.47262 .18442 L
.4727 .18442 L
.47278 .18442 L
.47286 .18442 L
.47294 .17645 L
.47302 .17645 L
.4731 .17645 L
.47317 .16208 L
.47325 .16208 L
.47333 .10954 L
.47341 .10954 L
.47349 .10954 L
.47357 .10954 L
.47365 .10954 L
.47373 .10954 L
.47381 .07983 L
.47389 .06794 L
.47397 .06794 L
.47405 .09231 L
.47413 .09231 L
.47421 .11115 L
.47429 .11115 L
.47437 .11115 L
.47444 .08354 L
Mistroke
.47452 .08354 L
.4746 .09407 L
.47468 .09222 L
.47476 .09222 L
.47484 .09222 L
.47492 .10134 L
.475 .10134 L
.47508 .10134 L
.47516 .10134 L
.47524 .10134 L
.47532 .10134 L
.4754 .07038 L
.47548 .07038 L
.47556 .09224 L
.47563 .09224 L
.47571 .08229 L
.47579 .08229 L
.47587 .08493 L
.47595 .08806 L
.47603 .08806 L
.47611 .09354 L
.47619 .13202 L
.47627 .13202 L
.47635 .13202 L
.47643 .15498 L
.47651 .09893 L
.47659 .09464 L
.47667 .09464 L
.47675 .09464 L
.47683 .08343 L
.4769 .08343 L
.47698 .08343 L
.47706 .08148 L
.47714 .08148 L
.47722 .08148 L
.4773 .08169 L
.47738 .08169 L
.47746 .09302 L
.47754 .09302 L
.47762 .10325 L
.4777 .10325 L
.47778 .10593 L
.47786 .10913 L
.47794 .10913 L
.47802 .07136 L
.4781 .07136 L
.47817 .1112 L
.47825 .1112 L
.47833 .1112 L
.47841 .1112 L
Mistroke
.47849 .1112 L
.47857 .1112 L
.47865 .1112 L
.47873 .1112 L
.47881 .1112 L
.47889 .1112 L
.47897 .11454 L
.47905 .11454 L
.47913 .11454 L
.47921 .12646 L
.47929 .14062 L
.47937 .14062 L
.47944 .14062 L
.47952 .14062 L
.4796 .14062 L
.47968 .14062 L
.47976 .14062 L
.47984 .14062 L
.47992 .18419 L
.48 .18419 L
.48008 .18419 L
.48016 .17904 L
.48024 .17904 L
.48032 .20344 L
.4804 .13493 L
.48048 .13493 L
.48056 .13493 L
.48063 .13493 L
.48071 .18034 L
.48079 .18034 L
.48087 .18034 L
.48095 .15678 L
.48103 .15678 L
.48111 .15678 L
.48119 .1297 L
.48127 .13486 L
.48135 .13486 L
.48143 .13438 L
.48151 .12388 L
.48159 .13101 L
.48167 .13101 L
.48175 .13101 L
.48183 .12406 L
.4819 .12406 L
.48198 .12406 L
.48206 .13045 L
.48214 .12136 L
.48222 .12136 L
.4823 .16496 L
.48238 .20354 L
Mistroke
.48246 .1777 L
.48254 .1777 L
.48262 .1777 L
.4827 .1777 L
.48278 .1777 L
.48286 .1777 L
.48294 .1777 L
.48302 .1777 L
.4831 .1777 L
.48317 .1777 L
.48325 .1777 L
.48333 .1777 L
.48341 .1777 L
.48349 .1777 L
.48357 .16925 L
.48365 .16925 L
.48373 .14491 L
.48381 .08703 L
.48389 .08703 L
.48397 .14609 L
.48405 .11662 L
.48413 .11662 L
.48421 .11662 L
.48429 .12132 L
.48437 .12132 L
.48444 .15322 L
.48452 .23961 L
.4846 .23961 L
.48468 .22359 L
.48476 .22359 L
.48484 .21833 L
.48492 .21833 L
.485 .21833 L
.48508 .2091 L
.48516 .2091 L
.48524 .19336 L
.48532 .18401 L
.4854 .13146 L
.48548 .13146 L
.48556 .12108 L
.48563 .12108 L
.48571 .12391 L
.48579 .14226 L
.48587 .16735 L
.48595 .16735 L
.48603 .14065 L
.48611 .10418 L
.48619 .08192 L
.48627 .08202 L
.48635 .08202 L
Mistroke
.48643 .10075 L
.48651 .10075 L
.48659 .10075 L
.48667 .10075 L
.48675 .12127 L
.48683 .13179 L
.4869 .13179 L
.48698 .13179 L
.48706 .09477 L
.48714 .08516 L
.48722 .10244 L
.4873 .10244 L
.48738 .10244 L
.48746 .10244 L
.48754 .13955 L
.48762 .13955 L
.4877 .13955 L
.48778 .13955 L
.48786 .14105 L
.48794 .15178 L
.48802 .15178 L
.4881 .15178 L
.48817 .15178 L
.48825 .14258 L
.48833 .14258 L
.48841 .14258 L
.48849 .14258 L
.48857 .10637 L
.48865 .10637 L
.48873 .1053 L
.48881 .12503 L
.48889 .12503 L
.48897 .12503 L
.48905 .12503 L
.48913 .12503 L
.48921 .1306 L
.48929 .1306 L
.48937 .10398 L
.48944 .10028 L
.48952 .10028 L
.4896 .09284 L
.48968 .09284 L
.48976 .09284 L
.48984 .09284 L
.48992 .09284 L
.49 .09284 L
.49008 .07943 L
.49016 .07943 L
.49024 .07943 L
.49032 .07261 L
Mistroke
.4904 .07261 L
.49048 .07261 L
.49056 .11834 L
.49063 .11834 L
.49071 .0849 L
.49079 .17067 L
.49087 .23177 L
.49095 .23177 L
.49103 .22329 L
.49111 .21066 L
.49119 .21066 L
.49127 .18588 L
.49135 .18588 L
.49143 .18588 L
.49151 .18588 L
.49159 .17624 L
.49167 .17624 L
.49175 .17624 L
.49183 .17624 L
.4919 .17624 L
.49198 .18345 L
.49206 .18345 L
.49214 .17985 L
.49222 .17667 L
.4923 .1588 L
.49238 .14052 L
.49246 .14052 L
.49254 .14829 L
.49262 .10826 L
.4927 .10274 L
.49278 .10274 L
.49286 .06356 L
.49294 .06356 L
.49302 .06356 L
.4931 .06356 L
.49317 .06511 L
.49325 .06511 L
.49333 .06511 L
.49341 .06511 L
.49349 .06511 L
.49357 .06511 L
.49365 .06511 L
.49373 .06511 L
.49381 .06511 L
.49389 .08775 L
.49397 .08775 L
.49405 .08775 L
.49413 .11379 L
.49421 .08457 L
.49429 .08457 L
Mistroke
.49437 .08251 L
.49444 .08251 L
.49452 .05749 L
.4946 .05749 L
.49468 .08597 L
.49476 .10011 L
.49484 .10011 L
.49492 .11136 L
.495 .11229 L
.49508 .11229 L
.49516 .11229 L
.49524 .11101 L
.49532 .16019 L
.4954 .16019 L
.49548 .16019 L
.49556 .16795 L
.49563 .10236 L
.49571 .07134 L
.49579 .0661 L
.49587 .0661 L
.49595 .0661 L
.49603 .0661 L
.49611 .0661 L
.49619 .0661 L
.49627 .06598 L
.49635 .11597 L
.49643 .11597 L
.49651 .11597 L
.49659 .11597 L
.49667 .11597 L
.49675 .11597 L
.49683 .11597 L
.4969 .11597 L
.49698 .09464 L
.49706 .09464 L
.49714 .09464 L
.49722 .09833 L
.4973 .09833 L
.49738 .12986 L
.49746 .12986 L
.49754 .12986 L
.49762 .12986 L
.4977 .1246 L
.49778 .1249 L
.49786 .10272 L
.49794 .10934 L
.49802 .11619 L
.4981 .07212 L
.49817 .07212 L
.49825 .07212 L
Mistroke
.49833 .07212 L
.49841 .05967 L
.49849 .08846 L
.49857 .09325 L
.49865 .1002 L
.49873 .1002 L
.49881 .1002 L
.49889 .05981 L
.49897 .05981 L
.49905 .05981 L
.49913 .05981 L
.49921 .06702 L
.49929 .0898 L
.49937 .07358 L
.49944 .07358 L
.49952 .07358 L
.4996 .08577 L
.49968 .09773 L
.49976 .09773 L
.49984 .09773 L
.49992 .08894 L
.5 .12711 L
.50008 .12711 L
.50016 .17633 L
.50024 .17633 L
.50032 .17633 L
.5004 .20084 L
.50048 .20084 L
.50056 .16982 L
.50063 .16304 L
.50071 .16304 L
.50079 .14083 L
.50087 .14083 L
.50095 .21483 L
.50103 .26341 L
.50111 .23811 L
.50119 .19488 L
.50127 .19148 L
.50135 .19148 L
.50143 .19148 L
.50151 .19148 L
.50159 .19148 L
.50167 .18532 L
.50175 .18532 L
.50183 .18532 L
.5019 .18532 L
.50198 .18532 L
.50206 .18532 L
.50214 .2145 L
.50222 .23004 L
Mistroke
.5023 .31961 L
.50238 .31961 L
.50246 .31961 L
.50254 .31961 L
.50262 .31961 L
.5027 .31961 L
.50278 .30429 L
.50286 .30429 L
.50294 .30429 L
.50302 .2916 L
.5031 .2916 L
.50317 .26036 L
.50325 .26036 L
.50333 .26968 L
.50341 .25773 L
.50349 .25773 L
.50357 .25773 L
.50365 .25773 L
.50373 .31391 L
.50381 .31391 L
.50389 .3519 L
.50397 .32565 L
.50405 .29347 L
.50413 .29347 L
.50421 .26274 L
.50429 .26274 L
.50437 .26274 L
.50444 .24038 L
.50452 .25349 L
.5046 .23832 L
.50468 .20608 L
.50476 .20608 L
.50484 .20608 L
.50492 .29439 L
.505 .31035 L
.50508 .31035 L
.50516 .31035 L
.50524 .28442 L
.50532 .28442 L
.5054 .28442 L
.50548 .28442 L
.50556 .28442 L
.50563 .28442 L
.50571 .28442 L
.50579 .28442 L
.50587 .24444 L
.50595 .21756 L
.50603 .21935 L
.50611 .21935 L
.50619 .21935 L
Mistroke
.50627 .21935 L
.50635 .20485 L
.50643 .20485 L
.50651 .19747 L
.50659 .18198 L
.50667 .15606 L
.50675 .16528 L
.50683 .16554 L
.5069 .16554 L
.50698 .16554 L
.50706 .16554 L
.50714 .15809 L
.50722 .15809 L
.5073 .15809 L
.50738 .12263 L
.50746 .12263 L
.50754 .12263 L
.50762 .13481 L
.5077 .13481 L
.50778 .13481 L
.50786 .12889 L
.50794 .12889 L
.50802 .13689 L
.5081 .13689 L
.50817 .13689 L
.50825 .1407 L
.50833 .1407 L
.50841 .12068 L
.50849 .12068 L
.50857 .132 L
.50865 .16302 L
.50873 .14328 L
.50881 .1714 L
.50889 .1714 L
.50897 .1714 L
.50905 .16786 L
.50913 .15648 L
.50921 .1396 L
.50929 .1396 L
.50937 .12909 L
.50944 .1314 L
.50952 .1314 L
.5096 .16706 L
.50968 .15537 L
.50976 .21899 L
.50984 .204 L
.50992 .204 L
.51 .23198 L
.51008 .19049 L
.51016 .19049 L
Mistroke
.51024 .19173 L
.51032 .19173 L
.5104 .18639 L
.51048 .20786 L
.51056 .22237 L
.51063 .22237 L
.51071 .22237 L
.51079 .22237 L
.51087 .22237 L
.51095 .21924 L
.51103 .21924 L
.51111 .2371 L
.51119 .22088 L
.51127 .23808 L
.51135 .24413 L
.51143 .24413 L
.51151 .22964 L
.51159 .22964 L
.51167 .19007 L
.51175 .24087 L
.51183 .24087 L
.5119 .19747 L
.51198 .27492 L
.51206 .27492 L
.51214 .2553 L
.51222 .2553 L
.5123 .2553 L
.51238 .22727 L
.51246 .24184 L
.51254 .23318 L
.51262 .17153 L
.5127 .17153 L
.51278 .17153 L
.51286 .17153 L
.51294 .17153 L
.51302 .18115 L
.5131 .18115 L
.51317 .18188 L
.51325 .15449 L
.51333 .16069 L
.51341 .16069 L
.51349 .17497 L
.51357 .15256 L
.51365 .15256 L
.51373 .15256 L
.51381 .19743 L
.51389 .1976 L
.51397 .1976 L
.51405 .17676 L
.51413 .18491 L
Mistroke
.51421 .19676 L
.51429 .22851 L
.51437 .22851 L
.51444 .22851 L
.51452 .22978 L
.5146 .22978 L
.51468 .22978 L
.51476 .22956 L
.51484 .22956 L
.51492 .24077 L
.515 .24077 L
.51508 .23213 L
.51516 .23213 L
.51524 .24594 L
.51532 .24594 L
.5154 .24594 L
.51548 .24594 L
.51556 .24594 L
.51563 .25749 L
.51571 .25749 L
.51579 .25749 L
.51587 .25749 L
.51595 .25749 L
.51603 .26849 L
.51611 .26849 L
.51619 .26849 L
.51627 .31128 L
.51635 .31128 L
.51643 .31128 L
.51651 .33677 L
.51659 .29443 L
.51667 .29406 L
.51675 .29406 L
.51683 .29406 L
.5169 .28128 L
.51698 .28128 L
.51706 .28128 L
.51714 .25273 L
.51722 .26617 L
.5173 .26617 L
.51738 .27217 L
.51746 .27217 L
.51754 .29336 L
.51762 .29336 L
.5177 .34182 L
.51778 .34182 L
.51786 .27444 L
.51794 .19802 L
.51802 .19802 L
.5181 .17204 L
Mistroke
.51817 .17204 L
.51825 .17204 L
.51833 .16303 L
.51841 .16303 L
.51849 .20109 L
.51857 .22809 L
.51865 .27038 L
.51873 .27038 L
.51881 .25947 L
.51889 .18507 L
.51897 .18507 L
.51905 .17249 L
.51913 .17249 L
.51921 .17249 L
.51929 .17249 L
.51937 .17764 L
.51944 .18073 L
.51952 .18073 L
.5196 .18073 L
.51968 .18073 L
.51976 .18073 L
.51984 .18073 L
.51992 .19174 L
.52 .20026 L
.52008 .16712 L
.52016 .17157 L
.52024 .17157 L
.52032 .16696 L
.5204 .16696 L
.52048 .16696 L
.52056 .16068 L
.52063 .18335 L
.52071 .21171 L
.52079 .21171 L
.52087 .21171 L
.52095 .21171 L
.52103 .21171 L
.52111 .21171 L
.52119 .19702 L
.52127 .16871 L
.52135 .16826 L
.52143 .21629 L
.52151 .21629 L
.52159 .22032 L
.52167 .25697 L
.52175 .20808 L
.52183 .20808 L
.5219 .17165 L
.52198 .17165 L
.52206 .17165 L
Mistroke
.52214 .17165 L
.52222 .17165 L
.5223 .17165 L
.52238 .1387 L
.52246 .1387 L
.52254 .1387 L
.52262 .1387 L
.5227 .1387 L
.52278 .1387 L
.52286 .1387 L
.52294 .14577 L
.52302 .14577 L
.5231 .1382 L
.52317 .12971 L
.52325 .12971 L
.52333 .1331 L
.52341 .1698 L
.52349 .1518 L
.52357 .1518 L
.52365 .1518 L
.52373 .17122 L
.52381 .18671 L
.52389 .15308 L
.52397 .17076 L
.52405 .17076 L
.52413 .16517 L
.52421 .12578 L
.52429 .12578 L
.52437 .12578 L
.52444 .12578 L
.52452 .13383 L
.5246 .13383 L
.52468 .14248 L
.52476 .14248 L
.52484 .15316 L
.52492 .15316 L
.525 .15316 L
.52508 .15316 L
.52516 .15316 L
.52524 .15316 L
.52532 .15316 L
.5254 .14276 L
.52548 .13014 L
.52556 .13014 L
.52563 .13014 L
.52571 .11903 L
.52579 .11903 L
.52587 .13944 L
.52595 .15371 L
.52603 .11752 L
Mistroke
.52611 .12372 L
.52619 .12372 L
.52627 .14011 L
.52635 .12876 L
.52643 .12876 L
.52651 .15167 L
.52659 .15167 L
.52667 .10687 L
.52675 .10411 L
.52683 .10411 L
.5269 .10411 L
.52698 .10411 L
.52706 .10411 L
.52714 .0908 L
.52722 .0908 L
.5273 .0908 L
.52738 .10871 L
.52746 .10871 L
.52754 .10871 L
.52762 .11421 L
.5277 .11421 L
.52778 .11421 L
.52786 .11421 L
.52794 .10506 L
.52802 .10506 L
.5281 .11054 L
.52817 .10353 L
.52825 .10353 L
.52833 .10282 L
.52841 .10282 L
.52849 .07221 L
.52857 .10774 L
.52865 .09209 L
.52873 .09209 L
.52881 .09209 L
.52889 .09209 L
.52897 .09556 L
.52905 .09556 L
.52913 .09556 L
.52921 .09556 L
.52929 .10151 L
.52937 .0972 L
.52944 .16711 L
.52952 .16711 L
.5296 .13378 L
.52968 .12734 L
.52976 .12654 L
.52984 .10584 L
.52992 .09424 L
.53 .12393 L
Mistroke
.53008 .12393 L
.53016 .10876 L
.53024 .10876 L
.53032 .10695 L
.5304 .10695 L
.53048 .10695 L
.53056 .10695 L
.53063 .10695 L
.53071 .10767 L
.53079 .15062 L
.53087 .15062 L
.53095 .1519 L
.53103 .13689 L
.53111 .16063 L
.53119 .17957 L
.53127 .17957 L
.53135 .17957 L
.53143 .18343 L
.53151 .18343 L
.53159 .20363 L
.53167 .23499 L
.53175 .23499 L
.53183 .23499 L
.5319 .19229 L
.53198 .20409 L
.53206 .20409 L
.53214 .22091 L
.53222 .21906 L
.5323 .21906 L
.53238 .23929 L
.53246 .23929 L
.53254 .23929 L
.53262 .23929 L
.5327 .24657 L
.53278 .24657 L
.53286 .20714 L
.53294 .20714 L
.53302 .14579 L
.5331 .14579 L
.53317 .14579 L
.53325 .14579 L
.53333 .14932 L
.53341 .12739 L
.53349 .12739 L
.53357 .11454 L
.53365 .08101 L
.53373 .08101 L
.53381 .06028 L
.53389 .06028 L
.53397 .02695 L
Mistroke
.53405 .02695 L
.53413 .0423 L
.53421 .0423 L
.53429 .0423 L
.53437 .0423 L
.53444 .0423 L
.53452 .02277 L
.5346 .03203 L
.53468 .03203 L
.53476 .03203 L
.53484 .03203 L
.53492 .03203 L
.535 .03203 L
.53508 .03203 L
.53516 .03495 L
.53524 .05288 L
.53532 .05288 L
.5354 .02683 L
.53548 .02683 L
.53556 .04923 L
.53563 .04923 L
.53571 .04923 L
.53579 .04753 L
.53587 .04753 L
.53595 .04753 L
.53603 .04753 L
.53611 .04753 L
.53619 .04753 L
.53627 .04753 L
.53635 .10405 L
.53643 .17115 L
.53651 .19763 L
.53659 .19763 L
.53667 .1754 L
.53675 .1754 L
.53683 .19499 L
.5369 .19499 L
.53698 .19499 L
.53706 .19499 L
.53714 .16681 L
.53722 .17544 L
.5373 .16964 L
.53738 .16964 L
.53746 .16964 L
.53754 .16964 L
.53762 .12892 L
.5377 .12892 L
.53778 .12892 L
.53786 .12438 L
.53794 .11691 L
Mistroke
.53802 .11691 L
.5381 .12409 L
.53817 .12409 L
.53825 .12601 L
.53833 .12016 L
.53841 .12016 L
.53849 .10377 L
.53857 .10377 L
.53865 .10377 L
.53873 .10377 L
.53881 .10377 L
.53889 .18716 L
.53897 .21097 L
.53905 .21097 L
.53913 .19186 L
.53921 .15456 L
.53929 .15456 L
.53937 .15456 L
.53944 .13844 L
.53952 .1716 L
.5396 .1716 L
.53968 .1716 L
.53976 .1716 L
.53984 .1716 L
.53992 .15004 L
.54 .15004 L
.54008 .15004 L
.54016 .15004 L
.54024 .15004 L
.54032 .15004 L
.5404 .15004 L
.54048 .21617 L
.54056 .22559 L
.54063 .26575 L
.54071 .23088 L
.54079 .23646 L
.54087 .23646 L
.54095 .23646 L
.54103 .23646 L
.54111 .23646 L
.54119 .20059 L
.54127 .20059 L
.54135 .20059 L
.54143 .18808 L
.54151 .18808 L
.54159 .18808 L
.54167 .1806 L
.54175 .18132 L
.54183 .19961 L
.5419 .19961 L
Mistroke
.54198 .21491 L
.54206 .26112 L
.54214 .26112 L
.54222 .22175 L
.5423 .22175 L
.54238 .2329 L
.54246 .2329 L
.54254 .24473 L
.54262 .24473 L
.5427 .2058 L
.54278 .2058 L
.54286 .20551 L
.54294 .20551 L
.54302 .18112 L
.5431 .18112 L
.54317 .18112 L
.54325 .24162 L
.54333 .23338 L
.54341 .23338 L
.54349 .23225 L
.54357 .23225 L
.54365 .23255 L
.54373 .23255 L
.54381 .23255 L
.54389 .23255 L
.54397 .24399 L
.54405 .18428 L
.54413 .18428 L
.54421 .19565 L
.54429 .17244 L
.54437 .17244 L
.54444 .17244 L
.54452 .17244 L
.5446 .17244 L
.54468 .17244 L
.54476 .16089 L
.54484 .16089 L
.54492 .14562 L
.545 .14562 L
.54508 .14562 L
.54516 .14562 L
.54524 .13024 L
.54532 .12462 L
.5454 .12462 L
.54548 .12462 L
.54556 .12462 L
.54563 .07344 L
.54571 .07344 L
.54579 .07344 L
.54587 .07344 L
Mistroke
.54595 .06832 L
.54603 .06832 L
.54611 .08968 L
.54619 .07596 L
.54627 .07596 L
.54635 .07596 L
.54643 .07596 L
.54651 .09201 L
.54659 .09201 L
.54667 .09389 L
.54675 .11256 L
.54683 .09431 L
.5469 .09431 L
.54698 .09423 L
.54706 .09423 L
.54714 .09423 L
.54722 .05416 L
.5473 .05416 L
.54738 .05416 L
.54746 .05416 L
.54754 .05416 L
.54762 .08129 L
.5477 .08129 L
.54778 .10669 L
.54786 .10669 L
.54794 .10669 L
.54802 .10669 L
.5481 .10669 L
.54817 .08506 L
.54825 .10009 L
.54833 .10327 L
.54841 .10327 L
.54849 .10327 L
.54857 .10327 L
.54865 .10327 L
.54873 .10327 L
.54881 .08524 L
.54889 .08524 L
.54897 .15129 L
.54905 .15129 L
.54913 .15129 L
.54921 .17799 L
.54929 .17799 L
.54937 .17799 L
.54944 .11669 L
.54952 .11669 L
.5496 .11669 L
.54968 .11669 L
.54976 .11669 L
.54984 .11669 L
Mistroke
.54992 .11694 L
.55 .11694 L
.55008 .11694 L
.55016 .11694 L
.55024 .11694 L
.55032 .11694 L
.5504 .17022 L
.55048 .16502 L
.55056 .16502 L
.55063 .12621 L
.55071 .09299 L
.55079 .09299 L
.55087 .09299 L
.55095 .09299 L
.55103 .09299 L
.55111 .11177 L
.55119 .11177 L
.55127 .11177 L
.55135 .15867 L
.55143 .15867 L
.55151 .15867 L
.55159 .15867 L
.55167 .15867 L
.55175 .15867 L
.55183 .15867 L
.5519 .15867 L
.55198 .17219 L
.55206 .18484 L
.55214 .15906 L
.55222 .16253 L
.5523 .16253 L
.55238 .11622 L
.55246 .11622 L
.55254 .11622 L
.55262 .11622 L
.5527 .09115 L
.55278 .09679 L
.55286 .06092 L
.55294 .07306 L
.55302 .07306 L
.5531 .07306 L
.55317 .07614 L
.55325 .07614 L
.55333 .08358 L
.55341 .08358 L
.55349 .08358 L
.55357 .08358 L
.55365 .08358 L
.55373 .08358 L
.55381 .08809 L
Mistroke
.55389 .10029 L
.55397 .10029 L
.55405 .10029 L
.55413 .10029 L
.55421 .10029 L
.55429 .07091 L
.55437 .10945 L
.55444 .10945 L
.55452 .07544 L
.5546 .07544 L
.55468 .07544 L
.55476 .08876 L
.55484 .08876 L
.55492 .08804 L
.555 .08804 L
.55508 .08804 L
.55516 .11503 L
.55524 .11843 L
.55532 .11928 L
.5554 .10519 L
.55548 .10519 L
.55556 .10519 L
.55563 .10519 L
.55571 .10519 L
.55579 .15895 L
.55587 .14672 L
.55595 .16126 L
.55603 .16061 L
.55611 .16061 L
.55619 .14926 L
.55627 .09165 L
.55635 .09165 L
.55643 .09165 L
.55651 .05849 L
.55659 .0587 L
.55667 .0587 L
.55675 .0587 L
.55683 .05854 L
.5569 .05854 L
.55698 .05854 L
.55706 .05854 L
.55714 .04885 L
.55722 .04885 L
.5573 .0599 L
.55738 .0599 L
.55746 .0599 L
.55754 .0599 L
.55762 .0599 L
.5577 .0599 L
.55778 .06132 L
Mistroke
.55786 .06132 L
.55794 .06132 L
.55802 .08032 L
.5581 .08032 L
.55817 .07991 L
.55825 .07991 L
.55833 .07991 L
.55841 .09026 L
.55849 .09026 L
.55857 .06983 L
.55865 .06983 L
.55873 .06983 L
.55881 .06983 L
.55889 .07466 L
.55897 .07466 L
.55905 .08075 L
.55913 .08075 L
.55921 .08075 L
.55929 .10484 L
.55937 .10484 L
.55944 .09098 L
.55952 .09993 L
.5596 .15808 L
.55968 .15808 L
.55976 .15808 L
.55984 .16873 L
.55992 .17194 L
.56 .17194 L
.56008 .09991 L
.56016 .08162 L
.56024 .08457 L
.56032 .08457 L
.5604 .0822 L
.56048 .0822 L
.56056 .07397 L
.56063 .08667 L
.56071 .08667 L
.56079 .10222 L
.56087 .16521 L
.56095 .21118 L
.56103 .16175 L
.56111 .16175 L
.56119 .16175 L
.56127 .16175 L
.56135 .16175 L
.56143 .14332 L
.56151 .14332 L
.56159 .18445 L
.56167 .17442 L
.56175 .17442 L
Mistroke
.56183 .19163 L
.5619 .22606 L
.56198 .21543 L
.56206 .21543 L
.56214 .20131 L
.56222 .20131 L
.5623 .14153 L
.56238 .14153 L
.56246 .14153 L
.56254 .14153 L
.56262 .17824 L
.5627 .16535 L
.56278 .16489 L
.56286 .18941 L
.56294 .16391 L
.56302 .16391 L
.5631 .16391 L
.56317 .16391 L
.56325 .16391 L
.56333 .16391 L
.56341 .15947 L
.56349 .15636 L
.56357 .16825 L
.56365 .18075 L
.56373 .18075 L
.56381 .18978 L
.56389 .18978 L
.56397 .16053 L
.56405 .16053 L
.56413 .17023 L
.56421 .18198 L
.56429 .18198 L
.56437 .18198 L
.56444 .18198 L
.56452 .18198 L
.5646 .18957 L
.56468 .18957 L
.56476 .14821 L
.56484 .14821 L
.56492 .14821 L
.565 .14821 L
.56508 .14902 L
.56516 .16825 L
.56524 .16825 L
.56532 .16825 L
.5654 .16825 L
.56548 .19984 L
.56556 .19984 L
.56563 .19244 L
.56571 .21109 L
Mistroke
.56579 .14568 L
.56587 .14568 L
.56595 .14568 L
.56603 .14568 L
.56611 .14568 L
.56619 .15839 L
.56627 .14388 L
.56635 .12053 L
.56643 .09986 L
.56651 .08659 L
.56659 .07828 L
.56667 .08112 L
.56675 .0716 L
.56683 .09832 L
.5669 .09446 L
.56698 .09446 L
.56706 .08609 L
.56714 .08609 L
.56722 .08609 L
.5673 .07251 L
.56738 .07251 L
.56746 .07251 L
.56754 .07251 L
.56762 .07903 L
.5677 .05658 L
.56778 .05658 L
.56786 .0776 L
.56794 .11922 L
.56802 .11922 L
.5681 .11922 L
.56817 .15214 L
.56825 .15214 L
.56833 .15214 L
.56841 .15214 L
.56849 .15214 L
.56857 .15214 L
.56865 .15214 L
.56873 .14006 L
.56881 .14006 L
.56889 .12387 L
.56897 .10947 L
.56905 .1465 L
.56913 .1465 L
.56921 .1465 L
.56929 .14054 L
.56937 .09686 L
.56944 .09686 L
.56952 .09686 L
.5696 .09686 L
.56968 .09686 L
Mistroke
.56976 .10819 L
.56984 .17401 L
.56992 .17401 L
.57 .17401 L
.57008 .17791 L
.57016 .17791 L
.57024 .22003 L
.57032 .23096 L
.5704 .22385 L
.57048 .21342 L
.57056 .21342 L
.57063 .20919 L
.57071 .1833 L
.57079 .1833 L
.57087 .1833 L
.57095 .17796 L
.57103 .17796 L
.57111 .18764 L
.57119 .18764 L
.57127 .18764 L
.57135 .18764 L
.57143 .18764 L
.57151 .19915 L
.57159 .20452 L
.57167 .23668 L
.57175 .23668 L
.57183 .23668 L
.5719 .15424 L
.57198 .15424 L
.57206 .13824 L
.57214 .09457 L
.57222 .09457 L
.5723 .09457 L
.57238 .13555 L
.57246 .16022 L
.57254 .22293 L
.57262 .17733 L
.5727 .23208 L
.57278 .21101 L
.57286 .21101 L
.57294 .21101 L
.57302 .20943 L
.5731 .2232 L
.57317 .2232 L
.57325 .2232 L
.57333 .22063 L
.57341 .21379 L
.57349 .20212 L
.57357 .15641 L
.57365 .13831 L
Mistroke
.57373 .13831 L
.57381 .13327 L
.57389 .11645 L
.57397 .11645 L
.57405 .11645 L
.57413 .11645 L
.57421 .11504 L
.57429 .10388 L
.57437 .10388 L
.57444 .10388 L
.57452 .07242 L
.5746 .07242 L
.57468 .07242 L
.57476 .08517 L
.57484 .09541 L
.57492 .09854 L
.575 .08567 L
.57508 .08567 L
.57516 .11549 L
.57524 .10197 L
.57532 .10197 L
.5754 .09125 L
.57548 .09125 L
.57556 .09125 L
.57563 .09754 L
.57571 .09754 L
.57579 .09754 L
.57587 .09754 L
.57595 .07912 L
.57603 .07912 L
.57611 .0787 L
.57619 .09344 L
.57627 .06617 L
.57635 .06617 L
.57643 .07513 L
.57651 .07513 L
.57659 .07193 L
.57667 .07193 L
.57675 .08574 L
.57683 .07321 L
.5769 .1175 L
.57698 .05395 L
.57706 .08539 L
.57714 .08539 L
.57722 .07903 L
.5773 .07903 L
.57738 .07903 L
.57746 .07674 L
.57754 .10955 L
.57762 .10955 L
Mistroke
.5777 .10955 L
.57778 .10955 L
.57786 .10853 L
.57794 .14917 L
.57802 .14917 L
.5781 .16168 L
.57817 .11965 L
.57825 .14932 L
.57833 .14932 L
.57841 .14932 L
.57849 .14932 L
.57857 .14932 L
.57865 .14932 L
.57873 .12796 L
.57881 .12796 L
.57889 .11002 L
.57897 .11002 L
.57905 .12249 L
.57913 .12249 L
.57921 .12915 L
.57929 .12915 L
.57937 .12915 L
.57944 .08764 L
.57952 .11048 L
.5796 .11048 L
.57968 .13104 L
.57976 .17542 L
.57984 .17542 L
.57992 .17542 L
.58 .17542 L
.58008 .17678 L
.58016 .18073 L
.58024 .14931 L
.58032 .14931 L
.5804 .14931 L
.58048 .12139 L
.58056 .10111 L
.58063 .10111 L
.58071 .10111 L
.58079 .10111 L
.58087 .10111 L
.58095 .10111 L
.58103 .10111 L
.58111 .10111 L
.58119 .10111 L
.58127 .10111 L
.58135 .10111 L
.58143 .10111 L
.58151 .10111 L
.58159 .10111 L
Mistroke
.58167 .09123 L
.58175 .14359 L
.58183 .20292 L
.5819 .19912 L
.58198 .19912 L
.58206 .19912 L
.58214 .17415 L
.58222 .17415 L
.5823 .17415 L
.58238 .17415 L
.58246 .20485 L
.58254 .18727 L
.58262 .27905 L
.5827 .28293 L
.58278 .22516 L
.58286 .17526 L
.58294 .17526 L
.58302 .17526 L
.5831 .17526 L
.58317 .13503 L
.58325 .14142 L
.58333 .14142 L
.58341 .12875 L
.58349 .14597 L
.58357 .14597 L
.58365 .14597 L
.58373 .1049 L
.58381 .15028 L
.58389 .15028 L
.58397 .10851 L
.58405 .09035 L
.58413 .07793 L
.58421 .07793 L
.58429 .07793 L
.58437 .07793 L
.58444 .05478 L
.58452 .05478 L
.5846 .10289 L
.58468 .10289 L
.58476 .10357 L
.58484 .10995 L
.58492 .13507 L
.585 .13507 L
.58508 .15713 L
.58516 .15713 L
.58524 .17937 L
.58532 .17937 L
.5854 .14955 L
.58548 .14955 L
.58556 .16571 L
Mistroke
.58563 .16571 L
.58571 .16571 L
.58579 .16571 L
.58587 .16571 L
.58595 .18289 L
.58603 .18289 L
.58611 .1481 L
.58619 .1481 L
.58627 .1512 L
.58635 .1512 L
.58643 .18443 L
.58651 .16305 L
.58659 .14888 L
.58667 .14888 L
.58675 .14888 L
.58683 .14888 L
.5869 .14888 L
.58698 .14888 L
.58706 .14888 L
.58714 .19376 L
.58722 .19376 L
.5873 .20666 L
.58738 .16372 L
.58746 .10269 L
.58754 .10269 L
.58762 .10269 L
.5877 .10269 L
.58778 .10269 L
.58786 .10269 L
.58794 .10423 L
.58802 .10423 L
.5881 .10423 L
.58817 .14024 L
.58825 .14024 L
.58833 .12081 L
.58841 .15638 L
.58849 .11824 L
.58857 .08339 L
.58865 .10565 L
.58873 .10969 L
.58881 .10437 L
.58889 .10437 L
.58897 .12069 L
.58905 .12069 L
.58913 .12069 L
.58921 .12069 L
.58929 .12069 L
.58937 .16172 L
.58944 .19107 L
.58952 .13978 L
Mistroke
.5896 .10817 L
.58968 .10719 L
.58976 .10648 L
.58984 .10648 L
.58992 .10648 L
.59 .10648 L
.59008 .10648 L
.59016 .10648 L
.59024 .10648 L
.59032 .10648 L
.5904 .10648 L
.59048 .10648 L
.59056 .12042 L
.59063 .12042 L
.59071 .16072 L
.59079 .16895 L
.59087 .16895 L
.59095 .12721 L
.59103 .12721 L
.59111 .12721 L
.59119 .12721 L
.59127 .12721 L
.59135 .12721 L
.59143 .12824 L
.59151 .12824 L
.59159 .12824 L
.59167 .11704 L
.59175 .11704 L
.59183 .12676 L
.5919 .12693 L
.59198 .12693 L
.59206 .14414 L
.59214 .14414 L
.59222 .14414 L
.5923 .14414 L
.59238 .14414 L
.59246 .14414 L
.59254 .14414 L
.59262 .14414 L
.5927 .12456 L
.59278 .11833 L
.59286 .0959 L
.59294 .0959 L
.59302 .08895 L
.5931 .08895 L
.59317 .08895 L
.59325 .14358 L
.59333 .1868 L
.59341 .19852 L
.59349 .19852 L
Mistroke
.59357 .14785 L
.59365 .12831 L
.59373 .16327 L
.59381 .16327 L
.59389 .16327 L
.59397 .16327 L
.59405 .18284 L
.59413 .10755 L
.59421 .10755 L
.59429 .10755 L
.59437 .11359 L
.59444 .1047 L
.59452 .1047 L
.5946 .1047 L
.59468 .10705 L
.59476 .10705 L
.59484 .10711 L
.59492 .12199 L
.595 .12199 L
.59508 .12199 L
.59516 .12199 L
.59524 .12199 L
.59532 .15364 L
.5954 .16481 L
.59548 .20825 L
.59556 .20357 L
.59563 .20357 L
.59571 .20357 L
.59579 .2415 L
.59587 .22428 L
.59595 .19931 L
.59603 .20965 L
.59611 .20965 L
.59619 .1686 L
.59627 .1686 L
.59635 .16221 L
.59643 .16221 L
.59651 .14676 L
.59659 .11978 L
.59667 .11978 L
.59675 .11971 L
.59683 .14132 L
.5969 .14132 L
.59698 .14132 L
.59706 .14132 L
.59714 .14132 L
.59722 .14132 L
.5973 .14132 L
.59738 .1611 L
.59746 .19081 L
Mistroke
.59754 .18718 L
.59762 .2194 L
.5977 .2194 L
.59778 .2194 L
.59786 .22135 L
.59794 .242 L
.59802 .20623 L
.5981 .20623 L
.59817 .20623 L
.59825 .20623 L
.59833 .209 L
.59841 .21739 L
.59849 .2282 L
.59857 .2282 L
.59865 .2282 L
.59873 .2282 L
.59881 .2282 L
.59889 .24495 L
.59897 .25388 L
.59905 .25388 L
.59913 .25388 L
.59921 .30119 L
.59929 .27914 L
.59937 .27616 L
.59944 .27616 L
.59952 .27616 L
.5996 .27616 L
.59968 .27012 L
.59976 .2685 L
.59984 .27337 L
.59992 .27337 L
.6 .27337 L
.60008 .27594 L
.60016 .28268 L
.60024 .28965 L
.60032 .28965 L
.6004 .28965 L
.60048 .31091 L
.60056 .32864 L
.60063 .32931 L
.60071 .32931 L
.60079 .32868 L
.60087 .32868 L
.60095 .32868 L
.60103 .34454 L
.60111 .34454 L
.60119 .34454 L
.60127 .34454 L
.60135 .33762 L
.60143 .30214 L
Mistroke
.60151 .25919 L
.60159 .25919 L
.60167 .25919 L
.60175 .25919 L
.60183 .23982 L
.6019 .23982 L
.60198 .25445 L
.60206 .222 L
.60214 .222 L
.60222 .222 L
.6023 .222 L
.60238 .22959 L
.60246 .22959 L
.60254 .17888 L
.60262 .12681 L
.6027 .12681 L
.60278 .12681 L
.60286 .105 L
.60294 .09096 L
.60302 .09096 L
.6031 .09096 L
.60317 .09096 L
.60325 .09354 L
.60333 .09644 L
.60341 .09644 L
.60349 .09644 L
.60357 .09644 L
.60365 .09644 L
.60373 .06631 L
.60381 .0732 L
.60389 .0732 L
.60397 .0732 L
.60405 .0732 L
.60413 .0732 L
.60421 .0732 L
.60429 .0732 L
.60437 .0732 L
.60444 .0732 L
.60452 .05501 L
.6046 .05501 L
.60468 .09053 L
.60476 .07233 L
.60484 .06808 L
.60492 .06808 L
.605 .07403 L
.60508 .06454 L
.60516 .06454 L
.60524 .09441 L
.60532 .09441 L
.6054 .07368 L
Mistroke
.60548 .10415 L
.60556 .10333 L
.60563 .09157 L
.60571 .0966 L
.60579 .0966 L
.60587 .06503 L
.60595 .06503 L
.60603 .06619 L
.60611 .0527 L
.60619 .0527 L
.60627 .0595 L
.60635 .0595 L
.60643 .08295 L
.60651 .09619 L
.60659 .11986 L
.60667 .11986 L
.60675 .07292 L
.60683 .07292 L
.6069 .07292 L
.60698 .07292 L
.60706 .07292 L
.60714 .07292 L
.60722 .05449 L
.6073 .05462 L
.60738 .04194 L
.60746 .0566 L
.60754 .0566 L
.60762 .0566 L
.6077 .04422 L
.60778 .04422 L
.60786 .04422 L
.60794 .04422 L
.60802 .04883 L
.6081 .05212 L
.60817 .06675 L
.60825 .06675 L
.60833 .05632 L
.60841 .06992 L
.60849 .06992 L
.60857 .06992 L
.60865 .0734 L
.60873 .06545 L
.60881 .06545 L
.60889 .06545 L
.60897 .05111 L
.60905 .05111 L
.60913 .06433 L
.60921 .06433 L
.60929 .08867 L
.60937 .05791 L
Mistroke
.60944 .05791 L
.60952 .05791 L
.6096 .05272 L
.60968 .05907 L
.60976 .08227 L
.60984 .08227 L
.60992 .08227 L
.61 .12754 L
.61008 .12754 L
.61016 .17441 L
.61024 .17441 L
.61032 .1826 L
.6104 .1826 L
.61048 .1826 L
.61056 .1826 L
.61063 .1826 L
.61071 .1826 L
.61079 .1826 L
.61087 .1826 L
.61095 .1826 L
.61103 .25218 L
.61111 .25218 L
.61119 .25218 L
.61127 .25218 L
.61135 .2188 L
.61143 .17857 L
.61151 .17857 L
.61159 .1579 L
.61167 .1263 L
.61175 .1263 L
.61183 .1263 L
.6119 .1263 L
.61198 .11854 L
.61206 .11854 L
.61214 .11102 L
.61222 .08708 L
.6123 .10274 L
.61238 .10274 L
.61246 .14117 L
.61254 .14117 L
.61262 .1385 L
.6127 .13792 L
.61278 .12064 L
.61286 .12064 L
.61294 .11617 L
.61302 .13141 L
.6131 .13141 L
.61317 .13141 L
.61325 .13141 L
.61333 .15132 L
Mistroke
.61341 .15156 L
.61349 .15156 L
.61357 .17211 L
.61365 .16654 L
.61373 .16654 L
.61381 .1656 L
.61389 .1656 L
.61397 .16844 L
.61405 .1786 L
.61413 .1786 L
.61421 .1786 L
.61429 .19466 L
.61437 .15412 L
.61444 .15412 L
.61452 .16545 L
.6146 .1741 L
.61468 .16404 L
.61476 .16404 L
.61484 .16404 L
.61492 .16404 L
.615 .15239 L
.61508 .15239 L
.61516 .15239 L
.61524 .15239 L
.61532 .15239 L
.6154 .15239 L
.61548 .15239 L
.61556 .15269 L
.61563 .15269 L
.61571 .15269 L
.61579 .15269 L
.61587 .15269 L
.61595 .18781 L
.61603 .12953 L
.61611 .12953 L
.61619 .12953 L
.61627 .12953 L
.61635 .20002 L
.61643 .19721 L
.61651 .19721 L
.61659 .18906 L
.61667 .1725 L
.61675 .19006 L
.61683 .19006 L
.6169 .19006 L
.61698 .2036 L
.61706 .17576 L
.61714 .17576 L
.61722 .17576 L
.6173 .17576 L
Mistroke
.61738 .15913 L
.61746 .13328 L
.61754 .13328 L
.61762 .10889 L
.6177 .10889 L
.61778 .13345 L
.61786 .13914 L
.61794 .13914 L
.61802 .10082 L
.6181 .10082 L
.61817 .10038 L
.61825 .12456 L
.61833 .13917 L
.61841 .10806 L
.61849 .10806 L
.61857 .10806 L
.61865 .12814 L
.61873 .12814 L
.61881 .13549 L
.61889 .13549 L
.61897 .15903 L
.61905 .13401 L
.61913 .11068 L
.61921 .11068 L
.61929 .11068 L
.61937 .09372 L
.61944 .10072 L
.61952 .10072 L
.6196 .11603 L
.61968 .10448 L
.61976 .10448 L
.61984 .1103 L
.61992 .10861 L
.62 .10861 L
.62008 .10861 L
.62016 .09713 L
.62024 .09713 L
.62032 .09713 L
.6204 .06028 L
.62048 .06028 L
.62056 .0559 L
.62063 .04413 L
.62071 .04413 L
.62079 .04413 L
.62087 .04342 L
.62095 .04342 L
.62103 .04342 L
.62111 .04342 L
.62119 .04042 L
.62127 .04108 L
Mistroke
.62135 .04108 L
.62143 .04108 L
.62151 .04108 L
.62159 .06237 L
.62167 .06237 L
.62175 .06237 L
.62183 .06237 L
.6219 .06237 L
.62198 .06237 L
.62206 .06187 L
.62214 .06187 L
.62222 .06187 L
.6223 .06187 L
.62238 .06187 L
.62246 .08355 L
.62254 .08355 L
.62262 .0868 L
.6227 .0868 L
.62278 .0868 L
.62286 .0868 L
.62294 .12268 L
.62302 .13302 L
.6231 .13302 L
.62317 .16229 L
.62325 .18101 L
.62333 .18101 L
.62341 .18101 L
.62349 .18101 L
.62357 .21516 L
.62365 .21516 L
.62373 .21516 L
.62381 .18689 L
.62389 .17635 L
.62397 .19902 L
.62405 .19902 L
.62413 .19902 L
.62421 .19902 L
.62429 .19902 L
.62437 .19902 L
.62444 .19902 L
.62452 .18514 L
.6246 .21283 L
.62468 .21283 L
.62476 .21283 L
.62484 .10082 L
.62492 .10082 L
.625 .10082 L
.62508 .10082 L
.62516 .10082 L
.62524 .10082 L
Mistroke
.62532 .14009 L
.6254 .14009 L
.62548 .13844 L
.62556 .13844 L
.62563 .12551 L
.62571 .12551 L
.62579 .12551 L
.62587 .12551 L
.62595 .12551 L
.62603 .12551 L
.62611 .12551 L
.62619 .12551 L
.62627 .06422 L
.62635 .06238 L
.62643 .06238 L
.62651 .06238 L
.62659 .06238 L
.62667 .08056 L
.62675 .08056 L
.62683 .06774 L
.6269 .05781 L
.62698 .05781 L
.62706 .05781 L
.62714 .05781 L
.62722 .05781 L
.6273 .05781 L
.62738 .05781 L
.62746 .05781 L
.62754 .05781 L
.62762 .05781 L
.6277 .081 L
.62778 .14701 L
.62786 .14701 L
.62794 .14701 L
.62802 .12038 L
.6281 .11797 L
.62817 .06219 L
.62825 .06219 L
.62833 .06219 L
.62841 .06219 L
.62849 .06219 L
.62857 .05915 L
.62865 .05195 L
.62873 .05363 L
.62881 .05363 L
.62889 .05363 L
.62897 .08435 L
.62905 .08435 L
.62913 .08435 L
.62921 .08653 L
Mistroke
.62929 .08653 L
.62937 .08653 L
.62944 .08653 L
.62952 .08653 L
.6296 .08653 L
.62968 .08653 L
.62976 .08653 L
.62984 .06435 L
.62992 .06435 L
.63 .06435 L
.63008 .06435 L
.63016 .06435 L
.63024 .05759 L
.63032 .05759 L
.6304 .05857 L
.63048 .05857 L
.63056 .05857 L
.63063 .05804 L
.63071 .05804 L
.63079 .05365 L
.63087 .05365 L
.63095 .05365 L
.63103 .05365 L
.63111 .12389 L
.63119 .12389 L
.63127 .12389 L
.63135 .12389 L
.63143 .12389 L
.63151 .12389 L
.63159 .13849 L
.63167 .13151 L
.63175 .13151 L
.63183 .13151 L
.6319 .08444 L
.63198 .08444 L
.63206 .09347 L
.63214 .09347 L
.63222 .10421 L
.6323 .13725 L
.63238 .14106 L
.63246 .14106 L
.63254 .09125 L
.63262 .09125 L
.6327 .07985 L
.63278 .0629 L
.63286 .0629 L
.63294 .0629 L
.63302 .0629 L
.6331 .06304 L
.63317 .04695 L
Mistroke
.63325 .04695 L
.63333 .03189 L
.63341 .09039 L
.63349 .08623 L
.63357 .08623 L
.63365 .08623 L
.63373 .12645 L
.63381 .12645 L
.63389 .12645 L
.63397 .12645 L
.63405 .11912 L
.63413 .08828 L
.63421 .08828 L
.63429 .08828 L
.63437 .08385 L
.63444 .07333 L
.63452 .10728 L
.6346 .10728 L
.63468 .10728 L
.63476 .103 L
.63484 .13298 L
.63492 .13298 L
.635 .13298 L
.63508 .10949 L
.63516 .10949 L
.63524 .10949 L
.63532 .10949 L
.6354 .10949 L
.63548 .10949 L
.63556 .08103 L
.63563 .08103 L
.63571 .08103 L
.63579 .08754 L
.63587 .06235 L
.63595 .06235 L
.63603 .07237 L
.63611 .07237 L
.63619 .07237 L
.63627 .09334 L
.63635 .09334 L
.63643 .09334 L
.63651 .09334 L
.63659 .09334 L
.63667 .09334 L
.63675 .09334 L
.63683 .09334 L
.6369 .07085 L
.63698 .07085 L
.63706 .07085 L
.63714 .07085 L
Mistroke
.63722 .08798 L
.6373 .08798 L
.63738 .13635 L
.63746 .13635 L
.63754 .13467 L
.63762 .14897 L
.6377 .16559 L
.63778 .16559 L
.63786 .16559 L
.63794 .16559 L
.63802 .18001 L
.6381 .18001 L
.63817 .11915 L
.63825 .11915 L
.63833 .15027 L
.63841 .15333 L
.63849 .15333 L
.63857 .15333 L
.63865 .11075 L
.63873 .11075 L
.63881 .11075 L
.63889 .11075 L
.63897 .10132 L
.63905 .09844 L
.63913 .08528 L
.63921 .08528 L
.63929 .06594 L
.63937 .06594 L
.63944 .06594 L
.63952 .06594 L
.6396 .10338 L
.63968 .12931 L
.63976 .12931 L
.63984 .12931 L
.63992 .12931 L
.64 .12818 L
.64008 .12466 L
.64016 .16508 L
.64024 .16508 L
.64032 .16508 L
.6404 .20519 L
.64048 .20519 L
.64056 .20519 L
.64063 .20519 L
.64071 .20519 L
.64079 .20402 L
.64087 .20402 L
.64095 .17814 L
.64103 .17814 L
.64111 .17814 L
Mistroke
.64119 .21856 L
.64127 .19468 L
.64135 .19468 L
.64143 .18761 L
.64151 .17454 L
.64159 .17024 L
.64167 .17024 L
.64175 .17024 L
.64183 .16877 L
.6419 .16877 L
.64198 .18249 L
.64206 .18249 L
.64214 .19786 L
.64222 .19786 L
.6423 .15492 L
.64238 .15492 L
.64246 .12111 L
.64254 .14196 L
.64262 .147 L
.6427 .147 L
.64278 .15746 L
.64286 .15746 L
.64294 .20306 L
.64302 .20306 L
.6431 .20306 L
.64317 .20306 L
.64325 .20306 L
.64333 .20306 L
.64341 .20306 L
.64349 .20306 L
.64357 .20272 L
.64365 .20272 L
.64373 .20272 L
.64381 .20272 L
.64389 .20272 L
.64397 .20163 L
.64405 .20163 L
.64413 .20163 L
.64421 .20163 L
.64429 .20163 L
.64437 .19239 L
.64444 .19239 L
.64452 .19239 L
.6446 .19239 L
.64468 .19239 L
.64476 .19239 L
.64484 .18115 L
.64492 .18115 L
.645 .18115 L
.64508 .18115 L
Mistroke
.64516 .18115 L
.64524 .18115 L
.64532 .16024 L
.6454 .16024 L
.64548 .14505 L
.64556 .14505 L
.64563 .14505 L
.64571 .14505 L
.64579 .14505 L
.64587 .14505 L
.64595 .12632 L
.64603 .1137 L
.64611 .10621 L
.64619 .10621 L
.64627 .10621 L
.64635 .10621 L
.64643 .10621 L
.64651 .11326 L
.64659 .11326 L
.64667 .10686 L
.64675 .11022 L
.64683 .11022 L
.6469 .11022 L
.64698 .11022 L
.64706 .11022 L
.64714 .1088 L
.64722 .1088 L
.6473 .1088 L
.64738 .103 L
.64746 .103 L
.64754 .103 L
.64762 .103 L
.6477 .103 L
.64778 .103 L
.64786 .103 L
.64794 .19786 L
.64802 .19786 L
.6481 .19786 L
.64817 .19786 L
.64825 .19786 L
.64833 .14258 L
.64841 .14258 L
.64849 .14258 L
.64857 .14258 L
.64865 .14258 L
.64873 .13039 L
.64881 .13039 L
.64889 .13039 L
.64897 .13039 L
.64905 .13039 L
Mistroke
.64913 .14173 L
.64921 .14173 L
.64929 .14438 L
.64937 .17171 L
.64944 .17171 L
.64952 .18478 L
.6496 .17495 L
.64968 .17495 L
.64976 .17495 L
.64984 .17495 L
.64992 .17495 L
.65 .17495 L
.65008 .17495 L
.65016 .17495 L
.65024 .17495 L
.65032 .17711 L
.6504 .14567 L
.65048 .13824 L
.65056 .14458 L
.65063 .14458 L
.65071 .14458 L
.65079 .14458 L
.65087 .14017 L
.65095 .15456 L
.65103 .12571 L
.65111 .11902 L
.65119 .11902 L
.65127 .14756 L
.65135 .14756 L
.65143 .13942 L
.65151 .13942 L
.65159 .15123 L
.65167 .14567 L
.65175 .12812 L
.65183 .07981 L
.6519 .07377 L
.65198 .09177 L
.65206 .12037 L
.65214 .12037 L
.65222 .12037 L
.6523 .12037 L
.65238 .12037 L
.65246 .12037 L
.65254 .12037 L
.65262 .13621 L
.6527 .13493 L
.65278 .09316 L
.65286 .09316 L
.65294 .09316 L
.65302 .09316 L
Mistroke
.6531 .1321 L
.65317 .1321 L
.65325 .15239 L
.65333 .15702 L
.65341 .15702 L
.65349 .15702 L
.65357 .13349 L
.65365 .13626 L
.65373 .17067 L
.65381 .17067 L
.65389 .17067 L
.65397 .14364 L
.65405 .14364 L
.65413 .1484 L
.65421 .1484 L
.65429 .14772 L
.65437 .10993 L
.65444 .16194 L
.65452 .16194 L
.6546 .12002 L
.65468 .12002 L
.65476 .12002 L
.65484 .12002 L
.65492 .12002 L
.655 .08133 L
.65508 .08133 L
.65516 .09186 L
.65524 .07141 L
.65532 .07141 L
.6554 .05701 L
.65548 .09264 L
.65556 .09264 L
.65563 .09119 L
.65571 .10543 L
.65579 .10543 L
.65587 .11259 L
.65595 .11259 L
.65603 .11259 L
.65611 .11259 L
.65619 .11259 L
.65627 .11259 L
.65635 .11259 L
.65643 .14193 L
.65651 .14193 L
.65659 .14193 L
.65667 .13768 L
.65675 .15981 L
.65683 .15981 L
.6569 .15981 L
.65698 .15981 L
Mistroke
.65706 .11353 L
.65714 .11353 L
.65722 .11353 L
.6573 .13964 L
.65738 .1301 L
.65746 .12622 L
.65754 .12622 L
.65762 .12622 L
.6577 .12622 L
.65778 .16449 L
.65786 .16955 L
.65794 .17906 L
.65802 .22375 L
.6581 .22375 L
.65817 .22375 L
.65825 .2214 L
.65833 .2214 L
.65841 .20962 L
.65849 .20962 L
.65857 .20205 L
.65865 .19268 L
.65873 .19268 L
.65881 .19268 L
.65889 .19268 L
.65897 .18855 L
.65905 .19302 L
.65913 .21062 L
.65921 .21178 L
.65929 .18223 L
.65937 .16436 L
.65944 .16436 L
.65952 .17342 L
.6596 .17342 L
.65968 .17342 L
.65976 .17342 L
.65984 .17342 L
.65992 .15593 L
.66 .15593 L
.66008 .12052 L
.66016 .12052 L
.66024 .12052 L
.66032 .12052 L
.6604 .12052 L
.66048 .12052 L
.66056 .12052 L
.66063 .12205 L
.66071 .12205 L
.66079 .12205 L
.66087 .1149 L
.66095 .1149 L
Mistroke
.66103 .1149 L
.66111 .11292 L
.66119 .11292 L
.66127 .08685 L
.66135 .08685 L
.66143 .08685 L
.66151 .08685 L
.66159 .12089 L
.66167 .10509 L
.66175 .12716 L
.66183 .09357 L
.6619 .08496 L
.66198 .0769 L
.66206 .0769 L
.66214 .0769 L
.66222 .0769 L
.6623 .08131 L
.66238 .08131 L
.66246 .08131 L
.66254 .08131 L
.66262 .09771 L
.6627 .08564 L
.66278 .08564 L
.66286 .08564 L
.66294 .08778 L
.66302 .11109 L
.6631 .12323 L
.66317 .12323 L
.66325 .12323 L
.66333 .12323 L
.66341 .12323 L
.66349 .12323 L
.66357 .12323 L
.66365 .12323 L
.66373 .12323 L
.66381 .12323 L
.66389 .12323 L
.66397 .11988 L
.66405 .12909 L
.66413 .12909 L
.66421 .22212 L
.66429 .21015 L
.66437 .21015 L
.66444 .21015 L
.66452 .21015 L
.6646 .21015 L
.66468 .19573 L
.66476 .19573 L
.66484 .22498 L
.66492 .22498 L
Mistroke
.665 .21387 L
.66508 .21387 L
.66516 .13145 L
.66524 .13145 L
.66532 .13145 L
.6654 .11324 L
.66548 .11324 L
.66556 .11324 L
.66563 .11324 L
.66571 .17088 L
.66579 .17088 L
.66587 .17088 L
.66595 .17088 L
.66603 .10662 L
.66611 .10662 L
.66619 .14008 L
.66627 .14827 L
.66635 .14827 L
.66643 .14569 L
.66651 .14569 L
.66659 .14569 L
.66667 .12442 L
.66675 .13024 L
.66683 .13024 L
.6669 .13024 L
.66698 .18028 L
.66706 .16957 L
.66714 .16083 L
.66722 .14897 L
.6673 .10889 L
.66738 .10889 L
.66746 .10889 L
.66754 .10889 L
.66762 .10889 L
.6677 .10641 L
.66778 .10641 L
.66786 .12067 L
.66794 .1393 L
.66802 .1393 L
.6681 .1042 L
.66817 .10416 L
.66825 .10416 L
.66833 .10416 L
.66841 .10416 L
.66849 .10416 L
.66857 .10416 L
.66865 .11039 L
.66873 .11039 L
.66881 .12164 L
.66889 .11798 L
Mistroke
.66897 .11798 L
.66905 .14503 L
.66913 .13919 L
.66921 .13919 L
.66929 .14946 L
.66937 .14946 L
.66944 .14946 L
.66952 .16568 L
.6696 .12618 L
.66968 .18468 L
.66976 .18468 L
.66984 .18468 L
.66992 .20816 L
.67 .19763 L
.67008 .19763 L
.67016 .19763 L
.67024 .20064 L
.67032 .18263 L
.6704 .18263 L
.67048 .21259 L
.67056 .21259 L
.67063 .21259 L
.67071 .21259 L
.67079 .21847 L
.67087 .20546 L
.67095 .16576 L
.67103 .16577 L
.67111 .16577 L
.67119 .19157 L
.67127 .19157 L
.67135 .19157 L
.67143 .19157 L
.67151 .19157 L
.67159 .16378 L
.67167 .16378 L
.67175 .15267 L
.67183 .15267 L
.6719 .19794 L
.67198 .18072 L
.67206 .18072 L
.67214 .12343 L
.67222 .14492 L
.6723 .14333 L
.67238 .14333 L
.67246 .14333 L
.67254 .19412 L
.67262 .19412 L
.6727 .19412 L
.67278 .2033 L
.67286 .2033 L
Mistroke
.67294 .14052 L
.67302 .1312 L
.6731 .1312 L
.67317 .1312 L
.67325 .1312 L
.67333 .16822 L
.67341 .16822 L
.67349 .16044 L
.67357 .18293 L
.67365 .15994 L
.67373 .15994 L
.67381 .15994 L
.67389 .15994 L
.67397 .15994 L
.67405 .21864 L
.67413 .21864 L
.67421 .21864 L
.67429 .21864 L
.67437 .21864 L
.67444 .21864 L
.67452 .21864 L
.6746 .21477 L
.67468 .21477 L
.67476 .21477 L
.67484 .21721 L
.67492 .21223 L
.675 .2416 L
.67508 .21307 L
.67516 .21307 L
.67524 .21636 L
.67532 .23082 L
.6754 .24847 L
.67548 .20786 L
.67556 .20786 L
.67563 .18095 L
.67571 .18022 L
.67579 .18022 L
.67587 .19965 L
.67595 .19965 L
.67603 .19965 L
.67611 .21485 L
.67619 .21485 L
.67627 .21485 L
.67635 .21485 L
.67643 .21485 L
.67651 .21485 L
.67659 .21485 L
.67667 .21485 L
.67675 .21485 L
.67683 .21485 L
Mistroke
.6769 .2002 L
.67698 .22302 L
.67706 .22302 L
.67714 .22302 L
.67722 .22302 L
.6773 .22302 L
.67738 .22302 L
.67746 .19609 L
.67754 .19609 L
.67762 .19609 L
.6777 .21871 L
.67778 .21871 L
.67786 .21871 L
.67794 .2292 L
.67802 .22758 L
.6781 .22758 L
.67817 .22809 L
.67825 .22379 L
.67833 .22379 L
.67841 .22442 L
.67849 .22442 L
.67857 .22442 L
.67865 .21465 L
.67873 .23374 L
.67881 .23374 L
.67889 .23374 L
.67897 .23374 L
.67905 .24695 L
.67913 .24695 L
.67921 .24695 L
.67929 .24695 L
.67937 .24695 L
.67944 .24695 L
.67952 .24695 L
.6796 .24695 L
.67968 .24223 L
.67976 .24223 L
.67984 .21745 L
.67992 .24855 L
.68 .20515 L
.68008 .19026 L
.68016 .19026 L
.68024 .19026 L
.68032 .19026 L
.6804 .21007 L
.68048 .21007 L
.68056 .21007 L
.68063 .21007 L
.68071 .21007 L
.68079 .21007 L
Mistroke
.68087 .21007 L
.68095 .20456 L
.68103 .19766 L
.68111 .19766 L
.68119 .19766 L
.68127 .19766 L
.68135 .22164 L
.68143 .22164 L
.68151 .31257 L
.68159 .31257 L
.68167 .31257 L
.68175 .24445 L
.68183 .2054 L
.6819 .14774 L
.68198 .14774 L
.68206 .14774 L
.68214 .14774 L
.68222 .1472 L
.6823 .14082 L
.68238 .15727 L
.68246 .13142 L
.68254 .11424 L
.68262 .11424 L
.6827 .09897 L
.68278 .09897 L
.68286 .08634 L
.68294 .08634 L
.68302 .08634 L
.6831 .07262 L
.68317 .08518 L
.68325 .0664 L
.68333 .08891 L
.68341 .08891 L
.68349 .09318 L
.68357 .09318 L
.68365 .14267 L
.68373 .17417 L
.68381 .17523 L
.68389 .17523 L
.68397 .17879 L
.68405 .17879 L
.68413 .17879 L
.68421 .17879 L
.68429 .17879 L
.68437 .17879 L
.68444 .17879 L
.68452 .19387 L
.6846 .19387 L
.68468 .17297 L
.68476 .18449 L
Mistroke
.68484 .18449 L
.68492 .18449 L
.685 .1444 L
.68508 .1444 L
.68516 .1444 L
.68524 .122 L
.68532 .122 L
.6854 .10761 L
.68548 .06389 L
.68556 .07503 L
.68563 .07503 L
.68571 .09936 L
.68579 .10386 L
.68587 .0811 L
.68595 .06668 L
.68603 .06668 L
.68611 .06668 L
.68619 .06668 L
.68627 .06668 L
.68635 .06668 L
.68643 .09645 L
.68651 .13856 L
.68659 .13856 L
.68667 .12148 L
.68675 .13557 L
.68683 .13557 L
.6869 .15653 L
.68698 .12094 L
.68706 .12094 L
.68714 .13366 L
.68722 .13366 L
.6873 .10566 L
.68738 .10566 L
.68746 .10566 L
.68754 .13313 L
.68762 .13313 L
.6877 .13313 L
.68778 .18394 L
.68786 .18394 L
.68794 .18394 L
.68802 .17514 L
.6881 .19357 L
.68817 .19357 L
.68825 .15197 L
.68833 .16395 L
.68841 .16395 L
.68849 .11476 L
.68857 .11465 L
.68865 .10315 L
.68873 .13478 L
Mistroke
.68881 .13478 L
.68889 .13478 L
.68897 .13478 L
.68905 .13478 L
.68913 .10179 L
.68921 .08151 L
.68929 .08151 L
.68937 .07591 L
.68944 .07427 L
.68952 .11374 L
.6896 .10518 L
.68968 .14303 L
.68976 .14303 L
.68984 .14303 L
.68992 .14694 L
.69 .1208 L
.69008 .1208 L
.69016 .09717 L
.69024 .0671 L
.69032 .06261 L
.6904 .06261 L
.69048 .11586 L
.69056 .11586 L
.69063 .11586 L
.69071 .11586 L
.69079 .11903 L
.69087 .1181 L
.69095 .1181 L
.69103 .1181 L
.69111 .1181 L
.69119 .1181 L
.69127 .17727 L
.69135 .17727 L
.69143 .12643 L
.69151 .12643 L
.69159 .11367 L
.69167 .12824 L
.69175 .10672 L
.69183 .1153 L
.6919 .1153 L
.69198 .13278 L
.69206 .13278 L
.69214 .13278 L
.69222 .10322 L
.6923 .092 L
.69238 .092 L
.69246 .08609 L
.69254 .1092 L
.69262 .1092 L
.6927 .1092 L
Mistroke
.69278 .1092 L
.69286 .1092 L
.69294 .09693 L
.69302 .13375 L
.6931 .09176 L
.69317 .09176 L
.69325 .09176 L
.69333 .09369 L
.69341 .1214 L
.69349 .1214 L
.69357 .1214 L
.69365 .1214 L
.69373 .1214 L
.69381 .1214 L
.69389 .1214 L
.69397 .1214 L
.69405 .1214 L
.69413 .1214 L
.69421 .1214 L
.69429 .1214 L
.69437 .1214 L
.69444 .1214 L
.69452 .12587 L
.6946 .12203 L
.69468 .12203 L
.69476 .12203 L
.69484 .12203 L
.69492 .12203 L
.695 .12203 L
.69508 .12203 L
.69516 .0759 L
.69524 .09572 L
.69532 .11459 L
.6954 .11506 L
.69548 .12006 L
.69556 .12544 L
.69563 .17151 L
.69571 .20883 L
.69579 .20883 L
.69587 .20125 L
.69595 .20125 L
.69603 .20125 L
.69611 .1872 L
.69619 .1872 L
.69627 .1797 L
.69635 .14653 L
.69643 .14213 L
.69651 .14628 L
.69659 .16077 L
.69667 .16077 L
Mistroke
.69675 .20775 L
.69683 .17866 L
.6969 .17866 L
.69698 .17866 L
.69706 .20445 L
.69714 .20445 L
.69722 .17232 L
.6973 .18446 L
.69738 .18446 L
.69746 .20411 L
.69754 .19861 L
.69762 .17321 L
.6977 .17321 L
.69778 .1537 L
.69786 .20509 L
.69794 .25995 L
.69802 .24583 L
.6981 .19565 L
.69817 .19571 L
.69825 .19571 L
.69833 .24378 L
.69841 .24378 L
.69849 .26699 L
.69857 .26699 L
.69865 .26699 L
.69873 .26699 L
.69881 .28713 L
.69889 .26221 L
.69897 .2391 L
.69905 .2391 L
.69913 .2391 L
.69921 .2391 L
.69929 .2391 L
.69937 .2391 L
.69944 .21721 L
.69952 .22582 L
.6996 .22582 L
.69968 .2227 L
.69976 .2227 L
.69984 .22773 L
.69992 .28315 L
.7 .28315 L
.70008 .28315 L
.70016 .28315 L
.70024 .27559 L
.70032 .29922 L
.7004 .29922 L
.70048 .27416 L
.70056 .26827 L
.70063 .2478 L
Mistroke
.70071 .2478 L
.70079 .2348 L
.70087 .2348 L
.70095 .2348 L
.70103 .2309 L
.70111 .19091 L
.70119 .19091 L
.70127 .17377 L
.70135 .18194 L
.70143 .19031 L
.70151 .19031 L
.70159 .19031 L
.70167 .19031 L
.70175 .19031 L
.70183 .1976 L
.7019 .1976 L
.70198 .1976 L
.70206 .15986 L
.70214 .17304 L
.70222 .17304 L
.7023 .22258 L
.70238 .22258 L
.70246 .22258 L
.70254 .20994 L
.70262 .20994 L
.7027 .17025 L
.70278 .14838 L
.70286 .14838 L
.70294 .10528 L
.70302 .11278 L
.7031 .11278 L
.70317 .1006 L
.70325 .1006 L
.70333 .1006 L
.70341 .1006 L
.70349 .1006 L
.70357 .1006 L
.70365 .11222 L
.70373 .11222 L
.70381 .11222 L
.70389 .11222 L
.70397 .10715 L
.70405 .09176 L
.70413 .10399 L
.70421 .16055 L
.70429 .12967 L
.70437 .12967 L
.70444 .13923 L
.70452 .13923 L
.7046 .13923 L
Mistroke
.70468 .13923 L
.70476 .11762 L
.70484 .09925 L
.70492 .10195 L
.705 .10764 L
.70508 .11971 L
.70516 .11971 L
.70524 .11971 L
.70532 .12031 L
.7054 .11456 L
.70548 .09373 L
.70556 .09126 L
.70563 .09126 L
.70571 .09126 L
.70579 .09126 L
.70587 .09126 L
.70595 .10754 L
.70603 .11053 L
.70611 .12112 L
.70619 .12112 L
.70627 .12112 L
.70635 .13278 L
.70643 .13278 L
.70651 .12897 L
.70659 .0683 L
.70667 .08443 L
.70675 .08658 L
.70683 .07299 L
.7069 .07299 L
.70698 .06251 L
.70706 .06251 L
.70714 .11638 L
.70722 .11638 L
.7073 .11638 L
.70738 .10273 L
.70746 .10656 L
.70754 .10656 L
.70762 .10656 L
.7077 .07462 L
.70778 .06743 L
.70786 .07375 L
.70794 .07375 L
.70802 .07832 L
.7081 .07832 L
.70817 .10494 L
.70825 .10494 L
.70833 .10494 L
.70841 .10494 L
.70849 .10494 L
.70857 .09429 L
Mistroke
.70865 .09429 L
.70873 .09429 L
.70881 .09429 L
.70889 .11758 L
.70897 .10302 L
.70905 .10522 L
.70913 .11461 L
.70921 .1583 L
.70929 .13211 L
.70937 .13211 L
.70944 .13211 L
.70952 .13211 L
.7096 .10998 L
.70968 .10998 L
.70976 .10998 L
.70984 .15634 L
.70992 .15634 L
.71 .15634 L
.71008 .19662 L
.71016 .19662 L
.71024 .19662 L
.71032 .19662 L
.7104 .1922 L
.71048 .1922 L
.71056 .1922 L
.71063 .1922 L
.71071 .1922 L
.71079 .1922 L
.71087 .1922 L
.71095 .13042 L
.71103 .13042 L
.71111 .11368 L
.71119 .11368 L
.71127 .11394 L
.71135 .1128 L
.71143 .14296 L
.71151 .16142 L
.71159 .16142 L
.71167 .16142 L
.71175 .17846 L
.71183 .17846 L
.7119 .17846 L
.71198 .21754 L
.71206 .19325 L
.71214 .19325 L
.71222 .19325 L
.7123 .19325 L
.71238 .21688 L
.71246 .21688 L
.71254 .21688 L
Mistroke
.71262 .21688 L
.7127 .21688 L
.71278 .20599 L
.71286 .20599 L
.71294 .19888 L
.71302 .19888 L
.7131 .19888 L
.71317 .18996 L
.71325 .18996 L
.71333 .20135 L
.71341 .19518 L
.71349 .20632 L
.71357 .18104 L
.71365 .18104 L
.71373 .18104 L
.71381 .18104 L
.71389 .18104 L
.71397 .18104 L
.71405 .18122 L
.71413 .18122 L
.71421 .19587 L
.71429 .22082 L
.71437 .22082 L
.71444 .22082 L
.71452 .22082 L
.7146 .28561 L
.71468 .28561 L
.71476 .28296 L
.71484 .28296 L
.71492 .28296 L
.715 .28296 L
.71508 .29857 L
.71516 .29857 L
.71524 .285 L
.71532 .285 L
.7154 .285 L
.71548 .285 L
.71556 .2583 L
.71563 .31913 L
.71571 .34094 L
.71579 .34094 L
.71587 .34094 L
.71595 .31227 L
.71603 .35461 L
.71611 .35461 L
.71619 .35882 L
.71627 .35882 L
.71635 .35882 L
.71643 .35033 L
.71651 .37184 L
Mistroke
.71659 .35323 L
.71667 .31639 L
.71675 .31639 L
.71683 .29733 L
.7169 .29733 L
.71698 .30851 L
.71706 .31432 L
.71714 .33611 L
.71722 .33611 L
.7173 .33611 L
.71738 .31258 L
.71746 .27077 L
.71754 .27077 L
.71762 .29367 L
.7177 .29367 L
.71778 .29367 L
.71786 .28658 L
.71794 .27986 L
.71802 .26832 L
.7181 .26832 L
.71817 .25358 L
.71825 .25358 L
.71833 .25358 L
.71841 .25358 L
.71849 .25358 L
.71857 .25358 L
.71865 .25358 L
.71873 .24866 L
.71881 .24866 L
.71889 .26978 L
.71897 .26978 L
.71905 .24049 L
.71913 .24049 L
.71921 .24049 L
.71929 .24049 L
.71937 .22486 L
.71944 .22364 L
.71952 .23802 L
.7196 .21279 L
.71968 .21279 L
.71976 .21279 L
.71984 .18577 L
.71992 .20171 L
.72 .21658 L
.72008 .21658 L
.72016 .21658 L
.72024 .14854 L
.72032 .14854 L
.7204 .14854 L
.72048 .14854 L
Mistroke
.72056 .11581 L
.72063 .11581 L
.72071 .10914 L
.72079 .10914 L
.72087 .10377 L
.72095 .10539 L
.72103 .13969 L
.72111 .19337 L
.72119 .21416 L
.72127 .24622 L
.72135 .2031 L
.72143 .19578 L
.72151 .18596 L
.72159 .18596 L
.72167 .12949 L
.72175 .12949 L
.72183 .12949 L
.7219 .12949 L
.72198 .12647 L
.72206 .12647 L
.72214 .13304 L
.72222 .16398 L
.7223 .16398 L
.72238 .14927 L
.72246 .14659 L
.72254 .08293 L
.72262 .09169 L
.7227 .09169 L
.72278 .08341 L
.72286 .08341 L
.72294 .04452 L
.72302 .01472 L
.7231 .01472 L
.72317 .02269 L
.72325 .06546 L
.72333 .04323 L
.72341 .07014 L
.72349 .07331 L
.72357 .07331 L
.72365 .0736 L
.72373 .11452 L
.72381 .11452 L
.72389 .11452 L
.72397 .11126 L
.72405 .05116 L
.72413 .05116 L
.72421 .05116 L
.72429 .07824 L
.72437 .07824 L
.72444 .0533 L
Mistroke
.72452 .0533 L
.7246 .0533 L
.72468 .03615 L
.72476 .03615 L
.72484 .03615 L
.72492 .03615 L
.725 .07104 L
.72508 .07104 L
.72516 .07104 L
.72524 .07949 L
.72532 .07949 L
.7254 .07949 L
.72548 .08548 L
.72556 .08548 L
.72563 .08548 L
.72571 .08548 L
.72579 .06976 L
.72587 .06976 L
.72595 .06976 L
.72603 .06976 L
.72611 .06976 L
.72619 .06976 L
.72627 .08858 L
.72635 .08858 L
.72643 .08858 L
.72651 .08858 L
.72659 .08858 L
.72667 .08858 L
.72675 .08129 L
.72683 .09889 L
.7269 .08732 L
.72698 .08732 L
.72706 .08732 L
.72714 .09671 L
.72722 .11614 L
.7273 .11124 L
.72738 .09886 L
.72746 .09373 L
.72754 .08071 L
.72762 .08071 L
.7277 .11375 L
.72778 .14099 L
.72786 .17595 L
.72794 .17595 L
.72802 .12688 L
.7281 .12688 L
.72817 .12688 L
.72825 .12688 L
.72833 .12266 L
.72841 .08663 L
Mistroke
.72849 .10353 L
.72857 .09816 L
.72865 .09816 L
.72873 .09816 L
.72881 .09816 L
.72889 .09816 L
.72897 .10118 L
.72905 .10118 L
.72913 .10118 L
.72921 .10118 L
.72929 .10118 L
.72937 .08416 L
.72944 .08416 L
.72952 .08416 L
.7296 .08416 L
.72968 .08416 L
.72976 .07517 L
.72984 .07517 L
.72992 .05601 L
.73 .0742 L
.73008 .05733 L
.73016 .05733 L
.73024 .05733 L
.73032 .04621 L
.7304 .0412 L
.73048 .0412 L
.73056 .0412 L
.73063 .03113 L
.73071 .03113 L
.73079 .03113 L
.73087 .03113 L
.73095 .02708 L
.73103 .02708 L
.73111 .02708 L
.73119 .02708 L
.73127 .02708 L
.73135 .07099 L
.73143 .07099 L
.73151 .07099 L
.73159 .14422 L
.73167 .14422 L
.73175 .09457 L
.73183 .13045 L
.7319 .2091 L
.73198 .21566 L
.73206 .21566 L
.73214 .21566 L
.73222 .21566 L
.7323 .17629 L
.73238 .17629 L
Mistroke
.73246 .17629 L
.73254 .17629 L
.73262 .17336 L
.7327 .16506 L
.73278 .16506 L
.73286 .16506 L
.73294 .17986 L
.73302 .17986 L
.7331 .17718 L
.73317 .17718 L
.73325 .17718 L
.73333 .21182 L
.73341 .21182 L
.73349 .22236 L
.73357 .16006 L
.73365 .15679 L
.73373 .12555 L
.73381 .12555 L
.73389 .11159 L
.73397 .11159 L
.73405 .11159 L
.73413 .11159 L
.73421 .11159 L
.73429 .05678 L
.73437 .05678 L
.73444 .05678 L
.73452 .09863 L
.7346 .05746 L
.73468 .05746 L
.73476 .0929 L
.73484 .11373 L
.73492 .11373 L
.735 .10728 L
.73508 .10728 L
.73516 .10876 L
.73524 .05848 L
.73532 .06627 L
.7354 .06627 L
.73548 .06627 L
.73556 .07403 L
.73563 .08491 L
.73571 .08491 L
.73579 .08491 L
.73587 .14012 L
.73595 .11031 L
.73603 .11031 L
.73611 .11031 L
.73619 .12491 L
.73627 .12491 L
.73635 .13962 L
Mistroke
.73643 .11487 L
.73651 .08959 L
.73659 .08959 L
.73667 .04992 L
.73675 .04992 L
.73683 .06991 L
.7369 .06991 L
.73698 .06991 L
.73706 .06991 L
.73714 .05171 L
.73722 .06241 L
.7373 .06241 L
.73738 .06241 L
.73746 .06241 L
.73754 .05714 L
.73762 .05714 L
.7377 .05714 L
.73778 .05714 L
.73786 .05714 L
.73794 .13028 L
.73802 .14298 L
.7381 .14298 L
.73817 .14298 L
.73825 .19671 L
.73833 .19671 L
.73841 .19809 L
.73849 .15918 L
.73857 .15918 L
.73865 .15918 L
.73873 .15918 L
.73881 .14496 L
.73889 .14496 L
.73897 .14496 L
.73905 .15173 L
.73913 .12645 L
.73921 .12645 L
.73929 .14886 L
.73937 .16575 L
.73944 .16575 L
.73952 .18931 L
.7396 .19455 L
.73968 .19455 L
.73976 .18124 L
.73984 .15895 L
.73992 .15895 L
.74 .15895 L
.74008 .1946 L
.74016 .1846 L
.74024 .1846 L
.74032 .13939 L
Mistroke
.7404 .15014 L
.74048 .15014 L
.74056 .15014 L
.74063 .15014 L
.74071 .15014 L
.74079 .10716 L
.74087 .10902 L
.74095 .10902 L
.74103 .10902 L
.74111 .12721 L
.74119 .12721 L
.74127 .12721 L
.74135 .12721 L
.74143 .12721 L
.74151 .12721 L
.74159 .15537 L
.74167 .15537 L
.74175 .15537 L
.74183 .15537 L
.7419 .15537 L
.74198 .17914 L
.74206 .20535 L
.74214 .20535 L
.74222 .20535 L
.7423 .24889 L
.74238 .24889 L
.74246 .24889 L
.74254 .30944 L
.74262 .29373 L
.7427 .27757 L
.74278 .27684 L
.74286 .27684 L
.74294 .23998 L
.74302 .18371 L
.7431 .18371 L
.74317 .18371 L
.74325 .18371 L
.74333 .18371 L
.74341 .17427 L
.74349 .1947 L
.74357 .17945 L
.74365 .17945 L
.74373 .17945 L
.74381 .17945 L
.74389 .17854 L
.74397 .17854 L
.74405 .17854 L
.74413 .16332 L
.74421 .15592 L
.74429 .15592 L
Mistroke
.74437 .21049 L
.74444 .19673 L
.74452 .19673 L
.7446 .19673 L
.74468 .19673 L
.74476 .19673 L
.74484 .19673 L
.74492 .19673 L
.745 .13432 L
.74508 .13432 L
.74516 .13432 L
.74524 .13432 L
.74532 .13432 L
.7454 .13432 L
.74548 .13479 L
.74556 .13479 L
.74563 .13479 L
.74571 .13479 L
.74579 .13479 L
.74587 .13479 L
.74595 .10845 L
.74603 .10845 L
.74611 .10229 L
.74619 .11609 L
.74627 .11609 L
.74635 .11995 L
.74643 .12333 L
.74651 .14506 L
.74659 .14506 L
.74667 .14581 L
.74675 .14581 L
.74683 .14581 L
.7469 .14581 L
.74698 .14581 L
.74706 .15242 L
.74714 .15382 L
.74722 .15202 L
.7473 .15576 L
.74738 .13198 L
.74746 .13198 L
.74754 .12911 L
.74762 .12911 L
.7477 .14328 L
.74778 .14328 L
.74786 .14328 L
.74794 .15255 L
.74802 .15255 L
.7481 .18421 L
.74817 .19187 L
.74825 .20547 L
Mistroke
.74833 .20547 L
.74841 .20547 L
.74849 .21612 L
.74857 .22191 L
.74865 .22191 L
.74873 .22191 L
.74881 .22191 L
.74889 .22083 L
.74897 .22083 L
.74905 .20447 L
.74913 .20447 L
.74921 .20447 L
.74929 .20447 L
.74937 .18128 L
.74944 .17759 L
.74952 .21214 L
.7496 .20135 L
.74968 .18122 L
.74976 .18122 L
.74984 .16197 L
.74992 .14152 L
.75 .15926 L
.75008 .15926 L
.75016 .21386 L
.75024 .21386 L
.75032 .1784 L
.7504 .14897 L
.75048 .15461 L
.75056 .17001 L
.75063 .17001 L
.75071 .17001 L
.75079 .17001 L
.75087 .17001 L
.75095 .14559 L
.75103 .15489 L
.75111 .1907 L
.75119 .18581 L
.75127 .19264 L
.75135 .19264 L
.75143 .19264 L
.75151 .19264 L
.75159 .19264 L
.75167 .19264 L
.75175 .19264 L
.75183 .24379 L
.7519 .24379 L
.75198 .31692 L
.75206 .2422 L
.75214 .27223 L
.75222 .27223 L
Mistroke
.7523 .27343 L
.75238 .27343 L
.75246 .27343 L
.75254 .23152 L
.75262 .21983 L
.7527 .21983 L
.75278 .19059 L
.75286 .19059 L
.75294 .20133 L
.75302 .19652 L
.7531 .18649 L
.75317 .19953 L
.75325 .19953 L
.75333 .16148 L
.75341 .16148 L
.75349 .22188 L
.75357 .19779 L
.75365 .1989 L
.75373 .1989 L
.75381 .1989 L
.75389 .19934 L
.75397 .17334 L
.75405 .17334 L
.75413 .1659 L
.75421 .15421 L
.75429 .15421 L
.75437 .15421 L
.75444 .16265 L
.75452 .16265 L
.7546 .15203 L
.75468 .15203 L
.75476 .17374 L
.75484 .17374 L
.75492 .17374 L
.755 .17374 L
.75508 .17374 L
.75516 .16053 L
.75524 .189 L
.75532 .19407 L
.7554 .19407 L
.75548 .19407 L
.75556 .1744 L
.75563 .1744 L
.75571 .16935 L
.75579 .17769 L
.75587 .25684 L
.75595 .25684 L
.75603 .26625 L
.75611 .26625 L
.75619 .26625 L
Mistroke
.75627 .24485 L
.75635 .24485 L
.75643 .19388 L
.75651 .19429 L
.75659 .15215 L
.75667 .13421 L
.75675 .16915 L
.75683 .22203 L
.7569 .20588 L
.75698 .19392 L
.75706 .24309 L
.75714 .23626 L
.75722 .23626 L
.7573 .23626 L
.75738 .23626 L
.75746 .23626 L
.75754 .23626 L
.75762 .23626 L
.7577 .23626 L
.75778 .23626 L
.75786 .23626 L
.75794 .23626 L
.75802 .23626 L
.7581 .2147 L
.75817 .16738 L
.75825 .16738 L
.75833 .16738 L
.75841 .16738 L
.75849 .16738 L
.75857 .13115 L
.75865 .13115 L
.75873 .10966 L
.75881 .10966 L
.75889 .10966 L
.75897 .10966 L
.75905 .10966 L
.75913 .10966 L
.75921 .10966 L
.75929 .12301 L
.75937 .15638 L
.75944 .15095 L
.75952 .10379 L
.7596 .10379 L
.75968 .10379 L
.75976 .13674 L
.75984 .12165 L
.75992 .12165 L
.76 .12165 L
.76008 .11398 L
.76016 .11398 L
Mistroke
.76024 .10121 L
.76032 .10121 L
.7604 .13167 L
.76048 .13167 L
.76056 .13167 L
.76063 .10124 L
.76071 .10332 L
.76079 .11173 L
.76087 .11416 L
.76095 .11416 L
.76103 .10818 L
.76111 .1599 L
.76119 .1599 L
.76127 .18541 L
.76135 .18946 L
.76143 .19735 L
.76151 .19735 L
.76159 .2232 L
.76167 .2232 L
.76175 .2232 L
.76183 .21659 L
.7619 .21659 L
.76198 .17779 L
.76206 .22121 L
.76214 .23004 L
.76222 .23004 L
.7623 .23004 L
.76238 .24425 L
.76246 .17546 L
.76254 .15555 L
.76262 .15555 L
.7627 .15555 L
.76278 .15555 L
.76286 .15903 L
.76294 .15903 L
.76302 .15903 L
.7631 .15903 L
.76317 .15903 L
.76325 .15948 L
.76333 .16669 L
.76341 .16669 L
.76349 .14496 L
.76357 .14496 L
.76365 .14496 L
.76373 .14496 L
.76381 .16235 L
.76389 .16235 L
.76397 .16235 L
.76405 .16235 L
.76413 .1603 L
Mistroke
.76421 .15903 L
.76429 .15903 L
.76437 .15536 L
.76444 .15829 L
.76452 .14059 L
.7646 .14059 L
.76468 .15754 L
.76476 .17032 L
.76484 .17032 L
.76492 .16064 L
.765 .12848 L
.76508 .12848 L
.76516 .12848 L
.76524 .12848 L
.76532 .1736 L
.7654 .15563 L
.76548 .17598 L
.76556 .15219 L
.76563 .17657 L
.76571 .1692 L
.76579 .1692 L
.76587 .1639 L
.76595 .1639 L
.76603 .18985 L
.76611 .1745 L
.76619 .1745 L
.76627 .1745 L
.76635 .17849 L
.76643 .17849 L
.76651 .177 L
.76659 .177 L
.76667 .177 L
.76675 .177 L
.76683 .177 L
.7669 .177 L
.76698 .177 L
.76706 .20135 L
.76714 .20306 L
.76722 .21302 L
.7673 .19002 L
.76738 .19002 L
.76746 .19002 L
.76754 .19002 L
.76762 .19793 L
.7677 .19604 L
.76778 .16928 L
.76786 .16928 L
.76794 .16928 L
.76802 .18165 L
.7681 .18165 L
Mistroke
.76817 .18165 L
.76825 .20558 L
.76833 .20558 L
.76841 .20966 L
.76849 .19701 L
.76857 .19701 L
.76865 .21213 L
.76873 .21213 L
.76881 .21213 L
.76889 .21213 L
.76897 .21213 L
.76905 .21213 L
.76913 .26451 L
.76921 .26791 L
.76929 .24435 L
.76937 .28496 L
.76944 .28496 L
.76952 .29158 L
.7696 .29158 L
.76968 .2928 L
.76976 .2928 L
.76984 .2928 L
.76992 .2645 L
.77 .2645 L
.77008 .24027 L
.77016 .22204 L
.77024 .22204 L
.77032 .27894 L
.7704 .31141 L
.77048 .31141 L
.77056 .31141 L
.77063 .31141 L
.77071 .30307 L
.77079 .30307 L
.77087 .2969 L
.77095 .2969 L
.77103 .2969 L
.77111 .2969 L
.77119 .22288 L
.77127 .22288 L
.77135 .19237 L
.77143 .19237 L
.77151 .18179 L
.77159 .16506 L
.77167 .18735 L
.77175 .17324 L
.77183 .15643 L
.7719 .15643 L
.77198 .15643 L
.77206 .18891 L
Mistroke
.77214 .18891 L
.77222 .18891 L
.7723 .15189 L
.77238 .13116 L
.77246 .1728 L
.77254 .1728 L
.77262 .1728 L
.7727 .14859 L
.77278 .14859 L
.77286 .14859 L
.77294 .14859 L
.77302 .14859 L
.7731 .14859 L
.77317 .14859 L
.77325 .14859 L
.77333 .14859 L
.77341 .15702 L
.77349 .13048 L
.77357 .13048 L
.77365 .13048 L
.77373 .10678 L
.77381 .10338 L
.77389 .10338 L
.77397 .10338 L
.77405 .10338 L
.77413 .10113 L
.77421 .09899 L
.77429 .09737 L
.77437 .07126 L
.77444 .07126 L
.77452 .08161 L
.7746 .06061 L
.77468 .06061 L
.77476 .06061 L
.77484 .06061 L
.77492 .05322 L
.775 .05322 L
.77508 .06138 L
.77516 .0623 L
.77524 .0623 L
.77532 .0623 L
.7754 .06824 L
.77548 .06824 L
.77556 .06824 L
.77563 .05151 L
.77571 .08386 L
.77579 .09492 L
.77587 .09492 L
.77595 .09492 L
.77603 .09492 L
Mistroke
.77611 .09492 L
.77619 .13523 L
.77627 .14338 L
.77635 .12353 L
.77643 .09884 L
.77651 .1163 L
.77659 .13506 L
.77667 .13506 L
.77675 .13506 L
.77683 .14816 L
.7769 .15993 L
.77698 .15993 L
.77706 .15425 L
.77714 .15425 L
.77722 .14486 L
.7773 .14486 L
.77738 .13453 L
.77746 .13453 L
.77754 .13453 L
.77762 .17039 L
.7777 .1848 L
.77778 .1848 L
.77786 .209 L
.77794 .209 L
.77802 .209 L
.7781 .209 L
.77817 .18907 L
.77825 .18907 L
.77833 .18907 L
.77841 .18907 L
.77849 .18907 L
.77857 .18907 L
.77865 .14912 L
.77873 .16187 L
.77881 .1716 L
.77889 .17291 L
.77897 .17291 L
.77905 .17291 L
.77913 .17291 L
.77921 .17049 L
.77929 .17049 L
.77937 .13603 L
.77944 .15455 L
.77952 .13996 L
.7796 .15054 L
.77968 .15054 L
.77976 .15054 L
.77984 .12458 L
.77992 .12458 L
.78 .09555 L
Mistroke
.78008 .09555 L
.78016 .11903 L
.78024 .11903 L
.78032 .11871 L
.7804 .16593 L
.78048 .16593 L
.78056 .16593 L
.78063 .16593 L
.78071 .16593 L
.78079 .17212 L
.78087 .17212 L
.78095 .17212 L
.78103 .15867 L
.78111 .20743 L
.78119 .20743 L
.78127 .20743 L
.78135 .20743 L
.78143 .21667 L
.78151 .21667 L
.78159 .21667 L
.78167 .21122 L
.78175 .21122 L
.78183 .21122 L
.7819 .18253 L
.78198 .18253 L
.78206 .18253 L
.78214 .18253 L
.78222 .18253 L
.7823 .14908 L
.78238 .17158 L
.78246 .18283 L
.78254 .1856 L
.78262 .21994 L
.7827 .21994 L
.78278 .21994 L
.78286 .23683 L
.78294 .25877 L
.78302 .25877 L
.7831 .25877 L
.78317 .24396 L
.78325 .20512 L
.78333 .15326 L
.78341 .18987 L
.78349 .20306 L
.78357 .20306 L
.78365 .20306 L
.78373 .20306 L
.78381 .20306 L
.78389 .20414 L
.78397 .2062 L
Mistroke
.78405 .16799 L
.78413 .1241 L
.78421 .1241 L
.78429 .1241 L
.78437 .1241 L
.78444 .12152 L
.78452 .13757 L
.7846 .13757 L
.78468 .13757 L
.78476 .13757 L
.78484 .0954 L
.78492 .106 L
.785 .106 L
.78508 .106 L
.78516 .10662 L
.78524 .10662 L
.78532 .15895 L
.7854 .15895 L
.78548 .15156 L
.78556 .12672 L
.78563 .12672 L
.78571 .17358 L
.78579 .23015 L
.78587 .24417 L
.78595 .24417 L
.78603 .2372 L
.78611 .2372 L
.78619 .25076 L
.78627 .25076 L
.78635 .23831 L
.78643 .26419 L
.78651 .26419 L
.78659 .26419 L
.78667 .25171 L
.78675 .21407 L
.78683 .18589 L
.7869 .18589 L
.78698 .18589 L
.78706 .18589 L
.78714 .18589 L
.78722 .14652 L
.7873 .1473 L
.78738 .12578 L
.78746 .12578 L
.78754 .12578 L
.78762 .12578 L
.7877 .10061 L
.78778 .10061 L
.78786 .11444 L
.78794 .11444 L
Mistroke
.78802 .11444 L
.7881 .14033 L
.78817 .1075 L
.78825 .1075 L
.78833 .06742 L
.78841 .10005 L
.78849 .12458 L
.78857 .11949 L
.78865 .11949 L
.78873 .11831 L
.78881 .11831 L
.78889 .11831 L
.78897 .11831 L
.78905 .08479 L
.78913 .08378 L
.78921 .08378 L
.78929 .08378 L
.78937 .08378 L
.78944 .10139 L
.78952 .10139 L
.7896 .10139 L
.78968 .14187 L
.78976 .1319 L
.78984 .1319 L
.78992 .1319 L
.79 .12579 L
.79008 .12579 L
.79016 .115 L
.79024 .115 L
.79032 .115 L
.7904 .15569 L
.79048 .12117 L
.79056 .07236 L
.79063 .07236 L
.79071 .09256 L
.79079 .09256 L
.79087 .1241 L
.79095 .11642 L
.79103 .15467 L
.79111 .15467 L
.79119 .14186 L
.79127 .14186 L
.79135 .16299 L
.79143 .16299 L
.79151 .16299 L
.79159 .13834 L
.79167 .14071 L
.79175 .14071 L
.79183 .11595 L
.7919 .06334 L
Mistroke
.79198 .04493 L
.79206 .04493 L
.79214 .03802 L
.79222 .03802 L
.7923 .03802 L
.79238 .04925 L
.79246 .04925 L
.79254 .06536 L
.79262 .06536 L
.7927 .09848 L
.79278 .09855 L
.79286 .10887 L
.79294 .07239 L
.79302 .07239 L
.7931 .07239 L
.79317 .07239 L
.79325 .07239 L
.79333 .07239 L
.79341 .08511 L
.79349 .08511 L
.79357 .08511 L
.79365 .08511 L
.79373 .06468 L
.79381 .06468 L
.79389 .06468 L
.79397 .08135 L
.79405 .08135 L
.79413 .08135 L
.79421 .07685 L
.79429 .07685 L
.79437 .07685 L
.79444 .07685 L
.79452 .07685 L
.7946 .07414 L
.79468 .07414 L
.79476 .07414 L
.79484 .07414 L
.79492 .07414 L
.795 .07414 L
.79508 .08 L
.79516 .08 L
.79524 .08 L
.79532 .08 L
.7954 .08 L
.79548 .08 L
.79556 .08 L
.79563 .08 L
.79571 .08 L
.79579 .09036 L
.79587 .09036 L
Mistroke
.79595 .1339 L
.79603 .12115 L
.79611 .12115 L
.79619 .1229 L
.79627 .15903 L
.79635 .16826 L
.79643 .18501 L
.79651 .18501 L
.79659 .21921 L
.79667 .21251 L
.79675 .21276 L
.79683 .21276 L
.7969 .21276 L
.79698 .21276 L
.79706 .21276 L
.79714 .18811 L
.79722 .20953 L
.7973 .21444 L
.79738 .20561 L
.79746 .20325 L
.79754 .20325 L
.79762 .20081 L
.7977 .27784 L
.79778 .26585 L
.79786 .28317 L
.79794 .33244 L
.79802 .27895 L
.7981 .27895 L
.79817 .26071 L
.79825 .23637 L
.79833 .29982 L
.79841 .29982 L
.79849 .29982 L
.79857 .3312 L
.79865 .33689 L
.79873 .33689 L
.79881 .33689 L
.79889 .33689 L
.79897 .31797 L
.79905 .31797 L
.79913 .31797 L
.79921 .31797 L
.79929 .33563 L
.79937 .31801 L
.79944 .3133 L
.79952 .3133 L
.7996 .2642 L
.79968 .2642 L
.79976 .2642 L
.79984 .2642 L
Mistroke
.79992 .2642 L
.8 .2504 L
.80008 .2504 L
.80016 .2504 L
.80024 .25051 L
.80032 .18452 L
.8004 .18452 L
.80048 .19563 L
.80056 .18645 L
.80063 .1691 L
.80071 .14358 L
.80079 .14335 L
.80087 .14335 L
.80095 .16604 L
.80103 .16604 L
.80111 .17385 L
.80119 .17385 L
.80127 .17385 L
.80135 .17385 L
.80143 .17385 L
.80151 .17385 L
.80159 .17385 L
.80167 .17385 L
.80175 .17385 L
.80183 .17385 L
.8019 .17385 L
.80198 .17385 L
.80206 .1235 L
.80214 .13446 L
.80222 .13446 L
.8023 .08668 L
.80238 .08668 L
.80246 .1304 L
.80254 .13628 L
.80262 .13628 L
.8027 .1203 L
.80278 .1203 L
.80286 .1203 L
.80294 .14017 L
.80302 .09868 L
.8031 .12469 L
.80317 .1687 L
.80325 .1687 L
.80333 .18259 L
.80341 .18259 L
.80349 .18259 L
.80357 .18259 L
.80365 .18259 L
.80373 .18259 L
.80381 .18259 L
Mistroke
.80389 .18259 L
.80397 .18259 L
.80405 .18192 L
.80413 .18192 L
.80421 .18192 L
.80429 .18723 L
.80437 .18723 L
.80444 .19464 L
.80452 .20567 L
.8046 .20567 L
.80468 .1991 L
.80476 .18385 L
.80484 .18751 L
.80492 .19266 L
.805 .19266 L
.80508 .17134 L
.80516 .17134 L
.80524 .17134 L
.80532 .17134 L
.8054 .15988 L
.80548 .16665 L
.80556 .16665 L
.80563 .16665 L
.80571 .14236 L
.80579 .14236 L
.80587 .17298 L
.80595 .17298 L
.80603 .17298 L
.80611 .17298 L
.80619 .17298 L
.80627 .17298 L
.80635 .17298 L
.80643 .17298 L
.80651 .18049 L
.80659 .16218 L
.80667 .16218 L
.80675 .16218 L
.80683 .16218 L
.8069 .09432 L
.80698 .10697 L
.80706 .10697 L
.80714 .10697 L
.80722 .12636 L
.8073 .12636 L
.80738 .14727 L
.80746 .12977 L
.80754 .12977 L
.80762 .13428 L
.8077 .18065 L
.80778 .17912 L
Mistroke
.80786 .17168 L
.80794 .17168 L
.80802 .17128 L
.8081 .23346 L
.80817 .1915 L
.80825 .16953 L
.80833 .15266 L
.80841 .15266 L
.80849 .124 L
.80857 .124 L
.80865 .12464 L
.80873 .11342 L
.80881 .11342 L
.80889 .11342 L
.80897 .11342 L
.80905 .08546 L
.80913 .1204 L
.80921 .1204 L
.80929 .1204 L
.80937 .11598 L
.80944 .07095 L
.80952 .08172 L
.8096 .08172 L
.80968 .08172 L
.80976 .08144 L
.80984 .08144 L
.80992 .08555 L
.81 .09636 L
.81008 .10128 L
.81016 .07753 L
.81024 .10456 L
.81032 .10456 L
.8104 .10456 L
.81048 .15732 L
.81056 .16101 L
.81063 .13763 L
.81071 .0993 L
.81079 .11873 L
.81087 .10389 L
.81095 .10389 L
.81103 .086 L
.81111 .086 L
.81119 .10289 L
.81127 .10501 L
.81135 .13663 L
.81143 .13663 L
.81151 .13663 L
.81159 .18595 L
.81167 .18595 L
.81175 .19487 L
Mistroke
.81183 .25844 L
.8119 .25844 L
.81198 .1831 L
.81206 .1831 L
.81214 .1831 L
.81222 .16109 L
.8123 .16109 L
.81238 .11927 L
.81246 .11927 L
.81254 .11767 L
.81262 .11046 L
.8127 .11046 L
.81278 .11046 L
.81286 .11046 L
.81294 .18544 L
.81302 .18544 L
.8131 .18544 L
.81317 .13567 L
.81325 .15361 L
.81333 .15361 L
.81341 .15361 L
.81349 .1675 L
.81357 .1675 L
.81365 .1675 L
.81373 .14263 L
.81381 .14263 L
.81389 .16753 L
.81397 .18992 L
.81405 .18992 L
.81413 .26574 L
.81421 .26073 L
.81429 .20694 L
.81437 .20694 L
.81444 .20694 L
.81452 .21911 L
.8146 .21911 L
.81468 .21911 L
.81476 .21911 L
.81484 .21911 L
.81492 .14751 L
.815 .14751 L
.81508 .14751 L
.81516 .16582 L
.81524 .15597 L
.81532 .15597 L
.8154 .15597 L
.81548 .16469 L
.81556 .21626 L
.81563 .21626 L
.81571 .21626 L
Mistroke
.81579 .23483 L
.81587 .23483 L
.81595 .23483 L
.81603 .23483 L
.81611 .23069 L
.81619 .23069 L
.81627 .23069 L
.81635 .23069 L
.81643 .23069 L
.81651 .20356 L
.81659 .19987 L
.81667 .19987 L
.81675 .20476 L
.81683 .20476 L
.8169 .20476 L
.81698 .20476 L
.81706 .2266 L
.81714 .19161 L
.81722 .19908 L
.8173 .19908 L
.81738 .19908 L
.81746 .19908 L
.81754 .19908 L
.81762 .19908 L
.8177 .19908 L
.81778 .23398 L
.81786 .23398 L
.81794 .23739 L
.81802 .22914 L
.8181 .22914 L
.81817 .21115 L
.81825 .21115 L
.81833 .21141 L
.81841 .16078 L
.81849 .16078 L
.81857 .16078 L
.81865 .16757 L
.81873 .1918 L
.81881 .1918 L
.81889 .1918 L
.81897 .1918 L
.81905 .19685 L
.81913 .19685 L
.81921 .19481 L
.81929 .19481 L
.81937 .19481 L
.81944 .19481 L
.81952 .16648 L
.8196 .17429 L
.81968 .17429 L
Mistroke
.81976 .17429 L
.81984 .17511 L
.81992 .17511 L
.82 .18319 L
.82008 .17847 L
.82016 .19846 L
.82024 .19846 L
.82032 .19846 L
.8204 .19846 L
.82048 .19846 L
.82056 .18167 L
.82063 .16783 L
.82071 .16783 L
.82079 .13547 L
.82087 .1569 L
.82095 .1569 L
.82103 .21187 L
.82111 .21187 L
.82119 .23411 L
.82127 .21394 L
.82135 .21394 L
.82143 .21394 L
.82151 .2137 L
.82159 .23193 L
.82167 .23193 L
.82175 .23193 L
.82183 .22065 L
.8219 .22065 L
.82198 .17915 L
.82206 .18821 L
.82214 .19273 L
.82222 .19273 L
.8223 .19273 L
.82238 .20473 L
.82246 .20473 L
.82254 .20473 L
.82262 .1858 L
.8227 .1858 L
.82278 .1858 L
.82286 .1858 L
.82294 .1858 L
.82302 .1858 L
.8231 .1858 L
.82317 .21761 L
.82325 .2442 L
.82333 .24623 L
.82341 .24623 L
.82349 .19355 L
.82357 .20886 L
.82365 .20936 L
Mistroke
.82373 .20936 L
.82381 .2324 L
.82389 .23699 L
.82397 .23699 L
.82405 .17102 L
.82413 .18688 L
.82421 .22675 L
.82429 .23759 L
.82437 .23759 L
.82444 .23058 L
.82452 .23288 L
.8246 .2643 L
.82468 .26831 L
.82476 .23078 L
.82484 .22425 L
.82492 .26739 L
.825 .27332 L
.82508 .24872 L
.82516 .24019 L
.82524 .24019 L
.82532 .21901 L
.8254 .20464 L
.82548 .1527 L
.82556 .15067 L
.82563 .15067 L
.82571 .15872 L
.82579 .15872 L
.82587 .14664 L
.82595 .1423 L
.82603 .1423 L
.82611 .15029 L
.82619 .18251 L
.82627 .18251 L
.82635 .18251 L
.82643 .18251 L
.82651 .18251 L
.82659 .12727 L
.82667 .12727 L
.82675 .15737 L
.82683 .15737 L
.8269 .15737 L
.82698 .15737 L
.82706 .15868 L
.82714 .15868 L
.82722 .13222 L
.8273 .13222 L
.82738 .17835 L
.82746 .17796 L
.82754 .20486 L
.82762 .20486 L
Mistroke
.8277 .20486 L
.82778 .20486 L
.82786 .20486 L
.82794 .20486 L
.82802 .20486 L
.8281 .20486 L
.82817 .20486 L
.82825 .20486 L
.82833 .20486 L
.82841 .18741 L
.82849 .20321 L
.82857 .2188 L
.82865 .19955 L
.82873 .19955 L
.82881 .19955 L
.82889 .18906 L
.82897 .18906 L
.82905 .20413 L
.82913 .20413 L
.82921 .20095 L
.82929 .20095 L
.82937 .20095 L
.82944 .14255 L
.82952 .14255 L
.8296 .14255 L
.82968 .1546 L
.82976 .1546 L
.82984 .23399 L
.82992 .21325 L
.83 .21059 L
.83008 .21059 L
.83016 .24081 L
.83024 .24081 L
.83032 .24081 L
.8304 .24081 L
.83048 .24081 L
.83056 .21907 L
.83063 .21907 L
.83071 .22732 L
.83079 .21035 L
.83087 .21035 L
.83095 .21035 L
.83103 .21431 L
.83111 .21988 L
.83119 .21988 L
.83127 .21988 L
.83135 .21988 L
.83143 .26099 L
.83151 .26099 L
.83159 .25539 L
Mistroke
.83167 .25847 L
.83175 .26309 L
.83183 .20297 L
.8319 .18378 L
.83198 .16637 L
.83206 .18816 L
.83214 .19342 L
.83222 .19342 L
.8323 .19342 L
.83238 .25751 L
.83246 .25751 L
.83254 .25751 L
.83262 .25254 L
.8327 .25374 L
.83278 .25374 L
.83286 .2374 L
.83294 .2374 L
.83302 .27121 L
.8331 .25469 L
.83317 .2765 L
.83325 .2765 L
.83333 .21589 L
.83341 .22547 L
.83349 .22547 L
.83357 .22547 L
.83365 .24121 L
.83373 .24121 L
.83381 .25759 L
.83389 .25759 L
.83397 .25759 L
.83405 .25759 L
.83413 .25759 L
.83421 .25759 L
.83429 .25805 L
.83437 .23376 L
.83444 .23376 L
.83452 .23376 L
.8346 .23376 L
.83468 .17181 L
.83476 .17181 L
.83484 .16049 L
.83492 .18958 L
.835 .18958 L
.83508 .16433 L
.83516 .16433 L
.83524 .16433 L
.83532 .12814 L
.8354 .15304 L
.83548 .16412 L
.83556 .17115 L
Mistroke
.83563 .14366 L
.83571 .14366 L
.83579 .14366 L
.83587 .14366 L
.83595 .14366 L
.83603 .14366 L
.83611 .14366 L
.83619 .14428 L
.83627 .1398 L
.83635 .14154 L
.83643 .17802 L
.83651 .17802 L
.83659 .16051 L
.83667 .16051 L
.83675 .19677 L
.83683 .19677 L
.8369 .19677 L
.83698 .19954 L
.83706 .19954 L
.83714 .22096 L
.83722 .22096 L
.8373 .22096 L
.83738 .22096 L
.83746 .22096 L
.83754 .22096 L
.83762 .22096 L
.8377 .23339 L
.83778 .23339 L
.83786 .18474 L
.83794 .18474 L
.83802 .19866 L
.8381 .19866 L
.83817 .19866 L
.83825 .19866 L
.83833 .19866 L
.83841 .19388 L
.83849 .19388 L
.83857 .19388 L
.83865 .19388 L
.83873 .19388 L
.83881 .1945 L
.83889 .18212 L
.83897 .18212 L
.83905 .18212 L
.83913 .16757 L
.83921 .16301 L
.83929 .13845 L
.83937 .13845 L
.83944 .13845 L
.83952 .13845 L
Mistroke
.8396 .13845 L
.83968 .13845 L
.83976 .13845 L
.83984 .14552 L
.83992 .14552 L
.84 .14552 L
.84008 .1316 L
.84016 .13777 L
.84024 .17222 L
.84032 .16509 L
.8404 .16509 L
.84048 .16771 L
.84056 .16965 L
.84063 .12947 L
.84071 .12947 L
.84079 .12947 L
.84087 .09918 L
.84095 .14789 L
.84103 .1575 L
.84111 .1575 L
.84119 .1575 L
.84127 .13199 L
.84135 .13199 L
.84143 .0971 L
.84151 .09705 L
.84159 .09705 L
.84167 .09705 L
.84175 .12553 L
.84183 .10577 L
.8419 .15804 L
.84198 .13302 L
.84206 .09684 L
.84214 .08098 L
.84222 .07592 L
.8423 .07592 L
.84238 .07592 L
.84246 .06925 L
.84254 .06551 L
.84262 .09479 L
.8427 .09479 L
.84278 .10642 L
.84286 .11178 L
.84294 .11178 L
.84302 .11178 L
.8431 .10771 L
.84317 .10771 L
.84325 .10771 L
.84333 .1026 L
.84341 .1026 L
.84349 .1026 L
Mistroke
.84357 .1026 L
.84365 .08713 L
.84373 .08713 L
.84381 .11165 L
.84389 .1282 L
.84397 .1282 L
.84405 .1282 L
.84413 .1282 L
.84421 .13249 L
.84429 .12024 L
.84437 .09615 L
.84444 .09615 L
.84452 .0988 L
.8446 .12338 L
.84468 .12338 L
.84476 .12338 L
.84484 .15227 L
.84492 .13272 L
.845 .1881 L
.84508 .1881 L
.84516 .18663 L
.84524 .18663 L
.84532 .14596 L
.8454 .14596 L
.84548 .14596 L
.84556 .14596 L
.84563 .14596 L
.84571 .14596 L
.84579 .14592 L
.84587 .14592 L
.84595 .11159 L
.84603 .08668 L
.84611 .08668 L
.84619 .08668 L
.84627 .09075 L
.84635 .1315 L
.84643 .1315 L
.84651 .05755 L
.84659 .05755 L
.84667 .05755 L
.84675 .05755 L
.84683 .05755 L
.8469 .03522 L
.84698 .04172 L
.84706 .04172 L
.84714 .0855 L
.84722 .08672 L
.8473 .08672 L
.84738 .09466 L
.84746 .09466 L
Mistroke
.84754 .09466 L
.84762 .09466 L
.8477 .09466 L
.84778 .09466 L
.84786 .11446 L
.84794 .11446 L
.84802 .11446 L
.8481 .12203 L
.84817 .15662 L
.84825 .15662 L
.84833 .13166 L
.84841 .13166 L
.84849 .13166 L
.84857 .13166 L
.84865 .12792 L
.84873 .12792 L
.84881 .11775 L
.84889 .11775 L
.84897 .07801 L
.84905 .083 L
.84913 .06816 L
.84921 .05374 L
.84929 .05374 L
.84937 .05374 L
.84944 .05374 L
.84952 .05842 L
.8496 .05842 L
.84968 .05842 L
.84976 .05842 L
.84984 .05842 L
.84992 .06927 L
.85 .06927 L
.85008 .06927 L
.85016 .06927 L
.85024 .08045 L
.85032 .08045 L
.8504 .08045 L
.85048 .10187 L
.85056 .10187 L
.85063 .10187 L
.85071 .10187 L
.85079 .10187 L
.85087 .10187 L
.85095 .10187 L
.85103 .10187 L
.85111 .16423 L
.85119 .16423 L
.85127 .16423 L
.85135 .16423 L
.85143 .16423 L
Mistroke
.85151 .1586 L
.85159 .1586 L
.85167 .1586 L
.85175 .15633 L
.85183 .15633 L
.8519 .15633 L
.85198 .15633 L
.85206 .13158 L
.85214 .13158 L
.85222 .13158 L
.8523 .11657 L
.85238 .11657 L
.85246 .12111 L
.85254 .12111 L
.85262 .12352 L
.8527 .12352 L
.85278 .14625 L
.85286 .11255 L
.85294 .10976 L
.85302 .10976 L
.8531 .10413 L
.85317 .10413 L
.85325 .1021 L
.85333 .1021 L
.85341 .10241 L
.85349 .10241 L
.85357 .10241 L
.85365 .10593 L
.85373 .10593 L
.85381 .11875 L
.85389 .11875 L
.85397 .11875 L
.85405 .19005 L
.85413 .19005 L
.85421 .19005 L
.85429 .19005 L
.85437 .17513 L
.85444 .16141 L
.85452 .19263 L
.8546 .19616 L
.85468 .19616 L
.85476 .19616 L
.85484 .11118 L
.85492 .12516 L
.855 .12516 L
.85508 .18788 L
.85516 .16356 L
.85524 .12469 L
.85532 .12469 L
.8554 .12469 L
Mistroke
.85548 .12469 L
.85556 .12469 L
.85563 .12469 L
.85571 .12469 L
.85579 .21494 L
.85587 .19298 L
.85595 .19298 L
.85603 .21148 L
.85611 .20931 L
.85619 .19795 L
.85627 .15063 L
.85635 .16006 L
.85643 .16006 L
.85651 .16006 L
.85659 .16006 L
.85667 .16006 L
.85675 .18207 L
.85683 .19958 L
.8569 .19672 L
.85698 .1968 L
.85706 .1968 L
.85714 .1968 L
.85722 .17476 L
.8573 .17476 L
.85738 .17476 L
.85746 .17476 L
.85754 .1201 L
.85762 .09957 L
.8577 .1409 L
.85778 .1409 L
.85786 .1409 L
.85794 .13988 L
.85802 .16687 L
.8581 .16687 L
.85817 .16687 L
.85825 .16687 L
.85833 .16687 L
.85841 .16687 L
.85849 .15815 L
.85857 .16108 L
.85865 .12783 L
.85873 .12931 L
.85881 .12569 L
.85889 .16653 L
.85897 .1562 L
.85905 .1562 L
.85913 .1562 L
.85921 .1562 L
.85929 .13995 L
.85937 .16244 L
Mistroke
.85944 .18154 L
.85952 .23108 L
.8596 .22417 L
.85968 .22417 L
.85976 .22417 L
.85984 .18839 L
.85992 .18839 L
.86 .14811 L
.86008 .14811 L
.86016 .14811 L
.86024 .14811 L
.86032 .14811 L
.8604 .14811 L
.86048 .18372 L
.86056 .18372 L
.86063 .18372 L
.86071 .18372 L
.86079 .1721 L
.86087 .1721 L
.86095 .1966 L
.86103 .1966 L
.86111 .1966 L
.86119 .22499 L
.86127 .21086 L
.86135 .25186 L
.86143 .25186 L
.86151 .33188 L
.86159 .33188 L
.86167 .33188 L
.86175 .33188 L
.86183 .33163 L
.8619 .31022 L
.86198 .31022 L
.86206 .31022 L
.86214 .31022 L
.86222 .33322 L
.8623 .33939 L
.86238 .33939 L
.86246 .33939 L
.86254 .33939 L
.86262 .33939 L
.8627 .33939 L
.86278 .33939 L
.86286 .33939 L
.86294 .29269 L
.86302 .29269 L
.8631 .25306 L
.86317 .25306 L
.86325 .25306 L
.86333 .23303 L
Mistroke
.86341 .23303 L
.86349 .2319 L
.86357 .23308 L
.86365 .23308 L
.86373 .23308 L
.86381 .23308 L
.86389 .28016 L
.86397 .24593 L
.86405 .21891 L
.86413 .21891 L
.86421 .21211 L
.86429 .23751 L
.86437 .23138 L
.86444 .23138 L
.86452 .23138 L
.8646 .23138 L
.86468 .25485 L
.86476 .25439 L
.86484 .25439 L
.86492 .25439 L
.865 .24878 L
.86508 .22715 L
.86516 .22715 L
.86524 .22715 L
.86532 .24067 L
.8654 .29075 L
.86548 .29075 L
.86556 .29075 L
.86563 .25447 L
.86571 .21986 L
.86579 .23209 L
.86587 .23209 L
.86595 .18444 L
.86603 .1689 L
.86611 .18663 L
.86619 .1474 L
.86627 .1474 L
.86635 .1474 L
.86643 .1474 L
.86651 .1474 L
.86659 .1474 L
.86667 .15062 L
.86675 .15062 L
.86683 .15062 L
.8669 .14914 L
.86698 .14914 L
.86706 .14914 L
.86714 .14914 L
.86722 .14333 L
.8673 .14333 L
Mistroke
.86738 .14333 L
.86746 .14281 L
.86754 .14281 L
.86762 .1492 L
.8677 .139 L
.86778 .11803 L
.86786 .09601 L
.86794 .09601 L
.86802 .10048 L
.8681 .10443 L
.86817 .08032 L
.86825 .08032 L
.86833 .08032 L
.86841 .05671 L
.86849 .07709 L
.86857 .08856 L
.86865 .10593 L
.86873 .10593 L
.86881 .10593 L
.86889 .09969 L
.86897 .09445 L
.86905 .09644 L
.86913 .07426 L
.86921 .07426 L
.86929 .07426 L
.86937 .07426 L
.86944 .0939 L
.86952 .0939 L
.8696 .0939 L
.86968 .0939 L
.86976 .14238 L
.86984 .14389 L
.86992 .14389 L
.87 .12876 L
.87008 .12876 L
.87016 .12837 L
.87024 .12837 L
.87032 .12837 L
.8704 .10255 L
.87048 .10255 L
.87056 .09486 L
.87063 .09486 L
.87071 .09486 L
.87079 .09486 L
.87087 .09486 L
.87095 .09486 L
.87103 .06898 L
.87111 .06898 L
.87119 .06898 L
.87127 .06898 L
Mistroke
.87135 .06898 L
.87143 .06898 L
.87151 .07727 L
.87159 .07727 L
.87167 .07727 L
.87175 .07727 L
.87183 .07727 L
.8719 .07727 L
.87198 .07727 L
.87206 .07727 L
.87214 .07727 L
.87222 .07727 L
.8723 .08376 L
.87238 .08376 L
.87246 .0772 L
.87254 .07537 L
.87262 .07537 L
.8727 .07537 L
.87278 .0547 L
.87286 .05702 L
.87294 .06911 L
.87302 .06911 L
.8731 .06911 L
.87317 .06911 L
.87325 .05915 L
.87333 .06504 L
.87341 .06504 L
.87349 .05527 L
.87357 .02941 L
.87365 .02697 L
.87373 .02697 L
.87381 .07083 L
.87389 .07083 L
.87397 .07506 L
.87405 .0938 L
.87413 .0896 L
.87421 .0896 L
.87429 .0896 L
.87437 .0896 L
.87444 .0896 L
.87452 .0896 L
.8746 .0896 L
.87468 .15814 L
.87476 .15814 L
.87484 .18933 L
.87492 .23099 L
.875 .18791 L
.87508 .18791 L
.87516 .18343 L
.87524 .18454 L
Mistroke
.87532 .18454 L
.8754 .18454 L
.87548 .18454 L
.87556 .18827 L
.87563 .18827 L
.87571 .18827 L
.87579 .18827 L
.87587 .18827 L
.87595 .19545 L
.87603 .19545 L
.87611 .16002 L
.87619 .17828 L
.87627 .17828 L
.87635 .17828 L
.87643 .17828 L
.87651 .17828 L
.87659 .17828 L
.87667 .17828 L
.87675 .17828 L
.87683 .1677 L
.8769 .1677 L
.87698 .15557 L
.87706 .15191 L
.87714 .15191 L
.87722 .15191 L
.8773 .15191 L
.87738 .15191 L
.87746 .15191 L
.87754 .12915 L
.87762 .1502 L
.8777 .1502 L
.87778 .14956 L
.87786 .1321 L
.87794 .1321 L
.87802 .16065 L
.8781 .16065 L
.87817 .14638 L
.87825 .14638 L
.87833 .15834 L
.87841 .15834 L
.87849 .15834 L
.87857 .1679 L
.87865 .1679 L
.87873 .1679 L
.87881 .17027 L
.87889 .17027 L
.87897 .16776 L
.87905 .16776 L
.87913 .14215 L
.87921 .14215 L
Mistroke
.87929 .16703 L
.87937 .17308 L
.87944 .15802 L
.87952 .15772 L
.8796 .19448 L
.87968 .19448 L
.87976 .18294 L
.87984 .20604 L
.87992 .20604 L
.88 .20604 L
.88008 .20604 L
.88016 .18072 L
.88024 .18072 L
.88032 .18072 L
.8804 .18072 L
.88048 .18072 L
.88056 .18072 L
.88063 .18072 L
.88071 .1927 L
.88079 .2055 L
.88087 .25322 L
.88095 .25322 L
.88103 .24577 L
.88111 .26732 L
.88119 .25599 L
.88127 .25599 L
.88135 .30323 L
.88143 .30323 L
.88151 .28577 L
.88159 .23443 L
.88167 .23443 L
.88175 .24858 L
.88183 .22343 L
.8819 .20446 L
.88198 .20446 L
.88206 .20446 L
.88214 .20446 L
.88222 .20933 L
.8823 .20933 L
.88238 .20933 L
.88246 .20933 L
.88254 .20933 L
.88262 .19611 L
.8827 .17804 L
.88278 .17804 L
.88286 .17452 L
.88294 .17452 L
.88302 .13747 L
.8831 .20928 L
.88317 .22762 L
Mistroke
.88325 .24144 L
.88333 .24144 L
.88341 .24144 L
.88349 .19117 L
.88357 .18365 L
.88365 .18365 L
.88373 .18365 L
.88381 .18365 L
.88389 .18365 L
.88397 .20633 L
.88405 .20633 L
.88413 .20633 L
.88421 .20633 L
.88429 .20676 L
.88437 .17022 L
.88444 .17022 L
.88452 .17022 L
.8846 .15685 L
.88468 .10942 L
.88476 .11883 L
.88484 .11883 L
.88492 .11883 L
.885 .08874 L
.88508 .08874 L
.88516 .11119 L
.88524 .11119 L
.88532 .11119 L
.8854 .10405 L
.88548 .10405 L
.88556 .10405 L
.88563 .10405 L
.88571 .13518 L
.88579 .13518 L
.88587 .13518 L
.88595 .13518 L
.88603 .129 L
.88611 .129 L
.88619 .129 L
.88627 .13058 L
.88635 .12538 L
.88643 .12996 L
.88651 .12996 L
.88659 .12996 L
.88667 .12996 L
.88675 .12996 L
.88683 .12326 L
.8869 .12326 L
.88698 .14267 L
.88706 .14267 L
.88714 .14267 L
Mistroke
.88722 .16015 L
.8873 .16015 L
.88738 .17345 L
.88746 .17345 L
.88754 .1529 L
.88762 .15966 L
.8877 .15966 L
.88778 .1701 L
.88786 .16164 L
.88794 .16164 L
.88802 .1199 L
.8881 .12217 L
.88817 .1314 L
.88825 .1314 L
.88833 .15553 L
.88841 .11633 L
.88849 .12341 L
.88857 .12341 L
.88865 .12152 L
.88873 .12152 L
.88881 .12152 L
.88889 .11893 L
.88897 .11893 L
.88905 .14227 L
.88913 .14227 L
.88921 .14227 L
.88929 .15631 L
.88937 .15631 L
.88944 .15631 L
.88952 .15631 L
.8896 .15631 L
.88968 .16086 L
.88976 .16576 L
.88984 .16576 L
.88992 .2627 L
.89 .2627 L
.89008 .34282 L
.89016 .34282 L
.89024 .34059 L
.89032 .31903 L
.8904 .31903 L
.89048 .36213 L
.89056 .36213 L
.89063 .36213 L
.89071 .36213 L
.89079 .31835 L
.89087 .28253 L
.89095 .28253 L
.89103 .28253 L
.89111 .28253 L
Mistroke
.89119 .28253 L
.89127 .28253 L
.89135 .29591 L
.89143 .29591 L
.89151 .2906 L
.89159 .2906 L
.89167 .2906 L
.89175 .2999 L
.89183 .2999 L
.8919 .2999 L
.89198 .2999 L
.89206 .2999 L
.89214 .31569 L
.89222 .31504 L
.8923 .32945 L
.89238 .27501 L
.89246 .27501 L
.89254 .27501 L
.89262 .27501 L
.8927 .27501 L
.89278 .27501 L
.89286 .29689 L
.89294 .27748 L
.89302 .27748 L
.8931 .27748 L
.89317 .281 L
.89325 .281 L
.89333 .281 L
.89341 .3044 L
.89349 .3044 L
.89357 .3044 L
.89365 .32272 L
.89373 .3105 L
.89381 .3105 L
.89389 .28429 L
.89397 .28429 L
.89405 .28429 L
.89413 .28429 L
.89421 .27195 L
.89429 .27195 L
.89437 .30284 L
.89444 .30284 L
.89452 .29846 L
.8946 .29846 L
.89468 .2712 L
.89476 .272 L
.89484 .28405 L
.89492 .28405 L
.895 .25774 L
.89508 .25774 L
Mistroke
.89516 .25774 L
.89524 .25774 L
.89532 .27074 L
.8954 .27074 L
.89548 .27074 L
.89556 .26585 L
.89563 .26658 L
.89571 .24649 L
.89579 .23243 L
.89587 .23243 L
.89595 .2474 L
.89603 .2474 L
.89611 .2474 L
.89619 .22242 L
.89627 .22242 L
.89635 .22242 L
.89643 .22242 L
.89651 .22242 L
.89659 .22052 L
.89667 .22052 L
.89675 .22052 L
.89683 .21019 L
.8969 .21019 L
.89698 .23168 L
.89706 .23168 L
.89714 .23168 L
.89722 .27469 L
.8973 .27469 L
.89738 .27469 L
.89746 .36552 L
.89754 .36552 L
.89762 .36113 L
.8977 .34018 L
.89778 .31897 L
.89786 .30878 L
.89794 .30878 L
.89802 .3081 L
.8981 .32562 L
.89817 .32562 L
.89825 .32562 L
.89833 .32562 L
.89841 .31918 L
.89849 .31918 L
.89857 .25809 L
.89865 .30818 L
.89873 .30818 L
.89881 .29058 L
.89889 .29225 L
.89897 .30527 L
.89905 .30527 L
Mistroke
.89913 .30527 L
.89921 .30912 L
.89929 .28096 L
.89937 .32317 L
.89944 .31323 L
.89952 .31393 L
.8996 .31393 L
.89968 .30466 L
.89976 .30466 L
.89984 .30466 L
.89992 .3106 L
.9 .33236 L
.90008 .30068 L
.90016 .30068 L
.90024 .30068 L
.90032 .30068 L
.9004 .30068 L
.90048 .30068 L
.90056 .34237 L
.90063 .34237 L
.90071 .36819 L
.90079 .37539 L
.90087 .38769 L
.90095 .38532 L
.90103 .38913 L
.90111 .38913 L
.90119 .38913 L
.90127 .36384 L
.90135 .36384 L
.90143 .3731 L
.90151 .38522 L
.90159 .38522 L
.90167 .39038 L
.90175 .39038 L
.90183 .39038 L
.9019 .39038 L
.90198 .40218 L
.90206 .40218 L
.90214 .40409 L
.90222 .41034 L
.9023 .41034 L
.90238 .42659 L
.90246 .41108 L
.90254 .41108 L
.90262 .41108 L
.9027 .41108 L
.90278 .40592 L
.90286 .43995 L
.90294 .45751 L
.90302 .47699 L
Mistroke
.9031 .45429 L
.90317 .45429 L
.90325 .48327 L
.90333 .48327 L
.90341 .47225 L
.90349 .49082 L
.90357 .49082 L
.90365 .48023 L
.90373 .48023 L
.90381 .48023 L
.90389 .48023 L
.90397 .46774 L
.90405 .46774 L
.90413 .46774 L
.90421 .46774 L
.90429 .40671 L
.90437 .39207 L
.90444 .40466 L
.90452 .41858 L
.9046 .40864 L
.90468 .33521 L
.90476 .33521 L
.90484 .32372 L
.90492 .26878 L
.905 .25801 L
.90508 .25801 L
.90516 .25801 L
.90524 .25801 L
.90532 .27199 L
.9054 .28066 L
.90548 .28066 L
.90556 .3078 L
.90563 .29126 L
.90571 .29126 L
.90579 .29126 L
.90587 .3266 L
.90595 .3266 L
.90603 .3266 L
.90611 .29249 L
.90619 .29249 L
.90627 .29492 L
.90635 .29492 L
.90643 .30973 L
.90651 .30973 L
.90659 .2863 L
.90667 .2863 L
.90675 .2863 L
.90683 .30133 L
.9069 .30196 L
.90698 .29212 L
Mistroke
.90706 .3292 L
.90714 .3292 L
.90722 .3292 L
.9073 .35887 L
.90738 .35887 L
.90746 .3204 L
.90754 .29583 L
.90762 .27379 L
.9077 .27379 L
.90778 .27401 L
.90786 .2751 L
.90794 .2751 L
.90802 .21618 L
.9081 .19804 L
.90817 .22259 L
.90825 .22109 L
.90833 .2312 L
.90841 .2312 L
.90849 .186 L
.90857 .186 L
.90865 .186 L
.90873 .18623 L
.90881 .17938 L
.90889 .17938 L
.90897 .17228 L
.90905 .17228 L
.90913 .17228 L
.90921 .17228 L
.90929 .1437 L
.90937 .14745 L
.90944 .14745 L
.90952 .14745 L
.9096 .14745 L
.90968 .16638 L
.90976 .16638 L
.90984 .16638 L
.90992 .19249 L
.91 .18733 L
.91008 .17073 L
.91016 .17073 L
.91024 .19829 L
.91032 .19662 L
.9104 .19662 L
.91048 .19662 L
.91056 .19662 L
.91063 .17172 L
.91071 .17172 L
.91079 .17172 L
.91087 .143 L
.91095 .10098 L
Mistroke
.91103 .10098 L
.91111 .11319 L
.91119 .1285 L
.91127 .1285 L
.91135 .1285 L
.91143 .11939 L
.91151 .11939 L
.91159 .11939 L
.91167 .1172 L
.91175 .1172 L
.91183 .1172 L
.9119 .08774 L
.91198 .10093 L
.91206 .10093 L
.91214 .12709 L
.91222 .12709 L
.9123 .12709 L
.91238 .1337 L
.91246 .1337 L
.91254 .18987 L
.91262 .18987 L
.9127 .17396 L
.91278 .17396 L
.91286 .2128 L
.91294 .2128 L
.91302 .2128 L
.9131 .2128 L
.91317 .16898 L
.91325 .1598 L
.91333 .1598 L
.91341 .1598 L
.91349 .1598 L
.91357 .1598 L
.91365 .1598 L
.91373 .1598 L
.91381 .1598 L
.91389 .1598 L
.91397 .1598 L
.91405 .1533 L
.91413 .20196 L
.91421 .20196 L
.91429 .26013 L
.91437 .26013 L
.91444 .2357 L
.91452 .25501 L
.9146 .26899 L
.91468 .25495 L
.91476 .34031 L
.91484 .20086 L
.91492 .13823 L
Mistroke
.915 .14294 L
.91508 .14103 L
.91516 .14941 L
.91524 .14941 L
.91532 .14941 L
.9154 .12735 L
.91548 .12928 L
.91556 .12928 L
.91563 .12928 L
.91571 .16735 L
.91579 .16862 L
.91587 .17375 L
.91595 .20444 L
.91603 .19065 L
.91611 .19065 L
.91619 .18447 L
.91627 .18552 L
.91635 .18552 L
.91643 .18552 L
.91651 .18552 L
.91659 .18552 L
.91667 .14683 L
.91675 .13949 L
.91683 .13949 L
.9169 .13949 L
.91698 .13949 L
.91706 .15725 L
.91714 .16992 L
.91722 .13151 L
.9173 .13151 L
.91738 .15484 L
.91746 .15358 L
.91754 .15301 L
.91762 .20022 L
.9177 .20022 L
.91778 .20022 L
.91786 .20022 L
.91794 .20022 L
.91802 .26631 L
.9181 .26631 L
.91817 .26631 L
.91825 .27642 L
.91833 .27642 L
.91841 .32053 L
.91849 .264 L
.91857 .264 L
.91865 .3297 L
.91873 .28197 L
.91881 .30147 L
.91889 .29753 L
Mistroke
.91897 .29753 L
.91905 .26724 L
.91913 .28614 L
.91921 .28614 L
.91929 .29796 L
.91937 .29582 L
.91944 .30687 L
.91952 .31903 L
.9196 .25279 L
.91968 .23223 L
.91976 .23223 L
.91984 .26962 L
.91992 .26962 L
.92 .28333 L
.92008 .28333 L
.92016 .28333 L
.92024 .28333 L
.92032 .28219 L
.9204 .28219 L
.92048 .28219 L
.92056 .28219 L
.92063 .29693 L
.92071 .2647 L
.92079 .2647 L
.92087 .2647 L
.92095 .26798 L
.92103 .26798 L
.92111 .24105 L
.92119 .24105 L
.92127 .32606 L
.92135 .32606 L
.92143 .32606 L
.92151 .32606 L
.92159 .32606 L
.92167 .32606 L
.92175 .32606 L
.92183 .32606 L
.9219 .33523 L
.92198 .28288 L
.92206 .26226 L
.92214 .26226 L
.92222 .21458 L
.9223 .21458 L
.92238 .1702 L
.92246 .18944 L
.92254 .18092 L
.92262 .18092 L
.9227 .18092 L
.92278 .18092 L
.92286 .17624 L
Mistroke
.92294 .17624 L
.92302 .17402 L
.9231 .16895 L
.92317 .16895 L
.92325 .16473 L
.92333 .16473 L
.92341 .13749 L
.92349 .13749 L
.92357 .13073 L
.92365 .11289 L
.92373 .14375 L
.92381 .14375 L
.92389 .14375 L
.92397 .11852 L
.92405 .11421 L
.92413 .09797 L
.92421 .09797 L
.92429 .10311 L
.92437 .10311 L
.92444 .09164 L
.92452 .10104 L
.9246 .09004 L
.92468 .09047 L
.92476 .09047 L
.92484 .09047 L
.92492 .07926 L
.925 .07485 L
.92508 .11971 L
.92516 .11971 L
.92524 .11971 L
.92532 .11042 L
.9254 .11042 L
.92548 .11243 L
.92556 .11243 L
.92563 .11243 L
.92571 .11243 L
.92579 .1013 L
.92587 .1328 L
.92595 .1328 L
.92603 .1328 L
.92611 .1328 L
.92619 .1328 L
.92627 .1328 L
.92635 .1328 L
.92643 .12528 L
.92651 .13888 L
.92659 .1317 L
.92667 .1317 L
.92675 .1352 L
.92683 .14522 L
Mistroke
.9269 .14522 L
.92698 .14522 L
.92706 .12502 L
.92714 .07764 L
.92722 .07764 L
.9273 .07764 L
.92738 .07764 L
.92746 .07764 L
.92754 .08762 L
.92762 .08762 L
.9277 .08762 L
.92778 .08762 L
.92786 .08762 L
.92794 .08762 L
.92802 .08762 L
.9281 .08762 L
.92817 .08762 L
.92825 .1048 L
.92833 .09466 L
.92841 .08697 L
.92849 .08697 L
.92857 .09018 L
.92865 .09018 L
.92873 .09018 L
.92881 .08086 L
.92889 .08086 L
.92897 .06468 L
.92905 .06468 L
.92913 .06493 L
.92921 .04581 L
.92929 .04889 L
.92937 .04889 L
.92944 .01955 L
.92952 .01955 L
.9296 .01955 L
.92968 .022 L
.92976 .03869 L
.92984 .03869 L
.92992 .07665 L
.93 .09417 L
.93008 .0973 L
.93016 .0973 L
.93024 .0973 L
.93032 .10641 L
.9304 .12659 L
.93048 .08921 L
.93056 .08921 L
.93063 .08921 L
.93071 .15049 L
.93079 .12941 L
Mistroke
.93087 .12941 L
.93095 .11411 L
.93103 .14564 L
.93111 .14564 L
.93119 .11885 L
.93127 .06094 L
.93135 .05976 L
.93143 .05976 L
.93151 .05976 L
.93159 .05976 L
.93167 .08177 L
.93175 .08177 L
.93183 .08177 L
.9319 .08177 L
.93198 .08177 L
.93206 .08177 L
.93214 .08177 L
.93222 .08177 L
.9323 .08177 L
.93238 .07474 L
.93246 .08231 L
.93254 .05331 L
.93262 .05331 L
.9327 .0722 L
.93278 .05451 L
.93286 .05451 L
.93294 .05451 L
.93302 .08501 L
.9331 .08501 L
.93317 .12442 L
.93325 .12442 L
.93333 .12593 L
.93341 .12593 L
.93349 .10709 L
.93357 .0898 L
.93365 .0898 L
.93373 .0898 L
.93381 .09387 L
.93389 .08564 L
.93397 .10505 L
.93405 .10505 L
.93413 .11013 L
.93421 .11013 L
.93429 .11013 L
.93437 .09174 L
.93444 .10238 L
.93452 .08863 L
.9346 .08863 L
.93468 .09622 L
.93476 .09622 L
Mistroke
.93484 .12931 L
.93492 .12931 L
.935 .12931 L
.93508 .12931 L
.93516 .12931 L
.93524 .12931 L
.93532 .12803 L
.9354 .15794 L
.93548 .15794 L
.93556 .15794 L
.93563 .17635 L
.93571 .17635 L
.93579 .17635 L
.93587 .17635 L
.93595 .17635 L
.93603 .17816 L
.93611 .17816 L
.93619 .22425 L
.93627 .22425 L
.93635 .22553 L
.93643 .2443 L
.93651 .2296 L
.93659 .2296 L
.93667 .2296 L
.93675 .2296 L
.93683 .2296 L
.9369 .2296 L
.93698 .2296 L
.93706 .23943 L
.93714 .23943 L
.93722 .23572 L
.9373 .21871 L
.93738 .21871 L
.93746 .22213 L
.93754 .23489 L
.93762 .24818 L
.9377 .25448 L
.93778 .25448 L
.93786 .25448 L
.93794 .1809 L
.93802 .1734 L
.9381 .1734 L
.93817 .1734 L
.93825 .1734 L
.93833 .1734 L
.93841 .19212 L
.93849 .19212 L
.93857 .26943 L
.93865 .26061 L
.93873 .26061 L
Mistroke
.93881 .26061 L
.93889 .2703 L
.93897 .2703 L
.93905 .2703 L
.93913 .2703 L
.93921 .2703 L
.93929 .2703 L
.93937 .27817 L
.93944 .28344 L
.93952 .28344 L
.9396 .28344 L
.93968 .30662 L
.93976 .30662 L
.93984 .31513 L
.93992 .31513 L
.94 .32503 L
.94008 .33013 L
.94016 .33013 L
.94024 .33013 L
.94032 .3381 L
.9404 .3381 L
.94048 .28829 L
.94056 .27903 L
.94063 .22199 L
.94071 .22199 L
.94079 .25453 L
.94087 .25453 L
.94095 .25453 L
.94103 .25453 L
.94111 .25453 L
.94119 .25453 L
.94127 .25453 L
.94135 .26702 L
.94143 .26702 L
.94151 .24814 L
.94159 .25381 L
.94167 .25381 L
.94175 .26262 L
.94183 .24801 L
.9419 .24801 L
.94198 .24801 L
.94206 .24801 L
.94214 .25396 L
.94222 .25396 L
.9423 .23853 L
.94238 .23853 L
.94246 .26361 L
.94254 .2561 L
.94262 .22741 L
.9427 .22741 L
Mistroke
.94278 .22741 L
.94286 .22741 L
.94294 .22741 L
.94302 .22675 L
.9431 .22675 L
.94317 .22675 L
.94325 .22675 L
.94333 .22944 L
.94341 .19976 L
.94349 .19976 L
.94357 .21315 L
.94365 .25179 L
.94373 .26264 L
.94381 .25952 L
.94389 .25952 L
.94397 .22444 L
.94405 .25305 L
.94413 .25305 L
.94421 .22733 L
.94429 .22733 L
.94437 .2305 L
.94444 .2461 L
.94452 .2461 L
.9446 .2461 L
.94468 .25353 L
.94476 .25353 L
.94484 .25373 L
.94492 .27581 L
.945 .27581 L
.94508 .27581 L
.94516 .27581 L
.94524 .30396 L
.94532 .30396 L
.9454 .28045 L
.94548 .28045 L
.94556 .28045 L
.94563 .28045 L
.94571 .29917 L
.94579 .29917 L
.94587 .2929 L
.94595 .2929 L
.94603 .2929 L
.94611 .24176 L
.94619 .24176 L
.94627 .24176 L
.94635 .24176 L
.94643 .21293 L
.94651 .22097 L
.94659 .20348 L
.94667 .20348 L
Mistroke
.94675 .20348 L
.94683 .20348 L
.9469 .20348 L
.94698 .20379 L
.94706 .16247 L
.94714 .16247 L
.94722 .16247 L
.9473 .15144 L
.94738 .15144 L
.94746 .16091 L
.94754 .17462 L
.94762 .13951 L
.9477 .13951 L
.94778 .13951 L
.94786 .13951 L
.94794 .13783 L
.94802 .13783 L
.9481 .18767 L
.94817 .18767 L
.94825 .18767 L
.94833 .18767 L
.94841 .18767 L
.94849 .16035 L
.94857 .11367 L
.94865 .11367 L
.94873 .11367 L
.94881 .11367 L
.94889 .11917 L
.94897 .11917 L
.94905 .13001 L
.94913 .13001 L
.94921 .13001 L
.94929 .1227 L
.94937 .15739 L
.94944 .15739 L
.94952 .13801 L
.9496 .13801 L
.94968 .13801 L
.94976 .09808 L
.94984 .09808 L
.94992 .07793 L
.95 .07793 L
.95008 .08625 L
.95016 .05689 L
.95024 .08588 L
.95032 .08588 L
.9504 .08588 L
.95048 .08588 L
.95056 .08588 L
.95063 .09118 L
Mistroke
.95071 .09224 L
.95079 .09224 L
.95087 .08988 L
.95095 .08516 L
.95103 .07354 L
.95111 .07354 L
.95119 .07354 L
.95127 .05256 L
.95135 .04825 L
.95143 .04586 L
.95151 .04586 L
.95159 .0546 L
.95167 .0546 L
.95175 .0463 L
.95183 .0463 L
.9519 .04105 L
.95198 .04105 L
.95206 .04105 L
.95214 .05013 L
.95222 .05264 L
.9523 .1058 L
.95238 .12702 L
.95246 .14855 L
.95254 .21266 L
.95262 .22545 L
.9527 .22545 L
.95278 .20621 L
.95286 .19237 L
.95294 .19237 L
.95302 .19237 L
.9531 .19237 L
.95317 .18472 L
.95325 .1568 L
.95333 .20012 L
.95341 .20012 L
.95349 .20012 L
.95357 .17717 L
.95365 .15606 L
.95373 .159 L
.95381 .11173 L
.95389 .11173 L
.95397 .11173 L
.95405 .11173 L
.95413 .11173 L
.95421 .10338 L
.95429 .10338 L
.95437 .08609 L
.95444 .08609 L
.95452 .1039 L
.9546 .1039 L
Mistroke
.95468 .1039 L
.95476 .1039 L
.95484 .12267 L
.95492 .12267 L
.955 .18803 L
.95508 .15649 L
.95516 .15649 L
.95524 .15649 L
.95532 .16118 L
.9554 .16118 L
.95548 .20411 L
.95556 .20226 L
.95563 .20226 L
.95571 .17762 L
.95579 .17762 L
.95587 .17762 L
.95595 .17762 L
.95603 .13214 L
.95611 .13214 L
.95619 .159 L
.95627 .13985 L
.95635 .14347 L
.95643 .14347 L
.95651 .14347 L
.95659 .1276 L
.95667 .13505 L
.95675 .13505 L
.95683 .14838 L
.9569 .10153 L
.95698 .10153 L
.95706 .1076 L
.95714 .09025 L
.95722 .09025 L
.9573 .09025 L
.95738 .09025 L
.95746 .09025 L
.95754 .09025 L
.95762 .09025 L
.9577 .09025 L
.95778 .09025 L
.95786 .09025 L
.95794 .09025 L
.95802 .09025 L
.9581 .09025 L
.95817 .07436 L
.95825 .07436 L
.95833 .09179 L
.95841 .05983 L
.95849 .08434 L
.95857 .08434 L
Mistroke
.95865 .09324 L
.95873 .09324 L
.95881 .11673 L
.95889 .11673 L
.95897 .11673 L
.95905 .11673 L
.95913 .11233 L
.95921 .11233 L
.95929 .11233 L
.95937 .13536 L
.95944 .14195 L
.95952 .14195 L
.9596 .17394 L
.95968 .15817 L
.95976 .19708 L
.95984 .21244 L
.95992 .21244 L
.96 .19738 L
.96008 .15716 L
.96016 .20639 L
.96024 .18697 L
.96032 .23017 L
.9604 .23017 L
.96048 .21772 L
.96056 .23648 L
.96063 .2215 L
.96071 .2215 L
.96079 .207 L
.96087 .20843 L
.96095 .18753 L
.96103 .18753 L
.96111 .19378 L
.96119 .19378 L
.96127 .19378 L
.96135 .19378 L
.96143 .17675 L
.96151 .16003 L
.96159 .14558 L
.96167 .14558 L
.96175 .12237 L
.96183 .11462 L
.9619 .11462 L
.96198 .14083 L
.96206 .14083 L
.96214 .14083 L
.96222 .14083 L
.9623 .14083 L
.96238 .17071 L
.96246 .17071 L
.96254 .17262 L
Mistroke
.96262 .17262 L
.9627 .18245 L
.96278 .15966 L
.96286 .15966 L
.96294 .15966 L
.96302 .15966 L
.9631 .14079 L
.96317 .14079 L
.96325 .14079 L
.96333 .15396 L
.96341 .15396 L
.96349 .15396 L
.96357 .13643 L
.96365 .13087 L
.96373 .13087 L
.96381 .13087 L
.96389 .1301 L
.96397 .1301 L
.96405 .1301 L
.96413 .1301 L
.96421 .1402 L
.96429 .1402 L
.96437 .1402 L
.96444 .14623 L
.96452 .1562 L
.9646 .1562 L
.96468 .1562 L
.96476 .11566 L
.96484 .12207 L
.96492 .10742 L
.965 .10742 L
.96508 .10742 L
.96516 .10165 L
.96524 .10165 L
.96532 .15103 L
.9654 .20309 L
.96548 .20309 L
.96556 .11368 L
.96563 .11368 L
.96571 .06157 L
.96579 .06725 L
.96587 .06725 L
.96595 .06725 L
.96603 .06725 L
.96611 .06725 L
.96619 .06961 L
.96627 .05499 L
.96635 .05499 L
.96643 .05499 L
.96651 .05499 L
Mistroke
.96659 .05499 L
.96667 .05499 L
.96675 .06649 L
.96683 .06649 L
.9669 .06564 L
.96698 .07414 L
.96706 .08447 L
.96714 .08447 L
.96722 .08447 L
.9673 .11203 L
.96738 .11203 L
.96746 .15258 L
.96754 .22895 L
.96762 .22895 L
.9677 .22895 L
.96778 .22061 L
.96786 .28419 L
.96794 .28419 L
.96802 .28419 L
.9681 .28419 L
.96817 .28419 L
.96825 .2693 L
.96833 .17246 L
.96841 .17246 L
.96849 .12562 L
.96857 .12562 L
.96865 .12562 L
.96873 .10262 L
.96881 .09314 L
.96889 .09314 L
.96897 .09314 L
.96905 .09314 L
.96913 .09314 L
.96921 .09314 L
.96929 .09314 L
.96937 .08596 L
.96944 .11269 L
.96952 .11269 L
.9696 .12048 L
.96968 .12048 L
.96976 .15493 L
.96984 .18957 L
.96992 .18957 L
.97 .18957 L
.97008 .18957 L
.97016 .14735 L
.97024 .18099 L
.97032 .17847 L
.9704 .17847 L
.97048 .17847 L
Mistroke
.97056 .17847 L
.97063 .25762 L
.97071 .25762 L
.97079 .18081 L
.97087 .18081 L
.97095 .17465 L
.97103 .16937 L
.97111 .16937 L
.97119 .14644 L
.97127 .13599 L
.97135 .13599 L
.97143 .13016 L
.97151 .12089 L
.97159 .12184 L
.97167 .12184 L
.97175 .12184 L
.97183 .12184 L
.9719 .11699 L
.97198 .16638 L
.97206 .15587 L
.97214 .16715 L
.97222 .16715 L
.9723 .16025 L
.97238 .16025 L
.97246 .12984 L
.97254 .12984 L
.97262 .14887 L
.9727 .14887 L
.97278 .14887 L
.97286 .14887 L
.97294 .18276 L
.97302 .1304 L
.9731 .1304 L
.97317 .11553 L
.97325 .13663 L
.97333 .0908 L
.97341 .0908 L
.97349 .0908 L
.97357 .0908 L
.97365 .1289 L
.97373 .1289 L
.97381 .19195 L
.97389 .19195 L
.97397 .15653 L
.97405 .12272 L
.97413 .12272 L
.97421 .12272 L
.97429 .12272 L
.97437 .11452 L
.97444 .10588 L
Mistroke
.97452 .10588 L
.9746 .10588 L
.97468 .10588 L
.97476 .10588 L
.97484 .10588 L
.97492 .10588 L
.975 .07013 L
.97508 .05432 L
.97516 .04751 L
.97524 .05739 L
.97532 .05739 L
.9754 .05739 L
.97548 .05739 L
.97556 .05739 L
.97563 .07165 L
.97571 .07521 L
.97579 .06305 L
.97587 .06305 L
.97595 .06305 L
.97603 .06305 L
.97611 .06305 L
.97619 .06305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
fOooool2o`0006;ooooo000Yooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool0HOoo
ool002Wooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo023ooooo000Yooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo000Yooooo`03o`000?oooooooooo09go
oooo0_l0000iooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Pooooo`00:Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo03So
oooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
023ooooo0007ooooo`Co000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0WOooool2o`0001gooooo00?o0000oooo
ooooool06Oooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08?ooool000Wooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo0_l000000ooooooo0000ooooo`0R
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0P
ooooo`001?l00005ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Iooooo`;o000000?oooooo`000?ooool04Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Poooo
o`002Oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0009gooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool2o`00
00;ooooo00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo017ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Iooooo`002Oooool00ol0003oooooooooo`05ooooo`03
ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool06Oooool2o`000003ooooool0003ooooo017ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Mooooo`;o00001Oooool00ol0
003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0I
ooooo`;o000000Coooooo`000?oooooo00004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool000Wooooo00?o0000ooooooooool00_ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2Mooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0001_ooooo0_l000001?oooooo0000ooooool0000;ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo
0007ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co0000
1_ooool00ol0003oooooooooo`2Mooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000oooooooo
ool00_l0000Kooooo`Ko00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo0_l00006ooooo`;o00004?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`00000Dooooo`00:Oooool00ol0003oooooooooo`2Aooooo`;o00002_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0oooool3o`0000;ooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo01;ooooo
1_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool2o`0000Gooooo
0ol0000@ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0001?o
oooo000Yooooo`03o`000?oooooooooo097ooooo0_l0000:ooooo`;o00000_ooool00ol0003ooooo
o`000002o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`?o0000
0_ooool6o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo1_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`;o0000
1Oooool3o`00013ooooo0_l00005ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l0
00004oooool002Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`05ooooo`?o0000
2_ooool2o`0000;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00oooool3o`0000;ooooo1ol00004ooooo`03o`000?oooooooooo00Oooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo1_l0000:ooooo`;o00001?ooool2o`0000kooooo
0ol00005ooooo`?o00004?ooool2o`0000Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo
0000o`00000Cooooo`00:Oooool2o`0008Wooooo00?o0000ooooool000001Oooool3o`0000[ooooo
0_l00002ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo0ol00002ooooo`Oo00001?ooool00ol0003oooooooooo`06ooooo`?o0000
1?ooool2o`0000?ooooo1_l0000:ooooo`;o00000oooool3o`0000kooooo0ol00005ooooo`?o0000
4?ooool2o`0000Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000o`00000Cooooo`00
:Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooo000000;o00000oooool3o`0000[ooooo
0_l00002ooooo`03o`000?oooooo000000;o000000Goooooo`000?l0003oooooo`000002ooooo`03
o`000?oooooooooo00?ooooo0ol00002ooooo`Oo00001?ooool00ol0003oooooooooo`06ooooo`?o
00001?ooool2o`0000?ooooo1_l0000:ooooo`;o00000oooool3o`0000?ooooo00?o0000oooooooo
ool02?ooool3o`0000Gooooo0ol0000@ooooo`;o00001Oooool01?l0003oooooo`000?ooool2o`00
0003ooooool0003o000001?ooooo000Yooooo`03o`000?oooooooooo08Sooooo00Co0000ooooool0
003o00000oooool4o`0000Sooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool01?ooool3o`0000;ooooo1ol0
0003ooooo`;o00002?ooool3o`0000Cooooo0_l00003ooooo`Ko00002_ooool2o`0000?ooooo0ol0
0003ooooo`03o`000?oooooooooo00Sooooo0ol00005ooooo`?o00003oooool3o`0000Gooooo00Co
0000ooooool0003ooooo0_l000000ooooooo0000o`00000Cooooo`00:Oooool00ol0003ooooooooo
o`28ooooo`Co00000oooool4o`0000Sooooo00Co0000ooooool0003o00000_ooool00ol0003ooooo
o`000002o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool01?ooool3o`0000;o
oooo1ol00003ooooo`;o000000?oooooo`000?ooool01Oooool3o`000004ooooool0003ooooooooo
o`;o00000oooool6o`0000[ooooo0_l00003ooooo`?o00000oooool2o`0000Wooooo0ol00005oooo
o`?o00003oooool3o`0000Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`0C
ooooo`00:Oooool00ol0003oooooooooo`27ooooo`Go00000_ooool5o`0000Sooooo00Co0000oooo
ool0003o00000_ooool00ol0003oooooo`000002o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?ooool01?ooool3o`0000;ooooo1ol00003ooooo`;o000000?oooooo`000?ooool01Ooo
ool3o`000004ooooool0003oooooooooo`;o00000oooool6o`0000[ooooo0_l00003ooooo`?o0000
0oooool2o`0000Wooooo0ol00005ooooo`?o00003oooool3o`0000Gooooo00Co0000ooooool0003o
oooo0_l000000ooooooo0000ooooo`0Cooooo`00:Oooool00ol0003oooooooooo`27ooooo`Go0000
0_ooool5o`0000Sooooo00Co0000ooooool0003o00000_ooool5o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo1ol00003ooooo`;o000000?oooooo`00
0?ooool01Oooool3o`000004ooooool0003oooooooooo`;o00000oooool6o`0000[ooooo0_l00003
ooooo`?o00000oooool2o`0000Wooooo0ol00005ooooo`?o00003oooool3o`0000Gooooo00Co0000
ooooool0003ooooo0_l000000ooooooo0000ooooo`0Cooooo`00:Oooool00ol0003oooooooooo`27
ooooo`Go000000?oooooo`000?l000001?l00008ooooo`04o`000?oooooo0000o`0000;ooooo1Ol0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000
o`000005o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Go00000_ooool2o`0000?ooooo
1_l0000:ooooo`;o00000oooool3o`000003ooooool0003ooooo00;o00002Oooool3o`0000Gooooo
0ol0000;ooooo`04o`000?ooooooooooooooo`?o00001Oooool3o`000003ooooool0003o000000;o
00005?ooool002Wooooo00?o0000ooooooooool0Qoooool5o`000003ooooool0003o000000Co0000
2?ooool01?l0003oooooo`000?l00002ooooo`Go000000Coooooo`000?l0003ooooo1Ol000001?oo
oooo0000ooooooooool4o`000003ooooool0003o000000Go00000oooool2o`000003ooooool0003o
oooo00Gooooo1Ol00002ooooo`;o00000oooool6o`0000[ooooo0_l00003ooooo`?o000000?ooooo
o`000?ooool00_l00009ooooo`?o00001Oooool3o`0000;ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooooooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`0001Cooooo000Y
ooooo`;o0000R?ooool5o`000003ooooool0003o000000Co00002?ooool4o`0000;ooooo1Ol00000
0ooooooo0000o`000006o`000004ooooool0003oooooooooo`Co000000?oooooo`000?l000001Ol0
0003ooooo`;o000000?oooooo`000?ooool01Oooool5o`000004ooooool0003o0000o`0000?ooooo
1_l0000:ooooo`;o00000oooool3o`000003ooooool0003ooooo00;o00002Oooool3o`0000Gooooo
0ol00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo1?l00003ooooo`Co
000000?oooooo`000?l000000_l0000Dooooo`00:Oooool00ol0003oooooooooo`26ooooo`Ko0000
00?oooooo`000?l000001?l00008ooooo`Co00000_ooool5o`000003ooooool0003o000000So0000
0_ooool4o`000003ooooool0003o000000Go00000oooool2o`000003ooooool0003ooooo00Gooooo
1Ol000001?oooooo0000o`000?l00003ooooo`Ko00002_ooool3o`000003ooooool0003o000000;o
000000?oooooo`000?ooool00_l00008ooooo`Co00001Oooool3o`0000;ooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooooooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`00
01Cooooo000Yooooo`03o`000?oooooooooo08Kooooo1_l000000ooooooo0000o`000004o`0000So
oooo1?l00002ooooo`Go000000?oooooo`000?l000002?l00002ooooo`co00000oooool2o`000003
ooooool0003ooooo00Gooooo1Ol000001?oooooo0000o`000?l00003ooooo`Ko00002_ooool3o`00
0003ooooool0003o000000;o000000?oooooo`000?ooool00_l00008ooooo`Co00000_ooool00ol0
003oooooooooo`03o`0000;ooooo00?o0000ooooooooool01Oooool2o`0000;ooooo1Ol00003oooo
o`Co000000?oooooo`000?l000000_l0000Dooooo`00:Oooool00ol0003oooooooooo`26ooooo`go
00002?ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000002?l00002ooooo`co
00000_ooool3o`000004ooooool0003oooooo`0000Cooooo1Ol000001?oooooo0000o`000?l00003
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003ooooo00;o00002?ooool5o`000004ooooool0003oooooooooo`?o0000
0_ooool2o`0000Kooooo0_l00002ooooo`Go00000oooool4o`000003ooooool0003o000000;o0000
5?ooool002Wooooo00?o0000ooooooooool0Q_ooool6o`000003ooooool0003o000000Co00002?oo
ool5o`000003ooooool0003o000000?o000000?oooooo`000?l000002?l00002ooooo`co000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?l00004ooooo`Go000000Coooooo`000?l0003o
00000oooool7o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003ooooo00;o00002?ooool5o`000004ooooool0003ooooo
ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool5o`0000?ooooo1?l00000
0ooooooo0000o`000003o`0001?ooooo000Yooooo`03o`000?oooooooooo08Kooooo3Ol00008oooo
o`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000008o`0000;ooooo3?l000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000Cooooo1Ol000001?oooooo0000o`000?l0
0003ooooo`Oo000000?oooooo`000?ooool00_ooool01?l0003oooooooooooooool3o`000003oooo
ool0003o000000;o000000?oooooo`000?ooool00ol00007ooooo`Go000000Coooooo`000?oooooo
oooo0ol00002ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`Go00000oooool4o`000003
ooooool0003o000000;o00005?ooool002Wooooo00?o0000ooooooooool0Q_ooool=o`0000Sooooo
1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000So00000_ooool<o`000003oooo
ool0003o000000Ko00001?ooool5o`000003ooooool0003o000000;o00000_ooool7o`000003oooo
ool0003ooooo00;ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`000002o`000003
ooooool0003ooooo00?o00001oooool7o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Go
oooo0_l00002ooooo`Go00000oooool9o`0001Cooooo000Yooooo`03o`000?oooooooooo08Kooooo
3Ol00008ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000008o`0000;ooooo
3?l000000ooooooo0000o`000006o`0000Cooooo1Ol000000ooooooo0000o`000002o`0000;ooooo
1ol000000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?l0
00000_l000000ooooooo0000ooooo`03o`0000Oooooo1ol00002ooooo`?o00000_ooool2o`0000Ko
oooo0_l00002ooooo`Go00000oooool9o`0001Cooooo000Yooooo`;o0000Qoooool=o`0000Oooooo
1_l000000ooooooo0000o`000003o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
2_l000000ooooooo0000o`000007o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo
00?o0000ooooool000001?l000000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooooooo`?o
000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Oooooo1ol00002ooooo`?o
00000_ooool2o`0000Kooooo0_l00002ooooo`Go00000oooool9o`0001Cooooo000Yooooo`03o`00
0?oooooooooo08Kooooo3Ol00002ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Wo000000?oooooo`000?ooool04ol00004ooooo`Go0000
00?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000000Co000000Coooooo`000?oooooo
oooo0_l00003ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`03o`0000Oo
oooo1ol00002ooooo`?o00000_ooool2o`0000Kooooo0_l00002ooooo`Go00000oooool9o`0001Co
oooo000Yooooo`03o`000?oooooooooo08Kooooo3Ol00002ooooo`03o`000?oooooooooo00;ooooo
1_l000000ooooooo0000o`000003o`000003ooooool0003o000000Wo000000?oooooo`000?ooool0
5?l00003ooooo`Go000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000000Ko0000
0_ooool2o`0000?ooooo2?l000000ooooooo0000ooooo`03o`0000Oooooo1ol00002ooooo`?o0000
0_ooool2o`0000Kooooo0_l00002ooooo`Go00000oooool9o`0001Cooooo000Yooooo`03o`000?oo
oooooooo023ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`03onk^k_lb<S;o000000ko000000Co<S8bo`00
0?lb<S;ok^k^0_ooool6o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000oooo
o`07o`000003ooooool0003ooooo01Co000000?ok^k^ooooooooool01Ol000000oo^k^ko0000o`00
0002o`0000;ooooo00?o0000ooooool000001_l00002ooooo`go000000?oooooo`000?ooool00ol0
00001_lb<S;ok^k^ooooool0003oooooonk^kPSo000000?o<S8bo`000?l000000ol000000ooooooo
0000o`000006ooooo`Wo000000?oooooo`000?l000002Ol000000olb<S;ok^k^ooooo`02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo000Yoooo
o`03o`000?oooooooooo023ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Gooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00omEEEGoMgMgo`00
000=o`000005ogMgMonHV9So0000oiRHV?mgMgL00_ooool6o`000003ooooool0003o000000?o0000
00Goooooo`000?l0003o0000ooooo`07o`000003ooooool0003ooooo01Go00000_ooool5o`000003
ogMgMol0003o000000;o00000_ooool00ol0003oooooo`000006o`0000;ooooo1?l000000ooooooo
0000o`000006o`000003ooooool0003ooooo00?o000000KoV9RHogMgMooooooo0000oooooomgMgL8
o`000004oiRHV?oooooo0000ogMgM`;o000000?oooooo`000?l000001_ooool3o`000003ooooool0
003o000000?o000000?ooooooiRHV?lQ8B402Ol000000onHV9SoMgMgooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo000Yooooo`03o`00
0?oooooooooo027ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005Oooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@01Cooooo00?o0000ooooool000003Ol000001Ol@413o
ooooo`000?oooooo410@00;ooooo1_l000000ooooooo0000o`000003o`000005ooooool0003o0000
o`000?ooool01ol000000ooooooo0000ooooo`0Eo`0000;ooooo1Ol000000ol@413o0000o`000002
o`0000;ooooo00?o0000ooooool000001_l00002ooooo`Co000000?oooooo`000?l000001_l00000
0ooooooo0000ooooo`03o`000006ooooool0003oooooo`000?oooooo410@2?l00002ooooo`05o`00
0?l@413o0000o`000?ooool00_l00006ooooo`?o000000?oooooo`000?l000000ol00002ooooo`03
oiRHV?l0003o000000Oo000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`00:Oooool00ol0003oooooooooo`0Roooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000001Gooooo00CoA4A4omgMgOl0003o
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oV9RHo`00000>o`000005ooooool0
003oooooo`000?ooool01ol000000ooooooo0000o`000003o`000003ooooool0003o000000Wo0000
00?oooooo`000?ooool01_l000000ooooooo0000o`00000<o`0000;ooooo0ol000000ooooooo0000
o`000004o`0000;ooooo00?o0000ooooool000001_l00002ooooo`Co000000?oooooo`000?l00000
1_l000000ooooooo0000ooooo`03o`000005ooooool0003oooooo`000?ooool02Ol00002ooooo`Co
000000?oooooo`000?l000001_ooool3o`000003ooooool0003o000000?o00000oooool9o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool002Wooooo00?o0000ooooooooool08oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00000Eooooo`04omgMgOmEEEGo0000o`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000001Cooooo00?o0000oeEEEOl000003_l000001Ooooooo0000ooooool0003ooooo00Oo0000
00?oooooo`000?l000001ol000000ooooooo0000o`000005o`000003ooooool0003ooooo00Ko0000
00?oooooo`000?l000003?l00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`03o`00
0?oooooo000000Oo000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`000003oooo
ool0003o000000?o000000?oooooo`000?ooool02ol00002ooooo`Co000000Coooooo`000?l0003o
00001Oooool3o`000003ooooool0003o000000?o00000oooool9o`000003ooooool0003ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
02Wooooo0_l0000Uooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Cooooo
00?oMgMgo`000?l000001?ooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00?oEEEEohN7Qol000003_l000001Ooooooo0000ooooool@413ooooo00Oo000000?ooooo
o`000?l000001ol000000ooooooo0000o`000005o`000003ooooool0003ooooo00Ko00000_ooool0
0ol@413o0000o`00000:o`0000;ooooo0ol000001Ooooooo0000oa0@4?l0003ooooo00;o00000_oo
ool00ol0003oooooo`000007o`000003ooooool0003o000000;o000000?oooooo`000?l000001_l0
00000ooooooo0000o`000003o`000003ooooool0003ooooo00;o000000?o410@o`000?l000001_l0
0002ooooo`Co000000?oooooo`000?l000001_ooool3o`000003ooooool0003o000000?o00000ooo
ool9o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000_ooool002Wooooo00?o0000ooooooooool08?ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00goMgMgoiRHV?ooooooV9RHogMgMooooooo0000oooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo
00oooooo00?ok^k^o`000?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00000
1?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003ooooo
ooooo`0:ooooo`03omgMgOl@413o000000ko000000GoV9RHo`000?nHV9SoMgMgooooo`0Ao`000003
ooooool0003o000000Go000000?oooooo`000?ooool01ol000000oooooooMgMgo`00000;o`000003
ooooool0003o000000;o000000Goooooo`000?mgMgOo0000ooooo`02o`000004ooooool0003o0000
ooooo`So000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`000003ooooool0003o
000000?o000000?oV9RHo`000?ooool00_l000000omgMgOo0000o`000009o`000004ogMgMol0003o
0000ooooo`;o00001_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?nj^[X02Ol0
00000onHV9SoMgMgooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;ooooo000Yooooo`03o`000?oooooooooo023ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^koooooo`000?ooooook^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0@oooo
o`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0;ooooo`03olc<
c?l0003o000000go000000Go<S8bo`000?lb<S;ok^k^ooooo`08o`000003ooooool0003o000000Ko
000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`06o`0000;ooooo00?ok^k^o`000?l0
00002_l000000ooooooo0000o`000004o`000003onk^k_l0003ooooo00;o000000Coooooo`000?l0
003ooooo3Ol000000ooooooo0000o`000006o`000003ooooool0003o000000?o000000?o<S8bo`00
0?l000000_l000000oo^k^ko0000o`000006o`000004oc8b<_l0003o0000onk^kP;o000000?ooooo
o`000?l000001_ooool3o`000009oeEEEOl0003o0000o`000?oooooo0000oooooonHV9So410@00Wo
000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`00:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`;o00002oooool2o`00
00Kooooo0_l0000;ooooo`03o`000?oooooooooo00cooooo3ol000001Ooooooo0000o`000?l0003o
oooo00;o000000?oooooo`000?l000000ol000000ooooooo0000o`000006o`000003ooooool0003o
000000Go000000?oooooo`000?ooool01_l00003ooooo`co000000?oooooo`000?l000000_l00000
1Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000
o`000006o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l000000ooooooo0000
o`000006o`000004ooooool0003oooooooooo`;o000000?oooooo`000?l000001_ooool3o`000003
ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`000003o`00
01Cooooo000Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`;o00002oooool2o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000go
oooo1_l000000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`Go000000?oooooo`00
0?l000001_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00Ko00000oooool<o`00
0003ooooool0003o000000;o000000Goooooo`000?oooooo0000ooooo`02o`000004ooooool0003o
0000ooooo`go000000?oooooo`000?l000001_l000000ooooooo0000o`000003o`000003ooooool0
003o000000;o000000?oooooo`000?l000001_l000001?oooooo0000ooooooooool2o`000004oooo
ool0003o0000o`0000Gooooo0ol000000ooooooo0000ooooo`02ooooo`04o`000?oooooooooooooo
o`?o000000?oooooo`000?l000000ol0000Dooooo`00:Oooool00ol0003oooooooooo`0Kooooo`;o
000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_l00004ooooo`Co
00002oooool2o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000gooooo0ol000001?oooooo
0000o`000?ooool<o`000004ooooool0003o0000ooooo`ko000000?oooooo`000?l000001Ol00000
0ooooooo0000ooooo`05o`0000Cooooo3?l000000ooooooo0000o`000002o`000005ooooool0003o
ooooo`000?ooool00_l000001?oooooo0000o`000?ooool=o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003ooooo3Ol000000ooooooo0000ooooo`03o`000004ooooool0003ooooooooo
o`Ko00001Oooool3o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo0ol00000
0ooooooo0000o`000003o`0001Cooooo000Yooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0ol00009
ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00001Oooool4o`0000_ooooo0_l0
0006ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`?o000000Coooooo`000?l0003ooooo
3ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l0
00001Ol000000ooooooo0000ooooo`03o`000003ooooool0003ooooo00?ooooo3?l000000ooooooo
0000o`000002o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool=
o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000oooo
o`03o`000004ooooool0003oooooooooo`Ko00001Oooool3o`000003ooooool0003ooooo00;ooooo
00Co0000oooooooooooooooo0ol000000ooooooo0000o`000003o`0001Cooooo000Yooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo0ol00002ooooo`;o00001Oooool01?l0003oooooooooool00004oooo
o`04o`000?oooooo0000o`0000Gooooo1?l0000;ooooo`;o00001_ooool00ol0003oooooooooo`0:
ooooo`;o00003Oooool3o`000004ooooool0003o0000ooooo`oo000000?oooooo`000?l000000ol0
00001?oooooo0000o`000?ooool5o`000003ooooool0003o000000Go000000?oooooo`000?ooool0
0ol000000ooooooo0000ooooo`03ooooo`Oo000000?oooooo`000?l000000_l000000ooooooo0000
o`000002o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool=o`00
0003ooooool0003o000000?o00000_ooool00ol0003oooooo`00000<o`000003ooooool0003ooooo
00?o000000Coooooo`000?oooooooooo1_l00005ooooo`?o000000?oooooo`000?ooool00_ooool0
1?l0003oooooooooooooool3o`000003ooooool0003o000000?o00005?ooool0027oooooool0000l
o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooo`000009oooo
o`;o00001Oooool3o`0000;ooooo0_l00005ooooo`04o`000?oooooo0000o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`Co00002oooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo0_l000000ooooooo0000ooooo`0:ooooo`?o000000Coooooo`000?l0003ooooo1Ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000Ko000000?oooooo`000?l000000ol0
00000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo1Ol00004ooooo`Go
000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`00
0?ooool00_l000001?oooooo0000o`000?ooool=o`000003ooooool0003o000000?o00000_ooool0
0ol0003oooooo`00000<o`000003ooooool0003ooooo00Go00000_ooool6o`000003ooooool0003o
oooo00;ooooo0ol000000ooooooo0000ooooo`02ooooo`;o00000_ooool3o`000003ooooool0003o
000000Co00004oooool002Wooooo00?o0000ooooooooool06oooool2o`000003ooooool0003ooooo
00Cooooo0_l00008ooooo`;o00001Oooool3o`0000;ooooo0_l00005ooooo`04o`000?oooooo0000
o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Co00001Oooool00ol0003oooooooooo`03
ooooo`;o00001Oooool2o`0000cooooo0_l0000=ooooo`04o`000?oooooo0000ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000007o`000003ooooool0003o000000?o000000Co
ooooo`000?l0003ooooo1Ol000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0
003ooooo0ol000000ooooooo0000ooooo`03ooooo`Go000000?oooooo`000?ooool01?l000000ooo
oooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?oo
ool=o`000003ooooool0003o000000?o00000_ooool00ol0003oooooo`00000<o`000003ooooool0
003ooooo00Go00000_ooool4o`000003ooooool0003ooooo00Cooooo0ol000000ooooooo0000oooo
o`02ooooo`;o00000_ooool:o`0001?ooooo000Yooooo`03o`000?oooooooooo01_ooooo0_l00000
0ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool3
o`0000;ooooo0_l00005ooooo`04o`000?oooooo0000o`0000?ooooo0_l000000ooooooo0000o`00
0005ooooo`Co00001Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000cooooo0_l0
000=ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000007o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1Ol000000ooooooo
0000o`000002o`000006ooooool0003o0000ooooool0003ooooo0ol000000ooooooo0000ooooo`03
ooooo`Co00000_ooool00ol0003oooooo`000007o`0000;ooooo0ol000000ooooooo0000o`000003
o`0000;ooooo3?l000000ooooooo0000o`000003o`0000;ooooo00?o0000ooooool000003?l00000
0ooooooo0000ooooo`05o`0000;ooooo1?l000000ooooooo0000ooooo`04ooooo`?o000000?ooooo
o`000?ooool00_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0001Cooooo000Yoooo
o`03o`000?oooooooooo01_ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool01?ooool3o`0000;ooooo0_l00005ooooo`Co00000oooool2o`00
0003ooooool0003o000000Gooooo1Ol00003ooooo`;o00001Oooool2o`0000Gooooo0_l00008oooo
o`04o`000?ooooooooooooooo`?o00003?ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000001ol000000ooooooo0000o`000003o`0000;ooooo00?o
0000ooooool000001?l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003o
oooo0ol000000ooooooo0000ooooo`03ooooo`Co00000_ooool01?l0003oooooo`000?ooool2o`00
0004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;ooooo4_l00002
ooooo`03o`000?oooooo000000co000000?oooooo`000?ooool01Ol00002ooooo`Co000000?ooooo
o`000?ooool01?ooool3o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`?o000000?ooooo
o`000?l000000ol0000Dooooo`00:Oooool00ol0003oooooooooo`0Kooooo`Co00000oooool01?l0
003oooooo`000?ooool2o`0000Kooooo00?o0000ooooooooool01?ooool3o`0000;ooooo0_l00005
ooooo`Co00000oooool2o`000003ooooool0003o000000Gooooo1Ol00003ooooo`;o00001Oooool2
o`0000Gooooo0_l00008ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003ooooooooo
o`07ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000007o`000003ooooool0003o000000?o00000_ooool00ol0003oooooo`000004o`0000;ooooo
0ol000001_oooooo0000o`000?oooooo0000ooooo`?o000000?oooooo`000?ooool00oooool4o`00
00;ooooo00Co0000ooooool0003ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?o
ooooo`000?l000000ol00002ooooo`co000000?oooooo`000?l000001?l000000ooooooo0000o`00
000=o`000003ooooool0003ooooo00Go00000_ooool4o`000003ooooool0003ooooo00Cooooo0ol0
00000ooooooo0000ooooo`02ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00005?oo
ool002Wooooo00?o0000ooooooooool06oooool4o`0000?ooooo00Go0000ooooool0003oooooo`00
0007ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000;ooooo0_l00005ooooo`Co0000
0oooool2o`000003ooooool0003o000000Gooooo1Ol00003ooooo`;o00001Oooool2o`0000Cooooo
0ol00008ooooo`03o`000?oooooooooo00Go000000?oooooo`000?ooool02?ooool01Ol0003ooooo
o`000?oooooo000000;ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo1Ol00004ooooo`Go
00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003ooooo00?o000000?oooooo`00
0?ooool00oooool4o`0000;ooooo00Co0000ooooool0003ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`?o000000?oooooo`000?l000000ol00002ooooo`co000000?oooooo`000?l000000ol0
0002ooooo`oo000000?oooooo`000?ooool01Ol00002ooooo`Co000000?oooooo`000?ooool01?oo
ool3o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000ol0
000Dooooo`00:Oooool00ol0003oooooooooo`0Kooooo`Co00000oooool01Ol0003oooooo`000?oo
oooo000000Oooooo00Go0000ooooooooooooooooo`000002ooooo`?o000000Goooooo`000?l0003o
0000ooooo`02o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool5o`0000?o
oooo0_l00005ooooo`;o00001?ooool3o`0000Sooooo00?o0000ooooooooool01?l00002ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002ooooo`Go000000?oooooo`00
0?l000001_l00002ooooo`Go00001?ooool5o`0000;ooooo00Co0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`03o`000003ooooool0003ooooo00?ooooo1?l00002ooooo`04o`000?oooooo
0000ooooo`Ko00000_ooool3o`000003ooooool0003o000000?o00000_oooolBo`0000;ooooo3ol0
0004ooooo`Co00000_ooool4o`000003ooooool0003ooooo00Cooooo0ol000000ooooooo0000oooo
o`02ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00005?ooool002Wooooo0_l0000L
ooooo`Co00000oooool00ol0003oooooo`000002o`0000Oooooo00?o0000ooooooooool00_l00002
ooooo`Oo000000?oooooo`000?ooool00_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`Go00000oooool2o`0000Gooooo0ol00003ooooo`?o00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Co00000_ooool00ol0003oooooooooo`07ooooo`05o`000?oo
ooooooooooooool000000_ooool5o`000003ooooool0003o000000Ko00000_ooool5o`0000Cooooo
1Ol00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00ol000000ooooooo
0000ooooo`03ooooo`Co00000_ooool01?l0003oooooo`000?ooool6o`0000;ooooo0ol000000ooo
oooo0000o`000003o`0000;ooooo3Ol000000ooooooo0000o`000002o`0000;ooooo3ol00004oooo
o`Co00000_ooool4o`000003ooooool0003ooooo00Cooooo0ol000000ooooooo0000ooooo`02oooo
o`;o00000_ooool3o`000003ooooool0003o000000;o00005Oooool002Wooooo00?o0000oooooooo
ool06oooool4o`0000?ooooo00?o0000ooooool000000ol00005ooooo`;o00000_ooool2o`0000;o
oooo1ol000000ooooooo0000ooooo`02ooooo`Co00000oooool2o`000003ooooool0003o000000;o
00000oooool5o`0000?ooooo0_l00005ooooo`;o00001?ooool4o`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04o`000003ooooool0003o000000Wooooo00Go0000oooooooo
ooooooooo`000002ooooo`Go000000?oooooo`000?l000001_l00002ooooo`Go00001?ooool5o`00
00;ooooo00Co0000ooooool0003ooooo0_l000001ooooooo0000ooooool0003oooooo`000?ooool0
0_l00003ooooo`Co00000_ooool01?l0003oooooo`000?ooool4o`0000Cooooo0ol000000ooooooo
0000o`000003o`0000;ooooo3Ol00002ooooo`?o00000_ooool?o`0000Cooooo1?l00002ooooo`06
o`000?oooooo0000o`000?oooooo00001?ooool6o`0000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;o00005Oooool002Wooooo00?o0000ooooooooool06oooool4o`00
00?ooooo00?o0000ooooool000000ol00005ooooo`;o00000_ooool2o`0000;ooooo1ol000001Ooo
oooo0000ooooool0003ooooo00Co00000oooool2o`000004ooooool0003o0000o`0000Cooooo1Ol0
0003ooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?l000000ooooooo0000o`000009ooooo`05o`000?ooooooooooooooool00000
0_ooool5o`000003ooooool0003o000000Ko00000_ooool2o`000003ooooool0003o000000Cooooo
1Ol00002ooooo`04o`000?oooooo0000ooooo`;o000000Soooooo`000?oooooo0000ooooool0003o
ooooo`0000Cooooo0ol00003ooooo`04o`000?oooooo0000ooooo`Co00001?ooool3o`0000;ooooo
1?l00002ooooo`;o000000?oooooo`000?l000002?l00002ooooo`?o00000_ooool>o`0000Gooooo
1?l00002ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool4o`000003ooooool0003ooooo
00;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co00005Oooool002Wooooo00?o0000oooo
ooooool06oooool4o`0000?ooooo00?o0000ooooool000000ol00005ooooo`;o00000_ooool2o`00
00;ooooo1ol000001Ooooooo0000ooooool0003ooooo00Co00000oooool6o`0000Cooooo1Ol00003
ooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`04o`000?ooooooooooooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000009ooooo`;o00000_ooool00ol0003ooooooooo
o`05o`0000;ooooo1ol00002ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo00Co
0000ooooool0003ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00001?ooool2
o`0000Cooooo00Co0000ooooool0003ooooo1?l00004ooooo`?o00000_ooool4o`0000;ooooo0_l0
00000ooooooo0000o`000008o`0000;ooooo0ol00002ooooo`ko00001Oooool4o`0000;ooooo00Ko
0000ooooool0003o0000ooooool00004ooooo`Co000000?oooooo`000?ooool00_ooool7o`000003
ooooool0003o000000;o00005Oooool002Wooooo00?o0000ooooooooool06oooool4o`0000?ooooo
00?o0000ooooool000000ol00005ooooo`;o00000_ooool2o`0000;ooooo1ol000001Ooooooo0000
ooooool0003ooooo00Co00000oooool6o`0000Cooooo1_l00002ooooo`;o00001Oooool2o`0000Co
oooo1?l00002ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000009ooooo`05o`000?ooooooooooooooool000000oooool4o`0000;ooooo1ol00002
ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo00Co0000ooooool0003ooooo0ol0
0002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?oooooo0000ooooo`Co00001?ooool3o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00002?l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000So00001Oooool4o`0000;o
oooo00Ko0000ooooool0003o0000ooooool00004ooooo`Co000000?oooooo`000?ooool00_ooool4
o`000006ooooool0003oooooooooool0003ooooo0_l0000Eooooo`00:Oooool00ol0003ooooooooo
o`0Eooooo`;o00001?ooool4o`0000?ooooo00?o0000ooooool000000ol00005ooooo`;o00000_oo
ool2o`0000;ooooo1ol000001Ooooooo0000ooooool0003ooooo00Co00000oooool6o`0000Cooooo
1Ol00003ooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?l000001_l00009ooooo`05o`000?ooooooooooooooool000000oooool4o`00
00;ooooo1ol00002ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo00Co0000oooo
oooooooooooo0ol00002ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`04o`000?oooooo0000ooooo`Co00001?ooool3o`0000;ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000002?l00003ooooo`;o00000_ooool3o`000003ooooool0003o000000So0000
1Oooool4o`0000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00Ko0000
ooooool0003o0000ooooool00003ooooo`Co000000Koooooo`000?ooooooooooo`000?ooool2o`00
01Gooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00004ooooo`Co00000oooool00ol0003o
ooooo`000003o`0000Cooooo0ol00002ooooo`;o00000_ooool7o`000005ooooool0003oooooo`00
0?ooool01?l00003ooooo`Ko00001?ooool5o`0000?ooooo0_l00005ooooo`;o00000oooool8o`00
00?ooooo0_l000000ooooooo0000o`000006o`0000Wooooo00Go0000ooooooooooooooooo`000003
ooooo`Co00000_ooool7o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`04o`000?oooooo
0000o`0000;ooooo00Co0000oooooooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`Co00001?ooool3o`00
00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000002?l00003ooooo`;o00000_ooool3o`00
0003ooooool0003o000000So00001Oooool4o`0000;ooooo00So0000ooooool0003o0000ooooool0
003oooooo`0000;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`Co000000Koooooo`00
0?ooooooooooo`000?ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00004
ooooo`Co00000oooool6o`0000Cooooo0ol00002ooooo`;o00000_ooool7o`000003ooooool0003o
oooo00Ko00000oooool7o`0000?ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooo`000002
ooooo`So00000oooool2o`000003ooooool0003o000000Oo00002?ooool01Ol0003ooooooooooooo
oooo000000?ooooo1?l00002ooooo`Oo00000_ooool2o`000003ooooool0003o000000Gooooo00Co
0000ooooool0003o00000_ooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`Co00001?ooool3o`00
00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000ooooo`02oooo
o`;o00000_ooool3o`000003ooooool0003o000000So00001_ooool3o`0000;ooooo00So0000oooo
ool0003o0000ooooool0003oooooo`0000;ooooo00Ko0000ooooool0003o0000ooooool00003oooo
o`Co000000Koooooo`000?ooooooooooo`000?ooool2o`0001Gooooo000Yooooo`;o00005_ooool2
o`0000Cooooo1?l00003ooooo`Ko00000oooool4o`0000;ooooo0_l00002ooooo`Wo000000?ooooo
o`000?l000001?l00003ooooo`Oo00000oooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooo
000000;ooooo2?l00003ooooo`;o000000?oooooo`000?l000001_l00009ooooo`05o`000?oooooo
ooooooooool000000oooool4o`0000;ooooo1ol00002ooooo`;o000000?oooooo`000?l000001Ooo
ool01?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooooooo`Co000000?oooooo`000?oo
ool03Oooool00ol0003oooooo`000002ooooo`?o00001?ooool3o`0000?ooooo0ol00003ooooo`03
o`000?oooooo000000Oo000000?oooooo`000?ooool00_ooool2o`0000;ooooo0ol000000ooooooo
0000o`000008o`0000Kooooo0ol00002ooooo`08o`000?oooooo0000o`000?oooooo0000ooooool0
0002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool4o`000006ooooool0003ooooooooo
ool0003ooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00001?ooool4o`00
00?ooooo1_l00003ooooo`Co00000_ooool2o`0000;ooooo2Ol000000ooooooo0000o`000004o`00
00?ooooo1ol00003ooooo`Ko00000_ooool2o`0000Cooooo0_l000001?oooooo0000ooooooooool8
o`0000?ooooo0_l000000ooooooo0000o`000006o`0000Wooooo00Go0000ooooooooooooooooo`00
0003ooooo`Co00000_ooool7o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`04o`000?oo
oooo0000o`0000;ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooool000000_ooool3o`0000Cooooo0ol00003ooooo`?o00000oooool01Ol0003o
ooooo`000?l0003ooooo00Go000000?oooooo`000?ooool00_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000004o`000004ooooool0003o0000o`0000Kooooo0ol00002ooooo`08o`000?oooooo
0000o`000?oooooo0000ooooool00002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool4
o`000006ooooool0003oooooooooool0003ooooo0_l0000Eooooo`00:Oooool00ol0003ooooooooo
o`0Eooooo`;o00001?ooool4o`0000?ooooo1_l00003ooooo`Co00000_ooool2o`0000;ooooo2Ol0
00000ooooooo0000o`000004o`0000?ooooo1ol00003ooooo`Oo000000?oooooo`000?l000001?oo
ool01?l0003oooooooooool00002ooooo`So00000oooool2o`000003ooooool0003o000000Ko0000
0oooool2o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`Co00000_ooool7o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooo
oooooooooooo0ol00002ooooo`03o`000?oooooooooo017ooooo0ol00004ooooo`;o00001?ooool3
o`0000Gooooo0_l000002?oooooo0000o`000?l0003oooooo`000?oooooo00000oooool2o`0000?o
oooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000Kooooo0ol00002oooo
o`08o`000?oooooo0000o`000?oooooo0000ooooool00002ooooo`06o`000?oooooo0000o`000?oo
oooo00000oooool4o`000006ooooool0003oooooooooool0003ooooo0_l0000Eooooo`00:Oooool0
0ol0003oooooooooo`0Eooooo`;o00001?ooool4o`0000?ooooo1_l00002ooooo`Go00000_ooool2
o`0000;ooooo4?l00003ooooo`Oo00000oooool:o`0000Cooooo00Co0000oooooooooooo00000_oo
ool8o`0000?ooooo0_l000000ooooooo0000o`000007o`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0000?ooooo00Co0000oooooooooooooooo1?l00002ooooo`Oo00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`04o`000?ooooooooooooooo`Co000000?oooooo`000?oo
ool04_ooool3o`0000Cooooo0_l00004ooooo`?o00001Oooool2o`000008ooooool0003o0000o`00
0?oooooo0000ooooool00003ooooo`;o00000oooool2o`000003ooooool0003o000000Co000000Co
ooooo`000?l0003o00001_ooool3o`0000;ooooo00So0000ooooool0003o0000ooooool0003ooooo
o`0000;ooooo1?l000000ooooooo0000ooooo`02ooooo`Co00001?ooool01?l0003oooooo`000?l0
000Eooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00001?ooool4o`0000?ooooo1_l00002
ooooo`Go000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000co00000_oo
ool7o`0000?ooooo2_l00004ooooo`04o`000?ooooooooooo`0000;ooooo2Ol00002ooooo`;o0000
00?oooooo`000?l000001ol00002ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`?o00000oooool7o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`04
o`000?ooooooooooo`0000?ooooo0ol00002ooooo`03o`000?oooooooooo017ooooo0ol00004oooo
o`?o00000oooool3o`0000Gooooo0_l000002?oooooo0000o`000?l0003oooooo`000?oooooo0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000Oo
oooo0_l00004ooooo`;o000000Coooooo`000?oooooo00000_ooool00ol0003oooooo`000003o`00
00?ooooo1?l00004ooooo`04o`000?oooooo0000o`0001Gooooo000Yooooo`03o`000?oooooooooo
01Gooooo0_l00004ooooo`Co00000oooool6o`0000;ooooo2Ol00002ooooo`;o000000?oooooo`00
0?l000002ol00003ooooo`Oo00000oooool:o`0000Cooooo00Co0000oooooooooooo00000_ooool:
o`000004ooooool0003o0000ooooo`Wo00000_ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l000000ooooooo0000o`000008ooooo`04o`000?ooooooooooo`0000?ooooo0ol00002ooooo`03
o`000?oooooooooo017ooooo0ol00004ooooo`;o00001?ooool3o`0000Gooooo0_l000002?oooooo
0000o`000?l0003oooooo`000?oooooo00000oooool2o`0000?ooooo0_l00002ooooo`?o000000?o
ooooo`000?ooool00_l00008ooooo`;o00001?ooool2o`000004ooooool0003oooooo`0000;ooooo
00?o0000ooooool000000ol00003ooooo`Co00001?ooool01?l0003oooooo`000?l0000Eooooo`00
:Oooool00ol0003oooooooooo`0Eooooo`;o00000_ooool00ol0003oooooo`000003o`0000?ooooo
1_l00002ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`go0000
0oooool7o`0000?ooooo2ol00003ooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo
0000o`000005o`000004ooooool0003o0000ooooo`Wo00000_ooool00ol0003oooooooooo`02oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`04o`000?ooooooooooooooo`?o00000_oo
ool00ol0003oooooooooo`0Aooooo`?o00001?ooool2o`0000Cooooo0ol00005ooooo`;o000000So
ooooo`000?l0003o0000ooooool0003oooooo`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00
00;ooooo00Co0000ooooool0003o00002?ooool2o`0000Cooooo0_l000001?oooooo0000ooooool0
0002ooooo`03o`000?oooooo000000?o00000oooool4o`0000Kooooo0_l0000Eooooo`00:Oooool0
0ol0003oooooooooo`0Eooooo`;o00000_ooool00ol0003oooooo`000003o`0000?ooooo1_l00002
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000002Ol000000ooooooo0000o`000006o`0000;ooooo3?l00003ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000Oo00000_oo
ool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00000ooo
ool01?l0003oooooo`000?l0000;ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooo000000Cooooo0_l00004ooooo`?o00001Oooool2o`000008
ooooool0003o0000o`000?oooooo0000ooooool00003ooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`04o`000?oooooo0000o`0000Sooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
00000_ooool00ol0003oooooo`000003o`0000?ooooo1Ol00005ooooo`;o00005Oooool002Wooooo
0_l0000Fooooo`;o00000_ooool7o`0000;ooooo1_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Wo0000
00Coooooo`000?l0003ooooo1Ol00002ooooo`co00000oooool01Ol0003oooooooooool0003ooooo
00?o000000?oooooo`000?l000002?l000000ooooooo0000o`000007o`000003ooooool0003o0000
00Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00003ooooo`04o`000?oooooo0000
o`0000_ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooo`000004ooooo`;o00001?ooool3o`0000Gooooo0_l000001?oooooo0000o`000?l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`04o`00
0?oooooo0000o`0000Sooooo0_l00004ooooo`03o`000?oooooooooo00?o00000_ooool00ol0003o
ooooo`000003o`0000?ooooo1?l00006ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool0
5Oooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l000000ooooooo0000
o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000;ooooo
3Ol000000ooooooo0000o`000003o`0000;ooooo3?l000001?oooooo0000ooooool00002ooooo`03
o`000?oooooo000000;o000000?oooooo`000?l000002?l000000ooooooo0000o`000007o`000003
ooooool0003o000000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
00002oooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooo000000Cooooo0_l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`00
00?ooooo00Co0000oooooooooooooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00Co0000
ooooool0003o00002?ooool2o`0000Cooooo00?o0000ooooooooool00ol00002ooooo`03o`000?oo
oooo000000?o00001?ooool3o`0000Kooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0E
ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000004o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00000_ooool=
o`000003ooooool0003o000000?o00000_ooool<o`000004ooooool0003oooooo`0000;ooooo00?o
0000ooooool000003Ol000000ooooooo0000o`000007o`000003ooooool0003o000000Cooooo0_l0
000=ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00002oooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooo`000?l00008
ooooo`;o00001?ooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooool000000ol00004
ooooo`?o00001_ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo01Gooooo0ol000000ooo
oooo0000o`000006o`000003ooooool0003o000000Co000000?oooooo`000?l000000ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00002ooooo`go000000?oooooo`00
0?l000000ol00002ooooo`co000000Coooooo`000?oooooo00000_ooool5o`000003ooooool0003o
000000So000000?oooooo`000?l000001ol000000ooooooo0000o`000004ooooo`;o00003Oooool2
o`000003ooooool0003o000000;o00001Oooool2o`0000_ooooo00?o0000ooooooooool00_ooool2
o`0001Sooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`04o`000?oooooo0000o`0000Sooooo0_l00004ooooo`03o`000?oooooooooo
00?o00000_ooool00ol0003oooooo`000003o`0000Cooooo0ol00006ooooo`;o00005Oooool002Wo
oooo00?o0000ooooooooool05Oooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00001?l000000ooooooo0000o`000003o`000003ooooool0003o000000Go00000_ooool2o`0000;o
oooo3Ol000000ooooooo0000o`000003o`0000;ooooo3?l000001?oooooo0000ooooool00002oooo
o`Go000000?oooooo`000?l000002?l000000ooooooo0000o`000007o`000003ooooool0003o0000
00Cooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000_ooooo00?o0000
ooooooooool00_ooool2o`0001Sooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`04o`000?oooooo0000o`0000Sooooo0_l00004oooo
o`03o`000?oooooooooo00?o000000Coooooo`000?l0003ooooo1?l00004ooooo`?o00001_ooool2
o`0001Gooooo000Yooooo`03o`000?oooooooooo01Gooooo0ol000000ooooooo0000o`000006o`00
0003ooooool0003o000000Co000000?oooooo`000?l000000ol000000ooooooo0000o`000005o`00
00;ooooo0_l00002ooooo`go000000?oooooo`000?l000000ol00002ooooo`co000000Coooooo`00
0?oooooo00000_ooool5o`000003ooooool0003o000000So000000?oooooo`000?l000001ol00000
0ooooooo0000o`000003ooooo`?o00003Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l0
000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Hooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooo`00
0?ooool00_l00008ooooo`;o00001?ooool00ol0003oooooooooo`03o`000004ooooool0003o0000
ooooo`Co00001?ooool3o`0000Kooooo00?o0000ooooooooool05?ooool002Wooooo00?o0000oooo
ooooool05Oooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l000000ooo
oooo0000o`000003o`000003ooooool0003o000000Go00000_ooool2o`0000;ooooo3Ol000000ooo
oooo0000o`000003o`0000;ooooo3?l000001?oooooo0000ooooool00002ooooo`Go000000?ooooo
o`000?l000002?l000000ooooooo0000o`000007o`000003ooooool0003o000000?ooooo0ol0000=
ooooo`;o000000Coooooo`000?l0003o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo0_l0000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01_ooool2o`0000Cooooo00?o0000ooooooooool00ol000001?oooooo0000o`000?ooool4
o`0000Cooooo0ol00006ooooo`03o`000?oooooooooo01Cooooo000Yooooo`03o`000?oooooooooo
01Gooooo2?l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000ol00000
0ooooooo0000o`000005o`0000;ooooo0_l00002ooooo`go000000Koooooo`000?l0003o0000oooo
ool00002ooooo`co000000Coooooo`000?oooooo00000_ooool5o`000003ooooool0003o000000co
000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`?o00003Oooool2o`000004
ooooool0003o0000o`0001?ooooo00?o0000ooooooooool00_ooool2o`0001Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Sooooo0_l00004ooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`?o00001_ooool00ol0003oooooooooo`0Dooooo`00:Oooool2o`0001Kooooo2?l00000
1Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000ol000000ooooooo0000o`00
0005o`0000;ooooo0_l00002ooooo`go000000Koooooo`000?l0003o0000ooooool00002ooooo`Co
00000_ooool6o`000004ooooool0003oooooo`0000;ooooo1Ol000000ooooooo0000o`00000<o`00
00;ooooo1?l000000ooooooo0000o`000003ooooo`?o00003Oooool2o`000004ooooool0003o0000
o`0001?ooooo00?o0000ooooooooool00_ooool2o`0001Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
0004ooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0003ooooo1?l00004ooooo`?o0000
1_ooool00ol0003oooooooooo`0Dooooo`00:Oooool00ol0003oooooooooo`0Eooooo`Oo00000_oo
ool3o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Go00000_ooool01?l0003oooooooooooooool=o`000006ooooool0003o0000o`00
0?oooooo00000_ooool4o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol0
00000ooooooo0000o`00000<o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`?o00003Ooo
ool2o`000004ooooool0003o0000o`0001?ooooo00?o0000ooooooooool00_ooool2o`0001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l00004ooooo`03o`000?oooooooooo00?o000000Koooooo`000?l0
003oooooo`000?ooool2o`0000Cooooo0ol00006ooooo`03o`000?oooooooooo01Cooooo000Yoooo
o`03o`000?oooooooooo01Gooooo1ol00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol00002ooooo`04o`000?oooooo
ooooooooo`go000000Koooooo`000?l0003o0000ooooool00002ooooo`Co00000_ooool6o`000004
ooooool0003o0000o`0000;ooooo1Ol000000ooooooo0000ooooo`0<o`0000;ooooo1?l000000ooo
oooo0000o`000003ooooo`?o00003Oooool2o`0000;ooooo0_l0000Cooooo`03o`000?oooooooooo
00;ooooo0_l0000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00
00Kooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003oooooooooo`03o`00
0006ooooool0003o0000ooooool0003ooooo0_l00004ooooo`?o00001_ooool00ol0003ooooooooo
o`0Dooooo`00:Oooool00ol0003oooooooooo`0Eooooo`Oo00000_ooool3o`000004ooooool0003o
0000o`0000;ooooo00?o0000ooooool000001?l000000ooooooo0000o`000005o`0000;ooooo00Co
0000oooooooooooooooo3Ol000001_oooooo0000o`000?l0003oooooo`0000;ooooo1?l00002oooo
o`?o000000Coooooo`000?l0003ooooo0ol00002ooooo`Go000000?oooooo`000?ooool03?l00002
ooooo`Co000000Coooooo`000?l0003o00000_ooool3o`0000gooooo0_l00002ooooo`;o00004ooo
ool00ol0003oooooooooo`02ooooo`;o00006?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0_l00006ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Aooooo`;o00001?ooool00ol0003oooooooooo`06o`000003oooo
ool0003ooooo00;o00001?ooool3o`0000Kooooo00?o0000ooooooooool05?ooool002Wooooo00?o
0000ooooooooool05Oooool7o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`03o`00
0?oooooo000000Co000000?oooooo`000?l000001Ol00002ooooo`04o`000?ooooooooooooooo`go
000000?oooooo`000?l000000_ooool00ol0003oooooooooo`04o`0000;ooooo0ol000001?oooooo
0000o`000?ooool3o`0000;ooooo1?l00002ooooo`03o`000?oooooo000000[o00000oooool4o`00
0003ooooool0003o000000?ooooo0ol0000=ooooo`;o00000_ooool2o`0001?ooooo00?o0000oooo
ooooool00_ooool2o`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`;o00001_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04Oooool2o`0000Cooooo00?o0000ooooooooool01_l000000ooooooo0000ooooo`02
o`0000Cooooo0ol00006ooooo`03o`000?oooooooooo01Cooooo000Yooooo`03o`000?oooooooooo
01Gooooo1ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooo`000004
o`000003ooooool0003o000000Co00000oooool01?l0003oooooooooooooool=o`000003ooooool0
003o000000;ooooo00?o0000ooooooooool01?l00002ooooo`?o000000Coooooo`000?l0003ooooo
0ol00002ooooo`Co00000_ooool00ol0003oooooo`00000:o`0000?ooooo1?l000000ooooooo0000
o`000003ooooo`?o00003Oooool2o`0000;ooooo0_l0000Hooooo`;o00006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`;o00001?ooool00ol0003o
ooooooooo`06o`000003ooooool0003ooooo00;o00001?ooool3o`0001gooooo0007ooooo`Co0000
00Co410@oooooooooooooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05Oooool7o`0000;ooooo0ol000001?oo
oooo0000o`000?l00002ooooo`03o`000?oooooo000000?o00000_ooool6o`0000?ooooo00Co0000
oooooooooooooooo1Ol00003ooooo`Go000000?oooooo`000?l000000_ooool00ol0003ooooooooo
o`04o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1?l00002ooooo`03o`00
0?oooooooooo00[o00000oooool4o`000003ooooool0003o000000?ooooo0ol0000=ooooo`;o0000
0_ooool2o`0001Sooooo0_l0000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo017ooooo0_l00004ooooo`03o`000?oooooooooo00Ko000000?oooooo`000?oo
ool00_l00004ooooo`?o00007Oooool000Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo
1ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooo`000003o`0000;o
oooo1_l00003ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000oooool5o`00
0003ooooool0003o000000;ooooo00?o0000ooooooooool01?l00002ooooo`?o000000?oooooo`00
0?l000001?l00002ooooo`Co00000_ooool00ol0003oooooooooo`0:o`0000?ooooo1?l000000ooo
oooo0000o`000003ooooo`;o00003_ooool2o`0000;ooooo0_l0000Hooooo`;o00006?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_l000000ooooooo0000ooooo`02o`0000Cooooo0ol0000M
ooooo`001?l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`?o00005Oooool7o`0000;ooooo1ol00002ooooo`03o`000?oooooo0000
00?o00000_ooool6o`0000?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000003
ooooo`Go000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`0000;ooooo0ol00000
0ooooooo0000o`000004o`0000;ooooo1?l00002ooooo`03o`000?oooooooooo00[o00000oooool4
o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00000_ooool2o`0001Sooooo0_l0000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00Co0000
oooooooooooo00001Oooool2o`0000Oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Ko000000?oooooo`000?ooool00_l00004ooooo`?o00007Ooo
ool000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool05Oooool7o`0000;ooooo1ol00002ooooo`03o`000?oooooo
000000?o00000_ooool6o`0000?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
0003ooooo`Go000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`0000;ooooo0_l0
0002ooooo`Ko00000_ooool4o`0000;ooooo00?o0000ooooooooool02_l00003ooooo`Co000000?o
ooooo`000?l000000oooool2o`0000kooooo0_l00002ooooo`;o00006?ooool2o`0001Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Ko000000?oooooo`000?ooool00_l00004ooooo`?o0000
7Oooool000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Eooooo`Oo00000_ooool7o`0000;ooooo
00?o0000ooooool000000ol00002ooooo`Ko00000oooool01?l0003oooooooooooooool2o`000003
ooooool0003o000000?ooooo1Ol000000ooooooo0000o`000002ooooo`03o`000?oooooo000000Co
00000_ooool2o`0000;ooooo1_l00002ooooo`Co00000_ooool00ol0003oooooooooo`0:o`0000?o
oooo1?l000000ooooooo0000o`000003ooooo`;o00003_ooool2o`0000;ooooo0_l0000Iooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool2o`0000Kooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06o`000003ooooool0003ooooo00;o00001?ooool3o`00
01gooooo0009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Gooooo1ol00002ooooo`Oo00000_ooool01?l0003o
ooooo`000?ooool2o`0000;ooooo1_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo1Ol000000ooooooo0000o`000002ooooo`05o`000?oooooo0000o`000?ooool00_l00002
ooooo`;o00000_ooool6o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00[o00000oooool2
o`000003ooooool0003ooooo00;o00000oooool2o`0000kooooo0_l00002ooooo`;o00006Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo1_l000000ooooooo0000ooooo`02o`0000Cooooo0_l0000Nooooo`002Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Eooooo`Oo00000_ooool00ol0003oooooo`000004o`0000;ooooo00Co0000
ooooool0003ooooo0_l00002ooooo`Ko00000oooool01?l0003oooooooooooooool2o`000003oooo
ool0003o000000?ooooo1Ol000000ooooooo0000o`000002ooooo`05o`000?oooooo0000o`000?oo
ool00_l00002ooooo`;o00000_ooool6o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00?o
000000?oooooo`000?l000000ol00005ooooo`04o`000?oooooo0000ooooo`?o00000_ooool2o`00
00kooooo0_l00002ooooo`;o00006Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo0_l00006ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1_l000000ooooooo0000ooooo`02
o`0000Cooooo0_l0000Nooooo`001oooool00omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo0000
00gooooo1?l00006ooooo`03o`000?oooooooooo01Gooooo1ol00002ooooo`03o`000?oooooo0000
00Co00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo1_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool01?l0003oooooooooooooool5o`000003ooooool0003o000000;ooooo
1?l00002ooooo`03o`000?oooooooooo00;o00000_ooool6o`0000?ooooo0ol00002ooooo`03o`00
0?oooooooooo00?o000000?oooooo`000?l000000ol00005ooooo`04o`000?oooooo0000ooooo`?o
00000_ooool2o`0000kooooo0_l00002ooooo`;o00006Oooool00ol0003oooooooooo`0Fooooo`;o
00002Oooool2o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool6o`000003ooooool0003ooooo00;o
00001?ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01Gooooo1_l00003ooooo`03o`00
0?oooooo000000Co00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo0ol000000ooooooo
0000o`000003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooooooool5
o`000003ooooool0003ooooo00;ooooo1?l00002ooooo`03o`000?oooooooooo00;o00000_ooool6
o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000000ol00005
ooooo`04o`000?oooooo0000ooooo`?o00000_ooool2o`0000kooooo0_l00002ooooo`;o00006Ooo
ool00ol0003oooooooooo`0Qooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01_ooool6o`000003ooooool0003ooooo00;o00001?oo
ool2o`0001kooooo000Yooooo`03o`000?oooooooooo01Gooooo1Ol00004ooooo`03o`000?oooooo
000000?o00000oooool01?l0003oooooo`000?ooool2o`0000;ooooo0ol000000ooooooo0000o`00
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooooooool5o`000003
ooooool0003ooooo00;ooooo1?l00002ooooo`03o`000?oooooooooo00;o00000_ooool6o`0000?o
oooo0ol00002ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000000ol00005ooooo`04
o`000?oooooo0000ooooo`?o00000_ooool2o`0000kooooo0_l00002ooooo`;o00006Oooool00ol0
003oooooooooo`0Qooooo`;o00006?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo1_l000000ooooooo0000ooooo`02o`0000Cooooo0_l0000Nooooo`00:Oooool2o`0001Ko
oooo1Ol00004ooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooo`000?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`04o`000?ooooooooooooooo`;o00000_ooool0
1?l0003oooooooooooooool4o`0000;ooooo00Co0000oooooooooooooooo1?l00002ooooo`03o`00
0?oooooooooo00;o00000_ooool6o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000000ol00005ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`;o00003oooool00ol0003oooooooooo`02o`0001Wooooo00?o0000ooooooooool08Oooool2o`00
01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`Ko000000?oooooo`00
0?ooool00_l00004ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool05Oooool5o`0000Co
oooo00?o0000ooooool000000ol00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`00
0003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`Co00000_ooool01?l0003oooooooooooooool4o`0000;ooooo00?o0000ooooooooool00_l0
0003ooooo`Go00000oooool3o`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000o`00
0003o`0000Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0000?ooooo`03
o`000?oooooooooo00;o00006Oooool00ol0003oooooooooo`0Qooooo`;o00006?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000ol000000ooooooo
0000ooooo`02o`0000Cooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Eooooo`Go0000
1?ooool00ol0003oooooo`000003o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`03
o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00?ooooo1Ol000000ooooooo0000ooooo`02ooooo`Co00000_ooool00ol0003oooooooooo`02o`00
00?ooooo1Ol00003ooooo`?o00001Oooool3o`000003ooooool0003ooooo00?o00001Oooool01ol0
003oooooo`000?oooooo0000ooooool000000_ooool2o`0000oooooo00Go0000oooooooooooooooo
o`00000Iooooo`03o`000?oooooooooo027ooooo0_l0000Hooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`000003o`000003ooooool0003ooooo00;o0000
1?ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01Gooooo1Ol00004ooooo`03o`000?oo
oooo000000?o00000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`Co
00000_ooool01?l0003oooooooooooooool4o`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`Go00000oooool3o`0000Gooooo0ol000000ooooooo0000o`000002o`0000Kooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l0000?ooooo`05o`000?ooooooooooooooool0
00006Oooool00ol0003oooooooooo`0Qooooo`;o00006?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000000ol000001Ooooooo0000oooooooooooo0000
00Cooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Eooooo`Go00001?ooool00ol0003o
ooooo`000003o`0000?ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`02o`0000So
oooo00?o0000ooooooooool01?ooool4o`0000;ooooo00Co0000oooooooooooooooo1?l00002oooo
o`03o`000?oooooooooo00Gooooo1Ol00003ooooo`?o00001Oooool3o`000003ooooool0003ooooo
00;o00001_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000oooooo00Go
0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo027ooooo0_l0000Hooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003o`000005oooo
ool0003oooooooooool000001?ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01Gooooo
1Ol00004ooooo`03o`000?oooooo000000?o00000oooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo00;o00002?ooool00ol0003oooooooooo`04ooooo`Co00000_ooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`Go00000oooool3o`0000Gooooo
00?o0000ooooool000000oooool2o`0000Kooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo0_l0000?ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooo000000?o000000?oooooo`000?ooool01_ooool2o`0001kooooo000Yoooo
o`03o`000?oooooooooo01Gooooo1Ol00004ooooo`03o`000?oooooo000000?o00000oooool3o`00
00Kooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00Cooooo1?l00002oooo
o`03o`000?oooooooooo00;ooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo1Ol00003oooo
o`?o00001Oooool00ol0003oooooo`000003ooooo`;o00001_ooool02?l0003oooooo`000?oooooo
0000ooooool0003ooooo0ol0000?ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool000000ol000000ooooooo
0000ooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Eooooo`Go00001?ooool00ol0003ooooo
o`000003o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00;o00002?ooool00ol0003ooooo
ooooo`04ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003ooooo
ooooo`05ooooo`Go00000oooool3o`0000Gooooo00?o0000ooooool000000oooool2o`0000Kooooo
00Ko0000ooooool0003oooooo`000?ooool5o`0000oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool000000ol0000Yoooo
o`00:Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go00001?ooool00ol0003o
ooooo`000003o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00;o00002?ooool00ol0003o
ooooooooo`04ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003o
ooooooooo`05ooooo`Go00000oooool3o`0000Gooooo00?o0000ooooool000000oooool2o`0000Ko
oooo0ol000000ooooooo0000ooooo`05o`0000oooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooo000000?o0000:Oooool002Wooooo0_l0000Cooooo`03o`00
0?oooooooooo00Go00001?ooool00ol0003oooooo`000003o`0000Cooooo0_l00006ooooo`03o`00
0?oooooooooo00;o00002?ooool00ol0003oooooooooo`04ooooo`Co00000_ooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`Go00000oooool3o`0000Gooooo
00?o0000ooooool000000oooool2o`0000Kooooo00Ko0000ooooool0003oooooo`000?ooool5o`00
00oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo0000
00?o0000:Oooool002Wooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o000000?o
00001?ooool00ol0003oooooo`000003o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00;o
00002?ooool00ol0003oooooooooo`04ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`?o
00000_ooool00ol0003oooooooooo`05ooooo`Go00000oooool3o`0000Gooooo00?o0000ooooool0
00000oooool2o`0000Kooooo00Ko0000ooooool0003oooooo`000?ooool5o`00057ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooo`000003o`0002Wooooo000Yooooo`03o`000?oooooooooo
01;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooool000000ol00004oooo
o`;o00001_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool4
o`0000;ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo00?o0000ooooooooool01Oooool5
o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`06o`000?oooooo
0000ooooool0003ooooo1Ol0001Aooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000
0ol0000Yooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?l000000ol0
0004ooooo`03o`000?oooooo000000?o00001?ooool2o`0000Kooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`03o`000?oooooooooo00Gooooo1Ol00003ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`;o00001_ooool01_l0003oooooo`000?oooooo0000ooooo`Go0000DOooool00ol0
003oooooooooo`0dooooo`03o`000?oooooo000000;o0000:_ooool002Wooooo00?o0000oooooooo
ool04_ooool3o`000003ooooool0003o000000;o00001?ooool01_l0003oooooo`000?l0003ooooo
o`0000Cooooo0_l00006ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`07ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000;ooooo`Co00000oooool2o`0000Kooooo
00?o0000ooooooooool00oooool2o`0000Kooooo00Ko0000ooooool0003oooooo`000?ooool5o`00
057ooooo00?o0000ooooooooool0=_ooool3o`0002[ooooo000Yooooo`03o`000?oooooooooo01;o
oooo0ol000000ooooooo0000ooooo`02o`0000Cooooo00Ko0000ooooool0003o0000ooooool00004
ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool00004ooooo`?o00002oooool4o`0000?ooooo0_l00006ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01_l0003oooooo`000?oooooo0000oooo
o`Go0000DOooool00ol0003oooooooooo`0fooooo`?o0000:_ooool002Wooooo00?o0000oooooooo
ool04_ooool3o`000003ooooool0003ooooo00;o00001?ooool01_l0003oooooo`000?l0003ooooo
o`0000Cooooo0_l00006ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`07ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000<ooooo`Co00000oooool2o`0000Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`Go000000?oooooo`000?l00000
0ol0001Aooooo`03o`000?oooooooooo03Oooooo0_l0000Zooooo`00:Oooool00ol0003ooooooooo
o`0Aooooo`Ko000000?oooooo`000?l000001?ooool01_l0003oooooo`000?l0003oooooo`0000Co
oooo0_l00006ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0000Cooooo0_l0000<ooooo`Co00000oooool2o`0000Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000ooooo`Go0000DOoo
ool00ol0003oooooooooo`0gooooo`;o0000:_ooool002Wooooo0_l0000Aooooo`Go000000?ooooo
o`000?l000000_l00004ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool2o`0000Kooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooo00001?ooool2o`0000cooooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000o`000003o`0008_ooooo0_l0000Zoooo
o`00:Oooool00ol0003oooooooooo`0@ooooo`Go000000?oooooo`000?ooool00_l00004ooooo`06
o`000?oooooo0000o`000?oooooo00001?ooool2o`0000Kooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`?o00001?ooool2o`0000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?l000000ol0
002;ooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool04?ooool5o`000003ooooool0003o
oooo00;o00001?ooool01_l0003oooooo`000?l0003oooooo`0000Cooooo0_l00006ooooo`05o`00
0?ooooooooooooooool000006_ooool2o`0000gooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000o`000003o`0008_o
oooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0@ooooo`Go000000?oooooo`000?ooool0
0_l00004ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool2o`0000Kooooo00Go0000oooo
ooooooooooooo`00000Jooooo`;o00003Oooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003o000000?o0000Roooool2
o`0002[ooooo000Yooooo`03o`000?oooooooooo013ooooo1Ol000000ooooooo0000ooooo`02o`00
00Cooooo00Co0000ooooool0003o00001_ooool2o`0000Kooooo00Go0000ooooooooooooooooo`00
000Jooooo`;o00003Oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000o`000003o`0008_ooooo0_l0
000Zooooo`00:Oooool00ol0003oooooooooo`0@ooooo`Go000000?oooooo`000?ooool00_l00004
ooooo`04o`000?oooooo0000o`0000Kooooo0_l00006ooooo`05o`000?ooooooooooooooool00000
6_ooool2o`0000gooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?l000000ol0002;ooooo`;o0000
:_ooool002Wooooo00?o0000ooooooooool04?ooool5o`000003ooooool0003ooooo00;o00001_oo
ool2o`0000Kooooo0_l00006ooooo`05o`000?ooooooooooooooool000006_ooool2o`0000gooooo
0_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool3o`000003oooo
ool0003o000000?o0000Roooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo013ooooo1Ol0
00000ooooooo0000ooooo`02o`0000Kooooo0_l00006ooooo`;o00001_ooool01Ol0003ooooooooo
oooooooo000001[ooooo0_l0000=ooooo`;o00001Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo0ol000000ooooooo0000o`000003o`0008_ooooo0_l0000Zooooo`00:Ooo
ool2o`00017ooooo1Ol000000ooooooo0000ooooo`02o`0000Kooooo0_l00006ooooo`;o00009Ooo
ool2o`0000gooooo0_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_oo
ool2o`0000;ooooo1Ol0002;ooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool04?ooool5
o`000003ooooool0003o000000;o00001_ooool2o`0000Kooooo0_l0000Uooooo`;o00003Oooool2
o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o00000_ooool5
o`0008cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool04?ooool5o`00
00?ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool2o`00
00gooooo0_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`00
00;ooooo1Ol0002<ooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo013o
oooo1Ol00003ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Co
oooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`;o00000_ooool2o`000003ooooool0003ooooo08cooooo00?o0000oooooooo
ool0:?ooool002Wooooo00?o0000ooooooooool04?ooool5o`0000Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Tooooo`;o00003_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Cooooo0_l00002ooooo`;o000000?oooooo`000?ooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`005oooool4o`000004oa0@4?ooooooooooooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`Ko00001?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Cooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool2o`0000;ooooo0_l0002?ooooo`03o`000?oooooooooo02Sooooo000Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`Ko00001?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo0_l0000>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0_l0002?ooooo`03o`000?oo
oooooooo02Sooooo000>ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`Oo00000oooool0
0ol0003oooooooooo`0<ooooo`;o00009Oooool2o`0000kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Dooooo`;o00000_ooool3o`0008kooooo00?o0000ooooooooool0:?ooool0
01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00002_ooool00ol0
003oooooooooo`02ooooo`Ko00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02Cooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool2o`00
00;ooooo0_l0002?ooooo`03o`000?oooooooooo02Sooooo000Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo1_l00004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool2o`0000ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`0008oo
oooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool6o`0000Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`;o00003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Cooooo0ol000000ooooooo0000o`00002?ooooo`03o`00
0?oooooooooo02Sooooo000Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo1_l00004ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool09?ooool2o`0000kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`0008oooooo00?o0000ooooooooool0:?oo
ool001Oooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`;o00003_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`;o0000Soooool00ol0003oooooooooo`0X
ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo1?l000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool2o`00
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`00
08oooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`;o000000Coooooo`000?oooooo00004oooool00ol0003oooooooooo`0Toooo
o`;o00003_ooool00ol0003oooooooooo`0Jooooo`;o00000_ooool2o`0008oooooo00?o0000oooo
ooooool0:?ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o
000000Coooooo`000?oooooo00004oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool06_ooool2o`0000;ooooo0_l0002?ooooo`03o`000?oooooooooo
02Sooooo000Yooooo`;o00002oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oo
oooo00004oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06_ooool2o`0000;ooooo0_l0002?ooooo`03o`000?oooooooooo02Sooooo000Yooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooo`00
01?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01[ooooo0_l00002ooooo`;o0000Soooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooool0000Coooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Joooo
o`;o00000_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02Sooooo000Yooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooo`00
01?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01[ooooo0_l00002ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0:?ooool002Wo
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00;o000000Coooooo`000?oo
oooo00004oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06_ooool2o`0000;ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Xoooo
o`00:Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooo`000?ooool00_l000001?oo
oooo0000ooooool0000Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Jooooo`;o0000Toooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo0000ooooool0000C
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0J
ooooo`;o0000Toooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0:oooo
o`Co000000Ooooooo`000?l0003oooooo`000?oooooo000003_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Jooooo`;o0000Toooool00ol0003oooooooooo`0Xooooo`00:Oooool2
o`0000_ooooo1ol000001?oooooo0000ooooool0000kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool06_ooool2o`0009?ooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000
ooooooooool02_ooool7o`000004ooooool0003oooooo`0003_ooooo00?o0000ooooooooool0:Ooo
ool2o`0009?ooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool02_ooool7
o`000004ooooool0003oooooo`0003_ooooo00?o0000ooooooooool0:Oooool2o`0009?ooooo00?o
0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool02_ooool7o`000004ooooool0003o
ooooo`0006Oooooo0_l0002Cooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooo
oooo00Wooooo2?l000001?oooooo0000ooooool0001Wooooo`;o0000Toooool00ol0003ooooooooo
o`0Xooooo`00:Oooool00ol0003oooooooooo`09ooooo`So000000Coooooo`000?oooooo0000Iooo
ool2o`000;kooooo000Yooooo`03o`000?oooooooooo00Wooooo2?l000001?oooooo0000ooooool0
001Wooooo`;o0000__ooool002Wooooo00?o0000ooooooooool02Oooool8o`000004ooooool0003o
ooooo`0006Oooooo0_l0002nooooo`00:Oooool2o`0000[ooooo2?l000001?oooooo0000ooooool0
001Wooooo`;o0000__ooool002Wooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o
000000?o000000Coooooo`000?oooooo0000Ioooool2o`000;kooooo000Yooooo`03o`000?oooooo
oooo00Wooooo0_l000000ooooooo0000o`000003o`000004ooooool0003oooooo`0006Oooooo0_l0
002nooooo`00:Oooool00ol0003oooooooooo`08ooooo`?o000000?oooooo`000?l000000ol00000
1?oooooo0000ooooool0001Wooooo`;o0000__ooool002Wooooo00?o0000ooooooooool02?ooool3
o`000003ooooool0003o000000?o000000Coooooo`000?oooooo0000Ioooool2o`000;kooooo000Y
ooooo`03o`000?oooooooooo00Sooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o
ooooo`0006Oooooo0_l0002nooooo`00:Oooool00ol0003oooooooooo`08ooooo`?o000000?ooooo
o`000?l000000ol000001?oooooo0000ooooool0001Wooooo`;o0000__ooool002Wooooo00?o0000
ooooooooool02?ooool3o`000003ooooool0003o000000;o00001?ooool00ol0003oooooooooo`1U
ooooo`;o0000__ooool002Wooooo0_l00009ooooo`?o000000?oooooo`000?l000000_l00004oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0_?ooool002Wooooo00?o0000oooooooo
ool02?ooool3o`000003ooooool0003o000000;o0000KOooool00ol0003oooooooooo`2looooo`00
:Oooool00ol0003oooooooooo`08ooooo`?o000000?oooooo`000?l000000_l0001]ooooo`03o`00
0?oooooooooo0;cooooo000Yooooo`03o`000?oooooooooo00Sooooo0ol000000ooooooo0000o`00
0002o`0006gooooo00?o0000ooooooooool0_?ooool002Wooooo00?o0000ooooooooool02?ooool3
o`000003ooooool0003o000000;o0000KOooool00ol0003oooooooooo`2looooo`00:Oooool00ol0
003oooooooooo`08ooooo`?o000000Coooooo`000?l0003o0000K_ooool00ol0003oooooooooo`2l
ooooo`001oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool3o`000004
ooooool0003o0000o`0006kooooo00?o0000ooooooooool0_?ooool000Wooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02?ooool3o`000004ooooool0003o0000o`0006kooooo00?o0000
ooooooooool0_?ooool000Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00002?ooool3o`000004ooooool0003o
0000o`0006kooooo00?o0000ooooooooool0_?ooool000Wooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`08ooooo`?o000000Coooooo`000?l0003o0000K_ooool00ol0003oooooooooo`2looooo`002Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool3o`000004ooooool0003o0000o`00
06kooooo00?o0000ooooooooool0_?ooool000Wooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`?o000000Coooooo`000?l0003o0000K_ooool00ol0003oooooooooo`2looooo`002Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo0ol000001?oooooo0000o`000?l0001^ooooo`03o`000?oo
oooooooo0;cooooo0007ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`?o000000Coooooo`000?l0003o0000
K_ooool00ol0003oooooooooo`2looooo`00:Oooool00ol0003oooooooooo`08ooooo`04o`000?oo
oooo0000ooooo`?o0000K_ooool00ol0003oooooooooo`2looooo`00:Oooool00ol0003ooooooooo
o`08ooooo`04o`000?oooooo0000ooooo`?o0000K_ooool00ol0003oooooooooo`2looooo`00:Ooo
ool2o`0000Wooooo00Co0000oooooooooooooooo0ol0001^ooooo`03o`000?oooooooooo0;cooooo
000Yooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo0ol0001^ooooo`03o`00
0?oooooooooo0;cooooo000Yooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo
0ol0001^ooooo`03o`000?oooooooooo0;cooooo000Yooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooooooo0ol0001^ooooo`03o`000?oooooooooo0;cooooo000Yooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooooooo0_l0001_ooooo`03o`000?oooooooooo0;cooooo
000Yooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo0_l0001_ooooo`03o`00
0?oooooooooo0;cooooo000Yooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo
0_l0001_ooooo`03o`000?oooooooooo0;cooooo000Yooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooooooo0_l0003ooooooboooooo000Yooooo`;o00002Oooool01?l0003ooooooooo
ooooool2o`000?oooooo;oooool002Wooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ooooool2o`000?oooooo;oooool002Wooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ooooool2o`000?oooooo;oooool002Wooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ooooool2o`000?oooooo;oooool002Wooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ooooool2o`000?oooooo;oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1663.45, -12.8269, 50.1966, \
0.0154598}}]
}, Open  ]],

Cell[TextData[{
  "For a period of time up to about 5000 timesteps, the system is caught in \
one of several metastable equilibria that exist for the ",
  Cell[BoxData[
      \(TraditionalForm\`M = 6\)]],
  " crystal [see Chapter 1, Sec. ",
  ButtonBox["1.4",
    ButtonData:>{"Chapter1.nb", "c:28"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (22)]. However, one can see that at about ",
  Cell[BoxData[
      \(TraditionalForm\`n = 6000\)]],
  " the system drops into a lower energy state, where it remains for the rest \
of the simulation. The average energy of this low-energy state is given \
below:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Uav[0.1]\  = \ Mean[Table[energy[n], {n, 6000, 12000}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.51"],

Cell[BoxData[
    \(\(-12.026086211382301`\)\)], "Output"]
}, Open  ]],

Cell["\<\
The magnitude of the fluctuations in the energy around this average \
value is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Delta]Uav\  = 
      Sqrt[\ Mean[Table[energy[n]^2, {n, 6000, 12000}]] - 
          Uav[ .1]^2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.52"],

Cell[BoxData[
    \(0.27350205401068683`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to estimate the error in the evaluation of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", we calculate and plot in Cell ",
  ButtonBox["8.48",
    ButtonData:>"Cell 8.48",
    ButtonStyle->"Hyperlink"],
  " the energy correlation function ",
  Cell[BoxData[
      \(TraditionalForm\`c(m)\)]],
  ", given by Eq. ",
  ButtonBox["(8.3.17)",
    ButtonData:>{"Chapter8.nb", "(8.3.17)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(c[
          m_]\ \  := \ \(c[
            m] = \ \ \((Sum[\((energy[n] - Uav[T])\)\ \((energy[n + m] - 
                        Uav[T])\), {n, 6000, 12000 - m}]/\((6000 - 
                    m)\))\)/\[Delta]Uav^2\);\)\), "\n", 
    \(\(Table[{m, c[m]}, {m, 0, 400, 4}];\)\), "\n", 
    \(\(ListPlot[%, PlotRange \[Rule] All, 
        AxesLabel \[Rule] {"\<m\>", "\<c(m)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.53"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00238095 0.0509589 0.552268 [
[.2619 .03846 -9 -9 ]
[.2619 .03846 9 0 ]
[.5 .03846 -9 -9 ]
[.5 .03846 9 0 ]
[.7381 .03846 -9 -9 ]
[.7381 .03846 9 0 ]
[.97619 .03846 -9 -9 ]
[.97619 .03846 9 0 ]
[1.025 .05096 0 -6 ]
[1.025 .05096 10.125 6 ]
[.01131 .16141 -18 -4.5 ]
[.01131 .16141 0 4.5 ]
[.01131 .27187 -18 -4.5 ]
[.01131 .27187 0 4.5 ]
[.01131 .38232 -18 -4.5 ]
[.01131 .38232 0 4.5 ]
[.01131 .49277 -18 -4.5 ]
[.01131 .49277 0 4.5 ]
[.01131 .60323 -6 -4.5 ]
[.01131 .60323 0 4.5 ]
[.02381 .64303 -14.0625 0 ]
[.02381 .64303 14.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .05096 m
.2619 .05721 L
s
[(100)] .2619 .03846 0 1 Mshowa
.5 .05096 m
.5 .05721 L
s
[(200)] .5 .03846 0 1 Mshowa
.7381 .05096 m
.7381 .05721 L
s
[(300)] .7381 .03846 0 1 Mshowa
.97619 .05096 m
.97619 .05721 L
s
[(400)] .97619 .03846 0 1 Mshowa
.125 Mabswid
.07143 .05096 m
.07143 .05471 L
s
.11905 .05096 m
.11905 .05471 L
s
.16667 .05096 m
.16667 .05471 L
s
.21429 .05096 m
.21429 .05471 L
s
.30952 .05096 m
.30952 .05471 L
s
.35714 .05096 m
.35714 .05471 L
s
.40476 .05096 m
.40476 .05471 L
s
.45238 .05096 m
.45238 .05471 L
s
.54762 .05096 m
.54762 .05471 L
s
.59524 .05096 m
.59524 .05471 L
s
.64286 .05096 m
.64286 .05471 L
s
.69048 .05096 m
.69048 .05471 L
s
.78571 .05096 m
.78571 .05471 L
s
.83333 .05096 m
.83333 .05471 L
s
.88095 .05096 m
.88095 .05471 L
s
.92857 .05096 m
.92857 .05471 L
s
.25 Mabswid
0 .05096 m
1 .05096 L
s
gsave
1.025 .05096 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .16141 m
.03006 .16141 L
s
[(0.2)] .01131 .16141 1 0 Mshowa
.02381 .27187 m
.03006 .27187 L
s
[(0.4)] .01131 .27187 1 0 Mshowa
.02381 .38232 m
.03006 .38232 L
s
[(0.6)] .01131 .38232 1 0 Mshowa
.02381 .49277 m
.03006 .49277 L
s
[(0.8)] .01131 .49277 1 0 Mshowa
.02381 .60323 m
.03006 .60323 L
s
[(1)] .01131 .60323 1 0 Mshowa
.125 Mabswid
.02381 .07857 m
.02756 .07857 L
s
.02381 .10619 m
.02756 .10619 L
s
.02381 .1338 m
.02756 .1338 L
s
.02381 .18903 m
.02756 .18903 L
s
.02381 .21664 m
.02756 .21664 L
s
.02381 .24425 m
.02756 .24425 L
s
.02381 .29948 m
.02756 .29948 L
s
.02381 .32709 m
.02756 .32709 L
s
.02381 .35471 m
.02756 .35471 L
s
.02381 .40993 m
.02756 .40993 L
s
.02381 .43755 m
.02756 .43755 L
s
.02381 .46516 m
.02756 .46516 L
s
.02381 .52039 m
.02756 .52039 L
s
.02381 .548 m
.02756 .548 L
s
.02381 .57561 m
.02756 .57561 L
s
.02381 .02335 m
.02756 .02335 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.125 13.000 moveto
(L) show
87.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.02381 .60332 Mdot
.03333 .53154 Mdot
.04286 .47601 Mdot
.05238 .4317 Mdot
.0619 .39577 Mdot
.07143 .36217 Mdot
.08095 .33397 Mdot
.09048 .3156 Mdot
.1 .2956 Mdot
.10952 .27343 Mdot
.11905 .2523 Mdot
.12857 .23012 Mdot
.1381 .21181 Mdot
.14762 .19646 Mdot
.15714 .17883 Mdot
.16667 .16199 Mdot
.17619 .14753 Mdot
.18571 .13794 Mdot
.19524 .12707 Mdot
.20476 .11651 Mdot
.21429 .10751 Mdot
.22381 .09885 Mdot
.23333 .09068 Mdot
.24286 .08173 Mdot
.25238 .07128 Mdot
.2619 .06416 Mdot
.27143 .06287 Mdot
.28095 .06015 Mdot
.29048 .05819 Mdot
.3 .05676 Mdot
.30952 .05703 Mdot
.31905 .05491 Mdot
.32857 .05358 Mdot
.3381 .05242 Mdot
.34762 .05043 Mdot
.35714 .04748 Mdot
.36667 .0485 Mdot
.37619 .05445 Mdot
.38571 .05907 Mdot
.39524 .06192 Mdot
.40476 .06609 Mdot
.41429 .06986 Mdot
.42381 .07553 Mdot
.43333 .07821 Mdot
.44286 .08086 Mdot
.45238 .08449 Mdot
.4619 .09184 Mdot
.47143 .09901 Mdot
.48095 .10449 Mdot
.49048 .10827 Mdot
.5 .11146 Mdot
.50952 .11214 Mdot
.51905 .1178 Mdot
.52857 .12231 Mdot
.5381 .12556 Mdot
.54762 .12028 Mdot
.55714 .11364 Mdot
.56667 .10676 Mdot
.57619 .10575 Mdot
.58571 .10496 Mdot
.59524 .10013 Mdot
.60476 .09654 Mdot
.61429 .09434 Mdot
.62381 .09325 Mdot
.63333 .09235 Mdot
.64286 .08758 Mdot
.65238 .08112 Mdot
.6619 .07359 Mdot
.67143 .06374 Mdot
.68095 .05917 Mdot
.69048 .05386 Mdot
.7 .05252 Mdot
.70952 .04832 Mdot
.71905 .044 Mdot
.72857 .04217 Mdot
.7381 .04079 Mdot
.74762 .03891 Mdot
.75714 .03897 Mdot
.76667 .03578 Mdot
.77619 .0338 Mdot
.78571 .03542 Mdot
.79524 .03772 Mdot
.80476 .03696 Mdot
.81429 .03954 Mdot
.82381 .04438 Mdot
.83333 .04475 Mdot
.84286 .04751 Mdot
.85238 .05216 Mdot
.8619 .05424 Mdot
.87143 .0535 Mdot
.88095 .04649 Mdot
.89048 .04086 Mdot
.9 .03812 Mdot
.90952 .03232 Mdot
.91905 .02924 Mdot
.92857 .02548 Mdot
.9381 .02327 Mdot
.94762 .02272 Mdot
.95714 .02214 Mdot
.96667 .01875 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`0o0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kP<0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0g0?ooo`D000000`3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00D0
k^k^03<c<`000000<c<c0>k^kP0g0?ooo`0509VIV@0A4A40000003<c<`3<c<`00`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0i0?ooo`80000000T04A4A
0?ooo`3oool0oooo0>k^kP0c<c<0000003<c<`3^k^h00`3oool01@3^k^h0<c<c0000000c<c<0k^k^
01@0oooo000J0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00P3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0g0?ooo`0509VIV@0R8R80
k^k^0?ooo`14A4@00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0g0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<00`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0j0?ooo`030000003oool0oooo0080oooo00<0
MgMg09VIV@3oool00P0000030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0503oool001X0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40
0`3oool01@0A4A40oooo0?ooo`3oool04A4A03P0oooo00<0VIVI028R8P3^k^h0103oool01@0A4A40
oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@0k0?ooo`050000003oool0
oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00<04A4A0?ooo`3oool0
=@3oool500000080oooo0P0000020?ooo`8000000`3oool01@0A4A40oooo0?ooo`3oool04A4A01@0
oooo000J0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000i0?ooo`0309VIV@0R8R80k^k^
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000>P3o
ool00`2ZZZX04A4A0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000003L0oooo00<0A4A40=gMg@3oool00`0000000`3oool00000000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`006P3oool200000480
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo0000000j0?ooo`0307MgM`1VIVH0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`000000>@3oool00`0A4A4000000;^k^`030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000380oooo0P000000103o
ool000000000003MgMd500000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000503oool001X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`020?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool01@0A4A40oooo0?ooo`3oool04A4A03/0
oooo00D000000?ooo`3oool0oooo014A4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool0
0`0A4A40oooo0?ooo`0h0?ooo`030;^k^`0R8R80oooo0080oooo00D04A4A0?ooo`3oool0oooo014A
4@030?ooo`05014A4@3oool0oooo0?ooo`0A4A40<P3oool2000000040?ooo`00000000000?ooo`<0
0000103oool01@0A4A40oooo0?ooo`3oool04A4A00<0oooo00D04A4A0?ooo`3oool0oooo014A4@0D
0?ooo`006P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00D0MgMg09VI
V@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0=`3oool01@000000^k^k0?oo
o`2IVIT04A4A00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL0=`3oool01@0A4A40VIVI0?ooo`2k^k/0000000<0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0;`3oool2000000L0oooo00<0k^k^04A4A0000000
103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0D0?oo
o`006P3oool00`000000oooo0?ooo`0o0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0
<c<c0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP0g0?ooo`0509VIV@0A4A40
0000028R8P3<c<`00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00D0k^k^03<c<`000000
<c<c0>k^kP0g0?ooo`050:ZZZP0A4A400000014A4@2ZZZX00`3oool01@3^k^h0<c<c0000000c<c<0
k^k^00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP020?ooo`800000:03oool2000000030?ooo`00
0000000000P0oooo00<0MgMg0000003oool00`3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0D0?ooo`006P3oool00`000000oooo0?ooo`3Z0?ooo`800000
00@0oooo000000000000oooo0P000000103oool000000000003oool2000001l0oooo0P00000b0?oo
o`006P3oool00`000000oooo0?ooo`3P0?ooo`80000000<0oooo0000000000000P3oool200000003
0?ooo`000000000000@0oooo0P000000103oool000000000003oool2000000030?ooo`0000000000
01H0oooo0P0000000`3oool000000000000e0?ooo`006P3oool00`000000oooo0?ooo`3J0?ooo`80
000000@0oooo000000000000oooo0P0000000`3oool00000000000020?ooo`800000403oool20000
01H0oooo0P0000000`3oool000000000000Y0?ooo`8000000P3oool01@000000oooo0?ooo`000000
4A4A00<0oooo000J0?ooo`030000003oool0oooo0=X0oooo0P0000000`3oool000000000000M0?oo
o`80000000<0oooo0000000000003@3oool200000300oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`006P3oool00`000000oooo0?ooo`1T0?ooo`80000000@0oooo0000
00000000oooo0P00001[0?ooo`8000008`3oool2000000040?ooo`00000000000?ooo`8000002P3o
ool200000300oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`004P3o
oooo0000048000002P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
000J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`8000000P3oool00`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000000000/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
0P000000103oool000000000003oool200000080oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00L000000<c<c03<c<`000000:ZZZP3MgMd0
8R8R00@0oooo000J0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01@3oool20000
00030?ooo`00000000000080oooo0P0000000`3oool000000000000@0?ooo`80000000<0oooo0000
000000008`3oool00`000000oooo0?ooo`0f0?ooo`80000000<0oooo0000000000003P3oool00`00
0000oooo0?ooo`0T0?ooo`8000008`3oool00`000000oooo0?ooo`0?0?ooo`08014A4@0000008R8R
0000001gMgL04A4A0000002ZZZX40?ooo`006P3oool00`000000oooo0?ooo`1;0?ooo`80000000@0
oooo000000000000oooo0P0000050?ooo`8000005P3oool2000000030?ooo`000000000005T0oooo
0P00001k0?ooo`006P3oool00`000000oooo0?ooo`180?ooo`80000000@0oooo000000000000oooo
0P00000S0?ooo`80000000<0oooo000000000000D`3oool2000007h0oooo000J0?ooo`030000003o
ool0oooo04P0oooo0P00000/0?ooo`800000D`3oool2000007h0oooo000J0?ooo`030000003oool0
oooo04D0oooo0P00000b0?ooo`800000d03oool001X0oooo00<000000?ooo`3oool0A@3oool20000
0380oooo0P0000000`3oool000000000001:0?ooo`800000P@3oool001X0oooo00<000000?ooo`3o
ool0O03oool2000000030?ooo`000000000004L0oooo0P0000210?ooo`006P3oool2000004<0oooo
0P00000k0?ooo`80000000<0oooo000000000000@@3oool2000008@0oooo000J0?ooo`030000003o
ool0oooo0480oooo0P00000n0?ooo`80000000<0oooo000000000000?P3oool2000008@0oooo000J
0?ooo`030000003oool0oooo08D0oooo0P00000k0?ooo`800000Q`3oool001X0oooo00<000000?oo
o`3oool0?`3oool200000840oooo0P0000270?ooo`006P3oool00`000000oooo0?ooo`0o0?ooo`80
0000A`3oool2000002l0oooo0P000000103oool000000000003oool2000008X0oooo000J0?ooo`03
0000003oool0oooo08P0oooo0P00000/0?ooo`80000000@0oooo000000000000oooo0P0000000`3o
ool000000000002:0?ooo`006P3oool00`000000oooo0?ooo`0l0?ooo`800000C@3oool2000002H0
oooo0P0000000`3oool000000000002C0?ooo`006P3oool00`000000oooo0?ooo`0l0?ooo`800000
C@3oool2000002H0oooo0P00002F0?ooo`006P3oool00`000000oooo0?ooo`2>0?ooo`8000006P3o
ool2000000040?ooo`00000000000?ooo`800000V@3oool001X0oooo0P00000j0?ooo`800000D`3o
ool2000000030?ooo`000000000001L0oooo0P000000103oool000000000003oool2000009T0oooo
000J0?ooo`030000003oool0oooo03T0oooo0P00001F0?ooo`80000000@0oooo000000000000oooo
0P00002b0?ooo`006P3oool00`000000oooo0?ooo`2D0?ooo`80000000<0oooo0000000000003P3o
ool200000:80oooo000J0?ooo`030000003oool0oooo03H0oooo0P00001R0?ooo`8000002`3oool2
00000:80oooo000J0?ooo`030000003oool0oooo03H0oooo0P00001R0?ooo`8000000P3oool20000
00@0oooo0P00002U0?ooo`006P3oool00`000000oooo0?ooo`2N0?ooo`80000000@0oooo00000000
0000oooo0P00002U0?ooo`006P3oool00`000000oooo0?ooo`0c0?ooo`800000K03oool200000:P0
oooo000J0?ooo`030000003oool0oooo03<0oooo0P00003o0?oooaL0oooo000J0?ooo`800000o`3o
oom=0?ooo`006P3oool00`000000oooo0?ooo`0`0?ooo`800000o`3ooolJ0?ooo`006P3oool00`00
0000oooo0?ooo`0`0?ooo`800000o`3ooolJ0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000J0?ooo`030000003oool0oooo02d0oooo0P00003o0?oooad0oooo000J0?ooo`030000003o
ool0oooo02d0oooo0P00003o0?oooad0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
000403<c<`000000<c<c0>k^kPD0oooo0P0R8R840?ooo`D000001P3oool00`000000oooo0?ooo`3o
0?oood`0oooo0000102IVIT0oooo09VIV@1gMgL50?ooo`808R8R103oool01@2IVIT08R8R0>k^kP3o
ool0A4A400H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`000`3oool00`0A4A40oooo0?ooo`0:
0?ooo`0309VIV@0R8R80k^k^00L0oooo0`00000Z0?ooo`800000o`3ooolP0?ooo`000`3oool00`00
0000oooo0?ooo`0;0?ooo`0309VIV@0R8R80k^k^00H0oooo00<000000?ooo`3oool0:P3oool20000
0?l0oooo803oool000<0oooo00<000000?ooo`3oool0303oool00`1gMgL0IVIV0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooC03oool000<0oooo00<04A4A0?ooo`3oool03@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooC03oool0000409VIV@3oool0VIVI07MgM`/0oooo
00D000000;^k^`3oool0VIVI014A4@060?ooo`030000003oool0oooo0?l0ooooC03oool0000403<c
<`000000<c<c0>k^kP/0oooo00D0VIVI014A4@0000008R8R0<c<c0060?ooo`030000003oool0oooo
02L0oooo0P00003o0?ooob<0oooo000J0?ooo`030000003oool0oooo02L0oooo0P00003o0?ooob<0
oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`006P3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`006P3oool00`000000oooo0?ooo`0T0?ooo`800000o`3ooolV0?ooo`006P3oool00`000000oooo
0?ooo`0T0?ooo`800000o`3ooolV0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J
0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`006P3oool00`000000oooo0?ooo`0Q0?ooo`800000o`3ooolY0?ooo`006P3oool00`000000oooo
0?ooo`0Q0?ooo`800000o`3ooolY0?ooo`006P3oool200000?l0ooooC@3oool001X0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`03
0000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool07P3oool200000?l0oooo
;03oool001X0oooo00<000000?ooo`3oool07P3oool200000?l0oooo;03oool001X0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`03
0000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003o
ool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool06`3oool200000?l0oooo;`3oool0
01X0oooo00<000000?ooo`3oool06`3oool200000?l0oooo;`3oool001X0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo0000100c<c<0000003<c
<`3^k^h50?ooo`808R8R1P3oool200000003014A4@3oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`0000@0VIVI0?ooo`2IVIT0MgMg1@3oool2028R8PL0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?oood`0oooo00030?ooo`03014A4@3oool0oooo00T0oooo1@00
00060?ooo`<00000o`3ooom<0?ooo`000`3oool00`000000oooo0?ooo`090?ooo`0404A4A03MgMd0
oooo000000L0oooo00<000000?ooo`3oool0603oool200000?l0oooo<P3oool000<0oooo00<00000
0?ooo`3oool02@3oool0103MgMd0EEEE0?ooo`0000070?ooo`030000003oool0oooo01P0oooo0P00
003o0?oooc80oooo00030?ooo`03014A4@3oool0oooo00X0oooo00<0MgMg0<c<c00000001`3oool0
0`000000oooo0?ooo`3o0?oood`0oooo0000102IVIT0oooo09VIV@1gMgL<0?ooo`030>k^kP14A4@0
000000L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`0000@0<c<c0000000c<c<0k^k^3@3oool0
0`1gMgL000000?ooo`060?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000
003oool0oooo01D0oooo0P00003o0?ooocD0oooo000J0?ooo`8000005P3oool200000?l0oooo=@3o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`0B0?ooo`800000o`3ooolh0?ooo`006P3oool0
0`000000oooo0?ooo`0B0?ooo`800000o`3ooolh0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool03`3oool2
00000?l0oooo>`3oool001X0oooo00<000000?ooo`3oool03`3oool200000?l0oooo>`3oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000o`3ooom=0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo00/0oooo0P00
003o0?ooocl0oooo000J0?ooo`030000003oool0oooo00/0oooo0P00003o0?ooocl0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
00@0<c<c0000000c<c<0k^k^1@3oool2028R8P@0oooo00D0k^k^03<c<`0000004A4A0<c<c0060?oo
o`030000003oool0oooo0?l0ooooC03oool0000409VIV@3oool0VIVI07MgM`D0oooo0P0R8R840?oo
o`0505EEE@1gMgL0oooo09VIV@0R8R801P3oool00`000000oooo0?ooo`3o0?oood`0oooo00030?oo
o`03014A4@3oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo0?l0ooooC03oool000<0oooo00<000000?ooo`3oool02@3oool01@000000VIVI0?ooo`2IVIT0
8R8R00H0oooo0`00003o0?oood`0oooo00030?ooo`030000003oool0oooo00T0oooo00D0000005EE
E@0000004A4A0<c<c0060?ooo`030000003oool0oooo0?l0ooooC03oool000<0oooo00<04A4A0?oo
o`3oool02@3oool00`1EEED0R8R80?ooo`080?ooo`030000003oool0oooo0?l0ooooC03oool00004
09VIV@3oool0VIVI07MgM`/0oooo00<0gMgM014A4@2IVIT0203oool00`000000oooo0?ooo`3o0?oo
od`0oooo0000100c<c<0000003<c<`3^k^h<0?ooo`040<c<c014A4@00000014A4@H0oooo00<00000
0?ooo`3oool0203oool200000?l0oooo@P3oool001X0oooo00<000000?ooo`3oool0203oool20000
0?l0oooo@P3oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o
0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003o
ool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`00
0000oooo0?ooo`050?ooo`800000o`3ooom50?ooo`006P3oool00`000000oooo0?ooo`050?ooo`80
0000o`3ooom50?ooo`006P3oool200000?l0ooooC@3oool001X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo
0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`80
0000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003o
ool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool00P3oool200000?l0ooooB03oool0
01X0oooo00<000000?ooo`3oool00P3oool200000?l0ooooB03oool001X0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo0000100c<c<0000003<c
<`3^k^h50?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00H0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`0000@0VIVI0?ooo`2IVIT0MgMg1@3oool2028R8P@0oooo00D08R8R09VIV@3o
ool0VIVI028R8P060?ooo`030000003oool0oooo0?l0ooooC03oool000<0oooo00<04A4A0?ooo`3o
ool02@3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00003o0?oood`0oooo00030?ooo`03
0000003oool0oooo00T0oooo00D0<c<c09VIV@3oool0VIVI03<c<`060?ooo`030000003oool0oooo
0?l0ooooC03oool000<0oooo00<000000?ooo`3oool02@3oool01@3<c<`00000000000000000c<c<
00H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`000`3oool00`0A4A40oooo0?ooo`090?ooo`05
014A4@2k^k/0oooo0;^k^`0A4A401P3oool00`000000oooo0?ooo`3o0?oood`0oooo0000102IVIT0
oooo09VIV@1gMgL;0?ooo`050000002k^k/0oooo0;^k^`0000001P3oool00`000000oooo0?ooo`3o
0?oood`0oooo0000100c<c<0000003<c<`3^k^h;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01P3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000J0?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J
0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00@000000?ooo`0000000000o`3ooom;
0?ooo`006P3oool010000000oooo00000000003o0?oood/0oooo000J0?ooo`030000003oool0oooo
0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o
0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003o
ool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`00
0000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo
0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`03
0000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3o
ool00`000000oooo0?ooo`3o0?oood`0oooo000@0?ooo`@0000000<04A4A0?ooo`3oool00`3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`@00000o`3ooom<0?ooo`00
4P3oool00`000000oooo0?ooo`040?ooo`800000o`3ooom>0?ooo`004P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`00403oool205EEE@030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`005`3oool00`1gMgL0IVIV0?ooo`090?ooo`0306IVIP1gMgL0oooo0?l0oooo
@`3oool001H0oooo00<0gMgM014A4@3^k^h02P3oool00`3^k^h04A4A0=gMg@3o0?oood<0oooo000=
0?ooo`0506IVIP000000000004A4A03<c<`0103oool0101EEED0VIVI0?ooo`3oool200000080oooo
00P000000?ooo`3oool00000014A4@3oool0R8R806IVI_l0oooo@`3oool000`0oooo00H0IVIV07Mg
M`3oool0oooo08R8R00A4A440?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3^k^h000000?l0oooo@`3oool000`0oooo00<000000?ooo`3oool0
1`3oool00`0c<c<0oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3o
ool0oooo0000003o0?oood<0oooo000<0?ooo`030000003oool0oooo00L0oooo00<0<c<c0?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000o`3ooom3
0?ooo`00303oool01P1VIVH0MgMg0?ooo`3oool0R8R8000000@0oooo00<000000>k^kP3oool00P3o
ool01`000000c<c<0<c<c0000000ZZZZ0=gMg@0R8R800P3oool00`3^k^h000000?ooo`3o0?oood80
oooo000<0?ooo`060>k^kP1VIVH0000000000014A4@00000103oool0301EEED0MgMg0?ooo`3oool0
4A4A0000000R8R80000007MgM`0A4A4000000:ZZZP80oooo00<0MgMg05EEE@3oool0o`3ooom20?oo
o`005P3oool00`3MgMd04A4A0>k^kP0:0?ooo`030>k^kP0A4A40gMgM0?l0oooo@`3oool001L0oooo
00<0MgMg06IVIP3oool02@3oool00`1VIVH0MgMg0?ooo`3o0?oood<0oooo003o0?ooofT0oooo003o
0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-34.8325, -0.094959, \
1.64336, 0.00708491}}]
}, Open  ]],

Cell[TextData[{
  "From this plot, we can see that the correlation time ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  "for the energy fluctuations is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c~\ 100\)]],
  " steps, so according to Eq. ",
  ButtonBox["(8.3.16)",
    ButtonData:>{"Chapter8.nb", "(8.3.16)"},
    ButtonStyle->"Hyperlink"],
  " the expected error ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "  in ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " is roughly"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]E[0.1]\  = \ \[Delta]Uav[ .1]/Sqrt[6000/100]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 8.54"],

Cell[BoxData[
    \(0.03530896334456372`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally, in Cell ",
  ButtonBox["8.50",
    ButtonData:>"Cell 8.50",
    ButtonStyle->"Hyperlink"],
  " we plot the configuration of the particles for several timesteps. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g\  = \ 
        Table[ScatterPlot3D[z[n], PlotStyle \[Rule] PointSize[0.015], 
            PlotRange \[Rule] {{\(-1.5\), 1}, {\(-1\), 1.5}, {\(- .5\), 2}}, 
            BoxRatios \[Rule] {1, 1, 1}], {n, 11000, 12000, 
            50}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.55"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.45743 .48324 Mdot
.55538 .71953 Mdot
.67581 .49214 Mdot
.33146 .58593 Mdot
.42988 .34055 Mdot
.53748 .56099 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003oo`3ooom<
0?ooo`00o`3ooom<0?ooo`00g03oool400000003014A4@3oool0oooo06P0oooo003N0?ooo`030000
003oool0oooo06X0oooo003N0?ooo`030000003oool0oooo06X0oooo003N0?ooo`030000003oool0
oooo06X0oooo003N0?ooo`030000003oool0oooo06X0oooo003N0?ooo`030000003oool0oooo06X0
oooo003N0?ooo`030000003oool0oooo06X0oooo003L0?ooo`80EEEE00<000000?ooo`3oool0JP3o
ool00?l0ooooC03oool00?l0ooooC03oool00?l0ooooC03oool00?l0ooooC03oool00?l0ooooC03o
ool00>80oooo0P00001W0?ooo`00g`3oool3000000030?ooo`000000oooo06H0oooo003M0?ooo`80
0000103oool2000006H0oooo002W0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0
oooo00D0A4A4000000000000<c<c0=gMg@0N0?ooo`8000001P3oool00`000000oooo0000001U0?oo
o`00Y`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo
01X0oooo0`0000000`3oool000000?ooo`050?ooo`030000003oool0000006D0oooo002W0?ooo`05
014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`0G0?ooo`8000002`3oool01000
0000oooo0?ooo`00001T0?ooo`00Y`3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg
03<c<`3oool05P3oool2000000d0oooo00@000000?ooo`3oool00000I03oool00:L0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`0503oool4000000h0oooo
00D000000?ooo`3oool0oooo0000001S0?ooo`00Y`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0
oooo00<000000?ooo`3oool0503oool200000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1P0?ooo`00Y`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3o
ool04@3oool3000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1P0?ooo`00
Y`3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo1000000>0?ooo`<000005`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05l0oooo00380?ooo`8000000P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G`3oool00<D0oooo0`00
000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0GP3oool00<<0oooo0P00000O
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G@3oool00<40oooo0P0000020?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1M0?oo
o`00_P3oool3000002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1L0?ooo`00
_03oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1K0?ooo`00^@3o
ool3000000030?ooo`000000oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1K0?ooo`00]`3oool2000000D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo05X0oooo002?0?ooo`050>k^kP0c<c<0000003<c<`3^k^h08@3oool2
000002d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1J0?ooo`00S`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg01h0oooo0`0000000`3oool000000?ooo`0/0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0F@3oool008l0oooo00D04A4A0?ooo`3oool0oooo014A4@0L
0?ooo`800000<P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05P0oooo002?0?oo
o`050000003oool0oooo0?ooo`0000006@3oool3000003@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1H0?ooo`00S`3oool01@000000oooo0?ooo`3oool0000001L0oooo0P000000
0`3oool000000?ooo`0d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0E`3oool0
08l0oooo00D04A4A0?ooo`3oool0oooo014A4@0E0?ooo`800000>@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo05L0oooo002?0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL04P3oool3
000003/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1F0?ooo`00S`3oool01@3^
k^h0<c<c0000000c<c<0k^k^0100oooo0P0000000`3oool000000?ooo`0k0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0E@3oool00:80oooo0P0000100?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0E@3oool009l0oooo0`0000130?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0E03oool009d0oooo0P0000000`3oool000000?ooo`130?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0D`3oool009X0oooo0`0000180?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0D`3oool009P0oooo0P00001;0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0DP3oool009H0oooo0`00001<0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0DP3oool009<0oooo0`0000030?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1A0?ooo`00G@3oool01@3^k^h0<c<c
0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd07@3oool30000
0580oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1@0?ooo`00G@3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo01/0oooo0`00001C0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0D03oool005D0oooo1P0000020?ooo`05
014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`0G0?ooo`<00000EP3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo04l0oooo001M0?ooo`050000003oool0oooo0?oo
o`0000003`3oool00`1gMgL0<c<c0?ooo`0E0?ooo`<00000F@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo04l0oooo001M0?ooo`050000003oool0oooo0?ooo`000000303oool01@00
00008R8R0000000c<c<0c<c<01@0oooo1000001J0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0CP3oool005d0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0
oooo01@0oooo0P00001N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0C@3oool0
05d0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo0140oooo0`00001P
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0C@3oool005d0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0<0?ooo`@000003P3oool400000640oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1<0?ooo`00OP3oool2000006D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1;0?ooo`00N`3oool3000006L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1;0?ooo`00N@3oool4000006P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1:0?ooo`00M`3oool2000006d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1:0?ooo`00M03oool3000006l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`19
0?ooo`00LP3oool2000000030?ooo`000000oooo06l0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`180?ooo`00B`3oool400000003014A4@3oool0oooo01h0oooo0P0000040?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`180?ooo`00
C@3oool00`000000oooo0?ooo`0M0?ooo`<00000MP3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04L0oooo00120?ooo`H000001@3oool00`000000oooo0?ooo`0K0?ooo`80000000<0
oooo0000003oool0MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04L0oooo001=
0?ooo`030000003oool0oooo01T0oooo0P00001k0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0AP3oool004d0oooo00<000000?ooo`3oool05P3oool3000007d0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`150?ooo`00C@3oool00`000000oooo0?ooo`0D0?ooo`80
00000P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0A@3oool004d0oooo00<000000?ooo`3oool04@3oool300000880oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`140?ooo`00B`3oool205EEE@030000003oool0oooo00l0oooo0P00
00250?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0@`3oool005d0oooo0P000002
0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`13
0?ooo`00FP3oool3000008T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`120?oo
o`00F03oool2000008`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`120?ooo`00
E@3oool300000080oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0440oooo001C0?ooo`800000T@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0400oooo001A0?ooo`<00000TP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0400oooo000J0?ooo`@0000000<04A4A0?ooo`3oool00P3oool2028R8PD0oooo00D0A4A40000
00000000<c<c0=gMg@0O0?ooo`<000000`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0?`3oool001`0oooo00<000000?ooo`3oool0103oool2028R
8PP0oooo00<0MgMg03<c<`3oool0703oool2000009T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0n0?ooo`004@3oool6000000D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0I0?ooo`80000000<0oooo0000003oool0V03oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo03h0oooo000L0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0
5`3oool3000009d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`00703o
ool00`000000oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`05P3oool200000:00oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`00703oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01D0oooo0`0000020?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0l0?ooo`00703oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01<0oooo0P00002U0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0>`3oool001X0oooo0P1EEED00`000000oooo0?ooo`0;0?ooo`@00000403oool30000
0:H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`00>`3oool300000:T0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0j0?ooo`00>@3oool200000:`0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0j0?ooo`00=`3oool2000000030?ooo`00
0000oooo0:/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0i0?ooo`00=03oool3
00000;00oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0h0?ooo`00<`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0>03oool003<0
oooo0P00002b0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0=`3oool001P0oooo
00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM
00D0oooo0P00002b0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=P3oool001P0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?oo
o`030000003oool000000;40oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0f0?oo
o`00403oool600000080oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000002`0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0=@3oool001P0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0
oooo00<0oooo0P0000030?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0e0?ooo`00603oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000
028R8P000000<c<c0<c<c0040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03@0oooo000H0?ooo`05014A4@3oool0
oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03<0oooo000H
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo03<0oooo000H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0<P3oool00340oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2Y
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0<P3oool00340oooo0P00000:0?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0a0?oo
o`00<@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0`0?ooo`00<@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0`0?ooo`00<@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0_0?ooo`00<@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`00<@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0^0?ooo`00<03oool200000140oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo000`0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo
000`0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0X03oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo02`0oooo000`0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02/0oooo000`0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02/0oooo000`0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02X0oooo000_0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo02X0oooo000_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0W03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02T0oooo000_0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo02P0oooo000_0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02P0oooo000_0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0B@3oool2000004h0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0W0?ooo`00;`3oool2000001d0oooo00<000000?ooo`3oool0A`3oool4000004d0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0V0?ooo`00;P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo04H0oooo1000001=0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool09P3oool002h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`16
0?ooo`800000CP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02D0oooo000S0?oo
o`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0U0?ooo`008`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0903oool002<0oooo00D04A4A0?oo
o`3oool0oooo014A4@060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02<0oooo000S0?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0S0?ooo`008`3oool01@000000oooo0?ooo`3oool0
000000D0oooo0P00000V0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0R0?ooo`008`3oool01@0A4A40oooo0?ooo`3oool04A4A00D0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool08P3oool002<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0240oooo000S0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0P
0?ooo`00;@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0P0?ooo`00;@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0O0?ooo`00
;03oool2000002d0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo01h0oooo000/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01h0oooo000/0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo01d0oooo000/0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo01d0oooo000/0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01`0
oooo000/0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo01/0oooo000[0?ooo`800000=03oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool06`3oool002/0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool06P3oool002/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool06P3oool002/0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool06@3oool002/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`220?ooo`030000
003oool0oooo0440oooo0`00000J0?ooo`00:`3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0?P3oool300000080oooo00<000000?ooo`3oool0603o
ool002/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo03/0oooo0`0000050?ooo`030000003oool0oooo01P0oooo000Z0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0h0?ooo`<00000203oool00`00
0000oooo0?ooo`0H0?ooo`00:P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0=@3oool3000000/0oooo00<000000?ooo`3oool0603oool002X0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0380oooo
0`00000?0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0_0?ooo`<000004P3oool00`000000oooo0?oo
o`0G0?ooo`00:P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool0;03oool3000001D0oooo00<000000?ooo`3oool05`3oool002X0oooo0P0000100?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0:@3oool3000001P0oooo00<000000?oo
o`3oool05`3oool002T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo02D0oooo0`00000K0?ooo`030000003oool0oooo01L0oooo000Y0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0R0?ooo`<00000
7P3oool00`000000oooo0?ooo`0G0?ooo`003P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool07`3oool300000240oooo00<000000?ooo`3o
ool05`3oool000h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0
<c<c0?ooo`040?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0K0?ooo`@000009@3oool00`000000oooo0?ooo`0F0?ooo`003P3oool01@0A4A40oooo
0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0603oool3000002T0oooo00<000000?ooo`3o
ool05P3oool000h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00@0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01D0
oooo0`00000/0?ooo`030000003oool0oooo01H0oooo000>0?ooo`050000003oool0oooo0?ooo`00
0000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo0180oooo0`00000_0?ooo`030000003oool0oooo
01H0oooo000>0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0?0?oo
o`<00000<P3oool00`000000oooo0?ooo`0F0?ooo`003P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0303oool3000003D0oooo00<000000?ooo`3oool05P3oool000h0
oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000001@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool02@3oool3000003P0oooo00<000000?oo
o`3oool05P3oool002P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0W0?ooo`80
0000B03oool00`000000oooo0?ooo`060?ooo`<00000?03oool00`000000oooo0?ooo`0E0?ooo`00
:03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02D0oooo100000170?ooo`030000
003oool0oooo00<0oooo0`00000o0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0903oool4000004L0oooo00<000000?ooo`3oool00`00
00120?ooo`030000003oool0oooo01D0oooo000W0?ooo`800000D@3oool00`000000oooo0?ooo`0T
0?ooo`800000@03oool2000000H0oooo0`0000150?ooo`030000003oool0oooo01D0oooo000W0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0I03oool400000080oooo100000170?oo
o`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0H`3oool6000000<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
9`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0640oooo100000060?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`1M0?ooo`<000002`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo01D0oooo000W0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0F@3oool3
000000h0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool20000
05P0oooo00<000000?ooo`3oool0E@3oool300000140oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0540
oooo0`00000D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1=0?ooo`<000005`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0B@3oool3000001X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo04D0oooo0`00000M
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`110?ooo`<00000803oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo01@0oooo000U0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0?@3oool3000002<0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool200000600oooo00<000000?ooo`3oool0>@3oool3000002H0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo03D0oooo0`00000Y0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0`0?ooo`@00000;03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0;03oool300000300oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02P0
oooo0`00000c0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3oool002D0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0T0?ooo`<00000=P3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01<0oooo000T0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0803oool3000003T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool3000006L0oooo00<000000?ooo`3oool0703oool3000003`0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo01P0oooo0`00000=0?ooo`800000<03oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0180oooo000J0?ooo`@0000000<04A4A0?ooo`3oool00`3oool00`000000
oooo0?ooo`1Y0?ooo`030000003oool0oooo01@0oooo0`00000?0?ooo`@00000<03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0180oooo000L0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0@0?ooo`<000004P3oool400000300oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0B0?ooo`00703oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0303oool3000001H0oooo0P00
000a0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool001`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00P0oooo0`00001<
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool001`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00@0oooo0`00001?0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04P3oool001`0oooo00<000000?ooo`3o
ool0103oool200000700oooo00<000000?ooo`3oool00`00001B0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool04@3oool001`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1`0?ooo`800000E@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0140oooo
000J0?ooo`80EEEE00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1E0?ooo`8000006@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0E03oool4000001P0oooo00<000000?ooo`3oool0DP3oool3
000004T0oooo00<000000?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool0E@3oool40000
01P0oooo00<000000?ooo`3oool0C`3oool300000080oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`1F0?ooo`8000006@3oool00`000000
oooo0?ooo`1<0?ooo`<000001P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0140
oooo000R0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0B@3oool3000000X0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0A0?ooo`008P3oool200000780oooo00<0
00000?ooo`3oool0A@3oool4000000h0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0480oooo0`00000C
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`0o0?ooo`<000005P3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0?03oool3000001X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0@0?ooo`00
8@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03T0oooo0`00000N0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0403oool00240oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`0e0?ooo`@000008P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0100oooo000Q0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0<P3oool3
000002L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0@0?ooo`008@3oool20000
07<0oooo00<000000?ooo`3oool0;`3oool3000002/0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0?0?ooo`00803oool2000007@0oooo00<000000?ooo`3oool0;03oool3000002h0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo02P0oooo1000000b0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`0V0?ooo`<00000=`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool08`3oool3000003/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo0200oooo0`00000o0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool03`3oool00200oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0M0?ooo`<0
0000@P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool06@3oool4000004H0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0?0?ooo`007`3oool2000007@0oooo00<000000?ooo`3oool05P3o
ool3000004/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01<0oooo0`00001?0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`0@0?ooo`<00000D`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0303oool4000005L0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00T0oooo0`00001K0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`060?ooo`<00000G`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00`3oool3000006<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0>0?ooo`007P3oool3000007@0oooo00<000000?oo
o`0000000`00001W0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000006`0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0=0?ooo`00103oool400000003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`1`0?ooo`<0000000<0oooo0000003o
ool0K03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00d0oooo00060?ooo`030000
003oool0oooo00@0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0
K@3oool3000000@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00d0oooo00060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1Z0?ooo`<000001`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool03@3oool000H0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo06H0oooo1000000:0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0=0?ooo`001P3oool00`00
0000oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?ooo`1S
0?ooo`<000003P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool03@3oool000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0640oooo0`00000A0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00H0oooo0P00001O0?ooo`<00000503oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0303oool000@0oooo0P1EEED00`000000oooo
0?ooo`0;0?ooo`@000001@3oool00`000000oooo0?ooo`1J0?ooo`@000005`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0E`3oool3000001/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000N
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1A0?ooo`<000008@3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0303oool001`0oooo00<000000?ooo`3o
ool0C`3oool3000002@0oooo00<000000?ooo`3oool09`3oool2000004/0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0<0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`@00000
9`3oool00`000000oooo0?ooo`0V0?ooo`@00000B`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000002/0oooo00<000000?ooo`3oool09P3o
ool4000004`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`150?ooo`<00000;P3oool00`000000oooo0?ooo`0W0?ooo`800000CP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00000a0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`0n0?ooo`@00000=03oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0?03oool3000003L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00
000j0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000?@3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool0<P3oool400000400oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`800000<03oool3000004@0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00X0oooo000J0?ooo`800000
;P3oool3000004L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00X0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001:0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`006P3oool0
0`000000oooo0?ooo`0W0?ooo`<00000C@3oool00`000000oooo0?ooo`200?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool02P3oool001X0oooo00<000000?ooo`3oool08`3oool40000
0500oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00X0oooo000J0?ooo`030000003oool0oooo0200oooo0`00001D0?ooo`030000003oool0oooo0880
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`006P3oool00`000000oooo
0?ooo`0M0?ooo`<00000E`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000005X0oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01H0oooo1000001M0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0D0?oo
o`<00000H@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool04@3oool3000006@0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo00h0oooo0`00001W0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000JP3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3o
ool001T0oooo00<000000?ooo`3oool01`3oool4000006d0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo000H0?ooo`8000001P3oool30000
0740oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0oooo0080oooo0`00001d0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`00603oool5000007L0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`800000NP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0203oool000d0oooo1@0000080?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo000=0?oo
o`0509VIV@0R8R80k^k^0?ooo`14A4@02@3oool2000007L0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo000>0?ooo`0309VIV@0R8R80k^k^
00`0oooo0P00001e0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`080?ooo`003`3oool00`2IVIT08R8R0>k^kP0<0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0
oooo000@0?ooo`0307MgM`1VIVH0oooo00`0oooo0P00001c0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`004@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00L0oooo000=0?ooo`050000002k^k/0oooo09VIV@0A4A40403o
ool3000006l0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00L0oooo000=0?ooo`0509VIV@0A4A400000028R8P3<c<`01P3oool400000003014A4@3o
ool0oooo00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01`3oool001X0oooo00<000000?ooo`3oool0203oool2
000006`0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00L0oooo000?0?ooo`H000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00L0oooo000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000J03oool00`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool001X0oooo
00<000000?ooo`3oool0303oool2000006P0oooo00<000000?ooo`3oool0UP3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00H0oooo000J0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01P3oool001X0oooo00<000000?ooo`3oool03`3oool2000006D0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo000H0?oo
o`80EEEE00<000000?ooo`3oool04@3oool2000006<0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo000_0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0
oooo000`0?ooo`800000H@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01P3oool00380oooo00@000000?ooo`3oool00000G@3oool00`000000oooo
0?ooo`2K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool003<0oooo0`00
001M0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`00=@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`00=P3oool2000005/0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo000h0?ooo`03
0000003oool0000005P0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo000i0?ooo`800000F03oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool003X0oooo0P00001G0?ooo`030000003o
ool0oooo0:00oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`00?03oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`00?@3oool3000005<0oooo00<000000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo000o0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo000[0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0oooo00@0A4A400000000
0000<c<c0P00001A0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`00:`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?oo
o`0407MgM`0c<c<0oooo00000500oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo000S0?ooo`H000000P3oool01@0A4A40oooo0?ooo`3oool0
4A4A0100oooo00H000000?ooo`3oool000000?ooo`00001=0?ooo`030000003oool0oooo0:D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`00:`3oool01@000000oooo0?oo
o`3oool0000000l0oooo00<0MgMg03<c<`3oool00P3oool2000004d0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo000[0?ooo`050000003o
ool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool002/0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00P0
oooo0P0000000`3oool000000?ooo`170?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`00:`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0
oooo00<000000?ooo`3oool02P3oool2000004P0oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo000[0?ooo`050>k^kP0c<c<0000003<c<`3^
k^h0303oool4000000X0oooo0P0000170?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`00C03oool010000000oooo0?ooo`0000130?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`00
C@3oool00`000000oooo000000130?ooo`030000003oool0oooo0:/0oooo00D000000?ooo`3oool0
oooo000000050?ooo`00CP3oool2000004<0oooo00<000000?ooo`3oool0[03oool010000000oooo
0?ooo`0000050?ooo`00D03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0:`0oooo
00@000000?ooo`3oool000001@3oool00540oooo0P0000000`3oool000000?ooo`0l0?ooo`030000
003oool0oooo0:h0oooo00@000000?ooo`3oool00000103oool005<0oooo0P00000m0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`000000103oool005@0oooo0P00000l0?ooo`030000003o
ool0oooo0;00oooo0P0000040?ooo`00EP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:l0oooo0`0000040?ooo`00E`3oool00`000000oooo0000000h0?ooo`030000003oool0oooo
0:/0oooo100000070?ooo`00F03oool2000003P0oooo00<000000?ooo`3oool0YP3oool5000000/0
oooo001J0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0XP3oool400000100oooo
001;0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool3000003@0oooo00<000000?ooo`3oool0
WP3oool4000001@0oooo001;0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL03@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo09T0oooo1@00000H0?ooo`00B`3oool01@0A4A40oooo0?oo
o`3oool04A4A00d0oooo0P00000c0?ooo`030000003oool0oooo09D0oooo1000000M0?ooo`00B`3o
ool01@000000oooo0?ooo`3oool0000000l0oooo0P00000a0?ooo`030000003oool0oooo0940oooo
1000000Q0?ooo`00B`3oool01@000000oooo0?ooo`3oool000000140oooo0P00000_0?ooo`030000
003oool0oooo08`0oooo1@00000U0?ooo`00B`3oool01@0A4A40oooo0?ooo`3oool04A4A0180oooo
0P00000^0?ooo`030000003oool0oooo08P0oooo1000000Z0?ooo`00B`3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg01@0oooo00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`240?ooo`@0
0000;P3oool004/0oooo00D0k^k^03<c<`000000<c<c0>k^kP0E0?ooo`<00000:P3oool00`000000
oooo0?ooo`1o0?ooo`D00000<P3oool006L0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`1k0?ooo`@00000=`3oool006P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1g0?ooo`@00000>`3oool006T0oooo0`00000V0?ooo`030000003oool0oooo07<0oooo1000000o
0?ooo`00J`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06h0oooo1@0000130?oo
o`00K03oool2000002@0oooo00<000000?ooo`3oool0JP3oool4000004P0oooo001^0?ooo`030000
003oool000000240oooo00<000000?ooo`3oool0IP3oool4000004`0oooo001_0?ooo`8000008@3o
ool00`000000oooo0?ooo`1Q0?ooo`D00000D03oool00740oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1M0?ooo`@00000E@3oool005X0oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM0080oooo00<000000?ooo`0000007@3o
ool00`000000oooo0?ooo`1I0?ooo`@00000F@3oool005X0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`020?ooo`8000007@3oool00`000000oooo0?oo
o`1D0?ooo`D00000G@3oool005X0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003o
ool0oooo0080oooo0P00000L0?ooo`030000003oool0oooo0500oooo1000001R0?ooo`00FP3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool01@3oool3000001T0oooo00<0
00000?ooo`3oool0C03oool4000006H0oooo001J0?ooo`050000003oool0oooo0?ooo`000000303o
ool01@0000008R8R0000000c<c<0c<c<00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`170?ooo`D00000JP3oool005X0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000
003oool0oooo00X0oooo0`0000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
@`3oool4000006l0oooo001J0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0?`3oool4000007<0oooo
001J0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000d0oooo0P00000D0?ooo`030000
003oool0oooo03X0oooo1@00001g0?ooo`00O@3oool200000180oooo00<000000?ooo`3oool0=`3o
ool4000007`0oooo001o0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0<`3oool4
00000800oooo00200?ooo`8000003`3oool00`000000oooo0?ooo`0_0?ooo`@00000Q03oool00840
oooo0P00000>0?ooo`030000003oool0oooo02X0oooo1@0000280?ooo`00P`3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02H0oooo1000002=0?ooo`00Q03oool2000000/0oooo00<0
00000?ooo`3oool08P3oool400000940oooo00260?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07@3oool5000009D0oooo00270?ooo`<000001`3oool00`000000oooo0?ooo`0I0?oo
o`@00000VP3oool007X0oooo100000000`0A4A40oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool05@3oool4000009h0oooo001l0?ooo`030000003oool0oooo00/0oooo
0P0000050?ooo`030000003oool0oooo0100oooo1@00002R0?ooo`00O03oool00`000000oooo0?oo
o`0=0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`@00000Y`3oool007`0oooo00<00000
0?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000X0oooo1000002[0?ooo`00O03oool0
0`000000oooo0?ooo`0?0?ooo`80000000<0oooo0000003oool0103oool500000:l0oooo001l0?oo
o`030000003oool0oooo0140oooo0P0000000`3oool000000000000200000;@0oooo001l0?ooo`03
0000003oool0oooo0180oooo0P00002h0?ooo`00NP3oool205EEE@030000003oool0oooo0<`0oooo
003o0?oood`0oooo003o0?oood`0oooo003o0?oood`0oooo003o0?oood`0oooo003o0?oood`0oooo
003o0?oood`0oooo00260?ooo`@0000000<04A4A0?ooo`3oool00P3oool2028R8PD0oooo00D0A4A4
000000000000<c<c0=gMg@2`0?ooo`00R03oool00`000000oooo0?ooo`040?ooo`808R8R203oool0
0`1gMgL0<c<c0?ooo`2_0?ooo`00R03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0:h0oooo00280?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0[`3oool008P0oooo
00<000000?ooo`3oool02`3oool01@0000008R8R0000000c<c<0c<c<0;00oooo00280?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0/P3oool008P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2b0?ooo`00QP3oool205EEE@030000003oool0oooo00/0oooo1000002a
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.44796 .49192 Mdot
.5537 .70981 Mdot
.6681 .47495 Mdot
.30808 .586 Mdot
.43354 .33796 Mdot
.55573 .53405 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0B_ooool2o`0004gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00
;oooool2o`0001gooooo00?o0000ooooooooool0B?ooool4o`0004cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Vooooo`00;_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo04Oooooo1?l0001<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09_oo
ool002kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`17ooooo`;o0000COooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Sooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo09Gooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`008oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09?ooool002?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Sooooo`008oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000V
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0R
ooooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo06Wooooo0_l00008oooo
o`03o`000?oooooooooo00cooooo0ol0000eooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1Wooooo`Co00001oooool00ol0003oooooooooo`09ooooo`?o0000>?ooool00ol0
003oooooooooo`0Fooooo`00:?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06Ko
oooo1?l00007ooooo`03o`000?oooooooooo00Kooooo0ol0000looooo`03o`000?oooooooooo01Go
oooo000Xooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0I_ooool2o`0000Sooooo
00?o0000ooooooooool00oooool3o`0003oooooo00?o0000ooooooooool05Oooool002Sooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00?o0000@_oo
ool00ol0003oooooooooo`0Eooooo`009oooool2o`00057ooooo00?o0000ooooooooool08_ooool2
o`0004[ooooo0ol00015ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool08?ooool4o`0004Kooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool07oooool4o`0004?o
oooo0ol00003ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool002Oooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Oooooo`;o0000@?ooool4o`0000Kooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo05gooooo0ol0000;ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1I
ooooo`?o00003_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Voooo
o`;o0000F?ooool00ol0003oooooooooo`1Eooooo`?o00004Oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool0DOooool3o`0001Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`00
9_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04gooooo0ol0000Gooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`19ooooo`?o00006_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01Cooooo000Vooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0AOooool3
o`0001gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo047ooooo0ol0000Pooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0mooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0eooooo`;o00000_ooool3o`0002Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo03?ooooo1Ol0000Yooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0`
ooooo`Ko0000:_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uoooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;?ooool3o`0000?ooooo0_l0000[oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Xooooo`?o0000<oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
9?ooool3o`0003Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009?oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo023ooooo0ol0000iooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04_ooool002Cooooo0ol0001Wooooo`03o`000?oooooo
oooo01cooooo0ol0000looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool0
02Cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Hooooo`?o0000?oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Jooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo0ol00013ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo013ooooo0ol00016ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00cooooo0ol00019ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Sooooo0ol0001<ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo00Cooooo0ol0001?ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool2o`00073o
oooo00?o0000ooooooooool00ol0001Booooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool04Oooool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1`ooooo`;o0000
EOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Jooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool0C_ooool2o`00023ooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Sooooo`03o`000?oooooo
oooo04gooooo1?l0000Oooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooo
oooo017ooooo000Rooooo`03o`000?oooooooooo04kooooo1?l0000Oooooo`03o`000?oooooooooo
04oooooo0ol00002ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool002;o
oooo00?o0000ooooooooool0Coooool2o`00023ooooo00?o0000ooooooooool0C?ooool3o`0000Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo04Wooooo0ol0000:ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04Oooool002;ooooo0_l0001booooo`03o`000?oooooooooo04Gooooo1?l0
000>ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`12ooooo`?o00004oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0?oooool3o`0001Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@oooo
o`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03cooooo0ol0000Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0iooooo`?o00007_ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0=Ooo
ool4o`0002;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`008Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo03;ooooo0ol0000Wooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool04?ooool0027ooooo0_l0001cooooo`03o`000?oooooooooo
02oooooo0ol0000[ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool0023o
oooo0_l0001dooooo`03o`000?oooooooooo02cooooo0ol0000^ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool03oooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0Xooooo`Co0000<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
000Pooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool09_ooool3o`0003Oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo02?ooooo0ol0000kooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Poooo
o`?o0000?oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool07Oooool3o`0004;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo01Wooooo1?l00016ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3oooool001oooooo0_l0001dooooo`03o`000?oooooooooo01Kooooo0ol0001;ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0Cooooo`?o0000Coooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04?ooool3o`00
05?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00cooooo1?l0001Gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`09ooooo`?o0000Foooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo
000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01_ooool3o`0005oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo00?ooooo0ol0001Sooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool03_ooool001kooooo0ol0001dooooo`03o`000?oooooo000000?o0000Ioooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo000Nooooo`03o`000?oooooooooo07?o
oooo0ol0001/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Cooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0L?ooool3o`000003ooooool0003ooooo06cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06gooooo0ol00004ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`001_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J_oo
ool3o`0000Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00gooooo0006ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Vooooo`Co00002_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Hoooool3o`0000kooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo0006oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qoooo
o`?o00004Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03?ooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o
0000Goooool3o`0001Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00cooooo0004ooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03o`00
0?oooooooooo05[ooooo1?l0000Gooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Gooooo`?o00006ooo
ool00ol0003oooooooooo`0Wooooo`;o0000BOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00cooooo000Mooooo`03o`000?oooooooooo05Cooooo0ol0000Nooooo`03o`000?oooooo
oooo02Kooooo1?l00019ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool0
01gooooo00?o0000ooooooooool0DOooool3o`00027ooooo00?o0000ooooooooool09_ooool4o`00
04[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`?o00009?ooool00ol0003oooooooooo`0Wooooo`;o0000Boooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo04_ooooo
1?l0000Wooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0;ooooo`007?ooool2o`0004Wooooo0ol0000[ooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`15
ooooo`?o0000;_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02oooool001cooooo00?o0000ooooooooool0@_ooool3o`00037ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo000Looooo`03
o`000?oooooooooo03kooooo1?l0000dooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0looooo`?o0000
=oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0>Oooool3o`0003[ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo03Kooooo0ol0000mooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0booooo`Co0000@?ooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool001_o
oooo0_l0000`ooooo`?o0000A?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02_ooool001[ooooo0_l0000^ooooo`?o0000Aoooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool001[ooooo00?o
0000ooooooooool0:_ooool3o`0004[ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02Oooooo0ol0001=
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:
ooooo`006_ooool00ol0003oooooooooo`0Sooooo`Co0000D?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000oooooooo
ool08?ooool3o`0005Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo01gooooo0ol0001Gooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_oo
ool00ol0003oooooooooo`0Jooooo`?o0000F_ooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool05_ooool4
o`0005gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Wooooo000Iooooo`03o`000?oooooooooo01Cooooo0ol0001Qooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003o
ooooooooo`0Aooooo`?o0000I?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool03_ooool3o`0006Oooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo
000Iooooo`03o`000?oooooooooo00_ooooo0ol0001Zooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`07
ooooo`Co0000KOooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool001Sooooo0_l00006ooooo`?o0000LOooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000oooooooo
ool00_ooool3o`0007Cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Sooooo000Hooooo`Go0000Moooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool001Sooooo0_l0001jooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`003Oooool5
o`0000Sooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2<ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool000gooooo00GoV9RHob4Q8Oo^k^koooooodA4A009
ooooo`;o0000Moooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool02?ooool000kooooo00?oV9RHob4Q8Oo^k^h03?ooool2o`0007Gooooo00?o0000oooo
ooooool0S_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo000?ooooo`03
oiRHV?lQ8B7ok^k^00cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0013ooooo00?oMgMgofIVI_ooool0
3?ooool2o`0007?ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool000gooooo00Go0000okZj^_ooooooV9RHoa0@400@ooooo`?o0000Koooool00ol0003ooooooooo
o`2Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool000gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`Co000000?o410@ooooooooool01Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`08ooooo`;o0000K?ooool00ol0003oooooooooo`2D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool000oooooo1_l00005oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Eoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool001[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooo`00001Xooooo`03o`000?oooooooooo09Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000
J?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`006_ooool0
0ol0003oooooooooo`0?ooooo`;o0000IOooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool001Sooooo00?oEEEEofIVI_l000004oooool2o`00
06?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo000_ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo000`ooooo`;o0000HOooool00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool003;ooooo00Co
0000oooooooooooo0000GOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool003?ooooo0ol0001Mooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`00=_ooool2o`0005_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo000hooooo`03o`000?oooooo000005Sooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000iooooo`;o0000
F?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool003[ooooo0_l0001Gooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`00??ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`00?Oooool3o`00
05?ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Cooooo000oooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l0001Aooooo`03o`000?oooooooooo
0:?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;oooooo`00053ooooo00?o0000
ooooooooool0Y?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Soooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00Ko0000oooooooooooo0000oooo
ool0001=ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`00:oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0_ooool2o`0004gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool002_ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000ooooo`17ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00
:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0004So
oooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l00017ooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`00
C?ooool01?l0003oooooooooool00013ooooo`03o`000?oooooooooo0:[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`00COooool00ol0003oooooo`000013ooooo`03o`00
0?oooooooooo0:_ooooo00Go0000ooooooooooooooooo`000005ooooo`00C_ooool2o`0004?ooooo
00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005ooooo`00D?ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0057ooooo
0_l000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo0:kooooo00Co0000oooooooooooo
00001?ooool005?ooooo0_l0000mooooo`03o`000?oooooooooo0:oooooo00?o0000ooooool00000
1?ooool005Cooooo0_l0000looooo`03o`000?oooooooooo0;3ooooo0_l00004ooooo`00E_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo0:oooooo0ol00004ooooo`00Eoooool00ol0
003oooooo`00000hooooo`03o`000?oooooooooo0:_ooooo1?l00007ooooo`00F?ooool2o`0003So
oooo00?o0000ooooooooool0Y_ooool5o`0000_ooooo001Jooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0X_ooool4o`00013ooooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool3o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0001Cooooo001;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09Wooooo
1Ol0000Hooooo`00Boooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000cooooo`03o`00
0?oooooooooo09Gooooo1?l0000Mooooo`00Boooool01Ol0003ooooooooooooooooo000000oooooo
0_l0000aooooo`03o`000?oooooooooo097ooooo1?l0000Qooooo`00Boooool01Ol0003ooooooooo
oooooooo0000017ooooo0_l0000_ooooo`03o`000?oooooooooo08cooooo1Ol0000Uooooo`00Booo
ool01Ol@413ooooooooooooooooo410@01;ooooo0_l0000^ooooo`03o`000?oooooooooo08Sooooo
1?l0000Zooooo`00Boooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00Co0000oooooooooooo
0000:_ooool00ol0003oooooooooo`24ooooo`Co0000;_ooool004_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Eooooo`?o0000:_ooool00ol0003oooooooooo`1oooooo`Go0000<_ooool006Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1kooooo`Co0000=oooool006Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1gooooo`Co0000>oooool006Wooooo0ol0000V
ooooo`03o`000?oooooooooo07?ooooo1?l0000oooooo`00Joooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06kooooo1Ol00013ooooo`00K?ooool2o`0002Cooooo00?o0000oooooooo
ool0J_ooool4o`0004Sooooo001^ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool0
I_ooool4o`0004cooooo001_ooooo`;o00008Oooool00ol0003oooooooooo`1Qooooo`Go0000D?oo
ool0077ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000EOooool0
05[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`1Iooooo`Co0000FOoo
ool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`02ooooo`;o00007Oooool00ol0003oooooooooo`1Dooooo`Go0000GOooool005[ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`03o`000?oo
oooooooo053ooooo1?l0001Rooooo`00F_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01Oooool3o`0001Wooooo00?o0000ooooooooool0C?ooool4o`0006Kooooo001J
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`Go0000J_ooool005[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00[ooooo0ol00002ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0@oooool4o`0006oooooo001Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000001Cooooo
00?o0000ooooooooool0?oooool4o`0007?ooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000gooooo0_l0000Dooooo`03o`000?oooooooooo03[ooooo1Ol0001gooooo`00OOoo
ool2o`0001;ooooo00?o0000ooooooooool0=oooool4o`0007cooooo001oooooo`03o`000?oooooo
000000oooooo00?o0000ooooooooool0<oooool4o`00083ooooo0020ooooo`;o00003oooool00ol0
003oooooooooo`0_ooooo`Co0000Q?ooool0087ooooo0_l0000>ooooo`03o`000?oooooooooo02[o
oooo1Ol00028ooooo`00Poooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo02Kooooo
1?l0002=ooooo`00Q?ooool2o`0000_ooooo00?o0000ooooooooool08_ooool4o`00097ooooo0026
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool5o`0009Gooooo0027oooo
o`?o00001oooool00ol0003oooooooooo`0Iooooo`Co0000V_ooool007[ooooo1?l000000ol@413o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0009ko
oooo001looooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo
1Ol0002Rooooo`00O?ooool00ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003ooooooooo
o`0<ooooo`Co0000Yoooool007cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo
oooo000000[ooooo1?l0002[ooooo`00O?ooool00ol0003oooooooooo`0?ooooo`;o000000?ooooo
o`000?ooool01?ooool5o`000:oooooo001looooo`03o`000?oooooooooo017ooooo0_l000000ooo
oooo0000o`000002o`000;Cooooo001looooo`03o`000?oooooooooo01;ooooo0_l0002hooooo`00
N_ooool00omEEEGoIVIVo`00003>ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<oooo
o`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00Q_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0/?ooool008Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2^ooooo`00R?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo0:oooooo0028ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c02`ooooo`00R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo
0028ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0/_ooool008Kooooo00?oEEEE
ofIVI_l000003Oooool4o`000;7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43369 .4903 Mdot
.67008 .48692 Mdot
.54523 .70461 Mdot
.3142 .58899 Mdot
.43182 .35139 Mdot
.54923 .54343 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0A_ooool2o`0004gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0U
ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`14ooooo`Co0000C?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Cooooo000Sooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo04?ooooo1?l0001<ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool08oooool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0@oooool2o`0004gooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Sooooo`008oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000V
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0R
ooooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06Kooooo0_l0
0007ooooo`03o`000?oooooooooo00?o0000@_ooool00ol0003oooooooooo`0Eooooo`009oooool2
o`00057ooooo00?o0000ooooooooool07Oooool2o`0004Gooooo1?l00006ooooo`?o0000AOooool0
0ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
01_ooooo1?l00014ooooo`Co00000oooool4o`0004Oooooo00?o0000ooooooooool05Oooool002Oo
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Jooooo`Co0000AOooool2o`000004
ooooool0003o0000o`0000?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eoooo
o`009oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01[ooooo0_l00015ooooo`Co
00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?oo
ool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0COooool3o`0001Oo
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo04Wooooo0ol0000Jooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`15ooooo`?o00007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000V
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@Oooool3o`00023ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009Oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo03gooooo0ol0000Sooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04oooool002Gooooo0_l0001Pooooo`03o`000?oooooooooo03Wooooo0ol0000Vooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0eooooo`?o0000:Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0<?oo
ool4o`0002cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02cooooo0ol000000ooooooo0000o`00000]
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Xooooo`?o00000oooool4o`0002cooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo02Cooooo0ol00006ooooo`Co0000;?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
8?ooool3o`0000[ooooo0_l0000]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4_ooool002Cooooo0ol0001Wooooo`03o`000?oooooooooo01cooooo0ol0000looooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0Hooooo`?o0000?oooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo01;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo01Cooooo0ol00013ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo013ooooo0ol00016ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool04_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo00cooooo0ol00019ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
4_ooool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Sooooo0ol0001<ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04_oo
ool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo00Cooooo0ol0001?ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04_ooool0
01cooooo00?o0000ooooooooool01?ooool2o`00073ooooo00?o0000ooooooooool00ol0001Boooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1`ooooo`;o0000EOooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo017ooooo000Jooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0
D?ooool2o`0001kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo017ooooo000Sooooo`03o`000?oooooooooo04oooooo1?l0000Mooooo`03o`000?oo
oooooooo05;ooooo0ol00019ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooo
oooo053ooooo1?l0000Mooooo`03o`000?oooooooooo04oooooo0ol00002ooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0DOooool2o`00
01kooooo00?o0000ooooooooool0C?ooool3o`0000Kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04Wo
oooo0ol0000:ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04Oooool002;ooooo
0_l0001booooo`03o`000?oooooooooo04Gooooo1?l0000>ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`12ooooo`?o00004oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0?oooool3o`0001Kooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03cooooo0ol0000Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0iooooo`?o
00007_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0=Oooool4o`0002;ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo03;ooooo0ol0000Wooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04?oo
ool0027ooooo0_l0001cooooo`03o`000?oooooooooo02oooooo0ol0000[ooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool03oooool0023ooooo0_l0001dooooo`03o`000?oooooooooo
02cooooo0ol0000^ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool0027o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Xooooo`Co0000<_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool09_ooool3o`0003Oooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02?ooooo0ol0
000kooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool0023ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`0Pooooo`?o0000?oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool07Oooool3o`0004;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?oooo
o`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Wooooo1?l00016ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool001oooooo0_l0001dooooo`03o`00
0?oooooooooo01Kooooo0ol0001;ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Cooooo`?o0000Cooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool04?ooool3o`0005?ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00cooooo1?l0001Gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03_ooool001oo
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`09ooooo`?o0000Foooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool01_ooool3o`0005oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo0ol0
001Sooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool001kooooo0ol0001d
ooooo`03o`000?oooooo000000?o0000Ioooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00gooooo000Nooooo`03o`000?oooooooooo07?ooooo0ol0001/ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03Oooool000Cooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0L?ooool3o`00
0003ooooool0003ooooo06cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=oooo
o`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo06gooooo0ol00004ooooo`03o`000?oooooooooo06cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0J_ooool3o`0000Oooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Vooooo`Co00002_oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Ooo
ool000Kooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0Hoooool3o`0000kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`?o00004Oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool000Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`;o0000Goooool3o`0001Cooooo00?o0000oooo
ooooool09?ooool2o`0004[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<oooo
o`001?ooool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003oooooooooo`1Jooooo`Co
00005oooool00ol0003oooooooooo`0Sooooo`Co0000B_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Oooooo0ol0000Kooooo`03o`00
0?oooooooooo02?ooooo1?l0001;ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
3?ooool001gooooo00?o0000ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool09?oo
ool2o`0004gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`007Oooool0
0ol0003oooooooooo`1Aooooo`?o00008Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool03?ooool001cooooo00?o0000ooooooooool0Coooool3o`00
02Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00cooooo000Looooo`03o`000?oooooooooo04_ooooo1?l0000Wooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`007?ooool2o`0004Wooooo
0ol0000[ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0;ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o0000;_ooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool001cooooo00?o0000
ooooooooool0@_ooool3o`00037ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo03kooooo1?l0000doooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0looooo`?o0000=oooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
>Oooool3o`0003[ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Kooooo0ol0000mooooo`03o`000?oo
oooooooo07cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0booooo`Co0000@?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool02_ooool001_ooooo0_l0000`ooooo`?o0000A?ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool001[o
oooo0_l0000^ooooo`?o0000Aoooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0:_ooool3o`0004[ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo
000Jooooo`03o`000?oooooooooo02Oooooo0ol0001=ooooo`03o`000?oooooooooo083ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0S
ooooo`Co0000D?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02_ooool001[ooooo00?o0000ooooooooool08?ooool3o`0005Cooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Jooooo`03
o`000?oooooooooo01gooooo0ol0001Gooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003oooooooooo`0Jooooo`?o0000
F_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2Oooool001[ooooo00?o0000ooooooooool05_ooool4o`0005gooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooo
oooo01Cooooo0ol0001Qooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Aooooo`?o0000I?ooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool001Wo
oooo00?o0000ooooooooool03_ooool3o`0006Oooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo00_ooooo
0ol0001Zooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`09ooooo`006Oooool00ol0003oooooooooo`07ooooo`Co0000KOooool00ol0003ooooooooo
o`28ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool001Sooooo0_l00006
ooooo`?o0000LOooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02?ooool001Sooooo00?o0000ooooooooool00_ooool3o`0007Cooooo00?o0000oooo
ooooool0R_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo000Hooooo`Go
0000Moooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02?ooool001Sooooo0_l0001jooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`08ooooo`003Oooool5o`0000Sooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool000gooooo00GoV9RHob4Q8Oo^k^koooooodA4A009ooooo`;o0000Moooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool000kooooo00?oV9RH
ob4Q8Oo^k^h03?ooool2o`0007Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oiRHV?lQ8B7ok^k^00cooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool01oooool0013ooooo00?oMgMgofIVI_ooool03?ooool2o`0007?ooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool000gooooo00Go0000okZj^_ooooooV9RH
oa0@400@ooooo`?o0000Koooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01oooool000gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`Co0000
00?o410@ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003ooooooooo
o`08ooooo`;o0000K?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01oooool001[ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001Xoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`006_ooool00ol0003oooooooooo`0<ooooo`;o0000J?ooool00ol0003oooooooooo`2Fooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0?ooooo`;o0000IOoo
ool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool001Sooooo00?oEEEEofIVI_l000004oooool2o`0006?ooooo00?o0000ooooooooool0VOooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo000_ooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Kooooo000`ooooo`;o0000HOooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool003;ooooo00Co0000oooooooooooo0000GOooool00ol0003o
ooooooooo`2Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool003?ooooo
0ol0001Mooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`05ooooo`00=Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`00=_ooool2o`0005_ooooo00?o0000
ooooooooool0W_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000hoooo
o`03o`000?oooooo000005Sooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo000iooooo`;o0000F?ooool00ol0003oooooooooo`2Oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool003[ooooo0_l0001Gooooo`03o`00
0?oooooooooo0:3ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`00??oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`00?Oooool3o`0005?ooooo00?o0000ooooooooool0X_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo000oooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`00
0?l0003o<S8b0_l0001Aooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`04ogMgMolb<S;oooooo`00053ooooo00?o0000ooooooooool0Y?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Cooooo000Sooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00Ko0000oooooooooooo0000ooooool0001=ooooo`03o`000?oooooooooo0:Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`00:oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00_ooool2o`0004gooooo00?o0000oooooooo
ool0Y_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool002_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Sooooo0_l000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo0:Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool02_ooool2o`0004Sooooo00?o0000ooooooooool0Z?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo000[ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000[ooooo0_l00017ooooo`03o`000?oooooooooo0:Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`00C?ooool01?l0003oooooooooool00013oooo
o`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`00COooool00ol0003oooooo`000013ooooo`03o`000?oooooooooo0:_ooooo00Go0000oooooooo
ooooooooo`000005ooooo`00C_ooool2o`0004?ooooo00?o0000ooooooooool0[?ooool01?l0003o
ooooooooool00005ooooo`00D?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0:co
oooo00Co0000oooooooooooo00001Oooool0057ooooo0_l000000ooooooo0000ooooo`0looooo`03
o`000?oooooooooo0:kooooo00Co0000oooooooooooo00001?ooool005?ooooo0_l0000mooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooool000001?ooool005Cooooo0_l0000looooo`03o`00
0?oooooooooo0;3ooooo0_l00004ooooo`00E_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo0:oooooo0ol00004ooooo`00Eoooool00ol0003oooooo`00000hooooo`03o`000?oooooo
oooo0:_ooooo1?l00007ooooo`00F?ooool2o`0003Sooooo00?o0000ooooooooool0Y_ooool5o`00
00_ooooo001Jooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0X_ooool4o`00013o
oooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool3o`0003Cooooo00?o0000oooooooo
ool0W_ooool4o`0001Cooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo09Wooooo1Ol0000Hooooo`00Boooool01Ol@413ooooo
oooooooooooo410@00gooooo0_l0000cooooo`03o`000?oooooooooo09Gooooo1?l0000Mooooo`00
Boooool01Ol0003ooooooooooooooooo000000oooooo0_l0000aooooo`03o`000?oooooooooo097o
oooo1?l0000Qooooo`00Boooool01Ol0003ooooooooooooooooo0000017ooooo0_l0000_ooooo`03
o`000?oooooooooo08cooooo1Ol0000Uooooo`00Boooool01Ol@413ooooooooooooooooo410@01;o
oooo0_l0000^ooooo`03o`000?oooooooooo08Sooooo1?l0000Zooooo`00Boooool01OmgMgOoV9RH
oooooonHV9SoMgMg01Cooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`24oooo
o`Co0000;_ooool004_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`?o0000:_ooool00ol0
003oooooooooo`1oooooo`Go0000<_ooool006Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`1kooooo`Co0000=oooool006Sooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1gooooo`Co0000>oooool006Wooooo0ol0000Vooooo`03o`000?oooooooooo07?ooooo1?l0
000oooooo`00Joooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06kooooo1Ol00013
ooooo`00K?ooool2o`0002Cooooo00?o0000ooooooooool0J_ooool4o`0004Sooooo001^ooooo`03
o`000?oooooo0000027ooooo00?o0000ooooooooool0I_ooool4o`0004cooooo001_ooooo`;o0000
8Oooool00ol0003oooooooooo`1Qooooo`Go0000D?ooool0077ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Mooooo`Co0000EOooool005[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00?o0000ooooool00000
7Oooool00ol0003oooooooooo`1Iooooo`Co0000FOooool005[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`;o00007Oooool00ol0003ooooo
ooooo`1Dooooo`Go0000GOooool005[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00;ooooo0_l0000Looooo`03o`000?oooooooooo053ooooo1?l0001Rooooo`00F_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01Oooool3o`0001Wooooo
00?o0000ooooooooool0C?ooool4o`0006Kooooo001Jooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`17ooooo`Go0000J_ooool005[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00[ooooo0ol00002ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0@oooool4o`0006oooooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0?oooool4o`0007?o
oooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000gooooo0_l0000Dooooo`03
o`000?oooooooooo03[ooooo1Ol0001gooooo`00OOooool2o`0001;ooooo00?o0000ooooooooool0
=oooool4o`0007cooooo001oooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0<ooo
ool4o`00083ooooo0020ooooo`;o00003oooool00ol0003oooooooooo`0_ooooo`Co0000Q?ooool0
087ooooo0_l0000>ooooo`03o`000?oooooooooo02[ooooo1Ol00028ooooo`00Poooool00ol0003o
ooooo`00000;ooooo`03o`000?oooooooooo02Kooooo1?l0002=ooooo`00Q?ooool2o`0000_ooooo
00?o0000ooooooooool08_ooool4o`00097ooooo0026ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07Oooool5o`0009Gooooo0027ooooo`?o00001oooool00ol0003oooooooooo`0I
ooooo`Co0000V_ooool007[ooooo1?l000000ol@413oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool4o`0009kooooo001looooo`03o`000?oooooooooo00_o
oooo0_l00005ooooo`03o`000?oooooooooo013ooooo1Ol0002Rooooo`00O?ooool00ol0003ooooo
ooooo`0=ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`Co0000Yoooool007cooooo00?o
0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002[ooooo`00O?oo
ool00ol0003oooooooooo`0?ooooo`;o000000?oooooo`000?ooool01?ooool5o`000:oooooo001l
ooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`000002o`000;Cooooo001loooo
o`03o`000?oooooooooo01;ooooo0_l0002hooooo`00N_ooool00omEEEGoIVIVo`00003>ooooo`00
oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00
oooooom<ooooo`00Q_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd0/?ooool008Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2^
ooooo`00R?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo0:oooooo0028ooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c02`ooooo`00R?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Kooooo00?oEEEEofIVI_l000003Oooool4o`000;7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.47102 .49683 Mdot
.53444 .71872 Mdot
.66832 .50246 Mdot
.31137 .59788 Mdot
.43201 .35693 Mdot
.53005 .55064 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo04Gooooo0_l0001=ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool0
02?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0@oooool4o`0004cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0S
ooooo`008oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`12ooooo`Co0000C?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02?ooooo000Sooooo`05o`000?ooooooooooooooool000001Oooool2o`0002Kooooo00?o0000
ooooooooool0@_ooool2o`0004gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0R
ooooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06[ooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09oooool2o`0003go
oooo0ol00003ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool002Oooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Uooooo`Co0000>?ooool4o`0000Kooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo02Cooooo1?l0000eooooo`Ko00002?ooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool09?ooool2o`0003?ooooo0ol00002ooooo`Co00002?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01Cooooo000Vooooo`;o0000F?ooool00ol0003oooooooooo`1Eoooo
o`?o00001_ooool2o`0000Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Doooo
o`009_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo057ooooo0ol0000Dooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`1=ooooo`?o00005oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0BOoo
ool3o`0001[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo04Gooooo0ol0000Mooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`11ooooo`?o00008?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
01Cooooo000Uooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0?Oooool3o`0002?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool2o`00063ooooo
00?o0000ooooooooool0>Oooool3o`0002Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03Gooooo0ol0
000Yooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0`ooooo`Co0000;?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0;?ooool3o`00033ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Coooo
o`009Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Sooooo0ol0000cooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Tooooo`?o000000?oooooo`000?l00000<oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool08?ooool3o`0000?ooooo1?l0000booooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool04_ooool002Cooooo0ol0001Wooooo`03o`000?oooooooooo01cooooo0ol00006
ooooo`Co0000<_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Toooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06?ooool3o`0000[ooooo0_l0000coooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool3o`0004?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool04?ooool3o`0004Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?ooool3o`0004Wooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3o`0004cooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`0004oooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`04ooooo`;o
0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo073ooooo
0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001[ooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooooooo017ooooo000Roooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Coooool3o`0000;ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1@ooooo`;o
00007oooool00ol0003oooooooooo`1<ooooo`?o00001_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo04oooooo1?l0000Nooooo`03o`00
0?oooooooooo04Wooooo0ol0000:ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
4Oooool002;ooooo0_l0001@ooooo`Co00007_ooool00ol0003oooooooooo`15ooooo`Co00003_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooo
oooo053ooooo0_l0000Oooooo`03o`000?oooooooooo04;ooooo0ol0000Cooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0??ooool3o`0001[o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo000Q
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3o`0002Oooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0007?ooooo00?o0000oooo
ooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?oooo
o`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002kooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
3oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Vooooo`?o0000=ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0023o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o0000@_ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_ooool3o`0004_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0@oooo
o`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo000Oooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
3_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`?o0000Gooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000ooooool000000ol0001Woooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001kooooo00?o0000oooooooo
ool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`00
1?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0KOooool3o`0000Cooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo
0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Sooooo`?o00003_ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool0
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
067ooooo0ol0000Aooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo0_l0001Oooooo`?o00005?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool03?ooool000Cooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo
00?o0000ooooooooool0F_ooool4o`0001Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Oooooo0ol0
000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0<ooooo`007Oooool00ol0003oooooooooo`1Dooooo`?o00007_ooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool001gooooo00?o0000oooo
ooooool0DOooool3o`00027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo04oooooo0ol0000Tooooo`03
o`000?oooooooooo027ooooo0_l0001Aooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool03?ooool001cooooo00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0
8?ooool4o`00057ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`007?oo
ool2o`0004Wooooo0ol0000[ooooo`03o`000?oooooooooo023ooooo1?l0001Booooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0AOooool3
o`0002kooooo00?o0000ooooooooool08Oooool2o`0005Cooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12ooooo`?o0000<Oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool001co
oooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03cooooo
0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_ooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000
ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03;ooooo1?l00010oooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:oooo
o`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo0ol00017ooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_oo
ool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool09oooool3
o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@ooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003o
ooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool07Oooool3o`0005Oooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo
000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oooooooooo08?ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003oooooooooo`0F
ooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00067ooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Iooooo`03
o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0>ooooo`?o0000
Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooo
oooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aooooo`03o`000?oooooooooo
08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003o
ooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`000?oooooooooo08_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?ooool2o`0007[ooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000=
ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<ooooo`;o0000MOooool00ol0
003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000oo
oooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo08oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`004?ooool00omgMgOoIVIV
ooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0001_ooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`003Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/ooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`003oooool6o`00
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000ooooooooool0UOooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00cooooo
0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo000J
ooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omEEEGoIVIVo`00000Coooo
o`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo0_l0001Qooooo`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00<_oo
ool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000eooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool00000F?ooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Wooooo
0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000moooo
o`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Sooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00057ooooo00?o0000oooo
ooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000D?ooool0
0ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
02?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool01_l0003oooooooooool0
003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0:Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00:oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo04Oo
oooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o
0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002_ooool2o`0004Oo
oooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ooooooooool0Z_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`000?oooooo000004?ooooo
00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Gooooo001>ooooo`;o0000
@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Gooooo001@ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005ooooo`00
DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0[_ooool01?l0003ooooo
ooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0[oooool00ol0003ooooo
o`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?ooool2o`0000Cooooo001F
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3o`0000Cooooo001Goooo
o`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`0000Oooooo001Hooooo`;o
0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00005?ooool004_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0003?ooooo
00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?ooooooooooooooool00000
3oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo001;ooooo`05o`000?oo
ooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0S?ooool5o`0002Gooooo
001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo00?o0000ooooooooool0
R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool01?l0003ooooo
ooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00Boooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oooooo1Ol0000booooo`00
Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo1?l0000gooooo`00J?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0000kooooo`00JOooool3
o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o00009?ooool00ol0003o
ooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool000008Oooool00ol0003ooooo
ooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oooooooooo067ooooo1Ol0
001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0001E
ooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo05Wooooo1?l0
001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0001Mooooo`00F_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2o`0001cooooo00?o
0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003oooooooooo`1<ooooo`Co0000I_oo
ool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
2?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo1Ol0001Zooooo`00F_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02_ooool3o`0000;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000Koooool005[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000
5?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0>_ooool5o`0007Oooooo
001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?ooool007oooooo00?o0000
ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0083ooooo0_l0000?oooo
o`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000kooooo00?o0000oooooooo
ool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0
9_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003oooooooooo`0Rooooo`Co0000TOoo
ool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Go0000UOooool0
08Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Jooooo`00N_ooool4o`000003
oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co
0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo00?o0000ooooooooool0
4?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l00003ooooo`03o`000?oo
oooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>ooooo`05o`000?oooooo
ooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooooooo00oooooo0_l00000
0ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000ooooooooool04Oooool2o`00
0003ooooool0003o000000;o0000]?ooool007cooooo00?o0000ooooooooool04_ooool2o`000;So
oooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026ooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@2`ooooo`00R?ooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2booooo`00Q_ooool0
0omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.47368 .50537 Mdot
.66661 .48215 Mdot
.5336 .71335 Mdot
.44831 .34149 Mdot
.31735 .58032 Mdot
.51986 .55927 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`1>ooooo`;o0000B?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo02Kooooo000^ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0C?oo
ool4o`0004Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`00;_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04_ooooo1?l00017ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09Oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Boooool2o`0004Sooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`008oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09?ooool002?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Sooooo`008oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000V
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0R
ooooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Wooooo`;o00002?ooool00ol0003o
ooooooooo`06ooooo`?o0000??ooool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06Gooooo1?l00007ooooo`03o`000?oooooooooo00?ooooo
0ol0000oooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool0I?ooool4o`0000Oooooo00?o0000ooooooooool00ol00012ooooo`03o`000?oo
oooooooo01Gooooo000Wooooo`;o0000DOooool00ol0003oooooooooo`1Tooooo`;o00002?ooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool09Oooool2o`0003Kooooo0ol0
000;ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0Sooooo`Co0000<_ooool3o`0000kooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool2o`0005Sooooo00?o0000oooo
ooooool08_ooool4o`0002oooooo0ol0000Aooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool05?ooool002Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Rooooo`;o
0000;Oooool3o`0001Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`00
9_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04gooooo0ol0000Gooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`19ooooo`?o00006_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01Cooooo000Vooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0AOooool3
o`0001gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo047ooooo0ol0000Pooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0mooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0=Oooool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Cooooo`009Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo033ooooo1?l0000/
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0/ooooo`?o0000<?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0:?ooool3o`0003?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`00
9Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Cooooo0ol0000fooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo01;ooooo000Tooooo`?o0000Ioooool00ol0003oooooooooo`0Looooo`?o00001?ooool2
o`0003Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo01Sooooo0ol00006ooooo`Co0000=Oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Jooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo0ol00009ooooo`Co
0000=_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0@ooooo`?o0000
3Oooool2o`0003Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000D_ooool2o`0001cooooo00?o0000ooooooooool00ol0001Booooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1@ooooo`Co00007?ooool2o`0005Gooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0Aooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oo
oooooooo053ooooo1?l0000Looooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`1Aooooo`;o00007Oooool0
0ol0003oooooooooo`1Booooo`?o0000BOooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo04oooooo0ol00002ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1<ooooo`?o00001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017o
oooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0BOooool3o`0000[ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`008_ooool2o`0007;ooooo00?o
0000ooooooooool0AOooool4o`0000kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04;ooooo0ol0000C
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3
o`0002Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`00
07?ooooo00?o0000ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0?ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002ko
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Vooooo`?o0000=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000P
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o
0000@_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_oo
ool3o`0004_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0@ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`06ooooo`?o0000Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000oooo
ool000000ol0001Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001ko
oooo00?o0000ooooooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?oo
ool0K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
KOooool3o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1S
ooooo`?o00003_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo067ooooo0ol0000Aooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo0_l0001Oooooo`?o00005?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool000Cooooo00?oEEEEofIVI_l00000
3Oooool4o`0000Gooooo00?o0000ooooooooool0F_ooool4o`0001Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oo
oooooooo05Oooooo0ol0000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Dooooo`?o00007_ooool0
0ol0003oooooooooo`0Pooooo`;o0000DOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00cooooo000Mooooo`03o`000?oooooooooo057ooooo0ol0000Qooooo`03o`000?oooooooooo
01oooooo1?l0001Aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001co
oooo00?o0000ooooooooool0Coooool3o`0002Cooooo00?o0000ooooooooool07oooool4o`00057o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`0Pooooo`;o0000Doooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
03;ooooo1?l00010ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0:ooooo`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo
0ol00017ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool09oooool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0
7Oooool3o`0005Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool0
0ol0003oooooooooo`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00
067ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo000Iooooo`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003ooooo
ooooo`0>ooooo`?o0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000I
ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?oo
ool2o`0007[ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<oooo
o`;o0000MOooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`00
4?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0
001_ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`07ooooo`003Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`00
0?oooooooooo00cooooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omE
EEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo
0_l0001Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`00<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000e
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool0
0000F?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool003Wooooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000mooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1_l0003oooooooooool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0004Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`00
0?oooooo000004?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Go
oooo001>ooooo`;o0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003ooooo
ooooool00005ooooo`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0
[_ooool01?l0003oooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0
[oooool00ol0003oooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?oo
ool2o`0000Cooooo001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3
o`0000Cooooo001Gooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`00
00Oooooo001Hooooo`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
5?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0003?ooooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo
001;ooooo`05o`000?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0
S?ooool5o`0002Gooooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo
00?o0000ooooooooool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00
Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oo
oooo1Ol0000booooo`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo
1?l0000gooooo`00J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0
000kooooo`00JOooool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o
00009?ooool00ol0003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oo
oooooooo067ooooo1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooooooo05Wooooo1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0
001Mooooo`00F_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003ooooooooo
o`1<ooooo`Co0000I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
1Ol0001Zooooo`00F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
2_ooool3o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000
Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0
>_ooool5o`0007Oooooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?oo
ool007oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0
083ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000ko
oooo00?o0000ooooooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003ooooooooo
o`0Rooooo`Co0000TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Go0000UOooool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Joooo
o`00N_ooool4o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l0
0003ooooo`03o`000?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000oooo
ooooool04Oooool2o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000oooooooo
ool04_ooool2o`000;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@2`ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_
ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2booooo`00Q_ooool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.4542 .51813 Mdot
.54281 .70052 Mdot
.67568 .47093 Mdot
.42486 .36653 Mdot
.29406 .60451 Mdot
.53057 .5601 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0@?ooool2o`0004oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`008oooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0nooooo`Co0000C_ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo000Sooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03gooooo1?l0001>
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool002?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0?Oooool2
o`0004oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0K?ooool2o`0000Kooooo00?o0000ooooooooool03oooool3o`00
03;ooooo00?o0000ooooooooool05_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Zoooo
o`Co00001Oooool00ol0003oooooooooo`0<ooooo`?o0000=Oooool00ol0003oooooooooo`0Foooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0JOooool4o`0000Gooooo00?o0000ooooooooool02Oooool3o`00
03Sooooo00?o0000ooooooooool05_ooool002Sooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`1Yooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`?o0000??ooool00ol0003o
ooooooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool00oooool3o`0003oooooo00?o0000ooooooooool05Oooool002Sooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00?o0000@_oo
ool00ol0003oooooooooo`0Eooooo`009oooool2o`00057ooooo00?o0000ooooooooool0K_ooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
6oooool2o`00033ooooo0ol0000Gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
5?ooool002Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Iooooo`Co0000;?oo
ool3o`0001[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Sooooo1?l0000Yooooo`?o00007Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool06?ooool2o`0002Oooooo0ol0000Pooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0mooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0=Oooool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Cooooo`009Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo033ooooo1?l0000/
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0/ooooo`?o0000<?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0:?ooool3o`0003?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`00
9Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Cooooo0ol0000fooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo01;ooooo000Tooooo`?o0000Ioooool00ol0003oooooooooo`0Looooo`?o0000??ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Tooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool06?ooool3o`0000_ooooo0_l0000booooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool04_ooool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool3o`0000gooooo1?l0000booooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo013ooooo0ol0000@ooooo`Co0000
<_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`?o00005?oo
ool2o`0003?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo073ooooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4Oooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooo
oooo017ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Coooool3o`00
00;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo04cooooo0ol00006ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`19ooooo`?o00002_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo
000Rooooo`;o0000C?ooool2o`0002Cooooo00?o0000ooooooooool0AOooool4o`0000kooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`1:
ooooo`Co00008oooool00ol0003oooooooooo`12ooooo`?o00004oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo04[ooooo1?l0000Soooo
o`03o`000?oooooooooo03oooooo0ol0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool04?ooool002;ooooo00?o0000ooooooooool0Boooool2o`0002Cooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3
o`0002Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`00
07?ooooo00?o0000ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0?ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002ko
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Vooooo`?o0000=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000P
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o
0000@_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_oo
ool3o`0004_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0@ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`06ooooo`?o0000Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000oooo
ool000000ol0001Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001ko
oooo00?o0000ooooooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?oo
ool0K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
KOooool3o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1S
ooooo`?o00003_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo067ooooo0ol0000Aooooo`03o`000?oooooooooo02?ooooo0_l0001;oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool000Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`;o0000Goooool3o`0001Cooooo00?o0000oooooooo
ool08_ooool4o`0004[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`00
1?ooool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003oooooooooo`1Jooooo`Co0000
5oooool00ol0003oooooooooo`0Rooooo`Co0000Boooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Oooooo0ol0000Kooooo`03o`000?oo
oooooooo02?ooooo0_l0001=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?oo
ool001gooooo00?o0000ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo
057ooooo0ol0000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00009?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo
00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
03;ooooo1?l00010ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0:ooooo`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo
0ol00017ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool09oooool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0
7Oooool3o`0005Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool0
0ol0003oooooooooo`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00
067ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo000Iooooo`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003ooooo
ooooo`0>ooooo`?o0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000I
ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?oo
ool2o`0007[ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<oooo
o`;o0000MOooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`00
4?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0
001_ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`07ooooo`003Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`00
0?oooooooooo00cooooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omE
EEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo
0_l0001Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`00<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000e
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool0
0000F?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool003Wooooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000mooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1_l0003oooooooooool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0004Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`00
0?oooooo000004?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Go
oooo001>ooooo`;o0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003ooooo
ooooool00005ooooo`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0
[_ooool01?l0003oooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0
[oooool00ol0003oooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?oo
ool2o`0000Cooooo001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3
o`0000Cooooo001Gooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`00
00Oooooo001Hooooo`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
5?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0003?ooooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo
001;ooooo`05o`000?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0
S?ooool5o`0002Gooooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo
00?o0000ooooooooool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00
Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oo
oooo1Ol0000booooo`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo
1?l0000gooooo`00J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0
000kooooo`00JOooool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o
00009?ooool00ol0003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oo
oooooooo067ooooo1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooooooo05Wooooo1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0
001Mooooo`00F_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003ooooooooo
o`1<ooooo`Co0000I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
1Ol0001Zooooo`00F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
2_ooool3o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000
Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0
>_ooool5o`0007Oooooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?oo
ool007oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0
083ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000ko
oooo00?o0000ooooooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003ooooooooo
o`0Rooooo`Co0000TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Go0000UOooool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Joooo
o`00N_ooool4o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l0
0003ooooo`03o`000?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000oooo
ooooool04Oooool2o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000oooooooo
ool04_ooool2o`000;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@2`ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_
ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2booooo`00Q_ooool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.4708 .53965 Mdot
.53977 .70832 Mdot
.65757 .48319 Mdot
.42117 .36764 Mdot
.28169 .58799 Mdot
.50858 .55812 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03gooooo0_l0001Aooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08_ooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>oooool4o`00053ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0jooooo`Co0000D?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo023ooooo000]ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0>_ooool2o`00057ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Tooooo`;o00002oooool00ol0003o
ooooooooo`06ooooo`?o0000??ooool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06;ooooo1?l0000:ooooo`03o`000?oooooooooo00?ooooo
0ol0000oooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool0HOooool4o`0000[ooooo00?o0000ooooooooool00ol00012ooooo`03o`000?oo
oooooooo01Gooooo000Wooooo`;o0000DOooool00ol0003oooooooooo`1Qooooo`;o00002oooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
COooool3o`0001Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Wooooo0ol0000Jooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`15ooooo`?o00007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo01Cooooo000Vooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@Oooool3o`00
023ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo03gooooo0ol0000Sooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04oooool002Gooooo0_l0001Pooooo`03o`000?oooooooooo03Wooooo
0ol0000Vooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0eooooo`?o0000:Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool06Oooool2o`0001Gooooo1?l0000/ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04oooool002Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Goooo
o`Co00004Oooool3o`00033ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Coooo
o`009Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01Kooooo1?l0000>ooooo`?o
0000<oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool05_ooool2o`0000cooooo0ol0000fooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo01;ooooo000Tooooo`?o0000Ioooool00ol0003oooooooooo`0Looooo`?o000000?ooooo
o`000?l00000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Toooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06?ooool3o`0000?ooooo1?l0000hoooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool3o`0000Ko
oooo1?l0000iooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo013ooooo
0ol0000:ooooo`;o0000>_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0<ooooo`?o0000BOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000L
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`08
ooooo`?o0000C?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Loooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`04oooo
o`?o0000Coooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03
o`000?oooooooooo00Cooooo0_l0001`ooooo`03o`000?oooooooooo00?o0000D_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0L?ooool2o`0005Gooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Aooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo04Kooooo0_l0
000Xooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Aooooo`008oooool00ol0003oooooooooo`15ooooo`Co00009oooool00ol0003oooooooooo`1B
ooooo`?o0000BOooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`16oooo
o`Co00009oooool00ol0003oooooooooo`1?ooooo`?o00000_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo04Oooooo0_l0000Xooooo`03
o`000?oooooooooo04cooooo0ol00006ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool04Oooool002;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`19ooooo`?o0000
2_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo000Rooooo`;o0000L_oo
ool00ol0003oooooooooo`15ooooo`Co00003_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0@_ooool3
o`0001?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03oooooo0ol0000Fooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0looooo`?o00006_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013o
oooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0>Oooool3o`0001kooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo03Gooooo1?l0000Rooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0b
ooooo`?o00009oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo000Qoooo
o`;o0000Loooool00ol0003oooooooooo`0_ooooo`?o0000:oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00oooooo000Pooooo`;o0000M?ooool00ol0003oooooooooo`0/ooooo`?o
0000;_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo000Qooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0:?ooool4o`0003;ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo02Kooooo0ol0000gooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03ooo
ool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Sooooo`?o0000>oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool08?ooool3o`0003oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01go
oooo0ol00012ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0023ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Iooooo`Co0000A_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00oooooo000Oooooo`;o0000M?ooool00ol0003ooooooooo
o`0Fooooo`?o0000Boooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04oooool3o`0004oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo013ooooo0ol0001Cooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0<ooooo`Co
0000Eoooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`00
0?oooooooooo07?ooooo00?o0000ooooooooool02Oooool3o`0005_ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00Kooooo0ol0001Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03_oo
ool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`?o0000Hoooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo000Nooooo`?o0000M?ooool00ol0
003oooooo`000003o`0006Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=oooo
o`007_ooool00ol0003oooooooooo`1cooooo`?o0000K?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00gooooo0004ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo073ooooo0ol000000ooooooo
0000ooooo`1/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Kooooo
00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`1]ooooo`?o00001?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06[ooooo0ol00007ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0I_ooool4o`0000[ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo0006oooo
o`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo06?ooooo0ol0000>ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0HOooool3o`00017ooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01_ooool2o`0005oooooo0ol0000Dooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`001?ooool00omEEEGoIVIV
o`00000=ooooo`Co00001Oooool00ol0003oooooooooo`1Jooooo`Co00005oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool001gooooo00?o
0000ooooooooool0Eoooool3o`0001_ooooo00?o0000ooooooooool08_ooool2o`0004kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1D
ooooo`?o00007_ooool00ol0003oooooooooo`0Qooooo`Co0000C_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo057ooooo0ol0000Qoooo
o`03o`000?oooooooooo027ooooo1?l0001?ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool03?ooool001cooooo00?o0000ooooooooool0Coooool3o`0002Cooooo00?o0000oooooooo
ool08_ooool2o`00053ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02oooool001cooooo0_l00019ooooo`?o0000:ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02ooo
ool001cooooo00?o0000ooooooooool0AOooool3o`0002kooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo
04;ooooo0ol0000aooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co0000=?ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0??ooool3o`0003Oooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Wooooo0ol0
000jooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0fooooo`?o0000?Oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0<_ooool4o`00043ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00[ooooo000Kooooo`;o0000<?ooool3o`0004Cooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000Jooooo`;o0000
;_ooool3o`0004Oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02[ooooo0ol0001:ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`006_ooool0
0ol0003oooooooooo`0Wooooo`?o0000COooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool08oooool4o`00
053ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00[ooooo000Jooooo`03o`000?oooooooooo023ooooo0ol0001Dooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003ooooo
ooooo`0Mooooo`?o0000Eoooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool06_ooool3o`0005[ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo000J
ooooo`03o`000?oooooooooo01Kooooo1?l0001Mooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Doooo
o`?o0000HOooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02Oooool001Wooooo00?o0000ooooooooool04Oooool3o`0006Cooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`00
0?oooooooooo00kooooo0ol0001Wooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0;ooooo`?o0000J_oo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Ooo
ool001Wooooo00?o0000ooooooooool01oooool4o`0006gooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Hooooo`;o00001_ooool3o`00
077ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Sooooo000Hooooo`03o`000?oooooooooo00;ooooo0ol0001dooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`006?ooool5o`0007Oooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
000Hooooo`;o0000N_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool000gooooo1Ol00008ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo000=oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@02Oooool2o`0007Oooooo00?o0000ooooooooool0SOooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo000>ooooo`03oiRHV?lQ8B7ok^k^
00cooooo0_l0001eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`08ooooo`003oooool00onHV9So8B4Qonk^kP0<ooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oo
oooo000@ooooo`03ogMgMomVIVKooooo00cooooo0_l0001cooooo`03o`000?oooooooooo093ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Oooooo000=ooooo`05o`000?nj^[[ooooooiRHV?l@41004?oo
ool3o`0006oooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Oooooo000=ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool4o`000003oa0@4?oo
oooooooo00Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2Booooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool02?ooool2
o`0006cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Oooooo000?ooooo`Ko00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Oooooo000Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000J?ooool00ol0003o
ooooooooo`2Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool001[ooooo
00?o0000ooooooooool03?ooool2o`0006Sooooo00?o0000ooooooooool0U_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool03oooool2o`0006Gooooo00?o0000
ooooooooool0V?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Hoooo
o`03oeEEEOmVIVKo000001?ooooo0_l0001Sooooo`03o`000?oooooooooo09Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`00;oooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00
<?ooool2o`00067ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo000booooo`04o`000?ooooooooooo`0005gooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo000cooooo`?o0000GOoo
ool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool003Gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool003Kooooo0_l0001Kooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`00>?ooool00ol0003o
ooooo`00001Hooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`05ooooo`00>Oooool2o`0005Sooooo00?o0000ooooooooool0Woooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo000jooooo`;o0000Eoooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool003cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool003gooooo0ol0001Cooooo`03o`000?oooooooooo0:;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`00?oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo0:?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b
<P;o0000DOooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool002_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mg
MgOo<S8booooool0001@ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`008oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`06o`000?ooooooooooo`000?oooooo0000COooool00ol0003oooooooooo`2Uooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0001=ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`00:oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo000[ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08ooooo`;o
000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool002_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00[ooooo0_l00018ooooo`03o`000?oooooooooo0:Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000:ooooo`;o0000Aoooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool004cooooo00Co0000oooooooooooo0000@oooool00ol0003o
ooooooooo`2Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool004gooooo
00?o0000ooooool00000@oooool00ol0003oooooooooo`2[ooooo`05o`000?ooooooooooooooool0
00001Oooool004kooooo0_l00013ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo
00001Oooool0053ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2/ooooo`04o`00
0?ooooooooooo`0000Gooooo001Aooooo`;o000000?oooooo`000?ooool0??ooool00ol0003ooooo
ooooo`2^ooooo`04o`000?ooooooooooo`0000Cooooo001Cooooo`;o0000?Oooool00ol0003ooooo
ooooo`2_ooooo`03o`000?oooooo000000Cooooo001Dooooo`;o0000??ooool00ol0003ooooooooo
o`2`ooooo`;o00001?ooool005Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2_
ooooo`?o00001?ooool005Oooooo00?o0000ooooool00000>?ooool00ol0003oooooooooo`2[oooo
o`Co00001oooool005Sooooo0_l0000hooooo`03o`000?oooooooooo0:Kooooo1Ol0000;ooooo`00
F_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:;ooooo1?l0000@ooooo`00Booo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0ol0000dooooo`03o`000?oooooooooo09kooooo
1?l0000Dooooo`00Boooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`2Iooooo`Go00006?ooool004_ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`;o0000<oooool00ol0003oooooooooo`2Eooooo`Co00007Oooool004_ooooo00Go
0000ooooooooooooooooo`00000?ooooo`;o0000<Oooool00ol0003oooooooooo`2Aooooo`Co0000
8Oooool004_ooooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000;oooool00ol0003ooooo
ooooo`2<ooooo`Go00009Oooool004_ooooo00Go410@oooooooooooooooooa0@400Booooo`;o0000
;_ooool00ol0003oooooooooo`28ooooo`Co0000:_ooool004_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Dooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool0Q?ooool4o`0002ko
oooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05Oooool3o`0002[ooooo00?o0000oooooooo
ool0Ooooool5o`0003;ooooo001Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
Noooool4o`0003Oooooo001Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Mooo
ool4o`0003_ooooo001Yooooo`?o00009_ooool00ol0003oooooooooo`1cooooo`Co0000?oooool0
06_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1^ooooo`Go0000@oooool006co
oooo0_l0000Tooooo`03o`000?oooooooooo06[ooooo1?l00018ooooo`00K_ooool00ol0003ooooo
o`00000Qooooo`03o`000?oooooooooo06Kooooo1?l0001<ooooo`00Koooool2o`00027ooooo00?o
0000ooooooooool0HOooool5o`00053ooooo001aooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0GOooool4o`0005Gooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`03o`000?oooooo000001gooooo00?o
0000ooooooooool0FOooool4o`0005Wooooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00_ooool2o`0001gooooo00?o0000ooooooooool0E?oo
ool5o`0005gooooo001Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`;o00007?ooool00ol0003oooooooooo`1@ooooo`Co0000H_ooool005[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Gooooo0ol0000Iooooo`03o`000?oo
oooooooo04cooooo1?l0001Vooooo`00F_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c008ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Aoooool5o`0006[ooooo001Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0:ooooo`?o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04?ooooo
1?l0001_ooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo03oooooo1?l0001cooooo`00F_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`;o00005?ooool00ol0003ooooo
ooooo`0jooooo`Go0000Moooool007gooooo0_l0000Booooo`03o`000?oooooooooo03Oooooo1?l0
001looooo`00Ooooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo03?ooooo1?l00020
ooooo`00P?ooool2o`0000oooooo00?o0000ooooooooool0;oooool4o`0008Cooooo0021ooooo`;o
00003_ooool00ol0003oooooooooo`0Zooooo`Go0000R?ooool008?ooooo00?o0000ooooool00000
2oooool00ol0003oooooooooo`0Vooooo`Co0000SOooool008Cooooo0_l0000;ooooo`03o`000?oo
oooooooo02;ooooo1?l0002Aooooo`00Q_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo1Ol0002Eooooo`00Qoooool3o`0000Oooooo00?o0000ooooooooool06Oooool4o`00
09[ooooo001jooooo`Co000000?o410@ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Gooooo1?l0002Nooooo`00O?ooool00ol0003oooooooooo`0;ooooo`;o0000
1Oooool00ol0003oooooooooo`0@ooooo`Go0000X_ooool007cooooo00?o0000ooooooooool03Ooo
ool2o`0000?ooooo00?o0000ooooooooool03?ooool4o`000:Oooooo001looooo`03o`000?oooooo
oooo00kooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000Zoooool007cooooo00?o0000
ooooooooool03oooool2o`000003ooooool0003ooooo00Cooooo1Ol0002_ooooo`00O?ooool00ol0
003oooooooooo`0Aooooo`;o000000?oooooo`000?l000000_l0002dooooo`00O?ooool00ol0003o
ooooooooo`0Booooo`;o0000^?ooool007[ooooo00?oEEEEofIVI_l00000c_ooool00?ooooooC?oo
ool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?oo
ool008Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM0;3ooooo0028ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo0:oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[_ooool008So
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0/?ooool008Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2booooo`00R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0;;ooooo0026ooooo`03oeEEEOmVIVKo000000gooooo1?l0002aooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.46392 .51984 Mdot
.53351 .7165 Mdot
.67059 .49569 Mdot
.29337 .58381 Mdot
.42869 .35849 Mdot
.48139 .55675 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`13
ooooo`;o0000C_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Soooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo047ooooo1?l0001=ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool0
02?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00009_ooool00ol0003oooooooooo`10
ooooo`Co0000COooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo000Soooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo043ooooo0_l0001>ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`Co0000Aoooool00ol0
003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo06;o
oooo1ol00003ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool002Oooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Qooooo`Co00001_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0GOooool3o`000003ooooool0003o000000Sooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool0
02Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Co
oooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0COooool3o`0001Oooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo01gooooo0_l0000Zooooo`?o00006_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool06oooool4o`0002Kooooo0ol0000Mooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Joooo
o`Co00008oooool3o`00023ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Doooo
o`009Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01[ooooo0_l0000Qooooo`?o
00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`;o0000
H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=Ooo
ool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo033ooooo1?l0000/ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0/ooooo`?o0000<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
01?ooooo000Uooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0:?ooool3o`0003?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo02Cooooo0ol0000fooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000T
ooooo`?o0000Ioooool00ol0003oooooooooo`0Hooooo`;o00000_ooool3o`0003cooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo01Kooooo1Ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool04_ooool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool05?ooool5o`00047ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Booooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool04?ooool3o`0000;ooooo0_l00012ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo00cooooo0ol00019ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo00Sooooo0ol0001<ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Cooooo0ol0001?ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04_ooool001cooooo00?o0000ooooooooool01?ooool2o`00073ooooo00?o0000oooooooo
ool00ol0001Booooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1:ooooo`;o00009?ooool2o`0005Gooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`006_ooool00omEEEGoIVIVo`00
0006ooooo`03o`000?oooooooooo04Wooooo1?l0000Sooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`19
ooooo`Co00008oooool00ol0003oooooooooo`1Booooo`?o0000BOooool00ol0003oooooooooo`0A
ooooo`008_ooool00ol0003oooooooooo`1;ooooo`;o00009?ooool00ol0003oooooooooo`1?oooo
o`?o00000_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Rooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0C?ooool3o`0000Kooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo04Wooooo0ol0000:ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
4Oooool002;ooooo0_l0001booooo`03o`000?oooooooooo04Gooooo1?l0000>ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`12ooooo`?o00004oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0?oooool3o`00
01Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo03cooooo0ol0000Jooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0iooooo`?o00007_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013ooooo
000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0=Oooool4o`0002;ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo03;ooooo0ol0000Wooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool04?ooool0027ooooo0_l0001cooooo`03o`000?oooooooooo02oooooo0ol0000[oooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool0023ooooo0_l0001dooooo`03
o`000?oooooooooo02cooooo0ol0000^ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool03oooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Xooooo`Co0000
<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool09_ooool3o`0003Oooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo02?ooooo0ol0000kooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool0
023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Pooooo`?o0000?oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool07Oooool3o`0004;ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Wooooo
1?l00016ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool001oooooo0_l0
001dooooo`03o`000?oooooooooo01Kooooo0ol0001;ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0C
ooooo`?o0000Coooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00kooooo000Ooooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04?ooool3o`0005?ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00cooooo1?l0001Gooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`09ooooo`?o0000
Foooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool01_ooool3o`0005oooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00?ooooo0ol0001Sooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool0
01kooooo0ol0001dooooo`03o`000?oooooo000000?o0000Ioooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00gooooo000Nooooo`03o`000?oooooooooo07?ooooo0ol0001/ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Cooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0L?ooool3o`000003ooooool0003ooooo06cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo06gooooo0ol00004ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J_ooool3o`0000Oooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo0006
ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1V
ooooo`Co00002_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0Hoooool3o`0000kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`?o00004Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool000Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o0000Goooool3o`0001Co
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00co
oooo0004ooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03o`000?oooooooooo05[ooooo
1?l0000Gooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Gooooo`?o00006oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool001gooooo00?o0000
ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo057ooooo0ol0000Qoooo
o`03o`000?oooooooooo023ooooo0_l0001Booooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool03?ooool001cooooo00?o0000ooooooooool0Coooool3o`0002Cooooo00?o0000oooooooo
ool07oooool4o`00057ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`0Oooooo`Co0000
D_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOoo
ool3o`0002_ooooo00?o0000ooooooooool08?ooool2o`0005Cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o0000;_ooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool0
01cooooo00?o0000ooooooooool0@_ooool3o`00037ooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo03ko
oooo1?l0000dooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0looooo`?o0000=oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool0>Oooool3o`0003[ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Kooooo0ol0000m
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0booooo`Co0000@?ooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool001_ooooo0_l0000`ooooo`?o
0000A?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool02_ooool001[ooooo0_l0000^ooooo`?o0000Aoooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0:_oo
ool3o`0004[ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00[ooooo000Jooooo`03o`000?oooooooooo02Oooooo0ol0001=ooooo`03o`000?oooooo
oooo083ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0
003oooooooooo`0Sooooo`Co0000D?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool08?ooool3o`0005Co
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo000Jooooo`03o`000?oooooooooo01gooooo0ol0001Gooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003ooooooooo
o`0Jooooo`?o0000F_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool05_ooool4o`0005gooooo00?o0000
ooooooooool0Q?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo000Ioooo
o`03o`000?oooooooooo01Cooooo0ol0001Qooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Aooooo`?o
0000I?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02Oooool001Wooooo00?o0000ooooooooool03_ooool3o`0006Oooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oo
oooooooo00_ooooo0ol0001Zooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`07ooooo`Co0000KOooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool0
01Sooooo0_l00006ooooo`?o0000LOooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000ooooooooool00_ooool3o`0007Co
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00So
oooo000Hooooo`Go0000Moooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool02?ooool001Sooooo0_l0001jooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`003Oooool5o`0000Sooooo00?o0000
ooooooooool0Moooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02?ooool000gooooo00GoV9RHob4Q8Oo^k^koooooodA4A009ooooo`;o0000Moooool0
0ol0003oooooooooo`2=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool0
00kooooo00?oV9RHob4Q8Oo^k^h03?ooool2o`0007Gooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool0013ooooo00?oMgMgofIVI_ooool03?ooool2o`0007?ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo
000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`2@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool000gooooo00Go0000
okZj^_ooooooV9RHoa0@400@ooooo`?o0000Koooool00ol0003oooooooooo`2Aooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01oooool000gooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo09;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`006_ooool0
0ol0003oooooooooo`08ooooo`;o0000K?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01oooool000oooooo1_l00005ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`00001Xooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000J?ooool00ol0003ooooo
ooooo`2Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool001[ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo09Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0?
ooooo`;o0000IOooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool001Sooooo00?oEEEEofIVI_l000004oooool2o`0006?ooooo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo000_ooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo000`ooooo`;o0000HOooool00ol0003oooooooooo`2Jooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01_ooool003;ooooo00Co0000oooooooooooo0000
GOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1Oooool003?ooooo0ol0001Mooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo09gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`00=_ooool2o`00
05_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo000hooooo`03o`000?oooooo000005Sooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000iooooo`;o0000F?ooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool003[ooooo0_l0
001Gooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`00??ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0:7ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`00?Oooool3o`0005?ooooo00?o0000oooo
ooooool0X_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo000oooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Cooooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00CoA4A4o`000?l0003o<S8b0_l0001Aooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;oooooo`00053ooooo00?o0000ooooooooool0Y?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Sooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00Ko0000oooooooooooo0000ooooool0001=ooooo`03o`00
0?oooooooooo0:Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`00:ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00_ooool2o`0004gooooo
00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
000[ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool002_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Sooooo0_l000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo0:Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00:oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0004Sooooo00?o0000oooooooo
ool0Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo000[ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l00017ooooo`03o`000?oooooooooo0:Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`00C?ooool01?l0003ooooo
ooooool00013ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`00COooool00ol0003oooooo`000013ooooo`03o`000?oooooooooo0:_ooooo
00Go0000ooooooooooooooooo`000005ooooo`00C_ooool2o`0004?ooooo00?o0000ooooooooool0
[?ooool01?l0003oooooooooool00005ooooo`00D?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0057ooooo0_l000000ooooooo0000
ooooo`0looooo`03o`000?oooooooooo0:kooooo00Co0000oooooooooooo00001?ooool005?ooooo
0_l0000mooooo`03o`000?oooooooooo0:oooooo00?o0000ooooool000001?ooool005Cooooo0_l0
000looooo`03o`000?oooooooooo0;3ooooo0_l00004ooooo`00E_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo0:oooooo0ol00004ooooo`00Eoooool00ol0003oooooo`00000hoooo
o`03o`000?oooooooooo0:_ooooo1?l00007ooooo`00F?ooool2o`0003Sooooo00?o0000oooooooo
ool0Y_ooool5o`0000_ooooo001Jooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
X_ooool4o`00013ooooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool3o`0003Cooooo
00?o0000ooooooooool0W_ooool4o`0001Cooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09Wooooo1Ol0000Hooooo`00Booo
ool01Ol@413ooooooooooooooooo410@00gooooo0_l0000cooooo`03o`000?oooooooooo09Gooooo
1?l0000Mooooo`00Boooool01Ol0003ooooooooooooooooo000000oooooo0_l0000aooooo`03o`00
0?oooooooooo097ooooo1?l0000Qooooo`00Boooool01Ol0003ooooooooooooooooo0000017ooooo
0_l0000_ooooo`03o`000?oooooooooo08cooooo1Ol0000Uooooo`00Boooool01Ol@413ooooooooo
oooooooo410@01;ooooo0_l0000^ooooo`03o`000?oooooooooo08Sooooo1?l0000Zooooo`00Booo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00Co0000oooooooooooo0000:_ooool00ol0003o
ooooooooo`24ooooo`Co0000;_ooool004_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`?o
0000:_ooool00ol0003oooooooooo`1oooooo`Go0000<_ooool006Oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1kooooo`Co0000=oooool006Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`1gooooo`Co0000>oooool006Wooooo0ol0000Vooooo`03o`000?oooooo
oooo07?ooooo1?l0000oooooo`00Joooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
06kooooo1Ol00013ooooo`00K?ooool2o`0002Cooooo00?o0000ooooooooool0J_ooool4o`0004So
oooo001^ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool0I_ooool4o`0004cooooo
001_ooooo`;o00008Oooool00ol0003oooooooooo`1Qooooo`Go0000D?ooool0077ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000EOooool005[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00?o
0000ooooool000007Oooool00ol0003oooooooooo`1Iooooo`Co0000FOooool005[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`;o00007Ooo
ool00ol0003oooooooooo`1Dooooo`Go0000GOooool005[ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`03o`000?oooooooooo053ooooo1?l0
001Rooooo`00F_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01Ooo
ool3o`0001Wooooo00?o0000ooooooooool0C?ooool4o`0006Kooooo001Jooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`17ooooo`Go0000J_ooool005[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00[ooooo0ol00002ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0@oooool4o`0006oooooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0
?oooool4o`0007?ooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000gooooo
0_l0000Dooooo`03o`000?oooooooooo03[ooooo1Ol0001gooooo`00OOooool2o`0001;ooooo00?o
0000ooooooooool0=oooool4o`0007cooooo001oooooo`03o`000?oooooo000000oooooo00?o0000
ooooooooool0<oooool4o`00083ooooo0020ooooo`;o00003oooool00ol0003oooooooooo`0_oooo
o`Co0000Q?ooool0087ooooo0_l0000>ooooo`03o`000?oooooooooo02[ooooo1Ol00028ooooo`00
Poooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo02Kooooo1?l0002=ooooo`00Q?oo
ool2o`0000_ooooo00?o0000ooooooooool08_ooool4o`00097ooooo0026ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool5o`0009Gooooo0027ooooo`?o00001oooool00ol0
003oooooooooo`0Iooooo`Co0000V_ooool007[ooooo1?l000000ol@413oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0009kooooo001looooo`03o`00
0?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo1Ol0002Rooooo`00O?oo
ool00ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`Co0000Yooo
ool007cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0
002[ooooo`00O?ooool00ol0003oooooooooo`0?ooooo`;o000000?oooooo`000?ooool01?ooool5
o`000:oooooo001looooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`000002o`00
0;Cooooo001looooo`03o`000?oooooooooo01;ooooo0_l0002hooooo`00N_ooool00omEEEGoIVIV
o`00003>ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00
oooooom<ooooo`00oooooom<ooooo`00Q_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd0/?ooool008Sooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2^ooooo`00R?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo0:oo
oooo0028ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c02`ooooo`00
R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo0028ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0/_ooool008Kooooo00?oEEEEofIVI_l000003Oooool4
o`000;7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.46637 .52221 Mdot
.53228 .72388 Mdot
.66414 .49103 Mdot
.28501 .60005 Mdot
.41519 .36176 Mdot
.48488 .55898 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?_ooool2
o`0005;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Sooooo`008oooool01Ol0
003ooooooooooooooooo000000Gooooo0_l0000Vooooo`03o`000?oooooooooo03cooooo1?l0001A
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool002?ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>oooool4
o`00057ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`008oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0k
ooooo`;o0000D_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1Sooooo`;o00002Oooool3o`0004Gooooo00?o0000ooooooooool05Oooool0
02Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Qooooo`Co00001Oooool4o`00
04Oooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`1Pooooo`Co00000_ooool3o`0000?ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo063ooooo
1Ol00006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`1Mooooo`?o00002oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0FOooool3o`0000kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0D
ooooo`009_ooool2o`0005Sooooo00?o0000ooooooooool0EOooool3o`00017ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo057ooooo0ol0000Dooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool05?ooool002Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1=ooooo`?o0000
5oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool07_ooool2o`0002Wooooo0ol0000Jooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Looooo`Co00009Oooool3o`0001gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01_ooooo1?l0000Rooooo`?o00008?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
01Cooooo000Uooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06oooool2o`00023o
oooo0ol0000Sooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo
0_l0001Pooooo`03o`000?oooooooooo03Wooooo0ol0000Vooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0eooooo`?o0000:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000U
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0<?ooool4o`0002cooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo02cooooo0ol0000`ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04oooool002Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Xooooo`?o
0000<oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool09?ooool3o`0003Kooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0Cooooo`009?ooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo023ooooo0ol0000iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_oo
ool002Cooooo0ol0001Wooooo`03o`000?oooooooooo01Wooooo0_l000001?oooooo0000o`000?l0
000looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`0Gooooo`Co0000?oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo01;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo1_l00010ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo013ooooo0ol00003ooooo`;o0000@Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`?o0000BOooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`08ooooo`?o0000C?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`04ooooo`?o0000Coooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Cooooo0_l0001`oooo
o`03o`000?oooooooooo00?o0000D_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
017ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`0005Go
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`006_ooool00omEEEGoIVIV
o`000006ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo017ooooo000Sooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0D_ooool3o`0004Wooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1?ooooo`?o00000_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0C?ooool3o`0000Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Aoooo
o`008_ooool00ol0003oooooooooo`18ooooo`;o00009oooool00ol0003oooooooooo`19ooooo`?o
00002_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo000Rooooo`;o0000
B?ooool4o`0002Kooooo00?o0000ooooooooool0AOooool4o`0000kooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`17ooooo`Co00009_oo
ool00ol0003oooooooooo`12ooooo`?o00004oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo013ooooo000Rooooo`03o`000?oooooooooo04Sooooo0_l0000Wooooo`03o`000?oooooo
oooo03oooooo0ol0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool0
02;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0looooo`?o00006_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0>Oooool3o`0001kooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Gooooo
1?l0000Rooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`0booooo`?o00009oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000Loooool00ol0003oooooooooo`0_
ooooo`?o0000:oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo000Poooo
o`;o0000M?ooool00ol0003oooooooooo`0/ooooo`?o0000;_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00oooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0:?ooool4o`0003;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`00
8?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02Kooooo0ol0000gooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0Sooooo`?o0000>oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08?ooool3
o`0003oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo01gooooo0ol00012ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`0Iooooo`Co0000A_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oo
oooo000Oooooo`;o0000M?ooool00ol0003oooooooooo`0Fooooo`?o0000Boooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool04oooool3o`0004oooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo013ooooo0ol0001C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03_ooool001oooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0<ooooo`Co0000Eoooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool02Oooool3o`0005_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`00
7oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Kooooo0ol0001Oooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`03ooooo`?o0000Hoooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00kooooo000Nooooo`?o0000M?ooool00ol0003oooooo`000003o`0006Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`007_ooool00ol0003oooooooooo`1coooo
o`?o0000K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0004ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo073ooooo0ol000000ooooooo0000ooooo`1/ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1]ooooo`?o00001?ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06[ooooo
0ol00007ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0=ooooo`001_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0I_ooool4o`0000[ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06?ooooo0ol0000>ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`001_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0HOooool3
o`00017ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00cooooo0006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`00
05oooooo0ol0000Dooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0<ooooo`001?ooool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003o
ooooooooo`1Jooooo`Co00005oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0Eoooool3o`0001_ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo
000Mooooo`03o`000?oooooooooo05Cooooo0ol0000Nooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1A
ooooo`?o00008Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool03?ooool001cooooo00?o0000ooooooooool0Coooool3o`0002Cooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo000Looooo`03
o`000?oooooooooo04_ooooo1?l0000Wooooo`03o`000?oooooooooo023ooooo0_l0001Cooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool001cooooo0_l00019ooooo`?o0000
:oooool00ol0003oooooooooo`0Oooooo`Co0000Doooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oo
oooooooo01oooooo1?l0001Dooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02ooo
ool001cooooo00?o0000ooooooooool0@_ooool3o`00037ooooo00?o0000ooooooooool08?ooool2
o`0005Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0
003oooooooooo`0nooooo`Co0000=?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0??ooool3o`0003Oo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo03Wooooo0ol0000jooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0fooooo`?o0000?Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<_ooool4o`00043ooooo00?o0000
ooooooooool0OOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo000Koooo
o`;o0000<?ooool3o`0004Cooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00[ooooo000Jooooo`;o0000;_ooool3o`0004Oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`00
0?oooooooooo02[ooooo0ol0001:ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Wooooo`?o0000COoo
ool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_oo
ool001[ooooo00?o0000ooooooooool08oooool4o`00053ooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo
023ooooo0ol0001Dooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Mooooo`?o0000Eoooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool001[ooooo
00?o0000ooooooooool06_ooool3o`0005[ooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01Kooooo1?l0
001Mooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`09ooooo`006Oooool00ol0003oooooooooo`0Dooooo`?o0000HOooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000oooo
ooooool04Oooool3o`0006Cooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo00kooooo0ol0001Wooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`00
6Oooool00ol0003oooooooooo`0;ooooo`?o0000J_ooool00ol0003oooooooooo`27ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool01ooo
ool4o`0006gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Sooooo000Hooooo`;o00001_ooool3o`00077ooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo
00;ooooo0ol0001dooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`08ooooo`006?ooool5o`0007Oooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000Hooooo`;o0000N_ooool00ol0003ooooo
ooooo`2;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool000gooooo1Ol0
0008ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0S?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo000=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02Ooo
ool2o`0007Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Sooooo000>ooooo`03oiRHV?lQ8B7ok^k^00cooooo0_l0001eooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`003oooool00onH
V9So8B4Qonk^kP0<ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo000@ooooo`03ogMgMomVIVKooooo00co
oooo0_l0001cooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`07ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo
000=ooooo`05o`000?nj^[[ooooooiRHV?l@41004?ooool3o`0006oooooo00?o0000ooooooooool0
TOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo000=ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1oooool001[ooooo00?o0000ooooooooool02?ooool2o`0006cooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo000?ooooo`Ko00001Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0UOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool00000J?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool03?ooool2o`0006So
oooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Ko
oooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool001[ooooo00?o
0000ooooooooool03oooool2o`0006Gooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo000Hooooo`03oeEEEOmVIVKo000001?ooooo0_l0001S
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06
ooooo`00;oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`06ooooo`00<?ooool2o`00067ooooo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo000booooo`04o`00
0?ooooooooooo`0005gooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Gooooo000cooooo`?o0000GOooool00ol0003oooooooooo`2Looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool003Gooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Ooo
ool003Kooooo0_l0001Kooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`00>?ooool00ol0003oooooo`00001Hooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`00>Oooool2o`0005So
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo000jooooo`;o0000Eoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01Oooool003cooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool003gooooo0ol0001C
ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`00?oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000DOooool00ol0003oooooooooo`2S
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool0001@ooooo`03o`000?oo
oooooooo0:Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`008oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`06o`000?ooooooooooo`000?oooooo
0000COooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool002_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;o
oooo0_l0001=ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`00:oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?ooool0Aoooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool002_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0_l00018oooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000:ooooo`;o0000Aoooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool004co
oooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool004gooooo00?o0000ooooool00000@oooool00ol0003o
ooooooooo`2[ooooo`05o`000?ooooooooooooooool000001Oooool004kooooo0_l00013ooooo`03
o`000?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0053ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Gooooo001Aooooo`;o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`2^ooooo`04o`000?ooooooooooo`00
00Cooooo001Cooooo`;o0000?Oooool00ol0003oooooooooo`2_ooooo`03o`000?oooooo000000Co
oooo001Dooooo`;o0000??ooool00ol0003oooooooooo`2`ooooo`;o00001?ooool005Kooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`2_ooooo`?o00001?ooool005Oooooo00?o0000
ooooool00000>?ooool00ol0003oooooooooo`2[ooooo`Co00001oooool005Sooooo0_l0000hoooo
o`03o`000?oooooooooo0:Kooooo1Ol0000;ooooo`00F_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo0:;ooooo1?l0000@ooooo`00Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo0ol0000dooooo`03o`000?oooooooooo09kooooo1?l0000Dooooo`00Boooool01OmgMgOoV9RH
oooooonHV9SoMgMg00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Iooooo`Go
00006?ooool004_ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000<oooool00ol0003o
ooooooooo`2Eooooo`Co00007Oooool004_ooooo00Go0000ooooooooooooooooo`00000?ooooo`;o
0000<Oooool00ol0003oooooooooo`2Aooooo`Co00008Oooool004_ooooo00Go0000oooooooooooo
ooooo`00000Aooooo`;o0000;oooool00ol0003oooooooooo`2<ooooo`Go00009Oooool004_ooooo
00Go410@oooooooooooooooooa0@400Booooo`;o0000;_ooool00ol0003oooooooooo`28ooooo`Co
0000:_ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`04o`000?ooooooooooo`00
02[ooooo00?o0000ooooooooool0Q?ooool4o`0002kooooo001;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h05Oooool3o`0002[ooooo00?o0000ooooooooool0Ooooool5o`0003;ooooo001Wooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0Noooool4o`0003Oooooo001Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0Moooool4o`0003_ooooo001Yooooo`?o00009_oo
ool00ol0003oooooooooo`1cooooo`Co0000?oooool006_ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1^ooooo`Go0000@oooool006cooooo0_l0000Tooooo`03o`000?oooooooooo
06[ooooo1?l00018ooooo`00K_ooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo06Ko
oooo1?l0001<ooooo`00Koooool2o`00027ooooo00?o0000ooooooooool0HOooool5o`00053ooooo
001aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool4o`0005Gooooo001J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool0FOooool4o`0005Wooooo
001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0_ooool2o`0001gooooo00?o0000ooooooooool0E?ooool5o`0005gooooo001Jooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00007?ooool00ol0003ooooo
ooooo`1@ooooo`Co0000H_ooool005[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Gooooo0ol0000Iooooo`03o`000?oooooooooo04cooooo1?l0001Vooooo`00F_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool5o`0006[ooooo001Jooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0:ooooo`?o00000_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04?ooooo1?l0001_ooooo`00F_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00000Dooooo`03
o`000?oooooooooo03oooooo1?l0001cooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000=ooooo`;o00005?ooool00ol0003oooooooooo`0jooooo`Go0000Moooool007gooooo
0_l0000Booooo`03o`000?oooooooooo03Oooooo1?l0001looooo`00Ooooool00ol0003oooooo`00
000?ooooo`03o`000?oooooooooo03?ooooo1?l00020ooooo`00P?ooool2o`0000oooooo00?o0000
ooooooooool0;oooool4o`0008Cooooo0021ooooo`;o00003_ooool00ol0003oooooooooo`0Zoooo
o`Go0000R?ooool008?ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0Vooooo`Co
0000SOooool008Cooooo0_l0000;ooooo`03o`000?oooooooooo02;ooooo1?l0002Aooooo`00Q_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1Ol0002Eooooo`00Qoooool3
o`0000Oooooo00?o0000ooooooooool06Oooool4o`0009[ooooo001jooooo`Co000000?o410@oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Noooo
o`00O?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`Go
0000X_ooool007cooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000ooooooooool0
3?ooool4o`000:Oooooo001looooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000Zoooool007cooooo00?o0000ooooooooool03oooool2o`000003ooooool0
003ooooo00Cooooo1Ol0002_ooooo`00O?ooool00ol0003oooooooooo`0Aooooo`;o000000?ooooo
o`000?l000000_l0002dooooo`00O?ooool00ol0003oooooooooo`0Booooo`;o0000^?ooool007[o
oooo00?oEEEEofIVI_l00000c_ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool0
0?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool008Kooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM0;3ooooo0028ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo0:oooooo0028ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0[_ooool008Sooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`2_ooooo`00R?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0/?ooool008Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2booooo`00
R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03oeEEEOmV
IVKo000000gooooo1?l0002aooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.44371 .52153 Mdot
.51221 .7188 Mdot
.65502 .48405 Mdot
.2772 .58112 Mdot
.41955 .34504 Mdot
.47068 .53691 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`14ooooo`;o0000DOoo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Kooooo000^ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0@_ooool4o`00053ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Uooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`11ooooo`Co0000D?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Gooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo047ooooo0_l0001Aooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09?ooool002?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Sooooo`008oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000V
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0R
ooooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0H_ooool2o`0000cooooo00?o0000ooooooooool00oooool3o`0003oooooo
00?o0000ooooooooool05Oooool002Sooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Pooooo`Co00002oooool00ol0003oooooooooo`03o`0004;ooooo00?o0000ooooooooool05Ooo
ool002Oooooo0_l0001Aooooo`03o`000?oooooooooo05oooooo1?l0000;ooooo`?o0000AOooool0
0ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
05oooooo0_l00009ooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
COooool3o`0001Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Oooooo0_l0000`ooooo`?o00006_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool05Oooool4o`0002cooooo0ol0000Mooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0Dooooo`Co0000:Oooool3o`00023ooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Dooooo`009Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Co
oooo0_l0000Wooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool06_ooool2o`0001Wooooo0ol0000Yooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0H
ooooo`Co00005?ooool4o`0002cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0C
ooooo`009Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Oooooo1?l0000Aoooo
o`?o0000<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool05oooool2o`0000oooooo0ol0000cooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Tooooo`?o0000=_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool08?oo
ool3o`0003Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool3
o`0006Oooooo00?o0000ooooooooool07?ooool3o`0003cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
01Sooooo0ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool05?ooool3o`0004?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
4?ooool3o`0004Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000A_ooool2o`0002Sooooo00?o0000ooooooooool00ol0001Booooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`14ooooo`Co0000:?ooool2o`0005Gooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0Aooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oo
oooooooo04Cooooo1?l0000Xooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`15ooooo`;o0000:Oooool0
0ol0003oooooooooo`1Booooo`?o0000BOooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo04oooooo0ol00002ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1<ooooo`?o00001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017o
oooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0BOooool3o`0000[ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`008_ooool2o`0007;ooooo00?o
0000ooooooooool0AOooool4o`0000kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04;ooooo0ol0000C
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3
o`0002Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`00
07?ooooo00?o0000ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0?ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002ko
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Vooooo`?o0000=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000P
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o
0000@_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_oo
ool3o`0004_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0@ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`06ooooo`?o0000Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000oooo
ool000000ol0001Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001ko
oooo00?o0000ooooooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?oo
ool0K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
KOooool3o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1S
ooooo`?o00003_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo067ooooo0ol0000Aooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo0_l0001Oooooo`?o00005?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool000Cooooo00?oEEEEofIVI_l00000
3Oooool4o`0000Gooooo00?o0000ooooooooool0F_ooool4o`0001Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oo
oooooooo05Oooooo0ol0000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Dooooo`?o00007_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool0
01gooooo00?o0000ooooooooool0DOooool3o`00027ooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo04oo
oooo0ol0000Tooooo`03o`000?oooooooooo01[ooooo0_l0001Hooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03?ooool001cooooo00?o0000ooooooooool0Boooool4o`0002Oooooo
00?o0000ooooooooool06Oooool4o`0005Sooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0;ooooo`007?ooool2o`0004Wooooo0ol0000[ooooo`03o`000?oooooooooo01Wooooo1?l0
001Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool001cooooo00?o0000
ooooooooool0AOooool3o`0002kooooo00?o0000ooooooooool06_ooool2o`0005_ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
03;ooooo1?l00010ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0:ooooo`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo
0ol00017ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool09oooool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0
7Oooool3o`0005Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool0
0ol0003oooooooooo`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00
067ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo000Iooooo`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003ooooo
ooooo`0>ooooo`?o0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000I
ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?oo
ool2o`0007[ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<oooo
o`;o0000MOooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`00
4?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0
001_ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`07ooooo`003Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`00
0?oooooooooo00cooooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omE
EEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo
0_l0001Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`00<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000e
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool0
0000F?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool003Wooooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000mooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1_l0003oooooooooool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0004Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`00
0?oooooo000004?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Go
oooo001>ooooo`;o0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003ooooo
ooooool00005ooooo`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0
[_ooool01?l0003oooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0
[oooool00ol0003oooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?oo
ool2o`0000Cooooo001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3
o`0000Cooooo001Gooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`00
00Oooooo001Hooooo`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
5?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0003?ooooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo
001;ooooo`05o`000?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0
S?ooool5o`0002Gooooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo
00?o0000ooooooooool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00
Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oo
oooo1Ol0000booooo`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo
1?l0000gooooo`00J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0
000kooooo`00JOooool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o
00009?ooool00ol0003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oo
oooooooo067ooooo1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooooooo05Wooooo1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0
001Mooooo`00F_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003ooooooooo
o`1<ooooo`Co0000I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
1Ol0001Zooooo`00F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
2_ooool3o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000
Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0
>_ooool5o`0007Oooooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?oo
ool007oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0
083ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000ko
oooo00?o0000ooooooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003ooooooooo
o`0Rooooo`Co0000TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Go0000UOooool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Joooo
o`00N_ooool4o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l0
0003ooooo`03o`000?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000oooo
ooooool04Oooool2o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000oooooooo
ool04_ooool2o`000;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@2`ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_
ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2booooo`00Q_ooool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43314 .51797 Mdot
.50837 .68394 Mdot
.66279 .4802 Mdot
.41765 .36665 Mdot
.2671 .59448 Mdot
.45713 .54441 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0?Oooool2o`0005;ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`008oooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0kooooo`Co0000DOooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo000Sooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03[ooooo1?l0001A
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool002?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0>_ooool2
o`0005;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Vooooo`;o00002Oooool00ol0003o
ooooooooo`06ooooo`?o0000??ooool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo06Cooooo1?l00008ooooo`03o`000?oooooooooo00?ooooo
0ol0000oooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool0Hoooool4o`0000Sooooo00?o0000ooooooooool00ol00012ooooo`03o`000?oo
oooooooo01Gooooo000Wooooo`;o0000DOooool00ol0003oooooooooo`1Sooooo`;o00002Oooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
5Oooool2o`0003Kooooo0ol0000Gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
5?ooool002Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`Co0000<_oo
ool3o`0001[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01;ooooo1?l0000_ooooo`?o00007Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool04_ooool2o`0002gooooo0ol0000Pooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0mooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0=Oooool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Cooooo`009Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo033ooooo1?l0000/
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Dooooo`;o00005_ooool3o`00033ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01;ooooo1?l0000Booooo`?o0000<oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
4Oooool4o`0000oooooo0ol0000fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
4oooool002Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Aooooo`;o00003Ooo
ool3o`0003Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool3
o`0006Oooooo00?o0000ooooooooool07?ooool3o`0003cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
01Sooooo0ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool05?ooool3o`0004?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
4?ooool3o`0004Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo073ooooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4Oooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooo
oooo017ooooo000Rooooo`03o`000?oooooooooo04?ooooo0_l0000/ooooo`03o`000?oooooooooo
04oooooo0ol00002ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool002;o
oooo00?o0000ooooooooool0@_ooool4o`0002_ooooo00?o0000ooooooooool0C?ooool3o`0000Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003ooooo
ooooo`12ooooo`Co0000:oooool00ol0003oooooooooo`19ooooo`?o00002_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo017ooooo000Rooooo`;o0000A?ooool2o`0002cooooo00?o
0000ooooooooool0AOooool4o`0000kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04;ooooo0ol0000C
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3
o`0002Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`00
07?ooooo00?o0000ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0?ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002ko
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Vooooo`?o0000=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000P
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o
0000@_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_oo
ool3o`0004_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0@ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`06ooooo`?o0000Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000oooo
ool000000ol0001Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001ko
oooo00?o0000ooooooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?oo
ool06_ooool2o`00053ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`00
1_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo06gooooo0ol00004ooooo`03o`000?oooooooooo01Sooooo1?l0001@ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06[ooooo0ol00007ooooo`03o`000?oo
oooooooo01Sooooo1?l0001Aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03Ooo
ool000Kooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo06Kooooo1?l0000:ooooo`03o`000?oooooooooo01Wooooo0_l0001Cooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Hoooool3o`0000kooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo0006oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qoooo
o`?o00004Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03?ooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o
0000Goooool3o`0001Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00cooooo0004ooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03o`00
0?oooooooooo05[ooooo1?l0000Gooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Gooooo`?o00006ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?oo
ool001gooooo00?o0000ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo
057ooooo0ol0000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00009?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo
00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
03;ooooo1?l00010ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0:ooooo`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo
0ol00017ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool09oooool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0
7Oooool3o`0005Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool0
0ol0003oooooooooo`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00
067ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo000Iooooo`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003ooooo
ooooo`0>ooooo`?o0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000I
ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?oo
ool2o`0007[ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<oooo
o`;o0000MOooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`00
4?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0
001_ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`07ooooo`003Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`00
0?oooooooooo00cooooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omE
EEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo
0_l0001Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`00<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000e
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool0
0000F?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool003Wooooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000mooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1_l0003oooooooooool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0004Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`00
0?oooooo000004?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Go
oooo001>ooooo`;o0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003ooooo
ooooool00005ooooo`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0
[_ooool01?l0003oooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0
[oooool00ol0003oooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?oo
ool2o`0000Cooooo001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3
o`0000Cooooo001Gooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`00
00Oooooo001Hooooo`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
5?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0003?ooooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo
001;ooooo`05o`000?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0
S?ooool5o`0002Gooooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo
00?o0000ooooooooool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00
Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oo
oooo1Ol0000booooo`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo
1?l0000gooooo`00J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0
000kooooo`00JOooool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o
00009?ooool00ol0003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oo
oooooooo067ooooo1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooooooo05Wooooo1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0
001Mooooo`00F_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003ooooooooo
o`1<ooooo`Co0000I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
1Ol0001Zooooo`00F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
2_ooool3o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000
Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0
>_ooool5o`0007Oooooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?oo
ool007oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0
083ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000ko
oooo00?o0000ooooooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003ooooooooo
o`0Rooooo`Co0000TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Go0000UOooool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Joooo
o`00N_ooool4o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l0
0003ooooo`03o`000?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000oooo
ooooool04Oooool2o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000oooooooo
ool04_ooool2o`000;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@2`ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_
ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2booooo`00Q_ooool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43698 .53212 Mdot
.48456 .69801 Mdot
.64982 .47777 Mdot
.40742 .37272 Mdot
.24624 .60443 Mdot
.45429 .53915 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0hooooo`;o0000EOooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo1?l0001Dooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool002gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0eooooo`Co0000E?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
023ooooo000]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0=Oooool2o`0005Go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
06?ooooo0_l0000=ooooo`03o`000?oooooooooo00Wooooo0ol0000hooooo`03o`000?oooooooooo
01Kooooo000Xooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0HOooool4o`0000co
oooo00?o0000ooooooooool01_ooool3o`0003cooooo00?o0000ooooooooool05Oooool002Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1Pooooo`Co00003?ooool00ol0003ooooo
ooooo`03ooooo`?o0000?oooool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo063ooooo0_l0000=ooooo`03o`000?oooooooooo00?o0000@_oo
ool00ol0003oooooooooo`0Eooooo`009oooool2o`00057ooooo00?o0000ooooooooool0K_ooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
COooool3o`0001Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Wooooo0ol0000Jooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`15ooooo`?o00007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo01Cooooo000Vooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@Oooool3o`00
023ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo0_l0000Yooooo`?o00008oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`;o0000H?ooool00ol0003ooooo
ooooo`0@ooooo`Co00009Oooool3o`0002Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00oooooo1?l0
0002ooooo`;o00007_ooool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Cooooo`009Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00oooooo0_l00002
ooooo`Co00006Oooool4o`0002cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0C
ooooo`009Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01;ooooo1?l0000Foooo
o`?o0000<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool04_ooool2o`0001Cooooo0ol0000cooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Tooooo`?o0000=_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool08?oo
ool3o`0003Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool3
o`0006Oooooo00?o0000ooooooooool07?ooool3o`0003cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
01Sooooo0ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool05?ooool3o`0004?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
4?ooool3o`0004Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo073ooooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4Oooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooo
oooo017ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Coooool3o`00
00;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo04cooooo0ol00006ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`19ooooo`?o00002_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo
000Rooooo`;o0000?_ooool2o`0003;ooooo00?o0000ooooooooool0AOooool4o`0000kooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0l
ooooo`Co0000<Oooool00ol0003oooooooooo`12ooooo`?o00004oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo03cooooo1?l0000aoooo
o`03o`000?oooooooooo03oooooo0ol0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool04?ooool002;ooooo00?o0000ooooooooool0?Oooool2o`0003;ooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3
o`0002Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`00
07?ooooo00?o0000ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0?ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002ko
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Vooooo`?o0000=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000P
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o
0000@_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_oo
ool3o`0004_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0@ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`06ooooo`?o0000Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000oooo
ool000000ol0001Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001ko
oooo00?o0000ooooooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?oo
ool0K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
KOooool3o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1S
ooooo`?o00003_ooool00ol0003oooooooooo`0Booooo`;o0000Foooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Qooooo`?o00004Oooool00ol0003oooooooooo`0Aoooo
o`Co0000Foooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo0006ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`0005oooooo0ol0000Dooooo`03
o`000?oooooooooo017ooooo1?l0001Kooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool03?ooool000Cooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0
F_ooool4o`0001Oooooo00?o0000ooooooooool04_ooool2o`0005gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Gooooo`?o00006ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?oo
ool001gooooo00?o0000ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo
057ooooo0ol0000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00009?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo
00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
03;ooooo1?l00010ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0:ooooo`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo
0ol00017ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool09oooool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0
7Oooool3o`0005Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool0
0ol0003oooooooooo`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00
067ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo000Iooooo`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003ooooo
ooooo`0>ooooo`?o0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000I
ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?oo
ool2o`0007[ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<oooo
o`;o0000MOooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`00
4?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0
001_ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`07ooooo`003Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`00
0?oooooooooo00cooooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omE
EEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo
0_l0001Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`00<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000e
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool0
0000F?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool003Wooooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000mooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1_l0003oooooooooool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0004Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`00
0?oooooo000004?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Go
oooo001>ooooo`;o0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003ooooo
ooooool00005ooooo`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0
[_ooool01?l0003oooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0
[oooool00ol0003oooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?oo
ool2o`0000Cooooo001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3
o`0000Cooooo001Gooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`00
00Oooooo001Hooooo`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
5?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0003?ooooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo
001;ooooo`05o`000?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0
S?ooool5o`0002Gooooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo
00?o0000ooooooooool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00
Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oo
oooo1Ol0000booooo`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo
1?l0000gooooo`00J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0
000kooooo`00JOooool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o
00009?ooool00ol0003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oo
oooooooo067ooooo1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooooooo05Wooooo1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0
001Mooooo`00F_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003ooooooooo
o`1<ooooo`Co0000I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
1Ol0001Zooooo`00F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
2_ooool3o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000
Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0
>_ooool5o`0007Oooooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?oo
ool007oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0
083ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000ko
oooo00?o0000ooooooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003ooooooooo
o`0Rooooo`Co0000TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Go0000UOooool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Joooo
o`00N_ooool4o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l0
0003ooooo`03o`000?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000oooo
ooooool04Oooool2o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000oooooooo
ool04_ooool2o`000;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@2`ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_
ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2booooo`00Q_ooool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.44683 .52123 Mdot
.48706 .70929 Mdot
.65095 .47016 Mdot
.39645 .37731 Mdot
.24088 .59688 Mdot
.4713 .5488 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=?ooool2o`0005Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03;ooooo1?l0001Gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool002go
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0aooooo`Co0000Eoooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo01oooooo000/ooooo`;o0000;Oooool00ol0003ooooo
ooooo`0aooooo`;o0000F?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0IOooool2o`0000gooooo00?o0000ooooooooool03oooool3o`00
03;ooooo00?o0000ooooooooool05_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Soooo
o`Co00003?ooool00ol0003oooooooooo`0<ooooo`?o0000=Oooool00ol0003oooooooooo`0Foooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0H_ooool4o`0000cooooo00?o0000ooooooooool02Oooool3o`00
03Sooooo00?o0000ooooooooool05_ooool002Sooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`1Rooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`?o0000??ooool00ol0003o
ooooooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool00oooool3o`0003oooooo00?o0000ooooooooool05Oooool002Sooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00?o0000@_oo
ool00ol0003oooooooooo`0Eooooo`009oooool2o`00057ooooo00?o0000ooooooooool0K_ooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
COooool3o`0001Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo0_l0000_ooooo`?o00006_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool05_ooool4o`0002_ooooo0ol0000Mooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0Eooooo`Co0000:?ooool3o`00023ooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Dooooo`009Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Go
oooo0_l0000Vooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0=Oooool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Cooooo`009Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo033ooooo1?l0000/
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0/ooooo`?o0000<?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool06?ooool2o`0000kooooo0ol0000cooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool04oooool002Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`Co0000
2_ooool3o`0003Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009?oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01Gooooo1?l00007ooooo`?o0000>Ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Tooooo`?o0000Ioooool0
0ol0003oooooooooo`0Eooooo`;o00001Oooool3o`0003cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
01Sooooo0ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool05?ooool3o`0004?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
4?ooool3o`0004Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo073ooooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4Oooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooo
oooo017ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Coooool3o`00
00;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003o
ooooooooo`0kooooo`;o0000=?ooool00ol0003oooooooooo`1<ooooo`?o00001_ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo03[ooooo
1?l0000cooooo`03o`000?oooooooooo04Wooooo0ol0000:ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04Oooool002;ooooo0_l0000kooooo`Co0000<oooool00ol0003ooooooooo
o`15ooooo`Co00003_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo03_ooooo0_l0000dooooo`03o`000?oooooooooo04;ooooo0ol0000C
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3
o`0002Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`00
07?ooooo00?o0000ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0?ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002ko
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Vooooo`?o0000=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000P
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o
0000@_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_oo
ool3o`0004_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0@ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`06ooooo`?o0000Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000oooo
ool000000ol0001Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001ko
oooo00?o0000ooooooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?oo
ool0K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
KOooool3o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1S
ooooo`?o00003_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo067ooooo0ol0000Aooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo0_l0001Oooooo`?o00005?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool000Cooooo00?oEEEEofIVI_l00000
3Oooool4o`0000Gooooo00?o0000ooooooooool0F_ooool4o`0001Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oo
oooooooo05Oooooo0ol0000Kooooo`03o`000?oooooooooo01;ooooo0_l0001Nooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0E?ooool3
o`0001kooooo00?o0000ooooooooool04Oooool4o`0005kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Aooooo`?o00008Oooool00ol0
003oooooooooo`0Aooooo`Co0000Goooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00cooooo000Looooo`03o`000?oooooooooo04oooooo0ol0000Tooooo`03o`000?oooooooooo01;o
oooo0_l0001Pooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo
00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
03;ooooo1?l00010ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0:ooooo`006oooool2o`00033ooooo0ol00014ooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool2o`0002kooooo
0ol00017ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool09oooool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@oooo
o`03o`000?oooooooooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool0
7Oooool3o`0005Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool0
0ol0003oooooooooo`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00
067ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo000Iooooo`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003ooooo
ooooo`0>ooooo`?o0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000I
ooooo`03o`000?oooooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?oo
ool2o`0007[ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<oooo
o`;o0000MOooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`00
4?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0
001_ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`07ooooo`003Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`00
0?oooooooooo00cooooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omE
EEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo
0_l0001Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`00<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000e
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool0
0000F?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool003Wooooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000mooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00
057ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1_l0003oooooooooool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003
ooooool0003ooooo04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0004Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000oooooooo
ool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`00
0?oooooo000004?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Go
oooo001>ooooo`;o0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003ooooo
ooooool00005ooooo`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0
[_ooool01?l0003oooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0
[oooool00ol0003oooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?oo
ool2o`0000Cooooo001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3
o`0000Cooooo001Gooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`00
00Oooooo001Hooooo`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
5?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0003?ooooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo
001;ooooo`05o`000?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0
S?ooool5o`0002Gooooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo
00?o0000ooooooooool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00
Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oo
oooo1Ol0000booooo`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo
1?l0000gooooo`00J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0
000kooooo`00JOooool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o
00009?ooool00ol0003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oo
oooooooo067ooooo1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooooooo05Wooooo1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0
001Mooooo`00F_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003ooooooooo
o`1<ooooo`Co0000I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
1Ol0001Zooooo`00F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
2_ooool3o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000
Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0
>_ooool5o`0007Oooooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?oo
ool007oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0
083ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000ko
oooo00?o0000ooooooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003ooooooooo
o`0Rooooo`Co0000TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`Go0000UOooool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Joooo
o`00N_ooool4o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l0
0003ooooo`03o`000?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000oooo
ooooool04Oooool2o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000oooooooo
ool04_ooool2o`000;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@2`ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_
ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2booooo`00Q_ooool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43213 .52695 Mdot
.48447 .71083 Mdot
.64462 .47672 Mdot
.39766 .36885 Mdot
.25278 .58363 Mdot
.47198 .56296 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Kooooo0_l0001Hooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08_ooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=?ooool4o`0005Oooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`Co0000Eoooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo023ooooo000]ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0<oooool2o`0005Sooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
067ooooo0_l0000?ooooo`03o`000?oooooooooo00Wooooo0ol0000hooooo`03o`000?oooooooooo
01Kooooo000Xooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Goooool4o`0000ko
oooo00?o0000ooooooooool01_ooool3o`0003cooooo00?o0000ooooooooool05Oooool002Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1Nooooo`Co00003_ooool00ol0003ooooo
ooooo`03ooooo`?o0000?oooool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo05kooooo0_l0000?ooooo`03o`000?oooooooooo00?o0000@_oo
ool00ol0003oooooooooo`0Eooooo`009oooool2o`00057ooooo00?o0000ooooooooool0K_ooool3
o`0004Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`1Zooooo`Co0000Aoooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo06Kooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
COooool3o`0001Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Wooooo0ol0000Jooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`15ooooo`?o00007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo01Cooooo000Vooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool04_ooool2o`00
02gooooo0ol0000Pooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Go
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0@ooooo`Co0000:Oooool3o`0002?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool2o`00063ooooo
00?o0000ooooooooool03oooool4o`0002Kooooo0ol0000Vooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0?ooooo`;o00009?ooool3o`0002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Cooooo`009Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo033ooooo1?l0000/
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0/ooooo`?o0000<?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0:?ooool3o`0003?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`00
9Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Cooooo0ol0000fooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo01;ooooo000Tooooo`?o0000Ioooool00ol0003oooooooooo`0Looooo`?o0000??ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Tooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool06?ooool3o`0003oooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Booooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`0Cooooo`Co0000@oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`0@ooooo`Go0000A?ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Jooo
ool00ol0003oooooooooo`0<ooooo`?o000000?oooooo`000?l000000_l00014ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Sooooo0ol00005ooooo`;o0000AOooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`04ooooo`?o0000Coooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Co
oooo0_l0001`ooooo`03o`000?oooooooooo00?o0000D_ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?_ooool2o`00033ooooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4Oooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0mooooo`Co0000;ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Ooo
ool002?ooooo00?o0000ooooooooool0?Oooool4o`0002oooooo00?o0000ooooooooool0D_ooool3
o`0004Wooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0?oooool2o`00
033ooooo00?o0000ooooooooool0Coooool3o`0000;ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04co
oooo0ol00006ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`19ooooo`?o00002_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo017ooooo000Rooooo`;o0000L_ooool00ol0003ooooooooo
o`15ooooo`Co00003_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0@_ooool3o`0001?ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03oooooo0ol0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0looooo`?o
00006_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0>Oooool3o`0001kooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo03Gooooo1?l0000Rooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool04?oo
ool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0booooo`?o00009oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000Loooool00ol0
003oooooooooo`0_ooooo`?o0000:oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00oooooo000Pooooo`;o0000M?ooool00ol0003oooooooooo`0/ooooo`?o0000;_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00oooooo000Qooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0:?ooool4o`0003;ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02Kooooo0ol0
000gooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03oooool0023ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`0Sooooo`?o0000>oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool08?ooool3o`0003oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?oooo
o`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01gooooo0ol00012ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0Iooooo`Co0000A_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00oooooo000Oooooo`;o0000M?ooool00ol0003oooooooooo`0Fooooo`?o0000Booo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool04oooool3o`0004oooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
013ooooo0ol0001Cooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03_ooool001oo
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0<ooooo`Co0000Eoooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool02Oooool3o`0005_ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Kooooo0ol0
001Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03_ooool001oooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`03ooooo`?o0000Hoooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00kooooo000Nooooo`?o0000M?ooool00ol0003oooooo`000003o`00
06Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`007_ooool00ol0003o
ooooooooo`1cooooo`?o0000K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00go
oooo0004ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo073ooooo0ol000000ooooooo0000ooooo`1/ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1]ooooo`?o0000
1?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
3Oooool000Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06[ooooo0ol00007ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0I_ooool4o`0000[ooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06?ooooo0ol0000>
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=
ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0HOooool3o`00017ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool2o`0005oooooo0ol0000Dooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0<ooooo`001?ooool00omEEEGoIVIVo`00000=ooooo`Co0000
1Oooool00ol0003oooooooooo`1Jooooo`Co00005oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0Eooo
ool3o`0001_ooooo00?o0000ooooooooool04_ooool2o`0005kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Dooooo`?o00007_ooool0
0ol0003oooooooooo`0Aooooo`Co0000G_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00cooooo000Mooooo`03o`000?oooooooooo057ooooo0ol0000Qooooo`03o`000?oooooooooo
017ooooo1?l0001Oooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001co
oooo00?o0000ooooooooool0Coooool3o`0002Cooooo00?o0000ooooooooool04_ooool2o`00063o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02oooool001cooooo0_l00019ooooo`?o0000:oooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool001cooooo00?o0000
ooooooooool0AOooool3o`0002kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000aoooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;oooo
o`007?ooool00ol0003oooooooooo`0nooooo`Co0000=?ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
??ooool3o`0003Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Wooooo0ol0000jooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0fooooo`?o0000?Oooool00ol0003oooooooooo`1looooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<_ooool4o`00
043ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00[ooooo000Kooooo`;o0000<?ooool3o`0004Cooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000Jooooo`;o0000;_ooool3o`0004Oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo
000Jooooo`03o`000?oooooooooo02[ooooo0ol0001:ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0W
ooooo`?o0000COooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02_ooool001[ooooo00?o0000ooooooooool08oooool4o`00053ooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo000Jooooo`03
o`000?oooooooooo023ooooo0ol0001Dooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Mooooo`?o0000
Eoooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2Oooool001[ooooo00?o0000ooooooooool06_ooool3o`0005[ooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooo
oooo01Kooooo1?l0001Mooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Dooooo`?o0000HOooool00ol0
003oooooooooo`25ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool001Wo
oooo00?o0000ooooooooool04Oooool3o`0006Cooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo00kooooo
0ol0001Wooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`09ooooo`006Oooool00ol0003oooooooooo`0;ooooo`?o0000J_ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000
ooooooooool01oooool4o`0006gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Sooooo000Hooooo`;o00001_ooool3o`00077ooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo000Hooooo`03
o`000?oooooooooo00;ooooo0ol0001dooooo`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`08ooooo`006?ooool5o`0007Oooooo00?o0000ooooooooool0
Roooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000Hooooo`;o0000N_oo
ool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?oo
ool000gooooo1Ol00008ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo000=ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@02Oooool2o`0007Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Sooooo000>ooooo`03oiRHV?lQ8B7ok^k^00cooooo0_l0001eoooo
o`03o`000?oooooooooo08kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08oooo
o`003oooool00onHV9So8B4Qonk^kP0<ooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo000@ooooo`03ogMg
MomVIVKooooo00cooooo0_l0001cooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Oooooo000=ooooo`05o`000?nj^[[ooooooiRHV?l@41004?ooool3o`0006oooooo00?o
0000ooooooooool0TOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo000=
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool4o`000003oa0@4?oooooooooo00Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool02?ooool2o`0006cooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo000?oooo
o`Ko00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo000Jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooool00000J?ooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool0
3?ooool2o`0006Sooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_oo
ool001[ooooo00?o0000ooooooooool03oooool2o`0006Gooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Hooooo`03oeEEEOmVIVKo0000
01?ooooo0_l0001Sooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`06ooooo`00;oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00<?ooool2o`00067ooooo
00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo
000booooo`04o`000?ooooooooooo`0005gooooo00?o0000ooooooooool0Voooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo000cooooo`?o0000GOooool00ol0003ooooooooo
o`2Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool003Gooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01Oooool003Kooooo0_l0001Kooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`00>?ooool00ol0003oooooo`00001Hooooo`03
o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`00
>Oooool2o`0005Sooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo000jooooo`;o0000Eoooool00ol0003oooooooooo`2Pooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool003cooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
03gooooo0ol0001Cooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`00?oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000DOooool00ol0
003oooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool0001@
ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04
ooooo`008oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`06o`000?oooooo
ooooo`000?oooooo0000COooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool002_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00;ooooo0_l0001=ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`00:oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0Yoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?oo
ool0Aoooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool002_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[o
oooo0_l00018ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000:ooooo`;o
0000Aoooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool004cooooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`2Zooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool004gooooo00?o0000ooooool00000
@oooool00ol0003oooooooooo`2[ooooo`05o`000?ooooooooooooooool000001Oooool004kooooo
0_l00013ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0053ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Go
oooo001Aooooo`;o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`2^ooooo`04o`00
0?ooooooooooo`0000Cooooo001Cooooo`;o0000?Oooool00ol0003oooooooooo`2_ooooo`03o`00
0?oooooo000000Cooooo001Dooooo`;o0000??ooool00ol0003oooooooooo`2`ooooo`;o00001?oo
ool005Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2_ooooo`?o00001?ooool0
05Oooooo00?o0000ooooool00000>?ooool00ol0003oooooooooo`2[ooooo`Co00001oooool005So
oooo0_l0000hooooo`03o`000?oooooooooo0:Kooooo1Ol0000;ooooo`00F_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo0:;ooooo1?l0000@ooooo`00Boooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo0ol0000dooooo`03o`000?oooooooooo09kooooo1?l0000Dooooo`00Booo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`2Iooooo`Go00006?ooool004_ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000
<oooool00ol0003oooooooooo`2Eooooo`Co00007Oooool004_ooooo00Go0000oooooooooooooooo
o`00000?ooooo`;o0000<Oooool00ol0003oooooooooo`2Aooooo`Co00008Oooool004_ooooo00Go
0000ooooooooooooooooo`00000Aooooo`;o0000;oooool00ol0003oooooooooo`2<ooooo`Go0000
9Oooool004_ooooo00Go410@oooooooooooooooooa0@400Booooo`;o0000;_ooool00ol0003ooooo
ooooo`28ooooo`Co0000:_ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`04o`00
0?ooooooooooo`0002[ooooo00?o0000ooooooooool0Q?ooool4o`0002kooooo001;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h05Oooool3o`0002[ooooo00?o0000ooooooooool0Ooooool5o`0003;o
oooo001Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Noooool4o`0003Oooooo
001Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Moooool4o`0003_ooooo001Y
ooooo`?o00009_ooool00ol0003oooooooooo`1cooooo`Co0000?oooool006_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1^ooooo`Go0000@oooool006cooooo0_l0000Tooooo`03
o`000?oooooooooo06[ooooo1?l00018ooooo`00K_ooool00ol0003oooooo`00000Qooooo`03o`00
0?oooooooooo06Kooooo1?l0001<ooooo`00Koooool2o`00027ooooo00?o0000ooooooooool0HOoo
ool5o`00053ooooo001aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool4
o`0005Gooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool0FOoo
ool4o`0005Wooooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00_ooool2o`0001gooooo00?o0000ooooooooool0E?ooool5o`0005gooooo001J
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00007?oo
ool00ol0003oooooooooo`1@ooooo`Co0000H_ooool005[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Gooooo0ol0000Iooooo`03o`000?oooooooooo04cooooo1?l0
001Vooooo`00F_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c008ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool5o`0006[ooooo
001Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0:ooooo`?o0000
0_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04?ooooo1?l0001_ooooo`00F_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
o`00000Dooooo`03o`000?oooooooooo03oooooo1?l0001cooooo`00F_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l0000=ooooo`;o00005?ooool00ol0003oooooooooo`0jooooo`Go0000
Moooool007gooooo0_l0000Booooo`03o`000?oooooooooo03Oooooo1?l0001looooo`00Ooooool0
0ol0003oooooo`00000?ooooo`03o`000?oooooooooo03?ooooo1?l00020ooooo`00P?ooool2o`00
00oooooo00?o0000ooooooooool0;oooool4o`0008Cooooo0021ooooo`;o00003_ooool00ol0003o
ooooooooo`0Zooooo`Go0000R?ooool008?ooooo00?o0000ooooool000002oooool00ol0003ooooo
ooooo`0Vooooo`Co0000SOooool008Cooooo0_l0000;ooooo`03o`000?oooooooooo02;ooooo1?l0
002Aooooo`00Q_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1Ol0002E
ooooo`00Qoooool3o`0000Oooooo00?o0000ooooooooool06Oooool4o`0009[ooooo001jooooo`Co
000000?o410@ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo1?l0002Nooooo`00O?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool00ol0003ooooo
ooooo`0@ooooo`Go0000X_ooool007cooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o
0000ooooooooool03?ooool4o`000:Oooooo001looooo`03o`000?oooooooooo00kooooo00Go0000
ooooooooooooooooo`00000:ooooo`Co0000Zoooool007cooooo00?o0000ooooooooool03oooool2
o`000003ooooool0003ooooo00Cooooo1Ol0002_ooooo`00O?ooool00ol0003oooooooooo`0Aoooo
o`;o000000?oooooo`000?l000000_l0002dooooo`00O?ooool00ol0003oooooooooo`0Booooo`;o
0000^?ooool007[ooooo00?oEEEEofIVI_l00000c_ooool00?ooooooC?ooool00?ooooooC?ooool0
0?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool008Kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM0;3ooooo0028
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo0:oooooo0028oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[_ooool008Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool00ol0003oooooooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0/?ooool008Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2booooo`00R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo0026
ooooo`03oeEEEOmVIVKo000000gooooo1?l0002aooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.44144 .54135 Mdot
.4989 .74591 Mdot
.63669 .48812 Mdot
.38829 .37246 Mdot
.25598 .60031 Mdot
.47503 .56056 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0cooooo`;o0000F_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo037ooooo1?l0001Iooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool002gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0`ooooo`Co0000FOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
023ooooo000]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<?ooool2o`0005[o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05cooooo0_l0
000Aooooo`03o`000?oooooooooo00?o0000@_ooool00ol0003oooooooooo`0Eooooo`009oooool2
o`00057ooooo00?o0000ooooooooool0F_ooool4o`00013ooooo0ol00015ooooo`03o`000?oooooo
oooo01Gooooo000Wooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0FOooool4o`00
00gooooo1?l00017ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0FOooool2o`0000_ooooo0ol00003ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Qooooo`Co00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo
000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0GOooool3o`0000_ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo05Wooooo0ol0000>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo0_l0001Hooooo`03o`000?oooooooooo05Gooooo0ol0000Aoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`1Aooooo`?o00005?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
COooool3o`0001Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Wooooo0ol0000Jooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`15ooooo`?o00007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo01Cooooo000Vooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@Oooool3o`00
023ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo03gooooo0ol0000Sooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04oooool002Gooooo0_l0001Pooooo`03o`000?oooooooooo03Wooooo
0ol0000Vooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0eooooo`?o0000:Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool04Oooool2o`0001gooooo1?l0000/ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04oooool002Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0?oooo
o`Co00006Oooool3o`00033ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Coooo
o`009Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo1?l0000Fooooo`?o
0000<oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool03_ooool2o`0001Cooooo0ol0000fooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo01;ooooo000Tooooo`?o0000Ioooool00ol0003oooooooooo`0Looooo`?o0000??ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Tooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool05Oooool2o`000004ooooool0003o0000o`0003oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`006_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Cooooo`Co0000@oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0@ooooo`Ko0000@oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`?o00000oooool2o`0004Cooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3o`0004cooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`0004oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`04oooo
o`;o0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo073o
oooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001[ooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo05;ooooo0ol00019ooooo`03o`000?oooooooooo017ooooo000R
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Coooool3o`0000;ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo04cooooo0ol00006ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04Oooool002;ooooo00?o0000ooooooooool0@?ooool2o`0002oooooo00?o0000oooooooo
ool0BOooool3o`0000[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`00
8_ooool2o`00043ooooo1?l0000^ooooo`03o`000?oooooooooo04Gooooo1?l0000>ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0?ooo
ool4o`0002kooooo00?o0000ooooooooool0@_ooool3o`0001?ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`10ooooo`;o0000;oooool0
0ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0??ooool3o`00
01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo
000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3o`0002Oooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0007?ooooo00?o0000
ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?
ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Vooooo`?o0000
=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0
023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o0000@_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_ooool3o`0004_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0@
ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo000Ooooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`?o0000
Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000ooooool000000ol0001W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001kooooo00?o0000oooo
ooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=oooo
o`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?ooool0K?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0KOooool3o`0000Co
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00go
oooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Sooooo`?o00003_oo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Ooo
ool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo067ooooo0ol0000Aooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_l0001Oooooo`?o00005?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool03?ooool000Cooooo00?oEEEEofIVI_l000003Oooool4o`0000Go
oooo00?o0000ooooooooool0F_ooool4o`0001Oooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Oooooo
0ol0000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Dooooo`?o00007_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool001gooooo00?o0000
ooooooooool0DOooool3o`00027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo04oooooo0ol0000Toooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<oooo
o`007?ooool00ol0003oooooooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool001cooooo0_l00019ooooo`?o0000
:oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2oooool001cooooo00?o0000ooooooooool0AOooool3o`0002kooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooo
oooo04;ooooo0ol0000aooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co0000=?ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0??ooool3o`0003Oooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Wooooo
0ol0000jooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0fooooo`?o0000?Oooool00ol0003ooooooooo
o`0Gooooo`;o0000Hoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo03;ooooo1?l00010ooooo`03o`000?oooooooooo01Kooooo1?l0001S
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool001_ooooo0_l0000`oooo
o`?o0000A?ooool00ol0003oooooooooo`0Fooooo`Co0000I?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00[ooooo000Jooooo`;o0000;_ooool3o`0004Oooooo00?o0000oooooooo
ool05oooool2o`0006Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`00
6_ooool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool09ooo
ool3o`0004gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00[ooooo000Jooooo`03o`000?oooooooooo02?ooooo1?l0001@ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0
003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool07Oooool3o`0005Oo
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wo
oooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003ooooooooo
o`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00067ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Ioooo
o`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0>ooooo`?o
0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oo
oooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0
003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`000?oooooooooo08_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?ooool2o`0007[ooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<ooooo`;o0000MOooool0
0ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool0
00oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`004?ooool00omgMgOo
IVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0001_ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`003Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413oooooooooo`05ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/ooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`003oooool6
o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000ooooooooool0UOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00co
oooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo
000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omEEEGoIVIVo`00000C
ooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo0_l0001Qooooo`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00
<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o0000ooooooooool0
W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000eooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool00000F?ooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Wo
oooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000m
ooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00057ooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000D?oo
ool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool01_l0003ooooooooo
ool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00:oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo
04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:oooo
o`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002_ooool2o`00
04Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ooooooooool0Z_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`000?oooooo000004?o
oooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Gooooo001>ooooo`;o
0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Gooooo001@ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005oooo
o`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0[_ooool01?l0003o
ooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0[oooool00ol0003o
ooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?ooool2o`0000Cooooo
001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3o`0000Cooooo001G
ooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`0000Oooooo001Hoooo
o`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00005?ooool004_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0003?o
oooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?ooooooooooooooool0
00003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo001;ooooo`05o`00
0?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0S?ooool5o`0002Go
oooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo00?o0000oooooooo
ool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool01?l0003o
ooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00Boooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oooooo1Ol0000boooo
o`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo1?l0000gooooo`00
J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0000kooooo`00JOoo
ool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o00009?ooool00ol0
003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool000008Oooool00ol0003o
ooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oooooooooo067ooooo
1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0
001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo05Wooooo
1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0001Mooooo`00F_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2o`0001cooooo
00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003oooooooooo`1<ooooo`Co0000
I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo1Ol0001Zooooo`00
F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02_ooool3o`0000;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000Koooool005[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool0
00005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0>_ooool5o`0007Oo
oooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?ooool007oooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0083ooooo0_l0000?
ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000kooooo00?o0000oooo
ooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003oooooooooo`0Rooooo`Co0000
TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Go0000UOoo
ool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Jooooo`00N_ooool4o`00
0003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo00?o0000oooooooo
ool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l00003ooooo`03o`00
0?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>ooooo`05o`000?oo
ooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooooooo00oooooo0_l0
00000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000ooooooooool04Oooool2
o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000ooooooooool04_ooool2o`00
0;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026ooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@2`ooooo`00R?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2booooo`00Q_oo
ool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.45374 .53614 Mdot
.49639 .73812 Mdot
.65268 .49603 Mdot
.42026 .36066 Mdot
.27606 .58792 Mdot
.48448 .55613 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`10
ooooo`;o0000DOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Soooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo03kooooo1?l0001@ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool0
02?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00009_ooool00ol0003oooooooooo`0m
ooooo`Co0000D?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo000Soooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03gooooo0_l0001Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo000Soooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo05kooooo0_l0000:ooooo`Co0000Aoooool00ol0
003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05co
oooo1?l00006ooooo`?o00000oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Go
oooo000Wooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0Foooool4o`0000;ooooo
1?l00006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool002Oooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`1Kooooo`Go00002oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0FOooool3o`0000kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0D
ooooo`009_ooool2o`0005Sooooo00?o0000ooooooooool0EOooool3o`00017ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo057ooooo0ol0000Dooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool05?ooool002Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1=ooooo`?o0000
5oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool0BOooool3o`0001[ooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo04Gooooo0ol0000Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool0
02Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`11ooooo`?o00008?ooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Uooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0?Oooool3o`0002?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Cooooo`009Oooool2o`00063ooooo00?o0000ooooooooool05_ooool2o`00027ooooo
0ol0000Vooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0Dooooo`Co00007Oooool3o`0002Wooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo01?ooooo1?l0000Iooooo`Co0000;?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool04oooool2o`0001Oooooo0ol0000`ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04oooool002Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Xooooo`?o
0000<oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool09?ooool3o`0003Kooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0Cooooo`009?ooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo023ooooo0ol0000iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_oo
ool002Cooooo0ol0001Wooooo`03o`000?oooooooooo01Wooooo0_l000001?oooooo0000o`000?l0
000looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`0Gooooo`Co0000?oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo01;ooooo000Jooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo1_l00010ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo013ooooo0ol00003ooooo`;o0000@Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`?o0000BOooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`08ooooo`?o0000C?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`04ooooo`?o0000Coooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Cooooo0_l0001`oooo
o`03o`000?oooooooooo00?o0000D_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
017ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`0005Go
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`006_ooool00omEEEGoIVIV
o`000006ooooo`03o`000?oooooooooo04Gooooo0_l0000Yooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003ooooooooo
o`14ooooo`Co0000:?ooool00ol0003oooooooooo`1Booooo`?o0000BOooool00ol0003ooooooooo
o`0Aooooo`008_ooool00ol0003oooooooooo`15ooooo`Co0000:?ooool00ol0003oooooooooo`1?
ooooo`?o00000_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Roooo
o`03o`000?oooooooooo04Kooooo0_l0000Yooooo`03o`000?oooooooooo04cooooo0ol00006oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`19ooooo`?o00002_ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo017ooooo000Rooooo`;o0000L_ooool00ol0003oooooooooo`15ooooo`Co0000
3_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0@_ooool3o`0001?ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03oooooo0ol0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool0
02;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0looooo`?o00006_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0>Oooool3o`0001kooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03Gooooo
1?l0000Rooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`0booooo`?o00009oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000Loooool00ol0003oooooooooo`0_
ooooo`?o0000:oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo000Poooo
o`;o0000M?ooool00ol0003oooooooooo`0/ooooo`?o0000;_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00oooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0:?ooool4o`0003;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`00
8?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02Kooooo0ol0000gooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`0Sooooo`?o0000>oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08?ooool3
o`0003oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo01gooooo0ol00012ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`0Iooooo`Co0000A_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oo
oooo000Oooooo`;o0000M?ooool00ol0003oooooooooo`0Fooooo`?o0000Boooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool04oooool3o`0004oooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo013ooooo0ol0001C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03_ooool001oooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0<ooooo`Co0000Eoooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool02Oooool3o`0005_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>ooooo`00
7oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Kooooo0ol0001Oooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`03ooooo`?o0000Hoooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00kooooo000Nooooo`?o0000M?ooool00ol0003oooooo`000003o`0006Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`007_ooool00ol0003oooooooooo`1coooo
o`?o0000K?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0004ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo073ooooo0ol000000ooooooo0000ooooo`1/ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1]ooooo`?o00001?ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06[ooooo
0ol00007ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0=ooooo`001_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0I_ooool4o`0000[ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06?ooooo0ol0000>ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`001_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0HOooool3
o`00017ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00cooooo0006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`00
05oooooo0ol0000Dooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0<ooooo`001?ooool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003o
ooooooooo`1Jooooo`Co00005oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0Eoooool3o`0001_ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo
000Mooooo`03o`000?oooooooooo05Cooooo0ol0000Nooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1A
ooooo`?o00008Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool03?ooool001cooooo00?o0000ooooooooool0Coooool3o`0002Cooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo000Looooo`03
o`000?oooooooooo04_ooooo1?l0000Wooooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0;ooooo`007?ooool2o`0004Wooooo0ol0000[ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0;ooooo`007?oo
ool00ol0003oooooooooo`15ooooo`?o0000;_ooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0@_ooool3
o`00037ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00_ooooo000Looooo`03o`000?oooooooooo03kooooo1?l0000dooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`0looooo`?o0000=oooool00ol0003oooooooooo`0Fooooo`;o0000H_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Wooooo
0ol0000jooooo`03o`000?oooooooooo01Gooooo1?l0001Rooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o
0000ooooooooool05Oooool4o`0006?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0booooo`Co0000@?ooool00ol0003oooooooooo`0F
ooooo`;o0000IOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo000Koooo
o`;o0000<?ooool3o`0004Cooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00[ooooo000Jooooo`;o0000;_ooool3o`0004Oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`00
0?oooooooooo02[ooooo0ol0001:ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Wooooo`?o0000COoo
ool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_oo
ool001[ooooo00?o0000ooooooooool08oooool4o`00053ooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo
023ooooo0ol0001Dooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Mooooo`?o0000Eoooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool001[ooooo
00?o0000ooooooooool06_ooool3o`0005[ooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo01Kooooo1?l0
001Mooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`09ooooo`006Oooool00ol0003oooooooooo`0Dooooo`?o0000HOooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000oooo
ooooool04Oooool3o`0006Cooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo00kooooo0ol0001Wooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`00
6Oooool00ol0003oooooooooo`0;ooooo`?o0000J_ooool00ol0003oooooooooo`27ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool01ooo
ool4o`0006gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Sooooo000Hooooo`;o00001_ooool3o`00077ooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo
00;ooooo0ol0001dooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`08ooooo`006?ooool5o`0007Oooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000Hooooo`;o0000N_ooool00ol0003ooooo
ooooo`2;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool000gooooo1Ol0
0008ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0S?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo000=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02Ooo
ool2o`0007Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Sooooo000>ooooo`03oiRHV?lQ8B7ok^k^00cooooo0_l0001eooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`003oooool00onH
V9So8B4Qonk^kP0<ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo000@ooooo`03ogMgMomVIVKooooo00co
oooo0_l0001cooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`07ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo
000=ooooo`05o`000?nj^[[ooooooiRHV?l@41004?ooool3o`0006oooooo00?o0000ooooooooool0
TOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo000=ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1oooool001[ooooo00?o0000ooooooooool02?ooool2o`0006cooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo000?ooooo`Ko00001Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0UOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool00000J?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool03?ooool2o`0006So
oooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Ko
oooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool001[ooooo00?o
0000ooooooooool03oooool2o`0006Gooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo000Hooooo`03oeEEEOmVIVKo000001?ooooo0_l0001S
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06
ooooo`00;oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`06ooooo`00<?ooool2o`00067ooooo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo000booooo`04o`00
0?ooooooooooo`0005gooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Gooooo000cooooo`?o0000GOooool00ol0003oooooooooo`2Looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool003Gooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Ooo
ool003Kooooo0_l0001Kooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`00>?ooool00ol0003oooooo`00001Hooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`00>Oooool2o`0005So
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo000jooooo`;o0000Eoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01Oooool003cooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool003gooooo0ol0001C
ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`00?oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000DOooool00ol0003oooooooooo`2S
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool0001@ooooo`03o`000?oo
oooooooo0:Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`008oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`06o`000?ooooooooooo`000?oooooo
0000COooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool002_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;o
oooo0_l0001=ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`00:oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?ooool0Aoooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool002_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0_l00018oooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000:ooooo`;o0000Aoooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool004co
oooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool004gooooo00?o0000ooooool00000@oooool00ol0003o
ooooooooo`2[ooooo`05o`000?ooooooooooooooool000001Oooool004kooooo0_l00013ooooo`03
o`000?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0053ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Gooooo001Aooooo`;o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`2^ooooo`04o`000?ooooooooooo`00
00Cooooo001Cooooo`;o0000?Oooool00ol0003oooooooooo`2_ooooo`03o`000?oooooo000000Co
oooo001Dooooo`;o0000??ooool00ol0003oooooooooo`2`ooooo`;o00001?ooool005Kooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`2_ooooo`?o00001?ooool005Oooooo00?o0000
ooooool00000>?ooool00ol0003oooooooooo`2[ooooo`Co00001oooool005Sooooo0_l0000hoooo
o`03o`000?oooooooooo0:Kooooo1Ol0000;ooooo`00F_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo0:;ooooo1?l0000@ooooo`00Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo0ol0000dooooo`03o`000?oooooooooo09kooooo1?l0000Dooooo`00Boooool01OmgMgOoV9RH
oooooonHV9SoMgMg00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Iooooo`Go
00006?ooool004_ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000<oooool00ol0003o
ooooooooo`2Eooooo`Co00007Oooool004_ooooo00Go0000ooooooooooooooooo`00000?ooooo`;o
0000<Oooool00ol0003oooooooooo`2Aooooo`Co00008Oooool004_ooooo00Go0000oooooooooooo
ooooo`00000Aooooo`;o0000;oooool00ol0003oooooooooo`2<ooooo`Go00009Oooool004_ooooo
00Go410@oooooooooooooooooa0@400Booooo`;o0000;_ooool00ol0003oooooooooo`28ooooo`Co
0000:_ooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`04o`000?ooooooooooo`00
02[ooooo00?o0000ooooooooool0Q?ooool4o`0002kooooo001;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h05Oooool3o`0002[ooooo00?o0000ooooooooool0Ooooool5o`0003;ooooo001Wooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0Noooool4o`0003Oooooo001Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0Moooool4o`0003_ooooo001Yooooo`?o00009_oo
ool00ol0003oooooooooo`1cooooo`Co0000?oooool006_ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1^ooooo`Go0000@oooool006cooooo0_l0000Tooooo`03o`000?oooooooooo
06[ooooo1?l00018ooooo`00K_ooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo06Ko
oooo1?l0001<ooooo`00Koooool2o`00027ooooo00?o0000ooooooooool0HOooool5o`00053ooooo
001aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool4o`0005Gooooo001J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool0FOooool4o`0005Wooooo
001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0_ooool2o`0001gooooo00?o0000ooooooooool0E?ooool5o`0005gooooo001Jooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00007?ooool00ol0003ooooo
ooooo`1@ooooo`Co0000H_ooool005[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Gooooo0ol0000Iooooo`03o`000?oooooooooo04cooooo1?l0001Vooooo`00F_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool5o`0006[ooooo001Jooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0:ooooo`?o00000_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04?ooooo1?l0001_ooooo`00F_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00000Dooooo`03
o`000?oooooooooo03oooooo1?l0001cooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000=ooooo`;o00005?ooool00ol0003oooooooooo`0jooooo`Go0000Moooool007gooooo
0_l0000Booooo`03o`000?oooooooooo03Oooooo1?l0001looooo`00Ooooool00ol0003oooooo`00
000?ooooo`03o`000?oooooooooo03?ooooo1?l00020ooooo`00P?ooool2o`0000oooooo00?o0000
ooooooooool0;oooool4o`0008Cooooo0021ooooo`;o00003_ooool00ol0003oooooooooo`0Zoooo
o`Go0000R?ooool008?ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0Vooooo`Co
0000SOooool008Cooooo0_l0000;ooooo`03o`000?oooooooooo02;ooooo1?l0002Aooooo`00Q_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1Ol0002Eooooo`00Qoooool3
o`0000Oooooo00?o0000ooooooooool06Oooool4o`0009[ooooo001jooooo`Co000000?o410@oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Noooo
o`00O?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`Go
0000X_ooool007cooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000ooooooooool0
3?ooool4o`000:Oooooo001looooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000Zoooool007cooooo00?o0000ooooooooool03oooool2o`000003ooooool0
003ooooo00Cooooo1Ol0002_ooooo`00O?ooool00ol0003oooooooooo`0Aooooo`;o000000?ooooo
o`000?l000000_l0002dooooo`00O?ooool00ol0003oooooooooo`0Booooo`;o0000^?ooool007[o
oooo00?oEEEEofIVI_l00000c_ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool0
0?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool008Kooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM0;3ooooo0028ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo0:oooooo0028ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0[_ooool008Sooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`2_ooooo`00R?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0/?ooool008Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2booooo`00
R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03oeEEEOmV
IVKo000000gooooo1?l0002aooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.44435 .54592 Mdot
.5074 .75174 Mdot
.66259 .50769 Mdot
.42012 .37399 Mdot
.27568 .59308 Mdot
.50954 .56206 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0looooo`;o0000DOooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03[ooooo1?l0001@ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool002gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0iooooo`Co0000D?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
023ooooo000]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>Oooool2o`00057o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06[ooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0I_ooool3o`0000?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo067ooooo1?l00006ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`1Mooooo`?o00002oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Gooooo000W
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0FOooool3o`000003ooooool0003o
000000_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool2o`00
05Sooooo00?o0000ooooooooool0EOooool3o`0000?ooooo1?l0000:ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`1Aooooo`?o00001_ooool4o`0000[ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04gooooo
0ol0000:ooooo`;o00002oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000Vooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0BOooool3o`0001[ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo04Gooooo0ol0000Mooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool05?ooool002Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`11oooo
o`?o00008?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Uooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0?Oooool3o`0002?ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool2o`00063ooooo00?o0000ooooooooool0
>Oooool3o`0002Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03Gooooo0ol0000Yooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0`ooooo`Co0000;?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01?ooooo000Uooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04?ooool2o`00
01[ooooo0ol0000`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Go
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0>ooooo`Co00005_ooool3o`0003?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00gooooo1?l0000Cooooo`?o0000=_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool03Oooool2o`00017ooooo0ol0000iooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool04_ooool002Cooooo0ol0001Wooooo`03o`000?oooooooooo01cooooo0ol0000l
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0Hooooo`?o00001?ooool2o`0003Wooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Booooo`006_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Dooooo`?o00001_ooool4o`0003Wo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool04?ooool3o`0000Wooooo
1?l0000iooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04_ooool001cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00cooooo0ol0
000=ooooo`;o0000>_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000L
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`08
ooooo`?o0000C?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Loooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`04oooo
o`?o0000Coooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03
o`000?oooooooooo00Cooooo0_l0001`ooooo`03o`000?oooooooooo00?o0000D_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0L?ooool2o`0005Gooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Aooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000S
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0D_ooool3o`0004Wooooo00?o0000
ooooooooool04Oooool002;ooooo00?o0000ooooooooool0AOooool2o`0002[ooooo00?o0000oooo
ooooool0Coooool3o`0000;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aoooo
o`008_ooool00ol0003oooooooooo`14ooooo`Co0000:Oooool00ol0003oooooooooo`1<ooooo`?o
00001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`00
0?oooooooooo04Cooooo1?l0000Yooooo`03o`000?oooooooooo04Wooooo0ol0000:ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool04Oooool002;ooooo0_l00016ooooo`;o0000:_oo
ool00ol0003oooooooooo`15ooooo`Co00003_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0@_ooool3
o`0001?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03oooooo0ol0000Fooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0looooo`?o00006_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013o
oooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0>Oooool3o`0001kooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo03Gooooo1?l0000Rooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0b
ooooo`?o00009oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo000Qoooo
o`;o0000Loooool00ol0003oooooooooo`0_ooooo`?o0000:oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00oooooo000Pooooo`;o0000M?ooool00ol0003oooooooooo`0/ooooo`?o
0000;_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo000Qooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0:?ooool4o`0003;ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo02Kooooo0ol0000gooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03ooo
ool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Sooooo`?o0000>oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool08?ooool3o`0003oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01go
oooo0ol00012ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0023ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Iooooo`Co0000A_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00oooooo000Oooooo`;o0000M?ooool00ol0003ooooooooo
o`0Fooooo`?o0000Boooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04oooool3o`0004oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo013ooooo0ol0001Cooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0<ooooo`Co
0000Eoooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`00
0?oooooooooo07?ooooo00?o0000ooooooooool02Oooool3o`0005_ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00Kooooo0ol0001Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03_oo
ool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`?o0000Hoooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo000Nooooo`?o0000M?ooool00ol0
003oooooo`000003o`0006Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=oooo
o`007_ooool00ol0003oooooooooo`1cooooo`?o0000K?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00gooooo0004ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo073ooooo0ol000000ooooooo
0000ooooo`1/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Kooooo
00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`1]ooooo`?o00001?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06[ooooo0ol00007ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0I_ooool4o`0000[ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo0006oooo
o`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo06?ooooo0ol0000>ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0HOooool3o`00017ooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01_ooool2o`0005oooooo0ol0000Dooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`001?ooool00omEEEGoIVIV
o`00000=ooooo`Co00001Oooool00ol0003oooooooooo`1Jooooo`Co00005oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool001gooooo00?o
0000ooooooooool0Eoooool3o`0001_ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Cooooo0ol0000N
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<
ooooo`007Oooool00ol0003oooooooooo`1Aooooo`?o00008Oooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo00?o0000oooooooo
ool0Coooool3o`0002Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo04_ooooo1?l0000Wooooo`03o`00
0?oooooooooo07Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`007?oo
ool2o`0004Wooooo0ol0000[ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o0000;_ooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool0
01cooooo00?o0000ooooooooool0@_ooool3o`00037ooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo03ko
oooo1?l0000dooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0looooo`?o0000=oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool0>Oooool3o`0003[ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Kooooo0ol0000m
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0booooo`Co0000@?ooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool001_ooooo0_l0000`ooooo`?o
0000A?ooool00ol0003oooooooooo`0Jooooo`;o0000H_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00[ooooo000Jooooo`;o0000;_ooool3o`0004Oooooo00?o0000ooooooooool0
6Oooool4o`00067ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_oo
ool00ol0003oooooooooo`0Zooooo`?o0000B_ooool00ol0003oooooooooo`0Iooooo`Co0000H_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooo
oooo02Oooooo0ol0001=ooooo`03o`000?oooooooooo01[ooooo0_l0001Tooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool08oooool4o`00
053ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00[ooooo000Jooooo`03o`000?oooooooooo023ooooo0ol0001Dooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003ooooo
ooooo`0Mooooo`?o0000Eoooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool06_ooool3o`0005[ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo000J
ooooo`03o`000?oooooooooo01Kooooo1?l0001Mooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0Doooo
o`?o0000HOooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02Oooool001Wooooo00?o0000ooooooooool04Oooool3o`0006Cooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`00
0?oooooooooo00kooooo0ol0001Wooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0;ooooo`?o0000J_oo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Ooo
ool001Wooooo00?o0000ooooooooool01oooool4o`0006gooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Hooooo`;o00001_ooool3o`00
077ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Sooooo000Hooooo`03o`000?oooooooooo00;ooooo0ol0001dooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`006?ooool5o`0007Oooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
000Hooooo`;o0000N_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool000gooooo1Ol00008ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo000=oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@02Oooool2o`0007Oooooo00?o0000ooooooooool0SOooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo000>ooooo`03oiRHV?lQ8B7ok^k^
00cooooo0_l0001eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`08ooooo`003oooool00onHV9So8B4Qonk^kP0<ooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oo
oooo000@ooooo`03ogMgMomVIVKooooo00cooooo0_l0001cooooo`03o`000?oooooooooo093ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Oooooo000=ooooo`05o`000?nj^[[ooooooiRHV?l@41004?oo
ool3o`0006oooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Oooooo000=ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool4o`000003oa0@4?oo
oooooooo00Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2Booooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool02?ooool2
o`0006cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Oooooo000?ooooo`Ko00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Oooooo000Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000J?ooool00ol0003o
ooooooooo`2Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool001[ooooo
00?o0000ooooooooool03?ooool2o`0006Sooooo00?o0000ooooooooool0U_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool03oooool2o`0006Gooooo00?o0000
ooooooooool0V?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Hoooo
o`03oeEEEOmVIVKo000001?ooooo0_l0001Sooooo`03o`000?oooooooooo09Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`00;oooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00
<?ooool2o`00067ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo000booooo`04o`000?ooooooooooo`0005gooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo000cooooo`?o0000GOoo
ool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool003Gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool003Kooooo0_l0001Kooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`00>?ooool00ol0003o
ooooo`00001Hooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`05ooooo`00>Oooool2o`0005Sooooo00?o0000ooooooooool0Woooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo000jooooo`;o0000Eoooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool003cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool003gooooo0ol0001Cooooo`03o`000?oooooooooo0:;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`00?oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo0:?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00
:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b
<P;o0000DOooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool002_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mg
MgOo<S8booooool0001@ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`008oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`06o`000?ooooooooooo`000?oooooo0000COooool00ol0003oooooooooo`2Uooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool002_ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0001=ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`00:oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo000[ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08ooooo`;o
000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool002_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00[ooooo0_l00018ooooo`03o`000?oooooooooo0:Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000:ooooo`;o0000Aoooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool004cooooo00Co0000oooooooooooo0000@oooool00ol0003o
ooooooooo`2Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool004gooooo
00?o0000ooooool00000@oooool00ol0003oooooooooo`2[ooooo`05o`000?ooooooooooooooool0
00001Oooool004kooooo0_l00013ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo
00001Oooool0053ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2/ooooo`04o`00
0?ooooooooooo`0000Gooooo001Aooooo`;o000000?oooooo`000?ooool0??ooool00ol0003ooooo
ooooo`2^ooooo`04o`000?ooooooooooo`0000Cooooo001Cooooo`;o0000?Oooool00ol0003ooooo
ooooo`2_ooooo`03o`000?oooooo000000Cooooo001Dooooo`;o0000??ooool00ol0003ooooooooo
o`2`ooooo`;o00001?ooool005Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2_
ooooo`?o00001?ooool005Oooooo00?o0000ooooool00000>?ooool00ol0003oooooooooo`2[oooo
o`Co00001oooool005Sooooo0_l0000hooooo`03o`000?oooooooooo0:Kooooo1Ol0000;ooooo`00
F_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:;ooooo1?l0000@ooooo`00Booo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0ol0000dooooo`03o`000?oooooooooo09kooooo
1?l0000Dooooo`00Boooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`2Iooooo`Go00006?ooool004_ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`;o0000<oooool00ol0003oooooooooo`2Eooooo`Co00007Oooool004_ooooo00Go
0000ooooooooooooooooo`00000?ooooo`;o0000<Oooool00ol0003oooooooooo`2Aooooo`Co0000
8Oooool004_ooooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000;oooool00ol0003ooooo
ooooo`2<ooooo`Go00009Oooool004_ooooo00Go410@oooooooooooooooooa0@400Booooo`;o0000
;_ooool00ol0003oooooooooo`28ooooo`Co0000:_ooool004_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Dooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool0Q?ooool4o`0002ko
oooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05Oooool3o`0002[ooooo00?o0000oooooooo
ool0Ooooool5o`0003;ooooo001Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
Noooool4o`0003Oooooo001Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Mooo
ool4o`0003_ooooo001Yooooo`?o00009_ooool00ol0003oooooooooo`1cooooo`Co0000?oooool0
06_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1^ooooo`Go0000@oooool006co
oooo0_l0000Tooooo`03o`000?oooooooooo06[ooooo1?l00018ooooo`00K_ooool00ol0003ooooo
o`00000Qooooo`03o`000?oooooooooo06Kooooo1?l0001<ooooo`00Koooool2o`00027ooooo00?o
0000ooooooooool0HOooool5o`00053ooooo001aooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0GOooool4o`0005Gooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`03o`000?oooooo000001gooooo00?o
0000ooooooooool0FOooool4o`0005Wooooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00_ooool2o`0001gooooo00?o0000ooooooooool0E?oo
ool5o`0005gooooo001Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`;o00007?ooool00ol0003oooooooooo`1@ooooo`Co0000H_ooool005[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Gooooo0ol0000Iooooo`03o`000?oo
oooooooo04cooooo1?l0001Vooooo`00F_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c008ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Aoooool5o`0006[ooooo001Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0:ooooo`?o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04?ooooo
1?l0001_ooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo03oooooo1?l0001cooooo`00F_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`;o00005?ooool00ol0003ooooo
ooooo`0jooooo`Go0000Moooool007gooooo0_l0000Booooo`03o`000?oooooooooo03Oooooo1?l0
001looooo`00Ooooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo03?ooooo1?l00020
ooooo`00P?ooool2o`0000oooooo00?o0000ooooooooool0;oooool4o`0008Cooooo0021ooooo`;o
00003_ooool00ol0003oooooooooo`0Zooooo`Go0000R?ooool008?ooooo00?o0000ooooool00000
2oooool00ol0003oooooooooo`0Vooooo`Co0000SOooool008Cooooo0_l0000;ooooo`03o`000?oo
oooooooo02;ooooo1?l0002Aooooo`00Q_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo1Ol0002Eooooo`00Qoooool3o`0000Oooooo00?o0000ooooooooool06Oooool4o`00
09[ooooo001jooooo`Co000000?o410@ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Gooooo1?l0002Nooooo`00O?ooool00ol0003oooooooooo`0;ooooo`;o0000
1Oooool00ol0003oooooooooo`0@ooooo`Go0000X_ooool007cooooo00?o0000ooooooooool03Ooo
ool2o`0000?ooooo00?o0000ooooooooool03?ooool4o`000:Oooooo001looooo`03o`000?oooooo
oooo00kooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000Zoooool007cooooo00?o0000
ooooooooool03oooool2o`000003ooooool0003ooooo00Cooooo1Ol0002_ooooo`00O?ooool00ol0
003oooooooooo`0Aooooo`;o000000?oooooo`000?l000000_l0002dooooo`00O?ooool00ol0003o
ooooooooo`0Booooo`;o0000^?ooool007[ooooo00?oEEEEofIVI_l00000c_ooool00?ooooooC?oo
ool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?oo
ool008Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM0;3ooooo0028ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo0:oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[_ooool008So
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0/?ooool008Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2booooo`00R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0;;ooooo0026ooooo`03oeEEEOmVIVKo000000gooooo1?l0002aooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43641 .54573 Mdot
.66169 .5021 Mdot
.51611 .74411 Mdot
.41509 .37173 Mdot
.27119 .59838 Mdot
.52434 .57675 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0kooooo`;o0000D_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Wooooo1?l0001Aooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool002gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0hooooo`Co0000DOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
023ooooo000]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>?ooool2o`0005;o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06[ooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0I_ooool3o`0000?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo05oooooo1_l00006ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`1Mooooo`Co00002_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Gooooo000W
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0FOooool7o`0000[ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool2o`0005Sooooo00?o0000oooo
ooooool0EOooool3o`0000Cooooo0_l0000;ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool05?ooool002Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Aooooo`?o
00005?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool0COooool3o`0001Oooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo04Wooooo0ol0000Jooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?oo
ool002Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`15ooooo`?o00007Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0@Oooool3o`00023ooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Dooooo`009Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03go
oooo0ol0000Sooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo
0_l0001Pooooo`03o`000?oooooooooo03Wooooo0ol0000Vooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0eooooo`?o0000:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000U
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0<?ooool4o`0002cooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo00kooooo0_l0000Looooo`?o0000<?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool03?ooool4o`0001Sooooo0ol0000cooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool04oooool002Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`Co0000
5Oooool3o`0003Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009?oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`?o0000>Ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo000Tooooo`?o0000Ioooool0
0ol0003oooooooooo`0Looooo`?o0000??ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo01;ooooo000Tooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06?ooool3o`00
03oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`006_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Dooooo`?o
0000@oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0@ooooo`?o0000
A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`?o0000BOoo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`08ooooo`?o0000C?ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`04ooooo`?o00006?ooool2o`00
03Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000L?ooool00ol0003oooooooooo`03o`0001[ooooo1?l0000dooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1`ooooo`;o00007Oooool4o`0003Cooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0Aooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool07Oooool2o`0003Gooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo05;ooooo0ol00019ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0Coooool3o`0000;ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`14ooooo`;o0000:oooool00ol0003o
ooooooooo`1<ooooo`?o00001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017o
oooo000Rooooo`03o`000?oooooooooo04?ooooo1?l0000Zooooo`03o`000?oooooooooo04Wooooo
0ol0000:ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04Oooool002;ooooo0_l0
0014ooooo`Co0000:_ooool00ol0003oooooooooo`15ooooo`Co00003_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo04Cooooo0_l0000[
ooooo`03o`000?oooooooooo04;ooooo0ol0000Cooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool04?ooool002;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0ooooo
o`?o00005_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo000Rooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0??ooool3o`0001[ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo03Wooooo0ol0000Nooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
4?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0eooooo`Co00008_oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0<_ooool3o`0002Oooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0@ooooo`008Oooool2o`0007?ooooo00?o0000ooooooooool0;oooool3o`00
02_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`008?ooool2o`0007Co
oooo00?o0000ooooooooool0;?ooool3o`0002kooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0?ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02Sooooo
1?l0000booooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool0023ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`0Vooooo`?o0000=oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool08oooool3o`0003_ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0?
ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo023ooooo0ol0000ooooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0023ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`0Mooooo`?o0000@_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
6Oooool4o`0004Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`007ooo
ool2o`0007Cooooo00?o0000ooooooooool05_ooool3o`0004_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo01?ooooo0ol0001?ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03_ooool0
01oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0@ooooo`?o0000Doooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool03?ooool4o`0005Oooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Wooooo
0ol0001Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03_ooool001oooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`?o0000Goooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool3o`0006?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0>
ooooo`007_ooool3o`0007Cooooo00?o0000ooooool000000ol0001Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03Oooool001kooooo00?o0000ooooooooool0Loooool3o`0006co
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`001?ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`1`ooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0KOooool3o`0000Cooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Zooooo`?o00001ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03Ooo
ool000Kooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo06Kooooo1?l0000:ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Sooooo`?o00003_ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo067ooooo0ol0000Aoooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<oooo
o`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_l0001Oooooo`?o
00005?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool03?ooool000Cooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0
F_ooool4o`0001Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Oooooo0ol0000Kooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`007Oooool0
0ol0003oooooooooo`1Dooooo`?o00007_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0DOooool3o`00
027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00cooooo000Looooo`03o`000?oooooooooo04oooooo0ol0000Tooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02oooool001cooooo0_l00019ooooo`?o0000:oooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool001cooooo00?o0000
ooooooooool0AOooool3o`0002kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000aoooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;oooo
o`007?ooool00ol0003oooooooooo`0nooooo`Co0000=?ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
??ooool3o`0003Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Wooooo0ol0000jooooo`03o`000?oo
oooooooo01cooooo0_l0001Mooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0=_ooool3o`0003gooooo00?o0000ooooooooool06oooool4
o`0005gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`0booooo`Co0000@?ooool00ol0003oooooooooo`0Kooooo`Co0000G_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo000Kooooo`;o0000<?ooool3o`0004Co
oooo00?o0000ooooooooool07?ooool2o`00063ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0:ooooo`006_ooool2o`0002kooooo0ol00017ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003ooooooooo
o`0Zooooo`?o0000B_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool09oooool3o`0004gooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo000Joooo
o`03o`000?oooooooooo02?ooooo1?l0001@ooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Pooooo`?o
0000E?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool001[ooooo00?o0000ooooooooool07Oooool3o`0005Oooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oo
oooooooo01[ooooo0ol0001Jooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`09ooooo`006_ooool00ol0003oooooooooo`0Fooooo`Co0000GOooool0
0ol0003oooooooooo`24ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool0
01Wooooo00?o0000ooooooooool05?ooool3o`00067ooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo017o
oooo0ol0001Tooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0>ooooo`?o0000Ioooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool001Wooooo00?o
0000ooooooooool02oooool3o`0006[ooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oooooooooo00Oooooo1?l0001]
ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08
ooooo`006?ooool2o`0000Kooooo0ol0001aooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`02ooooo`?o
0000M?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02?ooool001Sooooo1Ol0001gooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`08ooooo`006?ooool2o`0007[ooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000=ooooo`Go00002?ooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`08ooooo`003Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Wooooo0_l0001g
ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08
ooooo`003_ooool00onHV9So8B4Qonk^kP0<ooooo`;o0000MOooool00ol0003oooooooooo`2>oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000oooooo00?oV9RHob4Q8Oo^
k^h03?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo08oooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`07ooooo`004?ooool00omgMgOoIVIVooooo`0<ooooo`;o0000
Loooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1oooool0017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo093ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`003Oooool0
1Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0001_ooooo`03o`000?oooooooooo097ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`003Oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Kooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool0T_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo000J
ooooo`03o`000?oooooooooo00Sooooo0_l0001/ooooo`03o`000?oooooooooo09Cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`003oooool6o`0000Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo09Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000006Sooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00cooooo0_l0001Xooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`006_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Uooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooo
oooo00oooooo0_l0001Uooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`006?ooool00omEEEGoIVIVo`00000Cooooo`;o0000Hoooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool002oo
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool0033ooooo0_l0001Qooooo`03o`000?oooooooooo09[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00<_ooool01?l0003ooooooooo
ool0001Mooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`05ooooo`00<oooool3o`0005gooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Gooooo000eooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo000foooo
o`;o0000Foooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool003Sooooo00?o0000ooooool00000F?ooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Wooooo0_l0001Hooooo`03o`00
0?oooooooooo09oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`00>_oo
ool2o`0005Oooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo000looooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0XOooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000mooooo`?o0000Doooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool003oo
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01?ooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00057ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000D?ooool00ol0003oooooooooo`2T
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool002?ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool01_l0003oooooooooool0003oooooo`0004gooooo
00?o0000ooooooooool0YOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
000[ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`02ooooo`;o0000
COooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0:Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`00:oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo04Oooooo00?o0000oooooooo
ool0Yoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo000[ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o0000B?ooool00ol0003o
ooooooooo`2Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002_ooool2o`0004Oooooo00?o0000oooooooo
ool0ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo001<ooooo`04o`00
0?ooooooooooo`0004?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo001=ooooo`03o`000?oooooo000004?ooooo00?o0000ooooooooool0
Zoooool01Ol0003ooooooooooooooooo000000Gooooo001>ooooo`;o0000@oooool00ol0003ooooo
ooooo`2/ooooo`04o`000?ooooooooooo`0000Gooooo001@ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005ooooo`00DOooool2o`000003oooo
ool0003ooooo03cooooo00?o0000ooooooooool0[_ooool01?l0003oooooooooool00004ooooo`00
Doooool2o`0003gooooo00?o0000ooooooooool0[oooool00ol0003oooooo`000004ooooo`00E?oo
ool2o`0003cooooo00?o0000ooooooooool0/?ooool2o`0000Cooooo001Fooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0[oooool3o`0000Cooooo001Gooooo`03o`000?oooooo0000
03Sooooo00?o0000ooooooooool0Zoooool4o`0000Oooooo001Hooooo`;o0000>?ooool00ol0003o
ooooooooo`2Vooooo`Go00002oooool005[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`2Rooooo`Co00004?ooool004_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o0000
=?ooool00ol0003oooooooooo`2Nooooo`Co00005?ooool004_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0VOooool5o`0001Sooooo
001;ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0003?ooooo00?o0000ooooooooool0
UOooool4o`0001gooooo001;ooooo`05o`000?ooooooooooooooool000003oooool2o`00037ooooo
00?o0000ooooooooool0TOooool4o`00027ooooo001;ooooo`05o`000?ooooooooooooooool00000
4Oooool2o`0002oooooo00?o0000ooooooooool0S?ooool5o`0002Gooooo001;ooooo`05oa0@4?oo
ooooooooooooool@41004_ooool2o`0002kooooo00?o0000ooooooooool0R?ooool4o`0002[ooooo
001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool01?l0003oooooooooool0000Zooooo`03
o`000?oooooooooo08Cooooo1?l0000^ooooo`00Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Go
oooo0ol0000Zooooo`03o`000?oooooooooo07oooooo1Ol0000booooo`00Ioooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo07_ooooo1?l0000gooooo`00J?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo07Oooooo1?l0000kooooo`00JOooool3o`0002Kooooo00?o0000
ooooooooool0Loooool4o`0003oooooo001[ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0K_ooool5o`0004?ooooo001/ooooo`;o00009?ooool00ol0003oooooooooo`1Zooooo`Co
0000B?ooool006kooooo00?o0000ooooool000008Oooool00ol0003oooooooooo`1Vooooo`Co0000
C?ooool006oooooo0_l0000Qooooo`03o`000?oooooooooo067ooooo1Ol0001@ooooo`00LOooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0001Eooooo`00F_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo05Wooooo1?l0001Iooooo`00F_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0
000Mooooo`03o`000?oooooooooo05Cooooo1Ol0001Mooooo`00F_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool2o`0001cooooo00?o0000ooooooooool0D?oo
ool4o`0006;ooooo001Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`05ooooo`?o00006Oooool00ol0003oooooooooo`1<ooooo`Co0000I_ooool005[ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Oooooo1Ol0001Zooooo`00F_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool02_ooool3o`0000;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`13ooooo`Co0000Koooool005[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000005?ooool00ol0003ooooo
ooooo`0oooooo`Co0000Loooool005[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
3Oooool2o`0001Cooooo00?o0000ooooooooool0>_ooool5o`0007Oooooo001mooooo`;o00004_oo
ool00ol0003oooooooooo`0gooooo`Co0000O?ooool007oooooo00?o0000ooooool000003oooool0
0ol0003oooooooooo`0cooooo`Co0000P?ooool0083ooooo0_l0000?ooooo`03o`000?oooooooooo
02oooooo1?l00024ooooo`00POooool2o`0000kooooo00?o0000ooooooooool0:_ooool5o`0008So
oooo0023ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool09_ooool4o`0008gooooo
0024ooooo`;o00002oooool00ol0003oooooooooo`0Rooooo`Co0000TOooool008Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Go0000UOooool008Oooooo0ol00007oooo
o`03o`000?oooooooooo01Wooooo1?l0002Jooooo`00N_ooool4o`000003oa0@4?oooooooooo00So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000W_ooool007cooooo
00?o0000ooooooooool02oooool2o`0000Gooooo00?o0000ooooooooool04?ooool5o`000:;ooooo
001looooo`03o`000?oooooooooo00gooooo0_l00003ooooo`03o`000?oooooooooo00cooooo1?l0
002Wooooo`00O?ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000002_oo
ool4o`000:_ooooo001looooo`03o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`04
ooooo`Go0000[oooool007cooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003o0000
00;o0000]?ooool007cooooo00?o0000ooooooooool04_ooool2o`000;Sooooo001jooooo`03oeEE
EOmVIVKo00000<kooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodco
oooo003oooooodcooooo003oooooodcooooo0026ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@2`ooooo`00R?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0:kooooo0028ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool0[oooool008Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0;3o
oooo0028ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0/_ooool008Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2booooo`00Q_ooool00omEEEGoIVIVo`00000=
ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.44027 .54227 Mdot
.63721 .50853 Mdot
.52444 .7565 Mdot
.42921 .37775 Mdot
.28555 .6015 Mdot
.52742 .58606 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo023ooooo000]ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?Oooool2o`00
04kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00;Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo03_ooooo1?l0001=ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool07oooool002cooooo0_l0000]ooooo`03o`000?oooooooooo03[ooooo
1?l0001=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0jooooo`;o0000Coooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06[ooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0I_ooool3o`0000?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo067ooooo1?l00006ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`1Mooooo`?o00002oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Gooooo000W
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0E_ooool2o`000004ooooool0003o
0000o`0000kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool2
o`0005Sooooo00?o0000ooooooooool0E?ooool4o`00017ooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
057ooooo1_l0000Aooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Ko
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1=ooooo`?o00000oooool2o`0001;o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo04Wooooo0ol0000Jooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`15ooooo`?o00007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000V
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@Oooool3o`00023ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009Oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo03gooooo0ol0000Sooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04oooool002Gooooo0_l0001Pooooo`03o`000?oooooooooo03Wooooo0ol0000Vooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0eooooo`?o0000:Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool04?oo
ool2o`0001kooooo1?l0000/ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04ooo
ool002Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0>ooooo`Co00006_ooool3
o`00033ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00gooooo1?l0000Gooooo`?o0000<oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool03Oooool2o`0001Gooooo0ol0000fooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04oooool002Cooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`0Pooooo`?o0000>Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01;ooooo
000Tooooo`?o0000Ioooool00ol0003oooooooooo`0Looooo`?o0000??ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01;ooooo000Tooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool06?ooool3o`0003oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0B
ooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0Dooooo`?o0000@oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
01;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`0@ooooo`?o0000A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;o
oooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0<ooooo`?o0000BOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo
000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`08ooooo`?o0000C?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000L
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`04
ooooo`?o0000Coooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo000Loooo
o`03o`000?oooooooooo00Cooooo0_l0001`ooooo`03o`000?oooooooooo00?o0000D_ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0L?ooool2o`0005Gooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Aooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool07_ooool2o`0003Cooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Aooooo`008oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01gooooo1?l0
000aooooo`?o0000BOooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo01gooooo1?l0000^ooooo`?o00000_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool07_ooool2o`0002cooooo0ol00006ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04Oooool002;ooooo00?o0000ooooooooool0B?ooool2o`0002Oooooo00?o0000oooooooo
ool0BOooool3o`0000[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`00
8_ooool2o`0004Sooooo1?l0000Vooooo`03o`000?oooooooooo04Gooooo1?l0000>ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0Aooo
ool4o`0002Kooooo00?o0000ooooooooool0@_ooool3o`0001?ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`18ooooo`;o00009oooool0
0ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0??ooool3o`00
01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0eooooo`Co00008_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo
000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0<_ooool3o`0002Oooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0007?ooooo00?o0000
ooooooooool0;oooool3o`0002_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?
ooooo`008?ooool2o`0007Cooooo00?o0000ooooooooool0;?ooool3o`0002kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0?ooooo`008Oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo02Sooooo1?l0000booooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Vooooo`?o0000
=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool08oooool3o`0003_ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo023ooooo0ol0000oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool0
023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Mooooo`?o0000@_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool06Oooool4o`0004Kooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0?ooooo`007oooool2o`0007Cooooo00?o0000ooooooooool05_ooool3o`0004_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo01?ooooo0ol0001?ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0@
ooooo`?o0000Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo000Ooooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03?ooool4o`0005Oooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00Wooooo0ol0001Kooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`?o0000
Goooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool3o`0006?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0>ooooo`007_ooool3o`0007Cooooo00?o0000ooooool000000ol0001W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001kooooo00?o0000oooo
ooooool0Loooool3o`0006cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=oooo
o`001?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?ooool0K?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0006ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0KOooool3o`0000Co
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00go
oooo0006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Zooooo`?o00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo06Kooooo1?l0000:ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Sooooo`?o00003_oo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Ooo
ool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo067ooooo0ol0000Aooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_l0001Oooooo`?o00005?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool03?ooool000Cooooo00?oEEEEofIVI_l000003Oooool4o`0000Go
oooo00?o0000ooooooooool0F_ooool4o`0001Oooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo05Oooooo
0ol0000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Dooooo`?o00007_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool001gooooo00?o0000
ooooooooool0DOooool3o`00027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo04oooooo0ol0000Toooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<oooo
o`007?ooool00ol0003oooooooooo`1;ooooo`Co00009oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool001cooooo0_l00019ooooo`?o0000
:oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2oooool001cooooo00?o0000ooooooooool0AOooool3o`0002kooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooo
oooo04;ooooo0ol0000aooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co0000=?ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0??ooool3o`0003Oooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Wooooo
0ol0000jooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0fooooo`?o0000?Oooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000
ooooooooool0<_ooool4o`00043ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00[ooooo000Kooooo`;o0000<?ooool3o`0004Cooooo00?o0000oooo
ooooool0O_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000Jooooo`;o
0000;_ooool3o`0004Oooooo00?o0000ooooooooool07oooool2o`0005gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0003oooooooooo`0Zooooo`?o0000
B_ooool00ol0003oooooooooo`0Nooooo`Co0000GOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02Oooooo0ol0001=ooooo`03o`000?oo
oooooooo01kooooo1?l0001Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_oo
ool001[ooooo00?o0000ooooooooool08oooool4o`00053ooooo00?o0000ooooooooool07oooool2
o`00063ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`006_ooool00ol0
003oooooooooo`0Pooooo`?o0000E?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000ooooooooool07Oooool3o`0005Oo
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wo
oooo000Jooooo`03o`000?oooooooooo01[ooooo0ol0001Jooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003ooooooooo
o`0Fooooo`Co0000GOooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool05?ooool3o`00067ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Ioooo
o`03o`000?oooooooooo017ooooo0ol0001Tooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`0>ooooo`?o
0000Ioooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02Oooool001Wooooo00?o0000ooooooooool02oooool3o`0006[ooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Iooooo`03o`000?oo
oooooooo00Oooooo1?l0001]ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`08ooooo`006?ooool2o`0000Kooooo0ol0001aooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0
003oooooooooo`02ooooo`?o0000M?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool02?ooool001Sooooo1Ol0001gooooo`03o`000?oooooooooo08_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`006?ooool2o`0007[ooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
000=ooooo`Go00002?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`003Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Wooooo0_l0001gooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`08ooooo`003_ooool00onHV9So8B4Qonk^kP0<ooooo`;o0000MOooool0
0ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool0
00oooooo00?oV9RHob4Q8Oo^k^h03?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
08oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`004?ooool00omgMgOo
IVIVooooo`0<ooooo`;o0000Loooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`003Oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo0ol0001_ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`003Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo1?l000000ol@413oooooooooo`05ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo0_l0001/ooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`003oooool6
o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooo000006Sooooo00?o0000ooooooooool0UOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Jooooo`03o`000?oooooooooo00co
oooo0_l0001Xooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo
000Jooooo`03o`000?oooooooooo00oooooo0_l0001Uooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`006?ooool00omEEEGoIVIVo`00000C
ooooo`;o0000Hoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool002oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0033ooooo0_l0001Qooooo`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00
<_ooool01?l0003oooooooooool0001Mooooo`03o`000?oooooooooo09_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`00<oooool3o`0005gooooo00?o0000ooooooooool0
W?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000eooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo000fooooo`;o0000Foooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooool00000F?ooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool003Wo
oooo0_l0001Hooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`00>_ooool2o`0005Oooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000m
ooooo`?o0000Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool003oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool002_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`00057ooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000D?oo
ool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool01_l0003ooooooooo
ool0003oooooo`0004gooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`02ooooo`;o0000COooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
0:Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00:oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo
04Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:oooo
o`;o0000B?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002_ooool2o`00
04Oooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo001<ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ooooooooool0Z_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001=ooooo`03o`000?oooooo000004?o
oooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000000Gooooo001>ooooo`;o
0000@oooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Gooooo001@ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005oooo
o`00DOooool2o`000003ooooool0003ooooo03cooooo00?o0000ooooooooool0[_ooool01?l0003o
ooooooooool00004ooooo`00Doooool2o`0003gooooo00?o0000ooooooooool0[oooool00ol0003o
ooooo`000004ooooo`00E?ooool2o`0003cooooo00?o0000ooooooooool0/?ooool2o`0000Cooooo
001Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[oooool3o`0000Cooooo001G
ooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0Zoooool4o`0000Oooooo001Hoooo
o`;o0000>?ooool00ol0003oooooooooo`2Vooooo`Go00002oooool005[ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`2Rooooo`Co00004?ooool004_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`?o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00005?ooool004_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0VOooool5o`0001Sooooo001;ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0003?o
oooo00?o0000ooooooooool0UOooool4o`0001gooooo001;ooooo`05o`000?ooooooooooooooool0
00003oooool2o`00037ooooo00?o0000ooooooooool0TOooool4o`00027ooooo001;ooooo`05o`00
0?ooooooooooooooool000004Oooool2o`0002oooooo00?o0000ooooooooool0S?ooool5o`0002Go
oooo001;ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0002kooooo00?o0000oooooooo
ool0R?ooool4o`0002[ooooo001;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool01?l0003o
ooooooooool0000Zooooo`03o`000?oooooooooo08Cooooo1?l0000^ooooo`00Boooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Gooooo0ol0000Zooooo`03o`000?oooooooooo07oooooo1Ol0000boooo
o`00Ioooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07_ooooo1?l0000gooooo`00
J?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Oooooo1?l0000kooooo`00JOoo
ool3o`0002Kooooo00?o0000ooooooooool0Loooool4o`0003oooooo001[ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0K_ooool5o`0004?ooooo001/ooooo`;o00009?ooool00ol0
003oooooooooo`1Zooooo`Co0000B?ooool006kooooo00?o0000ooooool000008Oooool00ol0003o
ooooooooo`1Vooooo`Co0000C?ooool006oooooo0_l0000Qooooo`03o`000?oooooooooo067ooooo
1Ol0001@ooooo`00LOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0
001Eooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo05Wooooo
1?l0001Iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo05Cooooo1Ol0001Mooooo`00F_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2o`0001cooooo
00?o0000ooooooooool0D?ooool4o`0006;ooooo001Jooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`05ooooo`?o00006Oooool00ol0003oooooooooo`1<ooooo`Co0000
I_ooool005[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo1Ol0001Zooooo`00
F_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02_ooool3o`0000;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`13ooooo`Co0000Koooool005[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool0
00005?ooool00ol0003oooooooooo`0oooooo`Co0000Loooool005[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00003Oooool2o`0001Cooooo00?o0000ooooooooool0>_ooool5o`0007Oo
oooo001mooooo`;o00004_ooool00ol0003oooooooooo`0gooooo`Co0000O?ooool007oooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`0cooooo`Co0000P?ooool0083ooooo0_l0000?
ooooo`03o`000?oooooooooo02oooooo1?l00024ooooo`00POooool2o`0000kooooo00?o0000oooo
ooooool0:_ooool5o`0008Sooooo0023ooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool09_ooool4o`0008gooooo0024ooooo`;o00002oooool00ol0003oooooooooo`0Rooooo`Co0000
TOooool008Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Go0000UOoo
ool008Oooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1?l0002Jooooo`00N_ooool4o`00
0003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`Co0000W_ooool007cooooo00?o0000ooooooooool02oooool2o`0000Gooooo00?o0000oooooooo
ool04?ooool5o`000:;ooooo001looooo`03o`000?oooooooooo00gooooo0_l00003ooooo`03o`00
0?oooooooooo00cooooo1?l0002Wooooo`00O?ooool00ol0003oooooooooo`0>ooooo`05o`000?oo
ooooooooooooool000002_ooool4o`000:_ooooo001looooo`03o`000?oooooooooo00oooooo0_l0
00000ooooooo0000ooooo`04ooooo`Go0000[oooool007cooooo00?o0000ooooooooool04Oooool2
o`000003ooooool0003o000000;o0000]?ooool007cooooo00?o0000ooooooooool04_ooool2o`00
0;Sooooo001jooooo`03oeEEEOmVIVKo00000<kooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0026ooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@2`ooooo`00R?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2_ooooo`00R?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo0028ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000ooooooooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<0;3ooooo0028ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0/_ooool008Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2booooo`00Q_oo
ool00omEEEGoIVIVo`00000=ooooo`Co0000/Oooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43193 .53413 Mdot
.50865 .73297 Mdot
.66378 .49708 Mdot
.43611 .37514 Mdot
.29388 .60687 Mdot
.52374 .57653 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0@?ooool2o`0004cooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0Pooooo`00;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03kooooo1?l0001;ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool002go
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0mooooo`Co0000Boooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo01oooooo000/ooooo`;o0000;Oooool00ol0003ooooo
ooooo`0mooooo`;o0000C?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06[ooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0HOooool2o`0000?o
oooo0ol00003ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool002Oooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Oooooo`Ko00001_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Gooooo000Wooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0GOooool5o`0000Wooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Eooooo`009oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Wooooo0ol00002
ooooo`;o00002_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Voooo
o`;o0000F?ooool00ol0003oooooooooo`1Eooooo`?o00004Oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool0DOooool3o`0001Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`00
9_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04gooooo0ol0000Gooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`19ooooo`?o00006_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01Cooooo000Vooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0AOooool3
o`0001gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo047ooooo0ol0000Pooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0mooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0@ooooo`;o00009oooool3o`0002Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo00kooooo1?l0000Sooooo`?o0000:Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool03Oooool4o`0001oooooo1?l0000/ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04oooool002Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0=oooo
o`;o00007Oooool3o`00033ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Coooo
o`009Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Sooooo0ol0000cooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Tooooo`?o0000=_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool08?oo
ool3o`0003Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool3
o`0006Oooooo00?o0000ooooooooool07?ooool3o`0003cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
01Sooooo0ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool05?ooool3o`0004?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
4?ooool3o`0004Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
01Oooooo0_l0000fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04_ooool001co
oooo00?o0000ooooooooool01?ooool2o`00073ooooo00?o0000ooooooooool00ol0000Iooooo`Co
0000=Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`0001cooooo1?l0000eooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool04Oooool001[ooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01cooooo0_l0000fooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04Oooool002?ooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1Booooo`?o0000BOooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo04oooooo0ol00002ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1<ooooo`?o00001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo017o
oooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0BOooool3o`0000[ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`008_ooool2o`0007;ooooo00?o
0000ooooooooool0AOooool4o`0000kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`1;ooooo`;o00009?ooool00ol0003oooooooooo`12
ooooo`?o00004oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo000Roooo
o`03o`000?oooooooooo04[ooooo1?l0000Sooooo`03o`000?oooooooooo03oooooo0ol0000Foooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooooooo
ool0B_ooool4o`0002?ooooo00?o0000ooooooooool0??ooool3o`0001[ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1<ooooo`;o0000
9?ooool00ol0003oooooooooo`0iooooo`?o00007_ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0=Ooo
ool4o`0002;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`008Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo03;ooooo0ol0000Wooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool04?ooool0027ooooo0_l0001cooooo`03o`000?oooooooooo
02oooooo0ol0000[ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool0023o
oooo0_l0001dooooo`03o`000?oooooooooo02cooooo0ol0000^ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool03oooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0Xooooo`Co0000<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
000Pooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool09_ooool3o`0003Oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo02?ooooo0ol0000kooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Poooo
o`?o0000?oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool07Oooool3o`0004;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo01Wooooo1?l00016ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3oooool001oooooo0_l0001dooooo`03o`000?oooooooooo01Kooooo0ol0001;ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0Cooooo`?o0000Coooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04?ooool3o`00
05?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00cooooo1?l0001Gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`09ooooo`?o0000Foooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo
000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01_ooool3o`0005oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo00?ooooo0ol0001Sooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool03_ooool001kooooo0ol0001dooooo`03o`000?oooooo000000?o0000Ioooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo000Nooooo`03o`000?oooooooooo07?o
oooo0ol0001/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Cooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0L?ooool3o`000003ooooool0003ooooo06cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06gooooo0ol00004ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`001_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J_oo
ool3o`0000Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00gooooo0006ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Vooooo`Co00002_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Hoooool3o`0000kooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo0006oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qoooo
o`?o00004Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03?ooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o
0000Goooool3o`0001Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00cooooo0004ooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03o`00
0?oooooooooo05[ooooo1?l0000Gooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Gooooo`?o00006ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?oo
ool001gooooo00?o0000ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo
057ooooo0ol0000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00009?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo
00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`0Iooooo`;o0000GOooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo03kooooo1?l0000dooooo`03
o`000?oooooooooo01Sooooo1?l0001Mooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0??ooool3o`0003Oooooo00?o0000ooooooooool0
6Oooool4o`0005gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0iooooo`?o0000>_ooool00ol0003oooooooooo`0Jooooo`;o0000Gooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo03Kooooo0ol0000mooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0booooo`Co0000@?ooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool001_o
oooo0_l0000`ooooo`?o0000A?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02_ooool001[ooooo0_l0000^ooooo`?o0000Aoooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool001[ooooo00?o
0000ooooooooool0:_ooool3o`0004[ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02Oooooo0ol0001=
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:
ooooo`006_ooool00ol0003oooooooooo`0Sooooo`Co0000D?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000oooooooo
ool08?ooool3o`0005Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo01gooooo0ol0001Gooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_oo
ool00ol0003oooooooooo`0Jooooo`?o0000F_ooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool05_ooool4
o`0005gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Wooooo000Iooooo`03o`000?oooooooooo01Cooooo0ol0001Qooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003o
ooooooooo`0Aooooo`?o0000I?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool03_ooool3o`0006Oooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo
000Iooooo`03o`000?oooooooooo00_ooooo0ol0001Zooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`07
ooooo`Co0000KOooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool001Sooooo0_l00006ooooo`?o0000LOooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000oooooooo
ool00_ooool3o`0007Cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Sooooo000Hooooo`Go0000Moooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool001Sooooo0_l0001jooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`003Oooool5
o`0000Sooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2<ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool000gooooo00GoV9RHob4Q8Oo^k^koooooodA4A009
ooooo`;o0000Moooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool02?ooool000kooooo00?oV9RHob4Q8Oo^k^h03?ooool2o`0007Gooooo00?o0000oooo
ooooool0S_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo000?ooooo`03
oiRHV?lQ8B7ok^k^00cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0013ooooo00?oMgMgofIVI_ooool0
3?ooool2o`0007?ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool000gooooo00Go0000okZj^_ooooooV9RHoa0@400@ooooo`?o0000Koooool00ol0003ooooooooo
o`2Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool000gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`Co000000?o410@ooooooooool01Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`08ooooo`;o0000K?ooool00ol0003oooooooooo`2D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool000oooooo1_l00005oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Eoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool001[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooo`00001Xooooo`03o`000?oooooooooo09Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000
J?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`006_ooool0
0ol0003oooooooooo`0?ooooo`;o0000IOooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool001Sooooo00?oEEEEofIVI_l000004oooool2o`00
06?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo000_ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo000`ooooo`;o0000HOooool00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool003;ooooo00Co
0000oooooooooooo0000GOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool003?ooooo0ol0001Mooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`00=_ooool2o`0005_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo000hooooo`03o`000?oooooo000005Sooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000iooooo`;o0000
F?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool003[ooooo0_l0001Gooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`00??ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`00?Oooool3o`00
05?ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Cooooo000oooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l0001Aooooo`03o`000?oooooooooo
0:?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;oooooo`00053ooooo00?o0000
ooooooooool0Y?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Soooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00Ko0000oooooooooooo0000oooo
ool0001=ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`00:oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0_ooool2o`0004gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool002_ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000ooooo`17ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00
:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0004So
oooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l00017ooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`00
C?ooool01?l0003oooooooooool00013ooooo`03o`000?oooooooooo0:[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`00COooool00ol0003oooooo`000013ooooo`03o`00
0?oooooooooo0:_ooooo00Go0000ooooooooooooooooo`000005ooooo`00C_ooool2o`0004?ooooo
00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005ooooo`00D?ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0057ooooo
0_l000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo0:kooooo00Co0000oooooooooooo
00001?ooool005?ooooo0_l0000mooooo`03o`000?oooooooooo0:oooooo00?o0000ooooool00000
1?ooool005Cooooo0_l0000looooo`03o`000?oooooooooo0;3ooooo0_l00004ooooo`00E_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo0:oooooo0ol00004ooooo`00Eoooool00ol0
003oooooo`00000hooooo`03o`000?oooooooooo0:_ooooo1?l00007ooooo`00F?ooool2o`0003So
oooo00?o0000ooooooooool0Y_ooool5o`0000_ooooo001Jooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0X_ooool4o`00013ooooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool3o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0001Cooooo001;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09Wooooo
1Ol0000Hooooo`00Boooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000cooooo`03o`00
0?oooooooooo09Gooooo1?l0000Mooooo`00Boooool01Ol0003ooooooooooooooooo000000oooooo
0_l0000aooooo`03o`000?oooooooooo097ooooo1?l0000Qooooo`00Boooool01Ol0003ooooooooo
oooooooo0000017ooooo0_l0000_ooooo`03o`000?oooooooooo08cooooo1Ol0000Uooooo`00Booo
ool01Ol@413ooooooooooooooooo410@01;ooooo0_l0000^ooooo`03o`000?oooooooooo08Sooooo
1?l0000Zooooo`00Boooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00Co0000oooooooooooo
0000:_ooool00ol0003oooooooooo`24ooooo`Co0000;_ooool004_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Eooooo`?o0000:_ooool00ol0003oooooooooo`1oooooo`Go0000<_ooool006Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1kooooo`Co0000=oooool006Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1gooooo`Co0000>oooool006Wooooo0ol0000V
ooooo`03o`000?oooooooooo07?ooooo1?l0000oooooo`00Joooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06kooooo1Ol00013ooooo`00K?ooool2o`0002Cooooo00?o0000oooooooo
ool0J_ooool4o`0004Sooooo001^ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool0
I_ooool4o`0004cooooo001_ooooo`;o00008Oooool00ol0003oooooooooo`1Qooooo`Go0000D?oo
ool0077ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000EOooool0
05[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`1Iooooo`Co0000FOoo
ool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`02ooooo`;o00007Oooool00ol0003oooooooooo`1Dooooo`Go0000GOooool005[ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`03o`000?oo
oooooooo053ooooo1?l0001Rooooo`00F_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01Oooool3o`0001Wooooo00?o0000ooooooooool0C?ooool4o`0006Kooooo001J
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`Go0000J_ooool005[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00[ooooo0ol00002ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0@oooool4o`0006oooooo001Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000001Cooooo
00?o0000ooooooooool0?oooool4o`0007?ooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000gooooo0_l0000Dooooo`03o`000?oooooooooo03[ooooo1Ol0001gooooo`00OOoo
ool2o`0001;ooooo00?o0000ooooooooool0=oooool4o`0007cooooo001oooooo`03o`000?oooooo
000000oooooo00?o0000ooooooooool0<oooool4o`00083ooooo0020ooooo`;o00003oooool00ol0
003oooooooooo`0_ooooo`Co0000Q?ooool0087ooooo0_l0000>ooooo`03o`000?oooooooooo02[o
oooo1Ol00028ooooo`00Poooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo02Kooooo
1?l0002=ooooo`00Q?ooool2o`0000_ooooo00?o0000ooooooooool08_ooool4o`00097ooooo0026
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool5o`0009Gooooo0027oooo
o`?o00001oooool00ol0003oooooooooo`0Iooooo`Co0000V_ooool007[ooooo1?l000000ol@413o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0009ko
oooo001looooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo
1Ol0002Rooooo`00O?ooool00ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003ooooooooo
o`0<ooooo`Co0000Yoooool007cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo
oooo000000[ooooo1?l0002[ooooo`00O?ooool00ol0003oooooooooo`0?ooooo`;o000000?ooooo
o`000?ooool01?ooool5o`000:oooooo001looooo`03o`000?oooooooooo017ooooo0_l000000ooo
oooo0000o`000002o`000;Cooooo001looooo`03o`000?oooooooooo01;ooooo0_l0002hooooo`00
N_ooool00omEEEGoIVIVo`00003>ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<oooo
o`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00Q_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0/?ooool008Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2^ooooo`00R?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo0:oooooo0028ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c02`ooooo`00R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo
0028ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0/_ooool008Kooooo00?oEEEE
ofIVI_l000003Oooool4o`000;7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.07825 .23514 -23.7679 -9 ]
[.07825 .23514 .23211 0 ]
[.18503 .19003 -11.4436 -9 ]
[.18503 .19003 .55639 0 ]
[.29671 .14287 -22.0066 -9 ]
[.29671 .14287 1.99345 0 ]
[.41365 .09351 -5.28147 -9 ]
[.41365 .09351 .71853 0 ]
[.53622 .0418 -15.1839 -9 ]
[.53622 .0418 2.8161 0 ]
[.66483 -0.01242 -4.84113 -9 ]
[.66483 -0.01242 1.15887 0 ]
[-0.00228 .81813 -6.95083 0 ]
[-0.00228 .81813 5.04917 9 ]
[.09305 .88497 -13.5281 0 ]
[.09305 .88497 10.4719 9 ]
[.17993 .94589 -3.30004 0 ]
[.17993 .94589 2.69996 9 ]
[.25946 1.00164 -9.68248 0 ]
[.25946 1.00164 8.31752 9 ]
[.33252 1.05285 -3.16284 0 ]
[.33252 1.05285 2.83716 9 ]
[.39987 1.10006 -9.31459 0 ]
[.39987 1.10006 8.68541 9 ]
[.07502 .2512 -24 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0597 .34709 -6 -2.69294 ]
[.0597 .34709 0 6.30706 ]
[.04328 .44988 -18 -2.78472 ]
[.04328 .44988 0 6.21528 ]
[.02563 .56035 -6 -2.88407 ]
[.02563 .56035 0 6.11593 ]
[.00662 .67939 -18 -2.99197 ]
[.00662 .67939 0 6.00803 ]
[-0.01393 .80804 -6 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-0.5)] .07502 .2512 1 -0.42047 Mshowa
.07323 .34166 m
.07999 .33894 L
s
[(0)] .0597 .34709 1 -0.40157 Mshowa
.0569 .44469 m
.06371 .44209 L
s
[(0.5)] .04328 .44988 1 -0.38117 Mshowa
.03935 .55542 m
.04621 .55296 L
s
[(1)] .02563 .56035 1 -0.3591 Mshowa
.02044 .67476 m
.02735 .67244 L
s
[(1.5)] .00662 .67939 1 -0.33512 Mshowa
0 .80374 m
.00696 .80159 L
s
[(2)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08549 .26425 m
.08953 .26257 L
s
.08249 .28321 m
.08653 .28154 L
s
.07944 .30242 m
.08349 .30077 L
s
.07636 .3219 m
.08041 .32026 L
s
.07005 .36169 m
.07412 .36007 L
s
.06683 .382 m
.0709 .3804 L
s
.06357 .4026 m
.06764 .40101 L
s
.06026 .42349 m
.06434 .42192 L
s
.05349 .46619 m
.05758 .46465 L
s
.05003 .48801 m
.05413 .48648 L
s
.04653 .51015 m
.05063 .50864 L
s
.04296 .53262 m
.04707 .53112 L
s
.03568 .57857 m
.0398 .57711 L
s
.03196 .60207 m
.03609 .60063 L
s
.02818 .62593 m
.03231 .6245 L
s
.02434 .65016 m
.02848 .64875 L
s
.01648 .69975 m
.02063 .69838 L
s
.01246 .72513 m
.01662 .72378 L
s
.00837 .75092 m
.01254 .74958 L
s
.00422 .77712 m
.00839 .7758 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.015 w
.43591 .53785 Mdot
.64645 .50767 Mdot
.51204 .74264 Mdot
.41789 .37412 Mdot
.28977 .61579 Mdot
.50203 .59026 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-1.5)] .07825 .23514 .98066 1 Mshowa
.19482 .20083 m
.19972 .20623 L
s
[(-1)] .18503 .19003 .90727 1 Mshowa
.30604 .15406 m
.31071 .15966 L
s
[(-0.5)] .29671 .14287 .83388 1 Mshowa
.42247 .10511 m
.42688 .11091 L
s
[(0)] .41365 .09351 .76049 1 Mshowa
.54447 .05381 m
.5486 .05982 L
s
[(0.5)] .53622 .0418 .6871 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(1)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.10936 .23676 m
.11239 .23991 L
s
.13044 .2279 m
.13345 .23107 L
s
.15171 .21896 m
.1547 .22215 L
s
.17317 .20993 m
.17613 .21315 L
s
.21667 .19164 m
.21958 .19491 L
s
.23871 .18238 m
.24159 .18566 L
s
.26095 .17302 m
.26381 .17633 L
s
.2834 .16359 m
.28622 .16692 L
s
.3289 .14445 m
.33167 .14784 L
s
.35197 .13475 m
.35471 .13816 L
s
.37525 .12496 m
.37796 .1284 L
s
.39875 .11508 m
.40143 .11854 L
s
.44641 .09504 m
.44903 .09855 L
s
.47058 .08488 m
.47316 .08841 L
s
.49498 .07462 m
.49752 .07818 L
s
.5196 .06427 m
.52212 .06785 L
s
.56957 .04326 m
.57201 .04689 L
s
.59492 .0326 m
.59732 .03625 L
s
.62051 .02184 m
.62288 .02552 L
s
.64636 .01097 m
.64868 .01468 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-1)] -0.00228 .81813 .15847 -1 Mshowa
.09489 .87051 m
.09581 .86328 L
s
[(-0.5)] .09305 .88497 .12734 -1 Mshowa
.18139 .93139 m
.18211 .92413 L
s
[(0)] .17993 .94589 .10001 -1 Mshowa
.26056 .9871 m
.26111 .97984 L
s
[(0.5)] .25946 1.00164 .07583 -1 Mshowa
.33331 1.0383 m
.3337 1.03102 L
s
[(1)] .33252 1.05285 .05428 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(1.5)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.01971 .81761 m
.02036 .81328 L
s
.03904 .83121 m
.03967 .82688 L
s
.058 .84456 m
.05861 .84023 L
s
.07662 .85766 m
.0772 .85332 L
s
.11282 .88313 m
.11335 .87879 L
s
.13043 .89553 m
.13093 .89118 L
s
.14772 .90769 m
.1482 .90335 L
s
.1647 .91965 m
.16516 .9153 L
s
.19778 .94292 m
.19819 .93857 L
s
.21388 .95425 m
.21427 .9499 L
s
.22971 .96539 m
.23008 .96104 L
s
.24527 .97634 m
.24562 .97198 L
s
.2756 .99769 m
.27591 .99333 L
s
.29039 1.00809 m
.29068 1.00373 L
s
.30493 1.01833 m
.3052 1.01396 L
s
.31923 1.02839 m
.31949 1.02403 L
s
.34715 1.04804 m
.34737 1.04367 L
s
.36078 1.05763 m
.36098 1.05326 L
s
.37419 1.06707 m
.37437 1.0627 L
s
.38738 1.07635 m
.38755 1.07198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00g?ooool4o`000003oa0@4?oooooooooo06Sooooo003Nooooo`03o`00
0?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooo
oooo06[ooooo003Nooooo`03o`000?oooooooooo06[ooooo003Nooooo`03o`000?oooooooooo06[o
oooo003Nooooo`03o`000?oooooooooo06[ooooo003Looooo`03oeEEEOmVIVKo000006cooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003R
ooooo`;o0000Ioooool00=oooooo0ol000000ooooooo0000ooooo`1Vooooo`00gOooool2o`0000Co
oooo0_l0001Vooooo`00Yoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool2o`0000Kooooo00?o0000ooooool00000IOooool00:Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`?o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00001Uooooo`00Yoooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`0000_ooooo00Co0000oooo
oooooooo0000I?ooool00:Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo01Kooooo0_l0000=ooooo`04o`000?ooooooooooo`0006Cooooo002Wooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000>ooooo`05o`00
0?ooooooooooooooool00000Hoooool00:Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00:Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo0ol0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00:Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Oooooo`00b?ooool2o`0000;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo0035ooooo`?o00007?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0033ooooo`;o00007oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0031ooooo`;o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0GOooool00;ko
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00;cooooo
0_l0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00;Wooooo0ol0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`00Soooool01Oo^k^ko<S8bo`000?lb<S;ok^k^027ooooo0_l0000]
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool008oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Wooooo002?ooooo`05oa0@4?ooooooooooooooool@41007?ooool2
o`0003;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00Soooool01Ol0
003ooooooooooooooooo000001Wooooo0ol0000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F?ooool008oooooo00Go0000ooooooooooooooooo`00000Gooooo`;o000000?ooooo
o`000?ooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo002?oooo
o`05oa0@4?ooooooooooooooool@41005Oooool2o`0003Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Soooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0ol0000k
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool008oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05Gooooo002Rooooo`;o0000@?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Gooooo002Oooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Cooooo002Mooooo`;o000000?oooooo`000?ooool0@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05?ooooo002Jooooo`?o0000B?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05?ooooo002Hooooo`;o0000Boooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05;ooooo002Fooooo`?o0000C?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05;ooooo002Cooooo`?o00000oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool005gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo0ol0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool005gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o0000Doooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo001Eooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool3o`0005Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool05Oooool3o`0005Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`00GOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`Co0000F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04kooooo001Mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`;o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001Mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000kooooo1?l0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0C?ooool007kooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Boooool007_ooooo0ol0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Boooool007Wooooo1?l0001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool007Oooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_oo
ool007Cooooo0ol0001_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOooool0
07;ooooo0_l000000ooooooo0000ooooo`1_ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0B?ooool004_ooooo1?l000000ol@413oooooooooo`0Nooooo`;o00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool004gooooo
00?o0000ooooooooool07Oooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00@_ooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0
003ooooo07Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00COooool0
0ol0003oooooooooo`0Iooooo`;o0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Kooooo001=ooooo`03o`000?oooooooooo01Kooooo0ol0001mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0AOooool004gooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Go
oooo001=ooooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool004_ooooo00?oEEEEofIVI_l000004Oooool2o`0008Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04?ooooo001Joooo
o`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Hooooo`;o
0000S?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo001Eooooo`?o0000
0_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
@Oooool005?ooooo0_l0002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?oo
ool0057ooooo0ol0002Booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool0
01[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01oooooo0ol00003ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`007?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Looooo`;o0000VOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wo
oooo0_l000000ooooooo0000ooooo`2Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool001cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0Gooooo`?o0000
WOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000X?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool3o`0000;ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03cooooo000Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool2o`000:Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`006_ooool00omEEEGoIVIVo`00000=ooooo`Co00004?ooool3o`000:Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`00>oooool3o`000:Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0jooooo`00>Oooool2o`000:cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`000003ooooool0003ooooo0:_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00=?ooool3o`000;3ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0hooooo`00<oooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002booooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool001Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0002boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool001Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo0000
0;7ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool0
01Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`006?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Cooooo000Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool0037ooooo0_l0000:ooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0_ooooo`00<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`00<?ooool2o`00017ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
XOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000_oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000_ooooo`;o0000
7Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool002kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09_ooool002kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`008oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo000Sooooo`05o`000?oooooooooo
ooooool000001Oooool2o`0002Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Rooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0kooooo`;o0000D_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Wooooo1?l0001Aooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool002gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0hooooo`Co0000DOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
023ooooo000]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>?ooool2o`0005;o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`00;?ooool2o`0002gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo000/ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo000/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo01_ooooo000[ooooo`;o0000=?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool06oooool002_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06_ooool0
02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool002_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo047ooooo
0ol0000Jooooo`00:oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0?_ooool3o`0000;ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03_ooooo0ol00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0hooooo`?o00002?ooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0=Oooool3o`0000_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo03;ooooo0ol0000?ooooo`03o`00
0?oooooooooo01Oooooo000Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0_ooooo`?o00004_ooool00ol0003oooooooooo`0Gooooo`00:_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0;?ooool3
o`0001Gooooo00?o0000ooooooooool05oooool002[ooooo0_l00010ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0:Oooool3o`0001Sooooo00?o0000ooooooooool05oooool002Wo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02Go
oooo0ol0000Kooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Rooooo`?o00007_ooool00ol0003ooooo
ooooo`0Gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool07oooool3o`00027ooooo00?o0000ooooooooool05oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`Co
00009Oooool00ol0003oooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool06?ooool3o`0002Wooooo00?o0000ooooooooool05_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo0ol0000/ooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo01;ooooo0ol0000_ooooo`03o`000?oooooooooo01Kooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`?o0000<_ooool00ol0
003oooooooooo`0Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03?ooool3o`0003Gooooo00?o0000ooooooooool05_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool3o`0003Sooooo00?o0000ooooooooool05_ooool002So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo0ol0000looooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`?o0000?oooool00ol0003ooooo
ooooo`0Eooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool00ol00012ooooo`03o`000?oooooooooo01Gooooo000Wooooo`;o0000DOooool0
0ol0003oooooooooo`1^ooooo`?o0000AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo06[ooooo1?l00017ooooo`03o`000?oooooooooo
01Gooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0I_ooool3o`0000?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`009oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo067ooooo1?l00006ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05Oooool002Oooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`1Mooooo`?o00002oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Gooooo000W
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0FOooool3o`0000kooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool2o`0005Sooooo00?o0000oooo
ooooool0EOooool6o`0000kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Doooo
o`009_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo057ooooo0ol00002ooooo`Co
00003_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool0COooool3o`0000Kooooo0_l0000?ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`19ooooo`?o00006_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01Cooooo000Vooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0AOooool3
o`0001gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo047ooooo0ol0000Pooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05?ooool002Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0mooooo`?o00008oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo000Uooooo`;o0000H?ooool00ol0003oooooooooo`0iooooo`?o00009_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool04?ooool2o`0002?ooooo0ol0000Yooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0>
ooooo`Co00007_ooool4o`0002cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0C
ooooo`009Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00gooooo1?l0000Koooo
o`?o0000<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo000Uooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool03Oooool2o`0001Wooooo0ol0000cooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool002Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Tooooo`?o0000=_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01?ooooo000Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool08?oo
ool3o`0003Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Booooo`009?ooool3
o`0006Oooooo00?o0000ooooooooool07?ooool3o`0003cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
01Sooooo0ol0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04_ooool001[o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool05?ooool3o`0004?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
4?ooool3o`0004Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?oo
ool3o`0004Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool3
o`0004cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01?ooool3o`00
04oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003o
ooooooooo`04ooooo`;o0000L?ooool00ol0003oooooooooo`03o`0005;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo073ooooo0_l0001Eooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
4Oooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aooooo`008oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Kooooo0_l0000jooooo`?o0000BOooool0
0ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
01Gooooo1?l0000fooooo`?o00000_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
017ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool05Oooool4o`0003?o
oooo0ol00006ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Fooooo`;o0000<Oooool3o`0000[ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`008_ooool2o`0007;ooooo00?o
0000ooooooooool0AOooool4o`0000kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`008_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo04;ooooo0ol0000C
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0oooooo`?o00005_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0??ooool3o`0001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`1;ooooo`;o00009Oooool00ol0003oooooooooo`0iooooo`?o0000
7_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oo
oooooooo04[ooooo1?l0000Tooooo`03o`000?oooooooooo03Gooooo1?l0000Rooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0B_ooool4
o`0002Cooooo00?o0000ooooooooool0<_ooool3o`0002Oooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0@ooooo`008Oooool2o`0004cooooo0_l0000Uooooo`03o`000?oooooooooo
02oooooo0ol0000[ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool0023o
oooo0_l0001dooooo`03o`000?oooooooooo02cooooo0ol0000^ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool03oooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0Xooooo`Co0000<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
000Pooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool09_ooool3o`0003Oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo02?ooooo0ol0000kooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03oooool0023ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Poooo
o`?o0000?oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo000Pooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool07Oooool3o`0004;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo01Wooooo1?l00016ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3oooool001oooooo0_l0001dooooo`03o`000?oooooooooo01Kooooo0ol0001;ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0Cooooo`?o0000Coooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00kooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04?ooool3o`00
05?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00cooooo1?l0001Gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`09ooooo`?o0000Foooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo
000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01_ooool3o`0005oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo00?ooooo0ol0001Sooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool03_ooool001kooooo0ol0001dooooo`03o`000?oooooo000000?o0000Ioooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo000Nooooo`03o`000?oooooooooo07?o
oooo0ol0001/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool000Cooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0L?ooool3o`000003ooooool0003ooooo06cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06gooooo0ol00004ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`001_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J_oo
ool3o`0000Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00gooooo0006ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Vooooo`Co00002_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Hoooool3o`0000kooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo0006oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qoooo
o`?o00004Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03?ooool000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o
0000Goooool3o`0001Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00cooooo0004ooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03o`00
0?oooooooooo05[ooooo1?l0000Gooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`1Gooooo`?o00006ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?oo
ool001gooooo00?o0000ooooooooool0E?ooool3o`0001kooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo000Mooooo`03o`000?oooooooooo
057ooooo0ol0000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00009?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool001cooooo
00?o0000ooooooooool0Boooool4o`0002Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Looooo`;o0000BOooool3o`0002_ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0ol0000^ooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o0000<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0?_ooool4o`0003Cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo03cooooo0ol0000gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0iooooo`?o0000>_oo
ool00ol0003oooooooooo`0Kooooo`;o0000G_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Kooooo0ol0000mooooo`03o`000?oooooo
oooo01[ooooo1?l0001Nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool0<_ooool4o`00043ooooo00?o0000ooooooooool06_ooool4o`00
05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`006oooool2o`00033o
oooo0ol00014ooooo`03o`000?oooooooooo01_ooooo0_l0001Qooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02_ooool001[ooooo0_l0000^ooooo`?o0000Aoooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool001[ooooo00?o
0000ooooooooool0:_ooool3o`0004[ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo02Oooooo0ol0001=
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:
ooooo`006_ooool00ol0003oooooooooo`0Sooooo`Co0000D?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000oooooooo
ool08?ooool3o`0005Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Jooooo`03o`000?oooooooooo01gooooo0ol0001Gooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`006_oo
ool00ol0003oooooooooo`0Jooooo`?o0000F_ooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool05_ooool4
o`0005gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Wooooo000Iooooo`03o`000?oooooooooo01Cooooo0ol0001Qooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003o
ooooooooo`0Aooooo`?o0000I?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool03_ooool3o`0006Oooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo
000Iooooo`03o`000?oooooooooo00_ooooo0ol0001Zooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`07
ooooo`Co0000KOooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool001Sooooo0_l00006ooooo`?o0000LOooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000oooooooo
ool00_ooool3o`0007Cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Sooooo000Hooooo`Go0000Moooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool001Sooooo0_l0001jooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`003Oooool5
o`0000Sooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2<ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool000gooooo00GoV9RHob4Q8Oo^k^koooooodA4A009
ooooo`;o0000Moooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool02?ooool000kooooo00?oV9RHob4Q8Oo^k^h03?ooool2o`0007Gooooo00?o0000oooo
ooooool0S_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo000?ooooo`03
oiRHV?lQ8B7ok^k^00cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0013ooooo00?oMgMgofIVI_ooool0
3?ooool2o`0007?ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool000gooooo00Go0000okZj^_ooooooV9RHoa0@400@ooooo`?o0000Koooool00ol0003ooooooooo
o`2Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool000gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`Co000000?o410@ooooooooool01Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`08ooooo`;o0000K?ooool00ol0003oooooooooo`2D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool000oooooo1_l00005oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Eoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool001[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooo`00001Xooooo`03o`000?oooooooooo09Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000
J?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`006_ooool0
0ol0003oooooooooo`0?ooooo`;o0000IOooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool001Sooooo00?oEEEEofIVI_l000004oooool2o`00
06?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo000_ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo000`ooooo`;o0000HOooool00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool003;ooooo00Co
0000oooooooooooo0000GOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool003?ooooo0ol0001Mooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`00=_ooool2o`0005_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo000hooooo`03o`000?oooooo000005Sooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000iooooo`;o0000
F?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool003[ooooo0_l0001Gooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`00??ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`00?Oooool3o`00
05?ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Cooooo000oooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l0001Aooooo`03o`000?oooooooooo
0:?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00:oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;oooooo`00053ooooo00?o0000
ooooooooool0Y?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Soooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00Ko0000oooooooooooo0000oooo
ool0001=ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`00:oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0_ooool2o`0004gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo000[ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool002_ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000ooooo`17ooooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`00
:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0004So
oooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l00017ooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`00
C?ooool01?l0003oooooooooool00013ooooo`03o`000?oooooooooo0:[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`00COooool00ol0003oooooo`000013ooooo`03o`00
0?oooooooooo0:_ooooo00Go0000ooooooooooooooooo`000005ooooo`00C_ooool2o`0004?ooooo
00?o0000ooooooooool0[?ooool01?l0003oooooooooool00005ooooo`00D?ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00001Oooool0057ooooo
0_l000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo0:kooooo00Co0000oooooooooooo
00001?ooool005?ooooo0_l0000mooooo`03o`000?oooooooooo0:oooooo00?o0000ooooool00000
1?ooool005Cooooo0_l0000looooo`03o`000?oooooooooo0;3ooooo0_l00004ooooo`00E_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo0:oooooo0ol00004ooooo`00Eoooool00ol0
003oooooo`00000hooooo`03o`000?oooooooooo0:_ooooo1?l00007ooooo`00F?ooool2o`0003So
oooo00?o0000ooooooooool0Y_ooool5o`0000_ooooo001Jooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0X_ooool4o`00013ooooo001;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool3o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0001Cooooo001;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09Wooooo
1Ol0000Hooooo`00Boooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000cooooo`03o`00
0?oooooooooo09Gooooo1?l0000Mooooo`00Boooool01Ol0003ooooooooooooooooo000000oooooo
0_l0000aooooo`03o`000?oooooooooo097ooooo1?l0000Qooooo`00Boooool01Ol0003ooooooooo
oooooooo0000017ooooo0_l0000_ooooo`03o`000?oooooooooo08cooooo1Ol0000Uooooo`00Booo
ool01Ol@413ooooooooooooooooo410@01;ooooo0_l0000^ooooo`03o`000?oooooooooo08Sooooo
1?l0000Zooooo`00Boooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00Co0000oooooooooooo
0000:_ooool00ol0003oooooooooo`24ooooo`Co0000;_ooool004_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Eooooo`?o0000:_ooool00ol0003oooooooooo`1oooooo`Go0000<_ooool006Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1kooooo`Co0000=oooool006Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1gooooo`Co0000>oooool006Wooooo0ol0000V
ooooo`03o`000?oooooooooo07?ooooo1?l0000oooooo`00Joooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06kooooo1Ol00013ooooo`00K?ooool2o`0002Cooooo00?o0000oooooooo
ool0J_ooool4o`0004Sooooo001^ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool0
I_ooool4o`0004cooooo001_ooooo`;o00008Oooool00ol0003oooooooooo`1Qooooo`Go0000D?oo
ool0077ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000EOooool0
05[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`1Iooooo`Co0000FOoo
ool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`02ooooo`;o00007Oooool00ol0003oooooooooo`1Dooooo`Go0000GOooool005[ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`03o`000?oo
oooooooo053ooooo1?l0001Rooooo`00F_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01Oooool3o`0001Wooooo00?o0000ooooooooool0C?ooool4o`0006Kooooo001J
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`Go0000J_ooool005[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00[ooooo0ol00002ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0@oooool4o`0006oooooo001Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000001Cooooo
00?o0000ooooooooool0?oooool4o`0007?ooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000gooooo0_l0000Dooooo`03o`000?oooooooooo03[ooooo1Ol0001gooooo`00OOoo
ool2o`0001;ooooo00?o0000ooooooooool0=oooool4o`0007cooooo001oooooo`03o`000?oooooo
000000oooooo00?o0000ooooooooool0<oooool4o`00083ooooo0020ooooo`;o00003oooool00ol0
003oooooooooo`0_ooooo`Co0000Q?ooool0087ooooo0_l0000>ooooo`03o`000?oooooooooo02[o
oooo1Ol00028ooooo`00Poooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo02Kooooo
1?l0002=ooooo`00Q?ooool2o`0000_ooooo00?o0000ooooooooool08_ooool4o`00097ooooo0026
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool5o`0009Gooooo0027oooo
o`?o00001oooool00ol0003oooooooooo`0Iooooo`Co0000V_ooool007[ooooo1?l000000ol@413o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0009ko
oooo001looooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo
1Ol0002Rooooo`00O?ooool00ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003ooooooooo
o`0<ooooo`Co0000Yoooool007cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo
oooo000000[ooooo1?l0002[ooooo`00O?ooool00ol0003oooooooooo`0?ooooo`;o000000?ooooo
o`000?ooool01?ooool5o`000:oooooo001looooo`03o`000?oooooooooo017ooooo0_l000000ooo
oooo0000o`000002o`000;Cooooo001looooo`03o`000?oooooooooo01;ooooo0_l0002hooooo`00
N_ooool00omEEEGoIVIVo`00003>ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<oooo
o`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00Q_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0/?ooool008Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0[oooool008Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2^ooooo`00R?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo0:oooooo0028ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c02`ooooo`00R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo
0028ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0/_ooool008Kooooo00?oEEEE
ofIVI_l000003Oooool4o`000;7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.0205052, -0.0425637, \
0.00354531, 0.00354531}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The configuration is a symmetric octahedron, which also could be observed \
in the molecular dynamics simulations in Exercise (22), Sec. ",
  ButtonBox["1.4",
    ButtonData:>{"Chapter1.nb", "c:28"},
    ButtonStyle->"Hyperlink"],
  ". At temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0.1\)]],
  "the animation shows that particles move slightly around their equilibrium \
positions.  At larger temperatures, we expect this motion to increase in \
amplitude until the cluster \"melts\".  This can be studied using the Monte \
Carlo method by simply increasing the temperature and repeating the \
simulations. It is easiest to start from the position generated from a \
previous simulation rather than from random initial conditions, since for \
small temperature changes this allows the system to equilibrate quickly:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z[0]\  = \ z[12000]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.56"],

Cell[BoxData[
    \({{\(-0.3281391142408488`\), \(-0.4389375396069696`\), 
        0.21866166822292657`}, {\(-0.033571999676741966`\), \
\(-0.32215789011253765`\), 1.2244921986772244`}, {\(-0.48541833082215596`\), 
        0.5723447830623164`, 1.2014715381526477`}, {0.19997549486715865`, 
        0.3660245279919502`, 
        0.48156144459225847`}, {\(-0.9678682236230883`\), \
\(-0.23259834551281025`\), 0.9582138280721149`}, {\(-0.771222132276853`\), 
        0.45041548439296464`, 0.21410528022326272`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We then ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the previously-stored values of ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", clear the energy, and repeat the analysis for ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0.2, \ 0.3, \)]],
  " and so on. Since the temperature is now larger, we anticipate that we can \
take larger steps. Nevertheless, it is still useful to check after 2000 steps \
to see if our stepsize is giving us a 50% acceptance rate:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Do[Unset[z[n]], {n, 1, 12000}]; Clear[energy]; 
    energy[0]\  = \ U[z[0]];\), "\n", 
    \(T = 0.2; \ \[CapitalDelta]x\  = \ 0.03;\), "\n", 
    \(\(Do[\(z[n];\), {n, 0, 2000, 1}];\)\), "\n", 
    \(Mean[Table[nkept[n], {n, 1, 2000}]] // N\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 8.57"],

Cell[BoxData[
    \(0.429`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The acceptance level  is reasonably close to 50%, so we will continue with \
this value of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " up to 12,000 steps."
}], "Text"],

Cell[TextData[{
  "\t The results of several such runs at different temperatures are \
summarized in Fig. ",
  ButtonBox["8.9",
    ButtonData:>"Fig. 8.9",
    ButtonStyle->"Hyperlink"],
  ". Rather than plotting error bars based on our error estimates, we simply \
repeat several of the simulations. The scatter in the data provides an \
excellent measure of the statistical error in the results. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.333333 0.618034 0.0494427 [
[.16667 .60553 -9 -9 ]
[.16667 .60553 9 0 ]
[.33333 .60553 -3 -9 ]
[.33333 .60553 3 0 ]
[.5 .60553 -9 -9 ]
[.5 .60553 9 0 ]
[.66667 .60553 -3 -9 ]
[.66667 .60553 3 0 ]
[.83333 .60553 -9 -9 ]
[.83333 .60553 9 0 ]
[1 .60553 -3 -9 ]
[1 .60553 3 0 ]
[1.025 .61803 0 -6 ]
[1.025 .61803 10 6 ]
[-0.0125 .02472 -18 -4.5 ]
[-0.0125 .02472 0 4.5 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .22249 -12 -4.5 ]
[-0.0125 .22249 0 4.5 ]
[-0.0125 .32138 -12 -4.5 ]
[-0.0125 .32138 0 4.5 ]
[-0.0125 .42026 -12 -4.5 ]
[-0.0125 .42026 0 4.5 ]
[-0.0125 .51915 -12 -4.5 ]
[-0.0125 .51915 0 4.5 ]
[0 .64303 -11 0 ]
[0 .64303 11 12 ]
[ 0 0 0 0 ]
[ 1 .62428 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .61803 m
.16667 .62428 L
s
[(0.5)] .16667 .60553 0 1 Mshowa
.33333 .61803 m
.33333 .62428 L
s
[(1)] .33333 .60553 0 1 Mshowa
.5 .61803 m
.5 .62428 L
s
[(1.5)] .5 .60553 0 1 Mshowa
.66667 .61803 m
.66667 .62428 L
s
[(2)] .66667 .60553 0 1 Mshowa
.83333 .61803 m
.83333 .62428 L
s
[(2.5)] .83333 .60553 0 1 Mshowa
1 .61803 m
1 .62428 L
s
[(3)] 1 .60553 0 1 Mshowa
.125 Mabswid
.03333 .61803 m
.03333 .62178 L
s
.06667 .61803 m
.06667 .62178 L
s
.1 .61803 m
.1 .62178 L
s
.13333 .61803 m
.13333 .62178 L
s
.2 .61803 m
.2 .62178 L
s
.23333 .61803 m
.23333 .62178 L
s
.26667 .61803 m
.26667 .62178 L
s
.3 .61803 m
.3 .62178 L
s
.36667 .61803 m
.36667 .62178 L
s
.4 .61803 m
.4 .62178 L
s
.43333 .61803 m
.43333 .62178 L
s
.46667 .61803 m
.46667 .62178 L
s
.53333 .61803 m
.53333 .62178 L
s
.56667 .61803 m
.56667 .62178 L
s
.6 .61803 m
.6 .62178 L
s
.63333 .61803 m
.63333 .62178 L
s
.7 .61803 m
.7 .62178 L
s
.73333 .61803 m
.73333 .62178 L
s
.76667 .61803 m
.76667 .62178 L
s
.8 .61803 m
.8 .62178 L
s
.86667 .61803 m
.86667 .62178 L
s
.9 .61803 m
.9 .62178 L
s
.93333 .61803 m
.93333 .62178 L
s
.96667 .61803 m
.96667 .62178 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
1.025 .61803 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02472 m
.00625 .02472 L
s
[(-12)] -0.0125 .02472 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-10)] -0.0125 .12361 1 0 Mshowa
0 .22249 m
.00625 .22249 L
s
[(-8)] -0.0125 .22249 1 0 Mshowa
0 .32138 m
.00625 .32138 L
s
[(-6)] -0.0125 .32138 1 0 Mshowa
0 .42026 m
.00625 .42026 L
s
[(-4)] -0.0125 .42026 1 0 Mshowa
0 .51915 m
.00625 .51915 L
s
[(-2)] -0.0125 .51915 1 0 Mshowa
.125 Mabswid
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .24721 m
.00375 .24721 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .3461 m
.00375 .3461 L
s
0 .37082 m
.00375 .37082 L
s
0 .39554 m
.00375 .39554 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .49443 m
.00375 .49443 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(U) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.03 w
.33333 .56773 Mdot
.33333 .55826 Mdot
1 .58263 Mdot
.5 .57141 Mdot
.26667 .51915 Mdot
.23333 .53485 Mdot
.2 .52073 Mdot
.16667 .55639 Mdot
.13333 .49201 Mdot
.13333 .32263 Mdot
.1 .19593 Mdot
.06667 .09673 Mdot
.03333 .02343 Mdot
.08333 .10393 Mdot
.11667 .31982 Mdot
.16667 .46101 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`D00000o`3ooom20?ooo`006P3oool00`000000
oooo0?ooo`040?ooo`L00000o`3ooom10?ooo`00203oool400000003014A4@3oool0oooo00D00000
1P3oool00`000000oooo0?ooo`030?ooo`T00000o`3ooom00?ooo`002P3oool00`000000oooo0?oo
o`020?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01P3oool00`000000oooo0?ooo`030?ooo`T00000
o`3ooom00?ooo`001@0000050?ooo`030000003oool0oooo00<0oooo00<0VIVI028R8P3^k^h01`3o
ool00`000000oooo0?ooo`030?ooo`T00000o`3ooom00?ooo`002P3oool00`000000oooo0?ooo`04
0?ooo`0309VIV@0R8R80k^k^00H0oooo0`0000030?ooo`T00000o`3ooom00?ooo`002P3oool00`00
0000oooo0?ooo`050?ooo`0307MgM`1VIVH0oooo00D0oooo00<000000?ooo`3oool00`3oool90000
0?l0oooo@03oool000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo1`00003o0?oood40oooo000:0?ooo`030000003oool0oooo0080oooo
00D000000;^k^`3oool0VIVI014A4@060?ooo`030000003oool0oooo00D0oooo1@00003o0?oood80
oooo00080?ooo`80EEEE00<000000?ooo`3oool00P3oool01@2IVIT04A4A0000000R8R80c<c<00H0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`0@0?ooo`D00000o`3ooolg0?ooo`006P3oool00`000000
oooo0?ooo`0?0?ooo`L00000o`3ooolf0?ooo`006P3oool00`000000oooo0?ooo`0>0?ooo``00000
o`3ooolb0?ooo`006P3oool00`000000oooo0?ooo`0>0?ooo`d00000o`3ooola0?ooo`006P3oool0
0`000000oooo0?ooo`0>0?ooo`h00000o`3oool`0?ooo`006P3oool2000000l0oooo3P00003o0?oo
oc00oooo000J0?ooo`030000003oool0oooo00h0oooo3P00003o0?oooc00oooo000J0?ooo`030000
003oool0oooo00l0oooo3@00003o0?oooc00oooo000J0?ooo`030000003oool0oooo0100oooo3000
003o0?oooc00oooo000J0?ooo`030000003oool0oooo01@0oooo1`00003o0?oooc40oooo00080?oo
o`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kPH0oooo00<000000?ooo`3oool0
5@3oool500000?l0oooo<P3oool000X0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`001@0000050?ooo`030000003o
ool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo0?l0oooo
C03oool000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo
0`00003o0?oood`0oooo000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0?l0ooooC03oool000X0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`002P3o
ool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo
0?ooo`3o0?oood`0oooo00080?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0<c<c0000
000c<c<0k^k^00H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00003o0?oo
odd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0
oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0P00
003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`D00000o`3oool]0?ooo`00
6P3oool00`000000oooo0?ooo`0I0?ooo`L00000o`3oool/0?ooo`006P3oool00`000000oooo0?oo
o`0H0?ooo`T00000o`3oool[0?ooo`006P3oool00`000000oooo0?ooo`0H0?ooo`T00000o`3oool[
0?ooo`006P3oool00`000000oooo0?ooo`0H0?ooo`T00000o`3oool[0?ooo`006P3oool2000001T0
oooo2@00003o0?ooob/0oooo000J0?ooo`030000003oool0oooo01P0oooo2@00003o0?ooob/0oooo
000J0?ooo`030000003oool0oooo01T0oooo1`00003o0?ooob`0oooo000J0?ooo`030000003oool0
oooo01X0oooo1@00003o0?ooobd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool000l0
oooo00D0c<c<028R8P0000008R8R0<c<c0060?ooo`030000003oool0oooo0?l0ooooC03oool000l0
oooo00D08R8R09VIV@3oool0VIVI028R8P060?ooo`030000003oool0oooo0?l0ooooC03oool000L0
oooo1P0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool300000?l0ooooC03oool000l0
oooo00D0<c<c09VIV@3oool0VIVI03<c<`060?ooo`030000003oool0oooo0?l0ooooC03oool000l0
oooo00D0c<c<00000000000000000<c<c0060?ooo`030000003oool0oooo0?l0ooooC03oool000l0
oooo00D04A4A0;^k^`3oool0^k^k014A4@060?ooo`030000003oool0oooo0?l0ooooC03oool000l0
oooo00D000000;^k^`3oool0^k^k000000060?ooo`030000003oool0oooo0?l0ooooC03oool000l0
oooo00D0ZZZZ014A4@0000004A4A0:ZZZP060?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`800000o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
7`3oool500000?l0oooo:03oool001X0oooo00<000000?ooo`3oool07P3oool;00000?l0oooo8`3o
ool000l0oooo00D0k^k^03<c<`0000004A4A0<c<c0060?ooo`030000003oool0oooo01d0oooo3@00
003o0?ooob80oooo000?0?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801P3oool00`000000oooo0?oo
o`0M0?ooo`h00000o`3ooolQ0?ooo`001`3oool600000080oooo00D000000?ooo`3oool0oooo0000
00060?ooo`<000007@3oool>00000?l0oooo8@3oool000l0oooo00D0000009VIV@3oool0VIVI028R
8P060?ooo`030000003oool0oooo01d0oooo3P00003o0?ooob40oooo000?0?ooo`050000001EEED0
0000014A4@3<c<`01P3oool00`000000oooo0?ooo`0M0?ooo`h00000o`3ooolQ0?ooo`003`3oool0
0`1EEED0R8R80?ooo`080?ooo`030000003oool0oooo01h0oooo3@00003o0?ooob40oooo000?0?oo
o`030=gMg@0A4A40VIVI00P0oooo00<000000?ooo`3oool07`3oool;00000?l0oooo8P3oool00100
oooo00@0c<c<04A4A00000004A4A1P3oool00`000000oooo0?ooo`0T0?ooo`D00000o`3ooolS0?oo
o`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0oooo
C03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool0
01X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo
0?l0ooooC03oool001X0oooo0P00003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0oooo
C03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o
0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000o`3o
oom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo
0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool00140oooo0P000000
0`0A4A40oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooC03oool00180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?oood`0oooo00070?ooo`H000000P3oool5000000H0
oooo0`00003o0?oood`0oooo000?0?ooo`0404A4A03MgMd0oooo000000L0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`003`3oool0103MgMd0EEEE0?ooo`0000070?ooo`030000003oool0oooo0?l0
ooooC03oool00100oooo00<0MgMg0<c<c00000001`3oool00`000000oooo0?ooo`3o0?oood`0oooo
000@0?ooo`030>k^kP14A4@0000000L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`004@3oool0
0`1gMgL000000?ooo`060?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`800000
o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`0_0?ooo`D00000o`3ooolH0?ooo`006P3oool0
0`000000oooo0?ooo`0^0?ooo`L00000o`3ooolG0?ooo`006P3oool00`000000oooo0?ooo`0]0?oo
o`T00000o`3ooolF0?ooo`006P3oool00`000000oooo0?ooo`0]0?ooo`T00000o`3ooolF0?ooo`00
6P3oool00`000000oooo0?ooo`0]0?ooo`T00000o`3ooolF0?ooo`006P3oool00`000000oooo0?oo
o`0]0?ooo`T00000o`3ooolF0?ooo`006P3oool00`000000oooo0?ooo`0]0?ooo`T00000o`3ooolF
0?ooo`006P3oool2000002l0oooo1`00003o0?oooaL0oooo000J0?ooo`030000003oool0oooo02l0
oooo1@00003o0?oooaP0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0903oool500000?l0oooo8`3oool001X0oooo00<000000?ooo`3oool08`3oool7
00000?l0oooo8P3oool001X0oooo00<000000?ooo`3oool08P3oool900000?l0oooo8@3oool001X0
oooo00<000000?ooo`3oool08P3oool900000?l0oooo8@3oool001X0oooo0P00000S0?ooo`T00000
o`3ooolQ0?ooo`006P3oool00`000000oooo0?ooo`0R0?ooo`T00000o`3ooolQ0?ooo`006P3oool0
0`000000oooo0?ooo`0R0?ooo`T00000o`3ooolQ0?ooo`006P3oool00`000000oooo0?ooo`0S0?oo
o`L00000o`3ooolR0?ooo`006P3oool00`000000oooo0?ooo`0T0?ooo`D000009@3oool500000?P0
oooo000J0?ooo`030000003oool0oooo03T0oooo1@00000?0?ooo`L00000m`3oool000l0oooo1@00
00060?ooo`030000003oool0oooo03P0oooo1`00000=0?ooo`T00000mP3oool000l0oooo00D0VIVI
028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0oooo03L0oooo2@00000<0?ooo`T00000mP3o
ool000L0oooo1P0000030?ooo`0309VIV@0R8R80k^k^00L0oooo0`00000g0?ooo`T00000303oool9
00000?H0oooo000A0?ooo`0309VIV@0R8R80k^k^00H0oooo00<000000?ooo`3oool0=`3oool90000
00@0oooo1@0000030?ooo`T00000mP3oool00180oooo00<0MgMg06IVIP3oool01@3oool00`000000
oooo0?ooo`0g0?ooo`T000000`3oool700000080oooo2@00003f0?ooo`004`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03L0oooo2@0000020?ooo`T000000P3oool700000?L0oooo
000?0?ooo`050000002k^k/0oooo09VIV@0A4A401P3oool00`000000oooo0?ooo`0h0?ooo`L00000
0`3oool9000000<0oooo1@00003h0?ooo`003`3oool01@2IVIT04A4A0000000R8R80c<c<00H0oooo
00<000000?ooo`3oool0>@3oool5000000@0oooo2@00003o0?ooo`40oooo000J0?ooo`030000003o
ool0oooo0480oooo2@00003o0?ooo`40oooo000J0?ooo`030000003oool0oooo0480oooo2@00003o
0?ooo`40oooo000J0?ooo`800000<03oool5000000l0oooo1`00000I0?ooo`D00000h`3oool001X0
oooo00<000000?ooo`3oool0;P3oool7000000l0oooo1@00000I0?ooo`L00000hP3oool001X0oooo
00<000000?ooo`3oool0;@3oool9000002/0oooo2@00003Q0?ooo`006P3oool00`000000oooo0?oo
o`0]0?ooo`T00000:`3oool900000>40oooo000J0?ooo`030000003oool0oooo02d0oooo2@00000[
0?ooo`T00000;@3oool500000:l0oooo000J0?ooo`030000003oool0oooo02d0oooo2@00000[0?oo
o`T00000;03oool700000:h0oooo000J0?ooo`030000003oool0oooo02d0oooo2@00000[0?ooo`T0
0000:`3oool900000:d0oooo000J0?ooo`800000;`3oool7000002`0oooo2@00000[0?ooo`T00000
[@3oool001X0oooo00<000000?ooo`3oool0;`3oool5000002d0oooo2@00000[0?ooo`T00000U@3o
ool5000001<0oooo000J0?ooo`030000003oool0oooo0640oooo2@00000[0?ooo`T00000U03oool7
00000180oooo000J0?ooo`030000003oool0oooo02H0oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM02H0oooo1`00000V0?ooo`@0000000<0
4A4A0?ooo`000000200000001P3oool0A4A4000000000000<c<c0=gMgBH0oooo1@00000W0?ooo`D0
00001@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@0U0?ooo`T000004@3oool001X0
oooo00<000000?ooo`3oool09P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?oo
o`0307MgM`0c<c<0oooo02H0oooo1@00000Y0?ooo`030000003oool0oooo0080oooo1`0000050?oo
o`0307MgM`0c<c<0oooo02D0oooo00D0VIVI028R8P3^k^h0oooo04A4A00W0?ooo`0509VIV@0R8R80
k^k^0?ooo`14A4@01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0903oool900000140oooo000J
0?ooo`030000003oool0oooo02H0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`D000001`3o
ool00`000000oooo0?ooo`0U0?ooo`0309VIV@0R8R80k^k^02T0oooo00<0VIVI028R8P3^k^h04@3o
ool00`000000oooo0?ooo`0S0?ooo`T000004@3oool001X0oooo00<000000?ooo`3oool09P3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool09`3oool00`2IVIT08R8R0>k^
kP0Y0?ooo`0309VIV@0R8R80k^k^00l0oooo00<0MgMg03<c<`3oool0903oool900000140oooo000J
0?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R
8R80000003<c<`3<c<`0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo
00D00000028R8P000000<c<c0<c<c00Y0?ooo`0307MgM`1VIVH0oooo02T0oooo00<0MgMg06IVIP3o
ool02`3oool01@0000008R8R0000000c<c<0c<c<02D0oooo2@00000A0?ooo`006P3oool2000002L0
oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo1`00000B0?oo
o`006P3oool00`000000oooo0?ooo`0V0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0X0?ooo`050000002k^k/0oooo09VIV@0A4A409`3oool01@000000^k^k0?ooo`2I
VIT04A4A00`0oooo00<000000?ooo`3oool0:03oool00`0A4A40000000000003000001<0oooo000J
0?ooo`030000003oool0oooo02H0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@00000:03o
ool205EEE@030000003oool0oooo02L0oooo0P1EEED00`000000oooo0?ooo`0;0?ooo`@000009`3o
ool01@2IVIT04A4A0000000R8R80c<c<02L0oooo00D0VIVI014A4@0000008R8R0<c<c00<0?ooo`@0
00009`3oool01@2ZZZX04A4A0000000A4A40ZZZZ01@0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood80oooo00D04A4A0000000000000000014A4@050?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood@0oooo00<000000?ooo`3oool01@3oool001X0oooo00<000000?ooo`3oool0o`3ooom4
0?ooo`030000003oool0oooo00D0oooo000J0?ooool00000>P00000=0?ooo`030000003oool0oooo
00D0oooo000T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo001>0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00?l0ooooGP3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo003o0?oooeh0oooo1`0000040?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00503oool01@2IVIT08R8R0?ooo`3^k^h0EEEE0080000000H0A4A40>k^kP3oool0oooo028R
8P2IVIWo0?ooodP0oooo000A0?ooo`080=gMg@1VIVH0000005EEE@2ZZZX0oooo05EEE@1gMgL20?oo
o`0907MgM`14A4@0oooo0?ooo`2ZZZX0EEEE0000001VIVH0gMgM0?l0ooooA@3oool00100oooo00@0
VIVI0000000A4A40gMgM0`3oool00`000000k^k^0?ooo`020?ooo`030000003oool0oooo0080oooo
00@0gMgM014A4@000000VIVIo`3ooom40?ooo`004@3oool01`3MgMd0IVIV0000001EEED0ZZZZ0?oo
o`000000103oool020000000oooo0?ooo`2ZZZX0EEEE0000001VIVH0gMgMo`3ooom50?ooo`00503o
ool0102IVIT08R8R0?ooo`0000040?ooo`050000003oool0oooo028R8P2IVIT0o`3ooom80?ooo`00
5`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooBP3oool001L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooodX0oooo000F0?ooo`03014A4@000000
00000080oooo0P0000000`0A4A40oooo0?ooo`3o0?ooodT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.253664, -12.6802, \
0.0120082, 0.0809572}}],

Cell[TextData[{
  "Fig. 8.9 Mean potential energy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " vs temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " in a Lennard-Jones cluster consisting of ",
  Cell[BoxData[
      \(TraditionalForm\`six\)]],
  " atoms."
}], "Caption",
  CellTags->"Fig. 8.9"],

Cell[TextData[{
  "\tBy examining the configurations of the particles, we find that the \
cluster remains crystallized for ",
  Cell[BoxData[
      \(TraditionalForm\`T \[LessTilde] 0.2 - 0.3\)]],
  ", with particles confined to the octahedral lattice sites, but at higher \
temperatures it \"liquefies\" into a droplet with atoms able to move \
throughout the cluster with reasonable ease. Above a temperature of roughly \
",
  Cell[BoxData[
      \(TraditionalForm\`T~0.4 - 0.5\)]],
  " the droplet disassociates and atoms spend much of their time well \
separated from other atoms, or in the form of loosely bound pairs, triplets \
or quadruplets. One can see the jump in the energy that occurs as the cluster \
disassociates.  The data in this region exhibits rather large errors, caused \
by large fluctuations in the energy as the cluster disassociates and then \
reforms. The jump in ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`T~\ 0.4 - 0.5\)]],
  " is not, strictly speaking, a phase transition, since sharp phase \
transitions can occur only in bulk samples with many atoms. However, the jump \
is surprisingly abrupt, and seems to correspond to a region where both the \
droplet and disassociated phases of the cluster can coexist.   For high \
temperatures the disassociated cluster might  be characterized loosely as \
being in a vapor phase. "
}], "Text"],

Cell[TextData[{
  "\tThe numerical determination of the properties of atomic clusters has \
received much attention,  starting with some of the first papers in the \
computational physics literature. But even more effort has gone into \
numerical studies of bulk phases. The Rosenbluth-Teller-Metropolis Monte \
Carlo method is one of the main workhorses in this field. Simulations with \
thousands of interacting particles are regularly carried out on todays high \
speed computers.  Even so,  tricks must be applied so that these systems \
emulate infinite bulk matter. After all, 1000 particles is only a \
10-by-10-by-10 cube, so surface effects can play an important or even \
dominant role in such simulations. Periodic boundary conditions are often \
used in an attempt to remove or at least reduce such surface effects.  In \
addition, many  ingenious techniques have been invented in order to deal with \
the problems of large fluctuations near phase transitions, metastable states, \
long correlation times, and the like. We do not have the space to delve into \
these advanced subjects here, but interested readers are referred to the book \
by ",
  ButtonBox["Newman and Barkema (2001)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 8.3", "Subsubtitle",
  CellTags->"c:33"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Apply the integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[Integral]", 
              RowBox[{
                RowBox[{"\[DifferentialD]", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["r",
                        FontSlant->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}], 
                RowBox[{"\[DifferentialD]", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["r",
                        FontSlant->"Plain"], 
                      StyleBox["3",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}]}]}], "..."}], 
          RowBox[{"\[DifferentialD]", 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["N",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " to Eq. ",
  ButtonBox["(8.3.12)",
    ButtonData:>{"Chapter8.nb", "(8.3.12)"},
    ButtonStyle->"Hyperlink"],
  " and show that for an ideal gas, the result returns to the Fokker-Planck \
equation for the single-particle probability density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "(", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["1",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " . "
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A gas of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 100\)]],
  " neutral atoms is confined in a magnetic atom trap. Such traps can confine \
the atoms in a vacuum magnetic field by using the dipole force on the atoms' \
spin: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi](r)\), " ", "=", 
          RowBox[{
            RowBox[{
              RowBox[{"-", " ", 
                StyleBox["\[Mu]",
                  FontWeight->"Bold"]}], " ", "\[CenterDot]", 
              RowBox[{
                StyleBox["B",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["\[Mu]",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["B",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Mu]",
          FontWeight->"Bold"], TraditionalForm]]],
  " is the magnetic dipole moment of the atom, and in the second form we \
assume that the dipole is aligned ",
  StyleBox["against ",
    FontSlant->"Italic"],
  " the magnetic field. (Atoms whose dipoles are aligned along the field \
escape. Dipoles can remain antialigned with the field for long periods of \
time, even though a spin flip would lower their magnetic energy by ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Mu]\ B\)]],
  ", because processes that can absorb this large jump in energy are highly \
unlikely: for instance, atom-atom collisions are insufficiently energetic to \
flip the spin because the atoms are very cold. )    The trap is designed so \
that ",
  Cell[BoxData[
      \(TraditionalForm\`B(r)\)]],
  " has a spherically symmetric minimum at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", providing a confining potential of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r)\  = 
        a\  + \ \(\(k\)\(\ \ \)\(r\^2\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{
            StyleBox["\[Mu]",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], \(B(0)\)}]}], TraditionalForm]]],
  " and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(k = \[Mu]\ \(\(B\^\[DoublePrime]/
            2\)\(\ \)\)\)\)\)]],
  " are constants."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Evaluate the average potential energy of the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "  particles vs. ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " analytically using the thermal equilibrium (Boltzmann)  particle \
distribution."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Taking ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ 10\^\(\(-22\)\(\ \)\)\)]],
  "J/",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["m",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ", (a typical value in  such traps) plot the thermal equilibrium particle \
distribution vs ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "  for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"T", "=", 
            RowBox[{\(10\^\(-4\)\), 
              StyleBox["K",
                FontSlant->"Plain"]}]}], ","}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{\(10\^\(-3\)\), 
            StyleBox["K",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the Rosenbluth-Teller-Metropolis Monte Carlo method to evaluate the \
average energy numerically  for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["T",
            "TraditionalForm"], "=", 
          RowBox[{
            RowBox[{\(10\^\(-4\)\), 
              StyleBox["K",
                FontSlant->"Plain"], " ", "and", " ", "T"}], "=", 
            RowBox[{\(10\^\(-3\)\), 
              StyleBox["K",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", using the trap parameters from part (b). Compare with the analytic \
results.  (Remember to choose the step size properly.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Evaluate histograms ",
  Cell[BoxData[
      \(TraditionalForm\`H(r)\)]],
  " of the particle positions vs. the spherical radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and compare to the analytic results from part (b). Remember that, in one \
timestep, now ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(H(r)\), "\[RightAngleBracket]"}], " ", 
          "=", " ", 
          RowBox[{"4", " ", "\[Pi]", " ", \(r\^2\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]], " ", "N", 
            " ", \(\(\[Rho]\_B\)(r)\)}]}], TraditionalForm]]],
  ", where the factor ",
  Cell[BoxData[
      \(TraditionalForm\`4\ \[Pi]\ r\^2\)]],
  " occurs because we are counting the particles that fall between spheres  \
of radii ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", "+", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["r",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Plot the observed fluctuation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["H",
                  FontSlant->"Italic"]}]], "2"], "(", "r", ")"}], 
        TraditionalForm]]],
  " away from the expected value ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], \(H(r)\), "\[RightAngleBracket]"}], " "}], 
        TraditionalForm]]],
  " vs. ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], \(H(r)\), "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " via a ",
  StyleBox["LogLogListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", in order to test the scaling of Eq. ",
  ButtonBox["(8.3.18)",
    ButtonData:>{"Chapter8.nb", "(8.3.18)"},
    ButtonStyle->"Hyperlink"],
  ".   Is there a roughly linear dependence between these two variables?"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Run the Lennard-Jones Monte Carlo code given in the text for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(6\)\(\ \)\)\)]],
  " particles at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  " until an equilibrium is achieved. Using a realization of the equilibrium \
as your new initial condition, investigate the efficiency of the method as a \
function of the step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " by running the code 10 times for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_\(\(step\)\(\ \)\) = 5000\)]],
  " steps, each time starting from the same initial condition, but with step \
sizes chosen as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", "=", " ", "0.05"}], ",", " ", 
          "0.1", ",", " ", "0.15", ",", " ", "...", ",", " ", "0.5"}], 
        TraditionalForm]]],
  ". Make a table of the average energy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", the correlation length ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  ", the fraction of accepted steps,  and the estimated error ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in each run. For which value of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is the estimated error smallest?  What is the fraction of accepted steps \
in this case?"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Rewrite the Monte Carlo method used in the example on Lennard-Jones \
clusters so that only one particle is moved at a time in each Monte Carlo \
step. This particle can either be chosen randomly, or each particle in the \
cluster can be chosen consecutively. That is, at the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th step, either ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["i",
            FontFamily->"Courier",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontFamily->"Courier"], 
          RowBox[{
            StyleBox["Random",
              FontFamily->"Courier"], 
            StyleBox["[",
              FontFamily->"Courier"], 
            RowBox[{
              StyleBox["Integer",
                FontFamily->"Courier"], 
              StyleBox[",",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["{",
                  FontFamily->"Courier"], 
                RowBox[{
                  StyleBox["1",
                    FontFamily->"Courier"], 
                  StyleBox[",",
                    FontFamily->"Courier"], 
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontSlant->"Plain"]}], 
                StyleBox["}",
                  FontFamily->"Courier"]}]}], 
            StyleBox["]",
              FontFamily->"Courier"]}]}], TraditionalForm]],
    FontWeight->"Bold"],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["i",
            FontFamily->"Courier",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontFamily->"Courier"], 
          RowBox[{
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier"], 
              StyleBox["[",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier"], 
                StyleBox["M",
                  FontFamily->"Courier",
                  FontSlant->"Plain"]}], 
              StyleBox["]",
                FontFamily->"Courier"]}], 
            StyleBox["+",
              FontFamily->"Courier"], 
            StyleBox["1",
              FontFamily->"Courier"]}]}], TraditionalForm]],
    FontWeight->"Bold"],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox["i",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " labels the particle to be moved. Use the following trick to increase code \
efficiency: when evaluating ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["U",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ",  use the fact that only one particle has moved. If the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "th particle is moved from ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "i"], "\[Prime]"], TraditionalForm]]],
  ", then"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], " ", "=", 
          RowBox[{
            RowBox[{
              UnderoverscriptBox["\[CapitalSigma]", GridBox[{
                    {\(j = 1\)},
                    {\(j \[NotEqual] \ i\)}
                    }], "M"], "(", 
              RowBox[{
                RowBox[{\(\[Phi]\_int\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "i"], "\[Prime]"], "-", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "j"]}], ")"}], "-", 
                RowBox[{\(\[Phi]\_int\), "(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "i"], "-", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "j"]}], ")"}]}], ")"}], " ", "+",
             " ", 
            RowBox[{\(\[Phi]\_ext\), "(", 
              SuperscriptBox[
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], "\[Prime]"], ")"}], "-", 
            RowBox[{\(\[Phi]\_ext\), "(", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "i"], ")"}]}]}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Evaluate the energy at step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(U(n)\), " ", "=", " ", 
          RowBox[{\(U(n - 1)\), " ", "+", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["U",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ".  Thus, only the initial energy need be evaluated using the full energy \
function ",
  ButtonBox["(8.3.19)",
    ButtonData:>{"Chapter8.nb", "(8.3.19)"},
    ButtonStyle->"Hyperlink"],
  ". This method requires only ",
  Cell[BoxData[
      \(TraditionalForm\`2 \((M - 1)\)\)]],
  " evaluations of the interaction potential, as opposed to the ",
  Cell[BoxData[
      \(TraditionalForm\`\(M(M - 1)\)/2\)]],
  " evaluations needed in Eq. ",
  ButtonBox["(8.3.19)",
    ButtonData:>{"Chapter8.nb", "(8.3.19)"},
    ButtonStyle->"Hyperlink"],
  " .\n\tAnother factor of two speed increase can be attained by defining a \
list with elements ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(i\ j\)\), "=", 
          RowBox[{\(\[Phi]\_int\), "(", 
            RowBox[{
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "i"], "-", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "j"]}], ")"}]}], TraditionalForm]]],
  ".  When moving particle ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " one constructs a list with elements  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((\[Phi]\^\[Prime])\)\_j\), "=", 
          RowBox[{\(\[Phi]\_int\), "(", 
            RowBox[{
              SuperscriptBox[
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], "\[Prime]"], "-", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "j"]}], ")"}]}], TraditionalForm]]],
  ", uses it to evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]U\)]],
  ", and then updates ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(i\ j\)\)]],
  " if the step is accepted. Now only ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  " interaction potential evaluations are required in each step."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Run this code at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0.1\)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 6\)]],
  " particles, until an equilibrium is achieved.  Then vary the step until \
the average acceptance rate over 500 steps is  roughly 50% . How large a step \
can you take? (Recall that the required step size for 50% acceptance was ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.02"}], 
        TraditionalForm]]],
  " when all particle were moved.) Calculate the correlation time ",
  Cell[BoxData[
      \(TraditionalForm\`m\_\(\(c\)\(\ \)\)\)]],
  ". How does the value ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c/6\)]],
  " compare to ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  ", the correlation time achieved  when all particles are moved at once? (We \
divide ",
  Cell[BoxData[
      \(TraditionalForm\`m\_c\)]],
  " by six because it takes ",
  Cell[BoxData[
      \(TraditionalForm\`six\)]],
  " steps to move all six particles, assuming consecutive steps )"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Using the step size determined in part (a), start the code again from a \
random initial condition. Roughly how many steps per particle are required \
before equilibrium is achieved? (Recall that when all particles were moved at \
once, each particle had to be moved roughly 2000 times before an equilibrium \
was obtained.) Based on your results of  parts (a) and (b), which method is \
more efficient, moving all particles at once or moving them one at a time? "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use this code to investigate the mean potential energy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " vs. temperature for a Lennard-Jones cluster of ",
  Cell[BoxData[
      \(TraditionalForm\`M = 5\)]],
  " atoms, over the temperature range ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0 - 3\)]],
  ". Create a diagram analogous to Fig. ",
  ButtonBox["8.9",
    ButtonData:>"Fig. 8.9",
    ButtonStyle->"Hyperlink"],
  ", and discuss the configuration of the system as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  StyleBox[" Simulation project: The Ising model. ",
    FontSlant->"Italic"],
  "The Ising model  describes the behavior of ferromagnetic materials. Above \
a certain critical temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  ", such materials display no net magnetization; but below  ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  " a magnetization develops spontaneously.  In the Ising model, the \
ferromagnet is modeled as ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " atomic spins with fixed positions on a grid. Each spin ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  " is quantized, and can take a value only of 1 or -1 (i.e. up or down).  \
The total magnetization ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " of the sample is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%N \[Sigma]\_i\)]],
  ", and in dimensionless form is ",
  Cell[BoxData[
      \(TraditionalForm\`m = \[Sum]\+\(i = 1\)\%N \[Sigma]\_i\)]],
  ". "
}], "Text",
  CellTags->"i:77"],

Cell[TextData[{
  "\tThe spins interact only with the neighboring spins on the grid, with a \
potential ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(U\  = \ \(-\((J/
                2)\)\) \(\[Sum]\+\(i, j = 1\[IndentingNewLine]
              \((n\ n)\)\)\%N\( \[Sigma]\_i\) \[Sigma]\_j\)\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`J \[GreaterEqual] \ 0\)]],
  "is a parameter determining the strength of the interaction, ",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  "and where the sum is only over nearest neighbors on the grid. Note that \
the sum double-counts each interacting pair, which is why we require the \
factor of 1/2  in the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". Thus, the minimum-energy state has all spins aligned with ",
  Cell[BoxData[
      \(TraditionalForm\`U\  = \ \(-p\)\ \ N\ J/2\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is the number of nearest neighbors, and ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\[PlusMinus]1\)\)]],
  ", i.e., all spins are either up or down. This is the expected result for \
zero temperature.  However, at high temperature ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", ">>", 
          SubscriptBox[
            StyleBox["T",
              FontSlant->"Italic"], "c"]}], TraditionalForm]]],
  ", one expects that spins are randomly oriented and uncorrelated, with ",
  Cell[BoxData[
      \(TraditionalForm\`U\  \[TildeTilde] 0\ and\ m\  = 0\)]],
  ".\n\tWe will study the behavior of the Ising model using the Monte Carlo \
method. We will assume the spins are on an ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "-by-",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " square grid ",
  Cell[BoxData[
      \(TraditionalForm\`\((N\  = \ M\^2)\)\)]],
  "with periodic boundary conditions. Then the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "th spin ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  " has ",
  Cell[BoxData[
      \(TraditionalForm\`p = 4\)]],
  " nearest neighbors with which it can interact. We call these spins ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1,  ... , 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that the energy change when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  " flips to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Sigma]\_i\)\)]],
  " (all other spins fixed) is  "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], 
          "=", \(2  J\ \[Sigma]\_i\ \(\[Sum]\+\(n = 1\)\%4 \[Sigma]\_n\)\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThis result implies that the Ising model is particularly straightforward \
from the standpoint of the Monte Carlo method. In each move, we randomly \
choose a spin from the grid, evaluate ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["U",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", and apply the Monte Carlo algorithm in order to determine whether to \
flip the spin or leave it as it is. Since the Gibbs distribution depends only \
on ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], 
          "/", \((\(k\_\(\(B\)\(\ \)\)\) T)\)}], TraditionalForm]]],
  ", it is useful to define a parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k = J/\((k\_B\ T)\)\)\(,\)\)\)]],
  " which is the inverse temperature in units of ",
  Cell[BoxData[
      \(TraditionalForm\`J/k\_B\)]],
  ". We will couch all results in terms of the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and the number of spins, ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Program the Monte Carlo method. Do not bother calculating acceptance \
ratios since the size of the steps is not an adjustable parameter.  Define a \
matrix of spin values with components ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["[[i,j]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ,",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] \ i, 
      j, \(\(\[LessEqual]\)\(\ \)\(M\)\)\)]],
  ". In each move choose values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " randomly. The nearest neighbors are at ",
  Cell[BoxData[
      \(TraditionalForm\`\((i + 1, j)\), \((i - 1, j)\), \((i, 
        j + 1)\), \((i, j - 1)\)\)]],
  ", excepting those cases where ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " lie on an edge of the square domain, in which case periodic boundary \
conditions must be applied. "
}], "Text"],

Cell[TextData[{
  "\tUse the following tricks to increase the speed of your code.\n\t(i) \
Exponentials take a long time to evaluate. Therefore, do not evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{"exp", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]]}], 
              "/", \(k\_\(\(B\)\(\ \)\)\)}], "T"}], "]"}], 
        TraditionalForm]]],
  " unless ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], ">", "0"}], TraditionalForm]]],
  ". Also, note that for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], ">", "0"}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sigma]\_i\) \(\[Sum]\+\(n = 1\)\%4 \[Sigma]\_n\)\
\)]],
  "can take on only the values 2 and 4. Therefore, save the two possible \
values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"exp", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["U",
                      FontSlant->"Italic"]}]]}], 
              "/", \(k\_\(\(B\)\(\ \)\)\)}], "T"}], "]"}], 
        TraditionalForm]]],
  " that you will need in a given run for a given ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ",  in a list ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " that is evaluated at the beginning before you start moving the particles: \
",
  Cell[BoxData[
      \(TraditionalForm\`p = {\[ExponentialE]\^\(\(-4\) k\), \ \
\[ExponentialE]\^\(\(-8\) k\)}\)]],
  ". When deciding whether to accept a step, refer to the values stored in \
the list rather than evaluating the exponential directly: the probability of \
accepting a step with given  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["U",
                FontSlant->"Italic"]}]], ">", "0"}], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`p\_l\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(\[Sigma]\_i\) \(\[Sum]\+\(n = 1\)\%4 \
\[Sigma]\_n/2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t(ii) Evaluate the total energy of the lattice only once, at the \
beginning of the run. Then update the energy from step to step and store its \
value, by adding ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["U",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " to the previous stored energy value. Store the energy values at each \
timestep ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["energy",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(iii) Evaluate and store values of  ",
  Cell[BoxData[
      \(TraditionalForm\`m = \[Sum]\+\(i = 1\)\%N \[Sigma]\_i\)]],
  " in the same way, by storing the initial value of the sum and then  adding \
",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Sigma]\_i\)]],
  " to the previous stored value, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Sigma]\_i = \(-\[Sigma]\_i\)\)]],
  " if a move is accepted, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Sigma]\_i = 0\)]],
  " if not. "
}], "Text"],

Cell[TextData[{
  "\t(iv) You are going to perform calculations with many spins, for ",
  Cell[BoxData[
      \(TraditionalForm\`10\^5\)]],
  " moves or more. It is therefore best to ",
  StyleBox["not",
    FontSlant->"Italic"],
  " make ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remember all realizations of the spins during a run. Instead define a \
function ",
  StyleBox["lat[\[Sigma]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that takes the spin matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as its argument, and returns the new spin matrix after a Monte Carlo \
move. Simply update ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the command  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = lat[\[Sigma]]\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", using a ",
  StyleBox["Do",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " loop."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Starting with a lattice of spins in the ground state, calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "m", "\[RightAngleBracket]"}], " "}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "U", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ 0.7, 0.6, 0.5, 0.4, 0.3, 0.2, 0.1\)]],
  " (in that order). Plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[LeftAngleBracket]",
            "TraditionalForm"], "m", "\[RightAngleBracket]"}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox["\[LeftAngleBracket]",
              "TraditionalForm"], "U", "\[RightAngleBracket]"}], "/", "J"}], 
        TraditionalForm]]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". For each ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " plot an equilibrated  realization of the spins on the lattice, via ",
  StyleBox["ListDensityPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". (See Fig. ",
  ButtonBox["8.10",
    ButtonData:>"Fig. 8.10",
    ButtonStyle->"Hyperlink"],
  ".) In each run, plot ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " vs. timestep until you are sure it has equilibrated before starting to \
evaluate the averages. This could require ",
  Cell[BoxData[
      \(TraditionalForm\`10\^5\)]],
  " moves or more, depending on how close ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is to ",
  Cell[BoxData[
      \(TraditionalForm\`k\_c\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " The Ising model on an infinite  square lattice is analytically tractable. \
 The scaled critical temperature is given by ",
  Cell[BoxData[
      \(TraditionalForm\`k\_c\^\(-1\)\  = \ \(\(2.269 ... \)\(.\)\)\)]],
  ", the mean magnetization per spin is given by the expressions \n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox["\[LeftAngleBracket]",
                "TraditionalForm"], "m", "\[RightAngleBracket]"}], "/", "N"}],
           " ", "=", 
          RowBox[{
            TagBox[
              RowBox[{
                StyleBox["{",
                  ShowAutoStyles->False,
                  FontSize->18], 
                StyleBox[GridBox[{
                      {\(\(\ \)\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ k < \ k\_c, \)\)},
                      {\(\(\((1 + \[ExponentialE]\^\(\(-8\)\ k\) - 6\ \
\[ExponentialE]\^\(\(-4\)\ k\))\)\^\(1/8\)\ \((1 + \[ExponentialE]\^\(\(-4\)\ \
k\))\)\^\(1/4\)\)\/\@\(1 - \[ExponentialE]\^\(\(-4\)\ k\)\)\ , \ \ \ k > 
                          k\_c, \)}
                      }],
                  ShowAutoStyles->True]}],
              (#&)], Cell[""]}]}], TraditionalForm]]],
  "\nand the mean energy per spin is\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["\[LeftAngleBracket]",
                  "TraditionalForm"], "U", "\[RightAngleBracket]"}], "/", 
              "N"}], " ", "J"}], " ", "=", " ", 
          RowBox[{"-", 
            RowBox[{\(1\/\(tanh\ 2\ k\)\), "[", 
              RowBox[{"1", "+", 
                RowBox[{\(\(\(2\)\(\ \)\)\/\[Pi]\), 
                  RowBox[{
                    StyleBox["K",
                      FontSlant->"Italic"], 
                    StyleBox["(",
                      
                      FontSize->14], \(4\ \(\(sech\^2\)(
                        2\ k)\)\ \ \(\(tanh\^2\)(2\ k)\)\), 
                    StyleBox[")",
                      FontSize->14]}], 
                  " ", \((\(-1\) + 2\ tanh\^2\ 2\ k)\)}]}], "]"}]}]}], 
        TraditionalForm]]],
  ",\nwhere ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(K(m)\),
          FontSlant->"Italic"], TraditionalForm]]],
  " is a complete elliptic function (",
  StyleBox["EllipticK",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ").  [See for example, ",
  ButtonBox["Plischke and Bergerson (1989)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". ] Plot these expressions and overlay the results on your Monte Carlo \
data."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -6 -9 ]
[.25962 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.74038 -0.0125 -6 -9 ]
[.74038 -0.0125 6 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -12 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -12 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(10)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(20)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(30)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(40)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(10)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(20)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(30)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFF0000FFFFFF0000FFFFFF00FFFF00FFFF0000FF0000FFFFFFFFFF0000000000
0000FF00
FF00FFFF00FFFF00000000FFFFFFFF0000FFFFFFFF00FF000000FFFF0000FF0000FF0000
FFFFFFFF
FF00FFFF000000000000FFFF00FFFFFF0000FFFFFF000000000000000000FF00FF000000
00FFFFFF
FFFFFF0000000000000000000000FFFF00FFFF00FFFFFFFF00000000FFFFFF00FF000000
00FFFFFF
FF0000FF00000000000000FF0000FF00FFFFFF00FFFF0000000000000000000000FF0000
FFFFFFFF
FFFFFF000000000000FF00FF000000FFFF0000FFFFFF0000000000000000000000000000
FFFFFFFF
FF00FF000000000000FF00FFFFFF00FF0000FFFFFF00FF0000FFFF000000FFFFFF000000
0000FF00
0000FF000000000000FF0000FFFF0000FFFFFF000000FF00000000FFFF0000FFFFFF0000
00000000
000000000000000000FF00FF00FF00FFFF00000000000000FFFFFFFFFFFF0000FFFFFFFF
FF0000FF
00000000000000FF000000FFFF0000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000
0000000000000000000000FFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFF00FFFFFFFFFF
00000000
0000FFFF00000000FFFFFF00FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFF00FFFF000000
FF000000
00FFFFFFFFFF00FF00000000FFFF00FF00FF00FF000000FFFFFFFFFFFFFFFFFF00FFFF00
00FF0000
0000FFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FF00
FFFF0000
0000FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FF000000
000000000000FFFFFFFF00FFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFF
FF00FF00
FFFFFF00000000FF0000FFFFFF00000000FF0000FF00FF00000000FFFF0000000000FFFF
FF00FF00
00FFFF00FF0000FFFFFFFFFFFF0000FFFFFF0000FFFFFFFF0000FFFFFFFFFF0000FF00FF
FFFFFFFF
00FFFF00FF0000FFFF00FFFFFF00FFFFFF000000FFFFFFFF00FFFFFFFFFFFFFF00FF00FF
00FFFF00
00FFFF00FF0000FF0000FFFFFF00FF00FF000000000000FF00FF00FFFFFF0000FFFF0000
000000FF
00FF0000FFFF00000000FF0000FFFF00FFFF00FF000000FF00000000FFFF00FFFFFFFFFF
00000000
00FFFF0000000000FF00000000000000FFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFF
000000FF
FF00FF00000000FFFFFFFF0000FFFFFFFFFF0000000000FFFF000000000000FFFF00FFFF
000000FF
FFFFFFFF00FFFFFF0000FFFF0000FFFFFF000000000000000000FFFFFF000000FFFFFFFF
FF000000
FFFFFFFFFF000000FFFFFFFF0000FFFFFF00FFFFFFFF00FFFFFFFFFF0000FFFFFF0000FF
00000000
FFFFFF0000FFFFFFFFFF0000000000FFFFFFFFFFFF000000FFFFFFFF000000000000FF00
FF00FF00
FFFFFFFF00000000FFFFFFFFFF00FF0000FFFFFFFFFF0000FFFF0000FF00000000FFFFFF
FFFFFF00
FFFFFFFF000000FFFF00000000000000FFFFFF00FFFFFFFFFF000000FF00FFFFFFFFFF00
FFFFFFFF
FFFFFF000000FFFFFF000000000000000000000000FFFFFFFFFF0000FF00FFFFFF0000FF
0000FFFF
FFFF00FFFFFFFF000000FF0000FF00FF00FFFF0000FFFFFFFFFF000000000000FFFF00FF
FFFFFFFF
FFFFFFFFFFFFFF0000000000FF0000FFFFFFFF00FF00FFFFFFFF0000000000FFFFFFFF00
FFFFFFFF
00FFFFFF0000000000FFFFFFFF00FF0000FFFF00FF00FFFF00FF00000000000000FFFFFF
FFFFFFFF
FFFF00FFFF000000FF00FFFFFF00FFFFFFFFFF000000FFFFFF000000000000FFFFFFFFFF
FFFF00FF
000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFFFF
000000FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFF00FFFFFF0000FFFFFFFF00FFFFFFFF
FF0000FF
00FF00FFFFFFFFFF00FFFFFFFFFFFF00FF0000000000000000000000FFFFFF0000FF00FF
FF0000FF
00FFFF0000FFFF00FFFF000000FF00FFFFFF00000000000000FFFFFFFFFFFF0000000000
FFFF00FF
0000000000FFFFFFFFFF000000FF000000FF00FF0000FF0000FFFFFFFFFFFFFFFF000000
FFFFFFFF
FF0000FFFFFF00FFFF000000FF0000FFFFFF0000000000FF00FFFF00FFFFFFFF00000000
FFFFFFFF
FFFF00FFFF0000FFFF000000FFFFFF00FFFFFF00FF0000000000FFFFFFFFFF0000000000
0000FFFF
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.04327 .01923 m
.04327 .98077 L
s
.06731 .01923 m
.06731 .98077 L
s
.09135 .01923 m
.09135 .98077 L
s
.11538 .01923 m
.11538 .98077 L
s
.13942 .01923 m
.13942 .98077 L
s
.16346 .01923 m
.16346 .98077 L
s
.1875 .01923 m
.1875 .98077 L
s
.21154 .01923 m
.21154 .98077 L
s
.23558 .01923 m
.23558 .98077 L
s
.25962 .01923 m
.25962 .98077 L
s
.28365 .01923 m
.28365 .98077 L
s
.30769 .01923 m
.30769 .98077 L
s
.33173 .01923 m
.33173 .98077 L
s
.35577 .01923 m
.35577 .98077 L
s
.37981 .01923 m
.37981 .98077 L
s
.40385 .01923 m
.40385 .98077 L
s
.42788 .01923 m
.42788 .98077 L
s
.45192 .01923 m
.45192 .98077 L
s
.47596 .01923 m
.47596 .98077 L
s
.5 .01923 m
.5 .98077 L
s
.52404 .01923 m
.52404 .98077 L
s
.54808 .01923 m
.54808 .98077 L
s
.57212 .01923 m
.57212 .98077 L
s
.59615 .01923 m
.59615 .98077 L
s
.62019 .01923 m
.62019 .98077 L
s
.64423 .01923 m
.64423 .98077 L
s
.66827 .01923 m
.66827 .98077 L
s
.69231 .01923 m
.69231 .98077 L
s
.71635 .01923 m
.71635 .98077 L
s
.74038 .01923 m
.74038 .98077 L
s
.76442 .01923 m
.76442 .98077 L
s
.78846 .01923 m
.78846 .98077 L
s
.8125 .01923 m
.8125 .98077 L
s
.83654 .01923 m
.83654 .98077 L
s
.86058 .01923 m
.86058 .98077 L
s
.88462 .01923 m
.88462 .98077 L
s
.90865 .01923 m
.90865 .98077 L
s
.93269 .01923 m
.93269 .98077 L
s
.95673 .01923 m
.95673 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .04327 m
.98077 .04327 L
s
.01923 .06731 m
.98077 .06731 L
s
.01923 .09135 m
.98077 .09135 L
s
.01923 .11538 m
.98077 .11538 L
s
.01923 .13942 m
.98077 .13942 L
s
.01923 .16346 m
.98077 .16346 L
s
.01923 .1875 m
.98077 .1875 L
s
.01923 .21154 m
.98077 .21154 L
s
.01923 .23558 m
.98077 .23558 L
s
.01923 .25962 m
.98077 .25962 L
s
.01923 .28365 m
.98077 .28365 L
s
.01923 .30769 m
.98077 .30769 L
s
.01923 .33173 m
.98077 .33173 L
s
.01923 .35577 m
.98077 .35577 L
s
.01923 .37981 m
.98077 .37981 L
s
.01923 .40385 m
.98077 .40385 L
s
.01923 .42788 m
.98077 .42788 L
s
.01923 .45192 m
.98077 .45192 L
s
.01923 .47596 m
.98077 .47596 L
s
.01923 .5 m
.98077 .5 L
s
.01923 .52404 m
.98077 .52404 L
s
.01923 .54808 m
.98077 .54808 L
s
.01923 .57212 m
.98077 .57212 L
s
.01923 .59615 m
.98077 .59615 L
s
.01923 .62019 m
.98077 .62019 L
s
.01923 .64423 m
.98077 .64423 L
s
.01923 .66827 m
.98077 .66827 L
s
.01923 .69231 m
.98077 .69231 L
s
.01923 .71635 m
.98077 .71635 L
s
.01923 .74038 m
.98077 .74038 L
s
.01923 .76442 m
.98077 .76442 L
s
.01923 .78846 m
.98077 .78846 L
s
.01923 .8125 m
.98077 .8125 L
s
.01923 .83654 m
.98077 .83654 L
s
.01923 .86058 m
.98077 .86058 L
s
.01923 .88462 m
.98077 .88462 L
s
.01923 .90865 m
.98077 .90865 L
s
.01923 .93269 m
.98077 .93269 L
s
.01923 .95673 m
.98077 .95673 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.25962 -0.0125 -6 -9 ]
[.25962 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.74038 -0.0125 -6 -9 ]
[.74038 -0.0125 6 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -12 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -12 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(10)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(20)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(30)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(40)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(10)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(20)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(30)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000FF
0000FFFF00FFFFFF0000000000FFFF000000000000000000000000000000000000000000
00000000
0000FFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF0000000000000000
00000000
0000FFFFFFFFFFFF0000000000000000000000000000000000FF00000000000000000000
00000000
00FFFFFFFFFFFFFF0000000000FF00000000000000000000000000000000000000000000
00000000
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
00000000
FFFFFFFFFF000000000000000000000000000000000000000000FF000000000000000000
00000000
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
00000000
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FF
FFFFFF0000000000000000000000000000000000000000000000000000000000FF000000
000000FF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000FF
FFFFFF000000000000000000000000000000000000000000000000000000FF0000000000
00000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
00000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
00000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
FFFF0000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
FFFFFF00
FF000000000000000000000000000000000000000000FFFF0000000000000000000000FF
FFFFFFFF
FFFFFF000000000000000000FF00000000000000000000000000000000000000000000FF
FFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF000000000000000000000000FF00FFFFFF00FFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000000000000000000000FF0000FFFFFFFFFF
FFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000000000FFFFFFFFFFFFFFFF
00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000000000FFFFFFFFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000000000000000FFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000000000000000000000FFFF00FF00
00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00000000000000000000000000FFFF000000
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000000000000000000000000000FF00FF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000FF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000FF
FFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
FFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
FFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
0000FFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000FF
pop
P
% End of image
.01923 .01923 m
.01923 .98077 L
s
.04327 .01923 m
.04327 .98077 L
s
.06731 .01923 m
.06731 .98077 L
s
.09135 .01923 m
.09135 .98077 L
s
.11538 .01923 m
.11538 .98077 L
s
.13942 .01923 m
.13942 .98077 L
s
.16346 .01923 m
.16346 .98077 L
s
.1875 .01923 m
.1875 .98077 L
s
.21154 .01923 m
.21154 .98077 L
s
.23558 .01923 m
.23558 .98077 L
s
.25962 .01923 m
.25962 .98077 L
s
.28365 .01923 m
.28365 .98077 L
s
.30769 .01923 m
.30769 .98077 L
s
.33173 .01923 m
.33173 .98077 L
s
.35577 .01923 m
.35577 .98077 L
s
.37981 .01923 m
.37981 .98077 L
s
.40385 .01923 m
.40385 .98077 L
s
.42788 .01923 m
.42788 .98077 L
s
.45192 .01923 m
.45192 .98077 L
s
.47596 .01923 m
.47596 .98077 L
s
.5 .01923 m
.5 .98077 L
s
.52404 .01923 m
.52404 .98077 L
s
.54808 .01923 m
.54808 .98077 L
s
.57212 .01923 m
.57212 .98077 L
s
.59615 .01923 m
.59615 .98077 L
s
.62019 .01923 m
.62019 .98077 L
s
.64423 .01923 m
.64423 .98077 L
s
.66827 .01923 m
.66827 .98077 L
s
.69231 .01923 m
.69231 .98077 L
s
.71635 .01923 m
.71635 .98077 L
s
.74038 .01923 m
.74038 .98077 L
s
.76442 .01923 m
.76442 .98077 L
s
.78846 .01923 m
.78846 .98077 L
s
.8125 .01923 m
.8125 .98077 L
s
.83654 .01923 m
.83654 .98077 L
s
.86058 .01923 m
.86058 .98077 L
s
.88462 .01923 m
.88462 .98077 L
s
.90865 .01923 m
.90865 .98077 L
s
.93269 .01923 m
.93269 .98077 L
s
.95673 .01923 m
.95673 .98077 L
s
.98077 .01923 m
.98077 .98077 L
s
.01923 .01923 m
.98077 .01923 L
s
.01923 .04327 m
.98077 .04327 L
s
.01923 .06731 m
.98077 .06731 L
s
.01923 .09135 m
.98077 .09135 L
s
.01923 .11538 m
.98077 .11538 L
s
.01923 .13942 m
.98077 .13942 L
s
.01923 .16346 m
.98077 .16346 L
s
.01923 .1875 m
.98077 .1875 L
s
.01923 .21154 m
.98077 .21154 L
s
.01923 .23558 m
.98077 .23558 L
s
.01923 .25962 m
.98077 .25962 L
s
.01923 .28365 m
.98077 .28365 L
s
.01923 .30769 m
.98077 .30769 L
s
.01923 .33173 m
.98077 .33173 L
s
.01923 .35577 m
.98077 .35577 L
s
.01923 .37981 m
.98077 .37981 L
s
.01923 .40385 m
.98077 .40385 L
s
.01923 .42788 m
.98077 .42788 L
s
.01923 .45192 m
.98077 .45192 L
s
.01923 .47596 m
.98077 .47596 L
s
.01923 .5 m
.98077 .5 L
s
.01923 .52404 m
.98077 .52404 L
s
.01923 .54808 m
.98077 .54808 L
s
.01923 .57212 m
.98077 .57212 L
s
.01923 .59615 m
.98077 .59615 L
s
.01923 .62019 m
.98077 .62019 L
s
.01923 .64423 m
.98077 .64423 L
s
.01923 .66827 m
.98077 .66827 L
s
.01923 .69231 m
.98077 .69231 L
s
.01923 .71635 m
.98077 .71635 L
s
.01923 .74038 m
.98077 .74038 L
s
.01923 .76442 m
.98077 .76442 L
s
.01923 .78846 m
.98077 .78846 L
s
.01923 .8125 m
.98077 .8125 L
s
.01923 .83654 m
.98077 .83654 L
s
.01923 .86058 m
.98077 .86058 L
s
.01923 .88462 m
.98077 .88462 L
s
.01923 .90865 m
.98077 .90865 L
s
.01923 .93269 m
.98077 .93269 L
s
.01923 .95673 m
.98077 .95673 L
s
.01923 .98077 m
.98077 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{472, 224.562},
  ImageMargins->{{8, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009>000162000`400?l00000o`00003ooooooooo
oooooe3ooooo003oooooooooooooD?ooool00?oooooooooooom@ooooo`00oooooooooooooe3ooooo
003oooooooooooooD?ooool00?oooooooooooom@ooooo`00oooooooooooooe3ooooo003ooooooooo
ooooD?ooool00?oooooooooooom@ooooo`00oooooooooooooe3ooooo003oooooooooooooD?ooool0
0?oooooooooooom@ooooo`008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^;_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0^ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^033ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0`ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0<oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h^ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02kooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<?ooool2o`000009oa0@4?oooooo
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0=Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg037ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg033ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0e
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool002;ooooo00Go410@oooooooooooooooooa0@
400eooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400_ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400booooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0/ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@033ooooo00Go410@oooooooooooooooooa0@400eooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400_ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400booooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0/oooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo000Rooooo`05o`000?oooooooooo
ooooool00000=Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000<?oo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000<Oooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool00000;_ooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool00000<?ooool01Ol0003ooooooooooooooooo000003Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000033ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo0000037ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000002kooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000001;ooooo000Rooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000<Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool00000<?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool00000;_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000<?oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo0000037ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
033ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000002kooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001;ooooo000Rooooo`05oa0@4?oo
ooooooooooooool@4100=Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100<_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0;oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100;oooool00omgMgOoc<c<o`000004
ooooo`05oa0@4?ooooooooooooooool@4100<?ooool01Ol@413ooooooooooooooooo410@03Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03;ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo02oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@
413ooooooooooooooooo410@02oooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooo
oooo410@01;ooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02oooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg033ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0eooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02kooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0;oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04_ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0^ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0<?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0<?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03?ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0`ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Booooo`00oooooooooooooe3ooooo003oooooooooooooD?ooool00?oooooooooooom@oooo
o`00oooooooooooooe3ooooo000PooooooOo0000;_ooooogo`0001;ooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo013ooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`3cooooo`03o`000?oooooooooo02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo0??ooooo00?o0000ooooooooool04?ooool001Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool08_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`0@ooooo`00
5_ooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00002ooooongo00000_ooool3o`0002Co
oooo00Go410@oooooooooooooooooa0@4005ooooo`?o00000_ooooo]o`0000;ooooo0ol0000Boooo
o`005_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_oooolCo`00
00Gooooo00?o0000ooooooooool00oooool<o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo
00?ooooo3Ol00005ooooo`go00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooob[o00001Oooool7o`00
00Cooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo^?l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04?ooool001Kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00;ooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo3?l00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool0
0ol0003oooooooooo`03ooooo`go00001Oooool=o`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolZ
o`0000Gooooo1ol00004ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03oooookSo00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo000Fooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`02oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`co00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Cooooo00?o0000ooooooooool00ooo
ool7o`0000Gooooo00?o0000ooooooooool00oooool=o`0000Gooooo3Ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo:_l00005ooooo`Oo00001?ooool00ol0003oooooooooo`0Rooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooonho`0000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`005_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool00_oooolCo`0000Gooooo00?o0000ooooooooool0
0oooool<o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`00
0?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`go0000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooob[o00001Oooool7o`0000Cooooo00?o0000ooooooooool0
8_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00_ooool7o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo^?l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool001Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00;ooooo4ol00005ooooo`03
o`000?oooooooooo00?ooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo
00001?ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`go
00001Oooool=o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolZo`0000Gooooo1ol00004ooooo`03
o`000?oooooooooo02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03oooookSo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
013ooooo000Pooooo`03o`000?oooooooooo00;oooookOl00004ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooo
ooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`02oooooaWo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool<o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005oooooa?o00001?ooool00ol0003oooooooooo`03ooooo`go00001Oooool=o`0000Gooooo
3Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00?ooooo
U?l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o
0000ooooooooool00_oooolIo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001OoooolCo`0000Cooooo00?o
0000ooooooooool00oooool=o`0000Gooooo3Ol00005ooooo`go00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o
0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03oooooaoo00001Oooool00ol0003oooooooooo`03oooooiCo00001?ooool00ol0003ooooooooo
o`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol00005
ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo6Ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo4ol00004ooooo`03o`000?oooooooooo00?ooooo3Ol00005
ooooo`go00001Oooool=o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000
ooooooooool00ooooonDo`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03oooo
o`Oo00001Oooool00ol0003oooooooooo`02oooooaWo00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool<o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
oa?o00001?ooool00ol0003oooooooooo`03ooooo`go00001Oooool=o`0000Gooooo3Ol00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`go00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00?oooooU?l00004oooo
o`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000oooooooo
ool00_oooolIo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`Oo00001OoooolCo`0000Cooooo00?o0000oooooooo
ool00oooool=o`0000Gooooo3Ol00005ooooo`go00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000oooooooo
ool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooooaoo
00001Oooool00ol0003oooooooooo`03oooooiCo00001?ooool00ol0003oooooooooo`0@ooooo`00
8?ooool2o`0000?oooookOl00003ooooo`;o0000;_ooool2o`0000?oooookOl00003ooooo`;o0000
4_ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Ooo
ool00ol0003oooooooooo`03ooooobCo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3?l00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooolfo`0000Gooooo1ol00005oooooaSo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?oooooH?l00004ooooo`03o`000?oooooooooo00?oooooB?l00004ooooo`03o`000?oo
oooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool7
o`0000Gooooo00?o0000ooooooooool00ooooolTo`0000Gooooo00?o0000ooooooooool00oooool7
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`co00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo=_l00005ooooo`Oo00001OoooolH
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`go00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooof3o00001?ooool00ol0003oooooooooo`03ooooodSo00001?ooool0
0ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo9?l00005ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool<o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooocKo00001Oooool7o`00
00Gooooo6?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool=o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00ooooomPo`0000Cooooo00?o0000ooooooooool00ooooom8o`00
00Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooobCo00001Oooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolfo`0000Go
oooo1ol00005oooooaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
oooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?oooooH?l00004ooooo`03o`000?oooooooooo00?o
ooooB?l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooolTo`0000Gooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
=_l00005ooooo`Oo00001OoooolHo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooof3o00001?ooool00ol0003ooooo
ooooo`03ooooodSo00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003ooooooooo
o`02ooooongo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;oooookOl0
0004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo@_l00005
ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005
oooooaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo3Ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooomVo`0000GoooooDol00004
ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo@_l00005oooo
o`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
oaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
oaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo3Ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooomVo`0000GoooooDol00004oooo
o`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo@_l00005ooooo`03
o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooaSo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooaSo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooomVo`0000GoooooDol00004ooooo`03
o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo@_l00005ooooo`03o`00
0?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooaSo0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooaSo0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ooooomVo`0000GoooooDol00004ooooo`03o`00
0?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo@_l00005ooooo`03o`000?oo
oooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooaSo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooaSo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00ooooomVo`0000GoooooDol00004ooooo`03o`000?oo
oooooooo013ooooo000Pooooo`;o00000oooooo]o`0000?ooooo0_l0000^ooooo`;o00000oooooo]
o`0000?ooooo0_l0000Booooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo3Ol00005ooooob[o00001Oooool=o`0000Gooooo1ol00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooom2o`00
00Gooooo3Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00ooooolOo`0000GoooooV_l00004ooooo`03o`000?oooooooooo
013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Go
oooo:_l00005ooooo`go00001Oooool7o`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03oooood;o00001Oooool=o`0000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
oooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03oooooaoo00001OoooonJo`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`go00001OoooolZo`0000Gooooo
3Ol00005ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005ooooo`03o`000?oooooooooo00?ooooo@_l00005ooooo`go00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool7o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
7ol00005oooooi[o00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooob[o00001Oooool=o`0000Gooooo1ol0
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o
0000ooooooooool00ooooom2o`0000Gooooo3Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolOo`0000GoooooV_l0
0004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool=o`0000Gooooo:_l00005ooooo`go00001Oooool7o`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03
oooood;o00001Oooool=o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03oooooaoo00001OoooonJo`0000Cooooo00?o0000
ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@oooo
o`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooobCo00001Oooool7o`0000Gooooo4ol00005ooooo`03
o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00ooooomDo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooooo4o`0000Cooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`0000Gooooo1ol00005oooooa?o0000
1Oooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?oooooE?l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;oooooa?l00004ooooo`03o`00
0?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo9?l00005ooooo`Oo00001Ooo
oolCo`0000Gooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03oooooeCo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooolCo00001?oo
ool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooobCo00001Oooool7
o`0000Gooooo4ol00005ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooomDo`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooooo4
o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`00
00Gooooo1ol00005oooooa?o00001Oooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooE?l00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;oooooa?l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`;o00000oooooo]o`0000?o
oooo0_l0000^ooooo`;o00000oooooo]o`0000?ooooo0_l0000Booooo`008?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooobCo00001Oooool7o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool<o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool=o`0000Gooooo
00?o0000ooooooooool00_oooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03oooooako00001Oooool7o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooommo`0000Cooooo
C_l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool7o`0000Gooooo9?l00005ooooo`Oo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`go00001Oooool00ol0003ooooooooo
o`02oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo7_l0
0005ooooo`Oo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03oooooggo00001?oooom>o`0000Cooooo00?o
0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`Oo00001OoooolTo`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo4ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolNo`0000Gooooo1ol00004
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?oooooOOl00004ooooodko00001?ooool00ol0003oooooooooo`0@
ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
obCo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`Oo00001Oooool<o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`Oo00001Oooool=o`0000Gooooo00?o0000ooooooooool00_oooolCo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03oooooako00001Oooool7o`0000Cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ooooommo`0000CoooooC_l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool7o`0000Gooooo9?l00005ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`go
00001Oooool00ol0003oooooooooo`02oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo7_l00005ooooo`Oo00001?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooggo
00001?oooom>o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool0
0_ooooo]o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooongo0000
1?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001Ooo
oolTo`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo6?l00005ooooo`03o`000?oo
oooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
oolTo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooolWo00001?oo
ool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001OoooolT
o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo6?l00005ooooo`03o`000?oooooo
oooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolT
o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooolWo00001?ooool0
0ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001OoooolTo`00
00Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo6?l00005ooooo`03o`000?oooooooooo
00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`00
00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooolWo00001?ooool00ol0
003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001OoooolTo`0000Go
oooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooolCo`0000Gooooo6?l00005ooooo`03o`000?oooooooooo00?o
oooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`0000Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooolWo00001?ooool00ol0003o
ooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001OoooolTo`0000Gooooo
3Ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooolCo`0000Gooooo6?l00005ooooo`03o`000?oooooooooo00?ooooo
3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`0000Cooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooolWo00001?ooool00ol0003ooooo
ooooo`0@ooooo`008?ooool2o`0000?oooookOl00003ooooo`;o0000;_ooool2o`0000?oooookOl0
0003ooooo`;o00004_ooool0023ooooo00?o0000ooooooooool00_oooolfo`0000Gooooo1ol00005
ooooo`Oo00001Oooool7o`0000Gooooo00?o0000ooooooooool00_ooool[o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooooo3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@
ooooo`008?ooool00ol0003oooooooooo`02ooooocKo00001Oooool7o`0000Gooooo1ol00005oooo
o`Oo00001Oooool00ol0003oooooooooo`02ooooob_o00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo3Ol00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
ol?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03
o`000?oooooooooo00;ooooo=_l00005ooooo`Oo00001Oooool7o`0000Gooooo1ol00005ooooo`03
o`000?oooooooooo00;ooooo:ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo`ol00005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool0
0_oooolfo`0000Gooooo1ol00005ooooo`Oo00001Oooool7o`0000Gooooo00?o0000ooooooooool0
0_ooool[o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooooo3o`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooongo00001?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;oooookOl00004ooooo`03o`000?oo
oooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo:_l00005oooooa?o00001Oooool0
0ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo4ol00004ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooon/o`0000Gooooo9?l00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oooolZo`00
00Gooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolCo`00
00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooojco00001OoooolTo`00
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003o
ooooooooo`02ooooob[o00001OoooolCo`0000Gooooo00?o0000ooooooooool00oooool=o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooooaoo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02oooooa?o00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo[?l00005ooooobCo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013o
oooo000?ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo00?o0000
ooooooooool00_oooolZo`0000Gooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_oooolCo`0000Cooooo00?o0000ooooooooool06oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo[?l00005ooooobCo
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;o
oooo:_l00005oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo4ol00004ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooon/o`0000Gooooo9?l00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0017ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00002ooooongo00000_ooool3o`00
01oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00002
ooooongo00000_ooool3o`0001;ooooo000Aooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo@_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooooaWo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03oooooaSo00001?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooeOl0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0017ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_oo
oom2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo6Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00004ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooooEo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`004Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`02oooood;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ooooolIo`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0ooooolHo`0000Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooomGo00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo@_l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooooaWo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool6o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03oooooaSo00001?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?oooooeOl00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool000oo
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool00_oooom2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo6Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00004oooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooooEo`0000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00;oooookOl00004ooooo`03o`000?oooooooooo
013ooooo000Pooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooooooo00?o
oooo6?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001OoooolCo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo1ol00005ooooo`03o`000?oooooooooo00?ooooo4ol00004oooooa?o00001?ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?oooooX?l00005ooooocKo00001?ooool00ol0003o
ooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003ooooo
ooooo`03oooooaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool7o`0000Gooooo
4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03oooooa?o00001?oooolCo`0000Cooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooj3o00001Ooooolfo`0000Cooooo
00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o
0000ooooooooool00ooooolHo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol0
0005oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooolCo`0000Cooooo4ol0
0004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooonPo`0000Gooooo=_l0
0004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo3Ol00005
ooooo`03o`000?oooooooooo00?ooooo6?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`Oo00001OoooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo4ol00004
oooooa?o00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooX?l00005
ooooocKo00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02oooo
o`go00001Oooool00ol0003oooooooooo`03oooooaSo00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03oooo
oa?o00001?oooolCo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
oj3o00001Ooooolfo`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo0_l00003ooooongo
00000oooool2o`0002kooooo0_l00003ooooongo00000oooool2o`0001;ooooo000Pooooo`03o`00
0?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1_l00005oooooaWo0000
1Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool6o`0000Gooooo1ol00005oooooa?o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`00
0?oooooooooo00?ooooo3?l00005ooooo`go00001?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00;ooooo/_l00005ooooocKo00001?ooool00ol0003oooooooooo`0@ooooo`008?oo
ool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Ko00001Ooo
oolIo`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo1_l00005ooooo`Oo00001Ooo
oolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Ooo
ool00ol0003oooooooooo`03ooooo`co00001Oooool=o`0000Cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`02oooook;o00001Ooooolfo`0000Cooooo00?o0000ooooooooool04?oo
ool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6
o`0000Gooooo6Ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`Ko00001Oooool7
o`0000Gooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7
o`0000Gooooo00?o0000ooooooooool00oooool<o`0000Gooooo3Ol00004ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_oooonbo`0000Gooooo=_l00004ooooo`03o`000?oooooo
oooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1_l00005oooooaWo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool6o`00
00Gooooo1ol00005oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo3?l00005ooooo`go00001?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo/_l00005ooooocKo00001?ooool00ol0
003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Ko00001OoooolIo`0000Gooooo00?o0000ooooooooool00oooool7o`0000Go
oooo1_l00005ooooo`Oo00001OoooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`co00001Oooool=o`0000Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooook;o00001Ooooolfo`0000Co
oooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003ooooo
ooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo1ol0
0005ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`go00001Oooool7o`0000Cooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003ooooooooo
o`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo1ol00005
ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`go00001Oooool7o`0000Cooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@
ooooo`008?ooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo1ol00005oooo
o`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`go00001Oooool7o`0000Cooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@oooo
o`008?ooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo1ol00005ooooo`03
o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go
00001Oooool7o`0000Cooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@ooooo`00
8?ooool00ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo1ol00005ooooo`03o`00
0?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go0000
1Oooool7o`0000Cooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@ooooo`008?oo
ool2o`0000?oooookOl00003ooooo`;o0000;_ooool2o`0000?oooookOl00003ooooo`;o00004_oo
ool0023ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000ooooooooool00ooooolB
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_oooolCo`0000Cooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`02ooooocco00001Ooooon/o`0000Cooooo00?o0000ooooooooool04?ooool0
023ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000ooooooooool00ooooolBo`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_oooolCo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooocco00001Ooooon/o`0000Cooooo00?o0000ooooooooool04?ooool0023o
oooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000ooooooooool00ooooolBo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_oooolCo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`02ooooocco00001Ooooon/o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo
00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000ooooooooool00ooooolBo`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_oooolCo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooocco00001Ooooon/o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o
0000ooooooooool00_ooool=o`0000Gooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_oooolCo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`02ooooocco00001Ooooon/o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000
ooooooooool00_ooooo]o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02
ooooongo00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02oooo
obGo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo7_l00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool7o`0000Gooooo1ol00004ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool00_ooooo@o`0000Gooooo6?l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03
o`000?oooooooooo00;ooooo9Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Oo
00001OoooolNo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool7o`0000Cooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`02ooooom3o00001OoooolHo`0000Cooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_oooolUo`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`00
0?oooooooooo00?ooooo1ol00005oooooako00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooa?o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`Oo0000
1?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;oooood?l00005oooooaSo0000
1?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooobGo00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool7o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo7_l00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool7o`0000Gooooo1ol00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_oo
ooo@o`0000Gooooo6?l00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooo
oooo00;ooooo9Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001OoooolN
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`Oo00001Oooool7o`0000Cooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`02ooooom3o00001OoooolHo`0000Cooooo00?o0000ooooooooool04?ooool0
023ooooo0_l00003ooooongo00000oooool2o`0002kooooo0_l00003ooooongo00000oooool2o`00
01;ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00005ooooo`go00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00005ooooo`go00001Oooool7o`0000Go
oooo6?l00005ooooo`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool7o`0000Gooooo1ol00004ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool00_ooooo4o`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005ooooo`Oo00001OoooolHo`0000Gooooo
00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`Oo00001Oooool7o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooolCo00001Oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`go00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03oooooaSo00001Oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03oooooaSo00001Oooool=o`0000Gooooo1ol00005oooooaSo00001Oooool00ol0003ooooooooo
o`03oooooaoo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1ol0
0005ooooo`Oo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;oooooa?l0
0005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo3Ol0
0004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00005
ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00005
ooooo`go00001Oooool7o`0000Gooooo6?l00005ooooo`03o`000?oooooooooo00?ooooo7ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo1ol00004
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooooo4o`0000Gooooo1ol00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000
ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005oooo
o`Oo00001OoooolHo`0000Gooooo00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool7o`0000Cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`02ooooolCo00001Oooool7o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`go00001?ooool00ol0003oooooooooo`0@oooo
o`008?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;oooookOl00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`00
0?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo3Ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooooh?o0000
1Oooool00ol0003oooooooooo`03ooooodSo00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oo
oooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo3Ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooooh?o00001Ooo
ool00ol0003oooooooooo`03ooooodSo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooo
oooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo3Ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooooh?o00001Oooool0
0ol0003oooooooooo`03ooooodSo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo1ol00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo
00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo3Ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooooh?o00001Oooool00ol0
003oooooooooo`03ooooodSo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1ol00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;o
oooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo3Ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooooh?o00001Oooool00ol0003o
ooooooooo`03ooooodSo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo1ol00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`;o00000oooooo]o`0000?ooooo
0_l0000^ooooo`;o00000oooooo]o`0000?ooooo0_l0000Booooo`008?ooool00ol0003ooooooooo
o`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool<o`0000Gooooo00?o
0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo4ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool7o`0000Gooooo1ol00005ooooo`Ko00001Oooool00ol0003ooooooooo
o`03ooooo`Oo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00ooooommo`0000Gooooo00?o0000ooooooooool00ooooom2o`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000P
ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005
ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_oooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool7o`0000Gooooo1_l00005
ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03oooooggo00001Oooool00ol0003oooooooooo`03
oooood;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02oooooa?o00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooo
o`Oo00001Oooool6o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?oooooOOl00005oooo
o`03o`000?oooooooooo00?ooooo@_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool<o`0000Gooooo00?o0000oooooooo
ool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo4ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool7o`0000Gooooo1ol00005ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`Oo
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00ooooommo`0000Gooooo00?o0000ooooooooool00ooooom2o`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`00
0?oooooooooo00;oooookOl00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
0_ooooo]o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oo
ool7o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`go00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`Oo00001?oo
oolUo`0000Gooooo1ol00005ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo7_l00005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooocKo00001Ooo
oon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooo
oooo00?ooooo1ol00005ooooo`co00001Oooool=o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`Oo00001Oooool7o`0000Cooooo9Ol00005ooooo`Oo00001Oooool6
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool0
0ol0003oooooooooo`03oooooako00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolfo`0000GoooooPol00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0
003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool<o`00
00Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`00
00Gooooo1ol00004ooooobGo00001Oooool7o`0000Gooooo1_l00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00ooooolNo`00
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo=_l00005oooooh?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool000kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03oooo
o`Oo00001Oooool<o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo1ol00004ooooobGo00001Oooool7o`0000Gooooo1_l00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000oooo
ooooool00ooooolNo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Joooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolf
o`0000GoooooPol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0@ooooo`003_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oo
oooooooo00?ooooo1ol00005ooooo`co00001Oooool=o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`Oo00001Oooool7o`0000Cooooo9Ol00005ooooo`Oo00001Ooo
ool6o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Ooo
ool00ol0003oooooooooo`03oooooako00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooocKo00001Ooooon3o`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000?ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`?o00000_ooooo]o`0000;o
oooo0ol0000Mooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005oooo
o`?o00000_ooooo]o`0000;ooooo0ol0000Booooo`004?ooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool=o`00
00Gooooo00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo
00?ooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooa?o00001OoooolHo`00
00Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolHo`00
00Cooooo00?o0000ooooooooool07?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooodOo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`004Oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool=
o`0000Gooooo00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005ooooo`03o`000?oooooo
oooo00?ooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooa?o00001OoooolH
o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolH
o`0000Cooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooodOo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`004_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00oooool00ol0003oooooooooo`02ooooo`Oo00001Ooo
ool=o`0000Gooooo00?o0000ooooooooool00ooooolHo`0000Gooooo3Ol00005ooooo`03o`000?oo
oooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooa?o00001Ooo
oolHo`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
oolHo`0000Cooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooodOo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`003_ooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;o
oooo1ol00005ooooo`go00001Oooool00ol0003oooooooooo`03oooooaSo00001Oooool=o`0000Go
oooo00?o0000ooooooooool00oooool7o`0000Cooooo00?o0000ooooooooool00oooool7o`0000Go
oooo4ol00005oooooaSo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03oooooaSo00001?ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooom7o`0000Gooooo1ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
00kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`Oo00001Oooool=o`0000Gooooo00?o0000ooooooooool00ooo
oolHo`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oo
oooooooo00?ooooo1ol00005oooooa?o00001OoooolHo`0000Gooooo00?o0000ooooooooool00ooo
ool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooolHo`0000Cooooo00?o0000ooooooooool06_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooAol00005ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;oooookOl00004ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000ooooooooool0
4?ooool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00ooo
oolNo`0000Gooooo:ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03oooooa;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooomIo`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool0
0ol0003oooooooooo`03oooooako00001Oooool[o`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooeWo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo
00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo7_l00005ooooob_o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolBo`00
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?oooooFOl00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023o
oooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00ooooolNo`0000Go
oooo:ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03oooooa;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooomIo`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003ooooo
ooooo`03oooooako00001Oooool[o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooeWo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`;o00000oooooo]o`0000?ooooo0_l0
000^ooooo`;o00000oooooo]o`0000?ooooo0_l0000Booooo`008?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooaSo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00ooooolOo`0000Gooooo00?o0000ooooooooool00ooooolTo`0000Gooooo00?o0000
ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool=o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooodgo00001Oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001OoooolHo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00?ooooo9?l00005oooo
o`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo4_l00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ooooom=o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool7o`0000Gooooo6?l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03oooooaoo00001Oooool00ol0003oooooooooo`03ooooobCo
00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03oooooa;o
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`go00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?oooooCOl00005ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`00
8?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooaSo0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000ooooooooool0
0ooooolTo`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool0
0ooooolBo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooodgo00001Oooool=o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Ooo
oolHo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oo
oooooooo00?ooooo9?l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oo
oooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooom=o`0000Gooooo3Ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo013ooooo000Pooooo`03o`000?oooooooooo00;oooookOl00004ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000ooooooooool04?ooool0
023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo
00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolgo`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooa?o00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02oooooa?o00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo
00?ooooo??l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo=ol00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolCo`0000Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooocco00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo
00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooocOo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo4ol00004ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Cooooo
00?o0000ooooooooool00ooooollo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolgo`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03oooooa?o00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02oooooa?o00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo1ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo??l0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo=ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolCo`0000Cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooocco00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@
ooooo`008?ooool2o`0000?oooookOl00003ooooo`;o0000;_ooool2o`0000?oooookOl00003oooo
o`;o00004_ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`go
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005oooooaSo
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo??l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03oooooa;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go0000
1OoooolHo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooocco0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool=o`0000Gooooo6?l00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
oollo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo3Ol00005oooooaSo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo??l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooa;o00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`go00001OoooolHo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooocco00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003o
ooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
ooookOl00004ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
3Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo7ol00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo9Ol00005ooooo`Oo00001?ooool7o`0000Gooooo
1ol00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool7o`0000Gooooo
00?o0000ooooooooool00ooooolZo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00ooooolOo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00ooooolUo`0000Gooooo1ol00004ooooo`Oo00001Oooool7o`0000Cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooooooo
o`03ooooob[o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooaoo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4ol00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooobGo00001Oooool7o`0000Cooooo1ol00005ooooo`Oo00001?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo:_l00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Poooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo7ol00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo9Ol00005oooo
o`Oo00001?ooool7o`0000Gooooo1ol00004ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooolZo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool6o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool=o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03oooooa?o00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolUo`0000Gooooo1ol00004ooooo`Oo
00001Oooool7o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooob[o00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Ko
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool2o`0000?oooookOl00003ooooo`;o0000
;_ooool2o`0000?oooookOl00003ooooo`;o00004_ooool0023ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03oooooaSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Ooo
ool<o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00ooo
ool<o`0000Gooooo6Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool7o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`Oo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooob[o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo6?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`03ooooo`co00001OoooolI
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo:_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolHo`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo3?l00005oooooaWo00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool7o`00
00Gooooo00?o0000ooooooooool00ooooolZo`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooaSo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool<o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Go
oooo00?o0000ooooooooool00oooool<o`0000Gooooo6Ol00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool7o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003o
ooooooooo`03ooooob[o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo6?l00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003ooooo
ooooo`03ooooo`co00001OoooolIo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo
1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo
:_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;oooookOl0
0004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o
0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooa;o00001Oooool00ol0003oooooooooo`03ooooob_o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005
ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooom8o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo:ol00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ooooolBo`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
odSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000oooooooo
ool00oooool[o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03oooooa;o00001Oooool7o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool7o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?oooooB?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooa;o0000
1Oooool00ol0003oooooooooo`03ooooob_o00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`Oo0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ooooom8o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo:ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
oolBo`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooodSo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`;o00000oooooo]
o`0000?ooooo0_l0000^ooooo`;o00000oooooo]o`0000?ooooo0_l0000Booooo`008?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03oooooa?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?oooooB?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3?l00005ooooo`Oo00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`co00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03oooooa?o00001Ooooolfo`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooolCo`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooodSo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`co00001Oooool7o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`go00001Oooool<o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00ooooolCo`0000Gooooo=_l00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013o
oooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo4ol00004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooom8o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool<o`0000Gooooo
1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`0000Gooooo
3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo4ol00005ooooocKo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03oooooa?o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?oooooB?l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3?l0
0005ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol0
0005ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03oooooa?o00001Ooooolfo`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@
ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo4ol00005ooooo`go00001Oooool7o`0000Gooooo1_l00005oooo
o`03o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo9?l00005oooo
o`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ooooom8o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooooa?o
00001Oooool=o`0000Gooooo1ol00005ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`go
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooobCo00001Oooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooB?l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_oooolCo`0000Gooooo3Ol00005ooooo`Oo0000
1Oooool6o`0000Gooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0ooooolTo`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooodSo00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`003_oo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_oooolCo`0000Gooooo3Ol00005ooooo`Oo00001Oooool6o`0000Gooooo00?o0000oooooooo
ool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`0000Gooooo00?o0000oooooooo
ool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooB?l00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo000>ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02oooooa?o00001Oooool=o`0000Gooooo1ol0
0005ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooobCo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooom8o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool001;ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo0ol00002ooooongo
00000_ooool3o`00023ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00?ooooo0ol00002ooooongo00000_ooool3o`0001;ooooo000Aooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_oooolOo`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool7o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo7_l00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`Oo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03oooood;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo000@ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolOo`0000Gooooo3Ol00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`Oo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo7_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooood;o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Aooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_oooolOo`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool7o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo7_l0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03oooood;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo013ooooo000>ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooooaoo
00001Oooool=o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo1ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolNo`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00ooooom2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@
ooooo`003_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolOo`0000Gooooo3Ol0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo7_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo@_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo
00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003ooooooooo
o`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo7_l0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool<o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo1ol0
0005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooob[o00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooodSo00001Oooool00ol0003ooooooooo
o`03ooooo`Oo00001Oooool<o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000
ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooako00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo1ol00005
ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Oo00001OoooolZo`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool00ooooom8o`0000Gooooo00?o0000
ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Poooo
o`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ooooolNo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool00ol0003oooooooooo`03oooo
o`Oo00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo:_l00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00?oooooB?l00005oooo
o`03o`000?oooooooooo00?ooooo1ol00005ooooo`co00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`008?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo7_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool<o`0000Gooooo00?o0000oooooooo
ool00oooool7o`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooob[o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooodSo
00001Oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool<o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03oooooako00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`00
0?oooooooooo00?ooooo1ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Oo0000
1OoooolZo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0
0ooooom8o`0000Gooooo00?o0000ooooooooool00oooool7o`0000Gooooo3?l00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo013ooooo000Pooooo`;o00000oooooo]o`0000?ooooo0_l0000^ooooo`;o00000ooo
ooo]o`0000?ooooo0_l0000Booooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooolB
o`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooobCo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7
o`0000Gooooo00?o0000ooooooooool00oooool6o`0000GoooooC_l00005ooooo`03o`000?oooooo
oooo00?ooooo4ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`Oo00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo4ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo
00?ooooo1_l00005ooooodko00001Oooool00ol0003oooooooooo`03oooooa?o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003o
ooooooooo`03oooooa;o00001Oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooa?o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo9?l00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Ko00001Ooooom>o`0000Go
oooo00?o0000ooooooooool00ooooolCo`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooooolBo`0000Gooooo
1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooobCo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Gooooo
00?o0000ooooooooool00oooool6o`0000GoooooC_l00005ooooo`03o`000?oooooooooo00?ooooo
4ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol0
0005ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`Oo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolTo`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1ol0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo1_l0
0005ooooodko00001Oooool00ol0003oooooooooo`03oooooa?o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;oooookOl00004
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000
ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oooolCo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo3Ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000oooo
ooooool00oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool7o`0000GoooooJol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000oooooooo
ool00_oooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00ooooolBo`0000Gooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00ooooolBo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000GoooooJol00005ooooo`Oo
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_oooolCo`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000ooooooooool0
0oooool=o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool7o`0000GoooooJol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oo
oolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
oolBo`0000Gooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
oolBo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000GoooooJol00005ooooo`Oo00001Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?oo
ool0023ooooo00?o0000ooooooooool00_oooolCo`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000ooooooooool00oooool=
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolBo`0000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7
o`0000GoooooJol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo0_l00003ooooongo00000oooool2o`00
02kooooo0_l00003ooooongo00000oooool2o`0001;ooooo000Pooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool=o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`co00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool=o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooooooo00;oooookOl00004ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo1ol00005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool7o`0000Cooooo@_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool=o`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?oooooPol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo00001Ooo
ool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`Oo00001?oooom2o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`go00001Oooool7o`0000Gooooo00?o0000ooooooooool00_oo
ool=o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oooooo
oooo00;ooooo1ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004oooood;o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo3Ol00005ooooo`Oo00001Oooool0
0ol0003oooooooooo`02ooooo`go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooh?o00001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo1ol00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`00
00Cooooo@_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool=o`00
00Gooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo3Ol00005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?oooooPol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool7o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`Oo00001?oooom2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`go00001Oooool7o`0000Gooooo00?o0000ooooooooool00_ooool=o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooon3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`;o00000oooooo]o`0000?ooooo
0_l0000^ooooo`;o00000oooooo]o`0000?ooooo0_l0000Booooo`008?ooool00ol0003ooooooooo
o`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003ooooooooo
o`02ooooo`Oo00001Oooool00ol0003oooooooooo`03oooooa?o00001Oooool7o`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooob_o00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo7ol00004ooooo`03o`000?oooooooooo00?ooooo1ol0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?oooooVol00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000
ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000
ooooooooool00ooooolCo`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool[o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooaoo00001?ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
oooooi_o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Poooo
o`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo3Ol00005oooo
o`03o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo4ol00005oooo
o`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo:ol00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolOo`0000Cooooo00?o0000oooo
ooooool00oooool7o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooonKo`0000Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`Oo
00001Oooool00ol0003oooooooooo`03ooooo`go00001Oooool00ol0003oooooooooo`02ooooo`Oo
00001Oooool00ol0003oooooooooo`03oooooa?o00001Oooool7o`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooob_o00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo7ol00004ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?oooooVol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool0
0oooool=o`0000Gooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool0
0ooooolCo`0000Gooooo1ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool[o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooaoo0000
1?ooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooooi_o0000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oo
oooooooo00;oooookOl00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_oo
ooo]o`0000Cooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oooolO
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo4_l00005ooooo`Oo00001Oooool=
o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4ol00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?oooooVol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
023ooooo00?o0000ooooooooool00_oooolOo`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolCo`00
00Gooooo4_l00005ooooo`Oo00001Oooool=o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo4ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooVol00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oooolOo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00ooooolCo`0000Gooooo4_l00005ooooo`Oo00001Oooool=o`0000Go
oooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo4ol00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
ooooVol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo
00?o0000ooooooooool00_oooolOo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolCo`0000Gooooo
4_l00005ooooo`Oo00001Oooool=o`0000Gooooo3Ol00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
4ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?oooooVol00004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool0023ooooo00?o0000ooooooooool00_oooolOo`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00ooooolCo`0000Gooooo4_l00005ooooo`Oo00001Oooool=o`0000Gooooo3Ol0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo4ol00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?oooooVol0
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0023ooooo0_l00003
ooooongo00000oooool2o`0002kooooo0_l00003ooooongo00000oooool2o`0001;ooooo000Poooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`03oooo
oa?o00001Oooool=o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
oaoo00001Oooool7o`0000Gooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6Ol00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?oooooY_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool6o`0000Gooooo00?o0000ooooooooool00ooooolCo`0000Gooooo3Ol00005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo1ol00005ooooo`03
o`000?oooooooooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03oooooaWo00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooojKo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`go0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`00
0?oooooooooo00?ooooo4ol00005ooooo`go00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo7ol00005ooooo`Oo00001Oooool00ol0003oooooooooo`02ooooo`Oo0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0ooooolIo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00ooooonVo`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool=o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`03oooooa?o00001Ooo
ool=o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooooaoo00001Ooo
ool7o`0000Gooooo00?o0000ooooooooool00_ooool7o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo6Ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?oooooY_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo3Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6
o`0000Gooooo00?o0000ooooooooool00ooooolCo`0000Gooooo3Ol00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00ooooolOo`0000Gooooo1ol00005ooooo`03o`000?oooooo
oooo00;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03oooooaWo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooojKo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
023ooooo00?o0000ooooooooool00_ooooo]o`0000Cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooongo00001?ooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Go
oooo00?o0000ooooooooool00oooool<o`0000Gooooo00?o0000ooooooooool00ooooolCo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005oooooaoo00001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooob[o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00ooooonho`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0@ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo00?o0000ooooooooool00oooool<o`0000Gooooo
00?o0000ooooooooool00ooooolCo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`Oo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
1ol00005oooooaoo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooob[o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooonho`0000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`004?ooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`000?oooooooooo
00?ooooo3?l00005ooooo`03o`000?oooooooooo00?ooooo4ol00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool7o`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`Oo00001OoooolOo`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooooolZo`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01cooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooookSo0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Oo00001Oooool00ol0003ooooo
ooooo`03ooooo`co00001Oooool00ol0003oooooooooo`03oooooa?o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool7o`0000Gooooo7ol00004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
:_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooookSo
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000>ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00002ooooongo00000_ooool3o`0001co
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`0000;oooookOl00002oooo
o`?o00004_ooool000kooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`0Jooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0??ooooo
00?o0000ooooooooool04?ooool000kooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`0Jooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0??ooooo00?o0000ooooooooool04?ooool000oooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`0K
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo0??ooooo00?o0000ooooooooool04?ooool000oooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0013ooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooomol0000Nooooo`03ogMgMol0003ooooo00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooooOo00004_ooool00?oooooooooooom@ooooo`00oooo
oooooooooe3ooooo003oooooooooooooD?ooool00?oooooooooooom@ooooo`00oooooooooooooe3o
oooo003oooooooooooooD?ooool00?oooooooooooom@ooooo`00oooooooooooooe3ooooo003ooooo
ooooooooD?ooool00?oooooooooooom@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 589}, {279.688, 0}} -> {-0.0529704, -0.0238146, \
0.00446932, 0.00446932}, {{14.8125, 281.125}, {273, 6.625}} -> {-6.37271, \
-4.84213, 0.211845, 0.211845}, {{307.812, 574.125}, {273, 6.625}} -> \
{-56.0292, -4.84213, 0.211845, 0.211845}}],

Cell[TextData[{
  "Fig. 8.10 Realizations of the spins from Monte Carlo runs of the Ising \
model for ",
  Cell[BoxData[
      \(TraditionalForm\`k\^\(-1\) = 3\)]],
  " (left) and ",
  Cell[BoxData[
      \(TraditionalForm\`k\^\(-1\) = 2\)]],
  " (right) (above and below the critical temperature, respectively). Black \
denotes spin down, white spin up. "
}], "Caption",
  CellTags->"Fig. 8.10"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"refs", "c:31"}],

Cell[TextData[{
  StyleBox["M. Eden, \"A two-dimensional growth process\", In ",
    FontFamily->"Times New Roman"],
  StyleBox["Proceedings of Fourth Berkeley Symposium on Mathematics, \
Statistics, and Probability",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", volume 4, pages 223-239. University of California Press, \
Berkeley, 1960",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "E. M Lifshitz and  L. P. Pitaevskii, ",
  StyleBox["Physical Kinetics ",
    FontSlant->"Italic"],
  "(Pergamon Press, Oxford, 1981)"
}], "Text"],

Cell[TextData[{
  "N. Metropolis, A. W. Rosenbluth, M. N. Rosenbluth, A. H. Teller and E. \
Teller, ",
  StyleBox["Equation of state calculations by fast computing machines",
    FontSlant->"Italic"],
  ", ",
  "J. Chem. Phys. ",
  StyleBox["21",
    FontWeight->"Bold"],
  ", 1087 (1953)."
}], "Text"],

Cell[TextData[{
  "M. Newman and G. Barkema,  ",
  StyleBox["Monte Carlo Methods in Statistical Physics",
    FontSlant->"Italic"],
  " (Clarendon Press, Oxford, 2001)."
}], "Text"],

Cell[TextData[{
  "M. Plischke and B. Bergersen, ",
  StyleBox["Equilibrium Statistical Physics",
    FontSlant->"Italic"],
  " (Prentice Hall, Englewood Cliffs, New Jersey, 1989)."
}], "Text"],

Cell[TextData[{
  "F. Reif, ",
  StyleBox["Fundamentals of Statistical and Thermal Physics",
    FontSlant->"Italic"],
  " (McGraw Hill, New York, 1965)"
}], "Text"],

Cell[TextData[{
  "M. N. Rosenbluth and A. W. Rosenbluth, ",
  StyleBox["Monte Carlo calculation of the average extension of molecular \
chains",
    FontSlant->"Italic"],
  ", J. Chem. Phys.  ",
  StyleBox["23",
    FontWeight->"Bold"],
  ", 356 (1955)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->"EditBar",
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 8, Section 8.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 93, "IndexEntries" -> {{"i:1", \
"Bernoulli, Jacob"}, {"i:1", "Boltzmann, Ludwig"}, {"i:1", "Maxwell, James \
Clerk"}, {"i:12", "Decision tree"}, {"i:20", "Fokker-Planck equation"}, \
{"i:21", "Master equation"}, {"i:22", "Brownian motion"}, {"i:23", "Brown, \
Robert"}, {"i:25", "Entropy"}, {"i:26", "Irreversibility"}, {"i:27", "Poincar\
\[EAcute] recurrence"}, {"i:3", "Fick's law"}, {"i:32", "Stirling's \
formula"}, {"i:35", {"Resistivity (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Current density)"}}, {"i:36", "Langevin equation"}, {"i:38", \
"Einstein relation"}, {"i:5", "Mean free path"}, {"i:52", "Transformation \
method"}, {"i:53", "Rejection method"}, {"i:57", "Einstein relation"}, \
{"i:58", {"Free energy: ", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Irreversibility, nonuniform system"}}, {"i:6", 
  StyleBox[ "Random", FontWeight -> "Bold"]}, {"i:61", "Ensemble"}, {"i:63", 
  StyleBox[ 
  "While", FontWeight -> 
    "Bold"]}, {"i:64", "Transition probability"}, {"i:66", "Detailed \
balance"}, {"i:78", {"Percolation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Random walks, Eden model)"}}, {"i:80", "Thermal equilibrium"}, \
{"i:83", "Polymers"}, {"i:84", "Poincar\[EAcute] recurrence"}, {"i:85", \
"Metropolis, Nicholas"}, {"i:85", "Rosenbluth, Marshall"}, {"i:85", "Teller, \
Edward"}, {"i:86", "Acceptance rate"}, {"i:9", 
  StyleBox[ 
  "Mean", FontWeight -> 
    "Bold"]}, {"i:91", "Expected value"}, {"i:10", "Distribution", \
{"probability (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Probability)"}}, {"i:10", "Probability", "distribution, \
definition"}, {"i:13", "Average(s)", "position"}, {"i:14", "Average(s)", "in \
terms of probability distribution"}, {"i:15", "Average(s)", "linearity of"}, \
{"i:17", "Average(s)", "rms position, in random walk"}, {"i:18", "Diffusion", \
"coefficient, in random walk"}, {"i:2", "Thermal conductivity", {"microscopic \
model (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Diffusion)"}}, {"i:24", "Velocity", "terminal"}, {"i:28", \
"Density", {"probability (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Shroedinger's equation)"}}, {"i:28", "Probability", {"density \
(", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Density, probability)"}}, {"i:29", "Heat equation", \
{"connection to diffusion (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Diffusion, random walk)"}}, {"i:29", "Velocity", "drift, in \
Fokker Planck equation"}, {"i:31", "Average(s)", "rms position, in random \
walk"}, {"i:33", "Distribution", "Gaussian"}, {"i:34", "Distribution", \
"Poisson"}, {"i:36", "Ordinary differential equations", {"Langevin equation \
(", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Langevin equation)"}}, {"i:37", "Langevin equation", \
"finite-differenced form"}, {"i:38", "Velocity", "thermal"}, {"i:4", \
"Diffusion", "coefficient"}, {"i:40", "Diffusion", {"of velocity (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Langevin equation)"}}, {"i:42", "Equilibrium", {"thermal (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Thermal equilibrium)"}}, {"i:44", "Average(s)", "in a general \
random walk"}, {"i:45", "Probability", "conditional"}, {"i:46", "Master \
equation", "for a general random walk"}, {"i:49", "Master equation", "for \
inhomogeneous random walk"}, {"i:5", "Frequency", "collision"}, {"i:50", \
"Fokker-Planck equation", "for inhomogeneous system"}, {"i:51", \
"Fokker-Planck equation", "for inhomogeneous system"}, {"i:54", "Brownian \
motion", "in gravity"}, {"i:56", "Thermal equilibrium", {"Boltzmann \
distribution (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Distribution, Boltzmann)"}}, {"i:58", "Irreversibility", \
"nonuniform system"}, {"i:6", "Probability", "definition of"}, {"i:60", \
"Distribution", "Gibb's"}, {"i:60", "Thermal equilibrium", {"Gibb's \
distribution (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Distribution, Gibb's)"}}, {"i:62", "Probability", \
"transition"}, {"i:65", "Master equation", "in the \
Rosenbluth-Teller-Metropolis Monte-Carlo method"}, {"i:67", "Fokker-Planck \
equation", "for the Rosenbluth Teller Metropolis Monte-Carlo method"}, \
{"i:69", "Potential", "Lennard-Jones"}, {"i:7", 
  StyleBox[ "Histogram", FontWeight -> "Bold"], {
  StyleBox[ 
  " ", FontWeight -> 
    "Bold"], "function"}}, {"i:71", "Function(s)", "correlation"}, {"i:73", \
"Master equation", "solution via Fourier transforms"}, {"i:74", "Langevin \
equation", "master equation"}, {"i:74", "Master equation", {"for Langevin \
dynamics (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Langevin equation)"}}, {"i:76", "Distribution", "Maxwellain"}, \
{"i:78", "Random walk", "Eden model"}, {"i:79", "Average(s)", {
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ 
          RowBox[ {"(", "fluctuation", ")"}], "2"], 
        TraditionalForm]]], "in position (mean square change in position)"}}, \
{"i:81", "Distribution", "binomial"}, {"i:82", "Distribution", "binomial"}, \
{"i:87", "Correlation", "time"}, {"i:88", "Function(s)", "correlation"}, \
{"i:90", "Average(s)", "fluctuations in energy"}, {"i:92", "Langevin \
equation", "velocity correlations"}, {"i:16", "Average(s)", "position", ""}, \
{"i:19", "Diffusion", "coefficient, in random walk", ""}, {"i:20", "Partial \
differential equations", {"Fokker-Planck equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Fokker-Planck equation)"}, ""}, {"i:26", "Fokker-Planck \
equation", {"irreversible nature of solutions (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Irreversibility)"}, ""}, {"i:30", "Random walk", "", ""}, \
{"i:41", "Random walk", "self-avoiding", ""}, {"i:43", "Random walk", "with \
arbitrary steps", ""}, {"i:47", "Correlation", {"function (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Function(s), correlation)"}, ""}, {"i:47", "Function(s)", \
"correlation", ""}, {"i:48", "Random walk", "inhomogeneous", ""}, {"i:56", \
"Distribution", "Boltzmann", ""}, {"i:59", "Rosenbluth Teller Metropolis \
Monte-Carlo method", "", ""}, {"i:59", {"Monte-Carlo method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " The Rosenbluth Teller Metropolis Monte-Carlo method)"}, "", \
""}, {"i:68", "Rosenbluth Teller Metropolis Monte-Carlo method", "simulation \
of ideal gas", ""}, {"i:70", "Random walk", {"fluctuations from the mean (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Average(s))"}, ""}, {"i:72", "Rosenbluth Teller Metropolis \
Monte-Carlo method", "simulation for interacting classical particles", ""}, \
{"i:75", "Fokker-Planck equation", "for velocity diffusion", ""}, {"i:77", \
"Rosenbluth Teller Metropolis Monte Carlo method", "Ising model", ""}, \
{"i:77", {"Ising model (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Rosenbluith Teller Metropolis Monte Carlo method)"}, "", ""}, \
{"i:79", {"Fluctuations (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Average(s), Probability)"}, "", ""}, {"i:89", "Average(s)", \
"fluctuations in density", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(8.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(8.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(8.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(8.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(8.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UNNEQ"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, None}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["UNNEQ", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1727, 52, 71, 1, 69, "Title",
      CellTags->"c:1"]},
  "i:30"->{
    Cell[1842, 59, 65, 1, 39, "Subtitle",
      CellTags->{"i:30", "c:2"}]},
  "c:2"->{
    Cell[1842, 59, 65, 1, 39, "Subtitle",
      CellTags->{"i:30", "c:2"}]},
  "c:3"->{
    Cell[1951, 66, 60, 1, 41, "Subsubtitle",
      CellTags->"c:3"]},
  "i:3"->{
    Cell[2014, 69, 428, 11, 44, "Text",
      CellTags->"i:3"]},
  "(8.1.1)"->{
    Cell[2445, 82, 644, 19, 32, "NumberedEquation",
      CellTags->"(8.1.1)"]},
  "i:1"->{
    Cell[5005, 142, 976, 28, 78, "Text",
      CellTags->"i:1"]},
  "c:4"->{
    Cell[6018, 175, 78, 1, 30, "Subsubtitle",
      CellTags->"c:4"]},
  "c:5"->{
    Cell[6121, 180, 59, 1, 42, "Section",
      CellTags->"c:5"]},
  "i:2"->{
    Cell[6183, 183, 1201, 27, 112, "Text",
      CellTags->"i:2"]},
  "i:5"->{
    Cell[7387, 212, 1728, 55, 98, "Text",
      CellTags->"i:5"]},
  "(8.1.2)"->{
    Cell[9895, 297, 158, 5, 38, "NumberedEquation",
      CellTags->"(8.1.2)"]},
  "i:4"->{
    Cell[10056, 304, 1412, 50, 48, "Text",
      CellTags->"i:4"]},
  "c:6"->{
    Cell[12316, 373, 49, 1, 31, "Section",
      CellTags->"c:6"]},
  "i:6"->{
    Cell[12368, 376, 3230, 112, 112, "Text",
      CellTags->"i:6"]},
  "(8.1.3)"->{
    Cell[15601, 490, 177, 6, 29, "NumberedEquation",
      CellTags->"(8.1.3)"]},
  "i:91"->{
    Cell[15781, 498, 1285, 45, 78, "Text",
      CellTags->"i:91"]},
  "Cell 8.1"->{
    Cell[17480, 560, 173, 4, 67, "Input",
      CellTags->"Cell 8.1"]},
  "(8.1.4)"->{
    Cell[18868, 609, 149, 5, 33, "NumberedEquation",
      CellTags->"(8.1.4)"]},
  "Cell 8.2"->{
    Cell[19123, 621, 158, 4, 67, "Input",
      CellTags->"Cell 8.2"]},
  "Cell 8.3"->{
    Cell[19627, 640, 280, 7, 124, "Input",
      CellTags->"Cell 8.3"]},
  "Cell 8.4"->{
    Cell[20199, 662, 179, 5, 67, "Input",
      CellTags->"Cell 8.4"]},
  "Cell 8.5"->{
    Cell[43104, 1249, 137, 3, 67, "Input",
      CellTags->"Cell 8.5"]},
  "Cell 8.6"->{
    Cell[43436, 1264, 264, 6, 86, "Input",
      CellTags->"Cell 8.6"]},
  "i:7"->{
    Cell[1648572, 43482, 772, 20, 78, "Text",
      CellTags->"i:7"]},
  "(8.1.5)"->{
    Cell[1649347, 43504, 121, 2, 31, "NumberedEquation",
      CellTags->"(8.1.5)"]},
  "Cell 8.7"->{
    Cell[1651083, 43571, 208, 6, 86, "Input",
      CellTags->"Cell 8.7"]},
  "Cell 8.8"->{
    Cell[1652162, 43609, 686, 14, 238, "Input",
      CellTags->"Cell 8.8"]},
  "i:10"->{
    Cell[3693914, 110522, 1119, 29, 112, "Text",
      CellTags->"i:10"]},
  "(8.1.6)"->{
    Cell[3695036, 110553, 198, 6, 29, "NumberedEquation",
      CellTags->"(8.1.6)"]},
  "(8.1.7)"->{
    Cell[3695420, 110569, 136, 5, 32, "NumberedEquation",
      CellTags->"(8.1.7)"]},
  "i:13"->{
    Cell[3697287, 110633, 73, 1, 27, "Text",
      CellTags->"i:13"]},
  "(8.1.8)"->{
    Cell[3697363, 110636, 388, 12, 40, "NumberedEquation",
      CellTags->"(8.1.8)"]},
  "i:9"->{
    Cell[3697754, 110650, 982, 32, 78, "Text",
      CellTags->"i:9"]},
  "Cell 8.9"->{
    Cell[3698761, 110686, 360, 9, 143, "Input",
      CellTags->"Cell 8.9"]},
  "(8.1.9)"->{
    Cell[3724483, 111342, 176, 6, 29, "NumberedEquation",
      CellTags->"(8.1.9)"]},
  "i:31"->{
    Cell[3724727, 111352, 368, 11, 31, "Text",
      CellTags->"i:31"]},
  "(8.1.10)"->{
    Cell[3725098, 111365, 459, 15, 40, "NumberedEquation",
      CellTags->"(8.1.10)"]},
  "Cell 8.10"->{
    Cell[3726307, 111405, 110, 3, 67, "Input",
      CellTags->"Cell 8.10"]},
  "Fig. 8.1"->{
    Cell[3754141, 112109, 148, 4, 16, "Caption",
      CellTags->"Fig. 8.1"]},
  "i:81"->{
    Cell[3756006, 112167, 73, 1, 31, "Section",
      CellTags->{"i:81", "c:7"}]},
  "c:7"->{
    Cell[3756006, 112167, 73, 1, 31, "Section",
      CellTags->{"i:81", "c:7"}]},
  "i:12"->{
    Cell[3756082, 112170, 1381, 35, 129, "Text",
      CellTags->"i:12"]},
  "(8.1.11)"->{
    Cell[3757736, 112218, 307, 9, 42, "NumberedEquation",
      CellTags->"(8.1.11)"]},
  "Fig. 8.2"->{
    Cell[3885180, 113868, 297, 10, 16, "Caption",
      CellTags->"Fig. 8.2"]},
  "(8.1.12)"->{
    Cell[3885917, 113897, 122, 2, 27, "NumberedEquation",
      CellTags->"(8.1.12)"]},
  "(8.1.13)"->{
    Cell[3886065, 113903, 140, 5, 29, "NumberedEquation",
      CellTags->"(8.1.13)"]},
  "(8.1.14)"->{
    Cell[3886512, 113923, 138, 5, 29, "NumberedEquation",
      CellTags->"(8.1.14)"]},
  "(8.1.15)"->{
    Cell[3890006, 114044, 369, 12, 41, "NumberedEquation",
      CellTags->"(8.1.15)"]},
  "(8.1.16)"->{
    Cell[3891449, 114097, 283, 10, 29, "NumberedEquation",
      CellTags->"(8.1.16)"]},
  "i:82"->{
    Cell[3891735, 114109, 578, 19, 44, "Text",
      CellTags->"i:82"]},
  "Cell 8.11"->{
    Cell[3892338, 114132, 703, 17, 238, "Input",
      CellTags->"Cell 8.11"]},
  "c:8"->{
    Cell[5064866, 177041, 46, 1, 31, "Section",
      CellTags->"c:8"]},
  "(8.1.17)"->{
    Cell[5065642, 177068, 409, 12, 38, "NumberedEquation",
      CellTags->"(8.1.17)"]},
  "i:14"->{
    Cell[5068275, 177154, 362, 9, 31, "NumberedEquation",
      CellTags->{"i:14", "(8.1.18)"}]},
  "(8.1.18)"->{
    Cell[5068275, 177154, 362, 9, 31, "NumberedEquation",
      CellTags->{"i:14", "(8.1.18)"}]},
  "(8.1.19)"->{
    Cell[5069436, 177191, 665, 18, 27, "NumberedEquation",
      CellTags->"(8.1.19)"]},
  "i:15"->{
    Cell[5070104, 177211, 83, 1, 27, "Text",
      CellTags->"i:15"]},
  "(8.1.20)"->{
    Cell[5071199, 177249, 283, 7, 51, "NumberedEquation",
      CellTags->"(8.1.20)"]},
  "(8.1.21)"->{
    Cell[5071767, 177269, 221, 6, 33, "NumberedEquation",
      CellTags->"(8.1.21)"]},
  "(8.1.22)"->{
    Cell[5072486, 177295, 187, 6, 32, "NumberedEquation",
      CellTags->"(8.1.22)"]},
  "(8.1.23)"->{
    Cell[5073701, 177338, 1554, 42, 29, "NumberedEquation",
      CellTags->"(8.1.23)"]},
  "(8.1.24)"->{
    Cell[5076168, 177413, 725, 19, 77, "NumberedEquation",
      CellTags->"(8.1.24)"]},
  "(8.1.25)"->{
    Cell[5077409, 177450, 606, 16, 51, "NumberedEquation",
      CellTags->"(8.1.25)"]},
  "i:16"->{
    Cell[5078867, 177498, 761, 23, 29, "NumberedEquation",
      CellTags->{"i:16", "(8.1.26)"}]},
  "(8.1.26)"->{
    Cell[5078867, 177498, 761, 23, 29, "NumberedEquation",
      CellTags->{"i:16", "(8.1.26)"}]},
  "(8.1.27)"->{
    Cell[5080673, 177560, 511, 16, 38, "NumberedEquation",
      CellTags->"(8.1.27)"]},
  "(8.1.28)"->{
    Cell[5081983, 177605, 1955, 50, 33, "NumberedEquation",
      CellTags->"(8.1.28)"]},
  "i:17"->{
    Cell[5086196, 177716, 788, 23, 33, "NumberedEquation",
      CellTags->{"i:17", "(8.1.29)"}]},
  "(8.1.29)"->{
    Cell[5086196, 177716, 788, 23, 33, "NumberedEquation",
      CellTags->{"i:17", "(8.1.29)"}]},
  "i:18"->{
    Cell[5088237, 177788, 603, 20, 33, "NumberedEquation",
      CellTags->{"i:18", "(8.1.30)"}]},
  "(8.1.30)"->{
    Cell[5088237, 177788, 603, 20, 33, "NumberedEquation",
      CellTags->{"i:18", "(8.1.30)"}]},
  "i:79"->{
    Cell[5089786, 177840, 1505, 43, 69, "Text",
      CellTags->"i:79"]},
  "(8.1.31)"->{
    Cell[5091294, 177885, 2085, 55, 59, "NumberedEquation",
      CellTags->"(8.1.31)"]},
  "i:19"->{
    Cell[5093407, 177944, 151, 5, 30, "NumberedEquation",
      CellTags->{"i:19", "(8.1.32)"}]},
  "(8.1.32)"->{
    Cell[5093407, 177944, 151, 5, 30, "NumberedEquation",
      CellTags->{"i:19", "(8.1.32)"}]},
  "c:9"->{
    Cell[5094450, 177982, 111, 4, 31, "Section",
      CellTags->"c:9"]},
  "i:21"->{
    Cell[5094586, 177990, 64, 1, 27, "Subsubsection",
      CellTags->"i:21"]},
  "(8.1.33)"->{
    Cell[5096205, 178044, 702, 21, 29, "NumberedEquation",
      CellTags->"(8.1.33)"]},
  "(8.1.34)"->{
    Cell[5099867, 178164, 189, 4, 27, "NumberedEquation",
      CellTags->"(8.1.34)"]},
  "i:28"->{
    Cell[5100789, 178195, 1296, 45, 61, "Text",
      CellTags->"i:28"]},
  "(8.1.35)"->{
    Cell[5102088, 178242, 354, 11, 30, "NumberedEquation",
      CellTags->"(8.1.35)"]},
  "(8.1.36)"->{
    Cell[5103158, 178278, 204, 6, 34, "NumberedEquation",
      CellTags->"(8.1.36)"]},
  "(8.1.37)"->{
    Cell[5103476, 178291, 199, 6, 32, "NumberedEquation",
      CellTags->"(8.1.37)"]},
  "(8.1.38)"->{
    Cell[5104172, 178316, 915, 24, 29, "NumberedEquation",
      CellTags->"(8.1.38)"]},
  "(8.1.39)"->{
    Cell[5107512, 178415, 864, 23, 42, "NumberedEquation",
      CellTags->"(8.1.39)"]},
  "i:20"->{
    Cell[5108379, 178440, 649, 20, 44, "Text",
      CellTags->"i:20"]},
  "(8.1.40)"->{
    Cell[5109031, 178462, 278, 7, 43, "NumberedEquation",
      CellTags->"(8.1.40)"]},
  "i:29"->{
    Cell[5109312, 178471, 2173, 65, 99, "Text",
      CellTags->"i:29"]},
  "i:24"->{
    Cell[5112190, 178551, 158, 6, 29, "NumberedEquation",
      CellTags->{"i:24", "(8.1.41)"}]},
  "(8.1.41)"->{
    Cell[5112190, 178551, 158, 6, 29, "NumberedEquation",
      CellTags->{"i:24", "(8.1.41)"}]},
  "i:22"->{
    Cell[5112351, 178559, 340, 10, 44, "Text",
      CellTags->"i:22"]},
  "i:23"->{
    Cell[5112694, 178571, 528, 10, 78, "Text",
      CellTags->"i:23"]},
  "i:25"->{
    Cell[5119913, 178777, 260, 7, 44, "Text",
      CellTags->"i:25"]},
  "(8.1.42)"->{
    Cell[5120176, 178786, 239, 7, 31, "NumberedEquation",
      CellTags->"(8.1.42)"]},
  "(8.1.43)"->{
    Cell[5120630, 178803, 151, 3, 27, "NumberedEquation",
      CellTags->"(8.1.43)"]},
  "(8.1.44)"->{
    Cell[5123490, 178889, 260, 4, 45, "NumberedEquation",
      CellTags->"(8.1.44)"]},
  "i:26"->{
    Cell[5123753, 178895, 677, 17, 95, "Text",
      CellTags->"i:26"]},
  "i:27"->{
    Cell[5126204, 178952, 785, 19, 95, "Text",
      CellTags->"i:27"]},
  "c:10"->{
    Cell[5130273, 179065, 65, 1, 30, "Subsubtitle",
      CellTags->"c:10"]},
  "(8.1.45)"->{
    Cell[5136010, 179245, 284, 8, 41, "NumberedEquation",
      CellTags->"(8.1.45)"]},
  "i:32"->{
    Cell[5137333, 179293, 240, 10, 27, "Text",
      CellTags->"i:32"]},
  "(8.1.46)"->{
    Cell[5137576, 179305, 216, 7, 29, "NumberedEquation",
      CellTags->"(8.1.46)"]},
  "(8.1.47)"->{
    Cell[5138825, 179357, 220, 7, 36, "NumberedEquation",
      CellTags->"(8.1.47)"]},
  "i:33"->{
    Cell[5139048, 179366, 361, 12, 44, "Text",
      CellTags->"i:33"]},
  "(8.1.48)"->{
    Cell[5142546, 179498, 226, 8, 44, "NumberedEquation",
      CellTags->"(8.1.48)"]},
  "i:34"->{
    Cell[5142775, 179508, 507, 22, 27, "Text",
      CellTags->"i:34"]},
  "i:35"->{
    Cell[5146825, 179660, 1213, 38, 81, "Text",
      CellTags->"i:35"]},
  "i:36"->{
    Cell[5152178, 179825, 2745, 75, 138, "Text",
      CellTags->"i:36"]},
  "(8.1.49)"->{
    Cell[5154926, 179902, 554, 17, 42, "NumberedEquation",
      CellTags->"(8.1.49)"]},
  "i:37"->{
    Cell[5155483, 179921, 531, 16, 27, "Text",
      CellTags->"i:37"]},
  "(8.1.50)"->{
    Cell[5161627, 180133, 1054, 31, 45, "NumberedEquation",
      CellTags->"(8.1.50)"]},
  "i:40"->{
    Cell[5162684, 180166, 2140, 65, 72, "Text",
      CellTags->"i:40"]},
  "i:38"->{
    Cell[5164827, 180233, 901, 29, 65, "Text",
      CellTags->"i:38"]},
  "(8.1.51)"->{
    Cell[5165731, 180264, 146, 5, 29, "NumberedEquation",
      CellTags->"(8.1.51)"]},
  "i:84"->{
    Cell[5168848, 180368, 779, 20, 95, "Text",
      CellTags->"i:84"]},
  "i:83"->{
    Cell[5170802, 180431, 1040, 25, 112, "Text",
      CellTags->"i:83"]},
  "i:41"->{
    Cell[5173777, 180515, 542, 12, 78, "Text",
      CellTags->"i:41"]},
  "Fig. 8.3"->{
    Cell[5195788, 181047, 142, 4, 16, "Caption",
      CellTags->"Fig. 8.3"]},
  "c:11"->{
    Cell[5201082, 181207, 63, 1, 40, "Subtitle",
      CellTags->"c:11"]},
  "i:43"->{
    Cell[5201189, 181214, 92, 1, 41, "Subsubtitle",
      CellTags->{"i:43", "c:12"}]},
  "c:12"->{
    Cell[5201189, 181214, 92, 1, 41, "Subsubtitle",
      CellTags->{"i:43", "c:12"}]},
  "i:44"->{
    Cell[5201306, 181219, 57, 1, 42, "Section",
      CellTags->{"i:44", "c:13"}]},
  "c:13"->{
    Cell[5201306, 181219, 57, 1, 42, "Section",
      CellTags->{"i:44", "c:13"}]},
  "i:64"->{
    Cell[5201366, 181222, 593, 16, 61, "Text",
      CellTags->"i:64"]},
  "(8.2.1)"->{
    Cell[5201962, 181240, 175, 6, 34, "NE2",
      CellTags->"(8.2.1)"]},
  "(8.2.2)"->{
    Cell[5204598, 181328, 240, 7, 29, "NE2",
      CellTags->"(8.2.2)"]},
  "(8.2.3)"->{
    Cell[5206037, 181375, 771, 19, 32, "NE2",
      CellTags->"(8.2.3)"]},
  "(8.2.4)"->{
    Cell[5210357, 181504, 488, 16, 29, "NE2",
      CellTags->"(8.2.4)"]},
  "(8.2.5)"->{
    Cell[5214783, 181636, 796, 23, 33, "NE2",
      CellTags->"(8.2.5)"]},
  "(8.2.6)"->{
    Cell[5217160, 181713, 927, 27, 33, "NE2",
      CellTags->"(8.2.6)"]},
  "(8.2.7)"->{
    Cell[5218888, 181769, 680, 18, 42, "NE2",
      CellTags->"(8.2.7)"]},
  "i:45"->{
    Cell[5220193, 181811, 96, 1, 31, "Section",
      CellTags->{"i:45", "c:14"}]},
  "c:14"->{
    Cell[5220193, 181811, 96, 1, 31, "Section",
      CellTags->{"i:45", "c:14"}]},
  "(8.2.8)"->{
    Cell[5221526, 181854, 143, 5, 29, "NE2",
      CellTags->"(8.2.8)"]},
  "(8.2.9)"->{
    Cell[5223816, 181928, 149, 5, 29, "NE2",
      CellTags->"(8.2.9)"]},
  "(8.2.10)"->{
    Cell[5227147, 182037, 253, 8, 31, "NE2",
      CellTags->"(8.2.10)"]},
  "i:46"->{
    Cell[5229945, 182126, 1132, 35, 79, "Text",
      CellTags->"i:46"]},
  "(8.2.11)"->{
    Cell[5231080, 182163, 250, 7, 31, "NE2",
      CellTags->"(8.2.11)"]},
  "i:47"->{
    Cell[5231530, 182181, 70, 1, 31, "Section",
      CellTags->{"i:47", "c:15"}]},
  "c:15"->{
    Cell[5231530, 182181, 70, 1, 31, "Section",
      CellTags->{"i:47", "c:15"}]},
  "(8.2.12)"->{
    Cell[5231984, 182200, 1757, 45, 42, "NE2",
      CellTags->"(8.2.12)"]},
  "i:48"->{
    Cell[5243224, 182525, 75, 1, 31, "Section",
      CellTags->{"i:48", "c:16"}]},
  "c:16"->{
    Cell[5243224, 182525, 75, 1, 31, "Section",
      CellTags->{"i:48", "c:16"}]},
  "i:49"->{
    Cell[5244483, 182564, 709, 19, 63, "Text",
      CellTags->"i:49"]},
  "(8.2.13)"->{
    Cell[5245195, 182585, 268, 6, 31, "NE2",
      CellTags->"(8.2.13)"]},
  "i:50"->{
    Cell[5247206, 182646, 388, 13, 27, "Text",
      CellTags->"i:50"]},
  "(8.2.14)"->{
    Cell[5247597, 182661, 306, 8, 39, "NE2",
      CellTags->"(8.2.14)"]},
  "(8.2.15)"->{
    Cell[5248025, 182676, 769, 21, 33, "NE2",
      CellTags->"(8.2.15)"]},
  "(8.2.16)"->{
    Cell[5248857, 182701, 788, 21, 31, "NE2",
      CellTags->"(8.2.16)"]},
  "(8.2.17)"->{
    Cell[5250691, 182759, 209, 8, 38, "NE2",
      CellTags->"(8.2.17)"]},
  "i:51"->{
    Cell[5250903, 182769, 244, 9, 27, "Text",
      CellTags->"i:51"]},
  "(8.2.18)"->{
    Cell[5251150, 182780, 254, 4, 39, "NE2",
      CellTags->"(8.2.18)"]},
  "c:17"->{
    Cell[5252037, 182805, 60, 1, 30, "Subsubtitle",
      CellTags->"c:17"]},
  "i:52"->{
    Cell[5252816, 182828, 70, 1, 42, "Section",
      CellTags->{"i:52", "c:18"}]},
  "c:18"->{
    Cell[5252816, 182828, 70, 1, 42, "Section",
      CellTags->{"i:52", "c:18"}]},
  "(8.2.19)"->{
    Cell[5254582, 182882, 179, 6, 29, "NE2",
      CellTags->"(8.2.19)"]},
  "(8.2.20)"->{
    Cell[5254799, 182892, 170, 6, 29, "NE2",
      CellTags->"(8.2.20)"]},
  "(8.2.21)"->{
    Cell[5255536, 182921, 200, 7, 32, "NE2",
      CellTags->"(8.2.21)"]},
  "Fig. 8.4"->{
    Cell[5281241, 183577, 289, 12, 22, "Caption",
      CellTags->"Fig. 8.4"]},
  "Cell 8.12"->{
    Cell[5282736, 183632, 649, 15, 223, "Input",
      CellTags->"Cell 8.12"]},
  "i:53"->{
    Cell[5364385, 185386, 65, 1, 31, "Section",
      CellTags->{"i:53", "c:19"}]},
  "c:19"->{
    Cell[5364385, 185386, 65, 1, 31, "Section",
      CellTags->{"i:53", "c:19"}]},
  "Cell 8.13"->{
    Cell[5366925, 185479, 249, 6, 124, "Input",
      CellTags->"Cell 8.13"]},
  "Cell 8.14"->{
    Cell[5368279, 185521, 161, 4, 67, "Input",
      CellTags->"Cell 8.14"]},
  "i:63"->{
    Cell[5368443, 185527, 903, 29, 61, "Text",
      CellTags->"i:63"]},
  "Fig. 8.5"->{
    Cell[8473744, 228399, 255, 7, 16, "Caption",
      CellTags->"Fig. 8.5"]},
  "Cell 8.15"->{
    Cell[8475078, 228446, 199, 5, 105, "Input",
      CellTags->"Cell 8.15"]},
  "Cell 8.16"->{
    Cell[8475600, 228466, 158, 4, 86, "Input",
      CellTags->"Cell 8.16"]},
  "c:20"->{
    Cell[8592186, 230693, 81, 1, 31, "Section",
      CellTags->"c:20"]},
  "(8.2.22)"->{
    Cell[8592573, 230708, 271, 6, 40, "NE2",
      CellTags->"(8.2.22)"]},
  "Cell 8.17"->{
    Cell[8593271, 230735, 486, 12, 195, "Input",
      CellTags->"Cell 8.17"]},
  "Cell 8.18"->{
    Cell[8624656, 231481, 1364, 27, 352, "Input",
      CellTags->"Cell 8.18"]},
  "Fig. 8.6"->{
    Cell[9149812, 260122, 144, 4, 16, "Caption",
      CellTags->"Fig. 8.6"]},
  "i:54"->{
    Cell[9150069, 260133, 62, 1, 29, "Subsubsection",
      CellTags->"i:54"]},
  "(8.2.23)"->{
    Cell[9150927, 260161, 345, 8, 40, "NE2",
      CellTags->"(8.2.23)"]},
  "Cell 8.19"->{
    Cell[9153356, 260250, 1766, 35, 518, "Input",
      CellTags->"Cell 8.19"]},
  "Cell 8.20"->{
    Cell[9601184, 285789, 278, 6, 105, "Input",
      CellTags->"Cell 8.20"]},
  "i:80"->{
    Cell[9631224, 286593, 410, 11, 61, "Text",
      CellTags->"i:80"]},
  "i:42"->{
    Cell[9631695, 286611, 78, 1, 30, "Subsubtitle",
      CellTags->{"i:42", "c:21"}]},
  "c:21"->{
    Cell[9631695, 286611, 78, 1, 30, "Subsubtitle",
      CellTags->{"i:42", "c:21"}]},
  "i:56"->{
    Cell[9631798, 286616, 75, 1, 42, "Section",
      CellTags->{"i:56", "c:22"}]},
  "c:22"->{
    Cell[9631798, 286616, 75, 1, 42, "Section",
      CellTags->{"i:56", "c:22"}]},
  "(8.2.24)"->{
    Cell[9634649, 286710, 449, 10, 70, "NE2",
      CellTags->"(8.2.24)"]},
  "(8.2.25)"->{
    Cell[9635809, 286741, 304, 8, 35, "NE2",
      CellTags->"(8.2.25)"]},
  "i:57"->{
    Cell[9636372, 286764, 67, 1, 31, "Section",
      CellTags->{"i:57", "c:23"}]},
  "c:23"->{
    Cell[9636372, 286764, 67, 1, 31, "Section",
      CellTags->{"i:57", "c:23"}]},
  "(8.2.26)"->{
    Cell[9637200, 286791, 209, 6, 42, "NE2",
      CellTags->"(8.2.26)"]},
  "(8.2.27)"->{
    Cell[9638133, 286820, 189, 4, 42, "NE2",
      CellTags->"(8.2.27)"]},
  "(8.2.28)"->{
    Cell[9638687, 286839, 139, 5, 43, "NE2",
      CellTags->"(8.2.28)"]},
  "i:58"->{
    Cell[9639943, 286879, 84, 1, 31, "Section",
      CellTags->{"i:58", "c:24"}]},
  "c:24"->{
    Cell[9639943, 286879, 84, 1, 31, "Section",
      CellTags->{"i:58", "c:24"}]},
  "(8.2.29)"->{
    Cell[9640443, 286896, 661, 16, 31, "NE2",
      CellTags->"(8.2.29)"]},
  "(8.2.30)"->{
    Cell[9641324, 286922, 321, 5, 45, "NE2",
      CellTags->"(8.2.30)"]},
  "c:25"->{
    Cell[9642386, 286948, 66, 1, 31, "Section",
      CellTags->"c:25"]},
  "(8.2.31)"->{
    Cell[9643015, 286970, 198, 6, 32, "NE2",
      CellTags->"(8.2.31)"]},
  "Cell 8.21"->{
    Cell[9644772, 287023, 723, 15, 219, "Input",
      CellTags->"Cell 8.21"]},
  "Fig. 8.7"->{
    Cell[9744439, 289212, 444, 13, 29, "Caption",
      CellTags->"Fig. 8.7"]},
  "c:30"->{
    Cell[9744932, 289231, 65, 1, 30, "Subsubtitle",
      CellTags->"c:30"]},
  "i:73"->{
    Cell[9748205, 289326, 438, 12, 44, "Text",
      CellTags->"i:73"]},
  "(8.2.32)"->{
    Cell[9748646, 289340, 242, 7, 38, "NE2",
      CellTags->"(8.2.32)"]},
  "(8.2.33)"->{
    Cell[9749869, 289389, 442, 14, 40, "NE2",
      CellTags->"(8.2.33)"]},
  "i:92"->{
    Cell[9751819, 289456, 1448, 48, 61, "Text",
      CellTags->"i:92"]},
  "i:74"->{
    Cell[9762723, 289828, 449, 15, 44, "Text",
      CellTags->"i:74"]},
  "i:75"->{
    Cell[9763457, 289854, 521, 17, 69, "Text",
      CellTags->"i:75"]},
  "(8.2.34)"->{
    Cell[9763981, 289873, 242, 4, 42, "NE2",
      CellTags->"(8.2.34)"]},
  "i:76"->{
    Cell[9764901, 289902, 432, 16, 51, "Text",
      CellTags->"i:76"]},
  "(8.2.35)"->{
    Cell[9770623, 290089, 309, 6, 42, "NE2",
      CellTags->"(8.2.35)"]},
  "i:78"->{
    Cell[9774447, 290215, 1322, 28, 163, "Text",
      CellTags->"i:78"]},
  "Cell 8.22"->{
    Cell[9775772, 290245, 110, 3, 67, "Input",
      CellTags->"Cell 8.22"]},
  "Cell 8.23"->{
    Cell[9775977, 290255, 153, 4, 67, "Input",
      CellTags->"Cell 8.23"]},
  "Cell 8.24"->{
    Cell[9776509, 290275, 234, 7, 86, "Input",
      CellTags->"Cell 8.24"]},
  "Cell 8.25"->{
    Cell[9776841, 290289, 163, 4, 67, "Input",
      CellTags->"Cell 8.25"]},
  "Cell 8.26"->{
    Cell[9777294, 290302, 1127, 25, 219, "Input",
      CellTags->"Cell 8.26"]},
  "Fig. 8.8"->{
    Cell[9912677, 294733, 337, 10, 29, "Caption",
      CellTags->"Fig. 8.8"]},
  "i:59"->{
    Cell[9913063, 294749, 137, 2, 74, "Subtitle",
      CellTags->{"i:59", "c:26"}]},
  "c:26"->{
    Cell[9913063, 294749, 137, 2, 74, "Subtitle",
      CellTags->{"i:59", "c:26"}]},
  "c:27"->{
    Cell[9913244, 294757, 55, 1, 41, "Subsubtitle",
      CellTags->"c:27"]},
  "i:60"->{
    Cell[9913302, 294760, 2269, 63, 129, "Text",
      CellTags->"i:60"]},
  "(8.3.1)"->{
    Cell[9915574, 294825, 2710, 71, 32, "NE3",
      CellTags->"(8.3.1)"]},
  "(8.3.2)"->{
    Cell[9921011, 294974, 2515, 59, 33, "NE3",
      CellTags->"(8.3.2)"]},
  "i:61"->{
    Cell[9923529, 295035, 2898, 85, 112, "Text",
      CellTags->"i:61"]},
  "(8.3.3)"->{
    Cell[9929505, 295212, 6270, 154, 57, "NE3",
      CellTags->"(8.3.3)"]},
  "(8.3.4)"->{
    Cell[9936845, 295401, 2385, 60, 31, "NE3",
      CellTags->"(8.3.4)"]},
  "(8.3.5)"->{
    Cell[9939335, 295468, 878, 24, 34, "NE3",
      CellTags->"(8.3.5)"]},
  "i:85"->{
    Cell[9943431, 295589, 2189, 54, 180, "Text",
      CellTags->"i:85"]},
  "i:62"->{
    Cell[9949083, 295751, 3343, 103, 97, "Text",
      CellTags->"i:62"]},
  "(8.3.6)"->{
    Cell[9952429, 295856, 2193, 65, 30, "NE3",
      CellTags->"(8.3.6)"]},
  "(8.3.7)"->{
    Cell[9955663, 295956, 681, 20, 31, "NE3",
      CellTags->"(8.3.7)"]},
  "i:65"->{
    Cell[9956836, 295997, 2567, 70, 69, "Text",
      CellTags->"i:65"]},
  "(8.3.8)"->{
    Cell[9966160, 296271, 5500, 131, 32, "NE3",
      CellTags->"(8.3.8)"]},
  "(8.3.9)"->{
    Cell[9976132, 296534, 2965, 87, 30, "NE3",
      CellTags->"(8.3.9)"]},
  "(8.3.10)"->{
    Cell[9980469, 296668, 2272, 67, 32, "NE3",
      CellTags->"(8.3.10)"]},
  "i:66"->{
    Cell[9982744, 296737, 5394, 171, 66, "Text",
      CellTags->"i:66"]},
  "(8.3.11)"->{
    Cell[9989304, 296943, 6122, 146, 53, "NE3",
      CellTags->"(8.3.11)"]},
  "i:67"->{
    Cell[10030578, 298100, 1518, 38, 40, "NE3",
      CellTags->{"i:67", "(8.3.12)"}]},
  "(8.3.12)"->{
    Cell[10030578, 298100, 1518, 38, 40, "NE3",
      CellTags->{"i:67", "(8.3.12)"}]},
  "(8.3.13)"->{
    Cell[10037200, 298299, 319, 8, 27, "NE3",
      CellTags->"(8.3.13)"]},
  "(8.3.14)"->{
    Cell[10037709, 298319, 1117, 31, 30, "NE3",
      CellTags->"(8.3.14)"]},
  "c:32"->{
    Cell[10039986, 298388, 101, 4, 30, "Subsubtitle",
      CellTags->"c:32"]},
  "c:28"->{
    Cell[10040112, 298396, 70, 1, 42, "Section",
      CellTags->"c:28"]},
  "i:68"->{
    Cell[10040207, 298401, 67, 1, 27, "Subsubsection",
      CellTags->"i:68"]},
  "Cell 8.27"->{
    Cell[10041861, 298455, 179, 4, 86, "Input",
      CellTags->"Cell 8.27"]},
  "Cell 8.28"->{
    Cell[10043128, 298495, 1455, 30, 257, "Input",
      CellTags->"Cell 8.28"]},
  "i:86"->{
    Cell[10044586, 298527, 2020, 55, 146, "Text",
      CellTags->"i:86"]},
  "Cell 8.29"->{
    Cell[10046794, 298592, 101, 3, 67, "Input",
      CellTags->"Cell 8.29"]},
  "Cell 8.30"->{
    Cell[10046968, 298599, 192, 4, 86, "Input",
      CellTags->"Cell 8.30"]},
  "Cell 8.31"->{
    Cell[10047642, 298624, 135, 3, 67, "Input",
      CellTags->"Cell 8.31"]},
  "Cell 8.32"->{
    Cell[10047936, 298636, 154, 4, 67, "Input",
      CellTags->"Cell 8.32"]},
  "Cell 8.33"->{
    Cell[10048261, 298649, 188, 5, 86, "Input",
      CellTags->"Cell 8.33"]},
  "Cell 8.34"->{
    Cell[10048658, 298667, 326, 8, 124, "Input",
      CellTags->"Cell 8.34"]},
  "Cell 8.35"->{
    Cell[10049310, 298691, 263, 7, 86, "Input",
      CellTags->"Cell 8.35"]},
  "Cell 8.36"->{
    Cell[11516070, 336178, 324, 8, 105, "Input",
      CellTags->"Cell 8.36"]},
  "Cell 8.37"->{
    Cell[11555565, 337166, 121, 3, 67, "Input",
      CellTags->"Cell 8.37"]},
  "(8.3.15)"->{
    Cell[11555854, 337180, 488, 10, 33, "NE3",
      CellTags->"(8.3.15)"]},
  "i:70"->{
    Cell[11556870, 337213, 155, 4, 29, "Subsubsection",
      CellTags->"i:70"]},
  "i:90"->{
    Cell[11557028, 337219, 1254, 37, 53, "Text",
      CellTags->"i:90"]},
  "Cell 8.38"->{
    Cell[11558307, 337260, 168, 4, 67, "Input",
      CellTags->"Cell 8.38"]},
  "(8.3.16)"->{
    Cell[11559313, 337294, 753, 25, 42, "NE3",
      CellTags->"(8.3.16)"]},
  "i:71"->{
    Cell[11568684, 337584, 1079, 32, 33, "NE3",
      CellTags->{"i:71", "(8.3.17)"}]},
  "(8.3.17)"->{
    Cell[11568684, 337584, 1079, 32, 33, "NE3",
      CellTags->{"i:71", "(8.3.17)"}]},
  "i:88"->{
    Cell[11572985, 337722, 254, 8, 44, "Text",
      CellTags->"i:88"]},
  "Cell 8.39"->{
    Cell[11573264, 337734, 424, 9, 162, "Input",
      CellTags->"Cell 8.39"]},
  "i:87"->{
    Cell[11597767, 338337, 1205, 36, 99, "Text",
      CellTags->"i:87"]},
  "Cell 8.40"->{
    Cell[11599273, 338389, 127, 3, 67, "Input",
      CellTags->"Cell 8.40"]},
  "Cell 8.41"->{
    Cell[11600626, 338438, 741, 16, 238, "Input",
      CellTags->"Cell 8.41"]},
  "i:89"->{
    Cell[11650678, 339530, 863, 28, 82, "Text",
      CellTags->"i:89"]},
  "(8.3.18)"->{
    Cell[11658802, 339780, 688, 21, 33, "NE3",
      CellTags->"(8.3.18)"]},
  "i:72"->{
    Cell[11660599, 339840, 82, 1, 31, "Section",
      CellTags->{"i:72", "c:29"}]},
  "c:29"->{
    Cell[11660599, 339840, 82, 1, 31, "Section",
      CellTags->{"i:72", "c:29"}]},
  "i:69"->{
    Cell[11660684, 339843, 657, 18, 64, "Text",
      CellTags->"i:69"]},
  "Cell 8.42"->{
    Cell[11661344, 339863, 273, 7, 124, "Input",
      CellTags->"Cell 8.42"]},
  "Cell 8.43"->{
    Cell[11662659, 339905, 220, 5, 86, "Input",
      CellTags->"Cell 8.43"]},
  "(8.3.19)"->{
    Cell[11663051, 339918, 1113, 30, 36, "NE3",
      CellTags->"(8.3.19)"]},
  "Cell 8.44"->{
    Cell[11665294, 339988, 317, 7, 105, "Input",
      CellTags->"Cell 8.44"]},
  "Cell 8.45"->{
    Cell[11667014, 340042, 190, 6, 67, "Input",
      CellTags->"Cell 8.45"]},
  "Cell 8.46"->{
    Cell[11668589, 340079, 1614, 33, 295, "Input",
      CellTags->"Cell 8.46"]},
  "Cell 8.47"->{
    Cell[11670981, 340139, 286, 6, 105, "Input",
      CellTags->"Cell 8.47"]},
  "Cell 8.48"->{
    Cell[11671425, 340154, 174, 4, 86, "Input",
      CellTags->"Cell 8.48"]},
  "Cell 8.49"->{
    Cell[11671830, 340171, 230, 5, 105, "Input",
      CellTags->"Cell 8.49"]},
  "Cell 8.50"->{
    Cell[11672430, 340193, 165, 4, 67, "Input",
      CellTags->"Cell 8.50"]},
  "Cell 8.51"->{
    Cell[11944561, 353280, 135, 3, 67, "Input",
      CellTags->"Cell 8.51"]},
  "Cell 8.52"->{
    Cell[11944899, 353296, 177, 5, 67, "Input",
      CellTags->"Cell 8.52"]},
  "Cell 8.53"->{
    Cell[11945774, 353331, 463, 10, 162, "Input",
      CellTags->"Cell 8.53"]},
  "Cell 8.54"->{
    Cell[11972641, 353995, 141, 4, 67, "Input",
      CellTags->"Cell 8.54"]},
  "Cell 8.55"->{
    Cell[11973081, 354015, 320, 7, 105, "Input",
      CellTags->"Cell 8.55"]},
  "Cell 8.56"->{
    Cell[13035822, 377717, 99, 3, 67, "Input",
      CellTags->"Cell 8.56"]},
  "Cell 8.57"->{
    Cell[13037142, 377755, 323, 7, 124, "Input",
      CellTags->"Cell 8.57"]},
  "Fig. 8.9"->{
    Cell[13059878, 378335, 452, 16, 16, "Caption",
      CellTags->"Fig. 8.9"]},
  "c:33"->{
    Cell[13063217, 378414, 65, 1, 30, "Subsubtitle",
      CellTags->"c:33"]},
  "i:77"->{
    Cell[13085015, 379087, 1114, 31, 99, "Text",
      CellTags->"i:77"]},
  "Fig. 8.10"->{
    Cell[13335362, 383632, 396, 11, 33, "Caption",
      CellTags->"Fig. 8.10"]},
  "refs"->{
    Cell[13335807, 383649, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:31"}]},
  "c:31"->{
    Cell[13335807, 383649, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:31"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 13378518, 384978},
  {"i:30", 13378594, 384981},
  {"c:2", 13378682, 384984},
  {"c:3", 13378770, 384987},
  {"i:3", 13378851, 384990},
  {"(8.1.1)", 13378931, 384993},
  {"i:1", 13379023, 384996},
  {"c:4", 13379100, 384999},
  {"c:5", 13379182, 385002},
  {"i:2", 13379260, 385005},
  {"i:5", 13379339, 385008},
  {"(8.1.2)", 13379421, 385011},
  {"i:4", 13379513, 385014},
  {"c:6", 13379592, 385017},
  {"i:6", 13379671, 385020},
  {"(8.1.3)", 13379756, 385023},
  {"i:91", 13379850, 385026},
  {"Cell 8.1", 13379935, 385029},
  {"(8.1.4)", 13380022, 385032},
  {"Cell 8.2", 13380120, 385035},
  {"Cell 8.3", 13380208, 385038},
  {"Cell 8.4", 13380297, 385041},
  {"Cell 8.5", 13380385, 385044},
  {"Cell 8.6", 13380474, 385047},
  {"i:7", 13380558, 385050},
  {"(8.1.5)", 13380644, 385053},
  {"Cell 8.7", 13380746, 385056},
  {"Cell 8.8", 13380838, 385059},
  {"i:10", 13380928, 385062},
  {"(8.1.6)", 13381018, 385065},
  {"(8.1.7)", 13381120, 385068},
  {"i:13", 13381219, 385071},
  {"(8.1.8)", 13381305, 385074},
  {"i:9", 13381404, 385077},
  {"Cell 8.9", 13381492, 385080},
  {"(8.1.9)", 13381585, 385083},
  {"i:31", 13381684, 385086},
  {"(8.1.10)", 13381773, 385089},
  {"Cell 8.10", 13381879, 385092},
  {"Fig. 8.1", 13381973, 385095},
  {"i:81", 13382064, 385098},
  {"c:7", 13382158, 385101},
  {"i:12", 13382253, 385104},
  {"(8.1.11)", 13382344, 385107},
  {"Fig. 8.2", 13382448, 385110},
  {"(8.1.12)", 13382544, 385113},
  {"(8.1.13)", 13382648, 385116},
  {"(8.1.14)", 13382752, 385119},
  {"(8.1.15)", 13382856, 385122},
  {"(8.1.16)", 13382961, 385125},
  {"i:82", 13383062, 385128},
  {"Cell 8.11", 13383152, 385131},
  {"c:8", 13383243, 385134},
  {"(8.1.17)", 13383332, 385137},
  {"i:14", 13383433, 385140},
  {"(8.1.18)", 13383547, 385143},
  {"(8.1.19)", 13383661, 385146},
  {"i:15", 13383762, 385149},
  {"(8.1.20)", 13383849, 385152},
  {"(8.1.21)", 13383953, 385155},
  {"(8.1.22)", 13384057, 385158},
  {"(8.1.23)", 13384161, 385161},
  {"(8.1.24)", 13384267, 385164},
  {"(8.1.25)", 13384372, 385167},
  {"i:16", 13384473, 385170},
  {"(8.1.26)", 13384588, 385173},
  {"(8.1.27)", 13384703, 385176},
  {"(8.1.28)", 13384808, 385179},
  {"i:17", 13384910, 385182},
  {"(8.1.29)", 13385025, 385185},
  {"i:18", 13385136, 385188},
  {"(8.1.30)", 13385251, 385191},
  {"i:79", 13385362, 385194},
  {"(8.1.31)", 13385452, 385197},
  {"i:19", 13385554, 385200},
  {"(8.1.32)", 13385668, 385203},
  {"c:9", 13385777, 385206},
  {"i:21", 13385863, 385209},
  {"(8.1.33)", 13385959, 385212},
  {"(8.1.34)", 13386064, 385215},
  {"i:28", 13386164, 385218},
  {"(8.1.35)", 13386254, 385221},
  {"(8.1.36)", 13386359, 385224},
  {"(8.1.37)", 13386463, 385227},
  {"(8.1.38)", 13386567, 385230},
  {"(8.1.39)", 13386672, 385233},
  {"i:20", 13386773, 385236},
  {"(8.1.40)", 13386862, 385239},
  {"i:29", 13386962, 385242},
  {"i:24", 13387048, 385245},
  {"(8.1.41)", 13387162, 385248},
  {"i:22", 13387272, 385251},
  {"i:23", 13387357, 385254},
  {"i:25", 13387442, 385257},
  {"(8.1.42)", 13387530, 385260},
  {"(8.1.43)", 13387634, 385263},
  {"(8.1.44)", 13387738, 385266},
  {"i:26", 13387838, 385269},
  {"i:27", 13387923, 385272},
  {"c:10", 13388008, 385275},
  {"(8.1.45)", 13388102, 385278},
  {"i:32", 13388202, 385281},
  {"(8.1.46)", 13388291, 385284},
  {"(8.1.47)", 13388395, 385287},
  {"i:33", 13388495, 385290},
  {"(8.1.48)", 13388584, 385293},
  {"i:34", 13388684, 385296},
  {"i:35", 13388769, 385299},
  {"i:36", 13388855, 385302},
  {"(8.1.49)", 13388946, 385305},
  {"i:37", 13389047, 385308},
  {"(8.1.50)", 13389136, 385311},
  {"i:40", 13389238, 385314},
  {"i:38", 13389324, 385317},
  {"(8.1.51)", 13389413, 385320},
  {"i:84", 13389513, 385323},
  {"i:83", 13389598, 385326},
  {"i:41", 13389685, 385329},
  {"Fig. 8.3", 13389774, 385332},
  {"c:11", 13389865, 385335},
  {"i:43", 13389952, 385338},
  {"c:12", 13390052, 385341},
  {"i:44", 13390152, 385344},
  {"c:13", 13390248, 385347},
  {"i:64", 13390344, 385350},
  {"(8.2.1)", 13390432, 385353},
  {"(8.2.2)", 13390521, 385356},
  {"(8.2.3)", 13390610, 385359},
  {"(8.2.4)", 13390700, 385362},
  {"(8.2.5)", 13390790, 385365},
  {"(8.2.6)", 13390880, 385368},
  {"(8.2.7)", 13390970, 385371},
  {"i:45", 13391057, 385374},
  {"c:14", 13391153, 385377},
  {"(8.2.8)", 13391252, 385380},
  {"(8.2.9)", 13391341, 385383},
  {"(8.2.10)", 13391431, 385386},
  {"i:46", 13391518, 385389},
  {"(8.2.11)", 13391608, 385392},
  {"i:47", 13391695, 385395},
  {"c:15", 13391791, 385398},
  {"(8.2.12)", 13391891, 385401},
  {"i:48", 13391980, 385404},
  {"c:16", 13392076, 385407},
  {"i:49", 13392172, 385410},
  {"(8.2.13)", 13392261, 385413},
  {"i:50", 13392348, 385416},
  {"(8.2.14)", 13392437, 385419},
  {"(8.2.15)", 13392528, 385422},
  {"(8.2.16)", 13392620, 385425},
  {"(8.2.17)", 13392712, 385428},
  {"i:51", 13392799, 385431},
  {"(8.2.18)", 13392887, 385434},
  {"c:17", 13392974, 385437},
  {"i:52", 13393064, 385440},
  {"c:18", 13393160, 385443},
  {"(8.2.19)", 13393260, 385446},
  {"(8.2.20)", 13393351, 385449},
  {"(8.2.21)", 13393442, 385452},
  {"Fig. 8.4", 13393533, 385455},
  {"Cell 8.12", 13393630, 385458},
  {"i:53", 13393722, 385461},
  {"c:19", 13393818, 385464},
  {"Cell 8.13", 13393919, 385467},
  {"Cell 8.14", 13394015, 385470},
  {"i:63", 13394105, 385473},
  {"Fig. 8.5", 13394194, 385476},
  {"Cell 8.15", 13394290, 385479},
  {"Cell 8.16", 13394386, 385482},
  {"c:20", 13394476, 385485},
  {"(8.2.22)", 13394566, 385488},
  {"Cell 8.17", 13394658, 385491},
  {"Cell 8.18", 13394755, 385494},
  {"Fig. 8.6", 13394852, 385497},
  {"i:54", 13394943, 385500},
  {"(8.2.23)", 13395039, 385503},
  {"Cell 8.19", 13395131, 385506},
  {"Cell 8.20", 13395229, 385509},
  {"i:80", 13395320, 385512},
  {"i:42", 13395405, 385515},
  {"c:21", 13395505, 385518},
  {"i:56", 13395605, 385521},
  {"c:22", 13395701, 385524},
  {"(8.2.24)", 13395801, 385527},
  {"(8.2.25)", 13395893, 385530},
  {"i:57", 13395980, 385533},
  {"c:23", 13396076, 385536},
  {"(8.2.26)", 13396176, 385539},
  {"(8.2.27)", 13396267, 385542},
  {"(8.2.28)", 13396358, 385545},
  {"i:58", 13396445, 385548},
  {"c:24", 13396541, 385551},
  {"(8.2.29)", 13396641, 385554},
  {"(8.2.30)", 13396733, 385557},
  {"c:25", 13396820, 385560},
  {"(8.2.31)", 13396910, 385563},
  {"Cell 8.21", 13397002, 385566},
  {"Fig. 8.7", 13397098, 385569},
  {"c:30", 13397190, 385572},
  {"i:73", 13397280, 385575},
  {"(8.2.32)", 13397369, 385578},
  {"(8.2.33)", 13397460, 385581},
  {"i:92", 13397548, 385584},
  {"i:74", 13397634, 385587},
  {"i:75", 13397719, 385590},
  {"(8.2.34)", 13397808, 385593},
  {"i:76", 13397895, 385596},
  {"(8.2.35)", 13397984, 385599},
  {"i:78", 13398071, 385602},
  {"Cell 8.22", 13398163, 385605},
  {"Cell 8.23", 13398258, 385608},
  {"Cell 8.24", 13398353, 385611},
  {"Cell 8.25", 13398448, 385614},
  {"Cell 8.26", 13398543, 385617},
  {"Fig. 8.8", 13398640, 385620},
  {"i:59", 13398732, 385623},
  {"c:26", 13398830, 385626},
  {"c:27", 13398928, 385629},
  {"i:60", 13399018, 385632},
  {"(8.3.1)", 13399108, 385635},
  {"(8.3.2)", 13399199, 385638},
  {"i:61", 13399287, 385641},
  {"(8.3.3)", 13399377, 385644},
  {"(8.3.4)", 13399469, 385647},
  {"(8.3.5)", 13399560, 385650},
  {"i:85", 13399647, 385653},
  {"i:62", 13399734, 385656},
  {"(8.3.6)", 13399824, 385659},
  {"(8.3.7)", 13399915, 385662},
  {"i:65", 13400002, 385665},
  {"(8.3.8)", 13400091, 385668},
  {"(8.3.9)", 13400183, 385671},
  {"(8.3.10)", 13400275, 385674},
  {"i:66", 13400364, 385677},
  {"(8.3.11)", 13400455, 385680},
  {"i:67", 13400545, 385683},
  {"(8.3.12)", 13400649, 385686},
  {"(8.3.13)", 13400753, 385689},
  {"(8.3.14)", 13400845, 385692},
  {"c:32", 13400935, 385695},
  {"c:28", 13401027, 385698},
  {"i:68", 13401114, 385701},
  {"Cell 8.27", 13401212, 385704},
  {"Cell 8.28", 13401308, 385707},
  {"i:86", 13401402, 385710},
  {"Cell 8.29", 13401495, 385713},
  {"Cell 8.30", 13401591, 385716},
  {"Cell 8.31", 13401687, 385719},
  {"Cell 8.32", 13401783, 385722},
  {"Cell 8.33", 13401879, 385725},
  {"Cell 8.34", 13401975, 385728},
  {"Cell 8.35", 13402072, 385731},
  {"Cell 8.36", 13402168, 385734},
  {"Cell 8.37", 13402265, 385737},
  {"(8.3.15)", 13402360, 385740},
  {"i:70", 13402449, 385743},
  {"i:90", 13402543, 385746},
  {"Cell 8.38", 13402635, 385749},
  {"(8.3.16)", 13402730, 385752},
  {"i:71", 13402819, 385755},
  {"(8.3.17)", 13402923, 385758},
  {"i:88", 13403023, 385761},
  {"Cell 8.39", 13403113, 385764},
  {"i:87", 13403205, 385767},
  {"Cell 8.40", 13403297, 385770},
  {"Cell 8.41", 13403393, 385773},
  {"i:89", 13403486, 385776},
  {"(8.3.18)", 13403576, 385779},
  {"i:72", 13403665, 385782},
  {"c:29", 13403762, 385785},
  {"i:69", 13403859, 385788},
  {"Cell 8.42", 13403950, 385791},
  {"Cell 8.43", 13404047, 385794},
  {"(8.3.19)", 13404142, 385797},
  {"Cell 8.44", 13404237, 385800},
  {"Cell 8.45", 13404334, 385803},
  {"Cell 8.46", 13404430, 385806},
  {"Cell 8.47", 13404529, 385809},
  {"Cell 8.48", 13404626, 385812},
  {"Cell 8.49", 13404722, 385815},
  {"Cell 8.50", 13404819, 385818},
  {"Cell 8.51", 13404915, 385821},
  {"Cell 8.52", 13405011, 385824},
  {"Cell 8.53", 13405107, 385827},
  {"Cell 8.54", 13405205, 385830},
  {"Cell 8.55", 13405301, 385833},
  {"Cell 8.56", 13405398, 385836},
  {"Cell 8.57", 13405493, 385839},
  {"Fig. 8.9", 13405589, 385842},
  {"c:33", 13405682, 385845},
  {"i:77", 13405773, 385848},
  {"Fig. 8.10", 13405865, 385851},
  {"refs", 13405959, 385854},
  {"c:31", 13406057, 385857}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 71, 1, 69, "Title",
  CellTags->"c:1"],
Cell[1801, 55, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1842, 59, 65, 1, 39, "Subtitle",
  CellTags->{"i:30", "c:2"}],
Cell[1910, 62, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1951, 66, 60, 1, 41, "Subsubtitle",
  CellTags->"c:3"],
Cell[2014, 69, 428, 11, 44, "Text",
  CellTags->"i:3"],
Cell[2445, 82, 644, 19, 32, "NumberedEquation",
  CellTags->"(8.1.1)"],
Cell[3092, 103, 149, 3, 44, "Text"],
Cell[3244, 108, 587, 9, 95, "Text"],
Cell[3834, 119, 556, 9, 95, "Text"],
Cell[4393, 130, 609, 10, 95, "Text"],
Cell[5005, 142, 976, 28, 78, "Text",
  CellTags->"i:1"]
}, Closed]],

Cell[CellGroupData[{
Cell[6018, 175, 78, 1, 30, "Subsubtitle",
  CellTags->"c:4"],

Cell[CellGroupData[{
Cell[6121, 180, 59, 1, 42, "Section",
  CellTags->"c:5"],
Cell[6183, 183, 1201, 27, 112, "Text",
  CellTags->"i:2"],
Cell[7387, 212, 1728, 55, 98, "Text",
  CellTags->"i:5"],
Cell[9118, 269, 774, 26, 44, "Text"],
Cell[9895, 297, 158, 5, 38, "NumberedEquation",
  CellTags->"(8.1.2)"],
Cell[10056, 304, 1412, 50, 48, "Text",
  CellTags->"i:4"],
Cell[11471, 356, 808, 12, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12316, 373, 49, 1, 31, "Section",
  CellTags->"c:6"],
Cell[12368, 376, 3230, 112, 112, "Text",
  CellTags->"i:6"],
Cell[15601, 490, 177, 6, 29, "NumberedEquation",
  CellTags->"(8.1.3)"],
Cell[15781, 498, 1285, 45, 78, "Text",
  CellTags->"i:91"],
Cell[17069, 545, 408, 13, 44, "Text"],
Cell[17480, 560, 173, 4, 67, "Input",
  CellTags->"Cell 8.1"],
Cell[17656, 566, 800, 25, 44, "Text"],
Cell[18459, 593, 406, 14, 45, "Text"],
Cell[18868, 609, 149, 5, 33, "NumberedEquation",
  CellTags->"(8.1.4)"],
Cell[19020, 616, 100, 3, 27, "Text"],
Cell[19123, 621, 158, 4, 67, "Input",
  CellTags->"Cell 8.2"],
Cell[19284, 627, 340, 11, 45, "Text"],
Cell[19627, 640, 280, 7, 124, "Input",
  CellTags->"Cell 8.3"],
Cell[19910, 649, 264, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[20199, 662, 179, 5, 67, "Input",
  CellTags->"Cell 8.4"],
Cell[20381, 669, 22213, 560, 233, 6438, 361, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[42609, 1232, 270, 5, 61, "Text"],
Cell[42882, 1239, 219, 8, 27, "Text"],
Cell[43104, 1249, 137, 3, 67, "Input",
  CellTags->"Cell 8.5"],
Cell[43244, 1254, 167, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[43436, 1264, 264, 6, 86, "Input",
  CellTags->"Cell 8.6"],

Cell[CellGroupData[{
Cell[43725, 1274, 26903, 769, 233, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[70631, 2045, 30872, 818, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[101506, 2865, 29592, 802, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[131101, 3669, 31148, 822, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[162252, 4493, 30091, 809, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[192346, 5304, 31261, 823, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[223610, 6129, 30516, 814, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[254129, 6945, 31451, 825, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[285583, 7772, 30658, 816, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[316244, 8590, 31597, 827, 70, 10250, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[347844, 9419, 30861, 818, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[378708, 10239, 31853, 830, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[410564, 11071, 30954, 819, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[441521, 11892, 31469, 826, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[472993, 12720, 30764, 817, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[503760, 13539, 31797, 830, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[535560, 14371, 31189, 822, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[566752, 15195, 31975, 832, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[598730, 16029, 31201, 822, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[629934, 16853, 31999, 832, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[661936, 17687, 31456, 825, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[693395, 18514, 32044, 833, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[725442, 19349, 31221, 822, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[756666, 20173, 31752, 829, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[788421, 21004, 30922, 819, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[819346, 21825, 31845, 830, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[851194, 22657, 31250, 823, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[882447, 23482, 31845, 830, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[914295, 24314, 31408, 825, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[945706, 25141, 32270, 835, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[977979, 25978, 31497, 826, 70, 10251, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1009479, 26806, 32234, 835, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1041716, 27643, 31440, 825, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1073159, 28470, 32068, 833, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1105230, 29305, 31610, 827, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1136843, 30134, 32242, 835, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1169088, 30971, 31805, 830, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1200896, 31803, 32400, 837, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1233299, 32642, 31493, 826, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1264795, 33470, 32100, 833, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1296898, 34305, 31428, 825, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1328329, 35132, 32092, 833, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1360424, 35967, 31440, 825, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1391867, 36794, 32238, 835, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1424108, 37631, 31513, 826, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1455624, 38459, 32056, 833, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1487683, 39294, 31720, 829, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1519406, 40125, 32198, 835, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1551607, 40962, 31728, 829, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1583338, 41793, 32319, 836, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1615660, 42631, 31768, 829, 70, 10251, 559, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1647455, 43464, 1114, 16, 180, "Text"],
Cell[1648572, 43482, 772, 20, 78, "Text",
  CellTags->"i:7"],
Cell[1649347, 43504, 121, 2, 31, "NumberedEquation",
  CellTags->"(8.1.5)"],
Cell[1649471, 43508, 263, 11, 27, "Text"],
Cell[1649737, 43521, 1321, 46, 61, "Text"],

Cell[CellGroupData[{
Cell[1651083, 43571, 208, 6, 86, "Input",
  CellTags->"Cell 8.7"],
Cell[1651294, 43579, 52, 1, 46, "Output"]
}, Open  ]],
Cell[1651361, 43583, 776, 22, 78, "Text"],

Cell[CellGroupData[{
Cell[1652162, 43609, 686, 14, 238, "Input",
  CellTags->"Cell 8.8"],

Cell[CellGroupData[{
Cell[1652873, 43627, 29385, 1184, 233, 9581, 935, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1682261, 44813, 36321, 1269, 70, 9600, 935, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1718585, 46084, 36891, 1276, 70, 9619, 935, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1755479, 47362, 37751, 1284, 70, 9612, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1793233, 48648, 38674, 1295, 70, 9636, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1831910, 49945, 38309, 1290, 70, 9652, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1870222, 51237, 38832, 1297, 70, 9676, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1909057, 52536, 39172, 1301, 70, 9672, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1948232, 53839, 39309, 1302, 70, 9692, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1987544, 55143, 39147, 1300, 70, 9708, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2026694, 56445, 39581, 1305, 70, 9737, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2066278, 57752, 39553, 1305, 70, 9729, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2105834, 59059, 40119, 1311, 70, 9757, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2145956, 60372, 39759, 1307, 70, 9757, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2185718, 61681, 40034, 1310, 70, 9753, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2225755, 62993, 40192, 1312, 70, 9753, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2265950, 64307, 40342, 1314, 70, 9777, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2306295, 65623, 40472, 1316, 70, 9777, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2346770, 66941, 40358, 1314, 70, 9789, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2387131, 68257, 39799, 1307, 70, 9797, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2426933, 69566, 40471, 1315, 70, 9813, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2467407, 70883, 40070, 1310, 70, 9793, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2507480, 72195, 40896, 1320, 70, 9813, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2548379, 73517, 40281, 1313, 70, 9829, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2588663, 74832, 40694, 1318, 70, 9833, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2629360, 76152, 40775, 1319, 70, 9837, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2670138, 77473, 40905, 1321, 70, 9801, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2711046, 78796, 40608, 1316, 70, 9837, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2751657, 80114, 40876, 1320, 70, 9817, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2792536, 81436, 40831, 1319, 70, 9857, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2833370, 82757, 40884, 1320, 70, 9849, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2874257, 84079, 40867, 1319, 70, 9873, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2915127, 85400, 40964, 1320, 70, 9877, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2956094, 86722, 40770, 1318, 70, 9893, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2996867, 88042, 41333, 1325, 70, 9897, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3038203, 89369, 40806, 1318, 70, 9897, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3079012, 90689, 41417, 1325, 70, 9917, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3120432, 92016, 40996, 1320, 70, 9917, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3161431, 93338, 41090, 1322, 70, 9877, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3202524, 94662, 40855, 1319, 70, 9909, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3243382, 95983, 40855, 1319, 70, 9905, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3284240, 97304, 40632, 1316, 70, 9889, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3324875, 98622, 41004, 1320, 70, 9913, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3365882, 99944, 40518, 1314, 70, 9913, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3406403, 101260, 41025, 1321, 70, 9909, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3447431, 102583, 40850, 1318, 70, 9957, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3488284, 103903, 41174, 1322, 70, 9925, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3529461, 105227, 40814, 1318, 70, 9917, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3570278, 106547, 41150, 1322, 70, 9893, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3611431, 107871, 41243, 1323, 70, 9933, 932, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3652677, 109196, 41210, 1322, 70, 9953, 932, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[3693914, 110522, 1119, 29, 112, "Text",
  CellTags->"i:10"],
Cell[3695036, 110553, 198, 6, 29, "NumberedEquation",
  CellTags->"(8.1.6)"],
Cell[3695237, 110561, 180, 6, 27, "Text"],
Cell[3695420, 110569, 136, 5, 32, "NumberedEquation",
  CellTags->"(8.1.7)"],
Cell[3695559, 110576, 108, 3, 27, "Text"],
Cell[3695670, 110581, 1163, 35, 95, "Text"],
Cell[3696836, 110618, 448, 13, 48, "Text"],
Cell[3697287, 110633, 73, 1, 27, "Text",
  CellTags->"i:13"],
Cell[3697363, 110636, 388, 12, 40, "NumberedEquation",
  CellTags->"(8.1.8)"],
Cell[3697754, 110650, 982, 32, 78, "Text",
  CellTags->"i:9"],

Cell[CellGroupData[{
Cell[3698761, 110686, 360, 9, 143, "Input",
  CellTags->"Cell 8.9"],
Cell[3699124, 110697, 24664, 623, 233, 7133, 402, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3723803, 111323, 677, 17, 78, "Text"],
Cell[3724483, 111342, 176, 6, 29, "NumberedEquation",
  CellTags->"(8.1.9)"],
Cell[3724662, 111350, 62, 0, 27, "Text"],
Cell[3724727, 111352, 368, 11, 31, "Text",
  CellTags->"i:31"],
Cell[3725098, 111365, 459, 15, 40, "NumberedEquation",
  CellTags->"(8.1.10)"],
Cell[3725560, 111382, 744, 21, 65, "Text"],
Cell[3726307, 111405, 110, 3, 67, "Input",
  CellTags->"Cell 8.10"],
Cell[3726420, 111410, 300, 10, 27, "Text"],
Cell[3726723, 111422, 27415, 685, 233, 7927, 440, "GraphicsData", \
"PostScript", "Picture"],
Cell[3754141, 112109, 148, 4, 16, "Caption",
  CellTags->"Fig. 8.1"],
Cell[3754292, 112115, 1677, 47, 120, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3756006, 112167, 73, 1, 31, "Section",
  CellTags->{"i:81", "c:7"}],
Cell[3756082, 112170, 1381, 35, 129, "Text",
  CellTags->"i:12"],
Cell[3757466, 112207, 195, 7, 29, "UNNEQ"],
Cell[3757664, 112216, 69, 0, 27, "Text"],
Cell[3757736, 112218, 307, 9, 42, "NumberedEquation",
  CellTags->"(8.1.11)"],
Cell[3758046, 112229, 148, 5, 27, "Text"],
Cell[3758197, 112236, 171, 3, 46, "UNNEQ"],
Cell[3758371, 112241, 299, 12, 27, "Text"],
Cell[3758673, 112255, 521, 11, 78, "Text"],
Cell[3759197, 112268, 1075, 30, 109, "Text"],
Cell[3760275, 112300, 563, 18, 89, "UNNEQ"],
Cell[3760841, 112320, 264, 9, 27, "Text"],
Cell[3761108, 112331, 124069, 1535, 228, 123948, 1531, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[3885180, 113868, 297, 10, 16, "Caption",
  CellTags->"Fig. 8.2"],
Cell[3885480, 113880, 434, 15, 44, "Text"],
Cell[3885917, 113897, 122, 2, 27, "NumberedEquation",
  CellTags->"(8.1.12)"],
Cell[3886042, 113901, 20, 0, 27, "Text"],
Cell[3886065, 113903, 140, 5, 29, "NumberedEquation",
  CellTags->"(8.1.13)"],
Cell[3886208, 113910, 301, 11, 27, "Text"],
Cell[3886512, 113923, 138, 5, 29, "NumberedEquation",
  CellTags->"(8.1.14)"],
Cell[3886653, 113930, 482, 16, 44, "Text"],
Cell[3887138, 113948, 177, 5, 29, "UNNEQ"],
Cell[3887318, 113955, 862, 31, 61, "Text"],
Cell[3888183, 113988, 313, 7, 44, "Text"],
Cell[3888499, 113997, 170, 6, 39, "Text"],
Cell[3888672, 114005, 1203, 32, 129, "Text"],
Cell[3889878, 114039, 125, 3, 27, "Text"],
Cell[3890006, 114044, 369, 12, 41, "NumberedEquation",
  CellTags->"(8.1.15)"],
Cell[3890378, 114058, 1068, 37, 61, "Text"],
Cell[3891449, 114097, 283, 10, 29, "NumberedEquation",
  CellTags->"(8.1.16)"],
Cell[3891735, 114109, 578, 19, 44, "Text",
  CellTags->"i:82"],

Cell[CellGroupData[{
Cell[3892338, 114132, 703, 17, 238, "Input",
  CellTags->"Cell 8.11"],

Cell[CellGroupData[{
Cell[3893066, 114153, 33311, 1335, 233, 11278, 1058, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3926380, 115490, 11409, 1061, 70, 11287, 1057, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3937792, 116553, 11416, 1061, 70, 11294, 1057, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3949211, 117616, 11434, 1061, 70, 11312, 1057, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3960648, 118679, 11489, 1063, 70, 11367, 1059, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3972140, 119744, 35540, 1361, 70, 11377, 1058, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4007683, 121107, 35928, 1368, 70, 11437, 1061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4043614, 122477, 35519, 1368, 70, 11534, 1067, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4079136, 123847, 11727, 1074, 70, 11605, 1070, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4090866, 124923, 11771, 1076, 70, 11649, 1072, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4102640, 126001, 11907, 1083, 70, 11785, 1079, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4114550, 127086, 11913, 1084, 70, 11791, 1080, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4126466, 128172, 12048, 1091, 70, 11926, 1087, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4138517, 129265, 12104, 1095, 70, 11982, 1091, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4150624, 130362, 12117, 1096, 70, 11995, 1092, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4162744, 131460, 12236, 1105, 70, 12114, 1101, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4174983, 132567, 12211, 1104, 70, 12089, 1100, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4187197, 133673, 12256, 1108, 70, 12134, 1104, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4199456, 134783, 12321, 1113, 70, 12199, 1109, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4211780, 135898, 36580, 1420, 70, 12271, 1115, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4248363, 137320, 12496, 1125, 70, 12374, 1121, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4260862, 138447, 36602, 1431, 70, 12423, 1128, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4297467, 139880, 12606, 1136, 70, 12484, 1132, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4310076, 141018, 12673, 1140, 70, 12551, 1136, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4322752, 142160, 36828, 1443, 70, 12580, 1139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4359583, 143605, 36677, 1437, 70, 12518, 1134, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4396263, 145044, 36577, 1431, 70, 12422, 1128, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4432843, 146477, 36579, 1429, 70, 12465, 1127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4469425, 147908, 12468, 1123, 70, 12346, 1119, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4481896, 149033, 36602, 1418, 70, 12318, 1114, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4518501, 150453, 36600, 1414, 70, 12275, 1109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4555104, 151869, 36517, 1409, 70, 12224, 1104, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4591624, 153280, 36318, 1403, 70, 12175, 1100, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4627945, 154685, 36212, 1400, 70, 12199, 1099, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4664160, 156087, 12326, 1103, 70, 12204, 1099, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4676489, 157192, 12286, 1100, 70, 12164, 1096, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4688778, 158294, 12289, 1098, 70, 12167, 1094, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4701070, 159394, 12218, 1093, 70, 12096, 1089, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4713291, 160489, 36540, 1395, 70, 12037, 1088, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4749834, 161886, 36601, 1395, 70, 12074, 1088, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4786438, 163283, 12130, 1088, 70, 12008, 1084, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4798571, 164373, 36188, 1385, 70, 11944, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4834762, 165760, 36251, 1389, 70, 12027, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4871016, 167151, 36171, 1383, 70, 11931, 1079, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4907190, 168536, 12064, 1083, 70, 11942, 1079, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4919257, 169621, 12030, 1079, 70, 11908, 1075, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4931290, 170702, 12018, 1079, 70, 11896, 1075, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4943311, 171783, 11931, 1075, 70, 11809, 1071, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4955245, 172860, 36187, 1378, 70, 11822, 1073, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4991435, 174240, 36133, 1379, 70, 11909, 1075, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5027571, 175621, 36125, 1375, 70, 11865, 1071, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[5063723, 177000, 1106, 36, 80, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5064866, 177041, 46, 1, 31, "Section",
  CellTags->"c:8"],
Cell[5064915, 177044, 724, 22, 48, "Text"],
Cell[5065642, 177068, 409, 12, 38, "NumberedEquation",
  CellTags->"(8.1.17)"],
Cell[5066054, 177082, 1300, 41, 82, "Text"],
Cell[5067357, 177125, 407, 10, 38, "UNNEQ"],
Cell[5067767, 177137, 505, 15, 45, "Text"],
Cell[5068275, 177154, 362, 9, 31, "NumberedEquation",
  CellTags->{"i:14", "(8.1.18)"}],
Cell[5068640, 177165, 793, 24, 61, "Text"],
Cell[5069436, 177191, 665, 18, 27, "NumberedEquation",
  CellTags->"(8.1.19)"],
Cell[5070104, 177211, 83, 1, 27, "Text",
  CellTags->"i:15"],
Cell[5070190, 177214, 1006, 33, 48, "Text"],
Cell[5071199, 177249, 283, 7, 51, "NumberedEquation",
  CellTags->"(8.1.20)"],
Cell[5071485, 177258, 279, 9, 27, "Text"],
Cell[5071767, 177269, 221, 6, 33, "NumberedEquation",
  CellTags->"(8.1.21)"],
Cell[5071991, 177277, 492, 16, 44, "Text"],
Cell[5072486, 177295, 187, 6, 32, "NumberedEquation",
  CellTags->"(8.1.22)"],
Cell[5072676, 177303, 1022, 33, 69, "Text"],
Cell[5073701, 177338, 1554, 42, 29, "NumberedEquation",
  CellTags->"(8.1.23)"],
Cell[5075258, 177382, 907, 29, 44, "Text"],
Cell[5076168, 177413, 725, 19, 77, "NumberedEquation",
  CellTags->"(8.1.24)"],
Cell[5076896, 177434, 510, 14, 44, "Text"],
Cell[5077409, 177450, 606, 16, 51, "NumberedEquation",
  CellTags->"(8.1.25)"],
Cell[5078018, 177468, 654, 20, 61, "Text"],
Cell[5078675, 177490, 189, 6, 27, "Text"],
Cell[5078867, 177498, 761, 23, 29, "NumberedEquation",
  CellTags->{"i:16", "(8.1.26)"}],
Cell[5079631, 177523, 1039, 35, 44, "Text"],
Cell[5080673, 177560, 511, 16, 38, "NumberedEquation",
  CellTags->"(8.1.27)"],
Cell[5081187, 177578, 793, 25, 48, "Text"],
Cell[5081983, 177605, 1955, 50, 33, "NumberedEquation",
  CellTags->"(8.1.28)"],
Cell[5083941, 177657, 1837, 44, 155, "Text"],
Cell[5085781, 177703, 412, 11, 56, "Text"],
Cell[5086196, 177716, 788, 23, 33, "NumberedEquation",
  CellTags->{"i:17", "(8.1.29)"}],
Cell[5086987, 177741, 351, 13, 27, "Text"],
Cell[5087341, 177756, 893, 30, 48, "Text"],
Cell[5088237, 177788, 603, 20, 33, "NumberedEquation",
  CellTags->{"i:18", "(8.1.30)"}],
Cell[5088843, 177810, 940, 28, 65, "Text"],
Cell[5089786, 177840, 1505, 43, 69, "Text",
  CellTags->"i:79"],
Cell[5091294, 177885, 2085, 55, 59, "NumberedEquation",
  CellTags->"(8.1.31)"],
Cell[5093382, 177942, 22, 0, 27, "Text"],
Cell[5093407, 177944, 151, 5, 30, "NumberedEquation",
  CellTags->{"i:19", "(8.1.32)"}],
Cell[5093561, 177951, 852, 26, 63, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5094450, 177982, 111, 4, 31, "Section",
  CellTags->"c:9"],

Cell[CellGroupData[{
Cell[5094586, 177990, 64, 1, 27, "Subsubsection",
  CellTags->"i:21"],
Cell[5094653, 177993, 1198, 36, 95, "Text"],
Cell[5095854, 178031, 348, 11, 44, "Text"],
Cell[5096205, 178044, 702, 21, 29, "NumberedEquation",
  CellTags->"(8.1.33)"],
Cell[5096910, 178067, 2954, 95, 134, "Text"],
Cell[5099867, 178164, 189, 4, 27, "NumberedEquation",
  CellTags->"(8.1.34)"],
Cell[5100059, 178170, 639, 18, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5100735, 178193, 51, 0, 29, "Subsubsection"],
Cell[5100789, 178195, 1296, 45, 61, "Text",
  CellTags->"i:28"],
Cell[5102088, 178242, 354, 11, 30, "NumberedEquation",
  CellTags->"(8.1.35)"],
Cell[5102445, 178255, 710, 21, 61, "Text"],
Cell[5103158, 178278, 204, 6, 34, "NumberedEquation",
  CellTags->"(8.1.36)"],
Cell[5103365, 178286, 108, 3, 27, "Text"],
Cell[5103476, 178291, 199, 6, 32, "NumberedEquation",
  CellTags->"(8.1.37)"],
Cell[5103678, 178299, 491, 15, 52, "Text"],
Cell[5104172, 178316, 915, 24, 29, "NumberedEquation",
  CellTags->"(8.1.38)"],
Cell[5105090, 178342, 605, 21, 44, "Text"],
Cell[5105698, 178365, 1657, 41, 78, "UNNEQ"],
Cell[5107358, 178408, 151, 5, 27, "Text"],
Cell[5107512, 178415, 864, 23, 42, "NumberedEquation",
  CellTags->"(8.1.39)"],
Cell[5108379, 178440, 649, 20, 44, "Text",
  CellTags->"i:20"],
Cell[5109031, 178462, 278, 7, 43, "NumberedEquation",
  CellTags->"(8.1.40)"],
Cell[5109312, 178471, 2173, 65, 99, "Text",
  CellTags->"i:29"],
Cell[5111488, 178538, 699, 11, 112, "Text"],
Cell[5112190, 178551, 158, 6, 29, "NumberedEquation",
  CellTags->{"i:24", "(8.1.41)"}],
Cell[5112351, 178559, 340, 10, 44, "Text",
  CellTags->"i:22"],
Cell[5112694, 178571, 528, 10, 78, "Text",
  CellTags->"i:23"],
Cell[5113225, 178583, 1736, 32, 239, "Text"],
Cell[5114964, 178617, 4857, 153, 187, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5119858, 178775, 52, 0, 29, "Subsubsection"],
Cell[5119913, 178777, 260, 7, 44, "Text",
  CellTags->"i:25"],
Cell[5120176, 178786, 239, 7, 31, "NumberedEquation",
  CellTags->"(8.1.42)"],
Cell[5120418, 178795, 209, 6, 44, "Text"],
Cell[5120630, 178803, 151, 3, 27, "NumberedEquation",
  CellTags->"(8.1.43)"],
Cell[5120784, 178808, 384, 11, 44, "Text"],
Cell[5121171, 178821, 313, 8, 38, "UNNEQ"],
Cell[5121487, 178831, 608, 16, 63, "Text"],
Cell[5122098, 178849, 313, 7, 46, "UNNEQ"],
Cell[5122414, 178858, 186, 5, 27, "Text"],
Cell[5122603, 178865, 466, 8, 45, "UNNEQ"],
Cell[5123072, 178875, 415, 12, 44, "Text"],
Cell[5123490, 178889, 260, 4, 45, "NumberedEquation",
  CellTags->"(8.1.44)"],
Cell[5123753, 178895, 677, 17, 95, "Text",
  CellTags->"i:26"],
Cell[5124433, 178914, 1136, 23, 129, "Text"],
Cell[5125572, 178939, 629, 11, 95, "Text"],
Cell[5126204, 178952, 785, 19, 95, "Text",
  CellTags->"i:27"],
Cell[5126992, 178973, 1049, 30, 101, "Text"],
Cell[5128044, 179005, 375, 6, 78, "Text"],
Cell[5128422, 179013, 1321, 35, 129, "Text"],
Cell[5129746, 179050, 466, 8, 78, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5130273, 179065, 65, 1, 30, "Subsubtitle",
  CellTags->"c:10"],
Cell[5130341, 179068, 198, 5, 44, "Text"],
Cell[5130542, 179075, 331, 9, 44, "Text"],
Cell[5130876, 179086, 750, 21, 78, "Text"],
Cell[5131629, 179109, 262, 6, 44, "Text"],
Cell[5131894, 179117, 594, 12, 78, "Text"],
Cell[5132491, 179131, 172, 5, 27, "Text"],
Cell[5132666, 179138, 512, 9, 78, "Text"],
Cell[5133181, 179149, 168, 5, 27, "Text"],
Cell[5133352, 179156, 394, 9, 61, "Text"],
Cell[5133749, 179167, 155, 5, 27, "Text"],
Cell[5133907, 179174, 1108, 33, 82, "Text"],
Cell[5135018, 179209, 989, 34, 61, "Text"],
Cell[5136010, 179245, 284, 8, 41, "NumberedEquation",
  CellTags->"(8.1.45)"],
Cell[5136297, 179255, 1033, 36, 61, "Text"],
Cell[5137333, 179293, 240, 10, 27, "Text",
  CellTags->"i:32"],
Cell[5137576, 179305, 216, 7, 29, "NumberedEquation",
  CellTags->"(8.1.46)"],
Cell[5137795, 179314, 434, 18, 44, "Text"],
Cell[5138232, 179334, 467, 15, 47, "Text"],
Cell[5138702, 179351, 120, 4, 27, "Text"],
Cell[5138825, 179357, 220, 7, 36, "NumberedEquation",
  CellTags->"(8.1.47)"],
Cell[5139048, 179366, 361, 12, 44, "Text",
  CellTags->"i:33"],
Cell[5139412, 179380, 1278, 39, 85, "Text"],
Cell[5140693, 179421, 465, 18, 27, "Text"],
Cell[5141161, 179441, 667, 23, 44, "Text"],
Cell[5141831, 179466, 304, 11, 27, "Text"],
Cell[5142138, 179479, 224, 8, 27, "Text"],
Cell[5142365, 179489, 178, 7, 27, "Text"],
Cell[5142546, 179498, 226, 8, 44, "NumberedEquation",
  CellTags->"(8.1.48)"],
Cell[5142775, 179508, 507, 22, 27, "Text",
  CellTags->"i:34"],
Cell[5143285, 179532, 523, 18, 48, "Text"],
Cell[5143811, 179552, 387, 13, 44, "Text"],
Cell[5144201, 179567, 1639, 55, 78, "Text"],
Cell[5145843, 179624, 414, 15, 27, "Text"],
Cell[5146260, 179641, 289, 6, 44, "Text"],
Cell[5146552, 179649, 270, 9, 27, "Text"],
Cell[5146825, 179660, 1213, 38, 81, "Text",
  CellTags->"i:35"],
Cell[5148041, 179700, 831, 24, 67, "Text"],
Cell[5148875, 179726, 2028, 62, 104, "Text"],
Cell[5150906, 179790, 1269, 33, 129, "Text"],
Cell[5152178, 179825, 2745, 75, 138, "Text",
  CellTags->"i:36"],
Cell[5154926, 179902, 554, 17, 42, "NumberedEquation",
  CellTags->"(8.1.49)"],
Cell[5155483, 179921, 531, 16, 27, "Text",
  CellTags->"i:37"],
Cell[5156017, 179939, 763, 25, 44, "Text"],
Cell[5156783, 179966, 142, 4, 27, "Text"],
Cell[5156928, 179972, 1141, 37, 44, "Text"],
Cell[5158072, 180011, 922, 26, 48, "Text"],
Cell[5158997, 180039, 259, 8, 44, "Text"],
Cell[5159259, 180049, 216, 7, 27, "Text"],
Cell[5159478, 180058, 712, 21, 33, "UNNEQ"],
Cell[5160193, 180081, 642, 21, 44, "Text"],
Cell[5160838, 180104, 786, 27, 27, "Text"],
Cell[5161627, 180133, 1054, 31, 45, "NumberedEquation",
  CellTags->"(8.1.50)"],
Cell[5162684, 180166, 2140, 65, 72, "Text",
  CellTags->"i:40"],
Cell[5164827, 180233, 901, 29, 65, "Text",
  CellTags->"i:38"],
Cell[5165731, 180264, 146, 5, 29, "NumberedEquation",
  CellTags->"(8.1.51)"],
Cell[5165880, 180271, 165, 6, 27, "Text"],
Cell[5166048, 180279, 642, 20, 47, "Text"],
Cell[5166693, 180301, 1158, 37, 69, "Text"],
Cell[5167854, 180340, 991, 26, 42, "Text"],
Cell[5168848, 180368, 779, 20, 95, "Text",
  CellTags->"i:84"],
Cell[5169630, 180390, 509, 16, 44, "Text"],
Cell[5170142, 180408, 657, 21, 48, "Text"],
Cell[5170802, 180431, 1040, 25, 112, "Text",
  CellTags->"i:83"],
Cell[5171845, 180458, 1351, 35, 88, "Text"],
Cell[5173199, 180495, 575, 18, 31, "Text"],
Cell[5173777, 180515, 542, 12, 78, "Text",
  CellTags->"i:41"],
Cell[5174322, 180529, 815, 20, 95, "Text"],
Cell[5175140, 180551, 20645, 494, 225, 6491, 315, "GraphicsData", \
"PostScript", "Picture"],
Cell[5195788, 181047, 142, 4, 16, "Caption",
  CellTags->"Fig. 8.3"],
Cell[5195933, 181053, 254, 5, 44, "Text"],
Cell[5196190, 181060, 1191, 36, 92, "Text"],
Cell[5197384, 181098, 807, 20, 84, "Text"],
Cell[5198194, 181120, 2839, 81, 205, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5201082, 181207, 63, 1, 40, "Subtitle",
  CellTags->"c:11"],
Cell[5201148, 181210, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5201189, 181214, 92, 1, 41, "Subsubtitle",
  CellTags->{"i:43", "c:12"}],

Cell[CellGroupData[{
Cell[5201306, 181219, 57, 1, 42, "Section",
  CellTags->{"i:44", "c:13"}],
Cell[5201366, 181222, 593, 16, 61, "Text",
  CellTags->"i:64"],
Cell[5201962, 181240, 175, 6, 34, "NE2",
  CellTags->"(8.2.1)"],
Cell[5202140, 181248, 265, 9, 27, "Text"],
Cell[5202408, 181259, 1554, 45, 47, "Text"],
Cell[5203965, 181306, 630, 20, 44, "Text"],
Cell[5204598, 181328, 240, 7, 29, "NE2",
  CellTags->"(8.2.2)"],
Cell[5204841, 181337, 691, 20, 63, "Text"],
Cell[5205535, 181359, 235, 6, 31, "UNNEQ"],
Cell[5205773, 181367, 261, 6, 44, "Text"],
Cell[5206037, 181375, 771, 19, 32, "NE2",
  CellTags->"(8.2.3)"],
Cell[5206811, 181396, 578, 17, 44, "Text"],
Cell[5207392, 181415, 1149, 30, 29, "UNNEQ"],
Cell[5208544, 181447, 511, 15, 44, "Text"],
Cell[5209058, 181464, 929, 24, 32, "UNNEQ"],
Cell[5209990, 181490, 364, 12, 27, "Text"],
Cell[5210357, 181504, 488, 16, 29, "NE2",
  CellTags->"(8.2.4)"],
Cell[5210848, 181522, 883, 26, 48, "Text"],
Cell[5211734, 181550, 1566, 40, 73, "UNNEQ"],
Cell[5213303, 181592, 1477, 42, 48, "Text"],
Cell[5214783, 181636, 796, 23, 33, "NE2",
  CellTags->"(8.2.5)"],
Cell[5215582, 181661, 1575, 50, 65, "Text"],
Cell[5217160, 181713, 927, 27, 33, "NE2",
  CellTags->"(8.2.6)"],
Cell[5218090, 181742, 795, 25, 48, "Text"],
Cell[5218888, 181769, 680, 18, 42, "NE2",
  CellTags->"(8.2.7)"],
Cell[5219571, 181789, 585, 17, 31, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5220193, 181811, 96, 1, 31, "Section",
  CellTags->{"i:45", "c:14"}],
Cell[5220292, 181814, 1231, 38, 114, "Text"],
Cell[5221526, 181854, 143, 5, 29, "NE2",
  CellTags->"(8.2.8)"],
Cell[5221672, 181861, 2141, 65, 148, "Text"],
Cell[5223816, 181928, 149, 5, 29, "NE2",
  CellTags->"(8.2.9)"],
Cell[5223968, 181935, 1443, 43, 97, "Text"],
Cell[5225414, 181980, 1730, 55, 115, "Text"],
Cell[5227147, 182037, 253, 8, 31, "NE2",
  CellTags->"(8.2.10)"],
Cell[5227403, 182047, 799, 24, 61, "Text"],
Cell[5228205, 182073, 1428, 42, 99, "Text"],
Cell[5229636, 182117, 306, 7, 30, "UNNEQ"],
Cell[5229945, 182126, 1132, 35, 79, "Text",
  CellTags->"i:46"],
Cell[5231080, 182163, 250, 7, 31, "NE2",
  CellTags->"(8.2.11)"],
Cell[5231333, 182172, 160, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5231530, 182181, 70, 1, 31, "Section",
  CellTags->{"i:47", "c:15"}],
Cell[5231603, 182184, 378, 14, 44, "Text"],
Cell[5231984, 182200, 1757, 45, 42, "NE2",
  CellTags->"(8.2.12)"],
Cell[5233744, 182247, 2799, 89, 124, "Text"],
Cell[5236546, 182338, 381, 12, 44, "Text"],
Cell[5236930, 182352, 1663, 43, 42, "UNNEQ"],
Cell[5238596, 182397, 4591, 123, 191, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5243224, 182525, 75, 1, 31, "Section",
  CellTags->{"i:48", "c:16"}],
Cell[5243302, 182528, 1178, 34, 112, "Text"],
Cell[5244483, 182564, 709, 19, 63, "Text",
  CellTags->"i:49"],
Cell[5245195, 182585, 268, 6, 31, "NE2",
  CellTags->"(8.2.13)"],
Cell[5245466, 182593, 733, 19, 79, "Text"],
Cell[5246202, 182614, 195, 3, 31, "UNNEQ"],
Cell[5246400, 182619, 370, 14, 44, "Text"],
Cell[5246773, 182635, 430, 9, 45, "UNNEQ"],
Cell[5247206, 182646, 388, 13, 27, "Text",
  CellTags->"i:50"],
Cell[5247597, 182661, 306, 8, 39, "NE2",
  CellTags->"(8.2.14)"],
Cell[5247906, 182671, 116, 3, 27, "Text"],
Cell[5248025, 182676, 769, 21, 33, "NE2",
  CellTags->"(8.2.15)"],
Cell[5248797, 182699, 57, 0, 27, "Text"],
Cell[5248857, 182701, 788, 21, 31, "NE2",
  CellTags->"(8.2.16)"],
Cell[5249648, 182724, 607, 16, 61, "Text"],
Cell[5250258, 182742, 300, 8, 39, "UNNEQ"],
Cell[5250561, 182752, 127, 5, 27, "Text"],
Cell[5250691, 182759, 209, 8, 38, "NE2",
  CellTags->"(8.2.17)"],
Cell[5250903, 182769, 244, 9, 27, "Text",
  CellTags->"i:51"],
Cell[5251150, 182780, 254, 4, 39, "NE2",
  CellTags->"(8.2.18)"],
Cell[5251407, 182786, 581, 13, 78, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5252037, 182805, 60, 1, 30, "Subsubtitle",
  CellTags->"c:17"],
Cell[5252100, 182808, 691, 16, 78, "Text"],

Cell[CellGroupData[{
Cell[5252816, 182828, 70, 1, 42, "Section",
  CellTags->{"i:52", "c:18"}],
Cell[5252889, 182831, 1690, 49, 112, "Text"],
Cell[5254582, 182882, 179, 6, 29, "NE2",
  CellTags->"(8.2.19)"],
Cell[5254764, 182890, 32, 0, 27, "Text"],
Cell[5254799, 182892, 170, 6, 29, "NE2",
  CellTags->"(8.2.20)"],
Cell[5254972, 182900, 561, 19, 44, "Text"],
Cell[5255536, 182921, 200, 7, 32, "NE2",
  CellTags->"(8.2.21)"],
Cell[5255739, 182930, 417, 14, 44, "Text"],
Cell[5256159, 182946, 1080, 38, 70, "Text"],
Cell[5257242, 182986, 23996, 589, 233, 6135, 364, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5281241, 183577, 289, 12, 22, "Caption",
  CellTags->"Fig. 8.4"],
Cell[5281533, 183591, 1178, 37, 81, "Text"],

Cell[CellGroupData[{
Cell[5282736, 183632, 649, 15, 223, "Input",
  CellTags->"Cell 8.12"],
Cell[5283388, 183649, 80766, 1723, 233, 10936, 856, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5364169, 185375, 179, 6, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5364385, 185386, 65, 1, 31, "Section",
  CellTags->{"i:53", "c:19"}],
Cell[5364453, 185389, 685, 21, 61, "Text"],
Cell[5365141, 185412, 1189, 42, 78, "Text"],
Cell[5366333, 185456, 589, 21, 62, "Text"],
Cell[5366925, 185479, 249, 6, 124, "Input",
  CellTags->"Cell 8.13"],
Cell[5367177, 185487, 1099, 32, 79, "Text"],
Cell[5368279, 185521, 161, 4, 67, "Input",
  CellTags->"Cell 8.14"],
Cell[5368443, 185527, 903, 29, 61, "Text",
  CellTags->"i:63"],
Cell[5369349, 185558, 3104392, 42839, 211, 3069279, 42401, "GraphicsData", \
"PostScript", "Picture"],
Cell[8473744, 228399, 255, 7, 16, "Caption",
  CellTags->"Fig. 8.5"],
Cell[8474002, 228408, 1073, 36, 89, "Text"],
Cell[8475078, 228446, 199, 5, 105, "Input",
  CellTags->"Cell 8.15"],
Cell[8475280, 228453, 295, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[8475600, 228466, 158, 4, 86, "Input",
  CellTags->"Cell 8.16"],
Cell[8475761, 228472, 116376, 2215, 233, 11342, 914, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8592186, 230693, 81, 1, 31, "Section",
  CellTags->"c:20"],

Cell[CellGroupData[{
Cell[8592292, 230698, 39, 0, 27, "Subsubsection"],
Cell[8592334, 230700, 236, 6, 44, "Text"],
Cell[8592573, 230708, 271, 6, 40, "NE2",
  CellTags->"(8.2.22)"],
Cell[8592847, 230716, 399, 15, 44, "Text"],

Cell[CellGroupData[{
Cell[8593271, 230735, 486, 12, 195, "Input",
  CellTags->"Cell 8.17"],
Cell[8593760, 230749, 27558, 622, 233, 5709, 348, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8621333, 231374, 2381, 71, 65, "Text"],
Cell[8623717, 231447, 914, 30, 61, "Text"],

Cell[CellGroupData[{
Cell[8624656, 231481, 1364, 27, 352, "Input",
  CellTags->"Cell 8.18"],

Cell[CellGroupData[{
Cell[8626045, 231512, 23328, 709, 233, 8901, 526, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8649376, 232223, 9073, 531, 70, 8885, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8658452, 232756, 9072, 531, 70, 8884, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8667527, 233289, 9068, 531, 70, 8880, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8676598, 233822, 9069, 531, 70, 8881, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8685670, 234355, 9073, 531, 70, 8885, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8694746, 234888, 9063, 531, 70, 8875, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8703812, 235421, 9072, 531, 70, 8884, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8712887, 235954, 9063, 531, 70, 8875, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8721953, 236487, 9062, 531, 70, 8874, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8731018, 237020, 9068, 531, 70, 8880, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8740089, 237553, 9060, 531, 70, 8872, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8749152, 238086, 9067, 531, 70, 8879, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8758222, 238619, 9058, 531, 70, 8870, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8767283, 239152, 9064, 531, 70, 8876, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8776350, 239685, 9064, 531, 70, 8876, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8785417, 240218, 9062, 531, 70, 8874, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8794482, 240751, 9068, 531, 70, 8880, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8803553, 241284, 9062, 531, 70, 8874, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8812618, 241817, 9067, 531, 70, 8879, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8821688, 242350, 9072, 531, 70, 8884, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8830763, 242883, 9067, 531, 70, 8879, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8839833, 243416, 9068, 531, 70, 8880, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8848904, 243949, 9065, 531, 70, 8877, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8857972, 244482, 9056, 531, 70, 8868, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8867031, 245015, 9068, 531, 70, 8880, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8876102, 245548, 9075, 531, 70, 8887, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8885180, 246081, 9075, 531, 70, 8887, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8894258, 246614, 9054, 531, 70, 8866, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8903315, 247147, 9065, 531, 70, 8877, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8912383, 247680, 9063, 531, 70, 8875, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8921449, 248213, 9071, 531, 70, 8883, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8930523, 248746, 9065, 531, 70, 8877, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8939591, 249279, 9074, 531, 70, 8886, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8948668, 249812, 9058, 531, 70, 8870, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8957729, 250345, 9066, 531, 70, 8878, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8966798, 250878, 9060, 531, 70, 8872, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8975861, 251411, 9070, 531, 70, 8882, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8984934, 251944, 9068, 531, 70, 8880, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[8994005, 252477, 9057, 531, 70, 8869, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9003065, 253010, 9067, 531, 70, 8879, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9012135, 253543, 9067, 531, 70, 8879, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9021205, 254076, 9062, 531, 70, 8874, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9030270, 254609, 9065, 531, 70, 8877, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9039338, 255142, 9057, 531, 70, 8869, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9048398, 255675, 9065, 531, 70, 8877, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9057466, 256208, 9061, 531, 70, 8873, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9066530, 256741, 9062, 531, 70, 8874, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9075595, 257274, 9071, 531, 70, 8883, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9084669, 257807, 9063, 531, 70, 8875, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9093735, 258340, 9060, 531, 70, 8872, 526, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[9102822, 258875, 587, 18, 44, "Text"],
Cell[9103412, 258895, 46397, 1225, 205, 14164, 823, "GraphicsData", \
"PostScript", "Picture"],
Cell[9149812, 260122, 144, 4, 16, "Caption",
  CellTags->"Fig. 8.6"],
Cell[9149959, 260128, 73, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9150069, 260133, 62, 1, 29, "Subsubsection",
  CellTags->"i:54"],
Cell[9150134, 260136, 790, 23, 78, "Text"],
Cell[9150927, 260161, 345, 8, 40, "NE2",
  CellTags->"(8.2.23)"],
Cell[9151275, 260171, 326, 14, 27, "Text"],
Cell[9151604, 260187, 1727, 59, 112, "Text"],

Cell[CellGroupData[{
Cell[9153356, 260250, 1766, 35, 518, "Input",
  CellTags->"Cell 8.19"],

Cell[CellGroupData[{
Cell[9155147, 260289, 22946, 675, 233, 8300, 490, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9178096, 260966, 8467, 495, 70, 8280, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9186566, 261463, 8463, 495, 70, 8276, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9195032, 261960, 8463, 495, 70, 8276, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9203498, 262457, 8454, 494, 70, 8267, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9211955, 262953, 8434, 493, 70, 8247, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9220392, 263448, 8441, 494, 70, 8254, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9228836, 263944, 8445, 494, 70, 8258, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9237284, 264440, 8431, 493, 70, 8244, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9245718, 264935, 8446, 494, 70, 8259, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9254167, 265431, 8447, 494, 70, 8260, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9262617, 265927, 8436, 493, 70, 8249, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9271056, 266422, 8410, 492, 70, 8223, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9279469, 266916, 8402, 492, 70, 8215, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9287874, 267410, 8408, 492, 70, 8221, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9296285, 267904, 8416, 492, 70, 8229, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9304704, 268398, 8412, 492, 70, 8225, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9313119, 268892, 8405, 492, 70, 8218, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9321527, 269386, 8440, 494, 70, 8253, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9329970, 269882, 8454, 494, 70, 8267, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9338427, 270378, 8444, 494, 70, 8257, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9346874, 270874, 8408, 492, 70, 8221, 487, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9355285, 271368, 8443, 494, 70, 8256, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9363731, 271864, 8430, 493, 70, 8243, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9372164, 272359, 8437, 494, 70, 8250, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9380604, 272855, 8416, 493, 70, 8229, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9389023, 273350, 8467, 495, 70, 8280, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9397493, 273847, 8449, 494, 70, 8262, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9405945, 274343, 8424, 493, 70, 8237, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9414372, 274838, 8448, 494, 70, 8261, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9422823, 275334, 8434, 493, 70, 8247, 488, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9431260, 275829, 8460, 494, 70, 8273, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9439723, 276325, 8467, 495, 70, 8280, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9448193, 276822, 8470, 495, 70, 8283, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9456666, 277319, 8463, 495, 70, 8276, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9465132, 277816, 8470, 495, 70, 8283, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9473605, 278313, 8463, 495, 70, 8276, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9482071, 278810, 8463, 495, 70, 8276, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9490537, 279307, 8463, 495, 70, 8276, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9499003, 279804, 8456, 495, 70, 8269, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9507462, 280301, 8460, 495, 70, 8273, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9515925, 280798, 8460, 495, 70, 8273, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9524388, 281295, 8461, 495, 70, 8274, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9532852, 281792, 8460, 495, 70, 8273, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9541315, 282289, 8461, 495, 70, 8274, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9549779, 282786, 8464, 495, 70, 8277, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9558246, 283283, 8472, 495, 70, 8285, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9566721, 283780, 8468, 495, 70, 8281, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9575192, 284277, 8466, 495, 70, 8279, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9583661, 284774, 8472, 495, 70, 8285, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[9592136, 285271, 8442, 494, 70, 8255, 489, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[9600605, 285769, 554, 16, 61, "Text"],

Cell[CellGroupData[{
Cell[9601184, 285789, 278, 6, 105, "Input",
  CellTags->"Cell 8.20"],
Cell[9601465, 285797, 29744, 793, 233, 8808, 530, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9631224, 286593, 410, 11, 61, "Text",
  CellTags->"i:80"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9631695, 286611, 78, 1, 30, "Subsubtitle",
  CellTags->{"i:42", "c:21"}],

Cell[CellGroupData[{
Cell[9631798, 286616, 75, 1, 42, "Section",
  CellTags->{"i:56", "c:22"}],
Cell[9631876, 286619, 488, 12, 61, "Text"],
Cell[9632367, 286633, 360, 10, 40, "UNNEQ"],
Cell[9632730, 286645, 53, 0, 27, "Text"],
Cell[9632786, 286647, 213, 6, 40, "UNNEQ"],
Cell[9633002, 286655, 742, 21, 78, "Text"],
Cell[9633747, 286678, 227, 6, 51, "UNNEQ"],
Cell[9633977, 286686, 669, 22, 61, "Text"],
Cell[9634649, 286710, 449, 10, 70, "NE2",
  CellTags->"(8.2.24)"],
Cell[9635101, 286722, 705, 17, 78, "Text"],
Cell[9635809, 286741, 304, 8, 35, "NE2",
  CellTags->"(8.2.25)"],
Cell[9636116, 286751, 219, 8, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9636372, 286764, 67, 1, 31, "Section",
  CellTags->{"i:57", "c:23"}],
Cell[9636442, 286767, 755, 22, 61, "Text"],
Cell[9637200, 286791, 209, 6, 42, "NE2",
  CellTags->"(8.2.26)"],
Cell[9637412, 286799, 718, 19, 61, "Text"],
Cell[9638133, 286820, 189, 4, 42, "NE2",
  CellTags->"(8.2.27)"],
Cell[9638325, 286826, 359, 11, 44, "Text"],
Cell[9638687, 286839, 139, 5, 43, "NE2",
  CellTags->"(8.2.28)"],
Cell[9638829, 286846, 1077, 28, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9639943, 286879, 84, 1, 31, "Section",
  CellTags->{"i:58", "c:24"}],
Cell[9640030, 286882, 410, 12, 61, "Text"],
Cell[9640443, 286896, 661, 16, 31, "NE2",
  CellTags->"(8.2.29)"],
Cell[9641107, 286914, 214, 6, 27, "Text"],
Cell[9641324, 286922, 321, 5, 45, "NE2",
  CellTags->"(8.2.30)"],
Cell[9641648, 286929, 701, 14, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9642386, 286948, 66, 1, 31, "Section",
  CellTags->"c:25"],
Cell[9642455, 286951, 557, 17, 61, "Text"],
Cell[9643015, 286970, 198, 6, 32, "NE2",
  CellTags->"(8.2.31)"],
Cell[9643216, 286978, 1531, 41, 113, "Text"],

Cell[CellGroupData[{
Cell[9644772, 287023, 723, 15, 219, "Input",
  CellTags->"Cell 8.21"],
Cell[9645498, 287040, 43798, 981, 233, 7904, 533, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9689311, 288024, 512, 13, 61, "Text"],
Cell[9689826, 288039, 710, 27, 61, "Text"],
Cell[9690539, 288068, 95, 1, 27, "UNNEQ"],
Cell[9690637, 288071, 1319, 41, 80, "Text"],
Cell[9691959, 288114, 372, 10, 86, "Text"],
Cell[9692334, 288126, 52102, 1084, 233, 8008, 535, "GraphicsData", \
"PostScript", "Picture"],
Cell[9744439, 289212, 444, 13, 29, "Caption",
  CellTags->"Fig. 8.7"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9744932, 289231, 65, 1, 30, "Subsubtitle",
  CellTags->"c:30"],
Cell[9745000, 289234, 417, 12, 44, "Text"],
Cell[9745420, 289248, 235, 6, 44, "Text"],
Cell[9745658, 289256, 246, 6, 44, "Text"],
Cell[9745907, 289264, 160, 5, 27, "Text"],
Cell[9746070, 289271, 164, 5, 27, "Text"],
Cell[9746237, 289278, 151, 5, 27, "Text"],
Cell[9746391, 289285, 302, 6, 44, "Text"],
Cell[9746696, 289293, 1172, 22, 163, "Text"],
Cell[9747871, 289317, 331, 7, 61, "Text"],
Cell[9748205, 289326, 438, 12, 44, "Text",
  CellTags->"i:73"],
Cell[9748646, 289340, 242, 7, 38, "NE2",
  CellTags->"(8.2.32)"],
Cell[9748891, 289349, 295, 11, 27, "Text"],
Cell[9749189, 289362, 431, 15, 30, "Text"],
Cell[9749623, 289379, 243, 8, 27, "Text"],
Cell[9749869, 289389, 442, 14, 40, "NE2",
  CellTags->"(8.2.33)"],
Cell[9750314, 289405, 1502, 49, 70, "Text"],
Cell[9751819, 289456, 1448, 48, 61, "Text",
  CellTags->"i:92"],
Cell[9753270, 289506, 612, 16, 42, "UNNEQ"],
Cell[9753885, 289524, 1735, 55, 77, "Text"],
Cell[9755623, 289581, 440, 12, 61, "Text"],
Cell[9756066, 289595, 553, 19, 44, "Text"],
Cell[9756622, 289616, 680, 22, 31, "Text"],
Cell[9757305, 289640, 197, 5, 44, "Text"],
Cell[9757505, 289647, 714, 26, 61, "Text"],
Cell[9758222, 289675, 414, 13, 44, "Text"],
Cell[9758639, 289690, 953, 35, 31, "Text"],
Cell[9759595, 289727, 134, 4, 27, "Text"],
Cell[9759732, 289733, 1233, 32, 41, "UNNEQ"],
Cell[9760968, 289767, 411, 14, 44, "Text"],
Cell[9761382, 289783, 992, 29, 61, "Text"],
Cell[9762377, 289814, 343, 12, 38, "Text"],
Cell[9762723, 289828, 449, 15, 44, "Text",
  CellTags->"i:74"],
Cell[9763175, 289845, 279, 7, 38, "UNNEQ"],
Cell[9763457, 289854, 521, 17, 69, "Text",
  CellTags->"i:75"],
Cell[9763981, 289873, 242, 4, 42, "NE2",
  CellTags->"(8.2.34)"],
Cell[9764226, 289879, 672, 21, 31, "Text"],
Cell[9764901, 289902, 432, 16, 51, "Text",
  CellTags->"i:76"],
Cell[9765336, 289920, 359, 11, 44, "Text"],
Cell[9765698, 289933, 271, 6, 46, "UNNEQ"],
Cell[9765972, 289941, 246, 8, 29, "Text"],
Cell[9766221, 289951, 375, 11, 44, "Text"],
Cell[9766599, 289964, 371, 6, 62, "UNNEQ"],
Cell[9766973, 289972, 257, 8, 27, "Text"],
Cell[9767233, 289982, 1616, 41, 51, "UNNEQ"],
Cell[9768852, 290025, 1150, 38, 48, "Text"],
Cell[9770005, 290065, 294, 9, 44, "Text"],
Cell[9770302, 290076, 318, 11, 27, "Text"],
Cell[9770623, 290089, 309, 6, 42, "NE2",
  CellTags->"(8.2.35)"],
Cell[9770935, 290097, 1426, 46, 109, "Text"],
Cell[9772364, 290145, 811, 26, 61, "Text"],
Cell[9773178, 290173, 512, 11, 45, "Text"],
Cell[9773693, 290186, 421, 14, 44, "Text"],
Cell[9774117, 290202, 327, 11, 44, "Text"],
Cell[9774447, 290215, 1322, 28, 163, "Text",
  CellTags->"i:78"],
Cell[9775772, 290245, 110, 3, 67, "Input",
  CellTags->"Cell 8.22"],
Cell[9775885, 290250, 89, 3, 27, "Text"],
Cell[9775977, 290255, 153, 4, 67, "Input",
  CellTags->"Cell 8.23"],
Cell[9776133, 290261, 373, 12, 44, "Text"],
Cell[9776509, 290275, 234, 7, 86, "Input",
  CellTags->"Cell 8.24"],
Cell[9776746, 290284, 92, 3, 27, "Text"],
Cell[9776841, 290289, 163, 4, 67, "Input",
  CellTags->"Cell 8.25"],
Cell[9777007, 290295, 284, 5, 61, "Text"],
Cell[9777294, 290302, 1127, 25, 219, "Input",
  CellTags->"Cell 8.26"],
Cell[9778424, 290329, 337, 11, 44, "Text"],
Cell[9778764, 290342, 662, 20, 64, "Text"],
Cell[9779429, 290364, 856, 25, 95, "Text"],
Cell[9780288, 290391, 746, 21, 78, "Text"],
Cell[9781037, 290414, 175, 8, 27, "Text"],
Cell[9781215, 290424, 131459, 4307, 233, 65642, 3490, "GraphicsData", \
"PostScript", "Picture"],
Cell[9912677, 294733, 337, 10, 29, "Caption",
  CellTags->"Fig. 8.8"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9913063, 294749, 137, 2, 74, "Subtitle",
  CellTags->{"i:59", "c:26"}],
Cell[9913203, 294753, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[9913244, 294757, 55, 1, 41, "Subsubtitle",
  CellTags->"c:27"],
Cell[9913302, 294760, 2269, 63, 129, "Text",
  CellTags->"i:60"],
Cell[9915574, 294825, 2710, 71, 32, "NE3",
  CellTags->"(8.3.1)"],
Cell[9918287, 294898, 436, 9, 61, "Text"],
Cell[9918726, 294909, 2157, 56, 31, "UNNEQ"],
Cell[9920886, 294967, 122, 5, 27, "Text"],
Cell[9921011, 294974, 2515, 59, 33, "NE3",
  CellTags->"(8.3.2)"],
Cell[9923529, 295035, 2898, 85, 112, "Text",
  CellTags->"i:61"],
Cell[9926430, 295122, 3072, 88, 95, "Text"],
Cell[9929505, 295212, 6270, 154, 57, "NE3",
  CellTags->"(8.3.3)"],
Cell[9935778, 295368, 1064, 31, 78, "Text"],
Cell[9936845, 295401, 2385, 60, 31, "NE3",
  CellTags->"(8.3.4)"],
Cell[9939233, 295463, 99, 3, 27, "Text"],
Cell[9939335, 295468, 878, 24, 34, "NE3",
  CellTags->"(8.3.5)"],
Cell[9940216, 295494, 2004, 61, 85, "Text"],
Cell[9942223, 295557, 1205, 30, 129, "Text"],
Cell[9943431, 295589, 2189, 54, 180, "Text",
  CellTags->"i:85"],
Cell[9945623, 295645, 3457, 104, 95, "Text"],
Cell[9949083, 295751, 3343, 103, 97, "Text",
  CellTags->"i:62"],
Cell[9952429, 295856, 2193, 65, 30, "NE3",
  CellTags->"(8.3.6)"],
Cell[9954625, 295923, 1035, 31, 45, "Text"],
Cell[9955663, 295956, 681, 20, 31, "NE3",
  CellTags->"(8.3.7)"],
Cell[9956347, 295978, 486, 17, 28, "Text"],
Cell[9956836, 295997, 2567, 70, 69, "Text",
  CellTags->"i:65"],
Cell[9959406, 296069, 6751, 200, 68, "Text"],
Cell[9966160, 296271, 5500, 131, 32, "NE3",
  CellTags->"(8.3.8)"],
Cell[9971663, 296404, 4466, 128, 62, "Text"],
Cell[9976132, 296534, 2965, 87, 30, "NE3",
  CellTags->"(8.3.9)"],
Cell[9979100, 296623, 1366, 43, 44, "Text"],
Cell[9980469, 296668, 2272, 67, 32, "NE3",
  CellTags->"(8.3.10)"],
Cell[9982744, 296737, 5394, 171, 66, "Text",
  CellTags->"i:66"],
Cell[9988141, 296910, 1160, 31, 45, "Text"],
Cell[9989304, 296943, 6122, 146, 53, "NE3",
  CellTags->"(8.3.11)"],
Cell[9995429, 297091, 7824, 220, 67, "Text"],
Cell[10003256, 297313, 12847, 363, 120, "Text"],
Cell[10016106, 297678, 5559, 159, 81, "Text"],
Cell[10021668, 297839, 4631, 136, 141, "Text"],
Cell[10026302, 297977, 2816, 80, 135, "Text"],
Cell[10029121, 298059, 1454, 39, 130, "Text"],
Cell[10030578, 298100, 1518, 38, 40, "NE3",
  CellTags->{"i:67", "(8.3.12)"}],
Cell[10032099, 298140, 22, 0, 27, "Text"],
Cell[10032124, 298142, 1808, 49, 38, "UNNEQ"],
Cell[10033935, 298193, 123, 3, 27, "Text"],
Cell[10034061, 298198, 1321, 40, 31, "UNNEQ"],
Cell[10035385, 298240, 319, 11, 27, "Text"],
Cell[10035707, 298253, 1091, 32, 31, "UNNEQ"],
Cell[10036801, 298287, 396, 10, 61, "Text"],
Cell[10037200, 298299, 319, 8, 27, "NE3",
  CellTags->"(8.3.13)"],
Cell[10037522, 298309, 184, 8, 27, "Text"],
Cell[10037709, 298319, 1117, 31, 30, "NE3",
  CellTags->"(8.3.14)"],
Cell[10038829, 298352, 577, 16, 61, "Text"],
Cell[10039409, 298370, 540, 13, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10039986, 298388, 101, 4, 30, "Subsubtitle",
  CellTags->"c:32"],

Cell[CellGroupData[{
Cell[10040112, 298396, 70, 1, 42, "Section",
  CellTags->"c:28"],

Cell[CellGroupData[{
Cell[10040207, 298401, 67, 1, 27, "Subsubsection",
  CellTags->"i:68"],
Cell[10040277, 298404, 915, 26, 85, "Text"],
Cell[10041195, 298432, 663, 21, 48, "Text"],
Cell[10041861, 298455, 179, 4, 86, "Input",
  CellTags->"Cell 8.27"],
Cell[10042043, 298461, 1082, 32, 64, "Text"],
Cell[10043128, 298495, 1455, 30, 257, "Input",
  CellTags->"Cell 8.28"],
Cell[10044586, 298527, 2020, 55, 146, "Text",
  CellTags->"i:86"],
Cell[10046609, 298584, 182, 6, 27, "Text"],
Cell[10046794, 298592, 101, 3, 67, "Input",
  CellTags->"Cell 8.29"],
Cell[10046898, 298597, 67, 0, 27, "Text"],
Cell[10046968, 298599, 192, 4, 86, "Input",
  CellTags->"Cell 8.30"],
Cell[10047163, 298605, 476, 17, 27, "Text"],
Cell[10047642, 298624, 135, 3, 67, "Input",
  CellTags->"Cell 8.31"],
Cell[10047780, 298629, 153, 5, 27, "Text"],
Cell[10047936, 298636, 154, 4, 67, "Input",
  CellTags->"Cell 8.32"],
Cell[10048093, 298642, 143, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[10048261, 298649, 188, 5, 86, "Input",
  CellTags->"Cell 8.33"],
Cell[10048452, 298656, 41, 1, 46, "Output"]
}, Open  ]],
Cell[10048508, 298660, 125, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[10048658, 298667, 326, 8, 124, "Input",
  CellTags->"Cell 8.34"],
Cell[10048987, 298677, 54, 1, 46, "Output"]
}, Open  ]],
Cell[10049056, 298681, 229, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[10049310, 298691, 263, 7, 86, "Input",
  CellTags->"Cell 8.35"],

Cell[CellGroupData[{
Cell[10049598, 298702, 24585, 683, 233, 7344, 466, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10074186, 299387, 28960, 738, 233, 7316, 466, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10103149, 300127, 28922, 737, 233, 7331, 466, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10132074, 300866, 28702, 731, 233, 7249, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10160779, 301599, 28754, 731, 233, 7228, 461, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10189536, 302332, 28775, 733, 233, 7261, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10218314, 303067, 28809, 733, 70, 7242, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10247126, 303802, 28743, 732, 70, 7245, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10275872, 304536, 28731, 732, 70, 7253, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10304606, 305270, 28649, 731, 70, 7252, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10333258, 306003, 28549, 730, 70, 7241, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10361810, 306735, 28650, 729, 70, 7213, 460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10390463, 307466, 28759, 730, 70, 7192, 459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10419225, 308198, 28865, 732, 70, 7209, 460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10448093, 308932, 28845, 733, 70, 7246, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10476941, 309667, 29013, 736, 70, 7268, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10505957, 310405, 28936, 735, 70, 7264, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10534896, 311142, 28864, 734, 70, 7265, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10563763, 311878, 28913, 736, 70, 7306, 465, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10592679, 312616, 28745, 733, 70, 7263, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10621427, 313351, 28706, 732, 70, 7244, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10650136, 314085, 28743, 732, 70, 7249, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10678882, 314819, 28714, 733, 70, 7289, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10707599, 315554, 28808, 734, 70, 7286, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10736410, 316290, 28771, 732, 70, 7245, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10765184, 317024, 28791, 733, 70, 7265, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10793978, 317759, 28950, 735, 70, 7274, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10822931, 318496, 28958, 735, 70, 7270, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10851892, 319233, 28893, 736, 70, 7298, 465, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10880788, 319971, 28968, 737, 70, 7304, 465, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10909759, 320710, 28970, 736, 70, 7286, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10938732, 321448, 28949, 736, 70, 7285, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10967684, 322186, 28819, 734, 70, 7289, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10996506, 322922, 28948, 735, 70, 7272, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11025457, 323659, 28909, 735, 70, 7294, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11054369, 324396, 28887, 734, 70, 7268, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11083259, 325132, 28973, 736, 70, 7293, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11112235, 325870, 28924, 736, 70, 7288, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11141162, 326608, 29034, 737, 70, 7285, 464, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11170199, 327347, 28719, 732, 70, 7257, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11198921, 328081, 28947, 735, 70, 7271, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11227871, 328818, 28715, 731, 70, 7229, 461, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11256589, 329551, 28813, 734, 70, 7270, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11285405, 330287, 28783, 732, 70, 7249, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11314191, 331021, 28719, 732, 70, 7245, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11342913, 331755, 28590, 729, 70, 7209, 460, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11371506, 332486, 28854, 734, 70, 7263, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11400363, 333222, 28765, 732, 70, 7243, 462, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11429131, 333956, 28873, 734, 70, 7266, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11458007, 334692, 28925, 735, 70, 7269, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11486935, 335429, 28752, 731, 70, 7230, 461, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[11515714, 336164, 331, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[11516070, 336178, 324, 8, 105, "Input",
  CellTags->"Cell 8.36"],
Cell[11516397, 336188, 38781, 963, 233, 10681, 611, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11555193, 337154, 347, 8, 61, "Text"],

Cell[CellGroupData[{
Cell[11555565, 337166, 121, 3, 67, "Input",
  CellTags->"Cell 8.37"],
Cell[11555689, 337171, 52, 1, 46, "Output"]
}, Open  ]],
Cell[11555756, 337175, 95, 3, 27, "Text"],
Cell[11555854, 337180, 488, 10, 33, "NE3",
  CellTags->"(8.3.15)"],
Cell[11556345, 337192, 488, 16, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11556870, 337213, 155, 4, 29, "Subsubsection",
  CellTags->"i:70"],
Cell[11557028, 337219, 1254, 37, 53, "Text",
  CellTags->"i:90"],

Cell[CellGroupData[{
Cell[11558307, 337260, 168, 4, 67, "Input",
  CellTags->"Cell 8.38"],
Cell[11558478, 337266, 52, 1, 46, "Output"]
}, Open  ]],
Cell[11558545, 337270, 765, 22, 62, "Text"],
Cell[11559313, 337294, 753, 25, 42, "NE3",
  CellTags->"(8.3.16)"],
Cell[11560069, 337321, 5323, 159, 226, "Text"],
Cell[11565395, 337482, 2078, 58, 142, "Text"],
Cell[11567476, 337542, 1205, 40, 61, "Text"],
Cell[11568684, 337584, 1079, 32, 33, "NE3",
  CellTags->{"i:71", "(8.3.17)"}],
Cell[11569766, 337618, 3216, 102, 48, "Text"],
Cell[11572985, 337722, 254, 8, 44, "Text",
  CellTags->"i:88"],

Cell[CellGroupData[{
Cell[11573264, 337734, 424, 9, 162, "Input",
  CellTags->"Cell 8.39"],
Cell[11573691, 337745, 24061, 589, 233, 6503, 368, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11597767, 338337, 1205, 36, 99, "Text",
  CellTags->"i:87"],
Cell[11598975, 338375, 273, 10, 46, "Text"],

Cell[CellGroupData[{
Cell[11599273, 338389, 127, 3, 67, "Input",
  CellTags->"Cell 8.40"],
Cell[11599403, 338394, 53, 1, 46, "Output"]
}, Open  ]],
Cell[11599471, 338398, 418, 11, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11599926, 338414, 78, 0, 29, "Subsubsection"],
Cell[11600007, 338416, 594, 18, 44, "Text"],

Cell[CellGroupData[{
Cell[11600626, 338438, 741, 16, 238, "Input",
  CellTags->"Cell 8.41"],
Cell[11601370, 338456, 48791, 1058, 233, 8067, 551, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11650176, 339517, 499, 11, 78, "Text"],
Cell[11650678, 339530, 863, 28, 82, "Text",
  CellTags->"i:89"],
Cell[11651544, 339560, 1339, 41, 103, "Text"],
Cell[11652886, 339603, 1561, 49, 52, "Text"],
Cell[11654450, 339654, 1703, 42, 39, "Text"],
Cell[11656156, 339698, 1511, 43, 69, "Text"],
Cell[11657670, 339743, 365, 11, 33, "UNNEQ"],
Cell[11658038, 339756, 761, 22, 48, "Text"],
Cell[11658802, 339780, 688, 21, 33, "NE3",
  CellTags->"(8.3.18)"],
Cell[11659493, 339803, 464, 13, 48, "Text"],
Cell[11659960, 339818, 590, 16, 65, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11660599, 339840, 82, 1, 31, "Section",
  CellTags->{"i:72", "c:29"}],
Cell[11660684, 339843, 657, 18, 64, "Text",
  CellTags->"i:69"],
Cell[11661344, 339863, 273, 7, 124, "Input",
  CellTags->"Cell 8.42"],
Cell[11661620, 339872, 775, 22, 81, "Text"],
Cell[11662398, 339896, 258, 7, 44, "Text"],
Cell[11662659, 339905, 220, 5, 86, "Input",
  CellTags->"Cell 8.43"],
Cell[11662882, 339912, 166, 4, 44, "Text"],
Cell[11663051, 339918, 1113, 30, 36, "NE3",
  CellTags->"(8.3.19)"],
Cell[11664167, 339950, 1124, 36, 27, "Text"],
Cell[11665294, 339988, 317, 7, 105, "Input",
  CellTags->"Cell 8.44"],
Cell[11665614, 339997, 1397, 43, 44, "Text"],
Cell[11667014, 340042, 190, 6, 67, "Input",
  CellTags->"Cell 8.45"],
Cell[11667207, 340050, 268, 5, 61, "Text"],
Cell[11667478, 340057, 1108, 20, 171, "Text"],
Cell[11668589, 340079, 1614, 33, 295, "Input",
  CellTags->"Cell 8.46"],
Cell[11670206, 340114, 212, 4, 44, "Text"],
Cell[11670421, 340120, 557, 17, 44, "Text"],
Cell[11670981, 340139, 286, 6, 105, "Input",
  CellTags->"Cell 8.47"],
Cell[11671270, 340147, 130, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[11671425, 340154, 174, 4, 86, "Input",
  CellTags->"Cell 8.48"],
Cell[11671602, 340160, 41, 1, 46, "Output"]
}, Open  ]],
Cell[11671658, 340164, 147, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[11671830, 340171, 230, 5, 105, "Input",
  CellTags->"Cell 8.49"],
Cell[11672063, 340178, 54, 1, 46, "Output"]
}, Open  ]],
Cell[11672132, 340182, 273, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[11672430, 340193, 165, 4, 67, "Input",
  CellTags->"Cell 8.50"],
Cell[11672598, 340199, 271304, 13059, 233, 187149, 12015, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11943917, 353261, 619, 15, 78, "Text"],

Cell[CellGroupData[{
Cell[11944561, 353280, 135, 3, 67, "Input",
  CellTags->"Cell 8.51"],
Cell[11944699, 353285, 58, 1, 46, "Output"]
}, Open  ]],
Cell[11944772, 353289, 102, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[11944899, 353296, 177, 5, 67, "Input",
  CellTags->"Cell 8.52"],
Cell[11945079, 353303, 54, 1, 46, "Output"]
}, Open  ]],
Cell[11945148, 353307, 601, 20, 44, "Text"],

Cell[CellGroupData[{
Cell[11945774, 353331, 463, 10, 162, "Input",
  CellTags->"Cell 8.53"],
Cell[11946240, 353343, 25582, 619, 233, 6760, 382, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11971837, 353965, 779, 26, 44, "Text"],

Cell[CellGroupData[{
Cell[11972641, 353995, 141, 4, 67, "Input",
  CellTags->"Cell 8.54"],
Cell[11972785, 354001, 54, 1, 46, "Output"]
}, Open  ]],
Cell[11972854, 354005, 202, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[11973081, 354015, 320, 7, 105, "Input",
  CellTags->"Cell 8.55"],

Cell[CellGroupData[{
Cell[11973426, 354026, 50582, 1126, 370, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12024011, 355154, 50525, 1125, 70, 8276, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12074539, 356281, 50572, 1126, 70, 8278, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12125114, 357409, 50537, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12175654, 358536, 50556, 1125, 70, 8279, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12226213, 359663, 50555, 1125, 70, 8278, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12276771, 360790, 50560, 1125, 70, 8279, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12327334, 361917, 50508, 1125, 70, 8279, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12377845, 363044, 50525, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12428373, 364171, 50555, 1125, 70, 8278, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12478931, 365298, 50555, 1125, 70, 8278, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12529489, 366425, 50557, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12580049, 367552, 50555, 1125, 70, 8278, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12630607, 368679, 50541, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12681151, 369806, 50540, 1125, 70, 8279, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12731694, 370933, 50525, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12782222, 372060, 50560, 1125, 70, 8279, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12832785, 373187, 50516, 1125, 70, 8279, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12883304, 374314, 50539, 1125, 70, 8278, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12933846, 375441, 50529, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12984378, 376568, 50529, 1125, 70, 8280, 599, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[13034934, 377697, 863, 16, 112, "Text"],

Cell[CellGroupData[{
Cell[13035822, 377717, 99, 3, 67, "Input",
  CellTags->"Cell 8.56"],
Cell[13035924, 377722, 522, 8, 84, "Output"]
}, Open  ]],
Cell[13036461, 377733, 656, 18, 61, "Text"],

Cell[CellGroupData[{
Cell[13037142, 377755, 323, 7, 124, "Input",
  CellTags->"Cell 8.57"],
Cell[13037468, 377764, 40, 1, 46, "Output"]
}, Open  ]],
Cell[13037523, 377768, 321, 10, 27, "Text"],
Cell[13037847, 377780, 411, 9, 61, "Text"],
Cell[13038261, 377791, 21614, 542, 233, 5423, 338, "GraphicsData", \
"PostScript", "Picture"],
Cell[13059878, 378335, 452, 16, 16, "Caption",
  CellTags->"Fig. 8.9"],
Cell[13060333, 378353, 1560, 32, 180, "Text"],
Cell[13061896, 378387, 1272, 21, 180, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13063217, 378414, 65, 1, 30, "Subsubtitle",
  CellTags->"c:33"],
Cell[13063285, 378417, 1929, 58, 46, "Text"],
Cell[13065217, 378477, 2980, 84, 149, "Text"],
Cell[13068200, 378563, 326, 11, 44, "Text"],
Cell[13068529, 378576, 931, 35, 50, "Text"],
Cell[13069463, 378613, 701, 19, 64, "Text"],
Cell[13070167, 378634, 1272, 40, 64, "Text"],
Cell[13071442, 378676, 1124, 37, 47, "Text"],
Cell[13072569, 378715, 2042, 59, 113, "Text"],
Cell[13074614, 378776, 3496, 109, 96, "Text"],
Cell[13078113, 378887, 1862, 49, 70, "UNNEQ"],
Cell[13079978, 378938, 2478, 71, 126, "Text"],
Cell[13082459, 379011, 1247, 37, 95, "Text"],
Cell[13083709, 379050, 539, 9, 78, "Text"],
Cell[13084251, 379061, 761, 24, 61, "Text"],
Cell[13085015, 379087, 1114, 31, 99, "Text",
  CellTags->"i:77"],
Cell[13086132, 379120, 172, 6, 27, "Text"],
Cell[13086307, 379128, 235, 6, 51, "Text"],
Cell[13086545, 379136, 1998, 58, 177, "Text"],
Cell[13088546, 379196, 281, 10, 27, "Text"],
Cell[13088830, 379208, 328, 12, 31, "Text"],
Cell[13089161, 379222, 1225, 34, 95, "Text"],
Cell[13090389, 379258, 1082, 32, 95, "Text"],
Cell[13091474, 379292, 2531, 78, 149, "Text"],
Cell[13094008, 379372, 1009, 32, 61, "Text"],
Cell[13095020, 379406, 570, 15, 48, "Text"],
Cell[13095593, 379423, 1060, 36, 81, "Text"],
Cell[13096656, 379461, 1940, 67, 98, "Text"],
Cell[13098599, 379530, 2817, 76, 209, "Text"],
Cell[13101419, 379608, 233940, 4022, 291, 20783, 1386, "GraphicsData", \
"PostScript", "Picture"],
Cell[13335362, 383632, 396, 11, 33, "Caption",
  CellTags->"Fig. 8.10"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13335807, 383649, 60, 1, 40, "Subtitle",
  CellTags->{"refs", "c:31"}],
Cell[13335870, 383652, 415, 10, 46, "Text"],
Cell[13336288, 383664, 164, 5, 27, "Text"],
Cell[13336455, 383671, 302, 10, 44, "Text"],
Cell[13336760, 383683, 181, 5, 27, "Text"],
Cell[13336944, 383690, 193, 5, 27, "Text"],
Cell[13337140, 383697, 165, 5, 27, "Text"],
Cell[13337308, 383704, 267, 9, 44, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

